(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   8766384,     199154]*)
(*NotebookOutlinePosition[   8767119,     199179]*)
(*  CellTagsIndexPosition[   8767075,     199175]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Introduction to signals and systems", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " definitions"
}], "Section"],

Cell[CellGroupData[{

Cell["Load needed packages for this notebook", "Subsection"],

Cell[BoxData[{
    \(\(<< Graphics`Colors`;\)\), "\[IndentingNewLine]", 
    \(\(<< Miscellaneous`Audio`;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set up defaults", "Subsection"],

Cell[CellGroupData[{

Cell["Turn off annoying warning messages", "Subsubsection"],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set default options for specific functions", "Subsubsection"],

Cell[BoxData[{
    \(\(SetOptions[Plot, Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, Frame \[Rule] True, \ PlotJoined \[Rule] True, \ 
        Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Fourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization functions", "Subsection"],

Cell[CellGroupData[{

Cell["Fix time variable for sampled signals", "Subsubsection"],

Cell[BoxData[
    \(\(FixTime[signal_, 
          sampleRate_] := \[IndentingNewLine]Module[{time, 
            data}, \[IndentingNewLine]time = 
            Table[i/sampleRate, {i, 1, 
                Length[signal]}]; \[IndentingNewLine]data\  = \ {time, 
                signal} // Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate periodic waveform from one period", "Subsubsection"],

Cell["\<\
PeriodicSignal[f, {dmin, dmax}, {t, min, max}] generates a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax].\
\>", "Text"],

Cell[BoxData[
    \(\(PeriodicSignal[
          f_, {dmin_, dmax_}, {t_, min_, 
            max_}] := \[IndentingNewLine]Module[{T, imin, 
            imax}, \[IndentingNewLine]T\  = \ 
            dmax\  - \ dmin; \[IndentingNewLine]imin = 
            Floor[\((min - dmin)\)/T]; \[IndentingNewLine]imax = 
            Ceiling[\((max - dmax)\)/T]; \ \[IndentingNewLine]Sum[
            f[t - i\ T]\ \((UnitStep[t - dmin - i\ T]\  - \ 
                  UnitStep[t - dmax - i\ T])\), {i, imin, 
              imax}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot periodic waveforms", "Subsubsection"],

Cell[TextData[{
  "PeriodicPlot[f, {dmin, dmax}, {t, min, max}, opts] plots a a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax]. The 'opts' argument \
passed plotting options to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Plot[ ]."
}], "Text"],

Cell[BoxData[
    \(\(PeriodicPlot[f_, {dmin_, dmax_}, {t_, min_, max_}, 
          opts___] := \[IndentingNewLine]Module[{fnc}, \[IndentingNewLine]fnc \
= PeriodicSignal[f, {dmin, dmax}, {t, min, max}]; \[IndentingNewLine]Plot[
            fnc, {t, min, max}, opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .015], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Filtering definitions", "Subsection"],

Cell[TextData[{
  "FourierRearrange[fft] rearranges the result of an FFT (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Fourier[ ]), to a easier to visualize the spectrum represented \
by 'fft'. The length of the list 'fft' is assumed to be even; if it is not, \
the last term in 'fft' is dropped. "
}], "Text"],

Cell[BoxData[
    \(\(FourierRearrange[fft_, \ 
          samplingRate_] := \[IndentingNewLine]Module[{fft2, n, 
            n2}, \[IndentingNewLine]If[EvenQ[Length[fft]], \ 
            fft2\  = \ fft, \ 
            fft2\  = \ Drop[fft, \(-1\)]]; \ \[IndentingNewLine]n = 
            Length[fft]; 
          n2 = n/2; \[IndentingNewLine]{Table[\ 
                samplingRate\ i/n, {i, \(-n2\) + 1, n2}], 
              Take[fft2, {n2 + 2, n2*2}]~Join~Take[fft2, {1, n2 + 1}]} // 
            Transpose\[IndentingNewLine]];\)\)], "Input"],

Cell["\<\
Filter[n, sampleRate, {lowFreq, highFreq}] generates an ideal \
discrete filter for an FFT list of length 'n' (sampled at 'sampleRate'), with \
a bandpass from 'lowFreq' to 'highFreq' (in Hz).\
\>", "Text"],

Cell[BoxData[
    \(\(Filter[n_, 
          samplingRate_, {lowF_, 
            highF_}] := \[IndentingNewLine]Module[{coeff, l, 
            h}, \[IndentingNewLine]coeff = 
            Table[0, {n}]; \[IndentingNewLine]l = Floor[lowF*n/samplingRate]; 
          h = Ceiling[highF*n/samplingRate]; \[IndentingNewLine]If[
            l\  == \ 0, \ l\  = \ 1; \ 
            coeff = ReplacePart[coeff, 1, 1]]; \[IndentingNewLine]coeff = 
            ReplacePart[coeff, 1, Table[{i}, {i, l + 1, h + 1}]]; 
          coeff = ReplacePart[coeff, 1, 
              Table[{i}, {i, n + 1 - h, 
                  n + 1 - l}]]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sample signals", "Section"],

Cell[CellGroupData[{

Cell["Simple signals", "Subsection"],

Cell[CellGroupData[{

Cell["Example #1", "Subsubsection"],

Cell[BoxData[
    \(\(s1\  = \ Sin[2  \[Pi]\ t];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Plot[s1, {t, 0, 2}, \ 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\[Florin][t]\  == s1\  // \ TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309012 0.294307 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -12 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16186 -24 -4.5 ]
[-0.0125 .16186 0 4.5 ]
[-0.0125 .30901 -6 -4.5 ]
[-0.0125 .30901 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(-1)] -0.0125 .01471 1 0 Mshowa
0 .16186 m
.00625 .16186 L
s
[(-0.5)] -0.0125 .16186 1 0 Mshowa
0 .30901 m
.00625 .30901 L
s
[(0)] -0.0125 .30901 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07357 m
.00375 .07357 L
s
0 .103 m
.00375 .103 L
s
0 .13243 m
.00375 .13243 L
s
0 .19129 m
.00375 .19129 L
s
0 .22072 m
.00375 .22072 L
s
0 .25015 m
.00375 .25015 L
s
0 .27958 m
.00375 .27958 L
s
0 .33844 m
.00375 .33844 L
s
0 .36787 m
.00375 .36787 L
s
0 .3973 m
.00375 .3973 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16186 m
1 .16186 L
s
.99375 .30901 m
1 .30901 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07357 m
1 .07357 L
s
.99625 .103 m
1 .103 L
s
.99625 .13243 m
1 .13243 L
s
.99625 .19129 m
1 .19129 L
s
.99625 .22072 m
1 .22072 L
s
.99625 .25015 m
1 .25015 L
s
.99625 .27958 m
1 .27958 L
s
.99625 .33844 m
1 .33844 L
s
.99625 .36787 m
1 .36787 L
s
.99625 .3973 m
1 .3973 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30901 m
1 .30901 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30901 m
.06244 .45263 L
.08255 .51497 L
.0932 .54236 L
.10458 .56657 L
.11009 .57624 L
.11531 .58409 L
.12038 .59047 L
.12507 .59525 L
.12951 .59877 L
.13178 .60018 L
.13422 .60141 L
.13549 .60193 L
.13666 .60234 L
.13784 .60268 L
.13895 .60293 L
.14022 .60314 L
.1409 .60322 L
.14161 .60328 L
.1423 .60331 L
.14295 .60332 L
.14415 .60328 L
.14531 .60316 L
.14656 .60297 L
.14773 .60271 L
.14881 .60241 L
.15143 .60144 L
.15392 .60019 L
.15886 .59679 L
.16423 .59169 L
.17383 .57909 L
.1827 .56357 L
.20137 .51988 L
.22197 .45702 L
.26217 .30797 L
.30086 .16431 L
.32051 .10345 L
.3309 .07659 L
.342 .05273 L
.35275 .03484 L
.35784 .02829 L
.36253 .02336 L
.36724 .01951 L
.36972 .01793 L
.37235 .0166 L
.37463 .01573 L
.37573 .01541 L
.37677 .01515 L
.37799 .01493 L
.37911 .01479 L
Mistroke
.38031 .01472 L
.38162 .01472 L
.38227 .01475 L
.38296 .01481 L
.38419 .01497 L
.38551 .01524 L
.38695 .01563 L
.38955 .0166 L
.39197 .01781 L
.39649 .02087 L
.40134 .02529 L
.40698 .03189 L
.41232 .03955 L
.42232 .05747 L
.44227 .10589 L
.4607 .16316 L
.50002 .3091 L
.53782 .44987 L
.55884 .51523 L
.56803 .53913 L
.57808 .56136 L
.58722 .57774 L
.59696 .59091 L
.60236 .59621 L
.60726 .59976 L
.60962 .60104 L
.61086 .6016 L
.61218 .60211 L
.61333 .60248 L
.61459 .60281 L
.61574 .60304 L
.61682 .60319 L
.61808 .60329 L
.61871 .60332 L
.61941 .60332 L
.62065 .60325 L
.62181 .60312 L
.62248 .60302 L
.62318 .60288 L
.62443 .60258 L
.62578 .60216 L
.62725 .6016 L
.62973 .6004 L
.63238 .59878 L
.63715 .59497 L
.64214 .58976 L
.64686 .58372 L
.6557 .56958 L
.67568 .52489 L
.69413 .47033 L
Mistroke
.7335 .32685 L
.77136 .18396 L
.79241 .11569 L
.81166 .06613 L
.82118 .04723 L
.8262 .03889 L
.83155 .03132 L
.8367 .02535 L
.84136 .02107 L
.84361 .01939 L
.84604 .01786 L
.84835 .01668 L
.85045 .01585 L
.85159 .01549 L
.85283 .01518 L
.85414 .01494 L
.85538 .01479 L
.85653 .01472 L
.85776 .01472 L
.85881 .01478 L
.85997 .01491 L
.86063 .01502 L
.86132 .01515 L
.86256 .01546 L
.86535 .01643 L
.86777 .01759 L
.87041 .0192 L
.87569 .02347 L
.88133 .02956 L
.89148 .04439 L
.90173 .06419 L
.91284 .09067 L
.933 .15021 L
.97393 .30025 L
.97619 .30901 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`008?ooool2o`0003Kooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol0000eooooo`?o0000=?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0003Co
oooo1Ol00006ooooo`007oooool01?l0003oooooooooool0000dooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000003Cooooo00Co0000oooooooooooo0000
1_ooool001oooooo00Co0000oooooooooooo0000=?ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool01_ooool001oooooo00Co0000oooooooooooo
0000=?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01Oooool001oooooo00Co0000oooooooooooo0000=?ooool01?l0003oooooooooool00007
ooooo`Co0000=_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo1?l0000d
ooooo`05o`000?ooooooooooooooool000001_ooool001oooooo00Co0000oooooooooooo0000=?oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo03Kooooo0_l0000eooooo`;o0000
2Oooool00ol0003oooooooooo`0eooooo`05o`000?ooooooooooooooool000001_ooool0023ooooo
0_l0000fooooo`;o00002?ooool5o`0003Gooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`07ooooo`Go0000=?ooool3o`0000Oooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo000Koooooooo00001Ol00001ooooo`004oooool3
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool000cooooo1Ol00003ooooo`03
o`000?oooooooooo00Cooooo0_l0001Pooooo`;o003oN_ooool2o`00ob;ooooo0_l00001ooooo`00
5?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05gooooo0ol00?l01?oooooo003o
o`00ool00?mdooooo`?o003o00Coooooo`00ool00?oo003o8Oooool1o`00007ooooo000Dooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0G?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo073ooooo0_l00?l6ooooo`03o`00oooooooooooo01kooooo0Ol00001ooooo`00
4oooool2o`0000Kooooo00?o0000ooooooooool0Foooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo06kooooo00?o003oooooooooool01oooool20000oakooooo0Ol00001ooooo`005?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`1^ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool06ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo05Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`1/ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool06oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`1Zooooo`030000oooooooooooo00cooooo00<0003oooooooooool06_ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`1Xooooo`030000oooooooooooo00gooooo00<0003oooooooooool06_ooool1o`00007o
oooo000Kooooo`;o0000F?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo06Sooooo
00<0003oooooooooool03_ooool00`000?ooooooooooo`0Hooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool0Eoooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo06Kooooo00<0
003oooooooooool03oooool00`000?ooooooooooo`0Iooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0E_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo06Kooooo00<0003o
ooooooooool04?ooool00`000?ooooooooooo`0Hooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0E_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo06Gooooo00<0003ooooo
ooooool04_ooool00`000?ooooooooooo`0Gooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0EOooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo06?ooooo00<0003ooooooooo
ool04oooool00`000?ooooooooooo`0Gooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
EOooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo06?ooooo00<0003oooooooooool0
5?ooool00`000?ooooooooooo`0Fooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0E?oo
ool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo067ooooo00<0003oooooooooool05Ooo
ool00`000?ooooooooooo`0Fooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0E?ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo067ooooo00<0003oooooooooool05_ooool0
0`000?ooooooooooo`0Eooooo`7o00000Oooool001_ooooo0_l0001Dooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool0Goooool00`000?ooooooooooo`0Gooooo`030000oooooooooooo
01Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1Cooooo`03o`00oooooooooooo01Ko
oooo00?o003oooooooooool0Goooool00`000?ooooooooooo`0Hooooo`030000oooooooooooo01Co
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool0G_ooool00`000?ooooooooooo`0Hooooo`030000oooooooooooo01Cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1Booooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool0GOooool00`000?ooooooooooo`0Iooooo`030000oooooooooooo01Cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool0G?ooool00`000?ooooooooooo`0Jooooo`030000oooooooooooo01?ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool0Foooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo01?ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1Aooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool0F_ooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo01?ooooo0Ol00001ooooo`00
6oooool2o`00057ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`1Jooooo`030000
oooooooooooo01cooooo00<0003oooooooooool04Oooool2o`00007ooooo000Kooooo`03o`000?oo
oooooooo053ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`1Hooooo`030000oooo
oooooooo01gooooo00<0003oooooooooool04_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo053ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`1Hooooo`030000oooooooo
oooo01gooooo00<0003oooooooooool04_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
04oooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`1Hooooo`030000oooooooooooo
01kooooo00<0003oooooooooool04Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04oo
oooo00?o003oooooooooool07oooool00ol00?ooooooooooo`1Fooooo`030000oooooooooooo01oo
oooo00<0003oooooooooool04Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04oooooo
00?o003oooooooooool07oooool00ol00?ooooooooooo`1Fooooo`030000oooooooooooo01oooooo
00<0003oooooooooool04Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04kooooo00?o
003oooooooooool08?ooool00ol00?ooooooooooo`1Fooooo`030000oooooooooooo023ooooo00<0
003oooooooooool04?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04kooooo00?o003o
ooooooooool08?ooool00ol00?ooooooooooo`1Eooooo`030000oooooooooooo027ooooo00<0003o
ooooooooool04?ooool1o`00007ooooo000Kooooo`;o0000Coooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo05Cooooo00<0003oooooooooool08Oooool00`000?ooooooooooo`0?oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`0Rooooo`03
o`00oooooooooooo05Cooooo00<0003oooooooooool08_ooool00`000?ooooooooooo`0?ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`0Rooooo`03o`00
oooooooooooo05?ooooo00<0003oooooooooool08oooool00`000?ooooooooooo`0?ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`0Sooooo`03o`00oooo
oooooooo05;ooooo00<0003oooooooooool08oooool00`000?ooooooooooo`0?ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooo
oooo05;ooooo00<0003oooooooooool09?ooool00`000?ooooooooooo`0>ooooo`7o00000Oooool0
00Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo
04cooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`1Aooooo`030000oooooooooooo
02Gooooo00<0003oooooooooool03_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo04cooooo00?o003o
ooooooooool09?ooool00ol00?ooooooooooo`1Aooooo`030000oooooooooooo02Gooooo00<0003o
ooooooooool03_ooool1o`00007ooooo0005o`0000;ooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool09_ooool0
0ol00?ooooooooooo`1@ooooo`030000oooooooooooo02Gooooo00<0003oooooooooool03_ooool1
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2
o`0004cooooo00?o003oooooooooool09_ooool00ol00?ooooooooooo`1@ooooo`030000oooooooo
oooo02Kooooo00<0003oooooooooool03?ooool2o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Oooooo1?l00005ooooo`03o`000?oooooooooo04_ooooo00?o003oooooooooool09_ooool0
0ol00?ooooooooooo`1?ooooo`030000oooooooooooo02Oooooo00<0003oooooooooool03Oooool1
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1;ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool0Coooool0
0`000?ooooooooooo`0Wooooo`030000oooooooooooo00gooooo0Ol00001ooooo`002?ooool2o`00
00Sooooo1Ol00004ooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool0:?ooool00ol0
0?ooooooooooo`1>ooooo`030000oooooooooooo02Sooooo00<0003oooooooooool03?ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool0:?ooool00ol00?oo
ooooooooo`1=ooooo`030000oooooooooooo02Wooooo00<0003oooooooooool03?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool0:?ooool00ol00?oooooo
ooooo`1=ooooo`030000oooooooooooo02Wooooo00<0003oooooooooool03?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo04[ooooo00?o003oooooooooool0:Oooool00ol00?oooooooooo
o`1<ooooo`030000oooooooooooo02Wooooo00<0003oooooooooool03?ooool1o`00007ooooo000K
ooooo`;o0000B_ooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo04cooooo00<0003o
ooooooooool0:_ooool00`000?ooooooooooo`0:ooooo`;o00000Oooool001_ooooo00?o0000oooo
ooooool0BOooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo04_ooooo00<0003ooooo
ooooool0:oooool00`000?ooooooooooo`0;ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0BOooool00ol00?ooooooooooo`0Zooooo`03o`00oooooooooooo04_ooooo00<0003ooooooooo
ool0:oooool00`000?ooooooooooo`0;ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
B?ooool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo04[ooooo00<0003oooooooooool0
;?ooool00`000?ooooooooooo`0:ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0B?oo
ool00ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo04[ooooo00<0003oooooooooool0;?oo
ool00`000?ooooooooooo`0:ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0B?ooool0
0ol00?ooooooooooo`0/ooooo`03o`00oooooooooooo04Wooooo00<0003oooooooooool0;Oooool0
0`000?ooooooooooo`0:ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0B?ooool00ol0
0?ooooooooooo`0]ooooo`03o`00oooooooooooo04Sooooo00<0003oooooooooool0;Oooool00`00
0?ooooooooooo`0:ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Aoooool00ol00?oo
ooooooooo`0^ooooo`03o`00oooooooooooo04Sooooo00<0003oooooooooool0;_ooool00`000?oo
ooooooooo`09ooooo`7o00000Oooool001_ooooo0_l00018ooooo`03o`00oooooooooooo02kooooo
00?o003oooooooooool0Aoooool00`000?ooooooooooo`0_ooooo`030000oooooooooooo00Sooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`17ooooo`03o`00oooooooooooo02kooooo00?o
003oooooooooool0Aoooool00`000?ooooooooooo`0_ooooo`030000oooooooooooo00Wooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`17ooooo`03o`00oooooooooooo02oooooo00?o003o
ooooooooool0A_ooool00`000?ooooooooooo`0`ooooo`030000oooooooooooo00Sooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo033ooooo00?o003ooooo
ooooool0A_ooool00`000?ooooooooooo`0`ooooo`030000oooooooooooo00Sooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo033ooooo00?o003ooooooooo
ool0AOooool00`000?ooooooooooo`0aooooo`030000oooooooooooo00Sooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0
A?ooool00`000?ooooooooooo`0aooooo`030000oooooooooooo00Sooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`16ooooo`03o`00oooooooooooo037ooooo00?o003oooooooooool0A?oo
ool00`000?ooooooooooo`0booooo`030000oooooooooooo00Oooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`15ooooo`03o`00oooooooooooo03;ooooo00?o003oooooooooool0A?ooool0
0`000?ooooooooooo`0booooo`030000oooooooooooo00Oooooo0Ol00001ooooo`006oooool2o`00
04Kooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`12ooooo`030000oooooooooooo
03?ooooo00<0003oooooooooool01_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo04Go
oooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`12ooooo`030000oooooooooooo03?o
oooo00<0003oooooooooool01oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04Gooooo
00?o003oooooooooool0<oooool00ol00?ooooooooooo`12ooooo`030000oooooooooooo03Cooooo
00<0003oooooooooool01_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04Cooooo00?o
003oooooooooool0=?ooool00ol00?ooooooooooo`11ooooo`030000oooooooooooo03Gooooo00<0
003oooooooooool01_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04Cooooo00?o003o
ooooooooool0=Oooool00ol00?ooooooooooo`10ooooo`030000oooooooooooo03Gooooo00<0003o
ooooooooool01_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04Cooooo00?o003ooooo
ooooool0=Oooool00ol00?ooooooooooo`10ooooo`030000oooooooooooo03Kooooo00<0003ooooo
ooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04?ooooo00?o003ooooooooo
ool0=_ooool00ol00?ooooooooooo`10ooooo`030000oooooooooooo03Kooooo00<0003ooooooooo
ool01Oooool1o`00007ooooo000Kooooo`;o0000A?ooool00ol00?ooooooooooo`0gooooo`03o`00
oooooooooooo03kooooo00<0003oooooooooool0=oooool00`000?ooooooooooo`04ooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0gooooo`03o`00oooo
oooooooo03kooooo00<0003oooooooooool0=oooool00`000?ooooooooooo`05ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0@oooool00ol00?ooooooooooo`0gooooo`03o`00oooooooo
oooo03kooooo00<0003oooooooooool0>?ooool00`000?ooooooooooo`04ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`0hooooo`03o`00oooooooooooo
03kooooo00<0003oooooooooool0>?ooool00`000?ooooooooooo`04ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03co
oooo00<0003oooooooooool0>Oooool00`000?ooooooooooo`04ooooo`7o00000Oooool001Cooooo
0_l00005ooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0>Oooool00ol00?oooooo
ooooo`0looooo`030000oooooooooooo03[ooooo00<0003oooooooooool00oooool1o`00007ooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0@_ooool00ol00?oooooo
ooooo`0iooooo`03o`00oooooooooooo03cooooo00<0003oooooooooool0>_ooool00`000?oooooo
ooooo`03ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`11ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0>_ooool00`000?oooooo
ooooo`0kooooo`030000oooooooooooo00?ooooo0Ol00001ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`Ko000000?o003oo`000?l00000>ol000000ol00?oo0000o`00000ko`000003o`00
ool0003o000003[o000000<0003oo`000?l00000>ol000000`000?oo0000o`000004o`00007ooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`0kooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0>_ooool00`000?oooooo
ooooo`11ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0>oooool00ol00?oooooo
ooooo`0jooooo`030000oooooooooooo047ooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o
0000ooooooooool01?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03gooooo00?o
003oooooooooool0>?ooool00`000?ooooooooooo`12ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool01?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03gooooo00?o003o
ooooooooool0>?ooool00`000?ooooooooooo`12ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool01?ooool00ol00?ooooooooooo`0iooooo`03o`00oooooooooooo03gooooo00?o003ooooo
ooooool0>?ooool00`000?ooooooooooo`12ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool01?ooool00ol00?ooooooooooo`0hooooo`03o`00oooooooooooo03kooooo00?o003ooooooooo
ool0>?ooool00`000?ooooooooooo`12ooooo`7o00000Oooool001_ooooo0_l00006ooooo`03o`00
oooooooooooo03Oooooo00?o003oooooooooool0?oooool00ol00?ooooooooooo`0fooooo`030000
oooooooooooo04;ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo03Oooooo00?o003oooooooooool0?oooool00ol00?ooooooooooo`0fooooo`030000oooo
oooooooo04?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo03Oooooo00?o003oooooooooool0?oooool00ol00?ooooooooooo`0fooooo`030000oooooooo
oooo04?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo
03Gooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`0fooooo`030000oooooooooooo
04?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo03Go
oooo00?o003oooooooooool0@Oooool00ol00?ooooooooooo`0dooooo`030000oooooooooooo04Co
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo03Gooooo
00?o003oooooooooool0@Oooool00ol00?ooooooooooo`0dooooo`030000oooooooooooo04Cooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo03Cooooo00?o
003oooooooooool0@_ooool00ol00?ooooooooooo`0dooooo`030000oooooooooooo04Cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo03?ooooo00?o003o
ooooooooool0@_ooool00ol00?ooooooooooo`0cooooo`030000oooooooooooo04Gooooo0Ol00001
ooooo`006oooool2o`0000Sooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`13oooo
o`03o`00oooooooooooo03;ooooo00<0003oooooooooool0A?ooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool0<oooool00ol00?ooooooooooo`13ooooo`03
o`00oooooooooooo03;ooooo00<0003oooooooooool0AOooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00Oooooo00?o003oooooooooool0<_ooool00ol00?ooooooooooo`14ooooo`03o`00
oooooooooooo03;ooooo00<0003oooooooooool0AOooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00Sooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`14ooooo`03o`00oooo
oooooooo037ooooo00<0003oooooooooool0A_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooooooool0<Oooool00ol00?ooooooooooo`15ooooo`03o`00oooooooo
oooo033ooooo00<0003oooooooooool0A_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00Sooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo
033ooooo00<0003oooooooooool0A_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Wo
oooo00?o003oooooooooool0;oooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo033o
oooo00<0003oooooooooool0A_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Wooooo
00?o003oooooooooool0;oooool00ol00?ooooooooooo`16ooooo`03o`00oooooooooooo02oooooo
00<0003oooooooooool0Aoooool1o`00007ooooo000Kooooo`;o00002_ooool00ol00?oooooooooo
o`0^ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool0;_ooool00`000?oooooooooo
o`16ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`0^
ooooo`03o`00oooooooooooo04Sooooo00?o003oooooooooool0;_ooool00`000?ooooooooooo`17
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0]oooo
o`03o`00oooooooooooo04Sooooo00?o003oooooooooool0;_ooool00`000?ooooooooooo`17oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0]ooooo`03
o`00oooooooooooo04Sooooo00?o003oooooooooool0;Oooool00`000?ooooooooooo`18ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0/ooooo`03o`00
oooooooooooo04[ooooo00?o003oooooooooool0;?ooool00`000?ooooooooooo`18ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0/ooooo`03o`00oooo
oooooooo04[ooooo00?o003oooooooooool0;?ooool00`000?ooooooooooo`18ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`0[ooooo`03o`00oooooooo
oooo04[ooooo00?o003oooooooooool0;?ooool00`000?ooooooooooo`18ooooo`7o00000Oooool0
01_ooooo0_l0000<ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0Boooool00ol0
0?ooooooooooo`0[ooooo`030000oooooooooooo04Sooooo0_l00001ooooo`006oooool00ol0003o
ooooooooo`0;ooooo`03o`00oooooooooooo02[ooooo00?o003oooooooooool0C?ooool00ol00?oo
ooooooooo`0Zooooo`030000oooooooooooo04Wooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`0<ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool0C?ooool00ol00?oooooo
ooooo`0Zooooo`030000oooooooooooo04Wooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`0<ooooo`03o`00oooooooooooo02Wooooo00?o003oooooooooool0C?ooool00ol00?oooooooooo
o`0Yooooo`030000oooooooooooo04[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0<
ooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool0COooool00ol00?ooooooooooo`0Y
ooooo`030000oooooooooooo04[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0<oooo
o`03o`00oooooooooooo02Sooooo00?o003oooooooooool0C_ooool00ol00?ooooooooooo`0Xoooo
o`030000oooooooooooo04[ooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`0Wooooo`03
o`00oooooooooooo04kooooo00?o003oooooooooool0:?ooool00`000?ooooooooooo`1:ooooo`7o
00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool03Oooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo
04oooooo00?o003oooooooooool09oooool00`000?ooooooooooo`1;ooooo`7o00000Oooool000Oo
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o00003_ooool00ol0
0?ooooooooooo`0Vooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool09_ooool00`00
0?ooooooooooo`1:ooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool09_ooool00ol0
0?ooooooooooo`1@ooooo`03o`00oooooooooooo02Kooooo00<0003oooooooooool0Boooool1o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo
00kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo
02Kooooo00<0003oooooooooool0Boooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooooooo
02Cooooo00?o003oooooooooool0D_ooool00ol00?ooooooooooo`0Tooooo`030000oooooooooooo
04cooooo0Ol00001ooooo`002?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo00ko
oooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`1Booooo`03o`00oooooooooooo02Co
oooo00<0003oooooooooool0C?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00oooooo
00?o003oooooooooool08oooool00ol00?ooooooooooo`1Booooo`03o`00oooooooooooo02Cooooo
00?o003oooooooooool0C?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00oooooo00?o
003oooooooooool08_ooool00ol00?ooooooooooo`1Dooooo`03o`00oooooooooooo02;ooooo00?o
003oooooooooool0COooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00oooooo00?o003o
ooooooooool08_ooool00ol00?ooooooooooo`1Dooooo`03o`00oooooooooooo02;ooooo00?o003o
ooooooooool0COooool1o`00007ooooo000Kooooo`;o00004Oooool00ol00?ooooooooooo`0Qoooo
o`03o`00oooooooooooo05Cooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`1<oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`03
o`00oooooooooooo05Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`1>ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`0Pooooo`03o`00
oooooooooooo05Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`1>ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooo
oooooooo05Kooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`1>ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo
oooo05Oooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`1?ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo
05Sooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`1?ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo05So
oooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`1?ooooo`7o00000Oooool001_ooooo
0_l0000Cooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0FOooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo04oooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`0Booooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0F_ooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo053ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0C
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool0F_ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo053ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Coooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool0Foooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo057ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Dooooo`03
o`00oooooooooooo01Wooooo00?o003oooooooooool0G?ooool00ol00?ooooooooooo`0Jooooo`03
o`00oooooooooooo057ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`00
oooooooooooo01Wooooo00?o003oooooooooool0G?ooool00ol00?ooooooooooo`0Iooooo`03o`00
oooooooooooo05;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Dooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool0G_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo05;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooo
oooo01Oooooo00?o003oooooooooool0G_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooo
oooo05?ooooo0Ol00001ooooo`006oooool2o`0001Kooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`1Oooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0D_ooool2o`00
007ooooo000Kooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`1Pooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0E?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo01Kooooo00?o003oooooooooool05Oooool00ol00?oooooo
ooooo`1Qooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0E?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?oooooooooo
o`1Rooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0E?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool04oooool00ol00?ooooooooooo`1S
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool0EOooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo01Oooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`1Toooo
o`03o`00oooooooooooo01;ooooo00?o003oooooooooool0EOooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo01Sooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`1Uooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool0E_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo01Sooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`1Vooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool0E_ooool1o`00007ooooo000Kooooo`;o00006_oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo06Kooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`1Fooooo`;o00000Oooool001_ooooo00?o0000ooooooooool06_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo06Sooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`1Gooooo`7o00000Oooool001_ooooo00?o0000ooooooooool06oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo06[ooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`1Hooooo`7o00000Oooool001_ooooo00?o0000ooooooooool06oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo06cooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`1Iooooo`7o00000Oooool001_ooooo00?o0000ooooooooool07?ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo06kooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`1Jooooo`7o00000Oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo01gooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`1_ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool0Foooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07_ooool2o`00o`Gooooo0_l00?mcooooo`03o`00oooooooooooo00?ooooo0_l00?mN
ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool2o`00027ooooo1Ol00?mfoooo
o`Ko003oG_ooool2o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0ooooool1ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool1o`00007ooooo
000Cooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`7o00000Oooool001Cooooo00?o0000
ooooooooool01?ooooooo`0000Go00000Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.270385, -1.23348, \
0.00808853, 0.0130873}}],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](t) == sin(2\ \[Pi]\ t)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example #2", "Subsubsection"],

Cell[BoxData[
    \(\(\(s2\  = Sin[2  \[Pi]\ 500\ t];\)\(\ \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Plot[s2, {t, 0, 2}, \ PlotPoints \[Rule] 100, \ 
        PlotStyle \[Rule] Blue];\)\ \), "\[IndentingNewLine]", 
    \(\[Florin][t] \[Equal] s2\  // \ TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309017 0.294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30904 m
.02409 .58934 L
.02435 .18118 L
.02465 .11549 L
.02494 .57753 L
.0252 .38647 L
.02544 .02339 L
.0257 .28995 L
.02599 .5963 L
.02627 .16554 L
.02657 .13558 L
.02686 .5892 L
.02712 .35374 L
.02743 .02758 L
.0276 .27072 L
.02776 .54513 L
.02805 .3865 L
.02837 .02282 L
.02853 .22381 L
.02869 .52156 L
.02899 .41362 L
.02916 .11193 L
.02931 .01986 L
.02948 .23345 L
.02967 .54756 L
.02982 .57866 L
.03 .31768 L
.03031 .04436 L
.03061 .53593 L
.03089 .42689 L
.03116 .02003 L
.03142 .28604 L
.0317 .59762 L
.032 .13884 L
.0323 .15494 L
.03261 .60304 L
.03288 .26207 L
.03318 .05516 L
.03335 .33701 L
.03351 .57672 L
.03368 .53011 L
.03387 .20346 L
.03418 .1128 L
.03435 .43233 L
.03452 .60293 L
.03482 .19381 L
.0351 .08035 L
.03526 .34761 L
.03543 .58783 L
.03573 .27086 L
Mistroke
.03592 .02152 L
.03609 .13484 L
.03625 .42413 L
.03642 .60294 L
.03661 .42306 L
.0368 .07978 L
.03697 .04081 L
.03715 .32715 L
.03732 .58294 L
.03748 .54169 L
.03766 .22741 L
.03783 .01854 L
.03814 .38866 L
.03831 .59937 L
.03847 .49592 L
.03875 .03748 L
.03905 .3205 L
.03934 .58428 L
.0396 .16159 L
.0399 .12125 L
.04021 .59957 L
.04037 .4914 L
.04055 .17709 L
.04086 .13399 L
.04103 .44777 L
.04118 .60307 L
.04136 .44284 L
.04154 .11203 L
.04185 .19952 L
.04202 .51389 L
.04218 .59228 L
.04249 .11708 L
.04277 .14278 L
.04339 .20118 L
.04368 .08527 L
.04399 .58213 L
.04428 .31328 L
.04455 .02019 L
.04484 .45256 L
.04514 .48562 L
.04545 .01898 L
.04563 .14709 L
.04579 .44915 L
.04608 .50698 L
.04635 .05164 L
.0466 .17862 L
.04686 .59232 L
.04715 .2892 L
.04746 .05405 L
.04772 .49458 L
Mistroke
.04801 .46404 L
.04832 .01538 L
.0485 .17115 L
.04866 .46412 L
.04884 .596 L
.04902 .3619 L
.04918 .07995 L
.04936 .04811 L
.04951 .28865 L
.04968 .56436 L
.04986 .54355 L
.05003 .25961 L
.05032 .0583 L
.05064 .56765 L
.05095 .31699 L
.05111 .05384 L
.05128 .06972 L
.0516 .57721 L
.0519 .3258 L
.05218 .02222 L
.05244 .42233 L
.05273 .52774 L
.05304 .03278 L
.05334 .31846 L
.05361 .59191 L
.05392 .11861 L
.05409 .02381 L
.05424 .21989 L
.05455 .59887 L
.05473 .3788 L
.05489 .0924 L
.05518 .20704 L
.0555 .60001 L
.05577 .2102 L
.05605 .07741 L
.05632 .53609 L
.05657 .48197 L
.05686 .02689 L
.05718 .37382 L
.05747 .54904 L
.05775 .08443 L
.05807 .25963 L
.05825 .5592 L
.05841 .56244 L
.05872 .06689 L
.05904 .29062 L
.05933 .59301 L
.05959 .17726 L
.05989 .11148 L
.0602 .59564 L
Mistroke
.06038 .48594 L
.06054 .18859 L
.06072 .01478 L
.06091 .21979 L
.06122 .59711 L
.0614 .36154 L
.06157 .0728 L
.06188 .26606 L
.06217 .59902 L
.06233 .41203 L
.0625 .10201 L
.06281 .22521 L
.06311 .60109 L
.06343 .13146 L
.0636 .01906 L
.06378 .25169 L
.0641 .58568 L
.0644 .10337 L
.06457 .02989 L
.06473 .24277 L
.06503 .59824 L
.06531 .16917 L
.06559 .08931 L
.06588 .56772 L
.06613 .4321 L
.0664 .02032 L
.06669 .35815 L
.06701 .53739 L
.06731 .04936 L
.06758 .23478 L
.06788 .60094 L
.06819 .13248 L
.06849 .16058 L
.06876 .58936 L
.06908 .24311 L
.06926 .01834 L
.06943 .13511 L
.06973 .59803 L
.06989 .50866 L
.07006 .2022 L
.07023 .01511 L
.0704 .15966 L
.07071 .60283 L
.07088 .4465 L
.07104 .14934 L
.07122 .01873 L
.0714 .26008 L
.07157 .54199 L
.07174 .56583 L
.07191 .2967 L
Mistroke
.07206 .05298 L
.07236 .26114 L
.07266 .59057 L
.07296 .12356 L
.07313 .02157 L
.07328 .21283 L
.07357 .6032 L
.07387 .197 L
.07414 .06555 L
.07439 .49687 L
.07467 .48028 L
.07497 .02201 L
.07527 .36269 L
.07544 .59285 L
.07559 .51962 L
.07591 .02483 L
.07609 .12952 L
.07625 .42718 L
.07654 .52158 L
.07686 .02761 L
.07716 .33749 L
.07743 .58688 L
.07769 .17871 L
.07796 .08497 L
.07822 .5302 L
.07846 .5042 L
.07874 .04555 L
.07904 .2986 L
.07933 .59185 L
.07959 .17927 L
.07986 .07931 L
.08012 .51734 L
.0804 .45272 L
.0807 .0159 L
.081 .39946 L
.08131 .50956 L
.08158 .05736 L
.08188 .25879 L
.0822 .58448 L
.08249 .1129 L
.08265 .01906 L
.08281 .22698 L
.08299 .53889 L
.08316 .57962 L
.08346 .09478 L
.08362 .03132 L
.08378 .25213 L
.08406 .60244 L
.08436 .16354 L
.08466 .12844 L
Mistroke
.08493 .57389 L
.08524 .2992 L
.08554 .03775 L
.08581 .481 L
.08606 .53296 L
.08633 .06971 L
.08662 .22888 L
.08694 .59498 L
.08723 .15055 L
.08739 .01507 L
.08756 .20014 L
.08788 .6009 L
.08817 .16811 L
.08848 .14777 L
.08875 .58124 L
.08904 .31415 L
.08921 .04833 L
.08939 .08041 L
.0897 .58234 L
.08988 .51818 L
.09004 .22523 L
.09022 .01612 L
.09041 .19337 L
.09058 .49717 L
.09076 .58909 L
.09093 .34875 L
.09109 .0785 L
.09139 .22772 L
.0917 .59584 L
.09199 .14477 L
.09231 .18408 L
.09262 .60328 L
.0929 .23274 L
.09317 .05419 L
.09343 .47813 L
.09372 .47866 L
.09399 .03612 L
.09429 .31576 L
.09461 .56174 L
.09488 .1088 L
.09517 .18326 L
.09534 .48579 L
.09551 .59396 L
.09568 .36868 L
.09584 .09289 L
.09613 .2027 L
.09645 .60102 L
.09672 .20746 L
.09698 .04622 L
.09726 .50856 L
Mistroke
.09756 .42535 L
.09785 .0152 L
.09817 .44203 L
.09847 .49677 L
.09875 .0406 L
.09903 .2733 L
.09929 .60331 L
.09958 .19575 L
.09986 .07871 L
.10012 .51808 L
.10036 .51949 L
.10061 .0767 L
.10089 .18696 L
.10118 .60291 L
.10135 .45612 L
.1015 .16926 L
.10179 .10216 L
.10209 .58392 L
.10236 .35775 L
.10261 .01554 L
.10288 .36112 L
.10318 .55612 L
.10348 .06584 L
.10365 .0533 L
.10381 .30493 L
.10413 .5651 L
.1043 .27368 L
.10447 .03586 L
.10476 .29856 L
.10507 .57105 L
.10537 .08501 L
.10564 .17697 L
.1059 .58552 L
.10617 .34054 L
.10643 .01488 L
.10667 .31704 L
.10695 .59138 L
.10725 .11709 L
.10754 .15608 L
.1078 .58354 L
.1081 .29915 L
.10838 .02967 L
.10863 .42825 L
.10891 .54345 L
.10921 .0538 L
.10952 .30578 L
.10979 .59775 L
.11009 .14945 L
.1104 .17356 L
.1107 .60132 L
Mistroke
.11085 .49377 L
.11102 .18531 L
.11119 .01481 L
.11136 .17945 L
.11166 .60319 L
.11194 .24228 L
.11224 .07771 L
.11256 .58426 L
.11283 .35284 L
.11312 .01965 L
.1134 .42609 L
.11364 .57147 L
.11393 .09391 L
.11425 .23875 L
.11455 .59988 L
.11482 .19642 L
.11511 .09413 L
.11543 .58867 L
.11572 .28886 L
.116 .0265 L
.11631 .52101 L
.11649 .57823 L
.11666 .32647 L
.11696 .03551 L
.11713 .28814 L
.11729 .54737 L
.11745 .57336 L
.11762 .30165 L
.11793 .05006 L
.1181 .32708 L
.11827 .57403 L
.11844 .53171 L
.11863 .19836 L
.11879 .01648 L
.11897 .16466 L
.11914 .47278 L
.11929 .60311 L
.11958 .19595 L
.11989 .11863 L
.12019 .58563 L
.1205 .25544 L
.1208 .0658 L
.12108 .53417 L
.12136 .43582 L
.12161 .03372 L
.1219 .30262 L
.12217 .59702 L
.12247 .14145 L
.12279 .17963 L
.12306 .59573 L
Mistroke
.12335 .27095 L
.12367 .07171 L
.12396 .55642 L
.12414 .55022 L
.12431 .26224 L
.12463 .08178 L
.12488 .51923 L
.12516 .44851 L
.12544 .02459 L
.12573 .34285 L
.12601 .58478 L
.12626 .18151 L
.1265 .04614 L
.12675 .46753 L
.12703 .50942 L
.12732 .03476 L
.1276 .27875 L
.12786 .60332 L
.12815 .19638 L
.12832 .01542 L
.12848 .13871 L
.12876 .58941 L
.12906 .27657 L
.12936 .04723 L
.12968 .55873 L
.12998 .34896 L
.13026 .01762 L
.13054 .42384 L
.13079 .56893 L
.13108 .09151 L
.13135 .16565 L
.13165 .60129 L
.13193 .26761 L
.13222 .04782 L
.13253 .55673 L
.1327 .56166 L
.13285 .3156 L
.13303 .0412 L
.1332 .07934 L
.13349 .56237 L
.13381 .31053 L
.13408 .02293 L
.13434 .41429 L
.13462 .54156 L
.13493 .04717 L
.13523 .29401 L
.13555 .57076 L
.13582 .12075 L
.13612 .17008 L
.13637 .58387 L
Mistroke
.13661 .41014 L
.13686 .02519 L
.13714 .30276 L
.13742 .59458 L
.13772 .13234 L
.13799 .12746 L
.13825 .55792 L
.13856 .32383 L
.13873 .05388 L
.13891 .07422 L
.13906 .33668 L
.13923 .58526 L
.13953 .29109 L
.13983 .04696 L
.14 .31403 L
.14016 .56292 L
.14044 .37191 L
.14074 .02064 L
.14102 .42787 L
.1413 .5235 L
.14158 .06371 L
.14183 .16349 L
.14212 .60087 L
.1424 .26958 L
.14269 .04754 L
.14301 .55864 L
.14332 .32587 L
.1435 .04876 L
.14366 .06606 L
.14398 .57148 L
.14426 .35149 L
.14443 .07269 L
.1446 .05207 L
.14491 .5572 L
.14511 .53465 L
.14529 .21724 L
.14545 .01971 L
.14562 .14307 L
.14592 .59733 L
.14609 .48853 L
.14625 .19815 L
.14657 .13055 L
.14675 .45727 L
.14691 .60317 L
.1472 .19944 L
.14752 .12578 L
.14782 .59258 L
.14809 .31435 L
.14838 .02756 L
.14868 .50087 L
Mistroke
.14894 .50688 L
.14922 .04473 L
.14952 .30198 L
.14969 .56806 L
.14984 .56087 L
.15015 .0628 L
.15043 .21713 L
.15069 .60069 L
.15098 .26437 L
.15122 .0188 L
.15148 .40694 L
.15176 .5447 L
.15207 .04896 L
.15236 .26253 L
.15262 .60331 L
.15293 .17596 L
.1531 .01489 L
.15326 .16604 L
.15356 .60255 L
.15385 .23808 L
.15401 .024 L
.15418 .12206 L
.15449 .5956 L
.15466 .49168 L
.15482 .1987 L
.155 .01485 L
.15518 .20434 L
.1555 .60063 L
.15567 .38666 L
.15584 .09541 L
.15614 .2087 L
.15646 .59841 L
.15674 .17052 L
.15701 .08001 L
.1573 .56268 L
.15762 .31629 L
.15778 .05101 L
.15794 .0549 L
.15823 .53675 L
.15854 .36222 L
.15872 .06338 L
.15888 .04976 L
.15916 .50393 L
.15946 .43417 L
.15977 .01517 L
.16006 .42755 L
.16023 .60275 L
.16041 .43506 L
.16057 .14116 L
.16074 .01809 L
Mistroke
.16106 .49604 L
.16135 .45064 L
.16152 .14926 L
.16169 .01863 L
.16201 .49696 L
.16219 .58664 L
.16239 .29471 L
.16255 .0413 L
.16274 .09748 L
.16304 .58138 L
.16321 .52817 L
.16336 .2527 L
.16365 .05345 L
.16395 .54967 L
.16412 .56815 L
.16428 .32094 L
.16445 .0472 L
.16464 .09323 L
.16479 .36898 L
.16496 .59262 L
.16526 .27133 L
.16556 .05698 L
.16573 .34061 L
.16589 .57599 L
.16619 .30163 L
.16648 .03412 L
.16676 .48628 L
.16702 .51866 L
.16731 .05001 L
.1676 .28171 L
.1679 .59081 L
.16807 .35975 L
.16822 .08829 L
.16851 .18927 L
.16881 .60332 L
.16908 .24901 L
.16933 .02793 L
.16961 .4648 L
.16991 .47884 L
.17021 .02113 L
.17038 .12848 L
.17053 .41827 L
.17085 .4886 L
.17103 .16245 L
.17119 .01477 L
.17148 .41541 L
.1718 .4966 L
.1721 .02762 L
.17237 .2919 L
.17263 .60271 L
Mistroke
.1729 .21906 L
.17316 .04469 L
.1734 .43714 L
.17368 .53157 L
.17398 .04165 L
.17427 .27503 L
.17453 .60278 L
.1748 .22791 L
.17506 .03684 L
.17534 .49046 L
.17564 .44649 L
.17594 .01575 L
.17625 .43032 L
.17652 .54689 L
.17682 .06082 L
.17714 .29816 L
.17743 .58724 L
.17758 .37483 L
.17775 .08025 L
.17793 .04864 L
.1781 .31071 L
.1784 .5754 L
.17868 .11901 L
.17883 .01771 L
.179 .21547 L
.1793 .60129 L
.1796 .16536 L
.17987 .08761 L
.18018 .58366 L
.18048 .30983 L
.18075 .02199 L
.181 .39729 L
.18127 .56023 L
.18156 .07965 L
.18188 .26113 L
.18217 .59926 L
.18233 .41099 L
.1825 .10015 L
.18282 .22923 L
.18308 .60233 L
.18337 .23686 L
.18369 .09625 L
.18398 .57765 L
.18415 .53395 L
.18433 .21899 L
.18465 .11501 L
.18483 .43444 L
.18499 .60293 L
.18517 .43384 L
.18536 .09244 L
Mistroke
.18553 .03208 L
.18571 .29575 L
.18588 .56712 L
.18603 .56346 L
.18633 .07796 L
.18664 .25707 L
.18693 .59814 L
.18725 .1133 L
.18756 .18881 L
.18784 .60029 L
.18811 .27448 L
.18836 .02091 L
.18865 .46272 L
.18893 .51824 L
.18923 .03623 L
.18954 .34717 L
.18981 .58649 L
.19011 .11478 L
.19043 .2175 L
.19061 .53264 L
.19077 .58383 L
.19109 .08166 L
.19139 .2266 L
.19164 .59906 L
.19192 .27512 L
.19222 .04845 L
.19249 .50536 L
.19275 .50224 L
.19298 .09072 L
.19324 .14235 L
.19351 .58217 L
.19379 .34545 L
.19409 .02426 L
.19437 .45654 L
.19462 .54782 L
.19492 .05803 L
.19508 .05962 L
.19524 .312 L
.19552 .58862 L
.19583 .11227 L
.19612 .17726 L
.19629 .48366 L
.19644 .60232 L
.19672 .20027 L
.19702 .10237 L
.19729 .55517 L
.19754 .44723 L
.19782 .0229 L
.19812 .3558 L
.19842 .55879 L
Mistroke
.19859 .27894 L
.19874 .04144 L
.19906 .33822 L
.19924 .59054 L
.1994 .51962 L
.20002 .33896 L
.20028 .58965 L
.20058 .12193 L
.20086 .1333 L
.20111 .56539 L
.20138 .39371 L
.20168 .01532 L
.20199 .47375 L
.2023 .46327 L
.20257 .03069 L
.20287 .3245 L
.20315 .58468 L
.20341 .17128 L
.2037 .12119 L
.20398 .57829 L
.20424 .38769 L
.20448 .02491 L
.20475 .27875 L
.20502 .59981 L
.20532 .1582 L
.20549 .01546 L
.20564 .17337 L
.20593 .59873 L
.20623 .23875 L
.2065 .04341 L
.20675 .4603 L
.20703 .51489 L
.20732 .0354 L
.20762 .317 L
.20779 .57869 L
.20795 .54929 L
.20812 .26941 L
.20829 .02552 L
.20861 .38282 L
.2089 .55144 L
.20922 .04511 L
.20951 .28993 L
.20979 .59885 L
.21004 .22334 L
.21032 .05675 L
.21058 .49517 L
.21082 .53791 L
.2111 .07105 L
.2114 .24965 L
.21168 .60147 L
Mistroke
.21195 .22521 L
.21225 .0829 L
.21253 .55382 L
.21278 .44761 L
.21306 .02455 L
.21335 .35079 L
.21367 .54303 L
.21394 .08665 L
.21423 .211 L
.21453 .60296 L
.21485 .15365 L
.21501 .01543 L
.21519 .22021 L
.21551 .59576 L
.21581 .13413 L
.21598 .01936 L
.21613 .20126 L
.21643 .6032 L
.21672 .21223 L
.21699 .05855 L
.21728 .53754 L
.21755 .43779 L
.2178 .03699 L
.21809 .29783 L
.21841 .57097 L
.2187 .08436 L
.21898 .17733 L
.21927 .60147 L
.21954 .26824 L
.21986 .078 L
.22015 .55863 L
.22047 .31467 L
.22064 .04757 L
.22082 .08499 L
.22098 .35308 L
.22115 .59023 L
.22144 .27755 L
.22161 .03561 L
.22178 .09631 L
.22209 .58681 L
.22226 .51364 L
.22243 .22467 L
.2226 .01675 L
.22279 .18205 L
.22295 .48261 L
.22313 .59572 L
.2233 .37906 L
.22345 .10275 L
.22374 .18405 L
.22405 .60318 L
Mistroke
.22435 .19607 L
.22467 .13351 L
.22497 .59635 L
.22525 .29185 L
.22552 .02948 L
.22578 .42505 L
.22607 .52469 L
.22634 .06484 L
.22664 .25407 L
.22695 .58782 L
.22722 .159 L
.22752 .12967 L
.22784 .60111 L
.22802 .45383 L
.22818 .15287 L
.2285 .16921 L
.2288 .60211 L
.22905 .30268 L
.22933 .02842 L
.22963 .49259 L
.2299 .48728 L
.23016 .05469 L
.23039 .15608 L
.23065 .57697 L
.23092 .36541 L
.2312 .0156 L
.23146 .37254 L
.23177 .53761 L
.23205 .0684 L
.23234 .23541 L
.23266 .59281 L
.23296 .12572 L
.23323 .13087 L
.23354 .59687 L
.23383 .27185 L
.23409 .02521 L
.23437 .46571 L
.23468 .46449 L
.23483 .17684 L
.235 .0148 L
.23531 .43638 L
.23559 .52427 L
.23586 .06918 L
.23614 .21635 L
.23638 .59055 L
.23665 .34407 L
.23693 .02032 L
.23724 .48511 L
.23753 .47443 L
.23779 .0423 L
Mistroke
.2381 .32335 L
.23827 .58044 L
.23843 .54208 L
.23871 .07025 L
.23903 .26598 L
.2392 .55563 L
.23936 .56639 L
.23967 .06629 L
.23984 .05578 L
.24 .31428 L
.24018 .58052 L
.24036 .50619 L
.24068 .02196 L
.24086 .13805 L
.24102 .43947 L
.24132 .49788 L
.24164 .01898 L
.24193 .35024 L
.24219 .58782 L
.24248 .12344 L
.2428 .19601 L
.24295 .481 L
.24312 .59998 L
.24342 .15131 L
.24373 .16655 L
.24391 .49565 L
.24408 .59692 L
.24436 .17875 L
.24466 .12115 L
.24497 .5983 L
.24526 .25709 L
.24543 .02666 L
.24561 .1294 L
.24579 .44411 L
.24594 .60296 L
.24624 .20544 L
.24656 .12244 L
.24673 .42313 L
.2469 .60331 L
.24722 .1612 L
.24742 .02311 L
.2476 .27589 L
.24777 .55362 L
.24795 .5515 L
.24811 .2844 L
.24828 .03264 L
.24859 .34913 L
.2489 .55685 L
.24917 .08998 L
.24948 .22132 L
Mistroke
.24965 .52651 L
.24981 .58856 L
.24998 .34864 L
.25013 .08172 L
.25031 .04882 L
.25048 .31675 L
.25076 .58766 L
.25106 .11 L
.25132 .11861 L
.25161 .57939 L
.25191 .30108 L
.25208 .04255 L
.25224 .06829 L
.25254 .56832 L
.25283 .36738 L
.25313 .02147 L
.2533 .2398 L
.25345 .51858 L
.25374 .43836 L
.25404 .0148 L
.25432 .36765 L
.25457 .5896 L
.25485 .14886 L
.25515 .14456 L
.25547 .60272 L
.25565 .43643 L
.25581 .13069 L
.25612 .17424 L
.25627 .46085 L
.25644 .60198 L
.25674 .17897 L
.25705 .14314 L
.25735 .59739 L
.25762 .29896 L
.25788 .01919 L
.25816 .43246 L
.25842 .55385 L
.25866 .14607 L
.25894 .11736 L
.25924 .59201 L
.25953 .29685 L
.25979 .02146 L
.26007 .43556 L
.26032 .55846 L
.2606 .09025 L
.2609 .21766 L
.26122 .59684 L
.26152 .13965 L
.26179 .10708 L
.26208 .57876 L
Mistroke
.26224 .54871 L
.2624 .26912 L
.2627 .05254 L
.26301 .55779 L
.26319 .55052 L
.26335 .2706 L
.26365 .05479 L
.26392 .50963 L
.26424 .40219 L
.26453 .01536 L
.26469 .17027 L
.26486 .48176 L
.26503 .59594 L
.2652 .38209 L
.2655 .01738 L
.26582 .49201 L
.26599 .59639 L
.26617 .34781 L
.26636 .04128 L
.26654 .09509 L
.26671 .39617 L
.26687 .59356 L
.26704 .48971 L
.26721 .18346 L
.26749 .0895 L
.2678 .58348 L
.26796 .54157 L
.26812 .25242 L
.26843 .06904 L
.26873 .56152 L
.26901 .37539 L
.26927 .01643 L
.26955 .3565 L
.26972 .59256 L
.26988 .51446 L
.27019 .03223 L
.27036 .09864 L
.27051 .37696 L
.27068 .59699 L
.27086 .47207 L
.27116 .01907 L
.27144 .34046 L
.27175 .55738 L
.27192 .27012 L
.27208 .03837 L
.27237 .28672 L
.27264 .60075 L
.27293 .16465 L
.27325 .16033 L
.27341 .45499 L
Mistroke
.27359 .60205 L
.2739 .14111 L
.27421 .16675 L
.27449 .59798 L
.27479 .26219 L
.27506 .03783 L
.27531 .43792 L
.27557 .54496 L
.27586 .06286 L
.27617 .27335 L
.27643 .60308 L
.27672 .20219 L
.27688 .01728 L
.27706 .15725 L
.27738 .60332 L
.27769 .17239 L
.27798 .10685 L
.27829 .59199 L
.27847 .49457 L
.27863 .19078 L
.27881 .01472 L
.27897 .1619 L
.27914 .48137 L
.27933 .59165 L
.27962 .13189 L
.27989 .12026 L
.28006 .42481 L
.28022 .60094 L
.28051 .23724 L
.28083 .08979 L
.28111 .56493 L
.28143 .31125 L
.2816 .04223 L
.28176 .0701 L
.28205 .55475 L
.28237 .32188 L
.28266 .02354 L
.28296 .48831 L
.28325 .45988 L
.28353 .02585 L
.28378 .2503 L
.28405 .60331 L
.28435 .19523 L
.28451 .01527 L
.28467 .14416 L
.28499 .60259 L
.28517 .44159 L
.28533 .14243 L
.28562 .13615 L
.28593 .60116 L
Mistroke
.28623 .23064 L
.28651 .05238 L
.28676 .48014 L
.28703 .50141 L
.28729 .06219 L
.28753 .14693 L
.28779 .57638 L
.28807 .35701 L
.28838 .02634 L
.28866 .47153 L
.28896 .46867 L
.28924 .02572 L
.2895 .26033 L
.28977 .60236 L
.29007 .17692 L
.29038 .14082 L
.29065 .57849 L
.29095 .32228 L
.29126 .04572 L
.29155 .52371 L
.29187 .37069 L
.29203 .0867 L
.29221 .04593 L
.29251 .53215 L
.29268 .58052 L
.29283 .35568 L
.29312 .01762 L
.29342 .46052 L
.29368 .52511 L
.29397 .0502 L
.29424 .22924 L
.29449 .59653 L
.29478 .27076 L
.2951 .07275 L
.29539 .56155 L
.29567 .39548 L
.29596 .01514 L
.29627 .46299 L
.29657 .48461 L
.29684 .04093 L
.29716 .33547 L
.29734 .59015 L
.2975 .51506 L
.29781 .03154 L
.29798 .10019 L
.29813 .37543 L
.29829 .59308 L
.29847 .49781 L
.29877 .02233 L
.29895 .12777 L
Mistroke
.29911 .42253 L
.29928 .6033 L
.29947 .40652 L
.29964 .11137 L
.29981 .03091 L
.29998 .26952 L
.30013 .53684 L
.30043 .40359 L
.30074 .01805 L
.30101 .42405 L
.30132 .50922 L
.30163 .02311 L
.30192 .34531 L
.3022 .58333 L
.30245 .18076 L
.30274 .10103 L
.30301 .5588 L
.30331 .35784 L
.30362 .03138 L
.30389 .46017 L
.30419 .48803 L
.3045 .0172 L
.30468 .16139 L
.30484 .46237 L
.30516 .45251 L
.30546 .01626 L
.30574 .35992 L
.30599 .59228 L
.30629 .13475 L
.30656 .12097 L
.30682 .55569 L
.30705 .47478 L
.30731 .0481 L
.30758 .23758 L
.30786 .60328 L
.30812 .26371 L
.30843 .06867 L
.30871 .53831 L
.309 .40153 L
.30932 .02079 L
.30962 .47771 L
.30989 .49968 L
.3102 .02648 L
.31048 .32069 L
.31074 .59912 L
.31102 .17974 L
.31133 .12459 L
.3115 .43609 L
.31165 .6017 L
.31195 .21935 L
Mistroke
.31224 .06777 L
.3125 .5201 L
.31278 .44516 L
.31303 .0457 L
.31329 .22505 L
.31357 .60327 L
.31388 .17821 L
.31417 .10198 L
.31443 .54898 L
.31474 .352 L
.3149 .08133 L
.31507 .04433 L
.31537 .53803 L
.31566 .41328 L
.31582 .11574 L
.316 .02631 L
.3163 .5079 L
.31647 .58986 L
.31663 .37132 L
.31681 .07081 L
.317 .06749 L
.31731 .57283 L
.31749 .53205 L
.31765 .24502 L
.31795 .07144 L
.31827 .5789 L
.31856 .33894 L
.31882 .0158 L
.31912 .43565 L
.31943 .48078 L
.3196 .17406 L
.31975 .01524 L
.32005 .39686 L
.32036 .51098 L
.32054 .19005 L
.3207 .01559 L
.32098 .35597 L
.32128 .55647 L
.32159 .05068 L
.32188 .26805 L
.32205 .54991 L
.32223 .5549 L
.3224 .26842 L
.32256 .03686 L
.32286 .31209 L
.32318 .56262 L
.32334 .29718 L
.32352 .03449 L
.32383 .35654 L
.32402 .59799 L
Mistroke
.32421 .44496 L
.32438 .13952 L
.32456 .02304 L
.32472 .2252 L
.32489 .52846 L
.3252 .38177 L
.3255 .01923 L
.32578 .43523 L
.32608 .50016 L
.32625 .18786 L
.32642 .01589 L
.32658 .1564 L
.32674 .44295 L
.32692 .60246 L
.32709 .4183 L
.32737 .01582 L
.32767 .40328 L
.32793 .57421 L
.32821 .10865 L
.32851 .19675 L
.32868 .50633 L
.32884 .59758 L
.32913 .15993 L
.32943 .14205 L
.32973 .59697 L
.3299 .49163 L
.33005 .20677 L
.33034 .07744 L
.33064 .56969 L
.33091 .38776 L
.33116 .01905 L
.33144 .33521 L
.33174 .56889 L
.33206 .06087 L
.33224 .06824 L
.3324 .34936 L
.33271 .55627 L
.33288 .27255 L
.33303 .04146 L
.33332 .28688 L
.33364 .57578 L
.33394 .09159 L
.33421 .16746 L
.33447 .58304 L
.33474 .34511 L
.335 .01481 L
.33524 .31537 L
.33552 .59116 L
.33582 .11576 L
.33611 .15831 L
Mistroke
.33637 .58422 L
.33665 .35006 L
.3369 .01483 L
.33718 .38127 L
.33748 .54017 L
.33778 .05073 L
.3381 .31126 L
.33837 .59677 L
.33866 .14743 L
.33898 .18127 L
.33927 .60253 L
.33943 .48162 L
.3396 .1699 L
.33978 .01591 L
.33994 .19777 L
.34025 .60291 L
.34052 .21672 L
.34068 .02295 L
.34085 .11898 L
.34115 .59344 L
.34145 .26812 L
.34172 .03279 L
.34203 .52825 L
.34233 .41389 L
.3426 .0174 L
.34285 .29363 L
.34312 .5979 L
.34341 .15858 L
.34373 .1645 L
.34402 .59858 L
.34418 .49788 L
.34435 .18159 L
.34467 .13937 L
.34496 .5949 L
.34528 .23528 L
.34554 .0433 L
.34584 .5233 L
.34601 .58515 L
.34618 .32437 L
.3465 .04515 L
.34667 .32363 L
.34684 .57505 L
.34702 .52588 L
.34721 .18501 L
.34738 .01492 L
.34756 .18942 L
.34771 .48242 L
.34788 .59919 L
.3482 .12014 L
.34849 .16496 L
Mistroke
.34877 .59196 L
.34906 .28909 L
.34938 .06613 L
.34967 .55284 L
.34995 .4128 L
.3502 .02285 L
.35048 .32473 L
.35079 .56883 L
.35094 .3244 L
.35112 .05021 L
.35129 .08024 L
.35146 .3689 L
.35176 .55228 L
.35208 .04332 L
.35239 .32996 L
.35269 .57119 L
.35296 .12613 L
.35325 .15487 L
.35353 .59 L
.35378 .35849 L
.35407 .01719 L
.35437 .46745 L
.35469 .44286 L
.35499 .01504 L
.35526 .3599 L
.35556 .55878 L
.35584 .08988 L
.3561 .13748 L
.35639 .59384 L
.35667 .30906 L
.35692 .01697 L
.35716 .34171 L
.35742 .59409 L
.35769 .17146 L
.35799 .1193 L
.35816 .42459 L
.35831 .60017 L
.3586 .26324 L
.3589 .06192 L
.35917 .51574 L
.35942 .49798 L
.3597 .04285 L
.35999 .29631 L
.36029 .5843 L
.36046 .33554 L
.36062 .06959 L
.36094 .28338 L
.3611 .55524 L
.36128 .55382 L
.3616 .04484 L
Mistroke
.3619 .29461 L
.36219 .58965 L
.36246 .16543 L
.36271 .07138 L
.36299 .53524 L
.36325 .46285 L
.36349 .0589 L
.36377 .22406 L
.36407 .60071 L
.36435 .18143 L
.36462 .07037 L
.36492 .5615 L
.3652 .38234 L
.36545 .01818 L
.36573 .33176 L
.36603 .57018 L
.36634 .06327 L
.36661 .20049 L
.3669 .60332 L
.36722 .16137 L
.36752 .12456 L
.36767 .4058 L
.36784 .60119 L
.36802 .45687 L
.36818 .15144 L
.36848 .14931 L
.36876 .58916 L
.36892 .53413 L
.36908 .24098 L
.36939 .07905 L
.36969 .56652 L
.36996 .39509 L
.37027 .01982 L
.37056 .46312 L
.37083 .51906 L
.37108 .08643 L
.37136 .17574 L
.37165 .60106 L
.37196 .19756 L
.37225 .08725 L
.37241 .36658 L
.37258 .59548 L
.3729 .22893 L
.37319 .07393 L
.37351 .57604 L
.37377 .3802 L
.37407 .01714 L
.37423 .21157 L
.37441 .52538 L
.37473 .3777 L
Mistroke
.3749 .07413 L
.37507 .04182 L
.37525 .32253 L
.37544 .59346 L
.3756 .506 L
.37578 .17939 L
.37595 .01473 L
.37611 .16111 L
.37641 .60063 L
.37672 .20212 L
.37702 .09078 L
.37734 .59043 L
.37764 .27253 L
.37792 .03805 L
.3782 .48968 L
.37845 .5247 L
.37874 .04787 L
.37901 .2365 L
.37931 .59975 L
.37963 .1263 L
.3799 .12127 L
.38019 .58919 L
.38051 .24424 L
.38069 .01895 L
.38085 .12696 L
.38117 .6 L
.38147 .23509 L
.38172 .03425 L
.382 .48747 L
.3823 .46334 L
.38257 .02832 L
.38283 .25582 L
.38306 .5974 L
.38332 .329 L
.38359 .01815 L
.38387 .42618 L
.38417 .51643 L
.38445 .05255 L
.3847 .19081 L
.385 .60328 L
.38517 .44442 L
.38532 .15686 L
.38561 .11497 L
.38591 .58978 L
.3862 .28895 L
.38637 .03839 L
.38652 .06841 L
.3868 .54111 L
.38711 .38156 L
.38737 .01511 L
Mistroke
.38762 .32043 L
.3879 .59099 L
.3882 .12251 L
.3885 .17104 L
.38867 .48178 L
.38882 .60198 L
.38914 .13722 L
.38932 .02233 L
.38948 .22944 L
.38977 .60258 L
.39009 .14804 L
.39039 .14285 L
.39066 .58454 L
.39092 .38039 L
.39119 .01472 L
.39145 .34891 L
.39169 .60085 L
.39196 .19791 L
.39227 .10638 L
.39255 .57454 L
.39282 .38692 L
.39312 .01733 L
.3934 .4289 L
.39365 .56497 L
.39392 .10872 L
.39422 .18841 L
.39454 .60217 L
.39481 .22358 L
.3951 .079 L
.39542 .5823 L
.39571 .31495 L
.39588 .05042 L
.39603 .05484 L
.39619 .3171 L
.39637 .58418 L
.39668 .29092 L
.39695 .02959 L
.39726 .51092 L
.39758 .38828 L
.39785 .01528 L
.39814 .38749 L
.39841 .56804 L
.39866 .15397 L
.39895 .12698 L
.39926 .59969 L
.39956 .24003 L
.39983 .0475 L
.40013 .52708 L
.40044 .37778 L
.40074 .01796 L
Mistroke
.40101 .4137 L
.40132 .49589 L
.4015 .16946 L
.40167 .01477 L
.40197 .43858 L
.40214 .60331 L
.4023 .46253 L
.40246 .15962 L
.40263 .01624 L
.40294 .46825 L
.40312 .60054 L
.40328 .41648 L
.40346 .0854 L
.40364 .04557 L
.40396 .55657 L
.40425 .37415 L
.40457 .02555 L
.40474 .27025 L
.40491 .5476 L
.40521 .369 L
.40549 .01675 L
.40575 .38081 L
.40603 .56267 L
.40634 .06626 L
.40651 .054 L
.40666 .30047 L
.40696 .58175 L
.40725 .12272 L
.40751 .12034 L
.4078 .57936 L
.40804 .42053 L
.4083 .02149 L
.40859 .33594 L
.40889 .56229 L
.40918 .08518 L
.40944 .15679 L
.40975 .60219 L
.41004 .2376 L
.41034 .07643 L
.4105 .35108 L
.41067 .59105 L
.41085 .49786 L
.41103 .16041 L
.41119 .01472 L
.41136 .18903 L
.41153 .48522 L
.4117 .5971 L
.41201 .12397 L
.41232 .19771 L
.4125 .51642 L
Mistroke
.41266 .59099 L
.41296 .11888 L
.41328 .21116 L
.41355 .60045 L
.41384 .25791 L
.41415 .07866 L
.41444 .55969 L
.41461 .56138 L
.41476 .3098 L
.41505 .03224 L
.41533 .48002 L
.41563 .45742 L
.41591 .0257 L
.4162 .33303 L
.41645 .59975 L
.41673 .19739 L
.41689 .016 L
.41705 .13465 L
.41734 .59226 L
.41765 .24135 L
.41783 .01873 L
.418 .13061 L
.41827 .57799 L
.41857 .30871 L
.41889 .05191 L
.41918 .53709 L
.41944 .46078 L
.41973 .02316 L
.42002 .35117 L
.4203 .58122 L
.42056 .16074 L
.42079 .05197 L
.42106 .50497 L
.42132 .50392 L
.4216 .04413 L
.42189 .28803 L
.42215 .60324 L
.42242 .22705 L
.42272 .08009 L
.42304 .58552 L
.42334 .28734 L
.42362 .02997 L
.4239 .48212 L
.42417 .50943 L
.42447 .03628 L
.42478 .34782 L
.4251 .54678 L
.42525 .27954 L
.42543 .03064 L
.42573 .34385 L
Mistroke
.42602 .57659 L
.42631 .10542 L
.42658 .14857 L
.42682 .56288 L
.42709 .40887 L
.42738 .01472 L
.42769 .43683 L
.42795 .55057 L
.42824 .07095 L
.4284 .04127 L
.42857 .3121 L
.42889 .56142 L
.4292 .05912 L
.42949 .24228 L
.42967 .54525 L
.42983 .57347 L
.43014 .07363 L
.43031 .05107 L
.43047 .30489 L
.43065 .57686 L
.43083 .51499 L
.43112 .04398 L
.43139 .2436 L
.43171 .59221 L
.43199 .14463 L
.43231 .17611 L
.43249 .50015 L
.43265 .59599 L
.43295 .13829 L
.43327 .18524 L
.43354 .59876 L
.43384 .24871 L
.43412 .04786 L
.43437 .47114 L
.43466 .49175 L
.43493 .04506 L
.43522 .279 L
.43554 .57826 L
.43569 .35033 L
.43586 .06544 L
.43604 .06111 L
.4362 .33499 L
.4365 .57184 L
.43682 .06301 L
.43713 .2854 L
.43743 .58881 L
.4377 .16541 L
.43799 .11771 L
.43829 .59091 L
.43857 .30695 L
Mistroke
.43883 .01665 L
.4391 .41191 L
.4394 .52026 L
.43972 .02605 L
.43999 .29072 L
.44029 .58783 L
.44057 .14404 L
.44082 .08387 L
.44111 .56616 L
.44139 .38158 L
.44165 .01717 L
.44188 .26856 L
.44214 .60331 L
.44242 .23504 L
.4427 .05229 L
.443 .54607 L
.44332 .34452 L
.44361 .02348 L
.44388 .44905 L
.44414 .55546 L
.44442 .07559 L
.4447 .18729 L
.44499 .60302 L
.44527 .24826 L
.44556 .05652 L
.44587 .56555 L
.44619 .30042 L
.44637 .03553 L
.44654 .08864 L
.44686 .58937 L
.44715 .29621 L
.4474 .01792 L
.44768 .43093 L
.44798 .51643 L
.44825 .05619 L
.44851 .18934 L
.44874 .57535 L
.449 .39837 L
.44927 .01581 L
.44955 .35733 L
.44984 .56114 L
.45012 .09596 L
.45038 .12848 L
.45067 .59299 L
.45084 .50474 L
.451 .22323 L
.45128 .06692 L
.45158 .56068 L
.45188 .36331 L
.4522 .03251 L
Mistroke
.4525 .51341 L
.45278 .45734 L
.45334 .31996 L
.45387 .19824 L
.45417 .10234 L
.45434 .40577 L
.45449 .59674 L
.45477 .29988 L
.45506 .0352 L
.45537 .5332 L
.45566 .4105 L
.45598 .01988 L
.45616 .25057 L
.45632 .53552 L
.4566 .43643 L
.45689 .01592 L
.45714 .30441 L
.45742 .59562 L
.45771 .14191 L
.45803 .1832 L
.4583 .59739 L
.4586 .24804 L
.45889 .05272 L
.45915 .49577 L
.45943 .47804 L
.45973 .02151 L
.46001 .32366 L
.46027 .59677 L
.46051 .25175 L
.46076 .02876 L
.46106 .50156 L
.46133 .48143 L
.46165 .0167 L
.46195 .39237 L
.46222 .56216 L
.46248 .13091 L
.46276 .13284 L
.46306 .59459 L
.46323 .49528 L
.46339 .2075 L
.46356 .01565 L
.46374 .18116 L
.46405 .60332 L
.46422 .42947 L
.46438 .13158 L
.46469 .16981 L
.46496 .59476 L
.46528 .22478 L
.46558 .08542 L
.46588 .56784 L
Mistroke
.46604 .55092 L
.4662 .28905 L
.46652 .0624 L
.46669 .3603 L
.46686 .58781 L
.46714 .30845 L
.46746 .05136 L
.46775 .53805 L
.46803 .43203 L
.46835 .01605 L
.46853 .22373 L
.46869 .51879 L
.46899 .40929 L
.46932 .02032 L
.46949 .2487 L
.46966 .53681 L
.46984 .56558 L
.47003 .24323 L
.47021 .02003 L
.47038 .12703 L
.47069 .59825 L
.47096 .29047 L
.47126 .04459 L
.47154 .50665 L
.4718 .50002 L
.47208 .03725 L
.4724 .33721 L
.47255 .57592 L
.47272 .53852 L
.47303 .04571 L
.47319 .07289 L
.47335 .33423 L
.47352 .58354 L
.47369 .51121 L
.474 .03173 L
.47417 .10132 L
.47433 .38842 L
.47463 .53994 L
.4749 .0794 L
.47521 .25858 L
.47551 .59578 L
.47579 .16438 L
.47605 .07046 L
.47634 .55622 L
.47662 .40059 L
.47688 .01996 L
.47711 .25077 L
.47737 .60285 L
.47765 .25614 L
.47792 .04288 L
Mistroke
.47822 .52644 L
.4785 .43954 L
.47876 .03201 L
.47906 .32767 L
.47923 .58122 L
.47938 .54458 L
.47967 .06665 L
.47998 .26148 L
.48025 .60206 L
.48055 .16367 L
.48087 .15707 L
.48116 .59868 L
.48144 .28786 L
.48169 .01818 L
.48198 .44761 L
.48225 .53057 L
.48255 .04516 L
.48286 .32309 L
.48313 .59412 L
.48343 .13589 L
.48375 .19001 L
.48392 .51175 L
.48409 .59322 L
.4844 .10272 L
.4847 .19776 L
.48524 .31089 L
.48553 .033 L
.48581 .4749 L
.48604 .55736 L
.48629 .12954 L
.48657 .13261 L
.48683 .56413 L
.4871 .38411 L
.48736 .01683 L
.48765 .36296 L
.48795 .54873 L
.48827 .03982 L
.48857 .31022 L
.48884 .59618 L
.48914 .14534 L
.48943 .14546 L
.48971 .58395 L
.49002 .26897 L
.49032 .05584 L
.49059 .5151 L
.49085 .49508 L
.49113 .0391 L
.49143 .30486 L
.49159 .56216 L
.49175 .55623 L
Mistroke
.49194 .24519 L
.49211 .02272 L
.49241 .37122 L
.49259 .59669 L
.49275 .50188 L
.49305 .02688 L
.49333 .29756 L
.49365 .56849 L
.49395 .07654 L
.49424 .2217 L
.49441 .51957 L
.49456 .59362 L
.49488 .1059 L
.49505 .03334 L
.49522 .26693 L
.49549 .60219 L
.49579 .17127 L
.4961 .14347 L
.49639 .59382 L
.49656 .50515 L
.49674 .17873 L
.49691 .01473 L
.49706 .16098 L
.49736 .6005 L
.49767 .20402 L
.49784 .01728 L
.49801 .15526 L
.49833 .60311 L
.49852 .40639 L
.4987 .08425 L
.49887 .03583 L
.49905 .30621 L
.4992 .5614 L
.49937 .55886 L
.49967 .06974 L
.49999 .28572 L
.50017 .57556 L
.50034 .54047 L
.50064 .04667 L
.50081 .07171 L
.50097 .34002 L
.50125 .58121 L
.50156 .09096 L
.50183 .16558 L
.50213 .6019 L
.50244 .19428 L
.50274 .09764 L
.50301 .55792 L
.50326 .44425 L
.50355 .01745 L
Mistroke
.50383 .3416 L
.50415 .54324 L
.50444 .06233 L
.5046 .04858 L
.50477 .32733 L
.50509 .55606 L
.50538 .06802 L
.5057 .2753 L
.50596 .60239 L
.50626 .18176 L
.50644 .01508 L
.5066 .19209 L
.50692 .60167 L
.5071 .39569 L
.50726 .10197 L
.50744 .03727 L
.50763 .33324 L
.50795 .55433 L
.50824 .06752 L
.50841 .0516 L
.50857 .29657 L
.50874 .5686 L
.50891 .53566 L
.50919 .07009 L
.50948 .23347 L
.50964 .50974 L
.50981 .5909 L
.5101 .12434 L
.51038 .1381 L
.51068 .59693 L
.51097 .28222 L
.51123 .02251 L
.51154 .51047 L
.51172 .58362 L
.51189 .33946 L
.51219 .03149 L
.51236 .27784 L
.51252 .542 L
.51281 .39792 L
.51313 .02052 L
.51342 .47252 L
.5137 .50959 L
.51395 .06931 L
.51423 .20345 L
.51449 .59641 L
.51473 .37334 L
.51501 .01506 L
.51531 .44407 L
.5156 .51529 L
.51586 .06641 L
Mistroke
.51613 .20045 L
.51639 .59305 L
.51667 .30569 L
.51697 .04153 L
.51727 .52705 L
.51758 .37597 L
.51785 .01482 L
.51815 .40773 L
.5183 .59741 L
.51847 .49498 L
.51876 .02835 L
.51908 .37356 L
.51926 .59965 L
.51943 .47878 L
.51974 .01905 L
.52001 .33727 L
.52017 .57288 L
.52034 .5437 L
.52064 .04803 L
.52094 .28599 L
.52121 .6006 L
.52152 .13661 L
.52182 .14813 L
.52209 .58571 L
.52234 .38593 L
.52262 .01477 L
.52291 .40281 L
.52322 .50362 L
.52351 .0365 L
.52367 .07793 L
.52385 .37959 L
.52416 .52408 L
.52446 .04313 L
.52477 .32387 L
.52504 .59474 L
.52533 .13976 L
.52551 .0211 L
.52568 .23533 L
.52599 .59354 L
.52617 .35297 L
.52633 .07322 L
.52651 .05702 L
.5267 .37746 L
.52687 .59512 L
.52705 .47956 L
.52722 .16665 L
.52738 .01487 L
.52767 .41177 L
.52799 .50178 L
.52828 .03111 L
Mistroke
.52845 .09698 L
.5286 .37176 L
.52889 .5653 L
.52919 .07314 L
.52946 .18371 L
.52971 .58579 L
.52999 .33624 L
.53028 .02823 L
.53058 .49976 L
.53075 .59405 L
.53091 .39019 L
.53123 .02397 L
.53141 .26713 L
.53157 .54427 L
.53186 .39519 L
.53217 .02128 L
.53247 .47629 L
.53275 .50447 L
.533 .0675 L
.53328 .2041 L
.53354 .59606 L
.53377 .37557 L
.53405 .01487 L
.53436 .43893 L
.53464 .51997 L
.53491 .06981 L
.53521 .24536 L
.53549 .60262 L
.53574 .26022 L
.53601 .03774 L
.53631 .51996 L
.53663 .38522 L
.5369 .01518 L
.53719 .40165 L
.53751 .50467 L
.5378 .03389 L
.53796 .07425 L
.53812 .36466 L
.5383 .59638 L
.53847 .4981 L
.53877 .02531 L
.53905 .30635 L
.53935 .57649 L
.53967 .0657 L
.53994 .1991 L
.54023 .60297 L
.5405 .2567 L
.54075 .02312 L
.54104 .47304 L
.54136 .44205 L
Mistroke
.54166 .01553 L
.54193 .35725 L
.54222 .5634 L
.54254 .05668 L
.54283 .264 L
.5431 .60275 L
.54342 .14666 L
.5436 .02038 L
.54377 .22807 L
.54407 .59959 L
.54423 .42268 L
.5444 .11392 L
.54456 .02294 L
.54473 .25273 L
.54504 .59201 L
.54521 .35442 L
.54538 .07765 L
.54555 .05022 L
.54574 .3584 L
.5459 .58782 L
.54608 .50507 L
.54625 .20158 L
.5464 .01944 L
.54669 .36079 L
.547 .54364 L
.5473 .0603 L
.54761 .30031 L
.54792 .58144 L
.5482 .12799 L
.54847 .13054 L
.54872 .55741 L
.54901 .37468 L
.54929 .01472 L
.54959 .42516 L
.5499 .48796 L
.55017 .04356 L
.55047 .28944 L
.55078 .5722 L
.55096 .28806 L
.55113 .041 L
.55144 .33543 L
.55174 .56801 L
.552 .14183 L
.55228 .12312 L
.55257 .58851 L
.55285 .33037 L
.5531 .01507 L
.55334 .31765 L
.5536 .59949 L
.55387 .19907 L
Mistroke
.55414 .0725 L
.55444 .55914 L
.55472 .39213 L
.55497 .01981 L
.55527 .37028 L
.55544 .59402 L
.55559 .52027 L
.55618 .28696 L
.55648 .58438 L
.55677 .1208 L
.55703 .1109 L
.55731 .57442 L
.55762 .30827 L
.55779 .04535 L
.55795 .0631 L
.55825 .56273 L
.55853 .38641 L
.5588 .01537 L
.55908 .37586 L
.55932 .59401 L
.55959 .18693 L
.55987 .09184 L
.56018 .58179 L
.56047 .3246 L
.56073 .01643 L
.56104 .47269 L
.5612 .60288 L
.56137 .41684 L
.56168 .01545 L
.56196 .42075 L
.56214 .60305 L
.5623 .45793 L
.56261 .01539 L
.56278 .16694 L
.56294 .4629 L
.56312 .6006 L
.5633 .36782 L
.56362 .02862 L
.5638 .28266 L
.56396 .55497 L
.56426 .358 L
.56458 .03357 L
.56486 .49181 L
.56513 .50186 L
.56542 .03334 L
.56574 .34972 L
.56603 .56542 L
.5662 .29431 L
.56636 .04804 L
.56667 .32128 L
Mistroke
.56685 .58529 L
.56702 .5287 L
.56763 .32761 L
.56793 .57196 L
.5682 .12193 L
.5685 .17734 L
.56867 .48223 L
.56882 .6021 L
.56899 .41168 L
.56915 .12395 L
.56932 .02364 L
.56951 .27405 L
.56967 .54954 L
.56984 .56114 L
.57016 .05226 L
.57035 .0964 L
.57054 .42435 L
.5707 .60233 L
.57088 .44183 L
.57104 .14728 L
.57121 .01784 L
.57152 .48274 L
.57183 .45226 L
.57211 .02308 L
.57241 .36396 L
.57258 .5942 L
.57274 .51243 L
.57291 .20702 L
.57307 .02054 L
.57324 .14392 L
.57341 .45425 L
.5737 .51073 L
.574 .03164 L
.57425 .24573 L
.57454 .60234 L
.57484 .16433 L
.57501 .01542 L
.57517 .17571 L
.57546 .60048 L
.57576 .2246 L
.57606 .08403 L
.57623 .38077 L
.57638 .59052 L
.57667 .30193 L
.57697 .04446 L
.57725 .49285 L
.5775 .51846 L
.57778 .05433 L
.57808 .27286 L
.57839 .57981 L
Mistroke
.57857 .30404 L
.57874 .04478 L
.57905 .30495 L
.5792 .55916 L
.57937 .55892 L
.57966 .07973 L
.57993 .17957 L
.58009 .47095 L
.58025 .60167 L
.58055 .16983 L
.58083 .09554 L
.58108 .53205 L
.58138 .41052 L
.58165 .01616 L
.58191 .31397 L
.58214 .60332 L
.5824 .26751 L
.58268 .03597 L
.58295 .48247 L
.58325 .46414 L
.58353 .02612 L
.58379 .26189 L
.58408 .59473 L
.58425 .37079 L
.58441 .09272 L
.5847 .18988 L
.58501 .60312 L
.58531 .18025 L
.58548 .01473 L
.58564 .16582 L
.58581 .47599 L
.58596 .60301 L
.58614 .41142 L
.5863 .10787 L
.5866 .18701 L
.58688 .59837 L
.58718 .23983 L
.58733 .03039 L
.5875 .10025 L
.58767 .40335 L
.58783 .59702 L
.58799 .49772 L
.58817 .17118 L
.58835 .01675 L
.58855 .25925 L
.58873 .56032 L
.58889 .56192 L
.58906 .28763 L
.58921 .04767 L
.58938 .07335 L
Mistroke
.58956 .38383 L
.58986 .53808 L
.59004 .23895 L
.5902 .02547 L
.5905 .35393 L
.59067 .5911 L
.59083 .52293 L
.59114 .02849 L
.59143 .30986 L
.59171 .59141 L
.59197 .17885 L
.59225 .08933 L
.59255 .57711 L
.59286 .3015 L
.59304 .03631 L
.5932 .07844 L
.59337 .37242 L
.59355 .59968 L
.59372 .48001 L
.59387 .18674 L
.59418 .11498 L
.59446 .57412 L
.59476 .30867 L
.59493 .04506 L
.59509 .06198 L
.59536 .52655 L
.59567 .39962 L
.59596 .01528 L
.59628 .467 L
.59657 .48389 L
.59685 .03564 L
.5971 .21946 L
.59737 .60174 L
.59766 .22858 L
.59783 .01978 L
.59799 .11465 L
.5983 .59723 L
.59848 .47592 L
.59864 .1768 L
.59893 .10426 L
.59925 .59303 L
.59954 .27266 L
.59982 .03437 L
.60007 .44179 L
.60034 .53408 L
.6006 .09153 L
.60084 .10879 L
.6011 .55378 L
.60139 .38621 L
.60169 .01765 L
Mistroke
.60197 .42676 L
.60226 .51338 L
.60255 .04857 L
.6028 .19694 L
.60307 .59975 L
.60337 .23886 L
.60369 .09453 L
.60396 .5506 L
.60425 .3732 L
.60457 .02571 L
.60486 .47981 L
.60517 .42902 L
.60535 .10731 L
.60551 .0238 L
.60581 .48367 L
.60598 .59924 L
.60613 .42107 L
.60641 .01608 L
.60671 .39659 L
.60698 .56746 L
.60727 .09352 L
.60754 .15955 L
.60779 .57075 L
.60807 .34864 L
.60839 .03477 L
.60869 .51223 L
.60896 .46673 L
.60925 .02201 L
.60956 .38672 L
.60986 .54467 L
.61013 .08703 L
.61043 .21956 L
.6106 .52254 L
.61076 .59161 L
.61108 .09396 L
.61126 .04122 L
.61142 .28772 L
.61158 .55696 L
.61175 .55715 L
.61206 .05608 L
.61223 .06552 L
.61239 .33399 L
.61257 .58804 L
.61276 .48631 L
.61292 .18756 L
.6131 .01479 L
.61327 .18223 L
.61342 .46948 L
.61371 .48331 L
.61402 .01802 L
Mistroke
.61433 .38996 L
.6145 .59964 L
.61466 .49236 L
.61483 .18236 L
.61498 .01646 L
.61516 .16636 L
.61533 .47611 L
.61563 .46721 L
.6159 .02955 L
.61621 .34056 L
.61636 .57326 L
.61653 .54258 L
.61669 .2593 L
.61687 .02148 L
.61704 .12735 L
.6172 .41684 L
.61738 .6033 L
.61758 .38914 L
.61776 .07644 L
.61792 .04185 L
.61809 .30324 L
.61828 .58229 L
.61844 .53667 L
.61861 .23825 L
.6189 .0707 L
.61907 .35768 L
.61923 .58359 L
.61953 .28991 L
.61971 .03499 L
.61986 .07917 L
.62016 .56071 L
.62047 .33049 L
.62074 .01935 L
.621 .4009 L
.62128 .54801 L
.62159 .05008 L
.6219 .29752 L
.62207 .57427 L
.62223 .55061 L
.6224 .2632 L
.62259 .02171 L
.62275 .12371 L
.62291 .41415 L
.62321 .51631 L
.62349 .05256 L
.6238 .29011 L
.62397 .56358 L
.62412 .56684 L
.62442 .08473 L
.62474 .26036 L
Mistroke
.62502 .60112 L
.62532 .15988 L
.62561 .12795 L
.62589 .57998 L
.62614 .40332 L
.62641 .01679 L
.62671 .38771 L
.62688 .59814 L
.62703 .50339 L
.62735 .02045 L
.62753 .14409 L
.62769 .44338 L
.62798 .51089 L
.6283 .02383 L
.62859 .35043 L
.62887 .58197 L
.62912 .17011 L
.6294 .08949 L
.62965 .53301 L
.62989 .50158 L
.63015 .05791 L
.63044 .24384 L
.63074 .59827 L
.63102 .17987 L
.63132 .11509 L
.6316 .57598 L
.63185 .40691 L
.63213 .01636 L
.63243 .39398 L
.63274 .51306 L
.63301 .05948 L
.63331 .25752 L
.63362 .58733 L
.63391 .12286 L
.63423 .20956 L
.6344 .50358 L
.63457 .58739 L
.63487 .11374 L
.63504 .02467 L
.63519 .22353 L
.63548 .60332 L
.63578 .19315 L
.63604 .06769 L
.63633 .54622 L
.6366 .42693 L
.63685 .03287 L
.63714 .30668 L
.63746 .56724 L
.63775 .07979 L
.63803 .18455 L
Mistroke
.63832 .60188 L
.63859 .26681 L
.63891 .07719 L
.6392 .55747 L
.63952 .31964 L
.63969 .05037 L
.63987 .08113 L
.64004 .3771 L
.64019 .58811 L
.64049 .28361 L
.64065 .03866 L
.64083 .09023 L
.64113 .58342 L
.64131 .52127 L
.64147 .2351 L
.64164 .01822 L
.64183 .17322 L
.64199 .4738 L
.64217 .59795 L
.64234 .3894 L
.64249 .10983 L
.64279 .17603 L
.6431 .60331 L
.64337 .23355 L
.64367 .0801 L
.64399 .58195 L
.64428 .31515 L
.64456 .02217 L
.64481 .39748 L
.6451 .5451 L
.64537 .08459 L
.64567 .21819 L
.64598 .59799 L
.64625 .19677 L
.64655 .09747 L
.64686 .59194 L
.64704 .4928 L
.6472 .19465 L
.64752 .12893 L
.64782 .59407 L
.6481 .30195 L
.64835 .01699 L
.64864 .4457 L
.64892 .52896 L
.64918 .08936 L
.64941 .10846 L
.64967 .54858 L
.64994 .42272 L
.65022 .01796 L
.65051 .37533 L
Mistroke
.65079 .56817 L
.65104 .14394 L
.65134 .14727 L
.65151 .45705 L
.65166 .60326 L
.65195 .22473 L
.65225 .08668 L
.65254 .56671 L
.65286 .30155 L
.65316 .04254 L
.65344 .50092 L
.65372 .47716 L
.65397 .05435 L
.65426 .25442 L
.65453 .60306 L
.65483 .18406 L
.65514 .13712 L
.65541 .57783 L
.65571 .32091 L
.65603 .04894 L
.6562 .3364 L
.65637 .57963 L
.65668 .2765 L
.65698 .05312 L
.65724 .48045 L
.65752 .49149 L
.65781 .02842 L
.65809 .29098 L
.65834 .60283 L
.65858 .298 L
.65884 .01889 L
.65911 .42112 L
.65938 .54461 L
.65968 .05824 L
.65996 .22683 L
.66021 .59844 L
.66051 .24691 L
.66068 .0238 L
.66083 .09854 L
.66142 .32897 L
.66172 .03372 L
.66201 .49638 L
.66227 .50883 L
.66255 .04496 L
.66286 .30528 L
.66302 .57038 L
.66318 .55785 L
.66349 .05851 L
.66377 .22541 L
.66403 .60205 L
Mistroke
.66432 .25045 L
.66456 .02188 L
.66482 .4225 L
.66511 .53294 L
.66541 .04035 L
.6657 .28273 L
.66596 .60255 L
.66627 .15538 L
.66643 .01474 L
.6666 .18936 L
.66691 .60323 L
.66719 .21029 L
.66736 .01791 L
.66753 .14748 L
.66784 .60122 L
.66801 .46445 L
.66817 .16856 L
.66835 .01574 L
.66853 .23538 L
.66885 .59387 L
.66903 .35165 L
.66919 .07244 L
.66949 .2437 L
.66981 .5898 L
.67009 .13953 L
.67036 .10411 L
.67065 .57863 L
.67097 .2835 L
.67113 .03565 L
.67129 .07633 L
.67158 .56087 L
.6719 .31679 L
.67206 .05383 L
.67224 .07595 L
.67254 .56671 L
.67286 .30513 L
.67315 .03531 L
.67343 .47692 L
.67359 .6005 L
.67377 .37775 L
.67393 .09402 L
.6741 .03427 L
.67442 .5416 L
.67472 .38956 L
.67488 .09705 L
.67506 .03756 L
.67538 .5447 L
.67557 .5451 L
.67576 .2255 L
.67592 .01997 L
Mistroke
.6761 .15122 L
.67626 .44525 L
.67644 .60304 L
.67675 .16123 L
.67705 .13892 L
.67733 .58572 L
.67763 .28654 L
.6778 .03378 L
.67796 .08305 L
.67813 .37915 L
.67829 .58906 L
.67846 .50058 L
.67863 .19334 L
.67892 .08411 L
.67922 .57322 L
.67947 .4052 L
.67976 .01488 L
.68006 .42305 L
.68023 .603 L
.68039 .47155 L
.68068 .02408 L
.68098 .36166 L
.68128 .5547 L
.68145 .27216 L
.6816 .04013 L
.68189 .27877 L
.68219 .58805 L
.68246 .15756 L
.68272 .07339 L
.68299 .54079 L
.68329 .38561 L
.68361 .02441 L
.68379 .27076 L
.68396 .55121 L
.68426 .35735 L
.68443 .06825 L
.68459 .03844 L
.68488 .51218 L
.68519 .39493 L
.68549 .01619 L
.68577 .40625 L
.68602 .57139 L
.6863 .11411 L
.68656 .12038 L
.6868 .5344 L
.68708 .43124 L
.68738 .01472 L
.68767 .40129 L
.68793 .56823 L
.6882 .11521 L
Mistroke
.68846 .1109 L
.68874 .57252 L
.68904 .32172 L
.68934 .03374 L
.68966 .53358 L
.68992 .45013 L
.69022 .01733 L
.69037 .12538 L
.69054 .42785 L
.69084 .51474 L
.69115 .02345 L
.69133 .13751 L
.6915 .44818 L
.69181 .48297 L
.69209 .03388 L
.69224 .07546 L
.69241 .36475 L
.69272 .54618 L
.69299 .08783 L
.69329 .21743 L
.6936 .59882 L
.69389 .15716 L
.69417 .09863 L
.69442 .53168 L
.69469 .44156 L
.69498 .01698 L
.6953 .42443 L
.69559 .52638 L
.69575 .24329 L
.69592 .02056 L
.69624 .39884 L
.69653 .53634 L
.69685 .03665 L
.69711 .2516 L
.69741 .59889 L
.69758 .37585 L
.69775 .08206 L
.69807 .25693 L
.69824 .55427 L
.69841 .5682 L
.69859 .27755 L
.69878 .02068 L
.69895 .1257 L
.69913 .45446 L
.6993 .60262 L
.69945 .44204 L
.69975 .01567 L
.70006 .42843 L
.70036 .51393 L
.70053 .21272 L
Mistroke
.70068 .02161 L
.70097 .33395 L
.70127 .56694 L
.70154 .11803 L
.70179 .1041 L
.70206 .56525 L
.70236 .34332 L
.70266 .02676 L
.70283 .26065 L
.70299 .53495 L
.70331 .35671 L
.70349 .05911 L
.70365 .05255 L
.70394 .53239 L
.70426 .36738 L
.70455 .02023 L
.70483 .43258 L
.70508 .55932 L
.70536 .09806 L
.70562 .13609 L
.70586 .54627 L
.70613 .41584 L
.70644 .01515 L
.70672 .41529 L
.70699 .56049 L
.70729 .06932 L
.70757 .21329 L
.70782 .59535 L
.70809 .30965 L
.70839 .03788 L
.70871 .54112 L
.70898 .4389 L
.70927 .01571 L
.70959 .43581 L
.70989 .51141 L
.71004 .23516 L
.71021 .02071 L
.71038 .14078 L
.71055 .44562 L
.71085 .4887 L
.71113 .03739 L
.71145 .35276 L
.71176 .55363 L
.71203 .09649 L
.71232 .1869 L
.71284 .34951 L
.71315 .03703 L
.71345 .5203 L
.71372 .46617 L
.71402 .02122 L
Mistroke
.71433 .39813 L
.71463 .5364 L
.7148 .24004 L
.71495 .02902 L
.71513 .11824 L
.7153 .42677 L
.71546 .6024 L
.71564 .45064 L
.71595 .01473 L
.71612 .1843 L
.71629 .48401 L
.71647 .59456 L
.71666 .32527 L
.71695 .02969 L
.71712 .26584 L
.71728 .53574 L
.71759 .36369 L
.71777 .06543 L
.71793 .04532 L
.71821 .5167 L
.71853 .39721 L
.71882 .01532 L
.71909 .39102 L
.71939 .53166 L
.71968 .05483 L
.71994 .19631 L
.72022 .60174 L
.72053 .21029 L
.7207 .01624 L
.72085 .13042 L
.72116 .59534 L
.72144 .28898 L
.72171 .02492 L
.72199 .46483 L
.72223 .55533 L
.7225 .10753 L
.72278 .16642 L
.72309 .60276 L
.72337 .23059 L
.72364 .04168 L
.72395 .54123 L
.7241 .58314 L
.72428 .3261 L
.72458 .03629 L
.72487 .4994 L
.72503 .59659 L
.7252 .37294 L
.72551 .02336 L
.72568 .25231 L
.72584 .53206 L
Mistroke
.72602 .57455 L
.72621 .27687 L
.72652 .06897 L
.7267 .3726 L
.72686 .59235 L
.72716 .26808 L
.72748 .07786 L
.72777 .55294 L
.72803 .42553 L
.72833 .01508 L
.72864 .43681 L
.72893 .51011 L
.7291 .20729 L
.72926 .01942 L
.72958 .40696 L
.72975 .60286 L
.72992 .46225 L
.73019 .02825 L
.73049 .34172 L
.73081 .54946 L
.7311 .06531 L
.73127 .05184 L
.73145 .3483 L
.73162 .58959 L
.73178 .527 L
.7321 .02817 L
.7324 .33657 L
.73272 .54615 L
.73288 .25544 L
.73307 .01963 L
.73326 .16921 L
.73344 .49893 L
.7336 .59718 L
.73378 .36579 L
.73394 .08721 L
.73411 .03982 L
.73442 .53945 L
.73473 .37965 L
.735 .01482 L
.73531 .43731 L
.73548 .60329 L
.73564 .45027 L
.7358 .144 L
.73596 .01529 L
.73614 .21869 L
.73631 .51572 L
.73659 .4487 L
.73689 .01567 L
.73715 .32158 L
.73743 .5863 L
Mistroke
.73774 .10341 L
.73791 .03048 L
.73806 .24775 L
.73835 .60112 L
.73866 .15409 L
.73895 .13997 L
.73912 .45066 L
.73928 .60306 L
.73957 .22913 L
.73987 .0843 L
.74014 .54314 L
.74039 .46248 L
.74067 .02648 L
.74097 .34344 L
.74129 .54526 L
.74147 .23573 L
.74163 .02194 L
.74194 .37262 L
.74211 .59559 L
.74226 .51673 L
.74255 .04093 L
.74287 .33475 L
.74317 .56951 L
.74344 .11485 L
.7437 .11583 L
.74398 .57249 L
.74424 .39881 L
.74448 .02898 L
.74476 .2967 L
.74506 .58149 L
.74535 .11814 L
.74561 .12149 L
.74588 .5721 L
.74614 .41025 L
.74642 .01552 L
.74672 .40833 L
.74703 .50314 L
.74733 .02923 L
.7476 .27589 L
.7479 .59392 L
.74805 .39212 L
.74822 .09713 L
.74851 .1985 L
.74883 .6002 L
.74901 .37657 L
.74918 .08158 L
.74949 .23886 L
.74977 .60319 L
.74992 .45629 L
.75009 .14692 L
Mistroke
.75039 .15666 L
.75066 .58777 L
.75096 .28611 L
.75128 .06126 L
.75157 .54621 L
.75184 .42384 L
.75209 .02937 L
.75237 .28808 L
.75266 .59252 L
.75298 .09796 L
.75327 .18536 L
.75343 .48072 L
.7536 .59755 L
.75392 .11756 L
.75421 .17209 L
.75453 .6033 L
.75479 .24976 L
.75509 .06166 L
.75526 .35888 L
.75543 .59098 L
.75575 .24427 L
.75592 .01978 L
.75609 .12458 L
.75627 .45194 L
.75646 .59757 L
.75663 .38823 L
.75681 .07543 L
.75698 .0465 L
.75713 .28865 L
.75743 .58846 L
.75774 .0945 L
.75804 .2026 L
.75821 .5062 L
.75836 .59833 L
.75865 .17128 L
.75895 .12728 L
.75922 .5726 L
.75947 .41436 L
.75975 .01648 L
.76004 .39263 L
.76034 .53546 L
.76051 .23872 L
.76067 .02693 L
.76099 .38022 L
.76117 .60006 L
.76133 .4873 L
.76162 .02796 L
.76194 .36994 L
.76223 .55155 L
.76251 .08959 L
Mistroke
.76276 .14091 L
.76304 .58424 L
.7633 .37268 L
.76354 .022 L
.76382 .32057 L
.76412 .57202 L
.7644 .10192 L
.76467 .13957 L
.76497 .59725 L
.76525 .28798 L
.76554 .04104 L
.76586 .55088 L
.76614 .41024 L
.76639 .02464 L
.76668 .33448 L
.76695 .58753 L
.76726 .0995 L
.76755 .17539 L
.76786 .60326 L
.76802 .45307 L
.76819 .13464 L
.76836 .02102 L
.76852 .21735 L
.76869 .52218 L
.76888 .5715 L
.76905 .29986 L
.76921 .04907 L
.76953 .31424 L
.76984 .56268 L
.77014 .07395 L
.77041 .18027 L
.7707 .60136 L
.77101 .1949 L
.77117 .01693 L
.77135 .15748 L
.77166 .60256 L
.77194 .23272 L
.77222 .05669 L
.77253 .55371 L
.77282 .38466 L
.77308 .01549 L
.77332 .29039 L
.77359 .60153 L
.77386 .20503 L
.77412 .05086 L
.77441 .52311 L
.77471 .40789 L
.77497 .02176 L
.77525 .32771 L
.77555 .56795 L
Mistroke
.77572 .29565 L
.77588 .0517 L
.77618 .28108 L
.77646 .5971 L
.77674 .17356 L
.77704 .12329 L
.77732 .58184 L
.77758 .38093 L
.77788 .0195 L
.77806 .23339 L
.77821 .51772 L
.77851 .43242 L
.77882 .01497 L
.77898 .19046 L
.77914 .47753 L
.77931 .5994 L
.77949 .37352 L
.77979 .02091 L
.77996 .2413 L
.78012 .52509 L
.78042 .40723 L
.7807 .01652 L
.78101 .42272 L
.78131 .5157 L
.78157 .07529 L
.78185 .20704 L
.78215 .6032 L
.78242 .22517 L
.78268 .04095 L
.78292 .42854 L
.78318 .55772 L
.78345 .0982 L
.78373 .1675 L
.78403 .60162 L
.78431 .25749 L
.78457 .02684 L
.78487 .4986 L
.78504 .5944 L
.78519 .39454 L
.78548 .01482 L
.78578 .43901 L
.78608 .50755 L
.78624 .20578 L
.7864 .02028 L
.78668 .33845 L
.78698 .56537 L
.78725 .11701 L
.7875 .10429 L
.78778 .56479 L
.78808 .34472 L
Mistroke
.78838 .02577 L
.78854 .25622 L
.7887 .53173 L
.78902 .36295 L
.7892 .06279 L
.78936 .04926 L
.78965 .52703 L
.78997 .37575 L
.79026 .01863 L
.79054 .42474 L
.79079 .56464 L
.79107 .10632 L
.79133 .12597 L
.79156 .5383 L
.79184 .42902 L
.79214 .01472 L
.79243 .40099 L
.79269 .56788 L
.79299 .07902 L
.79327 .19783 L
.79353 .59097 L
.7938 .3262 L
.7941 .03172 L
.79441 .53054 L
.79468 .45332 L
.79498 .01733 L
.7953 .41919 L
.79559 .52557 L
.79574 .25612 L
.79591 .02604 L
.79609 .12214 L
.79625 .42407 L
.79655 .5085 L
.79683 .04893 L
.79714 .29426 L
.79746 .56842 L
.79773 .11879 L
.79801 .15871 L
.79829 .58918 L
.79853 .38211 L
.79882 .01613 L
.79914 .4771 L
.79944 .46762 L
.79971 .03052 L
.8 .31751 L
.80032 .56302 L
.80061 .07596 L
.80089 .1832 L
.80105 .48973 L
.80121 .60093 L
Mistroke
.80139 .38115 L
.80156 .09095 L
.80185 .21131 L
.80202 .51383 L
.80218 .59643 L
.80249 .11908 L
.80264 .01872 L
.80282 .22994 L
.80299 .5356 L
.80318 .56154 L
.80335 .27061 L
.80351 .03592 L
.80383 .34161 L
.804 .59062 L
.80417 .51798 L
.80447 .03622 L
.80478 .35009 L
.80507 .5683 L
.80539 .05784 L
.80569 .26947 L
.80597 .60055 L
.80625 .19711 L
.8065 .04708 L
.80679 .52258 L
.80706 .45781 L
.80736 .01789 L
.80764 .34043 L
.80792 .57534 L
.80824 .06808 L
.80856 .28868 L
.80874 .57056 L
.8089 .54742 L
.80922 .03872 L
.80952 .29303 L
.80977 .60293 L
.81005 .21319 L
.81034 .08284 L
.81062 .54657 L
.81087 .45321 L
.81111 .05545 L
.81137 .19412 L
.81164 .59861 L
.81192 .28755 L
.81221 .04407 L
.81249 .5027 L
.81274 .51003 L
.81304 .03325 L
.81321 .09412 L
.81336 .36876 L
.81365 .56541 L
Mistroke
.81395 .07254 L
.81424 .22886 L
.81456 .59335 L
.81487 .12375 L
.81515 .13944 L
.81542 .58494 L
.81567 .38714 L
.81596 .01552 L
.81624 .39705 L
.81654 .53275 L
.81685 .03261 L
.81712 .26731 L
.81742 .59501 L
.81774 .10409 L
.81791 .0355 L
.81808 .27408 L
.81839 .5804 L
.81869 .09752 L
.81895 .12912 L
.81923 .58304 L
.81952 .31105 L
.8198 .02311 L
.82005 .41332 L
.82029 .58618 L
.82055 .17427 L
.82082 .08328 L
.8211 .54882 L
.82139 .37882 L
.82167 .01484 L
.82192 .34696 L
.82222 .56356 L
.82239 .29015 L
.82255 .04864 L
.82283 .25714 L
.82313 .59495 L
.82343 .14045 L
.82375 .18981 L
.82405 .60331 L
.82433 .22519 L
.82458 .03558 L
.82486 .48562 L
.82515 .47052 L
.82542 .03252 L
.82572 .32679 L
.82604 .55555 L
.82631 .1 L
.82661 .19465 L
.82677 .49595 L
.82695 .59038 L
.82712 .35552 L
Mistroke
.82727 .08403 L
.82757 .2155 L
.82788 .59904 L
.82816 .19413 L
.82841 .05323 L
.82869 .51962 L
.82899 .41081 L
.82929 .01472 L
.8296 .45651 L
.8299 .48364 L
.83018 .03427 L
.83047 .29026 L
.83072 .60271 L
.83102 .17991 L
.8313 .0898 L
.83156 .52993 L
.83179 .50711 L
.83205 .06663 L
.83232 .20217 L
.83262 .60331 L
.83279 .43977 L
.83294 .15288 L
.83323 .11678 L
.83353 .59056 L
.8338 .33654 L
.83405 .01472 L
.83432 .38306 L
.83462 .54307 L
.83492 .05329 L
.83509 .0661 L
.83525 .32929 L
.83557 .55186 L
.83575 .24876 L
.83591 .02747 L
.8362 .3244 L
.83651 .55817 L
.83681 .06889 L
.83709 .20076 L
.83734 .59358 L
.83762 .31309 L
.83788 .01714 L
.83811 .34515 L
.83839 .58193 L
.83869 .09607 L
.83898 .18174 L
.83924 .59265 L
.83954 .26964 L
.83983 .04047 L
.84008 .45502 L
.84035 .52424 L
Mistroke
.84065 .04018 L
.84097 .33562 L
.84124 .59053 L
.84153 .12577 L
.84185 .20142 L
.84214 .60331 L
.84229 .46768 L
.84246 .15653 L
.84264 .01748 L
.84281 .2101 L
.84311 .60222 L
.84339 .20894 L
.84369 .10121 L
.84401 .59482 L
.84428 .31651 L
.84457 .02868 L
.84484 .45952 L
.84509 .55229 L
.84538 .06967 L
.8457 .27664 L
.846 .59149 L
.84627 .16192 L
.84656 .12295 L
.84688 .59853 L
.84717 .24859 L
.84745 .04063 L
.84776 .5476 L
.84794 .55871 L
.84811 .28475 L
.84841 .05373 L
.84857 .29867 L
.84874 .56939 L
.8489 .55216 L
.84907 .25945 L
.84938 .07296 L
.84956 .36953 L
.84972 .5898 L
.84989 .50141 L
.85008 .16014 L
.85024 .01491 L
.85042 .2034 L
.85058 .49002 L
.85074 .59844 L
.85105 .12497 L
.85134 .15232 L
.85164 .59735 L
.85196 .21271 L
.85226 .09403 L
.85254 .56082 L
.85281 .39227 L
Mistroke
.85306 .02064 L
.85335 .35026 L
.85363 .58337 L
.85393 .10369 L
.85424 .22582 L
.85451 .6024 L
.85481 .22178 L
.85513 .11083 L
.8553 .43422 L
.85547 .60283 L
.85578 .17883 L
.85608 .1177 L
.85634 .55229 L
.85662 .40003 L
.85691 .0151 L
.85719 .39522 L
.85744 .57783 L
.85768 .19449 L
.85794 .05539 L
.85821 .51033 L
.85849 .46599 L
.85878 .01968 L
.85906 .33395 L
.85931 .59832 L
.85961 .14752 L
.85978 .0168 L
.85993 .18643 L
.86022 .60114 L
.86052 .22331 L
.86081 .07727 L
.86114 .58399 L
.86144 .29122 L
.86172 .03147 L
.862 .47579 L
.86225 .53569 L
.86254 .05566 L
.86281 .22125 L
.86311 .60168 L
.86343 .13754 L
.8637 .11109 L
.86399 .58486 L
.86431 .25653 L
.86449 .02128 L
.86465 .11747 L
.86497 .59795 L
.86527 .24699 L
.86553 .0304 L
.86581 .47886 L
.8661 .47181 L
.86638 .03144 L
Mistroke
.86663 .2467 L
.86687 .59544 L
.86714 .31223 L
.8674 .0169 L
.86768 .41836 L
.86797 .5222 L
.86825 .05659 L
.8685 .18335 L
.8688 .60304 L
.86897 .45143 L
.86913 .1639 L
.86941 .10879 L
.86971 .58698 L
.87001 .2964 L
.87016 .05075 L
.87033 .06482 L
.87063 .56035 L
.87091 .38609 L
.87118 .01533 L
.87143 .31725 L
.87171 .59171 L
.87201 .12433 L
.87231 .16992 L
.87248 .48114 L
.87263 .60204 L
.87295 .1371 L
.87313 .02242 L
.87329 .22983 L
.87358 .6025 L
.8739 .14698 L
.8742 .14407 L
.87447 .58498 L
.87473 .37826 L
.875 .01472 L
.87526 .35223 L
.8755 .60037 L
.87578 .19409 L
.87608 .10958 L
.87636 .57649 L
.87663 .38264 L
.87693 .01804 L
.87721 .4337 L
.87746 .56223 L
.87774 .10488 L
.87803 .19347 L
.87835 .60165 L
.87862 .21866 L
.87891 .08187 L
.87923 .5845 L
.87952 .30783 L
Mistroke
.87969 .04678 L
.87985 .05909 L
.88001 .3258 L
.88019 .58723 L
.88049 .28094 L
.88077 .03309 L
.88107 .51892 L
.88139 .37722 L
.88166 .01477 L
.88195 .39993 L
.88222 .56134 L
.88247 .1425 L
.88276 .13844 L
.88308 .60161 L
.88338 .22581 L
.88365 .05448 L
.88394 .53721 L
.88426 .3619 L
.88456 .02093 L
.88483 .42945 L
.88514 .48186 L
.88532 .15389 L
.88549 .01565 L
.88579 .45469 L
.88595 .6031 L
.88612 .44689 L
.88628 .14401 L
.88645 .01874 L
.88676 .48383 L
.88694 .59729 L
.8871 .3984 L
.88728 .0734 L
.88746 .05456 L
.88778 .5664 L
.88807 .35554 L
.88838 .03117 L
.88856 .28866 L
.88872 .55771 L
.88903 .34975 L
.88931 .01987 L
.88957 .40142 L
.88985 .55078 L
.89016 .05394 L
.89033 .06661 L
.89048 .32431 L
.89079 .57161 L
.89107 .10429 L
.89134 .1407 L
.89162 .58865 L
.89186 .39534 L
Mistroke
.89212 .01695 L
.89241 .36324 L
.89271 .54702 L
.893 .06803 L
.89327 .18124 L
.89357 .6033 L
.89386 .20935 L
.89416 .09613 L
.89432 .38095 L
.8945 .59823 L
.89467 .4731 L
.89486 .13433 L
.89502 .01657 L
.89519 .2184 L
.89535 .50954 L
.89552 .58895 L
.89583 .10059 L
.89615 .22808 L
.89633 .5381 L
.89649 .58003 L
.89679 .09521 L
.89711 .24222 L
.89739 .60238 L
.89766 .23126 L
.89795 .07044 L
.89827 .57475 L
.89843 .54189 L
.89859 .27267 L
.89888 .04925 L
.8992 .55727 L
.89938 .55076 L
.89954 .27541 L
.89982 .03299 L
.90012 .51344 L
.90043 .39652 L
.90072 .01522 L
.90089 .19122 L
.90107 .5167 L
.90124 .58634 L
.9014 .36369 L
.9017 .02153 L
.90202 .50704 L
.90218 .59436 L
.90236 .35613 L
.90268 .03471 L
.90287 .33289 L
.90305 .59259 L
.90322 .50915 L
.9034 .18183 L
.90356 .01562 L
Mistroke
.90373 .16339 L
.90404 .60312 L
.90434 .19697 L
.90462 .07631 L
.90493 .56875 L
.9051 .54467 L
.90526 .27121 L
.90543 .03027 L
.90558 .08224 L
.90576 .39455 L
.90593 .59944 L
.90621 .26998 L
.90651 .05752 L
.90677 .49155 L
.90705 .47568 L
.90736 .019 L
.90753 .13908 L
.90768 .42837 L
.90797 .52429 L
.90827 .03637 L
.90857 .31294 L
.90873 .56445 L
.9089 .55527 L
.9092 .05722 L
.90949 .23526 L
.90976 .6031 L
.91001 .29086 L
.91029 .03007 L
.91059 .50409 L
.9109 .40395 L
.91108 .08727 L
.91125 .03558 L
.91155 .52348 L
.91172 .58361 L
.91188 .36337 L
.91217 .01897 L
.91248 .49461 L
.91278 .44822 L
.91306 .02427 L
.91331 .27247 L
.91359 .60092 L
.91385 .2284 L
.91409 .02572 L
.91437 .46106 L
.91467 .47502 L
.91496 .02633 L
.91522 .27758 L
.91549 .60131 L
.91575 .24194 L
.91603 .05162 L
Mistroke
.91633 .54407 L
.91663 .37942 L
.91694 .02502 L
.91721 .44192 L
.91751 .50615 L
.91766 .2237 L
.91783 .01996 L
.91812 .36445 L
.91844 .53098 L
.91862 .21164 L
.91879 .01681 L
.9191 .40262 L
.91938 .55328 L
.91953 .29818 L
.9197 .04119 L
.92 .31351 L
.9203 .57804 L
.92057 .13518 L
.92088 .18128 L
.92118 .60232 L
.92145 .26551 L
.9217 .02258 L
.92198 .44407 L
.92227 .5097 L
.92258 .02221 L
.92287 .34106 L
.92303 .57932 L
.92321 .52663 L
.92352 .02993 L
.92382 .32473 L
.92413 .56037 L
.9244 .11086 L
.92469 .17796 L
.92485 .47681 L
.92503 .59734 L
.9252 .38679 L
.92535 .10729 L
.92553 .03457 L
.92572 .32724 L
.9259 .58706 L
.92606 .52805 L
.92668 .32651 L
.92684 .57867 L
.927 .54696 L
.92718 .23372 L
.92735 .02166 L
.92764 .35077 L
.92796 .53935 L
.92826 .05286 L
.92853 .22857 L
Mistroke
.92882 .60295 L
.92913 .14908 L
.92929 .01519 L
.92947 .20013 L
.92978 .60171 L
.93005 .21543 L
.93035 .086 L
.93066 .58161 L
.93094 .32527 L
.93121 .01852 L
.93146 .37155 L
.93175 .56474 L
.93201 .11569 L
.9323 .16731 L
.93263 .60306 L
.93279 .44083 L
.93296 .12409 L
.93327 .19554 L
.93354 .59799 L
.93383 .27102 L
.93414 .07172 L
.93444 .55432 L
.93463 .53971 L
.9348 .22763 L
.93497 .02247 L
.93514 .12972 L
.93531 .44035 L
.93549 .60257 L
.93581 .14017 L
.93612 .17077 L
.9364 .59973 L
.93672 .20489 L
.9369 .01494 L
.93706 .15678 L
.93735 .59614 L
.93762 .31407 L
.93791 .03351 L
.93823 .53679 L
.93854 .36012 L
.9387 .08375 L
.93888 .04324 L
.93918 .53966 L
.93947 .41189 L
.93976 .01473 L
.94003 .37509 L
.94028 .59196 L
.94055 .17695 L
.94084 .10673 L
.94115 .59017 L
.94141 .34979 L
Mistroke
.9417 .02017 L
.94186 .21833 L
.94203 .52931 L
.94235 .36382 L
.94266 .02739 L
.94295 .4811 L
.94326 .4423 L
.94344 .12033 L
.9436 .02186 L
.94378 .2503 L
.94394 .53083 L
.94411 .57521 L
.9443 .28263 L
.94459 .04227 L
.9449 .54232 L
.94519 .39363 L
.94546 .01627 L
.94577 .42218 L
.94595 .60331 L
.94611 .45079 L
.94641 .01604 L
.94673 .43193 L
.94702 .51623 L
.94734 .02361 L
.94765 .35917 L
.94792 .57455 L
.9482 .11884 L
.94845 .10149 L
.94874 .57511 L
.94902 .3709 L
.94931 .01998 L
.94963 .49885 L
.9499 .49006 L
.9502 .02639 L
.95051 .38126 L
.95069 .60024 L
.95086 .4852 L
.95117 .01705 L
.95147 .39005 L
.95173 .5814 L
.95201 .12595 L
.9523 .15917 L
.95258 .59118 L
.95283 .3578 L
.95307 .0198 L
.95333 .29313 L
.9536 .59921 L
.95387 .18849 L
.95417 .10405 L
.95445 .56705 L
Mistroke
.9547 .4241 L
.955 .01472 L
.95517 .17641 L
.95532 .46403 L
.95561 .50041 L
.95591 .02705 L
.9562 .33175 L
.95652 .54873 L
.95682 .05473 L
.95711 .2364 L
.95738 .60329 L
.95763 .27893 L
.95792 .04369 L
.9582 .49368 L
.9585 .44612 L
.95881 .01486 L
.95908 .37959 L
.95938 .54793 L
.9597 .03937 L
.95988 .09722 L
.96004 .38764 L
.96036 .51665 L
.96066 .03564 L
.96091 .23215 L
.96119 .60324 L
.96149 .19665 L
.96176 .07278 L
.96202 .51264 L
.96226 .52525 L
.96253 .06686 L
.96279 .17533 L
.96306 .59666 L
.96336 .26017 L
.96364 .04234 L
.96389 .45923 L
.96419 .4842 L
.96436 .17531 L
.96451 .01562 L
.9648 .37573 L
.9651 .54465 L
.96539 .05835 L
.96556 .058 L
.96571 .30818 L
.966 .59062 L
.9663 .11721 L
.96657 .12835 L
.96682 .55698 L
.9671 .40029 L
.96739 .01568 L
.96769 .4451 L
Mistroke
.96786 .60321 L
.96802 .45136 L
.96834 .01481 L
.96852 .20274 L
.96868 .49852 L
.96897 .45643 L
.96928 .01475 L
.96958 .41722 L
.96986 .54911 L
.97011 .11198 L
.97039 .14422 L
.97065 .57363 L
.97088 .43938 L
.97116 .02056 L
.97146 .37475 L
.97175 .56153 L
.97201 .11563 L
.97231 .18078 L
.97259 .59937 L
.97285 .32866 L
.97312 .01871 L
.97342 .46676 L
.97373 .44885 L
.974 .02695 L
.9743 .3349 L
.97454 .60055 L
.97478 .27977 L
.97499 .01604 L
.97521 .25926 L
.97546 .60141 L
.97572 .29669 L
.97594 .01516 L
.97619 .309 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`008?ooool2o`0003Kooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol0000eooooo`?o0000=?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0003Co
oooo1Ol00006ooooo`007oooool01?l0003oooooooooool0000dooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000003Cooooo00Co0000oooooooooooo0000
1_ooool001oooooo00Co0000oooooooooooo0000=?ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool01_ooool001oooooo00Co0000oooooooooooo
0000=?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01Oooool001oooooo00Co0000oooooooooooo0000=?ooool01?l0003oooooooooool00007
ooooo`Co0000=_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo1?l0000d
ooooo`05o`000?ooooooooooooooool000001_ooool001oooooo00Co0000oooooooooooo0000=?oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo03Kooooo0_l0000eooooo`;o0000
2Oooool00ol0003oooooooooo`0eooooo`05o`000?ooooooooooooooool000001_ooool0023ooooo
0_l0000fooooo`;o00002?ooool5o`0003Gooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`07ooooo`Go0000=?ooool3o`0000Oooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo000Koooooooo00001Ol00001ooooo`004oooool3
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool000cooooo1Ol00003ooooo`03
o`000?oooooooooo00Cooooo0_l0000>ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`09ooooo`;o003o0oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`06
o`00ooooooooooooo`00oooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`0?ooooo`04o`00oooooooo003oooooo`?o
003o00?oooooo`00ool00?l00oooool2o`00o`Sooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0;ooooo`06o`00ooooooooooooo`00oooooooo003o1oooool01_l00?ooooooooooool0
0?ooooooo`00o`[ooooo00Co003oooooool00?oo003o1oooool01?l00?ooooooo`00ool00?l3oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool00?l03Oooool2o`00o`?ooooo0_l00?l00ooo
ool0003oooooo`05ooooo`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooo003o00?ooooo00?o003oooooool00?l00_ooool3o`00o`09
ooooool00?oo003oo`00oooooooo003oooooool00?oooooo00;o003o1?ooool4o`00o`04ooooool0
0?oo003oo`00o`Gooooo0_l00?l2ooooo`04o`00oooooooo003oooooo`;o003o1?ooool00ol00?oo
ooooo`00o`02o`00o`05ooooool00?ooooooo`00ooooool01?l00?l3ooooo`?o003o00?oooooo`00
ool00?l00_l00?l02?oooooo003ooooooooooooo003oooooool00?oooooo1ol00?l00ooooooo003o
o`00o`02ooooo`09o`00ooooooooooooo`00oooooooo003oooooool00?oooooo00;o003o0oooool2
o`00o`;ooooo0ol00?l01Ooooooo003oo`00ool00?oooooo00Co003o00Coooooo`00ool00?oooooo
0_l00?l01?oooooo003oo`00ooooool4o`00o`05ooooool00?oo003oooooool00?l00_ooool01_l0
0?ooooooo`00oooooooo003oooooo`;o003o00Coooooo`00oooooooo003o0_ooool00ol00?oooooo
o`00o`03o`00o`04ooooool00?oo003oooooo`;o003o00Coooooo`00oooooooo003o0_ooool01?l0
0?ooooooooooool00?l2ooooo`04o`00oooooooo003oooooo`Ko003o0_ooool2o`00o`05ooooool0
0?oo003oo`00ooooool00_l00?l01?oooooo003oo`00ooooool3o`00o`03ooooool00?oo003o00;o
003o00?oooooo`00ooooool00_ooool00ol00?ooooooooooo`05o`00o`03ooooool00?oo003o00;o
003o0`000?l5ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`Oo003o0_ooool4o`00o`05ooooool00?oo003oo`00ooooool00ol00?l01Ooooooo
003oooooool00?oooooo00;o003o00?oooooo`00ooooool01Ol00?l00ooooooo003oo`00o`02o`00
o`04ooooool00?ooooooooooo`;o003o0_ooool01?l00?ooooooo`00ooooool3o`00o`;ooooo1_l0
0?l01Ooooooo003oooooool00?oooooo00Go003o0_ooool8o`00o`04ooooool00?ooooooooooo`?o
003o00?oooooo`00ool00?l02?l00?l2ooooo`07o`00ooooooooooooo`00oooooooo003oooooo`05
o`00o`05ooooool00?oo003oo`00ooooool04ol00?l01?oooooo003oo`00ooooool>o`00o`03oooo
ool00?oo003o00;o003o00Goooooo`00ool00?oo003oooooo`02o`00o`03ooooool00?oo003o00So
003o00?oooooo`00ool00?l00_l00?l00ooooooo003oooooo`07o`00o`03ooooool00?oo003o00Co
003o0_ooool2o`00o`05ooooool00?oo003oo`00ooooool02Ol00?l00ooooooo003oo`00o`02o`00
o`04ooooool00?oo003oooooo`?o003o00?oooooo`00ool00?l02?l00?l30000o`Gooooo0Ol00001
ooooo`004oooool2o`0000Kooooo00?o0000ooooooooool00oooool9o`00o`03ooooool00?oo003o
00;o003o00Goooooo`00ool00?oo003oooooo`03o`00o`03ooooool00?oo003o00Ko003o00?ooooo
o`00ool00?l00ol00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00Ko003o00?ooooo
o`00ooooool00ol00?l00ooooooo003oo`00o`05o`00o`03ooooool00?oo003o00Oo003o00?ooooo
o`00ool00?l02Ol00?l2ooooo`?o003o00?oooooo`00ool00?l02Ol00?l01?oooooo003ooooooooo
ool3o`00o`03ooooool00?oo003o00?o003o00Goooooo`00ool00?oo003oooooo`0Co`00o`04oooo
ool00?oo003ooooooa?o003o00Goooooo`00ool00?oo003oooooo`0Bo`00o`03ooooool00?oooooo
00Oo003o00?oooooo`00ool00?l01?l00?l2ooooo`;o003o00Goooooo`00ool00?oo003oooooo`09
o`00o`03ooooool00?oo003o00;o003o00Coooooo`00ool00?oooooo0ol00?l00ooooooo003oo`00
o`08o`00o`<0003o1Oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00ooooolBo`00o`03ooooool00?oo003o00[o003o00?oooooo`00ool00?l00ol00?l0
0ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ool00?l02ol00?l0
0ooooooo003oo`00o`07o`00o`03ooooool00?oo003o00Wo003o0_ooool3o`00o`03ooooool00?oo
003o00_o003o0_ooool3o`00o`03ooooool00?oo003o00?o003o00Goooooo`00ool00?oo003ooooo
o`0Co`00o`04ooooool00?oo003ooooooa?o003o00Goooooo`00ool00?oo003oooooo`0So`00o`;o
oooo0_l00?l01Ooooooo003oo`00ool00?oooooo00Wo003o00?oooooo`00ool00?l00_l00?l00ooo
oooo003oo`00o`0?o`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?o
oooo4_l00?l00ooooooo003oo`00o`0:o`00o`03ooooool00?oo003o017o003o00?oooooo`00ool0
0?l02ol00?l00ooooooo003oo`00o`07o`00o`03ooooool00?oo003o00Wo003o0_ooool3o`00o`03
ooooool00?oo003o00_o003o0_ooool=o`00o`03ooooool00?oo003o01Co003o00?oooooo`00ool0
0?l04Ol00?l01Ooooooo003oo`00ool00?oooooo02?o003o00?oooooo`00ool00?l01Ol00?l00ooo
oooo003oo`00o`0No`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?o
oooo7ol00?l00ooooooo003oo`00o`0Yo`00o`03ooooool00?oo003o00Wo003o0_oooolAo`00o`;o
oooo3Ol00?l00ooooooo003oo`00o`0Do`00o`03ooooool00?oo003o017o003o00?oooooo`00ool0
0?l09Ol00?l00ooooooo003oo`00o`05o`00o`03ooooool00?oo003o01ko003o0`000?l5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00ooooolOo`00o`03ooooool00?oo003o02Wo003o
00?oooooo`00ool00?l02Ol00?l2oooooa7o003o0_oooolTo`00o`03ooooool00?oo003o017o003o
00?oooooo`00ool00?l0C_l00?l30000o`Gooooo0Ol00001ooooo`006oooool2o`0000Cooooo7ol0
0?l00ooooooo003oo`00o`22o`00o`03ooooool00?oo003o04ko003o0`000?l4ooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl0
0?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00
007ooooo000Kooooo`;o00001?oooooeo`00o`<0003o1?ooool2o`00007ooooo000Kooooo`03o`00
0?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooe
o`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000
o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo
000Kooooo`;o00001?oooooeo`00o`<0003o1?ooool2o`00007ooooo000Kooooo`03o`000?oooooo
oooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03oooo
ooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0
003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool2o`0000Co
oooomOl00?l30000o`Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o
0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool000So
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00?o
oooomOl00?l30000o`Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooooGo003o0`000?l5oooo
o`7o00000Oooool000Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool2o`0000CooooomOl00?l30000
o`Cooooo0_l00001ooooo`001oooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0
003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool000Oooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooomOl00?l30000
o`Gooooo0Ol00001ooooo`002?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo00?o
oooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o
0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001
ooooo`006oooool2o`0000CooooomOl00?l30000o`Cooooo0_l00001ooooo`006oooool00ol0003o
ooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl0
0?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo0_l0
0004ooooooGo003o0`000?l4ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00ooooooe
o`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000
o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`;o00001?oooooeo`00o`<0
003o1?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
0ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`;o00001?oooooeo`00o`<0003o1?oo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o
0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Cooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000C
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Ooo
ool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo1_l0003eo`00o`<0003o1_l0
0001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooomOl0
0?l30000o`Gooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000
ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo
003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o
1Oooool1o`00007ooooo000Kooooo`;o00001?oooooeo`00o`<0003o1?ooool2o`00007ooooo000K
ooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo
mOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`00
0?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001oooo
o`006oooool2o`0000CooooomOl00?l30000o`Cooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooo
oooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l3
0000o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo0_l00004
ooooooGo003o0`000?l4ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00
o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo0_l00004ooooooGo
003o0`000?l4ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o
1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`002?ooool2o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool00ooooooeo`00o`<0003o
1Oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`00
1oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooooGo
003o0`000?l4ooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`00
1oooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`03ooooooGo
003o0`000?l5ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`00
2?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool2o`0000Co
oooomOl00?l30000o`Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o
0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool2o`0000CooooomOl0
0?l30000o`Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`03ooooooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03oooo
ooGo003o0`000?l5ooooo`7o00000Oooool001_ooooo0_l00004ooooooGo003o0`000?l4ooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool00ooooooeo`00o`<0003o1Oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00?ooooomOl00?l30000o`Gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`03oooook?o003o00?oooooo`00ool00?l0<_l00?l00ooooooo003oo`00o`0:
o`00o`<0003o1Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?oooooCOl00?l00ooo
oooo003oo`00o`1So`00o`03ooooool00?oo003o03;o003o00?oooooo`00ool00?l02_l00?l30000
o`Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooodgo003o00?oooooo`00ool0
0?l0HOl00?l00ooooooo003oooooo`0do`00o`03ooooool00?oo003o00[o003o0`000?l5ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool00ooooom=o`00o`03ooooool00?oo003o02So003o
00?oooooo`00ool00?l0=_l00?l00ooooooo003oooooo`0Co`00o`03ooooool00?oo003o01ko003o
00?oooooo`00ool00?l02_l00?l30000o`Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`03ooooodgo003o00?oooooo`00ool00?l0:?l00?l00ooooooo003oo`00o`0eo`00o`;ooooo00?o
003oooooool00?l04_l00?l00ooooooo003oo`00o`0No`00o`03ooooool00?oo003o00[o003o0`00
0?l5ooooo`7o00000Oooool001_ooooo0_l00004ooooodgo003o00?oooooo`00ool00?l01Ol00?l0
0ooooooo003oo`00o`0Ao`00o`03ooooool00?oo003o00co003o00?oooooo`00ool00?l0<Ol00?l2
ooooo`;o003o0_ooool00ol00?ooooooo`00o`0Bo`00o`03ooooool00?oo003o01ko003o00?ooooo
o`00ool00?l02_l00?l30000o`Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`03oooo
o`Oo003o00?oooooo`00ool00?l0@ol00?l01?oooooo003oo`00ooooool4o`00o`03ooooool00?oo
003o017o003o00?oooooo`00ool00?l03?l00?l00ooooooo003oo`00o`0ao`00o`;ooooo0_l00?l2
ooooo`03o`00oooooooo003o01;o003o00?oooooo`00ool00?l07_l00?l00ooooooo003oo`00o`05
o`00o`03ooooool00?oo003o00;o003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00oooool7o`00o`03ooooool00?oo003o02ko003o00?oooooo`00ool00?l04_l00?l01?oo
oooo003oo`00ooooool4o`00o`03ooooool00?oo003o017o003o00?oooooo`00ool00?l03?l00?l0
0ooooooo003oo`00o`0ao`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o01;o003o00?ooooo
o`00ool00?l07_l00?l00ooooooo003oo`00o`05o`00o`03ooooool00?oo003o00;o003o0`000?l5
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00oooool7o`00o`03ooooool00?oo003o
00Go003o00?oooooo`00ool00?l09_l00?l00ooooooo003oo`00o`0=o`00o`03ooooool00?oo003o
00;o003o00Coooooo`00ool00?oooooo1?l00?l00ooooooo003oo`00o`0;o`00o`03ooooool00?oo
003o00?o003o00?oooooo`00ool00?l03?l00?l00ooooooo003oo`00o`0=o`00o`03ooooool00?oo
003o013o003o00?oooooo`00ool00?l03_l00?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`06
o`00o`03ooooool00?oo003o00Wo003o00?oooooo`00ool00?l07_l00?l00ooooooo003oo`00o`05
o`00o`03ooooool00?oo003o00;o003o0`000?l5ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00oooool7o`00o`03ooooool00?oo003o00Go003o00?oooooo`00ool00?l00ol00?l01?oo
oooo003oo`00ooooool5o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l04Ol00?l0
1?oooooo003oo`00ooooool<o`00o`03ooooool00?oo003o00;o003o00Coooooo`00ool00?oooooo
1?l00?l00ooooooo003oo`00o`0;o`00o`03ooooool00?oo003o00;o003o0_ooool00ol00?oooooo
o`00o`06o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l03Ol00?l00ooooooo003o
o`00o`0@o`00o`03ooooool00?oo003o00go003o0oooool2o`00o`;ooooo00?o003oooooool00?l0
1_l00?l00ooooooo003oo`00o`09o`00o`03ooooool00?oo003o01Oo003o00?oooooo`00ool00?l0
1?l00?l00ooooooo003oo`00o`05o`00o`03ooooool00?oo003o00;o003o0`000?l5ooooo`7o0000
0Oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o003oooooool00?l00_l0
0?l00ooooooo003oooooo`06o`00o`;ooooo1Ol00?l01?oooooo003oo`00ooooool5o`00o`03oooo
ool00?oo003o00?o003o0_ooool8o`00o`03ooooool00?oo003o00Ko003o0_ooool2o`00o`03oooo
ool00?oo003o00[o003o0_ooool2o`00o`;ooooo0_l00?l2ooooo`?o003o00?oooooo`00ool00?l0
2ol00?l00ooooooo003oo`00o`02o`00o`;ooooo00Go003ooooooooooooo003oooooo`04o`00o`03
ooooool00?oo003o00;o003o00?oooooo`00ool00?l03Ol00?l00ooooooo003oo`00o`08o`00o`03
ooooool00?oo003o00;o003o00Coooooo`00ool00?oooooo3?l00?l00ooooooo003oo`00o`03oooo
o`;o003o0_ooool00ol00?ooooooo`00o`06o`00o`03ooooool00?oo003o00Wo003o0ooooolGo`00
o`03ooooool00?oo003o00Co003o00?oooooo`00ool00?l00ol00?l00ooooooo003oooooo`04o`00
o`<0003o1Oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool3o`00o`?ooooo00?o003oooooool00?l00ol00?l2ooooo`Go003o00Koooooo`00ool0
0?ooooooo`00ooooool2o`00o`;ooooo1Ol00?l2ooooo`So003o00?oooooo`00ool00?l01_l00?l2
ooooo`;o003o00Goooooo`00ool00?oo003oooooo`06o`00o`04ooooool00?ooooooooooo`;o003o
0_ooool2o`00o`;ooooo0ol00?l2ooooo`co003o00?oooooo`00ool00?l00_l00?l2ooooo`04o`00
ooooooooooooo`00o`;ooooo0ol00?l00ooooooo003oooooo`02o`00o`;ooooo1Ol00?l00ooooooo
003oo`00o`03ooooo`?o003o00?oooooo`00ooooool02?l00?l00ooooooo003oo`00o`02o`00o`04
ooooool00?oo003oooooo`Ko003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`03oooo
o`;o003o1?ooool2o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l02?l00?l4oooo
o`?o003o0oooool3o`00o`03ooooool00?oo003o00_o003o00?oooooo`00ool00?l01?l00?l00ooo
oooo003oo`00o`03o`00o`03ooooool00?oooooo00?o003o00Cooooo0000o`000?l0003o1Oooool1
o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`?o003o1Oooool4o`00
o`;ooooo1Ol00?l01_oooooo003oo`00oooooooo003oooooo`;o003o0_ooool5o`00o`;ooooo1Ol0
0?l2ooooo`04o`00ooooooooooooooooo`Go003o1?ooool00ol00?ooooooo`00o`04ooooo`Go003o
00Coooooo`00oooooooooooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`Gooooo1?l00?l2oooo
o`?o003o00Coooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`Co003o0oooool01?l00?oooooooooo
ooooool3o`00o`?ooooo2?l00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l0
0_ooool01?l00?ooooooo`00ooooool5o`00o`03ooooool00?oo003o00Cooooo00?o003ooooooooo
ool00_ooool2o`00o`03ooooool00?oooooo00;o003o00Coooooo`00oooooooo003o0_ooool3o`00
o`03ooooool00?oooooo00?ooooo0ol00?l3ooooo`?o003o00?oooooo`00ool00?l00_ooool9o`00
o`05ooooool00?oo003oo`00ooooool00_l00?l00ooooooo003oooooo`03o`00o`04ooooool00?oo
ooooooooo`;o003o00Cooooo0000ooooool0003o1?ooool2o`00007ooooo000Dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool001Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool00oooool1o`00007ooooo000Cooooo`;o00001_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooooooo`0000Go00000Oooool00?oooooo
8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.270385, -1.23352, \
0.00808853, 0.0130875}}],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](t) == sin(1000\ \[Pi]\ t)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Play[s2, {t, 0, 2}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`00000Q
0000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooo`00003oo`0001co
00000Oooool10000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oo
oooo00000?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool1
0000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo
00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000000000<0
0000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo00007?l00001
ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000000000<00000ooooool0
0000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo00007?l00001ooooo`400000
00000`00003oooooo`00003oo`0001co00000Oooool10000000000<00000ooooool00000ool0000L
o`00007ooooo0@000000000300000?oooooo00000?oo00007?l00001ooooo`40000000000`00003o
ooooo`00003oo`0001co00000Oooool10000000000<00000ooooooooool0oooooolMooooo`400000
003o00000240000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooo0000
0?oo00007?l00001ooooo`40000000000`00003oooooooooo`0<o`000005ooooool0003o0000o`00
0?ooool02_l000000ooooooo0000o`000008o`000003ooooool0003o000000?o000000?oooooo`00
0?l000002?l000000ooooooo0000o`000008o`000003ooooool0003o000000So000000?oooooo`00
0?l000000ol000001Ooooooo0000o`000?l0003ooooo00Ko000000Goooooo`000?l0003o0000oooo
o`0:o`000003ooooool0003o000000?o000000?oooooo`000?l000002?l000000ooooooo0000o`00
0008o`000003ooooool0003o000000So000000?oooooo`000?l000000ol000000ooooooo0000o`00
0008o`000005ooooool0003o0000o`000?ooool01_l000001Ooooooo0000o`000?l0003ooooo00Go
000000?oooooo`000?l000001?l000001Ooooooo0000o`000?l0003ooooo00[o000000?oooooo`00
0?l000002?l000000ooooooo0000o`000003o`000003ooooool0003o000000So000000?oooooo`00
0?l000002?l000001Ooooooo0000o`000?l0003ooooo00co000000Goooooo`000?l0003o0000oooo
o`0:o`000005ooooool0003o0000o`000?ooool00@000000000300000?oooooo000000;ooooo0_l0
0002ooooo`04o`000?oooooo0000o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;o
oooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`000004ooooool0003oooooooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05
o`000?ooooooooooooooool000000_ooool2o`000004ooooool0003oooooooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000Coooooo`000?oooooooooo
0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`40000000000`00003oooooooooo`02o`0000;ooooo0_l000001?oooooo
0000o`000?ooool2o`000005ooooool0003oooooo`000?ooool00ol000001?oooooo0000o`000?oo
ool3o`000005ooooool0003o0000o`000?ooool00_l000001Ooooooo0000o`000?l0003ooooo00;o
00000_ooool00ol0003oooooo`000002o`000004ooooool0003o0000ooooo`?o000000Goooooo`00
0?l0003o0000ooooo`02o`000005ooooool0003o0000o`000?ooool00ol000001?oooooo0000o`00
0?ooool3o`000004ooooool0003oooooooooo`;o000000Goooooo`000?oooooo0000ooooo`06o`00
0005ooooool0003oooooo`000?ooool00ol000001?oooooo0000o`000?ooool3o`000003ooooool0
003o000000;ooooo00?o0000ooooool000000_l000001?oooooo0000o`000?ooool3o`000005oooo
ool0003o0000o`000?ooool00_l000001Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`00
0?l0003ooooo0ol000001?oooooo0000ooooooooool2o`000005ooooool0003o0000o`000?ooool0
0_l000002Ooooooo0000o`000?l0003oooooo`000?oooooo0000ooooo`06o`000005ooooool0003o
ooooo`000?ooool00_l00002ooooo`03o`000?oooooo000000;o000000Soooooo`000?l0003ooooo
o`000?oooooo0000ooooo`?o000000Coooooo`000?l0003ooooo0ol000001Ooooooo0000o`000?l0
003ooooo00;o000000Koooooo`000?l0003o0000ooooool00002ooooo`;o000000Goooooo`000?l0
003o0000ooooo`02o`000005ooooool0003o0000o`000?ooool00ol000001?oooooo0000o`000?oo
ool3o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000o`000?ooool2o`0000;o
oooo0_l000001Ooooooo0000ooooool0003ooooo00Ko000000Goooooo`000?l0003o0000ooooo`03
o`00007ooooo0@000000000400000?oooooo0000ooooo`[o000000?oooooo`000?l000000ol00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`Go000000Gooooo
o`000?l0003o0000ooooo`09o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_oo
ool2o`000004ooooool0003o0000ooooo`[o000000?oooooo`000?l000000ol00002ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`Go000000?oooooo`000?l00000
2?l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo
00?o0000ooooooooool00_l000000ooooooo0000o`000008o`000003ooooool0003o000000?o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool5o`000003oooo
ool0003o000000So000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooooooool02Ol000001Ooooooo0000o`000?l0003ooooo00Go00000_ooool2o`00
00;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool5o`000003ooooool0003o0000
00So000000Coooooo`000?l0003ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo0Ol00001ooooo`40000000001@00003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`010000000000<00000ooooool000000_ooool2o`000003ooooool0003o
000000?o00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o00000_oo
ool00ol0003oooooooooo`02o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00;o
00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l000001Ooooooo0000o`000?l0003ooooo
00Go00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Go000000Go
ooooo`000?l0003o0000ooooo`02o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo
0000o`000002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`0000;ooooo1Ol00000
1Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00;o000000Goooooo`000?l0003o0000ooooo`02o`000003oooo
ool0003o000000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool00ol0003o
ooooooooo`02o`0000;ooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`00
0?l000001?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`7o00000Oooool10000000000@00000oooooooo
oooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`00000=ooooool0003o0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`00
0002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`06o`00
0?ooooooooooooooool0003ooooo0ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o
oooo00;ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00002ooooo`;o000000[oooooo`000?oooooo0000ooooool0003ooooo
o`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_l00002ooooo`06o`000?ooooooooooooooool0003ooooo0ol000001?oooooo0000o`000?ooool3
o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?oooooo
ooooooooool000000_ooool2o`0000;ooooo00[o0000ooooool0003oooooo`000?oooooo0000oooo
ool0003ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00000_ooool01_l0003ooooooooooooooooo0000ooooo`?o000000Coooooo`00
0?l0003ooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`0:o`000?oooooo0000ooooool0003o
ooooo`000?oooooo0000ooooo`;o000000?oooooo`000?l000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01_l0003ooooooooooooooooo0000oooo
o`?o000000Woooooo`000?l0003oooooo`000?oooooo0000ooooool000000oooool10000000000D0
0000ooooooooooooooooo`000003ooooo`;o00000_ooool2o`0000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Oo0000oooooooooooo0000ooooool0003ooooo00;o00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00002ooooo`05o`00
0?ooooooooooooooool000000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`;o00000oooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?oooooo00000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02o`0000;ooooo0_l00003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooo`00
00;ooooo0@000000000300000?oooooo000000;ooooo0_l000002Ooooooo0000o`000?oooooo0000
ooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00002ooooo`0<o`000?ooooooooooooooool0003oooooo`000?oooooo
0000ooooool0003ooooo0ol00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000Woooooo`00
0?l0003oooooo`000?oooooo0000ooooool000000oooool00ol0003oooooooooo`02o`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool02_l0003ooooooooooooooooo0000
ooooool0003oooooo`000?ooool2o`000003ooooool0003o000000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_l000002Ooooooo0000o`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`0:
o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooo`;o000000?oooooo`000?l00000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?oooooooooooooo
ool000000_ooool2o`0000;ooooo0ol000002?oooooo0000ooooool0003oooooo`000?oooooo0000
0oooool00ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00000_ooool02_l0003ooooooooooooooooo0000ooooool0003oooooo`000?ooool2o`000003oooo
ool0003o000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000000Cooooo0@000000000300000?oooooooooo00;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo0_l00002oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`000003ooooool0
003o000000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l00002ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o0000
00?oooooo`000?l000000_ooool2o`000003ooooool0003o000000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l000000ooo
oooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooo
oooo00;o00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_l0
0002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo0_l00002ooooo`04o`00
0?oooooo0000o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool00ol0003o
ooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool100000000
00@00000oooooooooooo00003_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l000001Ooo
oooo0000ooooool0003ooooo00;o00000oooool00ol0003oooooooooo`0=ooooo`07o`000?oooooo
ooooo`000?oooooo0000ooooo`02o`0000;ooooo0_l000001?oooooo0000ooooool00002ooooo`03
o`000?oooooooooo00gooooo00Co0000oooooooooooooooo0_l000002Ooooooo0000ooooool0003o
ooooo`000?oooooo0000ooooo`02o`0000?ooooo00?o0000ooooooooool03Oooool01ol0003ooooo
ooooool0003oooooo`000?ooool00_l00002ooooo`;o000000Coooooo`000?oooooo00000_ooool0
0ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o000000Goooooo`000?oooooo0000
ooooo`02o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00gooooo00Oo0000oooooooooooo
0000ooooool0003ooooo00;o00000_ooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000
ooooooooool03Oooool01?l0003oooooooooooooool2o`000005ooooool0003oooooo`000?ooool0
0_l00002ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`08o`000?ooooooooooooooool0
003oooooo`000?ooool2o`0000;ooooo0_l000001?oooooo0000ooooool00003ooooo`4000000000
0`00003oooooooooo`02ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool2o`000006ooooool0003oooooo`000?oo
oooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000ooooool0003o00000_ooool2o`000003
ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02o`0000;ooooo00_o0000ooooool0003oooooo`00
0?oooooo0000ooooool0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
o`000?l00002ooooo`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00_o
0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?oooooo0000o`0000;ooooo0_l000000ooooooo0000ooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`0:o`000?oooooo0000o`000?oooooo0000ooooool0003o
ooooo`0000?ooooo0Ol00001ooooo`40000000001000003oooooooooool00002ooooo`;o00000_oo
ool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo00?o0000ooooooooool0
0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo
0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00;o
00000_ooool00ol0003oooooooooo`02o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o
00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02o`00
00;ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo00Co
0000oooooooooooo00000oooool10000000000D00000ooooooooooooooooo`000003ooooo`;o0000
00Coooooo`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000002ooooo`08o`000?ooooooooooooooool0003ooooo
o`000?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool2o`000004ooooool0
003oooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000_ooool02?l0003ooooooooooooooooo0000ooooool0003ooooo
0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool2o`000004ooooool0003o
ooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000_ooool02?l0003ooooooooooooooooo0000ooooool0003ooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000oooool02_l0003oooooooooool0003oooooo`000?oooooo0000oooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000;ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000;ooooo0@000000000300000?oooooo000000;ooooo0_l00008ooooo`05
o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002
ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000oooooooooooooooo
o`000008ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00008ooooo`05o`000?oooooo
ooooooooool000000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
0_ooool01Ol0003ooooooooooooooooo000000Sooooo0_l00002ooooo`05o`000?oooooooooooooo
ool000000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000Wooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000008oooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?oooooo
ooooooooool000001?ooool10000000000D00000ooooooooooooooooo`000003ooooo`;o00000_oo
ool2o`0000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00003ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`02o`00
00?ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2
o`000003ooooool0003o000000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000_oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o
00000_ooool2o`0000?ooooo00Oo0000oooooooooooo0000ooooool0003ooooo00;o00000oooool0
1?l0003oooooooooooooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000000oooool01?l0003oooooooooooooool2o`000004ooooool0003oooooo`0000;o
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo0_l00003ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`000003ooooool0003o
000000?ooooo00Co0000oooooooooooooooo0_l000001?oooooo0000ooooool00002ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o
00000oooool00ol0003oooooooooo`02o`0000;ooooo0_l00003ooooo`07o`000?ooooooooooo`00
0?oooooo0000ooooo`02o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool1
0000000000@00000ooooool0003o00000_ooool2o`0000;ooooo0_l00002ooooo`05o`000?oooooo
ooooooooool000005?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o0000
0_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool04_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool000000_ooool2o`0000;o
oooo00Go0000ooooooooooooooooo`00000Dooooo`40000000001P00003oooooooooool0003ooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`08o`000?oooooo0000ooooool0003o
ooooo`000?ooool2o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o0000
00Coooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l000002Ooo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`00000<ooooool0003oooooo`000?oo
oooo0000ooooool0003oooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Ko0000ooooool0003oooooo`000?ooool2o`00000;ooooool0003oooooo`000?oooooo0000
ooooool0003oooooo`000?ooool00_l000001?oooooo0000ooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool2o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo
00;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l00003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooo`000?ooool2o`00000;ooooool0003ooooo
o`000?oooooo0000ooooool0003oooooo`000?ooool00_l000001_oooooo0000ooooool0003ooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`0<o`000?oooooo0000ooooool0003o
ooooo`000?oooooo0000ooooool0003ooooo0_l000002Ooooooo0000ooooool0003oooooo`000?oo
oooo0000ooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
0000ooooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l000002?oo
oooo0000ooooool0003oooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000;o
oooo00[o0000ooooool0003oooooo`000?oooooo0000ooooool0003ooooo0_l000002ooooooo0000
ooooool0003oooooo`000?oooooo0000ooooool0003ooooo0040000000000`00003oooooo`000002
ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooooooooooo0000ooooo`;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0000;o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002
ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002
ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooooooooooo0000ooooo`;o
00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`000003
ooooool0003ooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`00
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooooooool0003ooooo
0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
00?oooooo`000?ooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o
000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool2
o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00000
0ooooooo0000ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l0
00000ooooooo0000o`000002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0Ol0
0001ooooo`40000000000`00003oooooooooo`03ooooo`;o00000_ooool2o`000004ooooool0003o
ooooo`0001Wooooo00Co0000ooooool0003ooooo0_l00002ooooo`;o00006_ooool2o`0000;ooooo
0_l000001?oooooo0000ooooool0000Iooooo`04o`000?oooooo0000ooooo`;o00000_ooool2o`00
01[ooooo0_l00002ooooo`;o000000Coooooo`000?oooooo00006Oooool01?l0003oooooo`000?oo
ool2o`0000;ooooo0_l0000Jooooo`;o000000Soooooo`000?oooooo0000ooooool0003oooooo`00
01Wooooo00Co0000ooooool0003ooooo0_l00002ooooo`;o00005oooool10000000000D00000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00005ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Gooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo0040000000000`00003oooooo`000003ooooo`04
o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooool00003ooooo`;o00000_ooool2
o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000;ooooo
0_l00002ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00Co0000oooooooooooo00000oooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`;o00000oooool01?l0003oooooooooool00003ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oo
ooooooooo`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000?ooooo
00Co0000oooooooooooo00000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0@0000000003
00000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000004?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000004?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo0000017ooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000004?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo0000017ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000004?ooool1o`00007ooooo0@000000000500000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000ooooool0003ooooo0_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000oooo
o`02o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l000002?oooooo0000oooo
ool0003oooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`;o00000_ooool2o`000009ooooool0003oooooo`000?oooooo
0000ooooool0003ooooo00;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool2o`00
0008ooooool0003oooooo`000?oooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l000002Ooooooo0000ooooool0003o
ooooo`000?oooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00So0000ooooool0003oooooo`000?oo
oooo0000ooooo`;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool2o`000009oooo
ool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000Coooooo`000?oooooo00000ooo
ool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000ooooool0
003ooooo0_l00002ooooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool0
0@000000000400000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_l00002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?oooooo
ooooooooool000000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000003ooooo`40000000001@00003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
0oooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooooooo`;o00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool02Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o00000ooo
ool01?l0003oooooooooool00002ooooo`40000000000`00003oooooo`000002ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`000003ooooool0003ooooo00;ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Ko0000ooooool0003oooooo`000?ooool2o`0000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`0000;ooooo0_l00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`;o00000_ooool2o`000003
ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000ooooool0003o0000
0_ooool2o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`000006ooooool0003oooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooo`000?l00002ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo0@000000
000800000?oooooo0000ooooool0003oooooo`000?ooool2o`00000:ooooool0003oooooo`000?oo
oooo0000ooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool03?l0003oooooo`000?oooooo0000ooooool0003oooooo`00
0?oooooo0000ooooo`;o000000Coooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01_l0003oooooo`000?oooooo0000ooooo`;o
000000[oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`0:o`000?oooooo0000
ooooool0003oooooo`000?oooooo0000ooooo`;o000000Koooooo`000?oooooo0000ooooool00003
ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
o`000?ooool2o`00000<ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`0:o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`;o000000Koooooo`00
0?oooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?oooooo0000ooooo`;o000000Woooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00_l00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00[o0000ooooool0003oooooo`000?oooooo0000ooooool0003o
oooo0_l000001_oooooo0000ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000Cooooo0@000000000300000?oooooooooo017ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`0Aooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000;o
oooo0_l00002ooooo`05o`000?ooooooooooooooool000004oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo00Co
0000oooooooooooo00000oooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000Cooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool04Oooool01?l0003oooooooooool00003ooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo0@000000000400000?ooooooooooo`0000;ooooo0_l00002ooooo`;o0000
0_ooool2o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l000000ooooooo0000o`000002oooo
o`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`;o00000_ooool2o`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooo`000?l00002ooooo`;o00000_ooool2o`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000000_ooool10000000000H00000oooooooooooo0000ooooool0000:ooooo`06o`00
0?oooooo0000ooooool0003ooooo0_l00002ooooo`;o000000Goooooo`000?oooooo0000ooooo`02
o`0000;ooooo0_l000000ooooooo0000ooooo`09ooooo`03o`000?oooooooooo00;o000000Gooooo
o`000?oooooo0000ooooo`02o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o0000
0_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo0000o`0000;ooooo0_l00002ooooo`;o
000000Goooooo`000?oooooo0000ooooo`02o`0000;ooooo0_l000000ooooooo0000ooooo`09oooo
o`03o`000?oooooooooo00;o000000Goooooo`000?oooooo0000ooooo`02o`0000;ooooo0_l00000
1Ooooooo0000ooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`08ooooo`04o`000?oo
oooo0000o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000ooooo`09ooooo`03o`000?oooooooooo00;o000000Goooooo`000?oo
oooo0000ooooo`02o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000_ooool0
0ol0003oooooooooo`08ooooo`04o`000?oooooo0000o`0000;ooooo0_l000001Ooooooo0000oooo
ool0003ooooo00;o00000_ooool2o`000006ooooool0003oooooo`000?oooooo00002_ooool01_l0
003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`0000;ooooo0_l000001ooooooo0000oooo
ool0003oooooo`000?ooool00@000000000300000?oooooooooo00;ooooo00?o0000ooooooooool0
0_l00002ooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00006?ooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000005oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00006?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000005ooo
ool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`03o`000?oooooooooo01Kooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000001Oooooo00Go0000oooo
ooooooooooooo`000002ooooo`;o00000_ooool00ol0003oooooooooo`0Dooooo`40000000001000
003oooooooooool0000>ooooo`04o`000?oooooo0000ooooo`;o000000Woooooo`000?oooooo0000
ooooool0003oooooo`000?ooool00_l00002ooooo`;o00003oooool2o`000005ooooool0003ooooo
o`000?ooool00_l00002ooooo`;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000ko
oooo00Co0000ooooool0003ooooo0_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000
ooooo`02o`000004ooooool0003oooooo`0000oooooo0_l000001Ooooooo0000ooooool0003ooooo
00;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l0000?ooooo`;o00000_ooool2
o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000Coooooo`000?oo
oooo00003_ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l00002ooooo`;o0000
00Goooooo`000?oooooo0000ooooo`02o`0000oooooo0_l00002ooooo`;o000000Goooooo`000?oo
oooo0000ooooo`02o`0000;ooooo0_l000001?oooooo0000ooooool0000>ooooo`08o`000?oooooo
0000ooooool0003oooooo`000?ooool2o`00000;ooooool0003oooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00@000000000400000?ooooooooooo`0000;ooooo0_l00002ooooo`;o0000
0_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l000000ooooooo0000o`000002
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o0000
0_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo0_l0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00;o00000_ooool2o`000003ooooool0003o000000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo0_l00002ooooo`;o00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool10000
000000<00000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00
0002ooooo`;o00000oooool01?l0003oooooooooool0000Cooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool04Oooool01?l0
003oooooooooool00003ooooo`;o00000oooool01?l0003oooooooooool0000Cooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool04Oooool01?l0003oooooooooool00003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo
000001?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`05
o`000?ooooooooooooooool000000_ooool10000000000P00000ooooool0003oooooo`000?oooooo
0000ooooo`;o000000[oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool0
0ol0003oooooooooo`09ooooo`0=o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`00
0?oooooo0000ooooo`02o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00[o0000ooooooooooooooooo`000?oooooo0000ooooool0003ooooo0_l000002_oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00Wo
oooo00go0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o
000000Koooooo`000?oooooo0000ooooool00003ooooo`03o`000?oooooooooo00Sooooo00Ko0000
ooooooooooooooooo`000?ooool2o`0000;ooooo0_l000002_oooooo0000ooooool0003oooooo`00
0?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00Wooooo00go0000oooooooooooo0000
ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000Koooooo`000?oooooo0000
ooooool00003ooooo`03o`000?oooooooooo00Sooooo00Ko0000ooooooooooooooooo`000?ooool2
o`0000;ooooo0_l000002_oooooo0000ooooool0003oooooo`000?oooooo0000ooooool00002oooo
o`03o`000?oooooooooo00Wooooo00go0000oooooooooooo0000ooooool0003oooooo`000?oooooo
0000ooooool0003ooooo00;o000000Koooooo`000?oooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool10000000000<00000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0
003ooooooooooooooooo000000Cooooo0@000000000500000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00cooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0<ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00@000000000400000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l00002ooooo`;o000000?o
ooooo`000?l000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000ooooool0003o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o00000_ooool2o`000003ooooool0
003o000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`0000;ooooo0_l00002oooo
o`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`02o`000003ooooool0003o000000;ooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooo`000?l00002ooooo`;o00000_ooool2o`00
0003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_l000000ooooooo0000o`000002ooooo`;o00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?oooooo0000o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?ooool00_ooool10000000000@00000oooooooooooo00000_ooool01?l0003oooooooooooooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`;o00000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0@00
0000000300000?oooooooooo017ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0001;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o
00000oooool01Ol0003ooooooooooooooooo000001;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001;ooooo00Go0000oooooooooooooooo
o`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000001;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001;ooooo00Go0000
ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000001;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooo`000002ooooo`05o`000?oooooooooooooo
ool000004_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000oooool0
1_l0003ooooooooooooooooo0000ooooo`40000000000`00003oooooooooo`02ooooo`03o`000?oo
oooooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000009ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00?o0000oooo
ooooool00_l00002ooooo`;o00000_ooool01?l0003oooooooooool0000:ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?oooooo
ooooo`0000[ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo0_l00002ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`05
o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01oooool01_l0003ooooooooooooooooo0000ooooo`40000000000`00003o
ooooo`000003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02o`0000;ooooo0_l00003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooooooo0_l000000ooooooo0000o`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooooooool2o`000003ooooool0003o000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000;ooooo00?o0000oooooooo
ool00_ooool10000000000D00000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00000Eooooo`05o`000?ooooooooooooooool000001Oooool0
1Ol0003ooooooooooooooooo000001Gooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooo
oooooooooooo000001Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooooooo
o`0001Kooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo000001Gooooo
00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0001Gooooo00Go0000oooo
ooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000005Oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo00005Oooool10000000000D00000oooooooooooo
ooooo`00000<ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0:ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000_ooool10000000000<00000ooooool000000oooool2o`0000;ooooo0_l000001?oooooo
0000ooooool00002ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000;ooooo00So0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000oooool01Ol0
003ooooooooooooooooo000000[ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_oo
ool2o`000004ooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?ooooooooooooooool000000_ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo
0_l00003ooooo`05o`000?ooooooooooooooool000002_ooool01Ol0003ooooooooooooooooo0000
00?ooooo0_l000002?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo0000
ooooo`;o00000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`00000:ooooo`05o`000?oo
ooooooooooooool000000oooool2o`000008ooooool0003oooooo`000?oooooo0000ooooool00002
ooooo`05o`000?ooooooooooooooool000002oooool01?l0003oooooooooool00003ooooo`04o`00
0?oooooo0000ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo00002oooool00ol0
003oooooooooo`02ooooo`40000000000`00003oooooooooo`0Dooooo`03o`000?oooooooooo00;o
00000_ooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo00;o00000_ooool2o`00
00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02o`000003ooooool0003o0000
00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002oooo
o`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooo
oooo01Kooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0@00
0000000400000?ooooooooooooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00003oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_oo
ool2o`0000;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02o`0000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000oooooo0_l00002ooooo`;o00000_oo
ool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l0
000?ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`;o0000
0_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo
00?o0000ooooooooool00_l00002ooooo`;o00003oooool2o`0000;ooooo00?o0000ooooooooool0
0_l00002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool03_ooool1o`00007ooooo
0@000000000400000?ooooooooooo`0000kooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
000:ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool03?ooool02_l0003ooooooooooooooooo0000ooooool0003oooooo`000?ooool2o`000006oooo
ool0003oooooo`000?oooooo00000oooool00ol0003oooooooooo`0<ooooo`04o`000?oooooooooo
o`0000;ooooo0_l000002_oooooo0000ooooool0003oooooo`000?oooooo0000ooooool00002oooo
o`03o`000?oooooooooo00cooooo00[o0000ooooooooooooooooo`000?oooooo0000ooooool0003o
oooo0_l000001_oooooo0000ooooool0003oooooo`0000?ooooo00?o0000ooooooooool03?ooool0
3Ol0003oooooooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l00002
ooooo`04o`000?ooooooooooo`0000kooooo00[o0000ooooooooooooooooo`000?oooooo0000oooo
ool0003ooooo0_l000001_oooooo0000ooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
3?ooool03Ol0003oooooooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool0
0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00cooooo00Ko0000oooooooooooo
ooooo`000?ooool2o`0000;ooooo0_l000001_oooooo0000ooooool0003oooooo`0000?ooooo0@00
0000000300000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`0Iooooo`05o`000?ooooooooooooooool000000_ooool2o`0001_ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000000_ooool2o`00
01[ooooo0_l00002ooooo`05o`000?ooooooooooooooool000006oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool06Oooool2o`0000;ooooo00Go0000oooooooooooooooo
o`00000Kooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Fooooo`40
000000001000003oooooooooool0000>ooooo`04o`000?ooooooooooo`0000;ooooo0_l000001Ooo
oooo0000ooooool0003ooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000gooooo00Ko
0000ooooooooooooooooo`000?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo0_l000001Ooo
oooo0000ooooool0003ooooo00;o00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?oo
ooooooooooooool0003ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003ooooo00;o
oooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00002ooooo`;o000000Goooooo`00
0?oooooo0000ooooo`02o`0000;ooooo00Co0000oooooooooooo00003_ooool01_l0003ooooooooo
oooooooo0000ooooo`;o00000_ooool2o`000006ooooool0003oooooo`000?oooooo00000oooool0
0ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool2o`000005ooooool0
003oooooo`000?ooool00_l00002ooooo`04o`000?ooooooooooo`0000kooooo00Ko0000oooooooo
ooooooooo`000?ooool2o`0000;ooooo0_l000001_oooooo0000ooooool0003oooooo`0000?ooooo
0@000000000400000?oooooo0000ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
0_ooool2o`0000;ooooo0_l0000?ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo
0_l000000ooooooo0000o`000002ooooo`;o00003oooool2o`0000;ooooo0_l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`000003ooooool0003o000000oooooo00Co0000ooooool0003o
oooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000?ooooo`;o
00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00003oooool2o`0000;ooooo0_l00002ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`00
00;ooooo0_l0000?ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000003oooool00ol0003oooooooooo`010000000000<00000oooooooo
ool05?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0001Sooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000006?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0001Sooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000006?ooool01?l0003oooooooooool00003ooooo`04o`00
0?ooooooooooo`0001Sooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000006?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0001Sooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool10000
000000<00000ooooool000000oooool02_l0003oooooo`000?l0003oooooo`000?oooooo0000oooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000_ooool02?l0003oooooo`000?oooooo0000ooooool0003o
oooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`0:o`000?oooooo0000o`000?oooooo
0000ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool02?l0003oooooo`000?oooooo0000
ooooool0003ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo0_l000002?oo
oooo0000ooooool0003oooooo`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`06o`000?oooooo
0000ooooool0003ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`06o`000?oooooo0000ooooool0003ooooo0_l000000ooooooo0000ooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool10000000000D00000ooooooooooooooooo`00000<ooooo`04o`000?oooooo
ooooo`0000?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool0000<ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`00
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00[ooooo00Co0000
oooooooooooo00000oooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oo
ooooooooo`0000cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02_ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000?ooooo00Co
0000oooooooooooo00003?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0:oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ooooooooooooooooo`000002ooooo`;o
00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`40000000001000003o
ooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0<ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0040000000000`00003oooooo`000003ooooo`04
o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000000oooool10000000000<00000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01_l0003ooooooooooooooooo
0000ooooo`40000000000`00003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00000@
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`00000?ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00000@ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`00000@ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00004?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000004?ooool1o`00007ooooo0@000000000400000?ooooooooooo`0000ko
oooo00Co0000oooooooooooooooo0_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000
ooooo`02o`0000?ooooo00?o0000ooooooooool03Oooool01ol0003oooooooooool0003oooooo`00
0?ooool00_l00002ooooo`;o000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`0<
ooooo`04o`000?ooooooooooooooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`00
0?ooool00_l00003ooooo`03o`000?oooooooooo00cooooo00So0000ooooooooooooooooo`000?oo
oooo0000ooooo`;o00000_ooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool03Oooool01?l0003oooooooooooooool2o`000009ooooool0003oooooo`000?oooooo0000oooo
ool0003ooooo00;o00000oooool00ol0003oooooooooo`0<ooooo`08o`000?ooooooooooooooool0
003oooooo`000?ooool2o`0000;ooooo0_l000001?oooooo0000ooooool00002ooooo`03o`000?oo
oooooooo00gooooo00Co0000oooooooooooooooo0_l000002Ooooooo0000ooooool0003oooooo`00
0?oooooo0000ooooo`02o`0000?ooooo00?o0000ooooooooool03?ooool02?l0003ooooooooooooo
oooo0000ooooool0003ooooo0_l000002?oooooo0000ooooool0003oooooo`000?oooooo00000ooo
ool10000000000@00000oooooooooooo00000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo0000
00gooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003oooooooooool0000>ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00002ooooo`;o00000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0000;ooooo00Co0000oooooooooooo00003Oooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool01Ol0003o
oooooooooooooooo000000gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00;o00000_ooool2o`0000;ooooo00Co0000oooooooooooo00003Oooool01?l0003ooooooooo
ooooool10000000000<00000ooooooooool05Oooool2o`0000;ooooo00?o0000ooooooooool00_l0
000Kooooo`03o`000?oooooooooo00;o00000_ooool2o`0001[ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00006_ooool2o`0000;ooooo0_l00002ooooo`;o00006_ooool2o`0000;ooooo00?o
0000ooooooooool00_l0000Jooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool06Ooo
ool2o`0000;ooooo00?o0000ooooooooool00_l0000Jooooo`;o00000_ooool2o`0000;ooooo00?o
0000ooooooooool01?ooool10000000000P00000ooooooooooooooooo`000?oooooo0000ooooo`;o
000000Soooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooooooool03Ooo
ool02ol0003oooooooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o00000_ooool2
o`0000?ooooo00?o0000ooooooooool03?ooool02?l0003ooooooooooooooooo0000ooooool0003o
oooo0_l000002?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool00ol0003ooooooooo
o`0=ooooo`0;o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l00002
ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`000008ooooool0003oooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo
00gooooo00_o0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`000004
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000oooool00ol0003ooooooooo
o`0=ooooo`0;o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l00000
1?oooooo0000ooooool00003ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00@00
0000000300000?oooooo0000013ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000004?ooool0
0ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_oo
ool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`02o`00
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000004?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000_ooool2o`0000;ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000001?ooool10000000000<0
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooo`000003ooooo`04o`000?ooooooooooo`0001;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000Boooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooo
oooo0000017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00004_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
000000?ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0001?ooooo0@0000000005
00000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`;o00000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool2o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool2o`00
00?ooooo00Co0000oooooooooooo00000_ooool10000000000@00000oooooooooooo00000oooool0
0ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00000ooo
ool10000000000@00000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000004oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo00005?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000004ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00005?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000004oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00005?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000004oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00005?ooool10000000000<00000ooooooooool04Oooool03ol0003oooooo`000?l0
003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`0001;ooooo00So
0000ooooool0003oooooo`000?oooooo0000ooooo`;o000000Soooooo`000?oooooo0000ooooool0
003oooooo`0001;ooooo00go0000ooooool0003o0000ooooool0003oooooo`000?oooooo0000oooo
ool0003ooooo00;o000000?oooooo`000?ooool04Oooool02?l0003oooooo`000?oooooo0000oooo
ool0003ooooo0_l000002?oooooo0000ooooool0003oooooo`000?oooooo00004_ooool2o`00000;
ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000
ooooo`0Aooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool2o`000008ooooool0003o
ooooo`000?oooooo0000ooooool0000Booooo`;o000000_oooooo`000?oooooo0000ooooool0003o
ooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo017ooooo00Ko0000ooooool0003o
ooooo`000?ooool2o`00000;ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000?oo
ool00@000000000300000?oooooooooo00;ooooo00?o0000ooooooooool00_l00002ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooo
ooooooooooooo`000002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002
ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000009ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00002ooooo`;o00000_ooool01?l0003oooooooooool0000:ooooo`04o`00
0?ooooooooooo`0000;ooooo0_l00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000_ooool2o`00
00;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo
000000Wooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Oo
oooo00Ko0000ooooooooooooooooo`000?ooool10000000000<00000ooooooooool05oooool2o`00
0003ooooool0003o000001kooooo0_l00002ooooo`;o00007_ooool2o`000003ooooool0003o0000
01kooooo0_l00002ooooo`;o00007_ooool2o`000003ooooool0003o000001kooooo0_l00002oooo
o`;o00007_ooool2o`000003ooooool0003o000001kooooo0_l00002ooooo`;o00001oooool10000
000000<00000ooooool000000oooool2o`0000;ooooo0_l000001?oooooo0000ooooool00002oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000ooooool0003ooooo0_l00002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000_o
oooo00Co0000oooooooooooo00000oooool2o`0000;ooooo0_l000001?oooooo0000ooooool00002
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000ooooool0003ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooool0000<oooo
o`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`;o000000Coooooo`000?oooooo00000_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?oooooo0000ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo00002oooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`;o000000?oooooo`000?l000000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?oooooo0000ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`02ooooo`40000000001@00003ooooooooooooooooo000000cooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo0@000000000500000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00cooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool03?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00@000000000300000?oooooo000000?ooooo00Co
0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool2o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00001?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00001?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00001?ooool10000000000<00000ooooooooool0
5?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0Booooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool03oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000001Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000005?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`7o00000Oooool1
0000000000@00000oooooooooooooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00?o0000
ooooooooool00_l0000?ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003ooooooooo
o`02o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_l0
0002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l0000?ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool00ol0003ooooo
ooooo`02o`0000?ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooooooool2o`000003
ooooool0003o000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`03
o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`00000@ooooo`7o00000Oooool10000000000@00000oooooooo
oooo00003_ooool01?l0003oooooooooool00002ooooo`;o000000[oooooo`000?oooooo0000oooo
ool0003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`0<ooooo`0:o`000?oooooooooo
ooooool0003oooooo`000?oooooo0000ooooo`;o000000Koooooo`000?oooooo0000ooooool00003
ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00000_ooool2o`000005ooooool0
003oooooo`000?ooool00_l00002ooooo`04o`000?ooooooooooo`0000kooooo00[o0000oooooooo
ooooooooo`000?oooooo0000ooooool0003ooooo0_l000001_oooooo0000ooooool0003oooooo`00
00?ooooo00?o0000ooooooooool03?ooool03Ol0003oooooooooool0003oooooo`000?oooooo0000
ooooool0003oooooo`000?ooool00_l00002ooooo`04o`000?ooooooooooo`0000kooooo00[o0000
ooooooooooooooooo`000?oooooo0000ooooool0003ooooo0_l000001_oooooo0000ooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool03?ooool03Ol0003oooooooooool0003oooooo`000?oo
oooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00cooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;ooooo0_l000001_oooooo
0000ooooool0003oooooo`0000?ooooo0@000000000300000?oooooooooo00Cooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
6Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06?ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
5_ooool10000000000@00000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000000_ooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?ooooooooooooooool0003ooooo0_l0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000000_ooool02ol0003ooooooooooooooooo0000ooooool0003ooooo
o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`;o00000_oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000;ooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool2o`000003ooooool0
003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00000oooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`00
0?oooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`;o000000?ooooo
o`000?ooool00_ooool01?l0003oooooooooooooool10000000000D00000ooooooooooooooooo`00
0003ooooo`;o00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
00000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
00000_ooool2o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooo`0000;ooooo0@000000000300000?oooooo000000;ooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo0@000000000300000?oooooo000000?ooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_l00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000Co
oooo0@000000000500000?ooooooooooooooool000000oooool2o`000004ooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000000_ooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?oo
oooo00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00[o0000oooooooooooo0000ooooool0003ooooo
o`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000002ooooo`08o`000?ooooooooooooooool0003oooooo`000?oo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000003ooooo`0:o`000?ooooooooooo`000?oooooo0000ooooool0
003oooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0000?ooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000;ooooo0@000000000300000?oooooooooo01;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0B
ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000oooooooooooooooo
o`00000Dooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002
ooooo`05o`000?ooooooooooooooool000005?ooool01?l0003oooooooooool00003ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000005?ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04_ooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool10000
000000@00000ooooool0003o00000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000004oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`00
01;ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l0000Coooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o00004_ooool2o`00
00;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0001?ooooo0_l00002oooo
o`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0000Booooo`;o00000_ooool2o`00
00;ooooo0_l000000ooooooo0000o`000002ooooo`;o00004oooool2o`000003ooooool0003o0000
00;ooooo0_l00002ooooo`;o00000_ooool2o`0001?ooooo0@000000000300000?oooooooooo013o
oooo00?o0000ooooooooool00_l00002ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`00
00;ooooo00?o0000ooooooooool03oooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_oo
ool2o`000006ooooool0003oooooo`000?oooooo00004Oooool00ol0003oooooooooo`02o`0000;o
oooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool00ol0003oooooooooo`0?ooooo`06
o`000?oooooo0000ooooool0003ooooo0_l00002ooooo`;o000000Koooooo`000?oooooo0000oooo
ool0000Aooooo`03o`000?oooooooooo00;o000000Goooooo`000?oooooo0000ooooo`02o`0000;o
oooo0_l00002ooooo`03o`000?oooooooooo00oooooo00Ko0000ooooool0003oooooo`000?ooool2
o`0000;ooooo0_l000001_oooooo0000ooooool0003oooooo`00017ooooo00?o0000ooooooooool0
0_l000001Ooooooo0000ooooool0003ooooo00;o00000_ooool2o`000003ooooool0003ooooo017o
oooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo0_l000001ooooooo0000ooooool0003o
ooooo`000?ooool00@000000000300000?oooooooooo00;ooooo00?o0000ooooooooool00_l00002
ooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`02o`0000;ooooo00Go0000oooooooo
ooooooooo`00000Gooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
000Hooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00000Gooooo`05
o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00?o0000ooooooooool05_ooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000005oooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00002ooooo`03o`000?oooooooooo01Cooooo0@000000000300000?oo
oooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000;ooooo
00_o0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000[ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`00
00;ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00_o0000ooooool0003oooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000002_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000ooooool0003o00000_ooool2o`000003ooooool0003ooooo00;o
oooo00Go0000ooooooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000000_ooool0
2ol0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Go0000oooo
ooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000000oooool02_l0003oooooo`00
0?l0003oooooo`000?oooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool000002_oo
ool01?l0003oooooooooool00003ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oooooo
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000[ooooo00Go0000oooooooooooo
ooooo`000003ooooo`0:o`000?oooooo0000o`000?oooooo0000ooooool0003oooooo`0000?ooooo
0Ol00001ooooo`40000000001000003oooooooooool00002ooooo`;o00000_ooool2o`0000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000?ooooo00Co0000oooo
oooooooo00003?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`;o00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo
00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002oooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Co0000oooooooooooooooo0@00000000040000
0?ooooooooooo`0000gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00_ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`0;ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000?ooooo0@000000000500000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool2o`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool1
0000000000<00000ooooool000000oooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000Cooooo0@000000000300000?oooooo0000013ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0000@oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000004?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000004?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000013o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`00000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000013ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool00_ooool10000000000@00000oooooooooooooooo0_l00002ooooo`;o00000_ooool2o`00
0004ooooool0003oooooo`0000;ooooo00?o0000ooooooooool03Oooool01?l0003ooooooooooooo
ool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`;o00000oooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`000005ooooool0003oooooo`00
0?ooool00_l00003ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooooooo0_l00000
1Ooooooo0000ooooool0003ooooo00;o00000_ooool2o`0000?ooooo00?o0000ooooooooool03?oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o
00000oooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00cooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`0000?ooooo00?o
0000ooooooooool03Oooool01ol0003oooooooooool0003oooooo`000?ooool00_l00002ooooo`;o
00000_ooool2o`0000?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0100000000
00@00000oooooooooooo00003_ooool01?l0003oooooooooool00002ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`06o`000?oooooo
ooooooooool0003ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool01Ol0003ooooooooooooooooo000000gooooo00Ko0000oooo
ooooooooooooo`000?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000003Oooool01_l0003o
oooooooooooooooo0000ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo00Co0000oooooooooooo00003_ooool01?l0003ooooo
ooooool00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`40
000000000`00003oooooooooo`03ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool0
6Oooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000Jooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000Joooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool00_l00002
ooooo`;o00006_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0001Oooooo0@000000000400000?ooooooooooo`0000kooooo00Co
0000oooooooooooooooo0_l000003?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0
003oooooo`0000;ooooo00?o0000ooooooooool03?ooool02_l0003ooooooooooooooooo0000oooo
ool0003oooooo`000?ooool2o`000006ooooool0003oooooo`000?oooooo00000oooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooooooo`;o000000Woooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00_l00003ooooo`03o`000?oooooooooo00cooooo00[o0000oooooooooooo
ooooo`000?oooooo0000ooooool0003ooooo0_l000001_oooooo0000ooooool0003oooooo`0000?o
oooo00?o0000ooooooooool03?ooool01?l0003oooooooooooooool2o`000009ooooool0003ooooo
o`000?oooooo0000ooooool0003ooooo00;o00000oooool00ol0003oooooooooo`0<ooooo`08o`00
0?ooooooooooooooool0003oooooo`000?ooool2o`000008ooooool0003oooooo`000?oooooo0000
ooooool00003ooooo`03o`000?oooooooooo00cooooo00oo0000oooooooooooo0000ooooool0003o
ooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l00003ooooo`03o`000?oooooooooo
00cooooo00So0000ooooooooooooooooo`000?oooooo0000ooooo`;o000000Soooooo`000?oooooo
0000ooooool0003oooooo`0000?ooooo0@000000000300000?oooooooooo00;ooooo00?o0000oooo
ooooool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0=
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?oooooooooo
ooooool000004?ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03
o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`03
o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;o00000_ooool01Ol0003ooooooooooooooooo0000013ooooo0Ol00001ooooo`40000000000`00
003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003
ooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000Aooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000004Ooo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00004Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool0
1Ol0003ooooooooooooooooo0000017ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo0000017ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`06o`000?oooooooooooooo
ool0003ooooo0@000000000300000?oooooo000000?ooooo00Co0000oooooooooooooooo0_l00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Cooooo0@00
0000000500000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;o
oooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000Gooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`010000000000D00000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03?ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00co
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`010000000000<00000ooooool000000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001?ooool10000000000<0
0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002oooo
o`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooo`000?l00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`40000000001@00003ooooooooooooooooo000000_ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`05o`000?ooooooooooooooool000002oooool01?l0003oooooooooool0
000@ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000?ooooo`05
o`000?ooooooooooooooool000002oooool01?l0003oooooooooool0000@ooooo`04o`000?oooooo
ooooo`0000_ooooo00Go0000ooooooooooooooooo`00000?ooooo`05o`000?ooooooooooooooool0
00002oooool01?l0003oooooooooool0000@ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000
ooooooooooooooooo`00000?ooooo`05o`000?ooooooooooooooool000002oooool01?l0003ooooo
ooooool0000@ooooo`7o00000Oooool10000000000@00000oooooooooooo00000oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`00
000:ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000ooooool0003oooooo`00
0?ooool2o`000006ooooool0003oooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o000000Go
ooooo`000?oooooo0000ooooo`02o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooo`000?oooooo
0000ooooo`;o000000Koooooo`000?oooooo0000ooooool00003ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o000000Gooooo
o`000?oooooo0000ooooo`02o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooo`000?oooooo0000
ooooo`;o000000Koooooo`000?oooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000002ooooo`0:o`000?oooooo0000ooooool0003oooooo`00
0?oooooo0000ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo0000o`0000;ooooo0_l0
00001_oooooo0000ooooool0003oooooo`0000?ooooo0@000000000400000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`40000000000`00003oooooooooo`0Aoooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000004oooool01?l0003oooooooooool00003ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000001;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00Go0000ooooooooooooooooo`00000Booooo`05o`000?ooooooooooooooool000000ooo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`00000Booooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000004_ooool01Ol0
003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooo
ooooo`00000Booooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooo
oooooooo00000_ooool10000000000@00000ooooool0003ooooo0_l00002ooooo`;o00000_ooool2
o`000003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o0000
0_ooool01?l0003oooooooooool0000:ooooo`06o`000?ooooooooooooooool0003ooooo0_l00002
ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo00Go0000ooooooooooooooooo`00
0009ooooo`05o`000?ooooooooooooooool000000_ooool2o`000003ooooool0003o000000;ooooo
0_l00002ooooo`;o00000_ooool01?l0003oooooooooool0000:ooooo`04o`000?ooooooooooo`00
00;ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000000_ooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003ooooooooo
o`08ooooo`04o`000?ooooooooooo`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
ooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oooooooooooooo
ool000000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo0@0000000003
00000?oooooo000000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000;o
oooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0@000000
000500000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00co
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
3?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00@000000000400000?oooooooooo
o`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000003Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000go
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02o`0000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo0_l00002oooo
o`05o`000?ooooooooooooooool000000_ooool10000000000<00000ooooool000000oooool2o`00
00;ooooo0_l00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o0000
00?oooooo`000?l000000_ooool2o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01ol0003o
ooooooooool0003oooooo`000?ooool00_l00002ooooo`;o00000oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
0@000000000300000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooo000000?ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000004Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool01Ol0003ooooo
oooooooooooo0000017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooo
oooo0000017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo
00Go0000ooooooooooooooooo`00000Aooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooo00000_ooool01_l0003ooooooooooooooooo0000ooooo`40000000000`00003ooooooooo
o`02ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000Wooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`06o`000?oooooooooooooo
ool0003ooooo0@000000000400000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000000oooool02_l0003oooooooooool0003oooooo`00
0?oooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`08o`000?oooooooooooooo
ool0003oooooo`000?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00[o0000oooo
oooooooo0000ooooool0003oooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool02_l0
003oooooooooool0003oooooo`000?oooooo0000ooooool00002ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02o`0000?ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooooooool2o`000004ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`0:o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?oooooo00000oooool01?l0003o
ooooooooooooool10000000000@00000oooooooooooo00000oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool02oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00_ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0@000000
000500000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool0
0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000;ooooo0_l00002oooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`00
0?oooooooooo00;o00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool2o`00
00;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool2o`0000;ooooo
00?o0000ooooooooool00_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00002oooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`03
o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`40000000000`00003oooooo`000003
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000001?ooool10000000000<0
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000[ooooo00Co0000oooooooooooo00000oooool0
1ol0003ooooooooooooooooo0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?oooooooooo
ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`08ooooo`04o`000?ooooooooooo`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`05o`000?oo
ooooooooooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000000_ooool0
1ol0003ooooooooooooooooo0000ooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
2_ooool00ol0003oooooooooo`02ooooo`40000000001@00003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o000000?oooooo`000?l000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_l00002ooooo`;o00000_ooool2o`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooooooool2o`0000;ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04
o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04
o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0003ooooooooo
o`010000000000@00000oooooooooooo00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o00000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0
003oooooooooo`02o`0000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02o`00
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00002ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`;o00000_ooool00ol0003oooooooooo`0;ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003ooooo
ooooool0000=ooooo`04o`000?ooooooooooooooo`40000000000`00003oooooooooo`0Cooooo`;o
000000coooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0000Eooooo`08
o`000?oooooo0000ooooool0003oooooo`000?ooool2o`000004ooooool0003oooooo`0001Kooooo
0_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`0001Kooooo00Ko0000
ooooool0003oooooo`000?ooool2o`000006ooooool0003oooooo`000?oooooo00005_ooool2o`00
0009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o00005_ooool01?l0003ooooo
o`000?ooool2o`000008ooooool0003oooooo`000?oooooo0000ooooool0000Eooooo`0<o`000?oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooool0003ooooo0_l0000Fooooo`04o`000?oo
oooo0000ooooo`;o000000Soooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo0@000000
000300000?oooooooooo00;ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?oooooooooo
ooooool000000_ooool2o`0000oooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooooooo
o`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l0000?ooooo`;o
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?oooooooooo
ooooool000004?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000_ooool2o`0000oooooo0_l00002ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo
00;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l0000?
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000004?ooool1o`00007ooooo0@000000000300000?oooooo000000?ooooo00Co
0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000ooooool0003ooooo0_l0
0002ooooo`;o00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o0000
0oooool01?l0003oooooooooool00003ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
oooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l00003ooooo`05o`000?oooooooooo
ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?oooooo00000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo00Co0000oooooooo
oooo00000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool2
o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo0_l00003ooooo`05
o`000?ooooooooooooooool000000_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`00
0?l000001?ooool10000000000D00000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00_ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`0;ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0040000000001@00003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_l000000ooo
oooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooooooool0
003oooooo`000?oooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool02_l0003o
ooooooooool0003oooooo`000?oooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`0;o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_l00002ooooo`05o`000?oooooo
ooooooooool000000oooool02_l0003oooooooooool0003oooooo`000?oooooo0000ooooool00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00_o0000ooooooooooooooooo`000?oooooo0000ooooool0003ooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`0:o`000?ooooooooooo`000?oooooo0000oooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooo`00
0?l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`010000000000<00000oooo
ool000000oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool2
o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000
ooooooooool01_ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool00_l0
0002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool00000
0_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
oooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000oooooooo
ool00_l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l00002ooooo`;o
00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`02o`00
00;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002oooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_oo
ool10000000000@00000oooooooooooooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0
003o000001Oooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0001Kooooo0_l0
0002ooooo`;o00000_ooool2o`000003ooooool0003o000001Oooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00000_ooool2o`0001Kooooo0_l00002ooooo`;o00000_ooool00ol0003ooooooooo
o`02o`0001Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool2o`0001Kooooo0_l0
0002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0001Oooooo00?o0000ooooooooool00_l0
0002ooooo`;o00000_ooool2o`0001Gooooo0@000000000400000?ooooooooooo`0000?ooooo00?o
0000ooooooooool01?ooool01_l0003ooooooooooooooooo0000ooooo`;o00000_ooool2o`000009
ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`05ooooo`0=o`000?ooooooooooo`000?oooooo0000ooooool0003ooooo
o`000?oooooo0000ooooo`02o`00000:ooooool0003oooooo`000?oooooo0000ooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool01?ooool01_l0003ooooooooooooooooo0000ooooo`;o0000
0_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`;o000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`04ooooo`0>o`000?ooooooooooooooool0003oooooo`000?oo
oooo0000ooooool0003oooooo`000?ooool2o`00000:ooooool0003oooooo`000?oooooo0000oooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool01?ooool01_l0003ooooooooooooooooo0000
ooooo`;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`;o000000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`04ooooo`0:o`000?ooooooooooooooool0003o
ooooo`000?oooooo0000ooooo`;o00000_ooool2o`00000:ooooool0003oooooo`000?oooooo0000
ooooool0003oooooo`0000;ooooo00?o0000ooooooooool01Oooool01_l0003ooooooooooooooooo
0000ooooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l00002oooo
o`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`04ooooo`0:o`000?oooooooooo
ooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`000005ooooool0003oooooo`00
0?ooool00_l00002ooooo`40000000001000003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o000000Go
ooooo`000?oooooo0000ooooo`02o`0000;ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?oooooo
0000ooooool0003ooooo0_l00002ooooo`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000_ooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooo`000?l00002ooooo`;o000000Koooooo`000?oo
oooo0000ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000_ooool2o`000005ooooool0003oooooo`00
0?ooool00_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooo`000?l00002ooooo`;o
000000Koooooo`000?oooooo0000ooooool00003ooooo`40000000001@00003ooooooooooooooooo
000000?ooooo0_l00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000oooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000oooool01?l0003ooooo
ooooool0000@ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`;o00000_ooool01Ol0
003ooooooooooooooooo000000oooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_oo
ool2o`0000?ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooool00003ooooo`;o
00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000?ooooo`05o`000?oooooooooo
ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000oooooo00Go
0000ooooooooooooooooo`000003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002oooo
o`;o00000oooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo0040000000000`00
003oooooo`000002ooooo`;o00002?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002
ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00Kooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Sooooo00Go0000oooooooooooo
ooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002oooo
o`05o`000?ooooooooooooooool000002?ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo
oooo00;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00002?ooool0
0ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`0000;ooooo00Go0000ooooooooooooooooo`000008ooooo`;o00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;o
oooo0_l00008ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000oooooooo
ool00_l00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Sooooo0_l00002oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`40000000001@00003ooooooooooooooooo000000?ooooo0_l000001?oooooo0000oooo
ool00003ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`;o00000_ooool02ol0003ooooooooooooooooo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00[o0000oooooooooooo0000oooo
ool0003oooooo`000?oooooo00000oooool00ol0003oooooooooo`02o`0000;ooooo0_l00002oooo
o`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00_o0000ooooooooooooooooo`00
0?oooooo0000ooooool0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`0:o`000?oo
ooooooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_l00002
ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo0_l00002ooooo`08o`000?oo
ooooooooooooool0003oooooo`000?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00[o
0000oooooooooooo0000ooooool0003oooooo`000?oooooo00000oooool00ol0003oooooooooo`02
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`40000000001P00003ooooooooooooooooo0000ooooo`;o00000_ooool2o`0000;ooooo0_l0
00000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000000_oo
ool2o`0000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02o`0000;ooooo0_l0
00001_oooooo0000ooooool0003oooooo`0001Gooooo00?o0000ooooooooool00_l000000ooooooo
0000o`000002ooooo`;o00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;o
00000_ooool2o`000003ooooool0003o000000;ooooo00?o0000ooooooooool04oooool01_l0003o
ooooo`000?oooooo0000ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`02o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooo
oooo01?ooooo00Co0000ooooool0003o00000_ooool2o`0000;ooooo0_l000000ooooooo0000oooo
o`0Dooooo`40000000000`00003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool01_l0003ooooooooooooooooo0000ooooo`;o00000_ooool2o`0000;ooooo0_l000001Ooooooo
0000ooooool0003ooooo00;o00000_ooool2o`000003ooooool0003ooooo00;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00;o000000Goooooo`000?oooooo0000oooo
o`02o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;ooooo0_l00002
ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`02
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l000001Ooooooo0000oooo
ool0003ooooo00;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;ooooo0_l0
0002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l000000ooooooo0000oooo
o`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l000000ooooooo0000
o`000002ooooo`;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`04
o`000?ooooooooooo`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;ooooo0_l0
00001Ooooooo0000ooooool0003ooooo00;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo0Ol00001ooooo`40
000000001@00003oooooooooool0003ooooo00;o000000?oooooo`000?ooool00_ooool02_l0003o
ooooo`000?oooooo0000ooooool0003oooooo`000?ooool2o`000009ooooool0003oooooo`000?oo
oooo0000ooooool0003ooooo00;o000000[oooooo`000?oooooo0000ooooool0003oooooo`000?oo
oooo00000oooool01?l0003oooooo`000?l00002ooooo`;o000000Woooooo`000?oooooo0000oooo
ool0003oooooo`000?ooool00_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000oooo
o`02o`000003ooooool0003ooooo00;ooooo00[o0000ooooool0003oooooo`000?oooooo0000oooo
ool0003ooooo0_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`00000:
ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000?ooooo00go0000ooooool0003o
0000ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o00000_ooool2o`000009oooo
ool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_ooool0
2_l0003oooooo`000?oooooo0000ooooool0003oooooo`000?ooool2o`000009ooooool0003ooooo
o`000?oooooo0000ooooool0003ooooo00;o000000[oooooo`000?oooooo0000ooooool0003ooooo
o`000?oooooo00000oooool03Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooool0003o
ooooo`000?ooool00_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`00
00;ooooo0_l000000ooooooo0000ooooo`02ooooo`06o`000?oooooo0000ooooool0003ooooo0_l0
0002ooooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l000002_oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooool00003ooooo`0=o`000?oooooo0000o`00
0?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`00000;ooooool0003oooooo`00
0?oooooo0000ooooool0003oooooo`000?ooool00@000000000400000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0;ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00_l00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0:
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0;ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0@000000
000800000?oooooo0000ooooool0003oooooo`000?ooool2o`000009ooooool0003oooooo`000?oo
oooo0000ooooool0003ooooo00;o00000oooool2o`0000;ooooo00?o0000ooooooooool00_l00003
ooooo`;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`;o000000Co
ooooo`000?oooooo00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool01?l0003ooooo
o`000?ooool2o`0000;ooooo0_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000oooo
o`02o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000oooool2o`000009ooooool0
003oooooo`000?oooooo0000ooooool0003ooooo00;o00000_ooool2o`000004ooooool0003ooooo
o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003ooooo0_l0
0002ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`;o0000
0_ooool00ol0003oooooooooo`02o`0000?ooooo0_l000002Ooooooo0000ooooool0003oooooo`00
0?oooooo0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool00002ooooo`;o
00000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000ooooo`;o00000_ooool2o`00
0005ooooool0003oooooo`000?ooool00_l00002ooooo`;o00000oooool2o`000003ooooool0003o
000000;ooooo0_l00003ooooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?oo
ool00_l000002?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool2o`0000;ooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000000_ooool10000000000P00000ooooool0003ooooo
o`000?oooooo0000ooooo`;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002
ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;o
oooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000_ooool2o`000006ooooool0003ooooo
o`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`06o`000?oooooo0000ooooool0
003ooooo0_l00002ooooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool0
0_l000000ooooooo0000o`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooo`000?l00002ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`0000;ooooo0_l00000
1_oooooo0000ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000oooool01_l0003o
ooooo`000?oooooo0000ooooo`;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l0
0002ooooo`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
0_l000003?oooooo0000o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`;o0000
0_ooool2o`000006ooooool0003oooooo`000?oooooo00000oooool01?l0003oooooooooool00003
ooooo`06o`000?oooooo0000ooooool0003ooooo0_l00002ooooo`;o000000Goooooo`000?oooooo
0000ooooo`02o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`02o`000005ooooool0003oooooo`000?ooool00_l00002
ooooo`;o000000[oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool2o`00
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo0@000000000400000?oooooo
ooooo`0000gooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool2o`000003oooo
ool0003o000000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`06o`000?oooooooooooooo
ool0003ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000gooooo00Ko0000oooooooooooo
ooooo`000?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00?o0000
ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000003Oooool01_l0003ooooooooo
oooooooo0000ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000?oooooo`00
0?l000000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003ooooo00;ooooo0@00
0000000500000?ooooooooooo`000?ooool00ol00002ooooo`;o00000_ooool02?l0003oooooo`00
0?oooooo0000ooooool0003ooooo0_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000
ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool00003ooooo`03o`000?oooooo
oooo00;o000000koooooo`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo
0000ooooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00ol00002oooo
o`;o00000_ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l000002Ooooooo0000
ooooool0003oooooo`000?oooooo0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000
ooooool00002ooooo`;o00000_ooool3o`00000;ooooool0003oooooo`000?oooooo0000ooooool0
003oooooo`000?ooool00_l000002ooooooo0000ooooool0003oooooo`000?oooooo0000ooooool0
003ooooo00?o00000_ooool03?l0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo
0000ooooo`;o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l000002?oo
oooo0000ooooool0003oooooo`000?oooooo00000_ooool2o`0000;ooooo0ol000002Ooooooo0000
ooooool0003oooooo`000?oooooo0000ooooo`02o`00000;ooooool0003oooooo`000?oooooo0000
ooooool0003oooooo`000?ooool00_l000000ooooooo0000o`000002ooooo`0:o`000?oooooooooo
ooooool0003oooooo`000?oooooo0000ooooo`;o000000_oooooo`000?oooooo0000ooooool0003o
ooooo`000?oooooo0000ooooo`02o`000008ooooool0003oooooo`000?oooooo0000ooooool00002
ooooo`;o00000_ooool3o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o
000000_oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`010000000000<0
0000ooooool000000_ooool2o`000003ooooool0003o000000?o00000_ooool2o`000003ooooool0
003o000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l0
00001Ooooooo0000ooooool0003ooooo00Go000000?oooooo`000?l000000_ooool2o`000005oooo
ool0003oooooo`000?ooool00_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o
oooo0_l000000ooooooo0000o`000003o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o
00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool5o`000003ooooool0003o000000;ooooo0_l000001Ooooooo0000ooooool0003ooooo
00;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`;o000000?ooooo
o`000?l000000ol00002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool2o`000003ooooool0003o000000;ooooo1Ol00000
0ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00000
1Ooooooo0000ooooool0003ooooo00;o00000_ooool2o`000003ooooool0003ooooo00?o000000Go
ooooo`000?oooooo0000ooooo`02o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`Go000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
0_ooool1o`00007ooooo0@000000000500000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo0040000000001P00003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`00
0009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00Co000000?oooooo`000?l00000
0_ooool00ol0003oooooo`000002o`000003ooooool0003o000000;o000000Woooooo`000?oooooo
0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`03o`000003ooooool0003o
oooo00?o00000_ooool3o`000003ooooool0003ooooo00?o000000?oooooo`000?ooool00_l00000
2Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`03o`000003ooooool0003o000000;o
000000?oooooo`000?ooool00_ooool00ol0003oooooo`000002o`000003ooooool0003o000000;o
000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000oooo
o`03o`000003ooooool0003ooooo00?o00000_ooool3o`000003ooooool0003ooooo00?o000000?o
ooooo`000?ooool00_l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`04o`00
0006ooooool0003o0000o`000?oooooo00000oooool00ol0003oooooo`000003o`00000=ooooool0
003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`000003ooooool0
003ooooo00?o000000?oooooo`000?ooool00ol00002ooooo`?o000000?oooooo`000?ooool00ol0
00000ooooooo0000ooooo`02o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo
00Co000000Koooooo`000?l0003o0000ooooool00002ooooo`;o000000?oooooo`000?l000000_l0
00002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`00000=ooooool0003ooooo
o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`03o`0000;ooooo0ol000001?oo
oooo0000ooooool00002ooooo`40000000000`00003oooooooooo`03o`000003ooooool0003o0000
00;o000000?oooooo`000?l000000ol000000ooooooo0000ooooo`02o`0000;ooooo0_l000002Ooo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00?o0000
00?oooooo`000?ooool02?l000002Ooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02
o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000000_l0
00000ooooooo0000o`000003o`000003ooooool0003ooooo00;o00000_ooool2o`000005ooooool0
003oooooo`000?ooool00_l00002ooooo`;o000000?oooooo`000?ooool00ol000000ooooooo0000
ooooo`04o`00000=ooooool0003o0000o`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooo`02o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00?o000000?ooooo
o`000?l000000_l000000ooooooo0000ooooo`03o`000003ooooool0003ooooo00;o00000_ooool2
o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`;o000000?oooooo`000?ooool01Ol0
00000ooooooo0000o`000002o`000009ooooool0003o0000o`000?oooooo0000ooooool0003ooooo
00;o00000_ooool2o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00Co0000
00Ooooooo`000?l0003o0000ooooool0003ooooo00?o000000?oooooo`000?ooool00_l000002Ooo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`0000;ooooo0_l000000ooooooo0000
ooooo`05o`000003ooooool0003o000000;o000000Woooooo`000?l0003o0000ooooool0003ooooo
o`000?ooool00_l00002ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`0000;ooooo0@00
0000000500000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo0_l00002ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`0000;o
oooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00So0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`000004
ooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000?ooooo0_l00002ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`0000;ooooo
0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?oooooo0000ooooo`;o00000_ooool2o`000008ooooool0003oooooo`000?oooooo0000
ooooool00002ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003
ooooo`;o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`;o00000ooo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooo`000?ooool2o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o0000
0_ooool2o`000005ooooool0003oooooo`000?ooool00_l00002ooooo`;o00000oooool01?l0003o
ooooooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooo`000?oo
ool2o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000_ooool10000000000@0
0000ooooool0003ooooo0ol000001?oooooo0000o`000?ooool3o`000007ooooool0003oooooo`00
0?oooooo0000ooooo`04o`000007ooooool0003o0000o`000?oooooo0000ooooo`03o`000003oooo
ool0003o000000;o000000?oooooo`000?ooool00ol000000ooooooo0000ooooo`04o`000007oooo
ool0003o0000o`000?oooooo0000ooooo`08o`000007ooooool0003oooooo`000?oooooo0000oooo
o`04o`000003ooooool0003ooooo00?o000000Goooooo`000?oooooo0000ooooo`02o`00000;oooo
ool0003o0000o`000?oooooo0000ooooool0003oooooo`000?ooool00ol000000ooooooo0000o`00
0002o`000003ooooool0003ooooo00?o000000?oooooo`000?ooool01?l000001ooooooo0000o`00
0?l0003oooooo`000?ooool02?l000000ooooooo0000ooooo`03o`000003ooooool0003o000000;o
000000?oooooo`000?ooool00ol000000ooooooo0000ooooo`04o`00000;ooooool0003o0000o`00
0?oooooo0000ooooool0003oooooo`000?ooool01?l000001ooooooo0000ooooool0003oooooo`00
0?ooool00ol000000ooooooo0000ooooo`04o`000007ooooool0003oooooo`000?oooooo0000oooo
o`08o`000003ooooool0003ooooo00?o000000?oooooo`000?l000000_l000000ooooooo0000oooo
o`03o`000003ooooool0003ooooo00Co000000Ooooooo`000?l0003o0000ooooool0003ooooo00?o
000000?oooooo`000?l000000_l000001ooooooo0000ooooool0003oooooo`000?ooool01_l00000
2ooooooo0000o`000?l0003oooooo`000?oooooo0000ooooool0003ooooo00Ko000000Koooooo`00
0?oooooo0000ooooool00002ooooo`40000000001000003oooooo`000?ooool:o`000003ooooool0
003o000000Oo000000Ooooooo`000?l0003o0000ooooool0003ooooo00[o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000008o`000003ooooool0003o000000Oo000000?oooooo`000?l0
00002?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000Oo000000?oooooo`00
0?l000002?l000000ooooooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`000003o`000003ooooool0003o000000So000000?oooooo`00
0?l000001ol000001?oooooo0000o`000?ooool3o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000001ol000000ooooooo0000o`000008o`000003ooooool0003o000000?o000000?ooooo
o`000?l000002?l000000ooooooo0000o`000003o`000003ooooool0003o000000So000000?ooooo
o`000?ooool00ol000000ooooooo0000o`000008o`000003ooooool0003o000000Oo000000?ooooo
o`000?l000001ol000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`4000000000
1000003oooooooooool00002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00_l0
0002ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`02o`000003ooooool0
003o000000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo
00Ko0000ooooooooooooooooo`000?ooool3o`000004ooooool0003o0000ooooo`?o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooo
oooo00;o00000_ooool2o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002
ooooo`06o`000?ooooooooooooooool0003ooooo0ol000001?oooooo0000o`000?ooool3o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool00ol0003o
ooooooooo`02o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo00;o
000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o
00000_ooool00ol0003oooooooooo`02o`000005ooooool0003o0000o`000?ooool00_l000001_oo
oooo0000o`000?l0003oooooo`0000;ooooo0_l00002ooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00002ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o
00000_ooool00ol0003oooooooooo`02o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000o`000002ooooo`04o`000?ooooooooooooooo`40000000000`00003oooooo`000002o`00
0003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`0Ko`000003ooooool0003o
000002Co000000Goooooo`000?l0003o0000ooooo`0Ko`000003ooooool0003o000002Co000000?o
ooooo`000?l000006Ol000001Ooooooo0000o`000?l0003ooooo02Ko000000?oooooo`000?l00000
6Ol000000ooooooo0000o`000008o`000003ooooool0003o000001?o00000Oooool10000000000<0
0000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooooooo0?oooooo7Oooool1
00000000o`00000Q00000000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000l002_f?Co
n=nhREP^3`046Sm]WL[[oOgZb9a[?AT40A0_FX^jh?Wom=N^OThU2P088DUhZ=?a
oo[T_i1P=1<10QHhIIK4iocnk/jSLT@N1P0<:U>3/m_fooKL]8EE:`d01Ae2LJ7=
kOklj<FHIcXG0`4B<Uj?_N?joo;DZWY:8`P02BA<O:cFlooihK^<G30A0@<H?6VJ
anWmo^c;Wfi06`D03RaGQkONmooefK61DBP;00LOAWFUd>oonnK2U6<f508253ER
Tl7Unoo`dJIfAb0700/WD82`fOGon=nhREP]3`046Sm]W/[/oOgZb9]Z?AT40A0`
Fh^jh?WolmN]ODdU2P088TUhZM?aoo[S_Y1O<a810aHiIYO4iocnk/jRLT<M1P0<
:UB4/m_fooKL]8ED:Pd01Ae2LJ;=k_klj<FGIcTF0`4B<ej?_^?joo;DZWU:8PP0
2BA=O:cFlooihK^<Fc0@0@<H?6ZJan[mo^c;Wfi06`D03ReGR;ONmooefK21DBP;
00LOAWFUd?3onnK1Tf<f508253IRTl7Unoo`dJIeAR0700/WD82`fOGon=jgR5P]
3P046cm]W/[/oOgZb9]Z?1P40A0`FhbjhOWolmJ]ODdU2P088TUiZM?aoo[S_Y1O
<a810aHiIYO4j?cnk/jRLD<M1P0=:UB4]=cfooKL]8AD:Pd01Qe3LJ;>k_klj<BG
ISTF0`4B<en@_^?joo7CZGU98PP02RE=OJgFlooihKZ<Fc0@0@@H?6ZKb>[moNc:
WVdo6`@03ReHR;ONn?oefK20D2L;00LPAWFVdO3onnG1Tf8f508253ISTl7Vnoo`
d:EeAQl700/XDH6`fOGommjgR5L]3P056d1^Wl_/o_gZaiYZ?1P30A0`FhbkhOWo
lmJ/O4dT2@088TYiZ]Cboo[S_XmN<a810aHiIiO5j?cnk/fRLD8M1@0=:UB5]=cf
ooKK/hAD:P`01Qe3LZ;>k_klilBGISTF0`4B<en@_^?joo7CZGQ98PP02RE=OJgG
looih;Z;Fc0@0@@I?FZKb>[moNc:WVdo6P@03beHRKSOn?oefK20D2L;00LPAgJV
dO3onnG1Tf8e508253ISU<;Vnoo_d:EeAQl700/XDH6afOGommjgQeL/3P056d1^
Wl_/o_gYaiYY?1P30A4`G8bkhOWolmJ/O4`T2@088dYjZ]Cboo[S_HmN<Q810aLj
IiS5j?cnkLfQLD8M1@0=:eF5]=cfooKK/h=C:P`01Qi4LZ?>k_klilBFICPF0P4C
=62@_nCjoo7CZ7Q98@P02RE>OZkGm?oih;Z;FRl@0@@I?F^Lb>[moN_:WFdo6P@0
3biHRKSOn?odf:n0D2L;00LPAgJWdO3onnG0TV8e50825CMSU<;Vnok_d:EdAAl6
00/XDH6af_GommjfQeL/3P056d1_Wl_/o_gYaiYY>aP30A4aG8fkhOWolmF/O4`T
2@098d]jZ]Cboo[R_HiN<Q810aLjIiS5j?cnkLfQL48L1@0=:eF5]McgooKK/h=C
:@`01Qi4Lj??k_klil>FICPF0P4C=62A_nCjoo7CZ7Q88@P02RI>OZkGm?ohh;V:
FRl@00@I?F^LbN_moN_:WF`n6P@03biIRKSOn?odf:moCbH:00LPAgJWd_3onnG0
TV4e4`825CMTUL;Vnok_cjAdAAl600`XDX:bf_GommffQeH/3P05745_X<c]o_cY
aYUX>aP30A4aGHflh_WolmF[Nd`T2@098d]jZmGboo[R_HiM<Q410aLjJ9S6jOcn
kLbQL44L1@0=:eF6]MggooKK/X=C:@`01Qi4LjC?koklil>EICPE0P4C=62A_nCj
oo7BZ7M88@P02RI?OZkGm?ohh;V:FRl?00@I?VbLbN_moN_9WF`n6P@03biIR[WO
n?odf:moCbH:00LQB7NWd_7onnC0TV4e4`825CMTUL?Wnok_cjAcAAh600`YDX:b
f_GommffQUH/3P05745_X<c]o_cYaYUX>aL30A4aGHjlh_Wol]F[Nd/S2@098d]k
ZmGbooWR_8iM<A410aLkJ9W6jOcnkLbPKd4L1@0>;5J6]]ggooGJ/X9B:@`01Qi5
LjC?kokkil>EI3LE0P8C=F6B`>Ckoo7BYgM88@L02RI?OjoHm?ohgkV:FBh?00@J
?VbMbN_moN_9W6`n6@@03bmJR[WPn?odejinCbH:00PQB7NXd_7on^BoTF0d4`42
5CQUUL?Wo?k_cjAcA1h600`YDh>bfoKommfeQUD[3@05745`XLc]o_cYaYQX>QL3
0A4bGHjmh_[ol]F[NT/S2@0994akZmGcooWR_8eM<A410aPkJ9W6jOcnkLbPKd4L
1@0>;5J7]]ggooGJ/X9B:0`01Qm5M:C?kokki/:EI3LE0P8C=F6B`>Gkoo3BYgI7
80L02RI?OjoHm?ohgkR9FBh?00@J?VbMb^_moN_9W6/m6@@042mJR[WPn?odejin
CRH:00PQB7RXdo7on^BoTF0d4`425SQUU/?Wo?k^cj=cA1h600`YDh>cfoKommbe
QED[3@05749`XLg]o_cXaIQW>QL30A8bGXjmh_[ol]BZNT/S2@0994al[=GcooWQ
^heL<A410aPkJI[7jOgnk<^OKd0K1@0>;5N7]]kgooGJ/H5A:0/01Qm5M:G@kokk
i/:DHcLE0P8D=F:B`>Gkoo3AYgI780L02bM@OjoHm?ohgkR9F2h?00@J?ffMb^_m
oN[8W6/m6@@142mJRk[PnOodejinCRD:00PQBGRXdo7on^BoT60d4`425SQUU/CW
o?k^cZ=bA1h600`ZDh>cfoKom]bdQED[3@057D9aXLg]o_cXaIQW>QL30A8bGXnm
ho[ol]BZNTXS200994al[=KcooWQ^haL<1410aPlJI[7jOgnk<^OKT0K1@0>;5N7
]mkgooGI/H5A:0/01am6MJG@kooki/:DHcHD0P8D=F:C`NGkoo3AYWI780L02bM@
P;3ImOohgkR9F2d?00@J?ffNb^cmoN[8VfXm6@@1431KRk[PnOocejemCBD:00PR
BGRYdo7on^>nT5lc4P435SUVUlCWo?k^cZ9b@ad600`ZE8BcfoKom]bdQE@Z3@05
7D9aX/g^o_cXaIMW>AH30A8cGXnnho[ol]BZNDXR200994el[=KcooWQ^haK<101
0aPlJY[7j_gnk<^OKT0K1@0>;EN8]mkgooGI/85A:0/01am6MJG@l?oki/6CHcHD
0P8D=V:C`NGkoo3AYWE680L02bM@P;3ImOohg[N8F2d>00@K?ffNb^cmoN[8VfXl
60@1431KS;[QnOoceZemCBD:00PRBGVYdo7on^>nT5lc4P435SUVUlCXo?k^cZ9a
@ad600dZE8Bdg?Kom]bdQ5@Z3@067D=aX/k^o_cXa9MV>AH30A8cGi2nho[olM>Y
NDTR200:9Dem[MKcooWQ^XaK<10111PlJY_8j_gmk<ZNKClK100>;ER8]mkhooGI
/81@9`/01b16MJKAl?okiL6CHSHD0P8D=V>C`NKkoo3@YGE67`L02bQAPK3ImOog
g[N8Ebd>00DK@6jObncnoN[7VVXl60<1431KS;_QnOoceZalCB@900PRBWVZe?;o
n^>nSehc4P435SUWUlGXo?k^cJ9a@Qd500dZE8Fdg?Kom]^cQ5@Z30067D=bX/k^
o_cWa9MV>AH30A8cGi2nho[olM>YN4TR200:9Dem[MOcooWP^X]K<10111TmJY_8
j_gmk<ZNKClJ100?;ER9^=ohooGI/81@9`/01b17MZKAl?okiL6CHSDD0P8D=V>D
`^Kkono@YGE67`L02bQAPK7ImOogg[N7Eb`>00DK@6jObncnoNW7VVTl60<14C1L
S;_QnOoceZalC2@900PSBWZZe?;on^>mSehb4P435cYWV<GXo?k]cJ5a@Qd500d[
EHFdg?Kom]^cPe<Z30067TAbXlk^o_cWa9IU>1H20A<dH92oi?[olM>XN4TQ200:
9Din[]OdooWP^X]J;a0111TmJic8j_gmjlZMKClJ100?;UR9^=ohooCH[h1@9`/0
1b17MZOAl?okiL2BHSDD0P8E=f>D`^Kko^o@YGA57`H02bQAPK7JmOogg[J7Eb`>
00DK@6nObncnoNW7VVTk60<14C5LSK_QnOoceJalC2@900TSBgZZe?;on^:mSUhb
4P435cYWV<GXo?k]cJ5`@Q`500d[EHFeg?Oom]^cPe<Y30067TAcXlo^o_cW`iIU
>1H20A<dH96oi?[olM>XN4PQ200:9Tin[]OdooSP^HYJ;a0011TmJic9jogmjlZM
K3hJ100?;UV9^=ohooCH[gm?9PX01b17MZOBl?okiL2BHCDC0P8E=fBE`^Kko^o?
Y7A57`H032QBP[;JmOoggKJ7ER`>00DL@FnPc>gno>W6VFPk60<14C5MSKcRnOoc
eJ]kC2@900TSBgZ[eO;on^:mSUdb4@435cYXV<KYo?k]c:5`@A`500d[EHJegOOo
m]^bPe<Y30067TAcY<o_o_cW`iEU>1D20A<dH96oi?[olM:XMdPQ200:9Tmn[]Od
ooSP^HYJ;`l011TnK9c9jogmjlVMK3hJ100?;UV:^MohooCH[gm?9PX01b58MjOB
lOoki<2BHCDC0P8E=fBE`nOko^o?Y7=57PH032UBP[;JmOoggKJ6ER`>00DL@FnP
c>gno>W6VFPk5`<14C5MS[cRnOobeJ]kBb<900TSBg^[eO;onN:lSUda4@435c]X
VLKYo?k]c:1_@A`500h/EXJfgOOomMZbPU8Y30067TEcY<o_o__W`iET=aD20Q<e
HI;0i?_olM:WMdPQ1`0:9Tmo[mSdooSO^HYI;Pl011XnK9g9jogmjlVLK3hI100?
;eZ:^N3hooCG[Wi?9PX02258MjSBlOoji;nAH3@C0@8E>6FE`nOlo^o?Y7=47PH0
32UCPk;Km_oggKF6EB/=00DL@G2Qc>gno>W6V6Pj5`<14C9MS[gRn_obeJ]jBb<9
00TTC7^[eO?onN:lSEda4@4363]XVLKYo?k]c:1_@A`500h/EXNfgOOomMZbPU8X
30067dEdY<o_o__V`YET=aD20Q<eHI;0iO_ol=:WMTLP1`0:9Tmo[mSdooSO^8UI
;Pl011XnK9g:jogmjlVLJcdI100@;eZ:^N3hooCG[Wi>9PX02258N:SClOoji;nA
H3@C0@8F>6FF`nOlo^k?Xg=47PH032UCPk?Km_ogg;F5EB/=00DL@W2QcNgno>S5
V6Lj5`<14S9NS[gRn_obe:YjBb<900TTC7b/eO?onN6kSE`a4@4363]YV/OYoOk/
bim_@1/500h/EhNfg_OomMZaPE4X2`067dEdYM3_o__V`YAS=aD20Q@eHY;0iO_o
l=6WMTLP1`0;9e1o[mSdooSO^8UH;Pl011XoKIg:jogmj/RLJcdI104@;eZ;^^3i
ooCG[Wi>9@X02259N:SClOoji;n@H3@C0@8F>6FFa>Olo^k>Xg947PH032YCPk?K
m_ofg;B5EB/=00DM@W6QcNgno>S5V6Lj5`<14S9NSkgSn_obe:YjBR<800TTC7b/
e_?onN6kS5``4@4363aYV/OYoOk/bim^@1/500h/EhNgg_OomMVaPE4X2`077dIe
YM3_oo_V`YAS=Q@20Q@eHY?1iO_ol=6VMTLP1`0;9e20/=WeooSO^8UH;@l011Xo
KIk:k?gmj/RKJSdI104@<5^;^^3ioo?G[Ge=9@X02299N:WClOojhkj@Gc<B0@<F
>FJGa>Olo^k>XW937@H032YDQ;?Km_ofg;B5E2X=00DM@W6RcNkno>S5UfLi5P<1
4S=NSkkSn_obe:YiBR8800TTCGb/e_?onN6kS5/`404363aZV/OZoOk/bim^@1/5
00h]EhRgg_OomMV`PE4X2`077dIeYM3`oo_V`I=S=Q@20Q@fHY?1iO_ol=6VMDHP
1`0;9e20/=WeooSN]hQH;@h011/oKIk:k?gmj/RKJS`H104@<5^<^^7ioo?F[Ge=
9@X02299NJWClOojhkj@Gc<B0@<F>FJGa>Slo^k>XW537@H03BYDQ;CLm_ofg;B4
E2X=00HM@g6Rc^kno>S4UfHi5P<14S=OT;kSn_oadjUiBB8800XUCGf]e_?onN6j
S5/`404463aZVlSZoOg/bYi]?a/400h]F8Rgg_SomMV`P50W2`0784IeY]7`oo_U
`I=R=Q@20Q@fHi?1i__ol=2UMDHO1`0;:561/=WeooON]hQG;@h01A]0KYo;k?km
j/NJJS`H0`4@<5^<^n7ioo?F[7a=90T0229:NJ[Dl_ojhkj?GS<B0@<F>FNGaNSl
o^k=XW527@D03BYDQKCLm_offk>4E2X<00HM@g:Rc^kno>O4UfHi5P<14S=OT;kS
n_oadjUhBB8800XUCGf]eo?onN2jRe/`40446CeZVlSZoOg/bYi]?aX400l]F8Vh
goSomMV`P50W2`0784MfY]7`oo_U`I=R=A@20Q@fHiC2i__okm2UMDHO1`0;:561
/MWeooON]hMG;0h01A]0KYo;k?kmjLNJJC`H0`4A<5b<^n7ioo?F[7a<90T022=:
NZ[Dl_ojhkf?GS8B0@<G>VNHaNSlo^g=XG527@D03B]EQKCLm_offk>3DbX<00HN
A7:Sc^kno>O4UVDh5P814cAPT;oTn_oadjQhBB4800XUCWj^eoConN2jReX_4044
6Ce[W<SZoOg[bYe]?aX400l^F8VhgoSom=R_P50W2`0784MfYm7`oo_U`99R=A@2
0QDgHiC2i__nkm2UM4DO1P0;:561/M[eooON]XMG;0h01A]0Kio;k?kmjLNJJC/H
0`4A<Eb=^n7ioo?E[7a<90T02B=;NZ[Dl_ojh[f>GS8B0@<G>VNHaNSlo^g=XG12
70D03B]EQKGLmooffk>3DbT<00HNA7>Scnkno>O3UVDh5P814cAPTKoTn_oadjQh
B24800XVCWj^eoCon>2iRUX_40046Ce[W<W[oOg[bYe/?QX400l^FHVhgoSom=R_
OdlV2P0784MfYm;`oo_U`99Q=A<20QDgI9G2i__nklnTM4DO1P0<:5:2/][eooOM
]XMF;0h01Aa1Kj3<kOkljLJIJ3/H0`4A<Ef=_>;ioo?EZg]<90T02B=;NZ_El_oj
h[f>GC8A0@<G>VRHa^Wlo^g<XG1170D03B]EQ[GMmooffk:3DbT<00HNA7>Tcnon
o>O3UFDh5@814cAPTKoTn_oadZQgB24800XVCgj^eoCon>2iRUX_3`046Ci/W<W[
oOg[bIe/?QX400l^FHZigoSom=R_OdlV2P078DQgYm;aoo_T`99Q=A<20QDgI9G3
io_nklnTLdDN1P0<:E:2/][eooOM]XIF;0h01Aa1Kj3<kOkljLJIJ3/G0`4A<Ef>
_>;ioo;EZg];8`T02B=;Nj_El_oih[b>GC4A0@<G>fRIa^Wlo^g<X6m170D03RaF
Q[KMmooef[:2DRT<00HNAG>TcnonnnO3UF@g5@824cEQT/3TnooadZMgB24700XV
Cgn_f?Con=niRUT^3`046Si/WLW[oOg[bIa/?QT400l_FXZih?Som=N^OTlV2P08
8DQgZ=;aoo[T_i5P=1<10QDhIIG3iocnklnTLd@N1P0<:E>3/]_fooOM]HIE:`d0
1Aa1L:7<kOkljLJHJ3XG0`4A<Uf>_N;joo;EZgY;8`T02BA<Nj_Elooih[b=GC4A
0@<H>fRIa^Wlo^g<X6m170D03RaFQkKMmooef[:2DRP<00HOAGBTcnonnnK2UF@g
5@824cEQT/3Unoo`dZMfAb0700XVCgn_f?Con=nhRET^3`046Si/WL[[oOg[bIa[
?AT4010_FXZih?Som=N^OThV2P088DQhZ=?aoo[T_i5P=1<10QHhIIK3iocnk/nS
Ld@N1P0<:E>3/m_fooOL]HEE:`d01Aa2L:7=kOklj<FHIcXG0`4B<Uj>_N;joo;D
ZWY;8`T02BA<O:cElooihK^=G34A0@<H>fVJanWmo^c;Wfm06`D03RaGQkKNmooe
f[61DBP;00HOAGBUd>onnnK2U6<g5@8253ERT/3Unoo`dJMfAb0700/WD7n_f?Co
n=nhREP^3`046Sm]WL[[oOgZb9a[?AT40A0_FX^jh?Wom=N^OThU2P088DUhZ=?a
oo[T_i1P=1<10QHhIIK4iocnk/jSLT@N1P0<:U>3/m_fooKL]8EE:`d01Ae2LJ7=
kOklj<FHIcXG0`4B<Uj?_N?joo;DZWY:8`P02BA<O:cFlooihK^<G30A0@<H?6VJ
anWmo^c;Wfi06`D03RaGQkONmooefK61DBP;00LOAWFUd>oonnK2U6<f508253ER
Tl7Unoo`dJIfAb0700/WD82`fOGon=nhREP]3`046Sm]W/[/oOgZb9]Z?AT40A0`
Fh^jh?WolmN]ODdU2P088TUhZM?aoo[S_Y1O<a810aHiIYO4iocnk/jRLT<M1P0<
:UB4/m_fooKL]8ED:Pd01Ae2LJ;=k_klj<FGIcTF0`4B<ej?_^?joo;DZWU:8PP0
2BA=O:cFlooihK^<Fc0@0@<H?6ZJan[mo^c;Wfi06`D03ReGR;ONmooefK21DBP;
00LOAWFUd?3onnK1Tf<f508253IRTl7Unoo`dJIeAR0700/WD82`fOGon=jgR5P]
3P046cm]W/[/oOgZb9]Z?1P40A0`FhbjhOWolmJ]ODdU2P088TUiZM?aoo[S_Y1O
<a810aHiIYO4j?cnk/jRLD<M1P0=:UB4]=cfooKL]8AD:Pd01Qe3LJ;>k_klj<BG
ISTF0`4B<en@_^?joo7CZGU98PP02RE=OJgFlooihKZ<Fc0@0@@H?6ZKb>[moNc:
WVdo6`@03ReHR;ONn?oefK20D2L;00LPAWFVdO3onnG1Tf8f508253ISTl7Vnoo`
d:EeAQl700/XDH6`fOGommjgR5L]3P056d1^Wl_/o_gZaiYZ?1P30A0`FhbkhOWo
lmJ/O4dT2@088TYiZ]Cboo[S_XmN<a810aHiIiO5j?cnk/fRLD8M1@0=:UB5]=cf
ooKK/hAD:P`01Qe3LZ;>k_klilBGISTF0`4B<en@_^?joo7CZGQ98PP02RE=OJgG
looih;Z;Fc0@0@@I?FZKb>[moNc:WVdo6P@03beHRKSOn?oefK20D2L;00LPAgJV
dO3onnG1Tf8e508253ISU<;Vnoo_d:EeAQl700/XDH6afOGommjgQeL/3P056d1^
Wl_/o_gYaiYY?1P30A4`G8bkhOWolmJ/O4`T2@088dYjZ]Cboo[S_HmN<Q810aLj
IiS5j?cnkLfQLD8M1@0=:eF5]=cfooKK/h=C:P`01Qi4LZ?>k_klilBFICPF0P4C
=62@_nCjoo7CZ7Q98@P02RE>OZkGm?oih;Z;FRl@0@@I?F^Lb>[moN_:WFdo6P@0
3biHRKSOn?odf:n0D2L;00LPAgJWdO3onnG0TV8e50825CMSU<;Vnok_d:EdAAl6
00/XDH6af_GommjfQeL/3P056d1_Wl_/o_gYaiYY>aP30A4aG8fkhOWolmF/O4`T
2@098d]jZ]Cboo[R_HiN<Q810aLjIiS5j?cnkLfQL48L1@0=:eF5]McgooKK/h=C
:@`01Qi4Lj??k_klil>FICPF0P4C=62A_nCjoo7CZ7Q88@P02RI>OZkGm?ohh;V:
FRl@00@I?F^LbN_moN_:WF`n6P@03biIRKSOn?odf:moCbH:00LPAgJWd_3onnG0
TV4e4`825CMTUL;Vnok_cjAdAAl600`XDX:bf_GommffQeH/3P05745_X<c]o_cY
aYUX>aP30A4aGHflh_WolmF[Nd`T2@098d]jZmGboo[R_HiM<Q410aLjJ9S6jOcn
kLbQL44L1@0=:eF6]MggooKK/X=C:@`01Qi4LjC?koklil>EICPE0P4C=62A_nCj
oo7BZ7M88@P02RI?OZkGm?ohh;V:FRl?00@I?VbLbN_moN_9WF`n6P@03biIR[WO
n?odf:moCbH:00LQB7NWd_7onnC0TV4e4`825CMTUL?Wnok_cjAcAAh600`YDX:b
f_GommffQUH/3P05745_X<c]o_cYaYUX>aL30A4aGHjlh_Wol]F[Nd/S2@098d]k
ZmGbooWR_8iM<A410aLkJ9W6jOcnkLbPKd4L1@0>;5J6]]ggooGJ/X9B:@`01Qi5
LjC?kokkil>EI3LE0P8C=F6B`>Ckoo7BYgM88@L02RI?OjoHm?ohgkV:FBh?00@J
?VbMbN_moN_9W6`n6@@03bmJR[WPn?odejinCbH:00PQB7NXd_7on^BoTF0d4`42
5CQUUL?Wo?k_cjAcA1h600`YDh>bfoKommfeQUD[3@05745`XLc]o_cYaYQX>QL3
0A4bGHjmh_[ol]F[NT/S2@0994akZmGcooWR_8eM<A410aPkJ9W6jOcnkLbPKd4L
1@0>;5J7]]ggooGJ/X9B:0`01Qm5M:C?kokki/:EI3LE0P8C=F6B`>Gkoo3BYgI7
80L02RI?OjoHm?ohgkR9FBh?00@J?VbMb^_moN_9W6/m6@@042mJR[WPn?odejin
CRH:00PQB7RXdo7on^BoTF0d4`425SQUU/?Wo?k^cj=cA1h600`YDh>cfoKommbe
QED[3@05749`XLg]o_cXaIQW>QL30A8bGXjmh_[ol]BZNT/S2@0994al[=GcooWQ
^heL<A410aPkJI[7jOgnk<^OKd0K1@0>;5N7]]kgooGJ/H5A:0/01Qm5M:G@kokk
i/:DHcLE0P8D=F:B`>Gkoo3AYgI780L02bM@OjoHm?ohgkR9F2h?00@J?ffMb^_m
oN[8W6/m6@@142mJRk[PnOodejinCRD:00PQBGRXdo7on^BoT60d4`425SQUU/CW
o?k^cZ=bA1h600`ZDh>cfoKom]bdQED[3@057D9aXLg]o_cXaIQW>QL30A8bGXnm
ho[ol]BZNTXS200994al[=KcooWQ^haL<1410aPlJI[7jOgnk<^OKT0K1@0>;5N7
]mkgooGI/H5A:0/01am6MJG@kooki/:DHcHD0P8D=F:C`NGkoo3AYWI780L02bM@
P;3ImOohgkR9F2d?00@J?ffNb^cmoN[8VfXm6@@1431KRk[PnOocejemCBD:00PR
BGRYdo7on^>nT5lc4P435SUVUlCWo?k^cZ9b@ad600`ZE8BcfoKom]bdQE@Z3@05
7D9aX/g^o_cXaIMW>AH30A8cGXnnho[ol]BZNDXR200994el[=KcooWQ^haK<101
0aPlJY[7j_gnk<^OKT0K1@0>;EN8]mkgooGI/85A:0/01am6MJG@l?oki/6CHcHD
0P8D=V:C`NGkoo3AYWE680L02bM@P;3ImOohg[N8F2d>00@K?ffNb^cmoN[8VfXl
60@1431KS;[QnOoceZemCBD:00PRBGVYdo7on^>nT5lc4P435SUVUlCXo?k^cZ9a
@ad600dZE8Bdg?Kom]bdQ5@Z3@067D=aX/k^o_cXa9MV>AH30A8cGi2nho[olM>Y
NDTR200:9Dem[MKcooWQ^XaK<10111PlJY_8j_gmk<ZNKClK100>;ER8]mkhooGI
/81@9`/01b16MJKAl?okiL6CHSHD0P8D=V>C`NKkoo3@YGE67`L02bQAPK3ImOog
g[N8Ebd>00DK@6jObncnoN[7VVXl60<1431KS;_QnOoceZalCB@900PRBWVZe?;o
n^>nSehc4P435SUWUlGXo?k^cJ9a@Qd500dZE8Fdg?Kom]^cQ5@Z30067D=bX/k^
o_cWa9MV>AH30A8cGi2nho[olM>YN4TR200:9Dem[MOcooWP^X]K<10111TmJY_8
j_gmk<ZNKClJ100?;ER9^=ohooGI/81@9`/01b17MZKAl?okiL6CHSDD0P8D=V>D
`^Kkono@YGE67`L02bQAPK7ImOogg[N7Eb`>00DK@6jObncnoNW7VVTl60<14C1L
S;_QnOoceZalC2@900PSBWZZe?;on^>mSehb4P435cYWV<GXo?k]cJ5a@Qd500d[
EHFdg?Kom]^cPe<Z30067TAbXlk^o_cWa9IU>1H20A<dH92oi?[olM>XN4TQ200:
9Din[]OdooWP^X]J;a0111TmJic8j_gmjlZMKClJ100?;UR9^=ohooCH[gm@9`/0
1b17MZOAl?okiL2BHSDD0P8E=f>D`^Kko^o@YGA57`H02bQAPK7JmOogg[J7Eb`>
00DK@6nObncnoNW7VVTk60<14C5LSK_QnOoceJalC2@900TSBgZZe?;on^:mSUhb
4P435cYWV<GXo?k]cJ5`@Q`500d[EHFeg?Oom]^cPe<Y30067TAcXlo^o_cW`iIU
>1H20A<dH96oi?[olM>XN4PQ200:9Tin[]OdooSP^HYJ;a0011TmJic9jogmjlZM
K3hJ100?;UV9^=ohooCH[gm?9PX01b17MZOBl?okiL2BHCDC0P8E=fBE`^Kko^o?
Y7A57`H032QBP[;JmOoggKJ7ER`>00DL@FnPc>gno>W6VFPk60<14C5MSKcRnOoc
eJ]kC2@900TSBgZ[eO;on^:mSUdb4@435cYXV<KYo?k]c:5`@A`500d[EHJegOOo
m]^bPe<Y30067TAcY<o_o_cW`iEU>1D20A<dH96oi?[olM:XMdPQ200:9Tmn[]Od
ooSP^HYJ;`l011TnK9c9jogmjlVMK3hJ100?;UV:^MohooCH[gm?9PX01b58MjOB
lOoki<2BHCDC0P8E=fBE`nOko^o?Y7=57PH032UBP[;JmOoggKJ6ER`>00DL@FnP
c>gno>W6VFPk5`<14C5MS[cRnOobeJ]kBb<900TSBg^[eO;onN:lSUda4@435c]X
VLKYo?k]c:1_@A`500h/EXJfgOOomMZbPU8Y30067TEcY<o_o__W`iET=aD20Q<e
HI;0i?_olM:WMdPQ1`0:9Tmo[mSdooSO^HYI;Pl011XnK9g9jogmjlVLK3hI100?
;eZ:^N3hooCG[Wi?9PX02258MjSBlOoji;nAH3@C0@8E>6FE`nOlo^o?Y7=47PH0
32UCPk;Km_oggKF6EB/=00DL@G2Qc>gno>W6V6Pj5`<14C9MS[gRn_obeJ]jBb<9
00TTC7^[eO?onN:lSEda4@4363]XVLKYo?k]c:1_@A`500h/EXNfgOOomMZbPU8X
30067dEdY<o_o__V`YET=aD20Q<eHI;0iO_ol=:WMTLP1`0:9Tmo[mSdooSO^8UI
;Pl011XnK9g:jogmjlVLJcdI100@;eZ:^N3hooCG[Wi>9PX02258N:SClOoji;nA
H3@C0@8F>6FF`nOlo^k?Xg=47PH032UCPk?Km_ogg;F5EB/=00DL@W2QcNgno>S5
V6Lj5`<14S9NS[gRn_obe:YjBb<900TTC7b/eO?onN6kSE`a4@4363]YV/OYoOk/
bim_@1/500h/EhNfg_OomMZaPE4X2`067dEdYM3_o__V`YAS=aD20Q@eHY;0iO_o
l=6WMTLP1`0;9e1o[mSdooSO^8UH;Pl011XoKIg:jogmj/RLJcdI104@;eZ;^^3i
ooCG[Wi>9@X02259N:SClOoji;n@H3@C0@8F>6FFa>Olo^k>Xg947PH032YCPk?K
m_ofg;B5EB/=00DM@W6QcNgno>S5V6Lj5`<14S9NSkgSn_obe:YjBR<800TTC7b/
e_?onN6kS5``4@4363aYV/OYoOk/bim^@1/500h/EhNgg_OomMVaPE4X2`077dIe
YM3_oo_V`YAS=Q@20Q@eHY?1iO_ol=6VMTLP1`0;9e20/=WeooSO^8UH;@l011Xo
KIk:k?gmj/RKJSdI104@<5^;^^3ioo?G[Ge=9@X02299N:WClOojhkj@Gc<B0@<F
>FJGa>Olo^k>XW937@H032YDQ;?Km_ofg;B5E2X=00DM@W6RcNkno>S5UfLi5P<1
4S=NSkkSn_obe:YiBR8800TTCGb/e_?onN6kS5/`404363aZV/OZoOk/bim^@1/5
00h]EhRgg_OomMV`PE4X2`077dIeYM3`oo_V`I=S=Q@20Q@fHY?1iO_ol=6VMDHP
1`0;9e20/=WeooSN]hQH;@h011/oKIk:k?gmj/RKJS`H104@<5^<^^7ioo?F[Ge=
9@X02299NJWClOojhkj@Gc<B0@<F>FJGa>Slo^k>XW537@H03BYDQ;CLm_ofg;B4
E2X=00HM@g6Rc^kno>S4UfHi5P<14S=OT;kSn_oadjUiBB8800XUCGf]e_?onN6j
S5/`404463aZVlSZoOg/bYi]?a/400h]F8Rgg_SomMV`P50W2`0784IeY]7`oo_U
`I=R=Q@20Q@fHi?1i__ol=2UMDHO1`0;:561/=WeooON]hQG;@h01A]0KYo;k?km
j/NJJS`H0`4@<5^<^n7ioo?F[7a=90T0229:NJ[Dl_ojhkj?GS<B0@<F>FNGaNSl
o^k=XW527@D03BYDQKCLm_offk>4E2X<00HM@g:Rc^kno>O4UfHi5P<14S=OT;kS
n_oadjUhBB8800XUCGf]eo?onN2jRe/`40446CeZVlSZoOg/bYi]?aX400l]F8Vh
goSomMV`P50W2`0784MfY]7`oo_U`I=R=A@20Q@fHiC2i__okm2UMDHO1`0;:561
/MWeooON]hMG;0h01A]0KYo;k?kmjLNJJC`H0`4A<5b<^n7ioo?F[7a<90T022=:
NZ[Dl_ojhkf?GS8B0@<G>VNHaNSlo^g=XG527@D03B]EQKCLm_offk>3DbX<00HN
A7:Sc^kno>O4UVDh5P814cAPT;oTn_oadjQhBB4800XUCWj^eoConN2jReX_4044
6Ce[W<SZoOg[bYe]?aX400l^F8VhgoSom=R_P50W2`0784MfYm7`oo_U`99R=A@2
0QDgHiC2i__nkm2UM4DO1P0;:561/M[eooON]XMG;0h01A]0Kio;k?kmjLNJJC/H
0`4A<Eb=^n7ioo?E[7a<90T02B=;NZ[Dl_ojh[f>GS8B0@<G>VNHaNSlo^g=XG12
70D03B]EQKGLmooffk>3DbT<00HNA7>Scnkno>O3UVDh5P814cAPTKoTn_oadjQh
B24800XVCWj^eoCon>2iRUX_40046Ce[W<W[oOg[bYe/?QX400l^FHVhgoSom=R_
OdlV2P0784MfYm;`oo_U`99Q=A<20QDgI9G2i__nklnTM4DO1P0<:5:2/][eooOM
]XMF;0h01Aa1Kj3<kOkljLJIJ3/H0`4A<Ef=_>;ioo?EZg]<90T02B=;NZ_El_oj
h[f>GC8A0@<G>VRHa^Wlo^g<XG1170D03B]EQ[GMmooffk:3DbT<00HNA7>Tcnon
o>O3UFDh5@814cAPTKoTn_oadZQgB24800XVCgj^eoCon>2iRUX_3`046Ci/W<W[
oOg[bIe/?QX400l^FHZigoSom=R_OdlV2P078DQgYm;aoo_T`99Q=A<20QDgI9G3
io_nklnTLdDN1P0<:E:2/][eooOM]XIF;0h01Aa1Kj3<kOkljLJIJ3/G0`4A<Ef>
_>;ioo;EZg];8`T02B=;Nj_El_oih[b>GC4A0@<G>fRIa^Wlo^g<X6m170D03RaF
Q[KMmooef[:2DRT<00HNAG>TcnonnnO3UF@g5@824cEQT/3TnooadZMgB24700XV
Cgn_f?Con=niRUT^3`046Si/WLW[oOg[bIa/?QT400l_FXZih?Som=N^OTlV2P08
8DQgZ=;aoo[T_i5P=1<10QDhIIG3iocnklnTLd@N1P0<:E>3/]_fooOM]HIE:`d0
1Aa1L:7<kOkljLJHJ3XG0`4A<Uf>_N;joo;EZgY;8`T02BA<Nj_Elooih[b=GC4A
0@<H>fRIa^Wlo^g<X6m170D03RaFQkKMmooef[:2DRP<00HOAGBTcnonnnK2UF@g
5@824cEQT/3Unoo`dZMfAb0700XVCgn_f?Con=nhRET^3`046Si/WL[[oOg[bIa[
?AT4010_FXZih?Som=N^OThV2P088DQhZ=?aoo[T_i5P=1<10QHhIIK3iocnk/nS
Ld@N1P0<:E>3/m_fooOL]HEE:`d01Aa2L:7=kOklj<FHIcXG0`4B<Uj>_N;joo;D
ZWY;8`T02BA<O:cElooihK^=G34A0@<H>fVJanWmo^c;Wfm06`D03RaGQkKNmooe
f[61DBP;00HOAGBUd>onnnK2U6<g5@8253ERT/3Unoo`dJMfAb0700/WD7n_f?Co
n=nhREP^3`046Sm]WL[[oOgZb9a[?AT40A0_FX^jh?Wom=N^OThU2P088DUhZ=?a
oo[T_i1P=1<10QHhIIK4iocnk/jSLT@N1P0<:U>3/m_fooKL]8EE:`d01Ae2LJ7=
kOklj<FHIcXG0`4B<Uj?_N?joo;DZWY:8`P02BA<O:cFlooihK^<G30A0@<H?6VJ
anWmo^c;Wfi06`D03RaGQkONmooefK61DBP;00LOAWFUd>oonnK2U6<f508253ER
Tl7Unoo`dJIfAb0700/WD82`fOGon=nhREP]3`046Sm]W/[/oOgZb9]Z?AT40A0`
Fh^jh?WolmN]ODdU2P088TUhZM?aoo[S_Y1O<a810aHiIYO4iocnk/jRLT<M1P0<
:UB4/m_fooKL]8ED:Pd01Ae2LJ;=k_klj<FGIcTF0`4B<ej?_^?joo;DZWU:8PP0
2BA=O:cFlooihK^<Fc0@0@<H?6ZJan[mo^c;Wfi06`D03ReGR;ONmooefK21DBP;
00LOAWFUd?3onnK1Tf<f508253IRTl7Unoo`dJIeAR0700/WD82`fOGon=jgR5P]
3P046cm]W/[/oOgZb9]Z?1P40A0`FhbjhOWolmJ]ODdU2P088TUiZM?aoo[S_Y1O
<a810aHiIYO4j?cnk/jRLD<M1P0=:UB4]=cfooKL]8AD:Pd01Qe3LJ;>k_klj<BG
ISTF0`4B<en@_^?joo7CZGU98PP02RE=OJgFlooihKZ<Fc0@0@@H?6ZKb>[moNc:
WVdo6`@03ReHR;ONn?oefK20D2L;00LPAWFVdO3onnG1Tf8f508253ISTl7Vnoo`
d:EeAQl700/XDH6`fOGommjgR5L]3P056d1^Wl_/o_gZaiYZ?1P30A0`FhbkhOWo
lmJ/O4dT2@088TYiZ]Cboo[S_XmN<a810aHiIiO5j?cnk/fRLD8M1@0=:UB5]=cf
ooKK/hAD:P`01Qe3LZ;>k_klilBGISTF0`4B<en@_^?joo7CZGQ98PP02RE=OJgG
looih;Z;Fc0@0@@I?FZKb>[moNc:WVdo6P@03beHRKSOn?oefK20D2L;00LPAgJV
dO3onnG1Tf8e508253ISU<;Vnoo_d:EeAQl700/XDH6afOGommjgQeL/3P056d1^
Wl_/o_gYaiYY?1P30A4`G8bkhOWolmJ/O4`T2@088dYjZ]Cboo[S_HmN<Q810aLj
IiS5j?cnkLfQLD8M1@0=:eF5]=cfooKK/h=C:P`01Qi4LZ?>k_klilBFICPF0P4C
=62@_nCjoo7CZ7Q98@P02RE>OZkGm?oih;Z;FRl@0@@I?F^Lb>[moN_:WFdo6P@0
3biHRKSOn?odf:moD2L;00LPAgJWdO3onnG0TV8e50825CMSU<;Vnok_d:EdAAl6
00/XDH6af_GommjfQeL/3P056d1_Wl_/o_gYaiYY>aP30A4aG8fkhOWolmF/O4`T
2@098d]jZ]Cboo[R_HiN<Q810aLjIiS5j?cnkLfQL48L1@0=:eF5]McgooKK/h=C
:@`01Qi4Lj??k_klil>FICPF0P4C=62A_nCjoo7CZ7Q88@P02RI>OZkGm?ohh;V:
FRl@00@I?F^LbN_moN_:WF`n6P@03biIRKSOn?odf:moCbH:00LPAgJWd_3onnG0
TV4e4`825CMTUL;Vnok_cjAdAAl600`XDX:bf_GommffQeH/3P05745_X<c]o_cY
aYUX>aP30A4aGHflh_WolmF[Nd`T2@098d]jZmGboo[R_HiM<Q410aLjJ9S6jOcn
kLbQL44L1@0=:eF6]MggooKK/X=C:@`01Qi4LjC?koklil>EICPE0P4C=62A_nCj
oo7BZ7M88@P02RI?OZkGm?ohh;V:FRl?00@I?VbLbN_moN_9WF`n6P@03biIR[WO
n?odf:moCbH:00LQB7NWd_7onnC0TV4e4`825CMTUL?Wnok_cjAcAAh600`YDX:b
f_GommffQUH/3P05745_X<c]o_cYaYUX>aL30A4aGHjlh_Wol]F[Nd/S2@098d]k
ZmGbooWR_8iM<A410aLkJ9W6jOcnkLbPKd4L1@0>;5J6]]ggooGJ/X9B:@`01Qi5
LjC?kokkil>EI3LE0P8C=F6B`>Ckoo7BYgM88@L02RI?OjoHm?ohgkV:FBh?00@J
?VbMbN_moN_9W6`n6@@03bmJR[WPn?odejinCbH:00PQB7NXd_7on^BoTF0d4`42
5CQUUL?Wo?k_cjAcA1h600`YDh>bfoKommfeQUD[3@05745`XLc]o_cYaYQX>QL3
0A4bGHjmh_[ol]F[NT/S2@0994akZmGcooWR_8eM<A410aPkJ9W6jOcnkLbPKd4L
1@0>;5J7]]ggooGJ/X9B:0`01Qm5M:C?kokki/:EI3LE0P8C=F6B`>Gkoo3BYgI7
80L02RI?OjoHm?ohgkR9FBh?00@J?VbMb^_moN_9W6/m6@@042mJR[WPn?odejin
CRH:00PQB7RXdo7on^BoTF0d4`425SQUU/?Wo?k^cj=cA1h600`YDh>cfoKommbe
QED[3@05749`XLg]o_cXaIQW>QL30A8bGXjmh_[ol]BZNT/S2@0994al[=GcooWQ
^heL<A410aPkJI[7jOgnk<^OKd0K1@0>;5N7]]kgooGJ/H5A:0/01Qm5M:G@kokk
i/:DHcLE0P8D=F:B`>Gkoo3AYgI780L02bM@OjoHm?ohgkR9F2h?00@J?ffMb^_m
oN[8W6/m6@@142mJRk[PnOodejinCRD:00PQBGRXdo7on^BoT60d4`425SQUU/CW
o?k^cZ=bA1h600`ZDh>cfoKom]bdQED[3@057D9aXLg]o_cXaIQW>QL30A8bGXnm
ho[ol]BZNTXS200994al[=KcooWQ^haL<1410aPlJI[7jOgnk<^OKT0K1@0>;5N7
]mkgooGI/H5A:0/01am6MJG@kooki/:DHcHD0P8D=F:C`NGkoo3AYWI780L02bM@
P;3ImOohgkR9F2d?00@J?ffNb^cmoN[8VfXm6@@1431KRk[PnOocejemCBD:00PR
BGRYdo7on^>nT5lc4P435SUVUlCWo?k^cZ9b@ad600`ZE8BcfoKom]bdQE@Z3@05
7D9aX/g^o_cXaIMW>AH30A8cGXnnho[ol]BZNDXR200994el[=KcooWQ^haK<101
0aPlJY[7j_gnk<^OKT0K1@0>;EN8]mkgooGI/85A:0/01am6MJG@l?oki/6CHcHD
0P8D=V:C`NGkoo3AYWE680L02bM@P;3ImOohg[N8F2d>00@K?ffNb^cmoN[8VfXl
60@1431KS;[QnOoceZemCBD:00PRBGVYdo7on^>nT5lc4P435SUVUlCXo?k^cZ9a
@ad600dZE8Bdg?Kom]bdQ5@Z3@067D=aX/k^o_cXa9MV>AH30A8cGi2nho[olM>Y
NDTR200:9Dem[MKcooWQ^XaK<10111PlJY_8j_gmk<ZNKClK100>;ER8]mkhooGI
/81@9`/01b16MJKAl?okiL6CHSHD0P8D=V>C`NKkoo3@YGE67`L02bQAPK3ImOog
g[N8Ebd>00DK@6jObncnoN[7VVXl60<1431KS;_QnOoceZalCB@900PRBWVZe?;o
n^>nSehc4P435SUWUlGXo?k^cJ9a@Qd500dZE8Fdg?Kom]^cQ5@Z30067D=bX/k^
o_cWa9MV>AH30A8cGi2nho[olM>YN4TR200:9Dem[MOcooWP^X]K<10111TmJY_8
j_gmk<ZNKClJ100?;ER9^=ohooGI/81@9`/01b17MZKAl?okiL6CHSDD0P8D=V>D
`^Kkono@YGE67`L02bQAPK7ImOogg[N7Eb`>00DK@6jObncnoNW7VVTl60<14C1L
S;_QnOoceZalC2@900PSBWZZe?;on^>mSehb4P435cYWV<GXo?k]cJ5a@Qd500d[
EHFdg?Kom]^cPe<Z30067TAbXlk^o_cWa9IU>1H20A<dH92oi?[olM>XN4TQ200:
9Din[]OdooWP^X]J;a0111TmJic8j_gmjlZMKClJ100?;UR9^=ohooCH[h1@9`/0
1b17MZOAl?okiL2BHSDD0P8E=f>D`^Kko^o@YGA57`H02bQAPK7JmOogg[J7Eb`>
00DK@6nObncnoNW7VVTk60<14C5LSK_QnOoceJalC2@900TSBgZZe?;on^:mSUhb
4P435cYWV<GXo?k]cJ5`@Q`500d[EHFeg?Oom]^cPe<Y30067TAcXlo^o_cW`iIU
>1H20A<dH96oi?[olM>XN4PQ200:9Tin[]OdooSP^HYJ;a0011TmJic9jogmjlZM
K3hJ100?;UV9^=ohooCH[gm?9PX01b17MZOBl?okiL2BHCDC0P8E=fBE`^Kko^o?
Y7A57`H032QBP[;JmOoggKJ7ER`>00DL@FnPc>gno>W6VFPk60<14C5MSKcRnOoc
eJ]kC2@900TSBgZ[eO;on^:mSUdb4@435cYXV<KYo?k]c:5`@A`500d[EHJegOOo
m]^bPe<Y30067TAcY<o_o_cW`iEU>1D20A<dH96oi?[olM:XMdPQ200:9Tmn[]Od
ooSP^HYJ;`l011TnK9c9jogmjlVMK3hJ100?;UV:^MohooCH[gm?9PX01b58MjOB
lOoki<2BHCDC0P8E=fBE`nOko^o?Y7=57PH032UBP[;JmOoggKJ6ER`>00DL@FnP
c>gno>W6VFPk5`<14C5MS[cRnOobeJ]kBb<900TSBg^[eO;onN:lSUda4@435c]X
VLKYo?k]c:1_@A`500h/EXJfgOOomMZbPU8Y30067TEcY<o_o__W`iET=aD20Q<e
HI;0i?_olM:WMdPQ1`0:9Tmo[mSdooSO^HYI;Pl011XnK9g9jogmjlVLK3hI100?
;eZ:^N3hooCG[Wi?9PX02258MjSBlOoji;nAH3@C0@8E>6FE`nOlo^o?Y7=47PH0
32UCPk;Km_oggKF6EB/=00DL@G2Qc>gno>W6V6Pj5`<14C9MS[gRn_obeJ]jBb<9
00TTC7^[eO?onN:lSEda4@4363]XVLKYo?k]c:1_@A`500h/EXNfgOOomMZbPU8X
30067dEdY<o_o__V`YET=aD20Q<eHI;0iO_ol=:WMTLP1`0:9Tmo[mSdooSO^8UI
;Pl011XnK9g:jogmjlVLJcdI100@;eZ:^N3hooCG[Wi>9PX02258N:SClOoji;nA
H3@C0@8F>6FF`nOlo^k?Xg=47PH032UCPk?Km_ogg;F5EB/=00DL@W2QcNgno>S5
V6Lj5`<14S9NS[gRn_obe:YjBb<900TTC7b/eO?onN6kSE`a4@4363]YV/OYoOk/
bim_@1/500h/EhNfg_OomMZaPE4X2`067dEdYM3_o__V`YAS=aD20Q@eHY;0iO_o
l=6WMTLP1`0;9e1o\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example #3", "Subsubsection"],

Cell[BoxData[
    \(\(s3 = Sin[\[Pi]\ t]\ Sin[2  \[Pi]\ 500\ t];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Plot[s3, {t, 0, 2}, \ 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\[Florin][t] \[Equal] s3\  // \ TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.309116 0.294822 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01429 -12 -4.5 ]
[-0.0125 .01429 0 4.5 ]
[-0.0125 .1617 -24 -4.5 ]
[-0.0125 .1617 0 4.5 ]
[-0.0125 .30912 -6 -4.5 ]
[-0.0125 .30912 0 4.5 ]
[-0.0125 .45653 -18 -4.5 ]
[-0.0125 .45653 0 4.5 ]
[-0.0125 .60394 -6 -4.5 ]
[-0.0125 .60394 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01429 m
.00625 .01429 L
s
[(-1)] -0.0125 .01429 1 0 Mshowa
0 .1617 m
.00625 .1617 L
s
[(-0.5)] -0.0125 .1617 1 0 Mshowa
0 .30912 m
.00625 .30912 L
s
[(0)] -0.0125 .30912 1 0 Mshowa
0 .45653 m
.00625 .45653 L
s
[(0.5)] -0.0125 .45653 1 0 Mshowa
0 .60394 m
.00625 .60394 L
s
[(1)] -0.0125 .60394 1 0 Mshowa
.125 Mabswid
0 .04378 m
.00375 .04378 L
s
0 .07326 m
.00375 .07326 L
s
0 .10274 m
.00375 .10274 L
s
0 .13222 m
.00375 .13222 L
s
0 .19119 m
.00375 .19119 L
s
0 .22067 m
.00375 .22067 L
s
0 .25015 m
.00375 .25015 L
s
0 .27963 m
.00375 .27963 L
s
0 .3386 m
.00375 .3386 L
s
0 .36808 m
.00375 .36808 L
s
0 .39756 m
.00375 .39756 L
s
0 .42704 m
.00375 .42704 L
s
0 .48601 m
.00375 .48601 L
s
0 .51549 m
.00375 .51549 L
s
0 .54497 m
.00375 .54497 L
s
0 .57445 m
.00375 .57445 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01429 m
1 .01429 L
s
.99375 .1617 m
1 .1617 L
s
.99375 .30912 m
1 .30912 L
s
.99375 .45653 m
1 .45653 L
s
.99375 .60394 m
1 .60394 L
s
.125 Mabswid
.99625 .04378 m
1 .04378 L
s
.99625 .07326 m
1 .07326 L
s
.99625 .10274 m
1 .10274 L
s
.99625 .13222 m
1 .13222 L
s
.99625 .19119 m
1 .19119 L
s
.99625 .22067 m
1 .22067 L
s
.99625 .25015 m
1 .25015 L
s
.99625 .27963 m
1 .27963 L
s
.99625 .3386 m
1 .3386 L
s
.99625 .36808 m
1 .36808 L
s
.99625 .39756 m
1 .39756 L
s
.99625 .42704 m
1 .42704 L
s
.99625 .48601 m
1 .48601 L
s
.99625 .51549 m
1 .51549 L
s
.99625 .54497 m
1 .54497 L
s
.99625 .57445 m
1 .57445 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30912 m
1 .30912 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30912 m
.02499 .31139 L
.02605 .31252 L
.02729 .30354 L
.02846 .3029 L
.02954 .31 L
.03053 .31385 L
.03163 .32377 L
.03279 .31704 L
.03404 .28926 L
.03523 .3081 L
.03589 .28773 L
.0366 .31896 L
.03786 .28184 L
.03906 .31064 L
.04033 .33572 L
.04153 .28803 L
.04262 .27263 L
.04383 .31505 L
.04495 .34799 L
.04618 .31248 L
.04748 .27193 L
.0486 .31936 L
.04966 .34774 L
.05081 .3506 L
.05205 .26394 L
.05275 .3463 L
.05339 .32981 L
.05408 .25202 L
.05484 .27824 L
.05613 .28343 L
.05683 .25324 L
.05749 .35844 L
.05873 .25026 L
.05987 .25764 L
.06057 .26939 L
.06122 .37972 L
.06244 .27874 L
.06362 .23692 L
.0649 .37147 L
.06556 .24166 L
.06626 .27084 L
.06752 .25938 L
.06869 .36776 L
.06977 .39693 L
.07097 .30124 L
.07225 .23763 L
.07296 .24972 L
.07362 .39891 L
.07435 .34803 L
Mistroke
.07512 .24109 L
.07586 .2279 L
.07655 .37729 L
.07785 .20632 L
.07913 .3653 L
.08031 .40416 L
.08161 .20832 L
.08226 .39037 L
.08297 .38518 L
.08367 .21781 L
.08432 .28213 L
.085 .4249 L
.08576 .34082 L
.08651 .20863 L
.08733 .1962 L
.08809 .31538 L
.08878 .42966 L
.09006 .25867 L
.09079 .4204 L
.09146 .33733 L
.09218 .1839 L
.09283 .3356 L
.09357 .44004 L
.09428 .30474 L
.09553 .43443 L
.09616 .28439 L
.09686 .17969 L
.09808 .29598 L
.09923 .43904 L
.09992 .23702 L
.10058 .22127 L
.10181 .22325 L
.1025 .20732 L
.10314 .4513 L
.10384 .33445 L
.10458 .16945 L
.10578 .37379 L
.10688 .46119 L
.10809 .31105 L
.10937 .1743 L
.11048 .3138 L
.11152 .39728 L
.11265 .4682 L
.11387 .24734 L
.11456 .47132 L
.11519 .26004 L
.11589 .15442 L
.11663 .34892 L
.11787 .13866 L
.11858 .29954 L
Mistroke
.11924 .47533 L
.12047 .31469 L
.1216 .15066 L
.12289 .35285 L
.12413 .4654 L
.12545 .1294 L
.12664 .27846 L
.1273 .14644 L
.12802 .3974 L
.12932 .12474 L
.13054 .38726 L
.13183 .40146 L
.13293 .21983 L
.13414 .14595 L
.13487 .18049 L
.13556 .47534 L
.13686 .11636 L
.13759 .34619 L
.13826 .4901 L
.139 .24844 L
.13979 .10737 L
.14108 .46125 L
.14229 .42471 L
.14299 .46582 L
.14362 .1113 L
.14432 .2605 L
.14506 .50617 L
.14629 .17593 L
.14699 .49022 L
.14763 .3282 L
.14881 .52554 L
.15006 .22047 L
.15118 .0898 L
.15223 .12321 L
.15338 .37336 L
.15461 .49724 L
.15592 .08854 L
.15666 .31806 L
.15735 .53081 L
.1586 .2593 L
.15931 .53663 L
.15994 .22456 L
.16115 .53288 L
.16245 .20242 L
.16368 .13498 L
.16481 .38711 L
.16588 .52003 L
.16702 .48056 L
.1681 .30299 L
.16908 .25828 L
Mistroke
.17023 .0668 L
.17148 .39439 L
.17266 .54361 L
.17375 .39599 L
.1748 .24167 L
.17593 .06263 L
.17717 .35503 L
.17833 .56023 L
.17963 .14589 L
.18087 .17154 L
.18197 .42171 L
.18318 .52179 L
.18383 .34405 L
.18451 .05262 L
.18573 .34339 L
.18705 .45904 L
.1878 .54864 L
.18849 .1808 L
.18976 .57097 L
.19091 .38578 L
.19154 .49113 L
.19224 .09395 L
.1935 .54245 L
.19462 .52827 L
.19585 .09944 L
.19714 .3067 L
.19835 .57605 L
.19948 .38343 L
.20052 .23827 L
.20165 .03851 L
.20285 .29379 L
.20416 .50855 L
.20536 .11686 L
.20602 .55969 L
.20673 .42687 L
.20803 .41633 L
.20925 .03784 L
.21055 .43225 L
.21165 .58583 L
.21286 .30108 L
.21359 .58637 L
.21429 .3111 L
.21559 .5153 L
.21632 .51791 L
.21699 .07245 L
.21773 .11703 L
.21852 .40131 L
.21921 .55704 L
.21995 .22239 L
.22066 .04658 L
Mistroke
.2213 .52193 L
.22253 .07715 L
.22382 .32463 L
.22504 .58461 L
.22573 .34359 L
.22637 .04257 L
.22754 .17209 L
.22879 .59401 L
.2299 .4874 L
.23094 .33093 L
.23208 .0415 L
.23332 .27421 L
.23455 .59439 L
.23525 .33477 L
.2359 .03433 L
.23722 .44862 L
.23796 .07665 L
.23862 .21092 L
.23982 .04224 L
.24113 .57506 L
.24235 .36012 L
.24349 .06183 L
.24454 .01904 L
.24568 .24589 L
.24675 .46905 L
.24773 .50996 L
.24888 .57168 L
.25013 .08836 L
.25131 .09938 L
.2524 .34728 L
.25352 .58644 L
.25457 .5893 L
.25572 .28865 L
.25697 .04117 L
.2582 .50202 L
.2595 .3483 L
.26061 .07685 L
.26183 .1685 L
.26314 .58896 L
.26436 .17563 L
.26499 .60332 L
.26569 .25936 L
.26642 .01523 L
.2671 .39135 L
.26835 .01715 L
.2695 .26316 L
.27013 .08284 L
.27082 .53026 L
.27208 .03885 L
.27331 .26273 L
Mistroke
.27442 .53971 L
.27571 .32227 L
.27692 .01682 L
.27804 .20674 L
.27907 .36083 L
.28021 .59637 L
.28141 .35045 L
.28271 .06897 L
.2839 .47196 L
.28456 .02431 L
.28527 .24612 L
.28657 .13661 L
.28778 .56695 L
.28907 .2587 L
.29018 .04412 L
.29139 .23632 L
.29208 .0436 L
.29281 .39922 L
.29411 .04488 L
.29484 .17519 L
.29551 .5896 L
.29625 .41981 L
.29704 .13092 L
.29773 .12115 L
.29847 .48501 L
.29917 .52009 L
.29982 .04473 L
.30105 .47628 L
.30235 .37454 L
.30356 .02667 L
.30488 .5037 L
.30612 .42991 L
.30728 .0886 L
.30842 .07784 L
.30946 .19831 L
.31059 .5041 L
.31179 .50603 L
.3131 .03095 L
.3143 .33131 L
.31559 .50846 L
.31633 .52486 L
.31701 .09842 L
.31825 .54656 L
.31938 .52661 L
.32069 .03954 L
.32193 .34646 L
.32298 .50452 L
.32414 .53063 L
.32535 .12442 L
.32649 .06184 L
Mistroke
.32755 .19006 L
.32852 .21959 L
.32964 .49306 L
.33071 .57359 L
.33185 .40527 L
.33307 .0505 L
.33422 .19687 L
.33526 .35125 L
.33649 .54568 L
.33719 .38308 L
.33783 .05624 L
.339 .22855 L
.34024 .5654 L
.34146 .26089 L
.34215 .56356 L
.34278 .18801 L
.34395 .51049 L
.34519 .38681 L
.3463 .14744 L
.34734 .07062 L
.34848 .16373 L
.34971 .53947 L
.35094 .33311 L
.35164 .55088 L
.35229 .16494 L
.35297 .15017 L
.35369 .47878 L
.355 .06819 L
.3562 .32437 L
.3575 .47746 L
.35873 .10622 L
.35986 .12134 L
.36091 .24306 L
.36203 .4767 L
.36325 .42676 L
.36439 .16331 L
.36555 .10904 L
.36665 .28024 L
.36763 .32586 L
.36869 .4704 L
.36995 .38153 L
.37058 .45281 L
.37128 .12285 L
.37251 .47067 L
.37365 .49662 L
.3748 .2573 L
.37584 .14807 L
.37705 .18297 L
.37819 .4308 L
.37936 .49692 L
Mistroke
.3806 .15848 L
.38166 .10196 L
.38283 .26818 L
.38408 .50879 L
.38478 .33792 L
.38543 .11677 L
.38662 .24596 L
.38787 .50719 L
.38895 .42238 L
.39011 .17601 L
.39121 .11636 L
.3922 .13009 L
.39337 .3535 L
.39464 .449 L
.39583 .17858 L
.39693 .12701 L
.39812 .34329 L
.3994 .44025 L
.40061 .17194 L
.40171 .13801 L
.403 .45059 L
.40373 .21922 L
.4044 .18742 L
.40564 .22979 L
.40696 .46815 L
.40768 .37364 L
.40834 .14163 L
.40906 .29066 L
.40983 .45835 L
.41112 .16484 L
.41185 .36926 L
.41253 .44149 L
.4138 .31696 L
.41496 .15721 L
.4156 .41298 L
.4163 .41178 L
.41757 .36126 L
.41877 .16381 L
.41991 .22871 L
.42123 .45007 L
.42244 .25558 L
.42357 .16668 L
.42462 .19642 L
.42577 .36248 L
.427 .41766 L
.42771 .38245 L
.42835 .17591 L
.42906 .29708 L
.42981 .43401 L
.43107 .21743 L
Mistroke
.43179 .39878 L
.43246 .36928 L
.43368 .40285 L
.43484 .2474 L
.43548 .43074 L
.43618 .30051 L
.4374 .42654 L
.4387 .22319 L
.43992 .24965 L
.44061 .22022 L
.44125 .41098 L
.44196 .34558 L
.4427 .21376 L
.44337 .28461 L
.44409 .41183 L
.44538 .22451 L
.44617 .32 L
.44692 .40958 L
.44759 .29252 L
.44832 .21082 L
.44954 .31799 L
.45023 .21421 L
.45088 .35468 L
.45218 .22024 L
.45291 .27782 L
.45358 .39787 L
.45477 .30479 L
.45607 .2477 L
.45729 .37735 L
.45843 .37388 L
.45971 .23617 L
.46091 .28615 L
.46215 .38183 L
.46281 .28834 L
.46352 .24294 L
.46429 .30702 L
.46502 .37598 L
.46567 .29197 L
.46639 .2468 L
.46705 .34557 L
.46776 .3578 L
.46902 .31983 L
.4702 .25349 L
.47147 .32287 L
.47266 .35967 L
.47376 .32518 L
.47498 .26117 L
.47567 .32343 L
.47631 .34127 L
.4776 .31339 L
Mistroke
.47833 .35111 L
.47899 .29323 L
.48015 .34144 L
.48138 .32001 L
.48245 .29491 L
.48359 .27744 L
.48481 .31922 L
.48596 .33633 L
.48666 .30822 L
.48733 .28614 L
.48857 .30883 L
.48966 .32467 L
.49082 .32314 L
.4918 .31898 L
.4929 .30568 L
.49406 .29763 L
.49532 .31397 L
.49651 .31487 L
.49761 .30954 L
.49888 .30716 L
.50008 .30903 L
.50116 .3069 L
.50233 .30773 L
.50361 .31591 L
.50425 .30742 L
.50496 .29974 L
.50622 .31118 L
.50739 .32346 L
.50857 .30971 L
.50968 .29276 L
.51069 .2887 L
.51178 .29241 L
.51297 .32573 L
.51423 .31912 L
.51542 .28109 L
.5165 .28078 L
.5178 .34117 L
.51845 .28381 L
.51917 .2824 L
.52044 .2992 L
.52162 .34921 L
.52234 .29756 L
.52302 .2699 L
.52429 .31177 L
.52501 .26075 L
.52567 .32462 L
.52639 .35851 L
.52716 .31434 L
.52834 .36382 L
.52962 .27548 L
Mistroke
.53082 .26452 L
.53193 .31876 L
.53315 .36839 L
.53385 .32541 L
.53449 .24395 L
.5358 .34551 L
.53653 .25363 L
.53719 .28612 L
.53839 .2398 L
.5395 .29916 L
.54073 .38699 L
.54205 .24445 L
.5427 .37835 L
.54342 .35551 L
.54473 .32708 L
.546 .22575 L
.54718 .332 L
.54839 .39565 L
.54952 .30976 L
.55054 .26876 L
.55164 .21192 L
.55285 .3017 L
.55412 .40186 L
.5552 .33506 L
.55639 .20569 L
.55706 .36592 L
.55779 .4075 L
.55848 .24358 L
.55911 .26358 L
.56031 .2088 L
.56159 .41076 L
.56225 .21842 L
.56296 .23684 L
.56424 .27097 L
.56502 .18736 L
.56576 .2718 L
.56643 .43422 L
.56716 .31929 L
.56848 .38546 L
.56967 .20037 L
.57034 .41424 L
.57105 .39247 L
.57236 .32992 L
.57358 .17182 L
.57487 .40311 L
.57598 .44884 L
.57719 .26547 L
.57849 .23568 L
.5797 .44353 L
.58102 .24519 L
Mistroke
.58169 .45906 L
.58242 .35247 L
.58366 .44049 L
.58435 .37128 L
.58498 .15332 L
.58615 .27065 L
.58739 .46974 L
.5885 .38499 L
.58969 .16483 L
.59081 .17333 L
.59183 .22663 L
.59303 .46146 L
.59433 .26371 L
.59555 .15781 L
.59669 .33236 L
.59789 .48231 L
.59918 .16863 L
.60041 .22707 L
.60152 .41415 L
.60283 .34635 L
.60425 .26526 L
.60489 .16721 L
.60558 .4517 L
.60684 .13454 L
.60758 .35798 L
.60826 .47952 L
.60954 .28404 L
.61021 .50199 L
.61094 .29746 L
.61171 .11831 L
.61242 .25685 L
.61373 .20721 L
.61492 .48442 L
.61558 .15071 L
.6163 .17854 L
.6176 .27902 L
.61882 .51696 L
.61994 .3949 L
.62116 .10097 L
.62246 .40987 L
.62358 .52298 L
.62463 .47133 L
.62578 .21219 L
.62701 .1435 L
.62771 .18142 L
.62836 .52716 L
.62907 .33504 L
.62981 .09941 L
.63107 .46906 L
.63179 .15192 L
Mistroke
.63246 .20169 L
.63368 .1366 L
.63484 .42099 L
.63548 .07936 L
.63618 .33032 L
.6374 .07835 L
.63869 .47579 L
.63991 .44244 L
.6406 .48582 L
.64124 .08672 L
.64194 .24725 L
.64268 .52586 L
.64336 .34383 L
.64407 .07272 L
.64537 .49151 L
.64616 .25954 L
.64691 .06609 L
.64758 .3733 L
.64831 .55016 L
.64952 .31289 L
.65021 .55207 L
.65086 .16559 L
.65216 .55596 L
.65289 .3679 L
.65356 .05938 L
.65475 .29263 L
.65605 .51121 L
.65728 .1137 L
.65841 .08949 L
.6597 .54435 L
.66035 .11651 L
.66106 .14316 L
.66232 .20272 L
.66349 .53346 L
.6642 .17435 L
.66488 .12844 L
.66614 .22634 L
.66685 .06403 L
.6675 .49203 L
.66822 .50329 L
.66898 .1996 L
.67016 .53829 L
.67142 .31728 L
.67262 .04138 L
.67372 .15278 L
.67493 .55097 L
.67562 .15064 L
.67626 .18947 L
.67756 .19786 L
.67828 .05363 L
Mistroke
.67894 .48868 L
.6801 .14213 L
.68133 .14088 L
.68238 .30335 L
.68353 .5757 L
.68477 .29063 L
.68547 .58596 L
.6861 .15954 L
.68734 .57687 L
.68851 .41794 L
.6896 .17854 L
.69075 .03823 L
.69185 .20242 L
.69283 .26648 L
.694 .57853 L
.69526 .26397 L
.69645 .029 L
.69755 .17855 L
.69882 .59391 L
.70001 .28138 L
.70109 .08149 L
.70226 .10641 L
.70353 .58802 L
.70418 .1207 L
.70489 .09959 L
.70614 .20881 L
.70731 .56641 L
.70842 .54706 L
.7096 .17347 L
.7106 .09907 L
.71169 .02304 L
.71288 .34557 L
.71414 .54921 L
.71533 .14267 L
.71641 .0192 L
.7177 .46563 L
.71836 .02017 L
.71907 .26182 L
.72034 .07866 L
.72152 .4789 L
.72224 .0726 L
.72292 .19459 L
.72419 .13808 L
.7249 .07312 L
.72556 .55658 L
.72629 .48216 L
.72706 .14805 L
.72824 .54646 L
.72951 .32966 L
.73072 .01472 L
Mistroke
.73182 .1574 L
.73305 .58902 L
.73374 .18057 L
.73439 .12604 L
.73569 .26824 L
.73641 .01563 L
.73709 .41105 L
.73832 .01565 L
.73897 .45182 L
.73967 .55381 L
.74041 .17616 L
.7411 .06349 L
.74241 .36294 L
.74363 .58456 L
.74476 .3202 L
.746 .02683 L
.74732 .5776 L
.74807 .25564 L
.74876 .03209 L
.74952 .32579 L
.75032 .56587 L
.75101 .42069 L
.75166 .01567 L
.75237 .3225 L
.75314 .59099 L
.75382 .32362 L
.75456 .02239 L
.75525 .28077 L
.7559 .58299 L
.75712 .35809 L
.75841 .05584 L
.75965 .52982 L
.76079 .56381 L
.76204 .08227 L
.76335 .34909 L
.7645 .59649 L
.76557 .54606 L
.76674 .17356 L
.76799 .12557 L
.7687 .08904 L
.76936 .56494 L
.77008 .45195 L
.77084 .11513 L
.77212 .59354 L
.77285 .29275 L
.77353 .03359 L
.7748 .37364 L
.77595 .59477 L
.77659 .17643 L
.77729 .07386 L
Mistroke
.77856 .28343 L
.77921 .06073 L
.7799 .48936 L
.78112 .05268 L
.78245 .42757 L
.7832 .08786 L
.7839 .15819 L
.78516 .1784 L
.78632 .52016 L
.78696 .04731 L
.78765 .24657 L
.78891 .09437 L
.79004 .38037 L
.79128 .54005 L
.79257 .04542 L
.79379 .26792 L
.7949 .52345 L
.79595 .5827 L
.79717 .25706 L
.79829 .05018 L
.79961 .45034 L
.8008 .53257 L
.80147 .37943 L
.80219 .05161 L
.80349 .53895 L
.80471 .39343 L
.80601 .05984 L
.80711 .25179 L
.80832 .57207 L
.80906 .32346 L
.80975 .04723 L
.81106 .47382 L
.81178 .12388 L
.81246 .1799 L
.8132 .50851 L
.81399 .54762 L
.81528 .23198 L
.8165 .08232 L
.8172 .21696 L
.81784 .562 L
.81854 .25575 L
.81928 .05589 L
.82051 .36731 L
.82121 .05903 L
.82185 .39982 L
.82303 .08383 L
.82428 .29323 L
.82532 .43427 L
.82644 .55471 L
.82767 .23149 L
Mistroke
.82882 .06595 L
.83013 .48718 L
.83086 .17709 L
.83155 .13602 L
.83281 .23099 L
.83351 .09089 L
.83414 .49971 L
.83535 .15017 L
.83665 .2872 L
.83788 .53912 L
.83901 .36233 L
.84008 .19634 L
.84122 .08366 L
.84229 .18571 L
.84327 .22337 L
.84443 .48834 L
.84568 .36561 L
.84685 .10232 L
.84795 .12662 L
.84908 .35335 L
.85033 .49183 L
.85154 .16423 L
.85285 .29646 L
.854 .51161 L
.85521 .34512 L
.85634 .13495 L
.85738 .10103 L
.85862 .36924 L
.85927 .10495 L
.85996 .3652 L
.86112 .12927 L
.86239 .32325 L
.86353 .4999 L
.86474 .33211 L
.86589 .12751 L
.86694 .12069 L
.86825 .47005 L
.86945 .39715 L
.87008 .40472 L
.87077 .13505 L
.8715 .22337 L
.87218 .48958 L
.87343 .20049 L
.87457 .1352 L
.87583 .43253 L
.87646 .13256 L
.87715 .29934 L
.87839 .14366 L
.87956 .34945 L
.88061 .44289 L
Mistroke
.88175 .45633 L
.88299 .17804 L
.88431 .33176 L
.88543 .46746 L
.88667 .30943 L
.88782 .15219 L
.88887 .16167 L
.89009 .39534 L
.89124 .45667 L
.89231 .38315 L
.89329 .35043 L
.89437 .22526 L
.89553 .16832 L
.89677 .40311 L
.89748 .19114 L
.89814 .27113 L
.89883 .45174 L
.89946 .25451 L
.9002 .17286 L
.90089 .36638 L
.90212 .17291 L
.90325 .23831 L
.9045 .44121 L
.90513 .2188 L
.90582 .22487 L
.90652 .41606 L
.90726 .40001 L
.90858 .30007 L
.90932 .43196 L
.91 .31285 L
.91076 .19055 L
.91156 .21616 L
.91226 .3934 L
.91292 .35874 L
.91361 .19437 L
.91436 .25157 L
.91506 .41684 L
.91571 .30913 L
.91695 .41688 L
.91821 .23545 L
.91885 .41353 L
.91956 .33308 L
.92027 .20498 L
.92103 .26033 L
.92174 .40094 L
.92239 .31267 L
.92366 .39344 L
.92437 .36326 L
.92503 .21354 L
.92624 .3408 L
Mistroke
.92752 .36626 L
.92866 .2569 L
.92989 .25028 L
.93105 .35969 L
.9321 .39035 L
.93334 .30702 L
.93404 .3898 L
.93468 .26837 L
.93586 .37408 L
.93712 .31984 L
.93832 .23638 L
.93964 .35679 L
.94088 .34165 L
.94203 .26097 L
.94317 .25276 L
.9442 .27703 L
.9454 .36058 L
.94652 .35597 L
.94908 .32115 L
.94976 .25798 L
.95048 .30708 L
.95179 .27662 L
.953 .3452 L
.9541 .34929 L
.9554 .27326 L
.95664 .30235 L
.9577 .32706 L
.95882 .34266 L
.95979 .34059 L
.96085 .32828 L
.96198 .2956 L
.96321 .29051 L
.96436 .32049 L
.96543 .32887 L
.96657 .32021 L
.96764 .30722 L
.96881 .29476 L
.97006 .31344 L
.97137 .31263 L
.97261 .30216 L
.97373 .3066 L
.97493 .31133 L
.97619 .30912 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`008?ooool2o`0003Kooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol0000eooooo`?o0000=?ooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0003Co
oooo1Ol00006ooooo`007oooool01?l0003oooooooooool0000dooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00000eooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000003Cooooo00Co0000oooooooooooo0000
1_ooool001oooooo00Co0000oooooooooooo0000=?ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool01_ooool001oooooo00Co0000oooooooooooo
0000=?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01Oooool001oooooo00Co0000oooooooooooo0000=?ooool01?l0003oooooooooool00007
ooooo`Co0000=_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo1?l0000d
ooooo`05o`000?ooooooooooooooool000001_ooool001oooooo00Co0000oooooooooooo0000=?oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo03Kooooo0_l0000eooooo`;o0000
2Oooool00ol0003oooooooooo`0eooooo`05o`000?ooooooooooooooool000001_ooool0023ooooo
0_l0000fooooo`;o00002?ooool5o`0003Gooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`07ooooo`Go0000=?ooool3o`0000Oooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo000Koooooooo00001Ol00001ooooo`004oooool3
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00?ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?oooooo0Oooool1o`00007ooooo000<ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`;o
0000@oooool00ol00?ooooooooooo`1eooooo`03o`00oooooooooooo04;ooooo0_l00001ooooo`00
5?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0
0oooool01?l00?ooooooooooool00?maooooo`06o`00ooooooooooooo`00oooooooo003o0oooool0
0ol00?ooooooooooo`0mooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0looooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003oL?ooool2
o`00o`;ooooo00?o003oooooool00?l00oooool2o`00ockooooo0Ol00001ooooo`004oooool2o`00
00Kooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`03ooooo`06o`00oooooooooooo
o`00oooooooo003o1?ooool00ol00?ooooooooooo`1Wooooo`;o003o0_ooool01_l00?ooooooo`00
oooooooo003oooooo`;o003o?_ooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0??ooool00ol00?ooooooooooo`03ooooo`06o`00ooooooooooooo`00oooo
oooo003o1?ooool00ol00?ooooooooooo`1Sooooo`04o`00ooooooooooooooooo`;o003o0_ooool0
1_l00?ooooooo`00oooooooo003oooooo`;o003o?_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo03[ooooo00?o003oooooool00?l01Oooool01_l00?ooooooooooool00?ooooooo`00o`Co
oooo00?o003oooooool00?l0Hoooool01?l00?ooooooooooooooool2o`00o`;ooooo00Co003ooooo
ool00?oooooo1?l00?l4ooooo`03o`00oooooooooooo03Oooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0cooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool01_l0
0?ooooooooooool00?ooooooo`00o`Cooooo00?o003oooooool00?l0HOooool00ol00?ooooooo`00
o`03ooooo`;o003o0_ooool01?l00?ooooooo`00ooooool4o`00o`Cooooo00?o003oooooooooool0
=oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo037ooooo00?o003oooooool00?l01Ooo
ool4o`00o`;ooooo00?o003oooooooooool00_l00?l01?oooooo003oooooool00?l4ooooo`05o`00
oooooooo003oooooool00?l0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00?o
oooo0_l00?l2ooooo`04o`00oooooooo003oooooo`Co003o1?ooool00ol00?ooooooooooo`0goooo
o`7o00000Oooool001_ooooo0_l0000booooo`03o`00oooooooo003o00Cooooo1Ol00?l2ooooo`03
o`00oooooooooooo00;o003o00?oooooo`00ooooool00ol00?l01ooooooo003oo`00oooooooo003o
ooooool00?l0F_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l2
ooooo`04o`00oooooooo003oooooo`Co003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo037ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`00oooooooo
003o00;ooooo00?o003oooooool00?l01?l00?l2ooooo`03o`00oooooooooooo00;o003o00?ooooo
o`00ooooool00ol00?l01ooooooo003oo`00oooooooo003oooooool00?l0F_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l2ooooo`04o`00oooooooo003oooooo`Co
003o1?ooool01_l00?ooooooooooool00?ooooooo`00o`?ooooo00?o003oooooooooool0;_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo02gooooo00Oo003oooooooooooooooooo`00oooo
oooo003o00;ooooo00?o003oooooool00?l01?l00?l2ooooo`03o`00oooooooooooo00;o003o00?o
ooooo`00ooooool00ol00?l01ooooooo003oo`00oooooooo003oooooool00?l00_ooool00ol00?oo
ooooooooo`1Eooooo`03o`00oooooooo003o00;ooooo00?o003oooooool00?l00oooool2o`00o`;o
oooo00Co003oooooool00?oooooo1?l00?l4ooooo`05o`00oooooooo003oo`00ooooool00ol00?l0
0ooooooo003oooooo`0_ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0;Oooool01ol0
0?oooooooooooooooooo003oooooool00?l00_ooool00ol00?ooooooo`00o`04o`00o`;ooooo00?o
003oooooooooool00_l00?l00ooooooo003oooooo`03o`00o`07ooooool00?oo003oooooool00?oo
ooooo`00o`02ooooo`;o003oE_ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00?o
oooo0_l00?l2ooooo`04o`00oooooooo003oooooo`Go003o0oooool01Ol00?ooooooo`00ool00?oo
oooo00?o003o00Coooooo`00oooooooo003o;_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo02gooooo00Oo003oooooooooooooooooo`00oooooooo003o00;ooooo00?o003oooooool00?l0
1?l00?l2ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ooooool00ol00?l01ooooooo003o
o`00oooooooo003oooooool00?l00_ooool2o`00oe7ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooo`00o`02ooooo`03o`00oooooooo003o00?ooooo0_l00?l2ooooo`04o`00oooooooo003o
ooooo`Go003o0oooool4o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l0;Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo02[ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooo`00o`02ooooo`03o`00oooooooo003o00Co003o0_ooool00ol00?ooooooooooo`02
o`00o`03ooooool00?oooooo00?o003o00Soooooo`00ool00?ooooooo`00oooooooo003oooooo`?o
003oDOooool01?l00?ooooooooooooooool2o`00o`07ooooool00?ooooooooooool00?ooooooo`00
o`02ooooo`?o003o0_ooool00ol00?ooooooo`00o`06o`00o`?ooooo1?l00?l00ooooooo003oo`00
o`03o`00o`03ooooool00?oo003o02gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Y
ooooo`;o003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00_ooool00ol00?oooooo
o`00o`04o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`03o`00o`08oooo
ool00?oo003oooooool00?ooooooo`00ooooool3o`00o`Cooooo00?o003oooooooooool0BOooool2
o`00o`?ooooo0_l00?l01ooooooo003ooooooooooooo003oooooool00?l00_ooool3o`00o`;ooooo
00?o003oooooool00?l01_l00?l3ooooo`Co003o00?oooooo`00ool00?l00ol00?l01Ooooooo003o
o`00oooooooo003o02_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Yooooo`;o003o
0_ooool02?l00?oooooooooooooooooo003oooooool00?oooooo0_l00?l00ooooooo003oo`00o`03
o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`03o`00o`08ooooool00?oo
003oooooool00?ooooooo`00ooooool3o`00o`;ooooo00?o003oooooool00?l0B_ooool3o`00o`?o
oooo0_l00?l01ooooooo003ooooooooooooo003oooooool00?l00_ooool6o`00o`03ooooool00?oo
003o00Go003o0oooool4o`00o`03ooooool00?oo003o00?o003o00Goooooo`00ool00?ooooooo`00
o`0[ooooo`7o00000Oooool001_ooooo0_l0000Zooooo`;o003o0_ooool02?l00?oooooooooooooo
oooo003oooooool00?oooooo0_l00?l00ooooooo003oo`00o`03o`00o`;ooooo0_l00?l01?oooooo
003oo`00ooooool5o`00o`08ooooool00?oo003oooooool00?ooooooo`00ooooool3o`00o`;ooooo
00?o003oooooool00?l0B_ooool3o`00o`?ooooo0_l00?l01ooooooo003ooooooooooooo003ooooo
ool00?l00_ooool6o`00o`03ooooool00?oo003o00Go003o0oooool4o`00o`03ooooool00?oo003o
00?o003o00Goooooo`00ool00?ooooooo`00o`0Zooooo`;o00000Oooool001_ooooo00?o0000oooo
ooooool0:Oooool2o`00o`;ooooo00So003oooooooooooooooooo`00oooooooo003oooooo`So003o
0_ooool2o`00o`04ooooool00?oo003oooooo`Go003o00?oooooo`00ool00?l00_l00?l00ooooooo
003oooooo`03o`00o`;ooooo00?o003oooooool00?l0B?ooool00ol00?ooooooo`00o`02o`00o`?o
oooo0_l00?l01ooooooo003ooooooooooooo003oooooool00?l00_ooool6o`00o`03ooooool00?oo
003o00Go003o0oooool4o`00o`03ooooool00?oo003o00?o003o00Goooooo`00ool00?ooooooo`00
o`0[ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0:Oooool2o`00o`;ooooo00So003o
ooooooooooooooooo`00oooooooo003oooooo`So003o0_ooool2o`00o`04ooooool00?oo003ooooo
o`Go003o00?oooooo`00ool00?l00_l00?l00ooooooo003oooooo`03o`00o`;ooooo00?o003ooooo
ool00?l0B?ooool00ol00?ooooooo`00o`02o`00o`?ooooo0_l00?l01_oooooo003ooooooooooooo
003oooooo`;o003o00?oooooo`00ool00?l01?l00?l00ooooooo003oo`00o`06o`00o`;ooooo1?l0
0?l00ooooooo003oo`00o`03o`00o`05ooooool00?oo003oooooool00?l00_ooool00ol00?oooooo
ooooo`0Vooooo`7o00000Oooool001_ooooo00?o0000ooooooooool09Oooool01?l00?oooooooooo
ooooool2o`00o`;ooooo00So003oooooooooooooooooo`00oooooooo003oooooo`So003o00Gooooo
o`00ool00?oo003oooooo`02o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l00_l0
0?l00ooooooo003oooooo`03o`00o`;ooooo00?o003oooooool00?l0B?ooool5o`00o`?ooooo0_l0
0?l01_oooooo003ooooooooooooo003oooooo`;o003o00?oooooo`00ool00?l03Ol00?l2ooooo`Co
003o00?oooooo`00ool00?l00ol00?l01Ooooooo003oo`00oooooooo003o00;ooooo00?o003ooooo
ooooool09_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02Cooooo0_l00?l3ooooo`;o
003o0_ooool02?l00?oooooooooooooooooo003oooooool00?oooooo2?l00?l01Ooooooo003oo`00
ool00?oooooo00;o003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`02o`00o`03oooo
ool00?oooooo00?o003o0_ooool00ol00?ooooooo`00o`18ooooo`Go003o00?oooooo`00ooooool0
0_l00?l01_oooooo003ooooooooooooo003oooooo`;o003o00?oooooo`00ool00?l03_l00?l00ooo
oooo003oo`00o`02o`00o`03ooooool00?oo003o00?o003o00Coooooo`00ool00?oooooo0_l00?l0
0ooooooo003oooooo`0Wooooo`7o00000Oooool001_ooooo00?o0000ooooooooool09?ooool2o`00
o`?ooooo0_l00?l2ooooo`08o`00oooooooo003oooooool00?ooooooo`00ooooool8o`00o`05oooo
ool00?oo003oo`00ooooool00_l00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00;o
003o00?oooooo`00ooooool00ol00?l2ooooo`03o`00oooooooo003o04Sooooo1Ol00?l00ooooooo
003oooooo`02o`00o`06ooooool00?ooooooooooool00?oooooo0_l00?l00ooooooo003oo`00o`0>
o`00o`03ooooool00?oo003o00So003o00Coooooo`00ool00?oooooo0_l00?l00ooooooo003ooooo
o`0Wooooo`7o00000Oooool001_ooooo00?o0000ooooooooool09?ooool2o`00o`?ooooo0_l00?l2
ooooo`03o`00oooooooo003o00;o003o00?oooooo`00ooooool02?l00?l01Ooooooo003oo`00ool0
0?oooooo00;o003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`08o`00o`;ooooo00?o
003oooooool00?l0A_ooool00ol00?ooooooo`00o`04o`00o`03ooooool00?oooooo00Co003o0_oo
ool00ol00?ooooooo`00o`0Bo`00o`03ooooool00?oo003o00So003o00Coooooo`00ool00?oooooo
0_l00?l00ooooooo003oooooo`0Wooooo`7o00000Oooool001_ooooo0_l0000Uooooo`;o003o0ooo
ool2o`00o`;ooooo00?o003oooooool00?l00_l00?l00ooooooo003oooooo`08o`00o`05ooooool0
0?oo003oo`00ooooool00_l00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00So003o
0_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo03_ooooo00Co003oooooool00?oo
oooo1Ol00?l00ooooooo003oooooo`04o`00o`;ooooo00?o003oooooool00?l04_l00?l00ooooooo
003oo`00o`08o`00o`04ooooool00?oo003oooooo`;o003o00Koooooo`00oooooooo003oooooool0
0?lSooooo`;o00000Oooool001_ooooo00?o0000ooooooooool08Oooool00ol00?ooooooooooo`02
o`00o`?ooooo0_l00?l2ooooo`03o`00oooooooo003o00;o003o00?oooooo`00ooooool02?l00?l0
1Ooooooo003oo`00ool00?oooooo00;o003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00
o`08o`00o`;ooooo00Co003oooooool00?oo003o1Oooool00ol00?ooooooooooo`0kooooo`04o`00
oooooooo003oooooo`Oo003o00?oooooo`00ool00?l00_l00?l2ooooo`03o`00oooooooo003o01;o
003o00?oooooo`00ool00?l02?l00?l01?oooooo003oo`00ooooool2o`00o`05ooooool00?oooooo
o`00ooooool00_l00?lSooooo`7o00000Oooool001_ooooo00?o0000ooooooooool08Oooool2o`00
o`03ooooool00?oo003o00?ooooo0_l00?l2ooooo`03o`00oooooooo003o00;o003o00?oooooo`00
ooooool02?l00?l01Ooooooo003oo`00ool00?oooooo00;o003o00?oooooo`00ool00?l00ol00?l0
0ooooooo003oo`00o`08o`00o`;ooooo00Ko003oooooool00?oo003oooooool00?l3ooooo`03o`00
oooooooooooo03_ooooo00Co003oooooool00?oooooo1ol00?l00ooooooo003oo`00o`02o`00o`;o
oooo00?o003oooooool00?l04_l00?l00ooooooo003oo`00o`08o`00o`04ooooool00?oo003ooooo
o`;o003o00Goooooo`00oooooooo003oooooo`02o`00ob?ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0Qooooo`;o003o00?oooooo`00ool00?l00oooool2o`00o`;ooooo00?o003ooooo
ool00?l00_l00?l00ooooooo003oooooo`08o`00o`05ooooool00?oo003oo`00ooooool00_l00?l0
0ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00So003o0_ooool01_l00?ooooooo`00ool0
0?ooooooo`00o`?ooooo00?o003oooooooooool0>oooool01?l00?ooooooo`00ooooool7o`00o`03
ooooool00?oo003o00;o003o0_ooool00ol00?ooooooo`00o`0Mo`00o`04ooooool00?oo003ooooo
o`;o003o00Goooooo`00oooooooo003oooooo`02o`00ob?ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0Pooooo`?o003o00?oooooo`00ool00?l00oooool2o`00o`;ooooo00?o003ooooo
ool00?l01?l00?l00ooooooo003oo`00o`06o`00o`05ooooool00?oo003oo`00ooooool00_l00?l0
0ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00So003o0_ooool01_l00?ooooooo`00ool0
0?ooooooo`00o`?ooooo0ol00?liooooo`06o`00oooooooo003oooooool00?oooooo1ol00?l00ooo
oooo003oo`00o`02o`00o`;ooooo00?o003oooooool00?l07Ol00?l01?oooooo003oo`00ooooool2
o`00o`05ooooool00?ooooooo`00ooooool00_l00?lSooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool08?ooool3o`00o`03ooooool00?oo003o00?ooooo0_l00?l2ooooo`03o`00oooooooo
003o00Co003o00?oooooo`00ool00?l01_l00?l01Ooooooo003oo`00ool00?oooooo00;o003o00?o
ooooo`00ool00?l03_l00?l2ooooo`05o`00oooooooo003oo`00ooooool00_l00?l2ooooo`?o003o
>Oooool01_l00?ooooooo`00oooooooo003oooooo`Oo003o00?oooooo`00ool00?l00_l00?l2oooo
o`03o`00oooooooo003o01go003o00Coooooo`00ool00?oooooo0_l00?l01Ooooooo003oooooool0
0?oooooo00;o003o00?oooooo`00ooooool08?ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo01kooooo00?o003oooooool00?l00_l00?l00ooooooo003oo`00o`03ooooo`;o003o0_ooool0
0ol00?ooooooo`00o`04o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ool00?l01?l00?l0
0ooooooo003oo`00o`0>o`00o`;ooooo00Go003oooooool00?oo003oooooo`02o`00o`;ooooo1Ol0
0?lgooooo`06o`00oooooooo003oooooool00?oooooo1ol00?l00ooooooo003oo`00o`02o`00o`;o
oooo00?o003oooooool00?l08?l00?l02?oooooo003oo`00oooooooo003oooooool00?oooooo0_l0
0?l00ooooooo003oooooo`0Pooooo`7o00000Oooool001_ooooo00?o0000ooooooooool07Oooool2
o`00o`05ooooool00?oo003oo`00ooooool00_l00?l3ooooo`;o003o0_ooool00ol00?ooooooo`00
o`04o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ool00?l01?l00?l00ooooooo003oo`00
o`0>o`00o`;ooooo00Go003oooooool00?oo003oooooo`02o`00o`;ooooo1Ol00?lgooooo`06o`00
oooooooo003oooooool00?oooooo3?l00?l2ooooo`03o`00oooooooo003o023o003o00Soooooo`00
ool00?ooooooo`00oooooooo003oooooo`;o003o00?oooooo`00ooooool08?ooool1o`00007ooooo
000Kooooo`;o00007_ooool2o`00o`05ooooool00?oo003oo`00ooooool00_l00?l3ooooo`;o003o
0_ooool00ol00?ooooooo`00o`04o`00o`03ooooool00?oo003o00go003o00?oooooo`00ool00?l0
3_l00?l2ooooo`05o`00oooooooo003oo`00ooooool00_l00?l2ooooo`Go003o=Oooool02?l00?oo
ooooo`00oooooooo003oooooool00?oooooo3?l00?l2ooooo`03o`00oooooooo003o023o003o00So
ooooo`00ool00?ooooooo`00oooooooo003oooooo`;o003o00Coooooo`00oooooooo003o7_ooool2
o`00007ooooo000Kooooo`03o`000?oooooooooo01gooooo0_l00?l01Ooooooo003oo`00ool00?oo
oooo00;o003o00?oooooo`00ooooool00_l00?l2ooooo`03o`00oooooooo003o00Co003o00?ooooo
o`00ool00?l03Ol00?l00ooooooo003oo`00o`0>o`00o`;ooooo00Go003oooooool00?oo003ooooo
o`02o`00o`;ooooo1_l00?ldooooo`06o`00oooooooo003oooooool00?oooooo3_l00?l2ooooo`03
o`00oooooooo003o023o003o00Soooooo`00ool00?ooooooo`00oooooooo003oooooo`;o003o00Co
ooooo`00ool00?oo003o7oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01_ooooo00Go
003oooooool00?oo003oooooo`03o`00o`06ooooool00?oo003oooooool00?oooooo0_l00?l2oooo
o`03o`00oooooooo003o00Co003o00?oooooo`00ool00?l03Ol00?l00ooooooo003oo`00o`0>o`00
o`;ooooo00?o003oooooool00?l01?l00?l2ooooo`Ko003o00?oooooo`00ooooool0<Oooool01_l0
0?ooooooo`00oooooooo003oooooo`oo003o00?oooooo`00ooooool08Ol00?l02?oooooo003oo`00
oooooooo003oooooool00?oooooo0_l00?l01?oooooo003oo`00ool00?lOooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool06oooool01Ol00?ooooooo`00ool00?oooooo00?o003o00Kooooo
o`00ool00?ooooooo`00ooooool3o`00o`03ooooool00?oooooo00Go003o00?oooooo`00ool00?l0
3Ol00?l00ooooooo003oo`00o`0?o`00o`03ooooool00?oooooo00Go003o0_ooool6o`00o`03oooo
ool00?oooooo037ooooo00Ko003oooooool00?ooooooo`00ooooool?o`00o`03ooooool00?oooooo
027o003o00Soooooo`00ool00?ooooooo`00oooooooo003oooooo`;o003o00?oooooo`00ool00?l0
0_l00?lNooooo`7o00000Oooool001_ooooo00?o0000ooooooooool06oooool01Ol00?ooooooo`00
ool00?oooooo00?o003o00Koooooo`00ool00?ooooooo`00ooooool3o`00o`03ooooool00?oooooo
00Go003o00?oooooo`00ool00?l03Ol00?l00ooooooo003oo`00o`0?o`00o`03ooooool00?oo003o
00Ko003o00?oooooo`00ool00?l01?l00?l00ooooooo003oooooo`0aooooo`06o`00oooooooo003o
ooooool00?oooooo3ol00?l00ooooooo003oo`00o`0Qo`00o`03ooooool00?oo003o00;o003o00?o
ooooo`00ooooool00_l00?l00ooooooo003oo`00o`02o`00oakooooo0Ol00001ooooo`002?ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool06oooool4
o`00o`05ooooool00?oo003oo`00ooooool00_l00?l00ooooooo003oooooo`03o`00o`03ooooool0
0?oooooo00Go003o00?oooooo`00ool00?l03Ol00?l00ooooooo003oo`00o`0?o`00o`03ooooool0
0?oo003o00Ko003o00?oooooo`00ool00?l01?l00?l00ooooooo003oooooo`0/ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooool00?l00_l00?l00ooooooo003oo`00o`0=o`00o`03ooooool0
0?oo003o027o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oooooo`02o`00o`03ooooool0
0?oo003o00;o003o00?oooooo`00ooooool06oooool1o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01_ooooo
1?l00?l01Ooooooo003oo`00ool00?oooooo00;o003o00?oooooo`00ooooool00ol00?l00ooooooo
003oooooo`05o`00o`03ooooool00?oo003o01oo003o00?oooooo`00ool00?l01_l00?l00ooooooo
003oo`00o`04o`00o`03ooooool00?oo003o02cooooo00?o003oooooool00?l00_ooool00ol00?oo
ooooo`00o`02o`00o`03ooooool00?oo003o00go003o00?oooooo`00ool00?l08Ol00?l00ooooooo
003oo`00o`02o`00o`03ooooool00?oooooo00;o003o00?oooooo`00ool00?l00_l00?l00ooooooo
003oooooo`0Kooooo`7o00000Oooool000Go00000_ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo00;ooooo0_l0000Looooo`Co003o00Goooooo`00ool00?oo003oooooo`02o`00
o`03ooooool00?oooooo00Go003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`0Oo`00
o`03ooooool00?oo003o00Ko003o00?oooooo`00ool00?l01?l00?l00ooooooo003oo`00o`0/oooo
o`03o`00oooooooo003o00;ooooo00?o003oooooool00?l00_l00?l00ooooooo003oo`00o`0ao`00
o`03ooooool00?oo003o00;o003o00?oooooo`00ooooool00_l00?l00ooooooo003oo`00o`02o`00
o`03ooooool00?oo003o01[ooooo0_l00001ooooo`001oooool01?l0003oooooooooool0000;oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool4o`00o`05ooooool00?oo003o
o`00ooooool00_l00?l00ooooooo003oooooo`05o`00o`03ooooool00?oo003o00?o003o00?ooooo
o`00ool00?l07ol00?l00ooooooo003oo`00o`06o`00o`03ooooool00?oo003o00Co003o00Cooooo
o`00ool00?oo003o:oooool3o`00o`;ooooo00?o003oooooool00?l00_l00?l00ooooooo003oo`00
o`0ao`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00
o`02o`00o`03ooooool00?oo003o01_ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0
0007ooooo`Co00001Oooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00Co003o00Go
ooooo`00ool00?oo003oooooo`02o`00o`03ooooool00?oooooo00Go003o00?oooooo`00ool00?l0
0ol00?l00ooooooo003oo`00o`0Oo`00o`03ooooool00?oo003o00go003o00Koooooo`00ool00?oo
003oooooool00?lYooooo`Co003o00?oooooo`00ooooool00ol00?l00ooooooo003oo`00o`0ao`00
o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`02o`00
o`04ooooool00?oo003oo`00oa[ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`04
o`00o`05ooooool00?oo003oo`00ooooool00_l00?l00ooooooo003oooooo`05o`00o`03ooooool0
0?oo003o00?o003o00?oooooo`00ool00?l07ol00?l00ooooooo003oo`00o`0=o`00o`06ooooool0
0?oo003oo`00oooooooo003o9_ooool00ol00?ooooooooooo`04o`00o`03ooooool00?oooooo00?o
003o00?oooooo`00ool00?l0<Ol00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00;o
003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`03o`00oaSooooo0Ol00001ooooo`00
2?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo01Sooooo0_l00?l00ooooooo003o
o`00o`02o`00o`03ooooool00?oo003o00Co003o00?oooooo`00ooooool01Ol00?l00ooooooo003o
o`00o`03o`00o`03ooooool00?oo003o01oo003o00?oooooo`00ool00?l03Ol00?l01Ooooooo003o
o`00ool00?oooooo00;o003o9Oooool00ol00?ooooooooooo`04o`00o`03ooooool00?oooooo00?o
003o00?oooooo`00ool00?l0<Ol00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00;o
003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`03o`00oaSooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`0Fooooo`05o`00oooooooo003oo`00ooooool01?l00?l00ooooooo
003oo`00o`04o`00o`03ooooool00?oooooo00_o003o00?oooooo`00ool00?l07ol00?l00ooooooo
003oo`00o`0=o`00o`05ooooool00?oo003oo`00ooooool00_l00?lUooooo`03o`00oooooooooooo
00Co003o00?oooooo`00ooooool00ol00?l00ooooooo003oo`00o`0ao`00o`03ooooool00?oo003o
00;o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`08o`00oaSooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0Eooooo`;o003o00Coooooo`00ool00?oooooo1?l00?l00ooo
oooo003oo`00o`04o`00o`03ooooool00?oooooo00_o003o00?oooooo`00ool00?l07ol00?l00ooo
oooo003oo`00o`0=o`00o`05ooooool00?oo003oo`00ooooool00_l00?lUooooo`03o`00oooooooo
oooo00Co003o00?oooooo`00ooooool0=ol00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo
003o00;o003o00?oooooo`00ool00?l02?l00?lHooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool05Oooool2o`00o`04ooooool00?oo003oooooo`_o003o00?oooooo`00ooooool02ol00?l0
0ooooooo003oo`00o`0co`00o`03ooooool00?oo003o02;ooooo00Co003ooooooooooooo003o0_oo
ool4o`00o`03ooooool00?oooooo03Oo003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00
o`02o`00o`03ooooool00?oo003o00So003o6?ooool1o`00007ooooo000Kooooo`;o00005_ooool2
o`00o`04ooooool00?oo003oooooo`_o003o00?oooooo`00ooooool02ol00?l00ooooooo003oo`00
o`0co`00o`03ooooool00?oo003o02;ooooo00Co003ooooooooooooo003o0_ooool4o`00o`03oooo
ool00?oooooo03co003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`08o`00o`03oooo
ool00?oooooo01Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Cooooo`05o`00oooo
oooo003oo`00ooooool00_l00?l00ooooooo003oo`00o`09o`00o`03ooooool00?oooooo00_o003o
00?oooooo`00ool00?l0<ol00?l00ooooooo003oo`00o`0Rooooo`04o`00ooooooooooooo`00o`;o
oooo1?l00?l00ooooooo003oooooo`0lo`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool0
0?l02?l00?l00ooooooo003oo`00o`0Eooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
4oooool01Ol00?ooooooo`00ool00?oooooo00;o003o00?oooooo`00ool00?l02Ol00?l00ooooooo
003oooooo`0;o`00o`03ooooool00?oo003o03Ko003o8_ooool01?l00?ooooooooooool00?l2oooo
o`Ko003o00?oooooo`00ool00?l0>_l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o
00So003o00?oooooo`00ool00?l05Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01?o
oooo00Go003oooooool00?oo003oooooo`02o`00o`03ooooool00?oo003o00Wo003o00?oooooo`00
ooooool02ol00?l00ooooooo003oo`00o`0fo`00ob;ooooo00Co003oooooool00?oo003o0_ooool6
o`00o`03ooooool00?oo003o03[o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`08
o`00o`03ooooool00?oo003o01Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Aoooo
o`04o`00oooooooo003oooooo`Go003o00?oooooo`00ool00?l02Ol00?l00ooooooo003oooooo`0;
o`00o`03ooooool00?oo003o03Ko003o8?ooool01?l00?ooooooo`00ooooool2o`00o`;ooooo1_l0
0?l00ooooooo003oo`00o`0oo`00o`03ooooool00?oo003o00So003o00Goooooo`00ool00?oooooo
o`00o`0Cooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04Oooool3o`00o`03ooooool0
0?oo003o00?o003o00?oooooo`00ool00?l02Ol00?l00ooooooo003oooooo`0;o`00o`03ooooool0
0?oo003o03Ko003o1?ooool00ol00?ooooooooooo`0Iooooo`?o003o00?oooooo`00ool00?l00_oo
oom8o`00o`03ooooool00?oo003o00So003o00Goooooo`00ool00?ooooooo`00o`0Cooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool04Oooool3o`00o`03ooooool00?oo003o00?o003o00?o
ooooo`00ool00?l02Ol00?l00ooooooo003oooooo`0;o`00o`03ooooool00?oo003o03Ko003o0ooo
ool3o`00oaWooooo1?l00?l00ooooooo003oo`00o`02ooooodSo003o00?oooooo`00ool00?l02?l0
0?l01?oooooo003oo`00ooooool2o`00oa;ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`0Aooooo`?o003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`09o`00o`03ooooool0
0?oooooo00_o003o00?oooooo`00ool00?l0=ol00?l2ooooo`?o003o6Oooool4o`00o`03ooooool0
0?oo003o00;oooooB?l00?l00ooooooo003oo`00o`0;o`00o`03ooooool00?oo003o01;ooooo0Ol0
0001ooooo`006oooool2o`0001;ooooo0ol00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo
003o00Wo003o00?oooooo`00ooooool02ol00?l00ooooooo003oo`00o`0go`00o`03ooooool00?oo
003o00;o003o6Oooool4o`00o`03ooooool00?oo003o00;oooooB?l00?l00ooooooo003oo`00o`0;
o`00o`03ooooool00?oo003o017ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Aoooo
o`?o003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`0;o`00o`03ooooool00?oo003o
00Wo003o00?oooooo`00ool00?l0=ol00?l00ooooooo003oo`00o`02o`00oaSooooo1Ol00?l00ooo
oooo003oo`00o`02ooooodSo003o00?oooooo`00ool00?l02ol00?l00ooooooo003oo`00o`0Boooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool04?ooool4o`00o`03ooooool00?oo003o00?o
003o00?oooooo`00ool00?l02ol00?l00ooooooo003oo`00o`09o`00o`03ooooool00?oo003o03Oo
003o00?oooooo`00ool00?l00_l00?lHooooo`Go003o00?oooooo`00ool00?l00_oooomFo`00o`03
ooooool00?oo003o01;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0@ooooo`Co003o
00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`0;o`00o`03ooooool00?oo003o00Wo003o
00?oooooo`00ool00?l0=ol00?l00ooooooo003oo`00o`02o`00oaSooooo2?l00?l2oooooeKo003o
00?oooooo`00ool00?l04_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00gooooo00?o
003oooooooooool01?l00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00_o003o00?o
ooooo`00ool00?l02Ol00?l00ooooooo003oo`00o`0go`00o`03ooooool00?oo003o00;o003o00?o
ooooo`00ooooool05Oooool9o`00o`03ooooool00?oo003o05Oo003o0_ooool00`000?oooooooooo
o`0=ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool03Oooool2o`00o`03ooooool00?oo
003o00;o003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`0;o`00o`03ooooool00?oo
003o00Wo003o00?oooooo`00ool00?l0=ol00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo
oooo01?ooooo00?o003oooooool00?l02?l00?l00ooooooo003oo`00o`1Go`00o`;ooooo00<0003o
ooooooooool03Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00gooooo0_l00?l00ooo
oooo003oo`00o`02o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l02ol00?l00ooo
oooo003oo`00o`09o`00o`03ooooool00?oo003o03Oo003o00?oooooo`00ool00?l00_l00?l00ooo
oooo003oo`00o`0Booooo`;o003o00?oooooo`00ool00?l0HOl00?l2ooooo`030000oooooooooooo
00gooooo0Ol00001ooooo`006oooool2o`0000gooooo0ol00?l00ooooooo003oo`00o`02o`00o`03
ooooool00?oo003o017o003o00?oooooo`00ool00?l02Ol00?l00ooooooo003oo`00o`10o`00oa7o
oooo0_l00?l00ooooooo003oo`00o`1Qo`00o`030000ooooool0003o00kooooo0_l00001ooooo`00
6oooool00ol0003oooooooooo`0;ooooo`Co003o00?oooooo`00ool00?l00_l00?l00ooooooo003o
o`00o`0Ao`00o`03ooooool00?oo003o00Wo003o00?oooooo`00ool00?l0@Ol00?l@ooooo`;o003o
00?oooooo`00ool00?l0HOl00?l01@000?oooooo0000ooooool0003o00gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`0;ooooo`Co003o00?oooooo`00ool00?l05_l00?l00ooooooo003o
o`00o`09o`00o`03ooooool00?oo003o047o003o4?ooool2o`00o`03ooooool00?oo003o067o003o
00@0003oooooo`000?oooooo0P000?l<ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
2oooool4o`00o`03ooooool00?oo003o01Ko003o00?oooooo`00ool00?l02Ol00?l00ooooooo003o
o`00o`12o`00o`cooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`1Qo`00o`030000
ooooool0003o00<0003o3?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00[ooooo1Ol0
0?l00ooooooo003oo`00o`0Ro`00o`03ooooool00?oo003o04;o003o3?ooool00ol00?ooooooo`00
o`02o`00o`03ooooool00?oo003o067o003o00<0003oooooo`000?l00`000?l<ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool02_ooool5o`00o`03ooooool00?oo003o02;o003o00?ooooo
o`00ool00?l0@_l00?l<ooooo`03o`00oooooooo003o00;o003o00?oooooo`00ool00?l0HOl00?l6
0000o`cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`08ooooobco003o00?oooooo`00
ool00?l0@_l00?l<ooooo`Go003o00?oooooo`00ool00?l0HOl00?l60000o`03ooooo`000?oooooo
00Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`08ooooobco003o00?oooooo`00ool0
0?l0@_l00?l<ooooo`Go003o00?oooooo`00ool00?l0HOl00?l80000o`[ooooo0Ol00001ooooo`00
6oooool2o`0000Wooooo;?l00?l00ooooooo003oo`00o`12o`00o`03ooooool00?oooooo00Oooooo
00?o003oooooool00?l0J?l00?l80000o`Wooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`07ooooobgo003o00?oooooo`00ool00?l0@_l00?l00ooooooo003oooooo`07ooooof_o003o2000
0?l:ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01_ooool^o`00o`03ooooool00?oo
003o04;o003o00?oooooo`00ool00?l01Oooool00ol00?ooooooo`00o`1Zo`00o`P0003o2_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00Kooooo;_l00?l00ooooooo003oo`00o`12o`00
o`03ooooool00?oo003o00GoooooKOl00?l80000o`03ooooo`000?oooooo00Oooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`06ooooobko003o00?oooooo`00ool00?l0AOl00?l5ooooofgo
003o20000?l00oooool0003o0000o`07ooooo`7o00000Oooool001Cooooo0_l00005ooooo`03o`00
0?oooooooooo00Kooooo;_l00?l00ooooooo003oo`00o`15o`00o`04ooooool00?ooooooooooofko
003o20000?l00oooool0003o0000o`07ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooo003o07Oo003o0_oooom^o`00o`P0
003o00Cooooo0000o`000?oo003o1_ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01?oooooZo`00o`P0003o00Gooooo0000o`000?l0003oo`00o`05
ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool6o`000>_o003o20000?l0
1Ol00000003o0000o`000?oo003o00Ko00000Oooool001?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`04ooooon[o003o30000?l6ooooo`7o00000Oooool001?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`05ooooogSo003o0_ooool2o`00o`03ooooool0
0?oo003o06[o003o2`000?l7ooooo`7o00000Oooool001Cooooo0_l00005ooooo`03o`000?oooooo
oooo00Gooooo00?o003oooooool00?l0MOl00?l3ooooo`03o`00oooooooo003o06_o003o2`000?l7
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`1eo`00
o`GoooooK?l00?l;0000o`Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`07ooooogGo
003o1ooooom[o`00o`X0003o2?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Oooooo
Lol00?l00ooooooo003oooooo`06ooooof_o003o2@000?l9ooooo`7o00000Oooool001_ooooo0_l0
0008ooooo`;o003o00?oooooo`00ool00?l0K_l00?l00ooooooo003oooooo`06ooooof_o003o1`00
0?l00oooool0003oooooo`07ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool02?ooool0
1?l00?ooooooo`00oooooom^o`00o`WoooooJ_l00?l60000o`04ooooo`000?oooooo0000o`Wooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`08ooooo`04o`00oooooooo003oooooofco003o
00?oooooo`00ooooool02OoooomYo`00o`H0003o00?ooooo0000ooooool02_ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00Sooooo00Co003oooooool00?ooooooK?l00?l00ooooooo003o
ooooo`09ooooo`Co003o00?oooooo`00ool00?l0H_l00?l60000o`03ooooo`000?oooooo00[ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooo003o06_o003o00?o
ooooo`00ooooool02_ooool3o`00o`03ooooool00?oo003o06;o003o1P000?l=ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool03?oooom;o`00o`03ooooool00?oo003o01ko003o3Oooool3
o`00o`05ooooool00?oo003oo`00ooooool0HOl00?l50000o`gooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`0<oooood_o003o00?oooooo`00ool00?l06?l00?l01_oooooo003oo`00ool0
0?ooooooo`00o`gooooo0ol00?l01Ooooooo003oo`00ool00?oooooo067o003o0`000?l00ooooooo
003oooooo`0<ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool03Ooooom:o`00o`03oooo
ool00?oo003o01So003o00Coooooo`00ool00?oo003o4?ooool2o`00o`05ooooool00?oo003oo`00
ooooool0HOl00?l30000o`oooooo0Ol00001ooooo`006oooool2o`0000kooooo3_l00?l00ooooooo
003oo`00o`0io`00o`03ooooool00?oo003o01So003o00Coooooo`00ool00?oo003o4Oooool00ol0
0?ooooooo`00o`02o`00o`03ooooool00?oo003o05Ko003o00?oooooo`00ool00?l01_l00?l30000
o`kooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0=ooooo`ko003o00?oooooo`00ool0
0?l0>Ol00?l00ooooooo003oo`00o`0Ho`00o`04ooooool00?oo003oo`00oa?ooooo0ol00?l00ooo
oooo003oo`00o`1=o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ooooool01_l00?l30000
o`oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooo003o00_o
003o00?oooooo`00ool00?l01_l00?l00ooooooo003oo`00o`0`o`00o`03ooooool00?oo003o01So
003o00Coooooo`00ool00?oo003o4oooool3o`00o`03ooooool00?oo003o04go003o00?oooooo`00
ool00?l01_l00?l00ooooooo003oooooo`06o`00o`<0003o3oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00gooooo00?o003oooooool00?l02ol00?l00ooooooo003oo`00o`06o`00o`03
ooooool00?oo003o033o003o00?oooooo`00ool00?l06?l00?l01?oooooo003oooooool00?lCoooo
o`?o003o00?oooooo`00ool00?l0COl00?l00ooooooo003oo`00o`06o`00o`03ooooool00?oooooo
00Ko003o00?ooooo0000ooooool03oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00oo
oooo3?l00?l00ooooooo003oo`00o`06o`00o`03ooooool00?oo003o033o003o00?oooooo`00ool0
0?l06?l00?l01?oooooo003oooooool00?lCooooo`04o`00oooooooo003oooooodoo003o00?ooooo
o`00ool00?l01_l00?l00ooooooo003oooooo`06o`00o`03ooooo`000?oooooo00oooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0?ooooo`;o003o00?oooooo`00ool00?l01Ol00?l00ooo
oooo003oooooo`08o`00o`03ooooool00?oo003o033o003o00?oooooo`00ool00?l06?l00?l00ooo
oooo003oooooo`0Dooooo`04o`00oooooooo003oooooodoo003o00?oooooo`00ool00?l01_l00?l0
0ooooooo003oooooo`06o`00o`03ooooo`000?oooooo00oooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0?ooooo`;o003o00?oooooo`00ool00?l01Ol00?l00ooooooo003oooooo`08o`00
o`03ooooool00?oo003o033o003o00?oooooo`00ool00?l06?l00?l00ooooooo003oooooo`0Foooo
o`03o`00oooooooo003o04ko003o00?oooooo`00ool00?l01_l00?l00ooooooo003oooooo`06o`00
o`03ooooo`000?oooooo00oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0?ooooo`;o
003o00?oooooo`00ool00?l01Ol00?l00ooooooo003oooooo`08o`00o`03ooooool00?oo003o033o
003o00?oooooo`00ool00?l04Ol00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oooooo01Ko
oooo00?o003oooooool00?l0C_l00?l00ooooooo003oo`00o`06o`00o`03ooooool00?oooooo00Ko
003o4_ooool1o`00007ooooo000Kooooo`;o00004?ooool2o`00o`03ooooool00?oo003o00Go003o
00?oooooo`00ooooool02?l00?l00ooooooo003oo`00o`0`o`00o`03ooooool00?oo003o017o003o
00?oooooo`00ool00?l01?l00?l00ooooooo003oooooo`0Hooooodoo003o00?oooooo`00ool00?l0
1_l00?l00ooooooo003oooooo`05o`00oa;ooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`0Booooo`Oo003o00?oooooo`00ooooool00_l00?l00ooooooo003oo`00o`03o`00o`03ooooool0
0?oo003o033o003o00?oooooo`00ool00?l04Ol00?l00ooooooo003oo`00o`04o`00oa_oooooAOl0
0?l00ooooooo003oo`00o`07o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ooooool01Ol0
0?lCooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04oooool6o`00o`03ooooool00?oo
oooo00;o003o0_ooool4o`00o`03ooooool00?oo003o033o003o00?oooooo`00ool00?l04Ol00?l0
0ooooooo003oooooo`04o`00oacoooooA?l00?l00ooooooo003oo`00o`07o`00o`03ooooool00?oo
003o00Ko003o00?oooooo`00ooooool01?l00?lDooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool04oooool6o`00o`03ooooool00?oooooo00;o003o0_ooool4o`00o`03ooooool00?oo003o
033o003o00?oooooo`00ool00?l04Ol00?l00ooooooo003oooooo`04o`00oagooooo@ol00?l00ooo
oooo003oo`00o`07o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ooooool01?l00?lDoooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool04oooool6o`00o`03ooooool00?oooooo00;o
003o0_ooool4o`00o`03ooooool00?oo003o033o003o00?oooooo`00ool00?l04Ol00?l01?oooooo
003oooooool00?lQooooobco003o00?oooooo`00ool00?l04ol00?l00ooooooo003oo`00o`07o`00
o`03ooooool00?oo003o00Ko003o00?oooooo`00ooooool01?l00?lDooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool04oooool6o`00o`03ooooool00?oooooo00;o003o0_ooool4o`00o`03
ooooool00?oo003o027o003o00?oooooo`00ool00?l03?l00?l00ooooooo003oo`00o`0?o`00o`06
ooooool00?ooooooo`00oooooooo003o8Oooool00ol00?ooooooo`00o`06o`00o`03ooooool00?oo
003o023o003o00?oooooo`00ool00?l04ol00?l00ooooooo003oo`00o`07o`00o`03ooooool00?oo
003o00Ko003o00?oooooo`00ooooool01?l00?lDooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool04oooool6o`00o`03ooooool00?oooooo00;o003o0_ooool4o`00o`03ooooool00?oo003o
027o003o00?oooooo`00ool00?l03?l00?l00ooooooo003oo`00o`0?o`00o`06ooooool00?oooooo
o`00oooooooo003o8Oooool00ol00?ooooooo`00o`06o`00o`03ooooool00?oo003o023o003o00?o
ooooo`00ool00?l04ol00?l00ooooooo003oo`00o`07o`00o`03ooooool00?oo003o00Ko003o00?o
ooooo`00ooooool00_l00?lFooooo`7o00000Oooool001_ooooo0_l0000Dooooo`Ko003o00?ooooo
o`00ooooool00_l00?l2ooooo`Co003o00?oooooo`00ool00?l08Ol00?l00ooooooo003oo`00o`0<
o`00o`03ooooool00?oo003o00oo003o00Koooooo`00oooooooo003oooooool00?lQooooo`03o`00
oooooooo003o00Ko003o00?oooooo`00ool00?l01_l00?l00ooooooo003oo`00o`0Go`00o`03oooo
ool00?oo003o01?o003o00?oooooo`00ool00?l01?l00?l01?oooooo003oo`00ooooool8o`00o`03
ooooool00?oooooo00;o003o5Oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo01Cooooo
1Ol00?l00ooooooo003oooooo`02o`00o`;ooooo1?l00?l00ooooooo003oo`00o`0Qo`00o`03oooo
ool00?oo003o00co003o00?oooooo`00ool00?l03ol00?l01_oooooo003oooooool00?ooooooo`00
ob7ooooo00?o003oooooool00?l00ol00?l01?oooooo003oo`00ooooool8o`00o`03ooooool00?oo
003o01Oo003o00?oooooo`00ool00?l04ol00?l00ooooooo003oo`00o`04o`00o`04ooooool00?oo
ooooooooo`So003o00?oooooo`00ooooool00_l00?lFooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool05Oooool4o`00o`03ooooool00?oooooo00;o003o0_ooool4o`00o`03ooooool00?oo
003o027o003o00?oooooo`00ool00?l03?l00?l00ooooooo003oo`00o`0?o`00o`04ooooool00?oo
ooooo`00ob?ooooo00?o003oooooool00?l00ol00?l01?oooooo003oo`00ooooool8o`00o`03oooo
ool00?oo003o01Oo003o00?oooooo`00ool00?l02Ol00?l00ooooooo003oo`00o`07o`00o`03oooo
ool00?oo003o00Co003o00Coooooo`00oooooooooooo2?l00?l00ooooooo003oooooo`02o`00oaKo
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Eooooo`07o`00oooooooo003oo`00oooo
oooo003oooooo`02o`00o`;ooooo1?l00?l00ooooooo003oo`00o`0Bo`00o`03ooooool00?oo003o
00co003o00?oooooo`00ool00?l03?l00?l00ooooooo003oo`00o`0?o`00o`03ooooool00?oooooo
02Kooooo1?l00?l01?oooooo003oo`00ooooool8o`00o`03ooooool00?oo003o01Oo003o00?ooooo
o`00ool00?l02Ol00?l00ooooooo003oo`00o`07o`00o`03ooooool00?oo003o00Co003o00Cooooo
o`00oooooooooooo0ol00?l00ooooooo003oo`00o`02o`00o`04ooooool00?ooooooo`00oaOooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0Eooooo`07o`00ooooooooooooo`00oooooooo
003oooooo`02o`00o`;ooooo1?l00?l00ooooooo003oo`00o`0Bo`00o`03ooooool00?oo003o00co
003o00?oooooo`00ool00?l03?l00?l00ooooooo003oo`00o`0?o`00o`03ooooool00?oooooo02Ko
oooo1?l00?l01?oooooo003oo`00ooooool8o`00o`03ooooool00?oo003o01Oo003o00?oooooo`00
ool00?l02Ol00?l00ooooooo003oo`00o`07o`00o`03ooooool00?oo003o00Co003o00Coooooo`00
oooooooooooo0ol00?l00ooooooo003oo`00o`02o`00o`04ooooool00?ooooooo`00oaOooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0Hooooo`04o`00oooooooo003oooooo`;o003o0_oo
ool4o`00o`03ooooool00?oo003o01;o003o00?oooooo`00ool00?l03?l00?l00ooooooo003oo`00
o`0<o`00o`03ooooool00?oo003o00[o003o00Coooooo`00ool00?oo003o0_ooool00ol00?oooooo
ooooo`0Uooooo`Co003o00Coooooo`00ool00?oooooo2?l00?l00ooooooo003oo`00o`0Go`00o`03
ooooool00?oo003o00Wo003o00?oooooo`00ool00?l01ol00?l00ooooooo003oo`00o`04o`00o`04
ooooool00?ooooooooooo`?o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oooooo`0Hoooo
o`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo01Sooooo00Co003oooooool00?oooooo0_l00?l2ooooo`Co003o00?oooooo`00
ool00?l04_l00?l00ooooooo003oo`00o`0<o`00o`03ooooool00?oo003o00co003o00?oooooo`00
ool00?l02_l00?l01?oooooo003oo`00ool00?l2ooooo`03o`00oooooooooooo02Gooooo00Go003o
ooooool00?oo003oooooo`02o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ool00?l05ol0
0?l00ooooooo003oo`00o`09o`00o`03ooooool00?oo003o00Oo003o00?oooooo`00ool00?l01?l0
0?l01?oooooo003oooooooooool3o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ooooool0
6?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo01Sooooo00Co003oooooool00?oooooo0_l00?l2oooo
o`Co003o00?oooooo`00ool00?l04_l00?l00ooooooo003oo`00o`0<o`00o`03ooooool00?oo003o
00co003o00?oooooo`00ool00?l02Ol00?l3ooooo`;o003o;?ooool2o`00o`04ooooool00?oo003o
ooooo`So003o00?oooooo`00ool00?l05ol00?l00ooooooo003oo`00o`09o`00o`03ooooool00?oo
003o00Oo003o00?oooooo`00ool00?l00_l00?l01?oooooo003oooooool00?l2ooooo`?o003o0_oo
ool3o`00o`03ooooool00?oooooo01Sooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo00;ooooo0_l0000Iooooo`04o`00oooooooo003oooooo`;o003o
0_ooool4o`00o`03ooooool00?oo003o01;o003o00?oooooo`00ool00?l03?l00?l00ooooooo003o
o`00o`0<o`00o`03ooooool00?oo003o00Wo003o0oooool2o`00obcooooo0_l00?l00ooooooo003o
o`00o`02ooooo`Oo003o00?oooooo`00ool00?l05ol00?l00ooooooo003oo`00o`09o`00o`03oooo
ool00?oo003o00Oo003o00?oooooo`00ool00?l00_l00?l01?oooooo003oooooool00?l2ooooo`?o
003o0_ooool3o`00oa[ooooo0_l00001ooooo`001oooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool01?l00?ooooooo`00ooooool2o`00
o`;ooooo1?l00?l00ooooooo003oo`00o`0Bo`00o`03ooooool00?oo003o00co003o00?oooooo`00
ool00?l03?l00?l00ooooooo003oo`00o`09o`00o`?ooooo0_l00?l/ooooo`;o003o00?oooooo`00
ool00?l00_ooool7o`00o`03ooooool00?oo003o01Oo003o00?oooooo`00ool00?l02Ol00?l00ooo
oooo003oo`00o`07o`00o`03ooooool00?oo003o00;o003o00Coooooo`00oooooooo003o0_ooool3
o`00o`?ooooo00?o003oooooooooool06_ooool1o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Oooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00Co003oooooool00?oo003o0_oo
ool4o`00o`03ooooool00?oo003o01;o003o00?oooooo`00ool00?l03?l00?l00ooooooo003oo`00
o`0<o`00o`03ooooool00?oo003o00Wo003o0oooool00ol00?ooooooooooo`0/ooooo`04o`00oooo
ooooooooo`00o`;ooooo1ol00?l00ooooooo003oo`00o`0Go`00o`03ooooool00?oo003o00Wo003o
00?oooooo`00ool00?l01ol00?l00ooooooo003oo`00o`02o`00o`04ooooool00?ooooooo`00o`;o
oooo0ol00?l3ooooo`03o`00oooooooooooo01[ooooo0Ol00001ooooo`001oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool00ol00?oo
ooooo`00o`03ooooo`Co003o00?oooooo`00ool00?l04_l00?l00ooooooo003oo`00o`0<o`00o`03
ooooool00?oo003o00co003o00?oooooo`00ool00?l02?l00?l4ooooo`03o`00oooooooooooo02co
oooo00Co003ooooooooooooo003o0_ooool3o`00o`05ooooool00?oo003oo`00ooooool05?l00?l0
0ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00Wo003o00?oooooo`00ool00?l00ol00?l0
1Ooooooo003oo`00ool00?oooooo00Co003o00Coooooo`00oooooooo003o0_ooool3o`00o`?ooooo
00?o003oooooooooool06_ooool1o`00007ooooo0008ooooo`;o00002?ooool5o`0000Cooooo00?o
0000ooooooooool06_ooool00ol00?ooooooo`00o`03ooooo`Co003o00?oooooo`00ool00?l00_l0
0?l00ooooooo003oo`00o`0=o`00o`06ooooool00?oo003oooooool00?oooooo2Ol00?l00ooooooo
003oo`00o`0<o`00o`03ooooool00?oo003o00So003o=_ooool00ol00?ooooooooooo`03o`00o`03
ooooool00?oo003o00;ooooo5?l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00Wo
003o00?oooooo`00ool00?l00ol00?l01Ooooooo003oo`00ool00?oooooo00Co003o00Coooooo`00
oooooooo003o0_ooool3o`00ob3ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Loooo
o`04o`00ooooooooooooooooo`Co003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`0=
o`00o`06ooooool00?oo003oooooool00?oooooo1ol00?l00ooooooo003oooooo`0>o`00o`03oooo
ool00?oo003o00;o003o00?oooooo`00ool00?l00ol00?lfooooo`03o`00oooooooooooo00?o003o
00?oooooo`00ool00?l00_oooolDo`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l0
2Ol00?l00ooooooo003oo`00o`03o`00o`05ooooool00?oo003oo`00ooooool01?l00?l01?oooooo
003oooooool00?l2ooooo`03o`00oooooooo003o023ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0Qooooo`?o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`0=o`00o`06
ooooool00?oo003oooooool00?oooooo1ol00?l00ooooooo003oooooo`02o`00o`03ooooool00?oo
003o00Wo003o00?oooooo`00ool00?l00oooool5o`00ocKooooo00?o003oooooooooool00ol00?l0
0ooooooo003oo`00o`02oooooaCo003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`09
o`00o`03ooooool00?oo003o00?o003o00Goooooo`00ool00?oo003oooooo`04o`00o`04ooooool0
0?ooooooo`00o`;ooooo00?o003oooooool00?l08?ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo027ooooo0ol00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00Go003o00?o
ooooo`00ool00?l01Ol00?l01_oooooo003oo`00oooooooo003oooooo`Oo003o00?oooooo`00oooo
ool00_l00?l00ooooooo003oo`00o`09o`00o`03ooooool00?oooooo00?ooooo1Ol00?lfooooo`03
o`00oooooooooooo00?o003o00?oooooo`00ool00?l00_oooolDo`00o`;ooooo0ol00?l00ooooooo
003oo`00o`09o`00o`03ooooool00?oo003o00?o003o00Goooooo`00ool00?oo003oooooo`04o`00
o`04ooooool00?ooooooo`00o`;ooooo00?o003oooooool00?l08?ooool1o`00007ooooo000Koooo
o`;o00008_ooool3o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l01Ol00?l00ooo
oooo003oo`00o`05o`00o`06ooooool00?oo003oooooool00?oooooo1ol00?l00ooooooo003ooooo
o`02o`00o`03ooooool00?oo003o00Wo003o00?oooooo`00ooooool01?ooool4o`00ocWooooo00Co
003oooooool00?oooooo0_l00?l2oooooaCo003o0_ooool3o`00o`03ooooool00?oo003o00Wo003o
00?oooooo`00ool00?l00ol00?l01Ooooooo003oo`00ool00?oooooo00Co003o00Coooooo`00oooo
oooo003o0_ooool00ol00?ooooooo`00o`0Oooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool08Oooool3o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l01Ol00?l00ooooooo
003oo`00o`05o`00o`06ooooool00?oo003oooooool00?oooooo1ol00?l00ooooooo003oooooo`02
o`00o`03ooooool00?oo003o00Wo003o00?oooooo`00ooooool01?ooool4o`00ocWooooo00Co003o
ooooool00?oooooo0_l00?l3ooooo`Wo003o00?oooooo`00ool00?l01ol00?l2ooooo`?o003o00?o
ooooo`00ool00?l02Ol00?l00ooooooo003oo`00o`03o`00o`07ooooool00?oo003oo`00oooooooo
003oooooo`02o`00o`?ooooo00Ko003ooooooooooooo003oooooool00?lPooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool08_ooool2o`00o`03ooooool00?oo003o00;o003o00?oooooo`00
ool00?l01Ol00?l00ooooooo003oo`00o`05o`00o`06ooooool00?oo003oooooool00?oooooo1ol0
0?l00ooooooo003oooooo`02o`00o`03ooooool00?oo003o00Wo003o00?oooooo`00ooooool01?oo
ool4o`00ocWooooo00Co003oooooool00?oooooo0_l00?l3ooooo`Wo003o00?oooooo`00ool00?l0
1ol00?l2ooooo`?o003o00?oooooo`00ool00?l02?l00?l2ooooo`?o003o00?oooooo`00ooooool0
0ol00?l00ooooooo003oooooo`02o`00o`?ooooo00Co003ooooooooooooo003o8_ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo02;ooooo0_l00?l00ooooooo003oo`00o`02o`00o`03oooo
ool00?oo003o00Go003o00?oooooo`00ool00?l01Ol00?l01_oooooo003oo`00oooooooo003ooooo
o`Oo003o00?oooooo`00ooooool00_l00?l00ooooooo003oo`00o`09o`00o`03ooooool00?oooooo
00Gooooo0ol00?liooooo`04o`00oooooooo003oooooo`;o003o0oooool9o`00o`04ooooool00?oo
003oooooo`Ko003o0_ooool3o`00o`03ooooool00?oo003o00So003o0_ooool3o`00o`03ooooool0
0?oooooo00?o003o00?oooooo`00ooooool00_l00?l3ooooo`04o`00ooooooooooooo`00ob;ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0Rooooo`;o003o0_ooool3o`00o`03ooooool0
0?oo003o00Go003o00?oooooo`00ool00?l01Ol00?l01_oooooo003oo`00oooooooo003oooooo`Oo
003o00?oooooo`00ooooool00_l00?l00ooooooo003oo`00o`09o`00o`03ooooool00?oooooo00Ko
oooo0_l00?liooooo`04o`00oooooooo003oooooo`;o003o0oooool9o`00o`04ooooool00?oo003o
ooooo`Ko003o0_ooool3o`00o`03ooooool00?oo003o00So003o0_ooool3o`00o`03ooooool00?oo
oooo00?o003o00Goooooo`00ooooooooooooo`00o`03ooooo`03o`00oooooooooooo02?ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0Rooooo`;o003o0_ooool3o`00o`05ooooool00?oo
003oo`00ooooool00ol00?l00ooooooo003oo`00o`05o`00o`08ooooool00?oo003oooooool00?oo
ooooo`00ooooool5o`00o`03ooooool00?oooooo00;o003o0oooool9o`00o`03ooooool00?oooooo
00Kooooo0_l00?lkooooo`04o`00oooooooo003oo`00o`?ooooo1_l00?l01?oooooo003oo`00oooo
ool2o`00o`03ooooool00?oo003o00Co003o0_ooool3o`00o`03ooooool00?oo003o00So003o0_oo
ool3o`00o`03ooooool00?oooooo00?o003o00Goooooo`00ooooooooooooo`00o`03ooooo`03o`00
oooooooooooo02?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Sooooo`03o`00oooo
oooooooo00?o003o00Goooooo`00ool00?oo003oooooo`03o`00o`03ooooool00?oo003o00Go003o
00Soooooo`00ool00?ooooooo`00oooooooo003oooooo`Go003o00?oooooo`00ooooool00_l00?l4
ooooo`So003o00?oooooo`00ooooool01_ooool00ol00?ooooooooooo`0jooooo`04o`00oooooooo
003oo`00o`?ooooo1_l00?l01?oooooo003oo`00ooooool2o`00o`03ooooool00?oo003o00Co003o
0_ooool3o`00o`03ooooool00?oo003o00So003o0_ooool3o`00o`03ooooool00?oooooo00?o003o
00Goooooo`00ooooooooooooo`00o`03ooooo`03o`00oooooooooooo02?ooooo0Ol00001ooooo`00
6oooool2o`0002Cooooo00?o003oooooooooool00ol00?l01Ooooooo003oo`00ool00?oooooo00?o
003o00?oooooo`00ooooool01Ol00?l02?oooooo003oo`00oooooooo003oooooool00?oooooo1Ol0
0?l00ooooooo003oooooo`02o`00o`Cooooo2?l00?l00ooooooo003oooooo`13ooooo`04o`00oooo
oooo003oo`00o`?ooooo0ol00?l01?oooooo003oo`00ooooool2o`00o`04ooooool00?oo003ooooo
o`Ko003o0_ooool3o`00o`03ooooool00?oo003o00So003o0_ooool3o`00o`03ooooool00?oooooo
00?o003o00Goooooo`00ooooooooooooo`00o`0Xooooo`;o00000Oooool001_ooooo00?o0000oooo
ooooool08oooool00ol00?ooooooooooo`03o`00o`05ooooool00?oo003oo`00ooooool00ol00?l0
0ooooooo003oooooo`05o`00o`08ooooool00?oo003oooooool00?ooooooo`00ooooool5o`00o`03
ooooool00?oooooo00;o003o1?ooool8o`00o`03ooooool00?oooooo04?ooooo00Co003oooooool0
0?oo003o0oooool3o`00o`04ooooool00?oo003oooooo`;o003o00Coooooo`00ool00?oooooo1_l0
0?l2ooooo`?o003o00?oooooo`00ool00?l02?l00?l2ooooo`?o003o00?oooooo`00ooooool00ol0
0?l01Ooooooo003ooooooooooooo003o02Wooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`0Sooooo`03o`00oooooooooooo00?o003o00Goooooo`00ool00?oo003oooooo`03o`00o`05oooo
ool00?ooooooo`00ooooool00ol00?l02?oooooo003oo`00oooooooo003oooooool00?oooooo1Ol0
0?l00ooooooo003oooooo`02o`00o`Cooooo2?l00?l00ooooooo003oooooo`15ooooo`;o003o0ooo
ool3o`00o`04ooooool00?oo003oooooo`;o003o00Coooooo`00ool00?oooooo1_l00?l2ooooo`?o
003o00?oooooo`00ool00?l02?l00?l2ooooo`?o003o00?oooooo`00ooooool00ol00?l01Ooooooo
003ooooooooooooo003o02Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Sooooo`03
o`00oooooooooooo00;o003o0_ooool2o`00o`;ooooo0ol00?l01Ooooooo003oooooool00?oooooo
00?o003o00Soooooo`00ool00?ooooooo`00oooooooo003oooooo`Go003o00Coooooo`00oooooooo
003o1Oooool8o`00o`03ooooool00?oooooo04Kooooo00Co003ooooooooooooooooo0ol00?l01?oo
oooo003oo`00ooooool2o`00o`04ooooool00?oo003oooooo`Ko003o0_ooool3o`00o`03ooooool0
0?oo003o00So003o0oooool2o`00o`03ooooool00?oooooo00?o003o00Goooooo`00oooooooooooo
o`00o`0Yooooo`7o00000Oooool001_ooooo00?o0000ooooooooool09_ooool2o`00o`;ooooo0_l0
0?l2ooooo`?o003o00Goooooo`00oooooooo003oooooo`03o`00o`08ooooool00?oo003oooooool0
0?ooooooo`00ooooool5o`00o`04ooooool00?ooooooo`00o`Gooooo2?l00?l00ooooooo003ooooo
o`1;ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l01?oooooo003oo`00ooooool6o`00o`;o
oooo0ol00?l00ooooooo003oo`00o`08o`00o`?ooooo0_l00?l00ooooooo003oooooo`03o`00o`05
ooooool00?ooooooooooool00?l0:Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02Ko
oooo0_l00?l2ooooo`;o003o0_ooool3o`00o`05ooooool00?ooooooo`00ooooool00ol00?l02?oo
oooo003oo`00oooooooo003oooooool00?oooooo0_l00?l01ooooooo003oo`00oooooooo003ooooo
ool00?l01Oooool2o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ooooool0Boooool2o`00
o`04ooooool00?oo003oooooo`;o003o00Coooooo`00ool00?oooooo1_l00?l2ooooo`?o003o00?o
ooooo`00ool00?l02?l00?l3ooooo`;o003o00?oooooo`00ooooool00ol00?l01Ooooooo003ooooo
oooooooo003o02Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Vooooo`04o`00oooo
ooooooooooooo`;o003o0_ooool3o`00o`05ooooool00?ooooooo`00ooooool00ol00?l02?oooooo
003oo`00oooooooo003oooooool00?oooooo0_l00?l01ooooooo003oo`00oooooooo003oooooool0
0?l01Oooool01?l00?ooooooooooooooool4o`00o`03ooooool00?oooooo04_ooooo0_l00?l01?oo
oooo003oooooooooool2o`00o`04ooooool00?oo003oooooo`Ko003o0_ooool3o`00o`03ooooool0
0?oo003o00So003o0oooool2o`00o`03ooooool00?oooooo00?o003o00Goooooo`00oooooooooooo
o`00o`0Yooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0:_ooool2o`00o`;ooooo0ol0
0?l01Ooooooo003oooooool00?oooooo00?o003o00Soooooo`00ool00?ooooooo`00oooooooo003o
ooooo`;o003o00Ooooooo`00ool00?ooooooo`00oooooooo003o00Gooooo00Co003ooooooooooooo
oooo1?l00?l00ooooooo003oooooo`1;ooooo`;o003o00?oooooo`00ooooool00_ooool01Ol00?oo
ooooo`00ool00?oooooo00Ko003o0_ooool3o`00o`03ooooool00?oo003o00So003o0oooool2o`00
o`?ooooo0ol00?l00ooooooo003oooooo`0[ooooo`7o00000Oooool001_ooooo0_l0000[ooooo`;o
003o0_ooool02?l00?ooooooo`00oooooooo003oooooool00?oooooo0ol00?l02?oooooo003oo`00
oooooooo003oooooool00?oooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l01Oooool0
1?l00?ooooooooooooooool4o`00o`03ooooool00?oooooo04_ooooo0_l00?l00ooooooo003ooooo
o`02ooooo`05o`00oooooooo003oo`00ooooool01_l00?l2ooooo`?o003o00?oooooo`00ool00?l0
2?l00?l4ooooo`04o`00ooooooooooooooooo`?o003o00?oooooo`00ooooool0:_ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo02_ooooo00_o003ooooooooooooo003oooooool00?oooooo
o`00oooooooo003oooooo`03o`00o`08ooooool00?oo003oooooool00?ooooooo`00ooooool2o`00
o`;ooooo00Go003oooooool00?ooooooo`00o`09ooooo`06o`00oooooooo003oo`00oooooooo003o
C?ooool2o`00o`Gooooo00Go003oooooool00?oo003oooooo`06o`00o`;ooooo00Co003oooooool0
0?oooooo2_l00?l4ooooo`04o`00ooooooooooooooooo`?o003o00?oooooo`00ooooool0:oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo02_ooooo00_o003ooooooooooooo003oooooool0
0?ooooooo`00oooooooo003oooooo`03o`00o`08ooooool00?oo003oooooool00?ooooooo`00oooo
ool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`09ooooo`06o`00oooooooo003oo`00oooo
oooo003oCOooool00ol00?ooooooooooo`03ooooo`05o`00oooooooo003oo`00ooooool01Ol00?l3
ooooo`04o`00oooooooo003oooooo`[o003o1?ooool02Ol00?oooooooooooooooooo003oooooool0
0?ooooooo`00o`0/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0:oooool02ol00?oo
ooooooooool00?ooooooo`00oooooooo003oooooool00?oooooo00?o003o00Soooooo`00ool00?oo
ooooo`00oooooooo003oooooo`;o003o0_ooool01Ol00?ooooooo`00oooooooo003o00Wooooo00Co
003oooooool00?oo003oCoooool00ol00?ooooooooooo`05ooooo`;o003o00?oooooo`00ool00?l0
0ol00?l3ooooo`03o`00oooooooo003o00;ooooo2Ol00?l4ooooo`09o`00ooooooooooooooooool0
0?ooooooo`00oooooooo003o02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0[oooo
o`0:o`00ooooooooooooo`00oooooooo003oooooool00?ooooooo`00o`;ooooo0_l00?l02?oooooo
003oo`00oooooooo003oooooool00?oooooo0_l00?l2ooooo`05o`00oooooooo003oooooool00?l0
2Oooool01?l00?ooooooo`00ool00?mGooooo`;o003o00?oooooo`00ool00?l00_l00?l6ooooo`03
o`00oooooooooooo00Wo003o1?ooool01ol00?oooooooooooooooooo003oooooool00?l0;_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo02kooooo00?o003oooooool00?l00oooool00ol0
0?ooooooooooo`02o`00o`08ooooool00?oo003oooooool00?ooooooo`00ooooool2o`00o`;ooooo
00Go003oooooool00?ooooooo`00o`09ooooo`04o`00oooooooo003oo`00oeOooooo0_l00?l00ooo
oooo003oo`00o`02o`00o`Kooooo00?o003oooooooooool02Ol00?l4ooooo`05o`00oooooooooooo
ooooool00?l0<?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02kooooo00?o003ooooo
ool00?l00oooool00ol00?ooooooooooo`02o`00o`08ooooool00?oo003oooooool00?ooooooo`00
ooooool2o`00o`;ooooo00Go003oooooool00?ooooooo`00o`09ooooo`03o`00oooooooooooo05So
oooo0_l00?l00ooooooo003oo`00o`02o`00o`Kooooo00?o003oooooooooool01?l00?l00ooooooo
003oo`00o`02o`00o`Cooooo00Go003oooooooooooooooooo`00o`0`ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0;_ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o
003o00Soooooo`00ool00?ooooooo`00oooooooo003oooooo`;o003o0_ooool01Ol00?oooooooooo
oooooooo003o00Wooooo00?o003oooooooooool0F?ooool2o`00o`04ooooool00?oo003oo`00o`Oo
oooo00?o003oooooooooool01?l00?l00ooooooo003oooooo`02o`00o`Cooooo00Go003ooooooooo
ooooooooo`00o`0`ooooo`7o00000Oooool001_ooooo0_l0000aooooo`05o`00oooooooooooooooo
ool00?l00_ooool2o`00o`03ooooool00?oo003o00?ooooo00Co003oooooool00?oo003o0_ooool0
1Ol00?oooooooooooooooooo003o06Cooooo0_l00?l01?oooooo003oo`00ool00?l7ooooo`03o`00
oooooooooooo00Co003o00?oooooo`00ooooool00_l00?l4ooooo`03o`00oooooooooooo037ooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00;o003o00?o
ooooo`00ooooool00oooool01?l00?ooooooo`00ool00?l2ooooo`05o`00ooooooooooooooooool0
0?l0IOooool00ol00?ooooooo`00o`02o`00o`Oooooo00Go003ooooooooooooo003oooooo`02o`00
o`03ooooool00?oooooo00;o003o1?ooool00ol00?ooooooooooo`0booooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0=?ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oooooo00?o
oooo00Co003oooooool00?oo003o0_ooool01Ol00?oooooooooooooooooo003o06Gooooo00?o003o
ooooooooool00_l00?l7ooooo`05o`00ooooooooooooo`00ooooool00_l00?l00ooooooo003ooooo
o`02o`00o`Cooooo00?o003oooooooooool0<_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo03Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00Cooooo00Co003oooooool00?oo
003o0_ooool01Ol00?oooooooooooooooooo003o06Gooooo00?o003oooooooooool00_l00?l7oooo
o`03o`00oooooooooooo00;ooooo00Go003ooooooooooooo003oooooo`02o`00ocWooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0hooooo`03o`00oooooooo003o00Cooooo00Co003ooooo
oooooooo003o0_ooool01Ol00?oooooooooooooooooo003o06Sooooo00?o003oooooooooool02ooo
ool01Ol00?ooooooooooool00?oooooo00;o003o>Oooool1o`00007ooooo000Cooooo`?o00001Ooo
ool00ol0003oooooooooo`0hooooo`03o`00oooooooo003o00Oooooo00Co003ooooooooooooo003o
K?ooool00ol00?ooooooooooo`0>ooooo`04o`00oooooooo003oo`00ocWooooo0Ol00001ooooo`00
5?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0
^oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l00013ooooo`03o`00oooo
oooooooo0;[ooooo0_l00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo0Oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`004oooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00007ooooo000Dooooo`03o`00
0?oooooooooo00Coooooool00005o`00007ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.270385, -1.23063, \
0.00808853, 0.0130644}}],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](
        t) == \(sin(\[Pi]\ t)\)\ \(sin(1000\ \[Pi]\ t)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Play[s3, {t, 0, 2}];\)\)], "Input",
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound
8080808080808080807F7F7F7F7F7F8080808081818180807F7F7F7E7E7E7F7F808081818181
8180807F7E7E7D7E7E7F8080818282828281807F7E7D7D7D7D7E7F80818283838382817F7E7D
7C7C7C7D7E8081838484848381807E7D7C7B7B7C7D7F81838485858482817F7D7B7A7A7B7C7E
80828485868584827F7D7B7A797A7B7D7F82848686868583807E7B7A79797A7C7E8184868787
8684827F7C7A7878797B7D8083868788878683807D7A787777797C7F82858889888784817E7A
787676787A7D81858789898886837F7B78767576797C808487898A8A8884807C79767575777A
7E8286898B8B8986827E7A76747475787C8185898B8C8B88847F7B77747374767A7F84888B8D
8C8A86817C7874727275787D82878B8D8D8C88847E7975727173767B80868A8D8E8D8A86807B
7672717174787E84898D8F8F8C88837D7773707072767C82888C8F908E8A857F7974706F7074
797F868B8F91908D88817B75716E6F72767D838A8E91918F8A847D77716E6D6F747A81888D91
92918D878079736E6D6E71777E858C9193938F8A837B746F6C6C6F747B838A909394928D867E
77706C6B6D717880888E9395938F898179726D6A6B6F757D858C929595928C847C746E6A6A6C
7279828A919596948F887F776F6A696A6F767E878F949796928B837A716B68686C727B848D93
9798958F867D746D68676A6F77818A92979997928A81776F6966676C747D878F969999958E84
7B716A6666697079838D94999A9791887E746C6765676C757F8992989B9A958C82786E686465
69717B868F979B9B9890867C71696463666D77828C959B9D9A948B80756C6562646A727D8992
9A9D9C978F84796E666262666E79848F989D9E9A93897D72696361646A74808C969C9F9D978D
82766B64606167707B87929B9F9F9A92867A6F66605F636B76838F999FA09D968B7F7368615E
6167727E8B969EA1A09A9084776B635E5E646D7986929CA1A29D95897C6F655F5D606874818E
99A0A3A0998E817468605C5E646F7C89969FA3A39D9386786C625C5C616A7684929CA3A4A098
8C7E70655D5B5D65717F8D99A2A5A39C918375685F5A5B616C798895A0A5A5A096897A6C615A
595E677482919DA4A7A39B8E8071645C585A626E7D8C99A3A7A69F948676685E58585E697786
95A0A7A8A3998C7C6D6159575A647180909DA6A9A69E928273655B56585F6B7A8A98A3A9A9A3
978878695D56565B65748494A0A8AAA69D8F7E6E61585457606E7E8E9CA7ABA9A2958574655A
54555C68778898A4ABACA69B8B7A6A5D55535862718292A0AAADA9A0928170615752545D6A7B
8C9CA7ADACA5988876665952525864748697A4ACAEA99E8F7D6C5D5451545E6D7F91A0ABAFAD
A4958472625650515967788A9BA8AFAFA89C8B796759514F5561718395A4AEB1ACA292806D5E
534E515B6A7C8F9FABB1B0A799877463564F4F566375889AA8B0B2AC9F8E7B6959504D525D6D
8093A4AFB3B0A596836F5E524C4E5766798D9EACB3B2AB9D8A7664554D4C525F718598A8B2B4
AFA3927E6A5A4F4B4E596A7D91A3AFB5B3A99986725F524B4B5462758A9DACB4B5AEA08E7965
564C494F5C6E8296A7B3B6B2A796816D5B4E494B56667A8FA2B0B7B6AD9D897461514949505F
72879BACB6B8B2A4927C67564B474C586A7F94A7B3B9B6AB9A856F5C4E47485262778CA1B0B8
B8B0A18D77625248464D5B6E849AABB7BAB5A8957F6A574A454854667C92A6B4BAB9AE9E8872
5D4D45454E5E738A9FB0BABBB4A5917A6452474449576A8197AAB7BCB8AC99836C584A434550
62788FA4B4BCBCB2A28C755F4E44434A5A6F869DAFBBBDB7A9957E665346414653667D95A9B8
BEBBB09E876F594941424C5E748CA2B4BDBEB6A69078614E434047566B839AAEBBC0BBAD9981
6954463F434F627992A8B8C0BEB4A28B725B4A404048597089A0B3BFC1BAAA947B634F423E43
52667F98ADBCC2BEB19D856C56453E3F4B5D758FA6B8C1C1B8A68F755D4A3F3D45556C859EB2
BFC3BDAE997F6650423C404D627B95ACBCC4C1B6A2896F58463C3D4759718BA4B7C2C4BCAB93
79604B3E3B415167819BB1C0C5C1B39D836952413A3D495E7792AABCC5C4BAA68E735A463B3A
43556D87A1B6C3C6BFAF987D634C3E383E4C637D98AFC0C7C4B7A2886C5442393A4559728EA7
BBC6C7BDAB92775C473A373F5068839EB5C4C9C3B39C81664E3D373A485E7995ADC0C9C7BBA6
8C705642373741546E8AA5BAC7CAC1B0977B5F483A353B4C637F9BB3C4CBC6B8A18669503E35
3744597491ABBFCACABFAB9174594336343D506986A2B9C8CCC5B49C7F624A3A3338475E7B98
B1C4CCCABCA68A6D523E343440546F8DA8BECBCCC3B096785C443632394B64829FB7C8CEC9B9
A084664C3A3235435A7694AFC3CDCDC0AB8F71553F33313C506B89A5BDCBCFC7B59A7D5F4636
3036465F7D9BB5C8D0CCBDA5886A4E3A30323E557190ACC2CECFC5B094755841322F384B6684
A2BBCCD1CBB9A0816348362E32425A7897B3C7D1CFC2AA8D6E513B2F2F3A506C8CA9C1CFD2C9
B5997A5B42322D3446607F9FB9CBD3CEBEA586674B362D2F3D557393B0C6D2D2C6B09272543D
2E2C364B6787A6BFCFD4CCBA9E7F5F44322B30415B7A9BB7CBD4D1C2AA8B6B4D372C2C39506E
8FADC5D3D4CAB59877583E2E2A32466282A2BDCFD6D0BEA4846347322A2D3D567596B4CAD5D4
C7AF906F50392B2A354B698AAAC3D3D7CEBA9D7C5B402E282F415C7D9EBBCFD7D3C3A9896749
33282A38517092B1C9D6D7CBB49674543A2B2731466385A6C1D3D9D2BFA28160432F262B3C57
789AB8CED9D6C8AE8E6C4D352727344B6B8DADC7D7D9CFB99B79583C2B252D415E80A2BFD3DA
D5C3A88664452F252837527295B5CDDAD9CCB494715036272530466588A9C5D7DCD3BFA17E5C
3F2B23293C587A9DBCD2DCD8C8AD8C6949312425334C6D90B1CBDADCD0B99976543827232C41
5F83A5C3D6DDD7C4A68460422C222637537598B9D1DDDBCDB3926E4C3224222F47678BADC9DA
DED4BE9F7B583B2721283C5A7DA1C0D6DFDAC8AC8965452D2123324D6F93B5CFDDDED1B89773
503424202A416186A9C7DAE0D8C3A5815D3E281F243754779CBDD4E0DDCDB28F6A482E20202E
47698EB1CDDEE0D5BE9D785437241E273C5B80A5C4D9E2DCC8AB876141291E21324E7297B9D3
E0E0D2B7956F4C30201E2A426389ADCBDDE2D9C3A37E593A241C2337557AA0C1D8E3DFCDB08C
67442B1D1E2D486C92B5D1E1E3D6BD9B755033201C263D5D83A8C8DDE4DDC8A9845E3D251B20
3250749BBDD7E4E2D2B6926C482D1D1C2943668CB1CEE1E5DAC2A17B5536211A2237577DA3C5
DCE5E0CDAF8A6340271A1D2D4A6E95B9D5E4E5D7BC99724D2F1D1A253D5F86ACCCE0E7DEC8A7
815A3922191E3251779EC1DAE6E4D2B5906844291A1A29446890B5D2E4E7DBC29F7751321E18
21385980A7C9DFE8E2CDAD875F3C23181B2D4B7199BDD8E7E6D7BB966E492B1A18243E628AB0
D0E3E9DFC7A57D56351E161D33537AA2C5DEE9E5D2B38D654025171828456B93B9D6E7E9DBC1
9C744D2E1A1620395B84ABCCE3EAE3CDAB845B3820151A2D4D749DC1DCEAE8D7B9936A452717
16243F648DB4D3E7EBDFC6A37A52311B141C33557DA6C9E1EBE6D2B18A613C22141729476D97
BDDAEAEADBBF9A70492A1714203A5E87AFD0E6ECE3CCA98058351C13192E4F77A0C5E0ECE9D7
B890674124141424416791B8D7EAEDE0C5A0774E2D18121C345781AACDE5EEE7D1AF875D381E
12162949709BC1DDECECDBBE976D452614121F3B608BB3D4E9EEE4CBA77D54311911182F517A
A4C9E3EFEAD6B68D633D20121324436A94BCDBECEEE0C49D734A2915101B355A84AED1E8F0E8
D0AD8359351B1015294B749EC5E1EFEDDBBC946941231211203D638EB7D8ECF0E4C9A479502D
160F1830537EA8CDE6F1EBD5B48A5F391D0F1225446D98C0DEEFEFE0C29B6F4626120F1B375D
88B2D4EBF2E8CFAB805531180E142A4D77A2C8E4F1EEDBBA91653D1F0F0F203E6692BBDBEFF2
E4C8A1764C29130D17315681ACD1E9F3EBD5B1875B351A0D112547709CC4E2F1F1DFC0986C42
22100D1B385F8BB6D8EEF3E8CEA87C512D150C142B4F7AA6CCE7F3EFDAB88E613A1C0D0E2040
6996BFDFF1F3E4C69E724826100B17325985B0D4ECF4ECD3AF835731160B10264973A0C8E5F4
F1DFBE94683F1F0D0C1C3A628FBADCF0F5E8CCA5794D29120A142D527EAAD0EAF5EFD9B58A5D
36190B0E21426D9AC3E2F3F4E3C49B6E44220E0A18345C88B4D8EFF6ECD2AC80532D13091027
4B77A4CCE8F6F2DEBC91643B1B0B0B1C3C6693BDDFF3F6E8CAA27549260F09142E5582AED4ED
F7EFD7B3875A3216090D2245709DC7E5F6F5E3C2986A401F0B0918365F8CB8DBF2F7ECD0A97C
4F2A110810294E7BA8CFEBF7F2DDB98E603718090B1D3E6997C1E2F5F7E7C89F7146220C0714
305885B2D7F0F8EFD6B083562E13070D234773A1CAE9F8F5E2C095673C1B090819386290BCDF
F4F8EBCEA6784B260E06102A517EACD3EEF9F2DBB78A5C3315070A1E416C9BC5E6F7F7E6C69C
6D421F0A0714325B89B6DBF3FAEFD4AD7F522B10060D254A77A5CEECF9F5E0BD916338180708
1A3A6594C0E2F6F9EACCA37448230C05112C5482B0D6F1FAF2DAB486582F12050A2043709FC9
E9F9F8E5C4986A3E1C080615345E8DBADEF5FBEED2AA7C4E270D040D274D7BA9D2EEFBF5DFBB
8E5F351506071B3D6998C3E5F8FAEACAA07144200904112E5786B4DAF3FCF2D8B183542C1004
0A214674A3CDEBFBF8E4C195663A19060516376191BEE1F7FBEED0A7784A240B030E29507FAD
D5F1FCF5DDB88A5B311304071C406C9CC7E8FAFAE8C79C6D401C070412315A8AB7DDF5FCF1D6
AE7F50280D030A234977A7D0EEFCF8E2BE91623616050518396595C1E4F9FCEDCEA374462109
030E2B5382B1D9F3FDF5DBB586572D1003081E4270A0CBEBFCFAE7C599693C19060313335E8E
BBE0F7FDF0D4AA7B4C250B020B254C7BAAD4F1FDF8E0BB8E5E33130305193C6999C5E7FBFCEB
CBA070421D07020F2D5786B5DCF5FEF4D9B182532A0E0208204674A4CEEEFDFAE5C295653917
040315366191BFE3F9FDEFD1A777492209010C27507FAED7F3FEF7DFB88A5A2F1102061B3F6C
9DC9EAFCFCEAC89C6C3F1B050211305A8AB9DFF7FEF3D7AE7F4F270B0109224978A7D2F0FEFA
E4BF91613514030316386595C3E6FBFEEECEA373451F07010D2A5383B2DAF5FFF6DCB586562C
0E01061D4270A0CCEDFDFCE8C599683B18040212325E8EBCE2F9FFF2D4AB7B4B2409000A244C
7BABD5F2FFF9E1BC8D5D32120104183B6999C6E9FCFDECCCA06F411C05010E2C5787B6DDF7FF
F5DAB28252290C00071F4574A4CFEFFEFBE6C295643715030214356192C0E5FBFFF0D2A77748
2108000B274F7FAFD8F4FFF8DFB889592E0F01041A3F6D9DCAEBFDFDEBC99C6B3E190401102F
5A8BBAE0F9FFF4D7AE7E4E260A0008214978A8D3F1FFFBE4BF91603413020216386596C4E7FC
FFEFCFA373441E06000C295383B3DBF6FFF7DDB586552B0D00051C4270A1CDEEFEFDE9C69867
3A17030112325E8FBDE3FAFFF2D5AA7A4B23090009244C7CACD6F3FFFAE2BC8D5C3111010318
3B699AC7EAFDFEEDCCA06F401B05000E2C5787B7DEF8FFF6DAB18252280B00061F4574A5D0F0
FFFCE6C294643715020214356292C1E5FBFFF1D2A776472007000B275080B0D9F5FFF8DFB889
592E0F00041A3F6D9ECAECFEFDEBC99C6B3D190400102F5A8BBAE1F9FFF4D7AE7E4E250A0008
214978A9D3F2FFFBE4BF91603413010216386696C4E8FCFFEFCFA372441E06000C2A5384B3DB
F6FFF7DDB585552B0D00051D4271A1CDEEFEFCE8C598673A17030112325E8FBDE3FAFFF2D4AA
7A4A23080009244C7CACD6F3FFF9E1BB8D5C31110103183C699AC7EAFDFEECCB9F6E401B0500
0E2D5788B7DEF8FFF5DAB18151280B00071F4675A5D0F0FFFBE6C294633715020214366293C1
E5FBFFF0D1A676472007000B275080B0D9F5FFF8DFB889582E0F01051B3F6D9ECAECFDFDEAC8
9B6B3D19040110305B8BBAE0F9FFF3D7AD7D4E250A0008224979A9D3F1FFFAE3BE9060341302
0317396697C4E7FCFEEECEA272441E06010D2A5484B3DBF6FFF6DCB485552B0E01061D4371A2
CDEDFEFCE8C497673A17040213335F8FBDE3F9FEF1D3A9794A2309010A254D7DACD6F2FFF8E0
BB8C5C31110205193D6A9AC7E9FCFDEBCA9F6E401C06010F2E5888B7DDF7FFF4D9B08151280C
0108204775A5D0EFFEFAE5C193633715030315376393C0E4FAFDEFD0A676472108010C285180
B0D8F4FEF6DDB788582E1002061C406E9ECAEBFCFBE9C79B6A3D1A050212315C8CBAE0F7FEF2
D5AC7D4E260B020A244A79A9D2F0FDF8E2BD8F6034140305183A6797C3E6FAFCECCDA272441F
08020F2C5584B3DAF4FDF4DAB384552C0F02081F4472A2CCECFCFAE6C397673B180504143560
8FBDE1F8FDEFD2A8794B240B020C274E7DACD5F1FDF6DFB98C5C321304061B3E6B9AC6E8FAFB
EAC99E6E411D0703112F5988B6DCF5FDF2D7AF80522A0E030A224876A5CFEDFCF8E3BF936338
17050517386493C0E3F8FBEDCEA57548220A030F2A5281AFD7F2FCF4DCB688592F1204081E42
6F9EC9E9FAF9E7C59A6A3E1C070514335D8CB9DEF5FBF0D3AB7D4F280D040C254C7AA8D1EEFB
F6E0BC8F60351606071A3C6897C2E4F8FAEACBA17245200A05112E5685B2D9F2FBF2D8B28455
2D11050A214672A1CBEAFAF7E4C296673C1A08061736618FBCE0F5FAEDD0A7794C260D050F29
507DABD3EFFAF4DDB88B5C331506091D406B9AC5E6F8F8E7C79D6E421F0A0614315A88B5DAF2
FAEFD5AE80522B10060D254976A5CDEBF9F5E0BE9264391908081A3A6593BFE1F5F8EACCA375
49240D06112C5481AFD5EFF9F1D9B487593114070B21446F9DC7E7F7F6E4C3996B401E0A0817
355E8CB8DCF2F8EDD1AA7C4F2910070F284D7AA8CFEBF8F3DDBA8E603718090A1D3E6996C1E2
F5F7E7C99F7246230D0814305885B1D7EFF8EFD6B083562F14080E244773A1C9E7F6F4E1BF95
673D1D0B0A1A39628FBBDDF2F7EACDA6794D281008122C517EABD1ECF7F0DAB68A5D35180A0D
20426C9AC3E3F4F5E4C59B6E44220D0A17345B88B4D8EFF6ECD2AC80532D140910274B77A4CB
E8F5F2DDBC91643B1C0C0C1D3D6693BDDEF2F5E7CAA2754A27100A152F5581ADD3ECF5EED6B2
875A33170B0F2446709DC5E4F3F2E1C1986B41210E0C1A385F8CB7D9EFF4E9CEA87C512C140B
132B4F7BA7CDE8F4EFDAB88D61391C0D0E20406A96BFDFF1F3E3C69E724826110C18335985B0
D4ECF4EBD2AE835732170C12274A74A0C7E4F2F0DDBD94683F200F0E1E3C638FB9DAEEF2E6CA
A4794E2B140D162F537EA9CEE8F2ECD6B48A5E371B0E1124446D99C1E0F0F0E0C29A6F452511
0E1B375D88B2D5EBF2E8CFAA7F5530170E152B4E78A3C9E4F1EDDAB990653D201010213F6792
BBDBEDF0E3C7A0754C2A140F19335782ACD0E8F1E9D2B0865B361B0F142848719CC3E0EFEEDD
BE966B432412101F3B618CB5D6EBF0E5CBA67C522F1810182F527BA5CAE4EFEAD6B58C623C1F
111325436B95BDDBECEEDFC39C724A2915111C365B85AED1E7EFE6CFAC8259351C11162B4C75
9FC4E0EDEBD9BA936842241413223F658FB7D6EAEDE1C7A279502E18121B33567FA8CBE4EDE7
D2B1895F3A20131628476F98BEDBEBEBDCBF996F48291613203A5F88B0D1E6EDE3CBA87F5634
1C131A2F5078A1C6E0ECE8D5B68F664024151626436992B8D7E8EBDEC39E754E2E19141E3659
82AACCE3EBE4CEAD855D392015192C4B729BC0DBEAE8D8BB956C46281816233E638BB2D2E5EA
E0C7A47C54331D151D33547CA4C7DFEAE5D1B28B633F24171829476C95BAD7E7E8DABF9B724C
2D1A16223A5D85ACCDE2E9E1CAA9825A3820171C304F769EC1DBE8E5D4B79169452819192742
678EB4D2E4E8DCC3A07952321E172037587FA6C8DEE8E2CEAE88613E24181B2D4B7097BBD7E5
E5D7BB97704A2D1C19253E6188AECDE1E7DDC7A57F583821191F345379A0C2DBE6E2D0B38E67
43291B1B2B466A91B6D2E3E5D8BF9C7650321F1A243B5C82A8C8DEE5DECAAA855E3D251B1F31
4F739ABDD6E4E2D3B7936D492D1D1C2942658BB0CDE0E4DAC3A27C5637221B2338577CA2C3DA
E4DFCDAF8A6442291D1F2F4A6E94B7D2E1E2D5BB99734F32201D273F6085AAC8DCE3DBC6A681
5C3C261D223552779CBDD6E2DFCFB3906A482E1F1F2D46688EB1CDDEE1D6BF9E795537241E26
3C5B7FA4C3D9E1DCC9AB8762422A1F22324E7196B8D1DFDFD1B795704E3222202B436388ABC8
DBE0D7C2A37E5A3C271F2639567A9EBED5DFDCCBAF8D68472E2122304A6C90B2CDDCDED2BB9A
76533725212A405F82A6C4D7DFD8C5A78460412B212536527498B9D1DDDCCDB3926E4D332423
2F47678BADC8D9DDD4BE9F7C593C2922293D5A7DA0BED4DDD8C7AB8966462F2425344E6F93B3
CCDADBCFB79773523727242E446285A7C4D6DCD4C1A3815F412C24293A56789AB9D0DBD8C9AF
8E6C4C332626334B6A8DAEC8D7DAD0BA9B79583C2A252D415E80A2BFD2DAD5C3A88664463026
2938527295B4CCD8D8CBB393715138292731476688A8C3D4D9D1BDA07E5D412E272C3E5A7A9C
BACFD8D5C5AB8B6A4B342829374F6E8FAFC7D5D7CCB69877563C2C2831456182A3BED1D7D1BF
A483624631292C3C567697B4CBD6D4C7AF906F50392B2A354B698AA9C3D2D6CDB99C7C5C412F
2A30425D7D9EBACDD5D1C1A888684B352B2D3B527191AFC6D3D4C8B29574563D2E2B34496585
A4BECFD4CDBBA0816146332B30405A7898B5C9D3D1C3AB8D6D503A2E2D394F6C8CAAC2D0D3C9
B599795B42312D344661809FB9CBD2CDBDA486664B372E303F567493B0C5D1D0C4AE9172553E
302E384D6887A5BECDD1CAB79D7E6046352E34445D7B9AB5C8D0CDBFA78A6B503B30313D536F
8EABC1CECFC5B196775A423330384A6482A0B9CACFCAB9A083654B383034435A7795B0C4CECD
C0AA8E70543F33323C506B89A6BDCBCEC6B3997C5F4737323848617E9BB4C6CDC9BBA4876A50
3C333541577290ABC0CBCCC1AD9275594336333C4E6885A1B8C7CCC6B59D80644B3A3438465D
7996B0C2CBC9BCA78B6F5440363640546E8BA6BCC8CAC2AF967A5E4839353C4C64809CB4C4CA
C6B7A08569503E3638455B7591ABBEC8C8BDA98F735944383740526B87A1B7C5C9C2B19A7E63
4C3C373C4A617C97AFC0C8C5B8A3896D544238394458718DA6BAC6C7BEAC93785E493B383F50
67829DB3C2C7C2B39D82685040393C495E7893ABBDC6C4B9A68D7259463B3A44566E88A2B6C3
C5BEAD967C624D3F3A404E647E98AFBEC5C1B4A0866C55443B3D485C748EA6B9C3C3BAA89076
5D4A3E3C43546B849DB2BFC4BEAF99806751423C404D627A94AABBC2C0B5A28A7059473E3E48
59718AA2B5C0C2BAAA937A624E413E4452688099AEBCC1BDB09C846B55463F414C5F7790A6B7
C0BFB6A48D755D4B414047586D869EB1BDC0BAAB967E665245404451657D95AAB9BFBDB19F87
6F5A4941424C5D738BA2B3BDBEB6A69079624F444148566B8299ADBABEB9AC99826A56484245
50637991A5B5BDBCB2A18B735E4D44434B5B70889EAFBABCB6A7937C665347434855687F95A9
B6BCB9AD9B856E5A4B44465061768DA1B1BABAB2A28E77625147454C5A6E849AABB7BAB5A996
806A574A454954667B91A5B3B9B8AE9D88725E4F47474F5F73899DAEB7B9B2A4907B66554A47
4C596B8096A8B4B8B5A998836E5B4E484A5464788DA1AFB7B6AE9F8B7662534A49505D708599
AAB4B7B1A5937E6A594D494D58697D92A4B0B6B4AA9A86725F514A4B5362758A9DACB4B5AEA0
8E7966564D4B505C6E8296A6B1B5B1A695816D5C504B4E57677A8EA0ADB3B2AA9B897563554D
4D5461738699A8B1B3ADA1907D6A5A504D515C6C7F92A2AEB2B0A697847160544E4F5766788B
9CA9B1B1AA9D8B786658504E5460718395A4AEB1ADA292806D5E534F525B6A7C8F9FAAB0AEA6
988774645750515864758799A6AEAFA99E8E7B6A5C5350555F6F8092A1ABAFACA29482716156
51535B697A8B9BA7ADADA6998978675A53525864738495A3ABADA99E8F7E6D5F5653565F6D7E
8F9DA8ACAAA2958574655954545B68778898A4ABABA59A8B7A6B5E565459637182929FA8ABA8
9E918171635955575F6C7B8C9AA5AAA9A2968777685D56565C67758594A0A8A9A59B8D7D6E61
59565A63707F8F9CA5A9A69E928374665C57585F6B798997A1A7A7A197897A6B6059585D6674
83919DA5A7A49B8E8071645C595B636F7D8C99A2A6A59E938577695F5A5A606A7786949EA4A5
A1978B7C6E635C5A5E6672808E9AA2A5A29B8F8274685F5B5D636E7B89959FA4A39E9487796C
625D5C616A7684919BA2A3A0978C7E71665F5C5F66717E8B979FA2A19A9084766B625E5E646D
7986929CA1A19D94887C6F655F5E626A75818E989FA19E978D807469625F6167717C89949CA0
9F9A9185796E656060656D788490999E9F9C948A7E72686260636A747F8B959C9F9D978E8277
6C65616267707B8691999D9D9991877B70686362666D77828D969B9D9A948A7F756B6563656A
737E8992999C9B968E84796F68646468707A848E969B9B9891887D736B6664676D76808A9399
9B99938B81776E6865666B737C868F969A99958E857B726B6766697079828C9398999691887F
756E6867696E767F8890969897938B8279716B68686C737B848D939797948E867D746D69686B
707881899195979590898078706B696A6F757E868E939695928B837B736D6A6A6D737A838A91
9495938D867E76706C6B6C717880878E9394938F89817A736E6C6C70757D848B909393908B84
7D76706D6C6F737A81888E9293918D878078736F6D6E72787E858C9092918E89827B75706E6E
71767C83898E91918F8A857E78736F6F70747A80868C8F908F8C87807A75716F7073787E8489
8D8F8F8D88837D7773717072767C81878B8E8F8D8A857F7A75727172757A7F85898D8E8D8B86
817C7774727274787D82878B8D8D8B88837E7975737374777C8085898C8C8B8985807B777573
74767A7F83878A8B8B8986827D7976747476797D8185888A8B8987837F7B78767576787C8084
87898A898784807D79777676787B7E82858889898885827E7B787777787A7D80848688888786
83807C7A7877787A7C7F82858788878683817E7B7978787A7C7E81838587878684827F7D7B79
797A7B7D8082848586858482807E7C7A7A7A7B7D7F81838485858483817F7D7B7B7B7B7D7E80
828384848483817F7E7D7C7B7C7D7E8081828384838381807F7D7D7C7C7D7E7F808182838382
81807F7E7E7D7D7D7E7F8081818282828180807F7E7E7E7E7E7F8080818181818180807F7F7F
7F7F7F7F7F808080808080808080807F7F7F808080808080807F7F7F80808080808080808080
7F7F7F7F7F7F7F7F8080818181818180807F7E7E7E7E7E7F8080818282828181807F7E7D7D7D
7E7E7F80818283838281807F7E7D7C7C7D7D7F8081838384838281807E7D7C7B7C7D7E7F8183
8484848382807E7D7B7B7B7B7D7F81838485858483817F7D7B7A7A7A7C7E8082848586858482
807D7B7A79797B7D7F82848687878583817E7C7A7878797B7E81838687888785827F7C7A7877
787A7C8083868788888684807D7A787777787B7E82858889898885827E7B78767677797D8084
87898A898784807C78767576787B7F8387898B8A8885817D7976747476797D8286898B8B8A87
837F7A76747375777B8085898B8C8C8985807C7774737375797E83888B8D8D8B87827D787472
7274777C81868B8D8E8D89857F7A75727172757A7F858A8D8F8E8B87817C7672707173777D83
888D8F8F8D89847E7873706F71757A80878C8F908F8C86807A74706F6F73787E858A8F91918E
89837C76716E6E70757B82898E9192908C857E78726E6D6F737880878D9193928E88817A736F
6C6D70767D848B909393908B847D75706C6C6E737A81898F9394938E878078716C6B6C70767E
868D939594918A837A736D6A6A6D737B838B929596938E867E756F6A696B7078808990959795
91898178706B68696D747D868E949797938D847B736C68686B7179828B9397989690887F766E
6967686E757F8891969998938C8279706966676B727B858E95999A968F867C736B6665686E77
818B93999B99938A80766D6764666B737D8891989B9B968E847A70686464686F79848E969B9C
9992897E736A6563656B757F8A949A9D9B968D82776D66626368707B8791999D9D9991867B70
676261656C77828E979D9F9C958B7F746A63606268727E8A949C9F9E999084786D656060656E
7985919A9FA09C94897C7167615F626974808D979EA19F988E81756A625E5F656F7C88949DA1
A19C9286796D645E5E626B7684909AA1A29F978B7E71665F5C5F66717E8C97A0A3A29B918476
6A615C5D626C7987949EA3A49F95897B6E635D5B5F6874828F9BA2A5A29A8E8072665E5A5C63
6E7C8B97A1A5A49E9486776A605A5A5F697785939EA5A6A2998C7D6F635B595C6471808E9BA4
A7A59D918374665D5859606B7A8997A1A7A7A19789796B5F58575C667483929EA6A9A59C8F7F
70635A5659616E7D8D9BA5A9A8A0948575675C56565D68778796A2A9AAA59A8C7B6C5F575559
637181919EA8ABA89F928271635954565E6B7A8B9AA5ABABA4988877685B54545965748595A2
AAACA89D8F7E6D5F5653565F6D7E8F9EA9ADABA3958473645852535A67788999A6ADADA79B8B
7A695B53515661718294A2ACAFABA192806F5F5550535C6A7B8E9EA9AFAEA699877564585150
5764748798A6AEB0AA9F8F7C6A5B524F535E6D8092A2ADB1AEA495837160544E505866788B9D
AAB1B1A99C8B7866574F4E5460718497A6B0B2AEA2927F6C5C514D505A6A7D90A1ADB3B1A899
867361544D4D556375899BAAB2B3ADA08E7A67574E4B505C6D8195A6B1B5B1A696826E5C504B
4D5666798EA0AEB5B4AC9D8A7562534B4A515F72869AAAB4B6B0A4927D69584D494D596A7E93
A5B1B7B4AA9985705D50494A5362768B9FAEB6B7AFA18D7864544A484E5B6E8398A9B5B8B4A8
96806B594C474A55667B90A4B2B9B7AE9D89735F4F47474F5E72889DAEB8B9B3A5917B665449
454A576A8096A9B5BAB7AB9A846E5A4C45475162778EA2B2BABAB1A18D76615046444B5A6E85
9BADB9BCB6A9957F685548434753667C93A7B6BCBAAF9E88705B4B43444D5E738BA1B2BCBDB5
A591796350454248566A8299ACB9BEBAAD99826B564841444F627990A6B6BEBDB3A28B735D4C
4241495A6F879FB1BDBFB9AA957D655144404552667E96ABBAC0BDB19E866D584740414B5D75
8DA4B6BFC0B7A690775F4C413F46556B849CB0BDC1BCAE99806852443E414E627A93AABAC2C0
B5A28A7159483E3E4759708AA2B5C0C2BBAA947A624D403C4251678099AFBEC4BFB29D846B54
433C3E4A5D7690A8BAC3C3B9A68E745C483D3B44556C86A0B4C1C5BEAF987E644E403A3F4D62
7C96ADBEC5C3B6A2886E56443A3B4659728DA6B9C4C6BDAB93785E493C39405068829DB3C2C7
C2B39D8267503F383B495E7893ACBEC7C6BAA68D715844393842546D89A3B8C5C8C0AF977C61
4A3C373C4C637E9AB1C2C9C5B7A1876B524037384459738FA9BDC8C8BEAB91755B4538363E50
6985A0B7C6CAC4B49C80644C3C3539485E7A96AFC2CAC8BCA68B6E5440363640546F8BA7BCC9
CBC2B096795D4638343A4B64809DB5C6CCC7B8A185684E3C333643597592ADC1CCCBC0AB9072
574135333C506A87A4BBC9CDC6B49B7E6148383237475F7C99B3C6CECBBDA6896B503C32333F
54708EAAC0CDCEC4B095775A433430384B6583A0B9CACFCAB9A082644A383033425A7796B1C5
CFCEC1AB8E6F533D31303B506B8AA7BFCDD0C8B59A7B5D44342E3546607E9DB7CAD1CDBEA587
684D382E303E557291AEC4D0D1C5B09374563F302E374B6686A4BDCDD2CBB99F806146342D31
425B7999B5C9D3D0C2AA8C6C4F392D2E3A506D8DABC3D1D3C9B598785A40302B33466181A0BB
CDD4CFBEA4856549342B2E3D567495B2C8D4D3C6AF9171523B2D2B354B6888A8C1D1D5CDBA9E
7D5D42302A2F415C7C9CB9CDD6D2C3A98A694B352A2B39506F90AFC7D4D6CBB49776563C2C29
31466283A4BFD1D7D1BEA382614531282C3C567798B6CCD7D5C7AF8F6E4F372928344B6A8BAB
C5D5D8CFBA9C7A5A3E2C272E415D7EA0BDD1D9D4C3A888664731272938517193B3CBD8D8CCB4
95725238292630466486A8C3D5DAD2BFA2805E412D252A3C58799BBAD0DAD7C8AE8D6A4B3326
26334C6C8EAFC9D8DBD0B99A78563A29242C415F81A3C1D4DCD6C4A78562442E242737527397
B7CFDBDACCB3936F4E3425242F466689ABC7D8DDD4BEA07D5A3D2922293C597C9FBED4DDD9C8
AD8B67472F2324334D6E92B3CDDCDDD1B99874523625212B416084A7C5D8DFD7C4A6825F402A
21253753769ABBD2DEDCCDB2906C4A3022212E47688DAFCBDCDFD5BE9E7A5639261F273C5A7E
A3C2D7E0DBC8AB8863432B2022324E7095B7D1DFDFD1B896714E32221F2A426287ABC9DCE1D9
C3A47F5B3C261E243755799EBFD6E1DECDB18E68462D1F1F2E486A90B3CFDFE2D6BD9C775235
221D263C5C81A6C6DBE3DCC8AA85603F271D20324F7399BBD5E2E1D2B7946E4A2F1F1D294264
8AAFCDDFE4DAC3A27C5738231B2237567CA2C3DAE4E0CDB08B6542291C1D2D496D93B7D3E2E4
D6BD9A734F311F1B253D5E85AACADEE5DEC8A8825C3B241A1F3250769CBFD8E5E3D2B6916A46
2B1B1B2943678EB3D0E2E6DBC2A07953341F192138587FA5C7DDE7E1CDAE88613E25191C2D4A
7097BBD7E5E5D7BB97704B2D1B18243E6188AECEE2E8DEC8A67F583720171E325279A0C3DCE8
E4D2B48E674227191928456991B7D4E5E8DBC19E764F301C1720385A82A9CAE1E9E2CDAC855D
3A22161A2D4C729BBFDAE8E7D7BA956C47291817243F638BB2D1E5EADFC7A47C54331D151D33
547CA4C7E0EAE5D2B28B633E23161828466C95BBD8E8EADBC09B724B2C191520395D85ADCEE4
EBE3CCAA8259361E14192E4E759EC3DEEBE8D7B89269432616152440668FB6D5E8ECE0C6A178
502F1A131C34567FA8CBE3EDE6D1B0885F3A20131629486F99BFDCEBEBDBBE986F4728161320
3A5F89B1D2E7EDE4CBA87F56331B12182E5079A2C7E1EDEAD6B78F653F22131424426893BAD9
EBEDE0C49F754C2B16111C355982ACCFE6EFE7D1AE855B361C1115294A729CC3DFEEECDBBD95
6B432513111F3C628CB5D6EAEFE4CAA57B522F1810182F527CA6CBE5F0EBD6B58C613B1F1012
24436B96BEDDEEEFE0C39C714828140F1B365B86B0D2E9F1E8D0AC825733190F142A4C75A0C7
E3F0EDDBBB92673F211010203D6590B9DAEDF1E4C9A3784E2B150E1730557FAACFE8F2EBD5B2
885D371B0E1125456F9AC2E0F0F0E0C1996D4424110E1B375E8AB4D6ECF2E8CEA97E532F160D
142B4E79A4CAE6F2EEDAB98F633C1E0E0F203F6894BDDDF0F2E4C7A0744A27120C17325783AE
D2EBF4ECD4B0855933180C112648729EC6E3F3F1DFBF966A40200E0D1C39618DB8DAEFF4E8CD
A77B4F2B130B142C517CA8CEE9F4EFD9B78C5F381A0C0E21416B98C1E1F2F3E4C59D7046240F
0B17335A87B2D6EEF5ECD3AD81552F150A10274A75A2CAE7F5F2DEBD93663D1D0C0C1C3B6491
BCDDF2F5E8CBA4774B271009142D5380ACD2ECF6EFD8B4885B34170A0D22446E9BC5E4F5F4E3
C39A6C42200D0A18355D8AB6DAF0F7ECD1AB7E512C120810284D79A6CDEAF7F2DDBB8F62391A
0A0B1D3D6795BFE1F4F6E7C9A17347240E08142F5683B0D6EFF8EFD7B185583014080D234672
9FC9E7F7F5E2C196693E1D0A091837608EBADDF3F8EBCFA87A4D280F0710294F7CAAD1EDF8F2
DCB88C5E3517080A1E406B99C3E4F6F7E7C79D6F44210B0714315987B4D9F1F9EFD5AF81542C
11060D244975A3CCEAF8F5E1BF93653A1A080819396492BEE0F5F9EBCDA57649250D06102B52
80AED5EFFAF2DAB5885A3114060A1F426E9DC7E7F8F8E6C59A6B401D090615335C8BB8DDF4FA
EFD3AB7D50290F050D264C79A7D0EDFAF5E0BC8F61361706081A3C6796C2E4F7FAEACBA17246
210A05112D5584B2D8F2FBF2D9B285562E11050A204572A1CBEAFAF8E4C297683C1A07061635
608FBCE0F6FBEED1A87A4C250C040D284F7DABD3F0FBF5DEB98C5D331405071C3E6A9AC5E7F9
FAE9C99E6F421E0804122F5988B6DCF4FCF2D7AF81522A0F030A224875A5CEEDFBF8E3C09364
3817050517386393BFE3F8FCEDCFA57648220A030E2A5280AFD7F2FDF5DCB688592F1103071D
416E9EC9EAFBFAE8C69A6B3E1B060413325C8CB9DFF6FDF1D5AC7D4E270C020B244B79A8D2EF
FDF8E1BD8F6035140405183B6797C3E6FAFCECCCA272441F08020F2C5584B3DAF4FDF4DAB384
552C0F02081F4472A2CDECFCFAE6C397673A1805031434608FBDE2F8FDF0D2A9794A240A020B
264E7DACD5F2FEF7E0BA8C5C311202051A3D6A9BC7E9FBFCEBCA9E6E401C0602102E5888B7DD
F6FEF4D8B08051280C0108214776A6D0EFFDFAE4C093633715030315376393C1E5FAFEEFD0A5
75472008010C285181B0D9F4FFF7DDB788582E0F01061C406E9FCAEBFDFCE9C79A6A3D190502
11315C8CBBE0F8FFF2D6AC7D4D250A0109234A79A9D3F1FEF9E3BD8F5F33130204173A6797C4
E8FCFEEDCDA271431D06010E2B5585B4DCF6FFF6DBB384542A0D01061E4472A2CEEEFEFCE7C4
97663917030213346090BEE3FAFFF1D3A979492208000A254E7DADD7F3FFF9E0BA8B5B301001
04193D6B9BC8EAFDFDECCA9E6D3F1B05010F2E5889B8DFF8FFF5D9B08050270B0007204776A6
D1F0FFFBE5C193623614020215376394C2E6FBFFF0D0A575461F07000B285181B1DAF5FFF8DE
B788572D0E00051B406E9FCBECFEFDEAC79A693C18030111315C8DBBE1F9FFF3D6AC7C4C2409
0008234A7AAAD4F2FFFAE3BD8F5E32120103173A6798C5E8FCFEEECDA171421D05000D2B5585
B5DDF7FFF6DBB384532A0C00061E4472A3CFEFFFFCE8C496663816020113346091BFE4FBFFF2
D3A978492108000A254E7EAED7F4FFF9E1BA8B5A2F100004193D6B9CC9EBFDFEECCA9E6D3F1A
04000F2E5989B8DFF8FFF5D9B08050270B0007204776A7D2F1FFFBE5C1926235140202153764
94C2E6FCFFF0D0A574451F06000B285282B1DAF6FFF8DEB787572C0E00051B406FA0CCEDFEFD
EAC79A693B18030111315C8DBCE2FAFFF3D6AC7C4C24090009234B7AAAD5F2FFFAE3BD8F5E32
120103173A6798C6E9FDFEEECDA170421C05000D2B5586B5DDF7FFF6DBB38353290C00061E44
73A3CFEFFFFCE7C496653816020213346091BFE4FBFFF1D3A878492108000A264E7EAED7F4FF
F9E0BA8B5A2F100104193E6B9CC9EBFDFDEBCA9D6D3F1A04010F2E5989B8DFF8FFF4D8AF7F4F
270B0008214877A7D2F0FFFBE5C092613514020315376495C2E6FBFEEFCFA474451F07000C29
5282B2DAF5FFF7DDB687572C0E01051C416FA0CCECFDFCE9C699693B18040112325D8DBCE1F9
FFF2D5AB7B4C240A0009244B7BABD4F2FFF9E2BC8E5E32120204183B6899C5E8FCFDEDCCA070
421D06010E2C5686B5DCF6FFF5DAB283532A0D01071F4573A3CEEEFEFBE6C395653816030314
356191BFE4FAFEF0D2A778492209010B274F7FAED7F3FEF7DFB98A5A301102051B3F6C9CC8EA
FCFCEAC99D6C3F1B0602112F5A8AB8DFF7FEF3D7AE7F50270C0109224977A7D1EFFDF9E3BF91
613615030417396595C2E5FAFDEECEA474462008020E2A5382B1D9F4FEF5DCB586572D0F0207
1D4270A0CBEBFCFBE7C599693C19050313335E8EBBE0F8FDF1D4AA7B4C250B020B254C7BAAD4
F0FDF7E0BB8E5E33130306193C6999C5E7FAFCEBCBA070421E0803102D5786B5DBF5FDF3D9B1
82532B0E0309214674A3CEEDFCF9E4C195653918050516366291BEE2F8FCEED0A77749230A03
0D28507FAED6F1FCF5DDB78A5A311204071C406D9CC7E8FAFAE8C79C6C401C070413315B8AB8
DDF5FCF1D5AD7F50290E030B244A78A7D0EEFBF7E1BE916137160506193A6695C1E4F8FBEBCD
A37446210A04102C5483B1D8F2FCF3DAB486572E110409204471A0CAEAFAF8E5C398693D1B07
0615355F8EBBDFF5FBEED2A97B4D270D040D274E7CAAD2EEFBF5DEBA8D5E341506081C3E6A98
C4E5F8F9E9C99F7043200A05122F5886B4DAF2FAF1D6B082542C11050C234874A3CCEAF9F6E2
C094653A1A080718386391BDE0F5F9ECCEA5774A250D06102B527FADD4EFFAF3DBB6895B3214
070A1F426D9CC6E6F7F7E6C59B6C411E0A0715335C8AB7DBF2F9EED3AC7E512A10060E264B78
A6CEEBF8F4DFBC9062381908091B3C6795C0E2F5F8E9CAA17347230D07132E5683B0D6EFF8F0
D7B285583014070C2246719FC8E7F7F5E2C197693E1D0B091837608EB9DDF2F7EBCFA87B4E29
1008112A4F7CA9D0ECF7F2DBB88C5F3618090B1F406A98C2E3F5F6E5C79D7045220D0916325A
87B3D7EFF7EDD4AE82552E14090F264975A2CAE8F6F3DFBD93663C1C0B0B1B3B6491BCDEF2F6
E8CCA4774B271009132D5380ACD2ECF6EFD8B4885C34180A0E22446E9BC4E3F4F3E2C39A6D42
210E0B19365D8AB5D9EFF5EAD0AA7E522D140A12294D79A5CCE8F5F0DCBA8F623A1C0C0D1F3F
6894BEDFF1F4E5C8A0734926100B16315783AFD3ECF4ECD4B0855932170B102648729EC6E4F3
F1DFBF966940200E0D1C3A618EB8DAEFF3E7CCA67A4F2B140C152D517CA8CEE8F3EED8B68B5F
381B0D1022426C98C0DFF1F1E2C49C704725110D1A355B87B1D5EBF3E9D1AC815631170D1329
4C76A1C8E4F2EFDBBB92663E200F0F1F3D6591BADBEEF1E4C8A2774D2A140E18315580ABCFE8
F2EBD4B2885D371B0F1226466F9BC2E0EFEFDEC0986D4425120F1D395F8AB4D5EBF1E6CDA87E
5330180F162D5079A4C9E4F0ECD8B78E633D20111223416994BCDBEDEFE1C59E744B2915101B
355983ADD0E8F0E8D1AE845A351B1015294A739DC4E0EEECDBBC946A43241312203D638DB6D6
EAEFE3C9A47A512F18111931547DA7CBE4EEE9D4B38B603B1F121426456D97BEDBECECDDC19B
70492916121E385D87AFD1E7EEE5CDAA8157341C12182D4E77A0C5E0EDEAD7B8916741241414
24416790B8D7E9ECE0C5A0774F2E19131C355880A9CCE3ECE6D0AF875E3A2014172A49709ABF
DBEAEADABD976D47291714223C618AB1D2E6EBE1C9A67D55331C141B31527AA3C6DFEBE7D3B4
8D643F24161727456A93B9D7E8EADCC19D744D2D1A1520385B84ABCDE3EAE3CCAB845B392016
1A2E4D749CC1DBE9E7D6B9936B452818172540658DB3D2E5E9DEC5A27A53331D161E35567DA5
C7DFE9E3D0B08A623E24181A2B496E96BBD7E6E7D8BD99714B2D1B18233C5F87ADCDE2E8DFC9
A780593821181E3251779FC2DBE7E4D2B5906844291A1A29446890B5D2E4E6DAC19E7751321E
1922395A81A7C8DEE7E0CCAC865F3D251A1D2F4D7299BCD7E5E4D5B9956E4A2D1D1A2740638A
AFCDE0E5DCC5A37D5737221A2136557BA1C2DAE5E1CEB18C6643291C1D2D486C92B6D2E2E4D7
BD9B745032201B253D5E84A9C8DDE4DDC8A8835D3D261C203350759BBDD6E3E1D1B5926C482D
1E1D2B44678CB0CDDFE3D8C1A07A5537231C243A597EA3C3D9E2DDCBAD8963422A1E20304C6F
95B7D2E0E0D3B997724E32211E29416187ABC8DCE2D9C4A5805B3C271E243754789DBED5E0DE
CDB18E69472E20202E486A8FB2CDDDE0D4BD9C775437241F283E5D81A5C3D8E0DAC7A9866141
2A202434507397B8D1DEDDCFB5936F4D3223212D456589ACC8DADFD6C0A17D5A3C2821273B58
7B9FBED4DEDAC9AD8B67472F2224324C6E92B3CDDBDDD1B99875533726222C426084A6C4D7DD
D6C3A5835F412C232738547699B9D0DCDACBB1906D4C3325243149698CADC8D8DCD2BC9D7A58
3C29232B3F5C7EA1BFD3DCD7C5A988654630252736507194B4CCD9DACDB59572523728252F45
6486A8C3D5DAD3BFA2805E412D252B3C58799BB9CFD9D7C7AD8D6B4B342727354D6C8EAEC8D6
D9CEB89A78573C2B262F436081A2BFD2D9D3C1A685634631272B3A547496B4CBD7D6C9B19270
51382A2833496789A9C3D3D7CFBB9E7D5C412F282E405B7C9DBACED7D3C3AA8A694B352A2B39
506F90AFC7D4D5CAB49675563D2D2A32476384A4BED0D6CFBDA2826246322A2E3E587798B5CA
D4D3C5AD8F6E50392C2C374D6B8BAAC2D1D4CBB79B7A5B41302B32445F7F9EBACCD4CFBFA687
674B362C2E3D547292B0C6D2D2C6B09373553D2F2D364B6786A5BECED3CBB99F7F6046342D32
425B7A99B5C9D2CFC1A98C6C503A2F2F3B516E8DAAC2CFD1C7B397785A42322E36486381A0B9
CBD1CCBBA284664B382F3241587594B0C5CFCEC2AC9071553E32303A4E6A88A5BDCCD0C8B59B
7D5F46363036465F7D9AB5C7CFCBBDA5896B503C31333F55718FABC0CDCDC3AF94765A433532
3A4C6684A0B9C9CEC8B79F82644B393236445C7896B0C3CCCBBEA88D6F544034343E526D8AA6
BCCACCC4B1987B5E4738333A4A627F9CB4C5CCC8B9A28669503D343643597491ABBFCACABFAB
9174594437353E506986A1B8C6CBC4B39B7F634C3B353A485F7B97B0C1CAC7BAA58A6E544137
374256708CA6BBC7C9C0AD95795E483A373D4E66819CB3C3C9C4B59E8368503F373A475C7792
ABBDC7C6BBA78E7259453A3942546C88A2B7C4C7C0AF987D634C3E383E4C637D98AFBFC6C3B6
A1876D55433A3B465A738EA6BAC4C5BCAA92775E493D3A415269839DB3C1C5C0B19B81675141
3B3E4B607993ABBCC4C2B7A48B7159473D3C46586F89A2B6C1C4BCAC957B624D403C4250667F
99AEBDC3BFB29E856C55453D3F4A5D758FA6B8C1C1B8A68F755D4B3F3E45566C859DB1BEC2BC
AD987F6652433E424F637B94AABAC1BFB3A08970594840404A5B728BA2B4BEC0B8A89279624F
433F4654698199ADBBC0BBAE9A836B564740434E617890A6B6BEBDB4A28C745E4C424149596F
879EB0BBBEB8A9957D665346414653667E95A9B7BDBBAF9D866F5A4A43444E5F758CA2B2BCBC
B4A48F78625045434A586C8399ACB8BCB7AA97816A5749444752647A91A5B4BBBAB09F8A735E
4E45454D5D72889EAEB9BAB4A6927C665448454A576A7F95A8B5BAB7AB9A846E5B4D46485262
778DA1B0B8B8B0A18C77625248474E5C6F859AABB6B9B3A7947F6A584C474B56677C92A4B2B8
B6AC9B87725F504949516174899DADB6B7B0A28F7A66564B494E5B6D8196A7B2B6B3A796826E
5C4F494C5665798EA0AEB5B4AC9D8A7562544B4B525F728699A9B3B5AFA3917D6A594E4B4F5A
6A7E92A3AFB4B2A89885715F524C4D5564768A9DABB2B3AC9E8D7966574E4C525E6F8396A5B0
B3AFA493806D5D524D5059697B8E9FACB2B0A89A887563564F4F5663748799A7B0B1AB9F8F7C
6A5B514E535E6D8092A2ACB1AEA495837161554F515967798B9CA8AFAFA89B8A786759515056
62728495A4ADAFABA0917F6D5E5451545D6C7D8F9EA9AEACA4978674645852525966768898A5
ACADA79C8C7B6A5D54525761708192A0A9ADAAA0928271625853555D6A7A8B9BA6ACABA49888
77685C55545A65748595A2A9ABA79C8E7E6E60575458616E7E8F9DA6AAA8A0948474655B5656
5D69788897A3A9A9A3988A7A6B5F58565B657382929EA6A9A69D908071645A5759616D7C8C99
A3A8A7A0958677695E58585E687686949FA6A7A3998C7D6E625A585C6471808E9BA3A7A49D91
8274675E595A616C7A8996A0A5A5A09588796C615B5A5F687583919CA3A5A2998D7F71655D5B
5D65707E8C98A0A4A39C9284766A615C5C626C7886939DA3A39F96897C6F645E5C606874818E
99A0A3A0998E817468605D5F656F7C89959DA2A19C9286796D645E5E636B7784909AA0A19E96
8B7E7267615E6168737F8B969DA09F998F83766B635F60666F7A86929A9F9F9B92877B706761
60646B76828D979D9F9C968C80746A64616369727D89939A9E9D988F84796E666262666E7984
8F979C9D9A92897D726A6462656C75808B949A9D9B958C82776D66636469717C8690989B9B97
8F867B71696564686E78828C959A9B9892897F756C6765676C747E8891979A99948D83797069
66666A717B848E959999968F877D746C6766696F77818A92979997928A81776F6A67686D747D
868F959897938D847B726C68686B717A838B929697948F877E766F6A696A6F777F888F949695
918A8279726C6A6A6E747C848C929595928C857D756F6B6A6D727981898F9395938E88807871
6D6B6C70777E868D929493908A837B746F6C6C6F747B838A8F9393918C857E77716E6D6E7379
80878D9192918D88817A746F6D6E71777D848A8F91918E8A837D76726F6E71757B81888D9091
8F8B867F7974706F7074797F858A8E908F8C88827C7672707073777D83888C8F8F8D89847E78
74717172767B80868A8D8E8D8A86807B7673717275797E84888C8D8D8B87827D787572727478
7C81868A8C8D8B88847F7A76747374777B7F84888B8C8B8985817C78757474767A7E8286898B
8B8986827E7A77757576797C8084888A8A898784807C79767576787B7F83868889898785817D
7A787676787A7E81848788898885827F7C797777787A7D8083868788878683807D7B7978787A
7C7F82848687878684817E7C7A79797A7B7E80838586868684827F7D7B7A797A7B7D7F828485
86858482807E7C7B7A7A7B7D7F81828485858483817F7D7C7B7B7C7D7E808183848484838180
7E7D7C7C7C7D7E7F81828383838281807F7E7D7D7D7D7E7F8081828282828180807F7E7E7D7E
7E7F8080818181818180807F7F7E7E7E7F7F7F8080818181808080807F7F7F7F7F7F80808080
808080808080
pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->-1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`00000Q
0000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`0_oooooboo
0000Goooool_o`00033ooooo0@000000000300000?oooooooooo02Gooooo@_l0001<oooood;o0000
9oooool10000000000<00000ooooooooool07OoooomBo`0003coooooD_l0000Oooooo`4000000000
0`00003oooooooooo`0Foooooeoo0000;ooooomOo`0001Wooooo0@000000000300000?oooooooooo
013oooooK?l0000Rooooof_o00004oooool10000000000<00000ooooooooool02Ooooomjo`0001Co
ooooN_l0000;ooooo`40000000000`00003oooooooooo`03ooooohGo00002Ooooon5o`0000Kooooo
0@000000000300000?oooooo00000?oo00007?l00001ooooo`40000000000`00003oooooo`00003o
o`0001co00000Oooool10000000000<00000ooooooooool01?oooon3o`0000_oooooPol00007oooo
o`40000000000`00003oooooooooo`0:ooooogSo00005_oooomgo`0000gooooo0@00000000030000
0?oooooooooo013oooooK?l0000Rooooofco00004_ooool10000000000<00000ooooooooool05ooo
oomMo`00037oooooGOl0000Jooooo`40000000000`00003oooooooooo`0Nooooodoo0000?ooooom?
o`00027ooooo0@000000000300000?oooooooooo02Kooooo@?l0001>oooood3o0000:?ooool10000
000000<00000ooooooooool0<?ooool[o`0006?ooooo;?l0000booooo`40000000000`00003ooooo
ooooo`3ooooooagooooo0@0000000?l000008@000000000300000?oooooooooo0?oooooo7Oooool1
0000000000<00000ooooooooool0?_ooool@o`0007kooooo4?l00010ooooo`40000000000`00003o
ooooooooo`0jooooo`So000000?oooooo`000?l000003?l0001gooooo`_o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000004o`0003gooooo0@000000000300000?oooooooooo03Wooooo
0ol00002ooooo`03o`000?oooooo000000;o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00?o0000ooooool00000MOooool4o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00Co
000000Coooooo`000?oooooooooo0ol0000kooooo`40000000000`00003oooooooooo`0gooooo`_o
000000Goooooo`000?l0003o0000ooooo`0>o`00073ooooo2ol000001?oooooo0000o`000?ooool3
o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000002o`0003Wooooo0@00
0000000300000?oooooooooo03Gooooo1Ol000001ooooooo0000o`000?l0003oooooo`000?ooool0
0ol000001?oooooo0000o`000?ooool3o`000005ooooool0003o0000o`000?ooool00ol000001?oo
oooo0000o`000?l0001[ooooo`co000000?oooooo`000?l000000ol00002ooooo`Co000000?ooooo
o`000?l000000_l000000ooooooo0000o`000003o`0003Oooooo0@000000000300000?oooooooooo
03Cooooo0ol00002ooooo`05o`000?ooooooooooo`000?ooool00ol00003ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo0000ooooool00000
JOooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooo`000?ooool00_l000001?oooooo0000ooooool00002
ooooo`Co0000=_ooool10000000000<00000ooooooooool0<_ooool4o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?ooool00_l000001?oooooo0000ooooooooool2o`000003ooooool0
003o000000;o00000_ooool3o`000003ooooool0003o000000Ko0000I_ooool6o`000003ooooool0
003o000000?o000000?oooooo`000?ooool00_l00002ooooo`;o000000Woooooo`000?l0003o0000
ooooool0003oooooo`000?ooool00ol000000ooooooo0000o`000004o`0003Cooooo0@0000000003
00000?oooooooooo037ooooo0ol000000ooooooo0000o`000003o`000004ooooool0003ooooooooo
o`;o000000Coooooo`000?oooooo00000oooool01Ol0003oooooooooool0003ooooo00;o000000Go
ooooo`000?oooooo0000ooooo`02o`000003ooooool0003o000000?o0000I?ooool5o`000004oooo
ool0003o0000o`0000;ooooo00?o0000ooooool000000_l00003ooooo`03o`000?oooooooooo00;o
000000Goooooo`000?l0003oooooo`000002ooooo`05o`000?oooooo0000o`000?ooool00_l00000
1?oooooo0000o`000?l0000cooooo`40000000000`00003oooooooooo`0`ooooo`04o`000?oooooo
0000o`0000?ooooo00Go0000oooooooooooo0000ooooo`02o`0000;ooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000?o0000H_ooool3o`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l00000
0ooooooo0000ooooo`02o`0000?ooooo00?o0000ooooooooool00ol000000ooooooo0000ooooo`0a
ooooo`40000000000`00003oooooo`00000^ooooo`Go000000Goooooo`000?l0003oooooo`000002
ooooo`04o`000?oooooo0000o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
00Koooooo`000?l0003o0000ooooool00002ooooo`Ko000000Coooooo`000?l0003o0000Goooool4
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?ooool01?l000000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00;o00001?ooool2o`000003ooooool0003ooooo00;o000000?o
ooooo`000?l000001Ol0000aooooo`40000000000`00003oooooooooo`0]ooooo`Go000000Cooooo
o`000?oooooo00000_ooool2o`000004ooooool0003oooooooooo`Co00000_ooool00ol0003ooooo
ooooo`02o`0000?ooooo0_l00002ooooo`?o000000Coooooo`000?oooooo00000_ooool6o`0005co
oooo1_l000001_oooooo0000oooooooooooo0000ooooo`?o000000Coooooo`000?oooooo00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo0ol00003ooooo`Co00000_ooool01?l0003ooooo
o`000?ooool5o`0002oooooo0@000000000300000?oooooooooo02cooooo00?o0000ooooool00000
0_ooool01_l0003oooooooooool0003oooooo`0000Cooooo0ol00005ooooo`04o`000?oooooooooo
o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol0
001Jooooo`?o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`000004ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00_l0000_ooooo`40000000000`00003ooooooooo
o`0[ooooo`[o000000Goooooo`000?l0003oooooo`000004ooooo`;o000000?oooooo`000?ooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000ooooool0003o0000ooooool0003o
oooo00;o000000?oooooo`000?l000001_l000000ooooooo0000o`00001Hooooo`ko000000?ooooo
o`000?ooool00ol00003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`02o`0000Cooooo00?o0000ooooool000000_l000001?oooooo0000o`000?ooool6o`0002gooooo
0@000000000300000?oooooooooo02[ooooo1?l000000ooooooo0000ooooo`02o`0000;ooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool00ol0003ooooooooo
o`02o`0000Cooooo00?o0000ooooool000000_ooool00ol0003oooooo`000004o`000003ooooool0
003o000000?o0000EOooool6o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool0
0_l000000ooooooo0000ooooo`03ooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo
0_l000001?oooooo0000ooooool00004ooooo`03o`000?oooooo000000;o000000Coooooo`000?l0
003ooooo0ol0000/ooooo`40000000000`00003oooooooooo`0Yooooo`;o00000_ooool4o`0000;o
oooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004ooooo`;o00000_ooool01Ol0
003ooooooooooooooooo000000Gooooo0_l00005ooooo`05o`000?oooooo0000ooooool000000_oo
ool01ol0003oooooo`000?oooooo0000ooooool00000E?ooool3o`000003ooooool0003o000000;o
oooo00Ko0000oooooooooooo0000ooooool00005ooooo`;o00001Oooool01?l0003oooooooooool0
0003ooooo`;o00000oooool01_l0003ooooooooooooooooo0000ooooo`?o00000oooool01Ol0003o
ooooo`000?l0003ooooo00;o0000;?ooool10000000000<00000ooooooooool0:?ooool5o`000007
ooooool0003oooooooooool0003oooooo`000002ooooo`06o`000?oooooo0000ooooool0003ooooo
0_l00004ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooo`000?l00004oooo
o`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooo`000?ooool0
0ol0001Booooo`Go00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;o
00000oooool01Ol0003oooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooo`000?ooool00_l00003ooooo`03o`000?oooooo000000;ooooo0_l0
00000ooooooo0000o`000002o`0002[ooooo0@000000000300000?oooooooooo02Kooooo0ol00000
0ooooooo0000ooooo`09o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`;o0000
00?oooooo`000?ooool00_l00003ooooo`;o00000_ooool2o`000004ooooool0003oooooo`0000Go
oooo00?o0000ooooool000001_l000000ooooooo0000o`000002o`00053ooooo1?l000000ooooooo
0000o`000003o`000003ooooool0003o000000Kooooo0_l00002ooooo`;o000000Coooooo`000?oo
oooo00000_ooool2o`0000;ooooo00?o0000ooooool000000oooool01Ol0003oooooo`000?oooooo
000000;ooooo0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00;o0000:Ooo
ool10000000000<00000ooooooooool09oooool2o`000003ooooool0003ooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Kooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooo`000?ooool00_l000000ooooooo
0000ooooo`06ooooo`03o`000?oooooooooo00?o0000C_ooool2o`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`Co0000:Oooool10000000000<00000ooooooooool09Oooool3
o`000003ooooool0003o000000;ooooo0_l000002Ooooooo0000oooooooooooo0000ooooool0003o
ooooo`000004ooooo`0=o`000?ooooooooooo`000?oooooo0000ooooool0003oooooo`000?oooooo
0000ooooo`02o`0000?ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000Cooooo00Oo
0000ooooool0003o0000ooooool0003ooooo00Ko0000C?ooool5o`0000;ooooo00Ko0000ooooool0
003o0000ooooool00004ooooo`;o00000_ooool01?l0003oooooo`000?l00002ooooo`0:o`000?oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000oooool00ol0003oooooooooo`02
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool2o`000004oooo
ool0003o0000o`0002Oooooo0@000000000300000?oooooooooo02Cooooo1_l000001?oooooo0000
o`000?ooool3o`000003ooooool0003o000000Cooooo0ol000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000000_ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooool0
00000_ooool5o`0000;ooooo0_l000001_oooooo0000o`000?oooooo0000ooooo`;o0000B_ooool3
o`000003ooooool0003o000000Co000000?oooooo`000?l000000_l000001?oooooo0000ooooool0
0002ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;ooooo
0_l00003ooooo`04o`000?oooooo0000ooooo`;o00001?ooool01Ol0003oooooo`000?l0003ooooo
00;o000000Goooooo`000?l0003o0000ooooo`05o`0002Kooooo0@000000000300000?oooooooooo
02Cooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003ooooo0_l00007ooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
1?l00019ooooo`Go00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00?o
oooo0_l00005ooooo`03o`000?oooooooooo00Sooooo0_l00007ooooo`?o00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`0Tooooo`40
000000000`00003oooooooooo`0Sooooo`Co00000oooool2o`000004ooooool0003o0000o`0000Ko
oooo00Co0000ooooool0003ooooo0_l00004ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`;o00001?ooool3o`000005ooooool0003oooooo`000?ooool0
0_l000001?oooooo0000o`000?ooool4o`000003ooooool0003o000004Oooooo0ol000000ooooooo
0000o`000006o`000003ooooool0003o000000;ooooo00Go0000ooooool0003oooooo`000004oooo
o`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00004
ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool4o`000004ooooool0003oooooooooo`Go
00009Oooool10000000000<00000ooooooooool08Oooool4o`0000;ooooo0_l000001Ooooooo0000
oooooooooooo000000;ooooo0ol000001Ooooooo0000oooooooooooo000000Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`05o`000?oooooo
ooooo`000?ooool00_l00004ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o
000000?oooooo`000?l000000ol00016ooooo`Go000000?oooooo`000?l000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000001?ooool3o`0000?ooooo00Go0000ooooool0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003ooooo00Co000000Koooooo`000?ooooooooooo`000?ooool3o`0000;ooooo0ol0000Toooo
o`40000000000`00003oooooooooo`0Qooooo`Co000000Coooooo`000?oooooo00000_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo0_l000000ooooooo0000ooooo`05ooooo`07o`000?ooooooooooo`000?oooooo0000
ooooo`03o`0004Cooooo00Co0000ooooool0003ooooo0_l00003ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool02?l0003ooooooooooooooooo0000ooooool0003ooooo1?l0000Sooooo`400000
00000`00003oooooooooo`0Pooooo`Oo000000Goooooo`000?l0003o0000ooooo`04o`000006oooo
ool0003oooooo`000?oooooo00001?ooool2o`0000Gooooo00Go0000ooooool0003oooooo`000002
ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000Gooooo
0ol000001?oooooo0000o`000?ooool2o`0000;ooooo1Ol00012ooooo`Co00000oooool2o`000003
ooooool0003o000000Co00001?ooool01?l0003oooooo`000?ooool2o`0000Cooooo0_l00002oooo
o`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000Gooooo00?o0000ooooooooool0
0oooool01_l0003oooooo`000?oooooo0000ooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000004o`0002?ooooo0@000000000300000?oooooooooo01oooooo1Ol000001?oo
oooo0000o`000?l00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000_ooool0
0ol0003oooooo`000004ooooo`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00004ooooo`05o`000?ooooooooooooooool000001?ooool3o`000003oooo
ool0003ooooo00Cooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`02o`00043ooooo
0_l000000ooooooo0000ooooo`02o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
o`000003o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`05o`000?ooooooooooooooool0
00000_ooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`000003ooooo`;o000000Oo
ooooo`000?ooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool3o`000003
ooooool0003o000000?o00008Oooool10000000000<00000ooooooooool07oooool01?l0003ooooo
ooooooooool2o`0001?ooooo00?o0000ooooool000001Oooool2o`0000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0004;ooooo0ol00008oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02oooo
o`;o00002?ooool01?l0003oooooooooooooool2o`0000Gooooo00?o0000ooooool000004oooool0
1?l0003oooooooooooooool2o`00027ooooo0@000000000300000?oooooooooo01kooooo0ol00000
0ooooooo0000ooooo`02o`000004ooooool0003o0000ooooo`Co000000Goooooo`000?oooooo0000
ooooo`02o`000005ooooool0003oooooooooool000000_ooool2o`0000Cooooo00Ko0000oooooooo
ooooooooo`000?ooool2o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool2o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00
0004o`0003gooooo0ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o0000
00?oooooo`000?l000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
0_l000000ooooooo0000o`000002ooooo`05o`000?ooooooooooooooool000001?ooool2o`000003
ooooool0003ooooo00;ooooo1Ol00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`Go00008?ooool10000000000<00000ooooooooool07Oooool6o`000006
ooooool0003oooooo`000?oooooo00001Oooool2o`0000Kooooo00?o0000ooooool000001Oooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo0_l0
0004ooooo`04o`000?oooooo0000ooooo`?o00000_ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooo000000?o000000?oooooo`000?l000000_l0000looooo`Co000000Coooooo`000?l0003o
00000_ooool02Ol0003oooooooooool0003oooooo`000?oooooo0000ooooo`02o`000004ooooool0
003oooooo`0000Cooooo0_l00005ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000004
ooooo`05o`000?ooooooooooo`000?ooool01?l000001?oooooo0000o`000?l0000Oooooo`400000
00000`00003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001ooo
ool01Ol0003oooooooooool0003ooooo00?o00002?ooool00ol0003oooooooooo`06ooooo`05o`00
0?ooooooooooooooool000000oooool2o`0000Gooooo0_l0000>ooooo`03o`000?oooooooooo00?o
oooo0_l000001?oooooo0000ooooool0000looooo`;o000000?oooooo`000?l000001_ooool00ol0
003oooooooooo`0;ooooo`;o00001Oooool00ol0003oooooo`000003ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`05ooooo`08o`000?oooooo0000o`000?oooooo0000
ooooool00008ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool07Oooool100000000
00<00000ooooooooool06oooool7o`000004ooooool0003o0000ooooo`;o000000Goooooo`000?l0
003oooooo`000005ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool2o`0000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
ooooo`000?oooooo000000Cooooo0_l00002ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?l000000ol000001_oooooo0000oooooooooooo0000ooooo`;o0000>Oooool3o`000006oooo
ool0003oooooooooool0003ooooo0ol000003Ooooooo0000o`000?oooooo0000ooooool0003ooooo
o`000?oooooo0000ooooool000001?ooool01?l0003oooooo`000?l00004ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo000000?o
ooooo`000?l000001?l0000Nooooo`40000000000`00003oooooooooo`0Kooooo`;o000000Kooooo
o`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0ol000001Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00oooool01_l0003o
ooooo`000?oooooo0000ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo00Ko
0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`000006o`0003Sooooo1ol000001ooooooo0000oooooooooooo
0000ooooool000000oooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00_l00003ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`02o`0000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`08o`000?ooooooooooo`00
0?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooo0000
ooooool0003ooooo00Co00007Oooool10000000000<00000ooooooooool06oooool5o`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Gooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l0000gooooo`;o
00002?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000002_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Go00007Oooool1
0000000000<00000ooooooooool06Oooool3o`000005ooooool0003oooooo`000?ooool01_l00000
1ooooooo0000o`000?oooooo0000ooooool000000_ooool2o`0000?ooooo0_l000001?oooooo0000
ooooool00004ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool00000
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo0000ooooo`02o`00
00Gooooo0_l000001?oooooo0000o`000?ooool4o`0000;ooooo1_l0000dooooo`Ko00000_ooool4
o`000003ooooool0003o000000?o00001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000oooool01_l0003oooooo`000?oooooo0000ooooo`;o
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;o00000oooool00ol0003o
ooooo`000002ooooo`05o`000?oooooo0000o`000?ooool01Ol000001ooooooo0000o`000?l0003o
ooooo`000?ooool01?l0000Kooooo`40000000000`00003oooooooooo`0Iooooo`Wo00001?ooool0
1Ol0003oooooooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`02o`0000Cooooo00Co
0000ooooool0003o00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;o
oooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooo`000002ooooo`;o
00000oooool3o`0003?ooooo0_l000001?oooooo0000ooooooooool3o`000005ooooool0003ooooo
ooooool000001?ooool4o`0000Cooooo00Ko0000oooooooooooo0000ooooool00005ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`07o`000?oooooo0000
ooooool0003oooooo`000004ooooo`;o000000?oooooo`000?ooool00_ooool2o`000004ooooool0
003oooooo`0000Gooooo0_l000000ooooooo0000o`000004o`0001_ooooo0@000000000300000?oo
oooooooo01Sooooo0_l000001Ooooooo0000oooooooooooo000000Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00003ooooo`;o
0000<_ooool2o`0000?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool01_l0003oooooooooool0003oooooo`0001_ooooo0@000000000300000?oo
oooooooo01Oooooo1Ol000000ooooooo0000ooooo`06o`000009ooooool0003o0000o`000?oooooo
0000ooooool0003ooooo00?o00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00;o00002?ooool01_l0003oooooo`000?oooooo0000ooooo`;o00001?ooool02?l0003ooooooooo
oooooooo0000ooooool0003ooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooo0000
00;o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`00037ooooo1ol000000ooo
oooo0000o`000003o`000005ooooool0003o0000ooooool000001Oooool02?l0003oooooo`000?l0
003oooooo`000?oooooo00000_ooool2o`0000?ooooo00Wo0000ooooool0003oooooo`000?oooooo
0000ooooool000002?ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01Ol0003o
ooooooooool0003ooooo00;o000000?oooooo`000?ooool01Ol000001Ooooooo0000o`000?l0003o
oooo00;o000000?oooooo`000?ooool01?l0000Jooooo`40000000000`00003oooooooooo`0Foooo
o`So00000_ooool01_l0003oooooooooool0003oooooo`0000Cooooo0_l00004ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000005ooooo`03o`00
0?oooooooooo00;o000000?oooooo`000?ooool00ol0000`ooooo`Co000000Coooooo`000?oooooo
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o000000Koooooo`000?oo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooool000001?ooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooooooool01ol0000Iooooo`40000000000`00003oooooooooo`0Fooooo`?o0000
0oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool000001oooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003
ooooo`;o00001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Ko0000;_oo
ool6o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo0_l00003ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ooooool3o`0001Sooooo0@000000000300000?oooooooooo01Gooooo1_l00002ooooo`Co000000?o
ooooo`000?l000000ol00006ooooo`07o`000?oooooo0000ooooool0003oooooo`000003ooooo`03
o`000?oooooooooo00;ooooo0_l00002ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`06ooooo`;o000000?oooooo`000?ooool00_ooool2o`0000Cooooo00Ko0000oooooooo
ooooooooo`000?ooool3o`000003ooooool0003o000000Co000000Koooooo`000?l0003oooooo`00
0?ooool4o`0002cooooo0ol000001?oooooo0000ooooooooool3o`000003ooooool0003o000000Co
000000Goooooo`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ool000000oooool01?l0003oooooo`000?l00008ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0002ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000ooooool0
00001_ooool3o`000004ooooool0003o0000ooooo`;o00000_ooool6o`0001Sooooo0@0000000003
00000?oooooooooo01Gooooo0ol000000ooooooo0000ooooo`02o`0000;ooooo00?o0000ooooool0
00001Oooool3o`0000Cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`;o
00002Oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooo`000?l0003oooooo`0000?ooooo
00Ko0000oooooooooooo0000ooooool00004ooooo`?o000000?oooooo`000?l000001?l0000[oooo
o`[o00001Oooool00ol0003oooooo`000002ooooo`06o`000?ooooooooooooooool0003ooooo0ol0
0003ooooo`03o`000?oooooo000000Gooooo0_l00002ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`06ooooo`;o00001?ooool01ol0003ooooooooooooooooo0000oooo
ool000001?ooool3o`0000Cooooo00Go0000oooooooooooo0000ooooo`03o`000003ooooool0003o
oooo00?o00005oooool10000000000<00000ooooooooool05?ooool2o`000004ooooool0003ooooo
o`0000Sooooo00?o0000ooooool000001Oooool2o`000003ooooool0003ooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooooooool3o`0002[ooooo0ol00003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool01?l0003oooooooooooooool2o`0000[ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooool0003o0000ooooo`02o`0001Kooooo0@000000000300000?oooooooooo
01?ooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`?o000000?ooooo
o`000?l000001_ooool01?l0003oooooooooooooool2o`0000Cooooo00Ko0000oooooooooooooooo
o`000?ooool2o`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`;o00001?ooool00ol0
003oooooooooo`02o`000003ooooool0003ooooo00Cooooo00?o0000ooooool000000_ooool00ol0
003oooooo`000005o`000004ooooool0003o0000ooooo`;o000000Goooooo`000?oooooo0000oooo
o`03o`0002Sooooo1Ol000000ooooooo0000ooooo`0:o`000005ooooool0003oooooo`000?ooool0
0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo00Co0000oooooooooooo00001oooool01Ol0003oooooo`000?oooooo0000
00?ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool00oooool01Ol0
003oooooo`000?l0003ooooo00?o000000Coooooo`000?l0003ooooo2?l0000Eooooo`4000000000
0`00003oooooooooo`0Booooo`Ko000000?oooooo`000?l000000oooool02Ol0003oooooooooool0
003oooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;o00001?ooool00ol0003o
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo0_l00002ooooo`;o00000_ooool01Ol0
003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?oo
ooooooooo`000?oooooo00001?ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00;o
000000?oooooo`000?l000001Ol0000Wooooo`So000000?oooooo`000?l000000_ooool00ol0003o
ooooooooo`04ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_l00005ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002
ooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000o`0000?ooooo
00Ko0000ooooool0003oooooo`000?ooool3o`0000;ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`03o`000003ooooool0003o000000?o00005Oooool10000000000<00000oooooooo
ool05?ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00003Oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool000001oooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo0ol0000Vooooo`?o00000oooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00004ooooo`06o`000?oooooo
ooooo`000?oooooo00002Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00[ooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooooooo0_l000000ooooooo0000o`00000Fooooo`40000000000`00003o
ooooooooo`0Aooooo`?o00000_ooool4o`000003ooooool0003o000000Co000000Koooooo`000?l0
003o0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?oooooo0000ooooool000000oooool01ol0003ooooooooooooooooo
0000ooooool000000_ooool3o`0000Gooooo1?l000001?oooooo0000o`000?ooool2o`0000;ooooo
1_l0000Uooooo`Oo00000_ooool2o`000003ooooool0003o000000Co00001_ooool3o`000004oooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00002ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`06o`000?oooooo
ooooooooool0003ooooo1?l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000;o
00000_ooool3o`0001?ooooo0@000000000300000?oooooooooo013ooooo1ol000001?oooooo0000
ooooool00002ooooo`03o`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00?o0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`;o
00001Oooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo1?l00004ooooo`03
o`000?oooooo000000;ooooo0ol000000ooooooo0000ooooo`03o`0002?ooooo1?l000000ooooooo
0000ooooo`02o`0000;ooooo00Co0000oooooooooooo00001?ooool3o`0000Kooooo00Co0000oooo
oooooooooooo0_l00002ooooo`03o`000?oooooo000000Gooooo0_l000001?oooooo0000ooooool0
0003ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`05o`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool01ol0003oooooooooool0003oooooo`000?ooool01_l0000Cooooo`400000
00000`00003oooooooooo`0@ooooo`?o00000oooool2o`0001Cooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000kooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o00001Oooool0
0ol0003oooooo`000008ooooo`03o`000?oooooo000000;ooooo0_l0000Rooooo`;o000000Cooooo
o`000?oooooo00002?ooool01?l0003oooooooooool00004ooooo`05o`000?oooooo0000ooooool0
00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool03?ooool01?l0
003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04ooo
ool01?l0003oooooooooooooool4o`0001;ooooo0@000000000300000?oooooooooo00oooooo0ol0
00001?oooooo0000ooooool00002ooooo`05o`000?oooooo0000o`000?ooool01_l00002ooooo`05
o`000?oooooo0000ooooool000001?ooool2o`000003ooooool0003ooooo00Cooooo00?o0000oooo
ooooool00_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_l00002oooo
o`;o00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l00003
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooool0003o0000ooooo`03o`000004ooooool0
003o0000ooooo`So00008?ooool9o`000004ooooool0003o0000ooooo`;o000000Coooooo`000?l0
003o00001_ooool01?l0003oooooooooooooool2o`0000Cooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`03ooooo`;o00000_ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Cooooo
0ol000001Ooooooo0000ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo1?l00002oooo
o`04o`000?oooooo0000ooooo`;o00004_ooool10000000000<00000ooooooooool03oooool7o`00
0003ooooool0003o000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000005oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool00_ooool2
o`00000:ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool01_l0003oooooooooool0003oooooo`0000Cooooo0_l00002ooooo`Go0000
00Goooooo`000?ooooooooooo`000002ooooo`03o`000?oooooooooo00?o000000Coooooo`000?l0
003ooooo0_l0000Pooooo`;o000000Coooooo`000?l0003ooooo0ol00002ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool3o`000003ooooool0003ooooo00;o00001?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l00008ooooo`06o`000?oooooo0000
ooooool0003ooooo0_l000001?oooooo0000ooooool00003ooooo`04o`000?ooooooooooooooo`;o
00000_ooool01ol0003ooooooooooooooooo0000ooooool000001Oooool00ol0003oooooo`000005
ooooo`05o`000?ooooooooooo`000?ooool01?l000001Ooooooo0000o`000?oooooo0000017ooooo
0@000000000300000?oooooooooo00kooooo0_l00002ooooo`05o`000?oooooo0000ooooool00000
0_ooool2o`00000:ooooool0003oooooooooool0003oooooo`000?oooooo0000ooooo`;o00001ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00Ko0000ooooool0003o0000
ooooool00003ooooo`;o000000?oooooo`000?ooool00_l0000Nooooo`05o`000?oooooo0000o`00
0?ooool00_l00003ooooo`;o000000?oooooo`000?l000003_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00Gooooo0ol00002ooooo`03o`000?oooooo000000;ooooo0ol00003oooo
o`06o`000?oooooo0000ooooool0003ooooo0ol0000@ooooo`40000000000`00003oooooooooo`0=
ooooo`Oo00000_ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000001Ooo
ool01ol0003oooooo`000?oooooo0000ooooool000000oooool2o`0000;ooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`02o`0000Cooooo0ol000000ooooooo0000ooooo`04o`0000Cooooo1Ol000000ooooooo0000o`00
0005o`0001cooooo0ol000001ooooooo0000o`000?l0003oooooo`000?ooool00_l00005ooooo`Go
00000_ooool3o`0000Cooooo0_l00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`02o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000002Oooool2o`0000?ooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o
00001_ooool2o`000004ooooool0003oooooooooo`Go00000_ooool6o`00013ooooo0@0000000003
00000?oooooooooo00gooooo0ol000000ooooooo0000ooooo`03o`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05o`0000?ooooo00Co0000oooooooooooooooo0_l00004oooo
o`06o`000?ooooooooooooooool0003ooooo0_l00002ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00002ooooo`;o00002?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`08o`0001cooooo1_l000001?oooooo
0000ooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`;o000000?ooooo
o`000?l000000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l000000ooooooo0000o`00
0002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooooooool3o`000004ooooool0003oooooo`0000Gooooo00?o0000ooooooooool00ol000000ooo
oooo0000ooooo`03o`0000oooooo0@000000000300000?oooooooooo00cooooo0_l000000ooooooo
0000o`000002o`0000?ooooo1?l000000ooooooo0000ooooo`09ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000Wooooo0_l0
0002ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Oo
oooo00?o0000ooooooooool01Oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo00Co0000
oooooooooooooooo0ol0000Kooooo`?o00000oooool2o`0000?ooooo00?o0000ooooool000000_l0
0007ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooooooo`;o00002Oooool01Ol0003ooooooooooooooooo0000
00oooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool0000;ooooo`;o000000Co
ooooo`000?l0003o00000oooool4o`000003ooooool0003ooooo00kooooo0@000000000300000?oo
oooooooo00cooooo0ol000000ooooooo0000ooooo`05o`0000;ooooo00Go0000oooooooooooo0000
ooooo`03o`0000?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02o`0000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
oooooooooooo0_l00003ooooo`;o00000oooool01?l0003oooooooooooooool3o`0000;ooooo00Go
0000ooooool0003oooooo`000002ooooo`04o`000?ooooooooooooooo`Co000000Goooooo`000?l0
003o0000ooooo`02o`0001Wooooo1ol000000ooooooo0000o`000002o`0000?ooooo00?o0000oooo
ool000000ol000001Ooooooo0000ooooool0003ooooo00;o00000oooool01?l0003ooooooooooooo
ool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooooooo`;o00000_ooool01?l0003oooooooooool00002oooo
o`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooool000000_ooool00ol0003oooooo`000002o`0000?ooooo00Co0000ooooool0003ooooo
1Ol000000ooooooo0000o`000002o`0000kooooo0@000000000300000?oooooooooo00_ooooo1Ol0
00000ooooooo0000o`000002o`0000;ooooo00Ko0000oooooooooooo0000ooooool00004ooooo`07
o`000?oooooo0000ooooool0003oooooo`000005ooooo`04o`000?ooooooooooo`0000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooooooo`;o000000Koooooo`000?oooooo0000ooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01ol0003oooooo`000?oooooo0000ooooool000001?ooool2o`000005
ooooool0003oooooooooool000000_ooool3o`0000;ooooo1?l000000ooooooo0000o`000002o`00
01Sooooo0ol000000ooooooo0000ooooo`03o`0000;ooooo00?o0000ooooool000000_ooool00ol0
003oooooo`000002ooooo`;o00001?ooool01?l0003oooooo`000?ooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`08o`000?oooooo0000o`000?oooooo0000ooooool00003oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;o00000_ooool01?l0003oooooooooool00005ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000004ooooo`04o`000?oooooo0000ooooo`;o000000Goooooo`000?l0003o0000ooooo`07
o`0000gooooo0@000000000300000?oooooooooo00[ooooo1?l000001?oooooo0000o`000?l00002
ooooo`03o`000?oooooo000000;ooooo0ol00006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000000?ooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o0000
5oooool3o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool000000oooool00ol0003o
ooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l00002ooooo`;o0000
0oooool2o`0000;ooooo00?o0000ooooool000003Oooool10000000000<00000ooooooooool02_oo
ool5o`0000;ooooo0ol000001ooooooo0000oooooooooooo0000ooooool000000_ooool3o`000003
ooooool0003ooooo00;o00000oooool2o`0000Cooooo0_l000000ooooooo0000ooooo`02ooooo`05
o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00003ooooo`;o00000_ooool2
o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooo`000004ooooo`05o`000?oo
ooooooooo`000?ooool02Ol0000Eooooo`_o00000_ooool00ol0003oooooooooo`03ooooo`;o0000
1Oooool2o`000003ooooool0003ooooo00Cooooo0_l00004ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`02o`0000;ooooo00Go0000ooooool0003oooooo`000003
ooooo`;o00001?ooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000ooooool000000_oo
ool01Ol0003oooooooooool0003ooooo00;o00000oooool00ol0003oooooo`000002o`0000cooooo
0@000000000300000?oooooooooo00Wooooo2?l000000ooooooo0000o`000003o`000005ooooool0
003oooooooooool000001?ooool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003ooooo
o`000005ooooo`;o00000_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l000000ooooooo
0000ooooo`02ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool00_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000ooooool0003ooooo0_l000000ooooooo0000ooooo`0:o`000004ooooool0003o0000ooooo`Co
00005?ooool3o`000005ooooool0003oooooo`000?ooool01Ol000002?oooooo0000o`000?oooooo
0000ooooool0003ooooo0ol00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`000004ooooool0003ooooo
o`0000;ooooo00Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooo000000?ooooo0_l0
0004ooooo`05o`000?ooooooooooooooool000000oooool7o`000003ooooool0003o000000Ko0000
2oooool10000000000<00000ooooooooool02Oooool3o`0000Gooooo00?o0000ooooooooool00ooo
ool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003o00001?ooool00ol0003o
ooooo`000005ooooo`;o00002?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`?o000000?oooooo`000?l000005?ooool00ol0003oooooo`000003o`00
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o
0000ooooool000001?ooool2o`000009ooooool0003oooooooooool0003oooooo`000?oooooo0000
00Gooooo00?o0000ooooooooool00oooool3o`0000_ooooo0@000000000300000?oooooooooo00So
oooo2?l000001Ooooooo0000o`000?oooooo000000Oooooo00?o0000ooooooooool00oooool3o`00
00Gooooo0_l00004ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0002ooooo`;o000000Koooooo`000?oooooo0000ooooool0000:ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool2
o`0000Cooooo00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00Co00004_ooool5o`000004
ooooool0003o0000o`0000;ooooo00Oo0000oooooooooooo0000ooooool0003ooooo00;o000000Co
ooooo`000?oooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool02?ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?ooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00Co
0000ooooool0003o00001Oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000o`0000;o
oooo2?l0000:ooooo`40000000000`00003oooooooooo`07ooooo`Co000000Coooooo`000?oooooo
oooo0ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?ooool01?l000001Ooo
oooo0000oooooooooooo000000;ooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooool000000oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000;ooooo
0_l00002ooooo`;o00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool02Ol0
003ooooooooooooooooo0000ooooool0003oooooo`000003ooooo`?o00000oooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000006o`00017ooooo
1ol000000ooooooo0000o`000007o`000003ooooool0003ooooo00?ooooo00Go0000oooooooooooo
0000ooooo`02o`0000?ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool00_l00002
ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`05o`000?ooooooooooo`000?oo
ool00_l000000ooooooo0000ooooo`05o`000004ooooool0003o0000ooooo`?o000000?oooooo`00
0?ooool01Ol00009ooooo`40000000000`00003oooooooooo`07ooooo`;o000000?oooooo`000?l0
00000ol0000;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00007ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000
ooooool0003oooooo`000005ooooo`;o000000?oooooo`000?ooool01?l0000@ooooo`Co000000Co
ooooo`000?oooooo00001_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`00
00Gooooo0_l00006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000000_l000001?oooooo0000ooooool0
0009ooooo`40000000000`00003oooooooooo`06ooooo`Go000000?oooooo`000?l000002Ol00000
1ooooooo0000oooooooooooo0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`00
00Gooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0
003oooooooooo`02o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000?ooooo0ol00003ooooo`;o00001Oooool3o`00
0004ooooool0003o0000o`0000;ooooo1ol0000>ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`Co000000?oooooo`000?l000001?ooool00ol0003oooooo`000003ooooo`?o00000oooool0
1ol0003oooooo`000?oooooo0000ooooool000001Oooool01?l0003oooooooooool00004ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool0
0_l00002ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`05o`000?oooooo0000ooooool000000_ooool6o`000003ooooool0003o000000;o000000?ooooo
o`000?l000000ol00008ooooo`40000000000`00003oooooooooo`05ooooo`Wo000000?oooooo`00
0?ooool01?ooool3o`000003ooooool0003ooooo00;ooooo0ol00002ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`08o`000?ooooooooooooooool0003oooooo`000?ooool2o`0000?ooooo0_l0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01ol0003oooooo`00
0?l0003oooooo`000?ooool00ol00002ooooo`03o`000?oooooo000000;ooooo2Ol0000=ooooo`Go
000000?oooooo`000?ooool00_l00002ooooo`06o`000?oooooo0000ooooool0003ooooo0_l00000
0ooooooo0000ooooo`03o`0000?ooooo00?o0000ooooool000001Oooool2o`0000;ooooo0_l00002
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00004
ooooo`04o`000?oooooo0000ooooo`;o00000_ooool00ol0003oooooo`000003o`0000Cooooo00?o
0000ooooool000002?l00008ooooo`40000000000`00003oooooooooo`05ooooo`?o000000Oooooo
o`000?oooooo0000ooooool0003ooooo00?o000000?oooooo`000?ooool01?ooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
o`000?l00003ooooo`Oo00003?ooool7o`0000?ooooo0ol00004ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000002ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo0000
00Sooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
0000o`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool3o`0000Oooooo0@00000000030000
0?oooooooooo00Cooooo2?l000000ooooooo0000o`000002ooooo`Ko000000Ooooooo`000?oooooo
0000ooooool0003ooooo00?o00000oooool01ol0003oooooo`000?oooooo0000ooooool000001Ooo
ool01?l0003oooooooooool0000=ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooooooo0_l000001Ooooooo0000ooooool0003ooooo00;o00000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`000003ooooool0
003o000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`Go000000?oooooo`000?ooool0
2ol0000:ooooo`Go000000?oooooo`000?l000000_l000001?oooooo0000ooooooooool3o`000004
ooooool0003oooooo`0000;ooooo00?o0000ooooool000000_ooool2o`000003ooooool0003o0000
00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00[o0000ooooooooooooooooo`000?oo
oooo0000ooooool0003ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooo
0000ooooo`?o00000oooool01?l0003oooooo`000?ooool2o`0000;ooooo00?o0000ooooool00000
0ol000001?oooooo0000ooooooooool:o`0000Oooooo0@000000000300000?oooooooooo00Cooooo
1ol000001?oooooo0000o`000?ooool3o`0000Gooooo0_l000000ooooooo0000ooooo`02o`0000?o
oooo0_l00007ooooo`04o`000?oooooo0000o`0000?ooooo00Co0000oooooooooooooooo0_l00000
0ooooooo0000o`000002ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool00_l00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01_l0
003oooooo`000?oooooo0000ooooo`;o000000Coooooo`000?l0003ooooo2?l0000:ooooo`ko0000
00Soooooo`000?oooooo0000ooooool0003oooooo`0000;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool2o`000003ooooool0003o000000;ooooo0_l00003ooooo`08o`000?ooooooooooo`000?oooooo
0000ooooool00006ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooo0000ooooo`02
o`0000Cooooo00?o0000ooooool000001?l000000ooooooo0000o`000005o`0000Kooooo0@000000
000300000?oooooooooo00?ooooo1Ol000000ooooooo0000o`000005ooooo`03o`000?oooooo0000
00;o000000Goooooo`000?ooooooooooo`000005ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02o`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000005ooooo`05o`000?oooooo0000ooooool00000
0_ooool2o`0000Wooooo0ol00002ooooo`05o`000?oooooo0000ooooool000001Oooool2o`0000Go
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Gooooo0_l00002
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo
0_l00002ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`06ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000;ooooo0ol000000ooooooo0000ooooo`03ooooo`?o000000?oooooo`000?l000000_l0
0006ooooo`40000000000`00003oooooooooo`03ooooo`Ko000000?oooooo`000?l000001?l00000
0ooooooo0000ooooo`02o`000007ooooool0003oooooooooool0003oooooo`000003ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02o`0000;ooooo
00[o0000ooooooooooooooooo`000?oooooo0000ooooool0003ooooo0_l000002?oooooo0000oooo
ool0003oooooo`000?oooooo00004?ooool01Ol0003ooooooooooooooooo000000Sooooo0_l00002
ooooo`;o00000oooool2o`0000?ooooo00Co0000ooooool0003ooooo0ol00002ooooo`?o000000Co
ooooo`000?l0003ooooo2?l00007ooooo`Wo000000?oooooo`000?l000001?l000000ooooooo0000
ooooo`02o`000004ooooool0003oooooo`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000So
oooo00Go0000ooooooooooooooooo`00000@ooooo`04o`000?oooooo0000ooooo`;o000000[ooooo
o`000?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooo`000002ooooo`;o000000Goooooo`000?oooooo0000ooooo`03o`00
0004ooooool0003o0000ooooo`Ko00001Oooool10000000000<00000ooooooooool00_ooool9o`00
0006ooooool0003o0000ooooool0003ooooo0_l00002ooooo`03o`000?oooooo000000Cooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`07ooooo`04o`000?oo
ooooooooo`00013ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00co0000oooooooooooo0000ooooool0003oooooo`000?oooooo
0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00So0000ooooooooooooooooo`000?oo
oooo0000ooooo`;o00000_ooool3o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooool0
00001ol00006ooooo`[o000000Coooooo`000?oooooooooo1Ol000001Ooooooo0000ooooool0003o
oooo00;o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000ooooool0003ooooo
0_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00kooooo00Go0000oooo
ooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000ooooool0003o0000
1?ooool2o`000004ooooool0003oooooooooo`;o000000?oooooo`000?ooool00_l000000ooooooo
0000o`000007o`0000Cooooo0@000000000300000?oooooooooo00;ooooo1_l000001Ooooooo0000
ooooool0003ooooo00;o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000001Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool00004ooooo`;o000000?oooooo`000?ooool00ol00003oooo
o`?o00001Oooool4o`0000?ooooo0_l00002ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ool000001Oooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo00Ko0000ooooool0003oooooo`000?ooool8o`0000Cooooo0@000000
000400000?ooooooooooooooo`Ko000000Coooooo`000?l0003ooooo0_l000000ooooooo0000oooo
o`03o`0000;ooooo0_l000002?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool2o`00
00?ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool01?l0003oooooooooool00003ooooo`;o00000_ooool2o`00
0003ooooool0003o000000;ooooo00?o0000ooooooooool00_l00002ooooo`07o`000?oooooooooo
ooooool0003oooooo`000002ooooo`;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00go
00001?ooool8o`000006ooooool0003o0000ooooool0003ooooo1Ol000000ooooooo0000ooooo`02
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`06o`000?ooooooooooooooool0003ooooo
0_l00002ooooo`;o00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o
000000Coooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000ooooool0003oooooo`000?ooool4
o`0000;ooooo0ol000000ooooooo0000ooooo`0<o`0000?ooooo0@000000000300000?oooooooooo
00Wo000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;o00000_ooool2
o`000003ooooool0003o000000;ooooo0_l00003ooooo`;o000000Goooooo`000?oooooo0000oooo
o`02o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Kooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Wooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo0_l00002ooooo`?o
000000?oooooo`000?l000000ol00002ooooo`[o00000_ooool:o`000003ooooool0003ooooo00Go
000000?oooooo`000?l000000_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
1Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?oo
oooo0000ooooool0003ooooo0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000;o
oooo0_l000001ooooooo0000ooooool0003oooooo`000?ooool00ol00002ooooo`_o00000_ooool1
0000000000<00000ooooooooool01Ol000002Ooooooo0000oooooooooooo0000ooooool0003ooooo
o`000002ooooo`03o`000?oooooooooo00;o00002oooool00ol0003oooooooooo`0>ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`08ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`000004ooooool0003o
ooooooooo`Ko00000_ooool6o`0000;ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000:oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00[ooooo0_l000000ooooooo0000ooooo`02ooooo`?o000000Coooooo`000?oooooo00000_oo
ool5o`0000;ooooo0@000000000300000?oooooo000000_o000000?oooooo`000?l000000_l00002
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`0=o`00
0?oooooo0000o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02o`0000?ooooo
00Go0000ooooooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000000oooool2o`00
00;ooooo0_l000001?oooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000002ooo
ool2o`0000;ooooo0_l000002_oooooo0000ooooool0003oooooo`000?oooooo0000ooooool00002
ooooo`04o`000?oooooo0000ooooo`?o000000?oooooo`000?l000006_l000000ooooooo0000oooo
o`02o`0000?ooooo00Ko0000ooooool0003oooooo`000?ooool2o`0000;ooooo0_l000001?oooooo
0000ooooool0000;ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000ooooool0003ooooo0_l0
00001?oooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000oooooooo
ooooooooo`000002ooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool2o`000006oooo
ool0003oooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00So0000
ooooooooooooooooo`000?oooooo0000oooooa3o00000Oooool10000000000<00000ooooool00000
1Ol00002ooooo`;o000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`02o`0000;o
oooo0_l00002ooooo`03o`000?oooooooooo00;o00005oooool00ol0003oooooooooo`02o`0000;o
oooo0_l00002ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_l00002ooooo`04
o`000?ooooooooooo`00013ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Co00000_ooool<o`0000;ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool03oooool01?l0003oooooo`000?l00002ooooo`;o0000
0_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o00000_ooool01?l0003ooooo
ooooool0000Hooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo0_l00002ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`000003ooooool0003ooooo00Go00000Oooool10000
000000<00000ooooool000002?l000001ooooooo0000o`000?l0003oooooo`000?ooool01?l00002
ooooo`;o000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`02o`0000;ooooo0_l0
0002ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_oo
ool2o`0000_ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
ooooo`02o`0000;ooooo0ol000000ooooooo0000ooooo`05o`000003ooooool0003o000001;o0000
00Goooooo`000?oooooo0000ooooo`03o`000004ooooool0003o0000o`0000;ooooo00?o0000oooo
ooooool00_l00002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool02_ooool2o`00
00;ooooo00?o0000ooooooooool00_l00002ooooo`;o00000_ooool01?l0003oooooooooool0000A
ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo0_l000001Ooooooo0000oooo
ool0003ooooo00?o000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`00007ooooo
0@000000000300000?oooooo000000_o000000Coooooo`000?l0003ooooo1?l00002ooooo`;o0000
00Koooooo`000?oooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool01Oooool03Ol0003oooooooooool0003oooooo`000?oooooo0000ooooool0003ooooo
o`000?ooool00_l000002?oooooo0000ooooool0003oooooo`000?oooooo00004?ooool01?l0003o
ooooooooool00002ooooo`;o000000Koooooo`000?oooooo0000ooooool00003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000?oooooo`000?l0
00000_l000001Ooooooo0000o`000?l0003ooooo01Go000000Coooooo`000?oooooooooo1Ol00000
1Ooooooo0000o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`0>ooooo`04o`000?oooooo0000ooooo`;o000000Wooooo
o`000?oooooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000oooool01_l0003ooooooooooooooooo
0000ooooo`;o00000_ooool2o`000003ooooool0003ooooo00Ko000000?oooooo`000?l000002Ol0
0002ooooo`40000000000`00003oooooooooo`0:o`000007ooooool0003o0000ooooool0003ooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool05_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oo
oooooooo00Wooooo0_l00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool3o`000006
ooooool0003o0000ooooool0003ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_l0
000;ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000001Oooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooool0003oooooo`000007ooooo`08o`000?ooooooooooooooool0003o
ooooo`000?ooool6o`000003ooooool0003o000000Co00000_ooool10000000000<00000oooooooo
ool03?l000001Ooooooo0000o`000?l0003ooooo00?o000000Coooooo`000?oooooo00000oooool0
1?l0003oooooooooool00002ooooo`;o00000_ooool01?l0003oooooooooool00009ooooo`0:o`00
0?ooooooooooooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_l000001Ooooooo0000ooooool0003ooooo00;o00000oooool2
o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`05o`000?oooooo0000o`000?ooool00ol0
00001?oooooo0000o`000?ooool<o`0000?ooooo3ol00002ooooo`;o000000Ooooooo`000?oooooo
0000ooooool0003ooooo00;o00000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000
ooooo`;o00000_ooool2o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;o
oooo0_l000000ooooooo0000o`000002ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0
003ooooooooooooooooo000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00;o000000Koooooo`000?l0003oooooo`000?ooool2o`000003ooooool0003o000000?o0000
00?oooooo`000?l000001Ol00003ooooo`40000000001000003oooooooooooooool8o`000005oooo
ool0003oooooo`000?ooool01?l000001Ooooooo0000o`000?oooooo000000;ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02o`0000;ooooo0_l00002ooooo`;o00002oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02o`0000;ooooo00So0000
ooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool3o`0000?ooooo0ol000001?oooooo
0000o`000?ooool9o`0000Cooooo2ol00002ooooo`03o`000?oooooo000000?ooooo0ol000001ooo
oooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Wooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003ooooo
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000002ooooo`;o00000_ooool0
1ol0003oooooo`000?l0003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00So
00000oooool10000000000<00000ooooooooool00_ooool3o`000003ooooool0003ooooo00;o0000
00?oooooo`000?l000001_ooool01?l0003oooooooooooooool2o`0000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool02?ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001Oooool00ol0003oooooo`000002
ooooo`05o`000?oooooo0000o`000?ooool00_l000000ooooooo0000o`000004o`0000Kooooo1_l0
00003?oooooo0000o`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`0000Gooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00000oooool00ol0
003oooooooooo`03ooooo`Ko000000?oooooo`000?ooool00ol00004ooooo`40000000000`00003o
ooooooooo`02ooooo`Ko000000?oooooo`000?l000000oooool5o`00000:ooooool0003oooooo`00
0?oooooo0000ooooool0003oooooo`0000;ooooo0_l00003ooooo`0:o`000?ooooooooooooooool0
003oooooo`000?oooooo0000ooooo`;o000000Coooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02o`0000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000
ooooool000000oooool3o`000005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00
0009o`0000Kooooo2ol000000ooooooo0000o`000004o`000004ooooool0003o0000o`0000?ooooo
00?o0000ooooool000000_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool2o`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o00000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l000002_oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo0_l000001_oooooo0000oooo
oooooooo0000ooooo`?o00000_ooool00ol0003oooooo`000006o`0000Gooooo0@00000000030000
0?oooooooooo00?ooooo2?l000002?oooooo0000o`000?oooooo0000ooooool0003ooooo1?l00003
ooooo`05o`000?oooooo0000ooooool000000oooool2o`0000?ooooo0_l000000ooooooo0000o`00
0002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooooooool2o`000004ooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool00_l00002ooooo`;o00002?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooooooool2o`0000Cooooo
0_l000000ooooooo0000o`000007o`0000Sooooo1Ol000000ooooooo0000o`000004o`0000Cooooo
0_l000001Ooooooo0000oooooooooooo000000Cooooo0_l00002ooooo`04o`000?ooooooooooo`00
00Sooooo0_l00002ooooo`05o`000?ooooooooooooooool000000oooool01_l0003oooooo`000?l0
003oooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo0000o`0000;ooooo0_l00003
ooooo`;o00000oooool01Ol0003oooooo`000?oooooo000000?ooooo0ol000001_oooooo0000oooo
oooooooo0000ooooo`;o000000?oooooo`000?l000001_l00005ooooo`40000000000`00003ooooo
ooooo`04ooooo`?o000000Koooooo`000?ooooooooooo`000?ooool2o`0000;ooooo0_l00006oooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00;ooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000_oo
ool:o`0000Wooooo2?l000000ooooooo0000ooooo`02ooooo`?o000000?oooooo`000?ooool00_oo
ool01?l0003oooooooooooooool2o`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00cooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo0_l00006ooooo`;o00000_ooool2o`000006ooooool0003oooooooooool0003ooooo0ol00006
ooooo`40000000000`00003oooooooooo`04ooooo`So000000?oooooo`000?l000000_l00002oooo
o`03o`000?oooooo000000;o00001?ooool2o`000003ooooool0003o000000;ooooo00?o0000oooo
ool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00003Ooo
ool01?l0003oooooooooool00002ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00001Oooool2o`0000?ooooo0_l00003ooooo`04
o`000?oooooo0000ooooo`?o000000Coooooo`000?oooooooooo0ol000000ooooooo0000o`000002
o`000003ooooool0003o000000?o00002_ooool5o`000003ooooool0003o000000;o000000Oooooo
o`000?l0003o0000ooooool0003ooooo00;o000000Koooooo`000?oooooo0000ooooool00003oooo
o`;o00000_ooool00ol0003oooooo`000005ooooo`;o00000_ooool2o`0000?ooooo00?o0000oooo
ooooool00_l00002ooooo`;o00000_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00001?ooool4o`000003oooo
ool0003ooooo00;o000000Coooooo`000?oooooooooo2?l00006ooooo`40000000000`00003ooooo
ooooo`05ooooo`Wo000000Coooooo`000?l0003ooooo0ol000001?oooooo0000ooooooooool3o`00
00?ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000;ooooo0_l000001Ooooooo
0000ooooool0003ooooo00;o00003Oooool01?l0003oooooooooool00003ooooo`09o`000?oooooo
ooooooooool0003oooooo`000?oooooo000000?ooooo00_o0000ooooooooooooooooo`000?oooooo
0000ooooool0003oooooo`000004ooooo`;o000000Goooooo`000?l0003o0000ooooo`02o`000003
ooooool0003o000000Go00003?ooool7o`000003ooooool0003o000000Co000000?oooooo`000?l0
00001?ooool2o`0000;ooooo0_l00004ooooo`09o`000?ooooooooooooooool0003oooooo`000?oo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00[ooooo
00Co0000ooooool0003ooooo0_l00002ooooo`;o000000Koooooo`000?oooooo0000ooooool00003
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`?o000000?oooooo`000?ooool01?l000000ooooooo
0000o`00000:o`0000Oooooo0@000000000300000?oooooooooo00Gooooo0ol000001?oooooo0000
ooooool00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`00
00?ooooo00?o0000ooooooooool00_ooool01ol0003oooooo`000?oooooo0000ooooool000001_oo
ool01?l0003oooooooooooooool4o`0000cooooo1?l00003ooooo`03o`000?oooooooooo00?ooooo
00So0000oooooooooooo0000ooooool0003oooooo`0000Cooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000000;ooooo0_l00008ooooo`40000000000`00003oooooooooo`06ooooo`Co
000000?oooooo`000?l000000_l000001?oooooo0000ooooooooool3o`000006ooooool0003o0000
ooooool0003ooooo0_l00004ooooo`07o`000?ooooooooooooooool0003oooooo`000005ooooo`;o
00000oooool01ol0003oooooooooool0003oooooo`000?ooool00_l00002ooooo`;o000000?ooooo
o`000?ooool00_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01_l0003o
ooooooooool0003oooooo`0000Cooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`00
0002o`000003ooooool0003o000000Go00003_ooool;o`000005ooooool0003oooooo`000?ooool0
0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00002
ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o000000Goooooo`000?oooooo
0000ooooo`02o`0000?ooooo00Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooool000000_l000000ooo
oooo0000o`000002ooooo`03o`000?oooooo000000?o000000?oooooo`000?l000000_l00008oooo
o`40000000000`00003oooooooooo`07ooooo`Ko000000Coooooo`000?l0003ooooo0_l00002oooo
o`03o`000?oooooooooo00;ooooo00Ko0000ooooool0003oooooo`000?ooool2o`0000?ooooo0_l0
0003ooooo`04o`000?oooooo0000o`0000Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?ooooooooooooooool000000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000?o
00000_ooool8o`0000oooooo2Ol00002ooooo`Co000000Goooooo`000?oooooo0000ooooo`02o`00
0005ooooool0003oooooooooool000000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02o`0000;ooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00003oooo
o`;o000000?oooooo`000?ooool00_l00005ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?l000001_l00009ooooo`40000000000`00003oooooooooo`07ooooo`?o00000_ooool01?l0
003oooooo`000?l00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`00
0004ooooo`05o`000?ooooooooooooooool000002oooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`02o`00013ooooo0_l0
00000ooooooo0000ooooo`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooooooo
o`000009ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000_ooooo00Go0000oooooooo
ooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool00ol0003ooooooooo
o`02o`000003ooooool0003ooooo00Co00002Oooool10000000000<00000ooooooooool01oooool7
o`0000;ooooo1ol000000ooooooo0000ooooo`03ooooo`;o00000_ooool00ol0003oooooo`000004
ooooo`05o`000?oooooo0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`;o00000_oo
ool2o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`0<o`000?ooooooooooo`000?oo
oooo0000ooooool0003oooooo`000?oooooo00000_ooool2o`0000;ooooo00?o0000ooooooooool0
0_ooool2o`000004ooooool0003oooooo`0000?ooooo0_l000001Ooooooo0000ooooool0003ooooo
00?o000000?oooooo`000?l000002ol0000Aooooo`Ko000000?oooooo`000?l000000ol000001Ooo
oooo0000o`000?oooooo000000;ooooo00?o0000ooooool000000_l00003ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Ko
0000ooooool0003oooooo`000?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Oooooo00?o0000ooooooooool01Oooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooo000000?ooooo0_l00004ooooo`03o`000?oo
oooo000000;o000000?oooooo`000?l000000oooool6o`0000[ooooo0@000000000300000?oooooo
oooo00Sooooo1Ol000001?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo00;ooooo00So
0000ooooool0003o0000ooooool0003oooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooo000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo0_l000001?oooooo0000ooooool00003ooooo`?o00000oooool2o`0000?ooooo00?o0000
ooooool000000_ooool2o`000003ooooool0003o000000Ko00004_ooool6o`000004ooooool0003o
0000o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003ooooo`?o0000
0oooool01?l0003oooooo`000?ooool2o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo0_l000001Ooooooo0000
oooooooooooo000000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00?o0000oooo
ool000001?l00005ooooo`03o`000?oooooooooo00Wo00002_ooool10000000000<00000oooooooo
ool02Oooool6o`0000;ooooo0ol000000ooooooo0000ooooo`02o`0000Oooooo00Ko0000oooooooo
oooo0000ooooool00005ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo0000013ooooo0_l00003ooooo`03o`000?oooooooooo01;ooooo
00Go0000oooooooooooo0000ooooo`02o`0000?ooooo00Wo0000ooooool0003o0000ooooool0003o
ooooo`000?ooool00ol0000Dooooo`;o00000_ooool2o`000003ooooool0003ooooo00?o00000ooo
ool2o`000004ooooool0003oooooo`0001Gooooo00Ko0000oooooooooooo0000ooooool0000@oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Ko0000oooooooooooo0000ooooool00007ooooo`06o`000?oooooo0000oooo
ool0003ooooo0_l00003ooooo`Ko00002oooool10000000000<00000ooooooooool02Oooool3o`00
0003ooooool0003ooooo00?o00000_ooool01?l0003oooooo`000?l00002ooooo`04o`000?oooooo
0000ooooo`;o000000Goooooo`000?ooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooo`00000=ooooo`04o`000?oooooo0000o`00
00;ooooo0_l000001?oooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003oooooo`000?oooooo000000?ooooo0ol00003ooooo`03o`000?oooooo000000Oooooo
0_l000001?oooooo0000ooooooooool7o`0001Gooooo2?l00002ooooo`04o`000?oooooo0000o`00
00Oooooo00?o0000ooooool000000_ooool01?l0003oooooo`000?l00003ooooo`04o`000?oooooo
0000o`0000Cooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo0_l000001_oooooo0000
ooooool0003oooooo`0000cooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`06
o`000?oooooo0000ooooool0003ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Go00003?oo
ool10000000000<00000ooooooooool02_ooool7o`000004ooooool0003oooooo`0000;ooooo00Co
0000ooooool0003ooooo0_l000000ooooooo0000ooooo`03ooooo`;o00000_ooool2o`0000?ooooo
0_l00003ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`;o00000_ooool2o`000003
ooooool0003o000000;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
00?ooooo0_l00003ooooo`04o`000?oooooo0000o`0000Cooooo00Oo0000oooooooooooo0000oooo
ool0003ooooo00Co000000Coooooo`000?oooooooooo1_l000000ooooooo0000o`000003o`0001Ko
oooo1?l000000ooooooo0000ooooo`05o`0000;ooooo00co0000ooooool0003o0000ooooool0003o
ooooo`000?oooooo0000ooooool00004ooooo`;o00000_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00Go0000ooooooooooooooooo`00000:ooooo`04o`000?oooooo0000o`0000;ooooo
0_l00002ooooo`;o000000?oooooo`000?ooool00_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003oooooo`0000Cooooo00So0000
ooooool0003o0000ooooool0003oooooo`0000;ooooo00Co0000ooooool0003ooooo1ol0000<oooo
o`40000000000`00003oooooooooo`0;ooooo`;o000000Coooooo`000?oooooo00000_ooool01Ol0
003oooooo`000?l0003ooooo00;o000000Coooooo`000?oooooo00000_ooool3o`0000Oooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000001Gooooo0_l00002ooooo`;o0000
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool4o`00
0003ooooool0003o000001Sooooo0_l000000ooooooo0000o`000002o`0000;ooooo00?o0000oooo
ool000000_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooool0003oooooo`000002ooooo`;o000000?oooooo`000?l000000_l00000
2?oooooo0000oooooooooooo0000ooooool0003ooooo0_l0000=ooooo`40000000000`00003ooooo
ooooo`0;ooooo`Wo000000Goooooo`000?ooooooooooo`000007ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02o`0000Cooooo00So0000oooooooo
ooooooooo`000?oooooo0000ooooo`;o000000Koooooo`000?oooooo0000ooooool00003ooooo`03
o`000?oooooooooo00[ooooo00Co0000oooooooooooo00000_ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool2o`000005ooooool0003oooooo`000?ooool00_l000001?oooooo0000ooooool0
0002ooooo`07o`000?ooooooooooo`000?oooooo0000ooooo`06o`0001Sooooo0_l000001Ooooooo
0000o`000?l0003ooooo00;o00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000000;o00000_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;ooooo0_l00000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Ko0000ooooooooooooooooo`00
0?ooool2o`000008ooooool0003oooooo`000?oooooo0000ooooool00003ooooo`03o`000?oooooo
oooo00;ooooo0_l000000ooooooo0000ooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooo`000?ooool02Ol0000=ooooo`40000000000`00003oooooooooo`0<
ooooo`Co000000Koooooo`000?ooooooooooo`000?ooool2o`000004ooooool0003o0000ooooo`Co
000000Goooooo`000?oooooo0000ooooo`02o`0000?ooooo00?o0000ooooool000001Oooool2o`00
00?ooooo0_l0000<ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000;ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004?l0000Jooooo`Oo0000
00Goooooo`000?l0003o0000ooooo`02o`000005ooooool0003o0000ooooool000001Oooool00ol0
003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00002ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool02_ooool2o`0000?ooooo0_l00005ooooo`03o`000?oooooo000000?ooooo0ol0
0002ooooo`04o`000?oooooo0000ooooo`[o00000_ooool00ol0003oooooo`000003o`0000kooooo
0@000000000300000?oooooooooo00cooooo1Ol000000ooooooo0000o`000005ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`;o00000_oo
ool2o`0000;ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo0_l00005ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`00000Kooooo`;o000000?oooooo`000?ooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Gooooo0_l0000=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l000001?oooooo
0000ooooool0000;ooooo`04o`000?ooooooooooooooo`;o00003_ooool00ol0003oooooooooo`03
ooooo`;o000000?oooooo`000?ooool00ol0000?ooooo`40000000000`00003oooooooooo`0=oooo
o`Ko000000Coooooo`000?l0003o00001Oooool00ol0003oooooo`000002ooooo`?o000000Cooooo
o`000?oooooo00001?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000009ooooo`04o`000?ooooooooooo`0000?ooooo0_l00002ooooo`;o000000?ooooo
o`000?ooool00_ooool01?l0003oooooooooooooool2o`0000?ooooo0_l000001?oooooo0000oooo
ool00005ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000000_ooool3o`000003oooo
ool0003o000000?o00007?ooool5o`000003ooooool0003o000000?ooooo00?o0000ooooool00000
1?ooool4o`0000Gooooo00Co0000ooooool0003ooooo0_l00003ooooo`;o00000oooool01?l0003o
ooooooooool00002ooooo`;o000000Coooooo`000?oooooo00000_ooool01Ol0003ooooooooooooo
oooo000000Wooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00oooool01?l0003oooooo`000?ooool3o`0000;ooooo00?o0000ooooool00000
1?ooool2o`000003ooooool0003ooooo00Ko00003oooool10000000000<00000ooooooooool03_oo
ool4o`000005ooooool0003o0000o`000?ooool01_l000001?oooooo0000o`000?l00005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01_ooool01?l0003oooooo`000?ooool2o`0000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`Co000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000?oooooo`00
0?l000000ol000000ooooooo0000o`000005o`0001kooooo1Ol000000ooooooo0000ooooo`02o`00
0004ooooool0003o0000ooooo`Co000000Goooooo`000?oooooo0000ooooo`02o`000005ooooool0
003oooooooooool000001?ooool02ol0003ooooooooooooooooo0000ooooool0003oooooo`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool01Ol0003ooooo
oooooooooooo000000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000004oooo
o`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`000?ooool5o`000004ooooool0003o
0000ooooo`Go00004?ooool10000000000<00000ooooooooool03_ooool6o`000005ooooool0003o
ooooooooool000001?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
2?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?oooooo0000ooooool000001oooool00ol0003oooooooooo`02
ooooo`;o00000oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000ooooool0003o00007oooool2o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0>ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooooooo`05oooo
o`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000cooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooo`000?ooool01Ol0000Aooooo`40
000000000`00003oooooooooo`0?ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`000003
ooooool0003ooooo00?ooooo00?o0000ooooooooool00ol000001Ooooooo0000oooooooooooo0000
00Cooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo0_l00002ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`;o00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000So00008?oo
ool7o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
o`000004ooooo`03o`000?oooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`?o000000?oooooo`000?oo
ool01?ooool00ol0003oooooo`000002o`000005ooooool0003o0000o`000?ooool00_l0000Aoooo
o`40000000000`00003oooooooooo`0@ooooo`Oo00000_ooool2o`000004ooooool0003o0000oooo
o`;o00001_ooool2o`000003ooooool0003ooooo00;o00001?ooool01ol0003ooooooooooooooooo
0000ooooool000002Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`00
00Gooooo00Ko0000ooooool0003oooooo`000?ooool2o`000004ooooool0003o0000ooooo`;o0000
00Koooooo`000?l0003oooooo`000?ooool4o`00027ooooo1Ol000000ooooooo0000ooooo`02o`00
0005ooooool0003o0000o`000?ooool01Ol00002ooooo`03o`000?oooooo000000Cooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o0000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool0
00000_ooool2o`0000Cooooo0_l000000ooooooo0000ooooo`02o`0000Kooooo1_l000001?oooooo
0000ooooooooool7o`0001;ooooo0@000000000300000?oooooooooo013ooooo00?o0000oooooooo
ool01?ooool2o`0000;ooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oooooo0000
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00Co0000
ooooool0003o00001oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooool000001?l0000Rooooo`?o000000Coooooo`000?oooooo00000oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003oooooo`00
0?oooooo000000Sooooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool00ol0003oooooo`000004ooooo`06o`000?ooooooooooo`000?oooooo00001Ooo
ool2o`0001;ooooo0@000000000300000?oooooooooo017ooooo0ol000000ooooooo0000ooooo`02
o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo00Oo0000
ooooooooooooooooo`000?oooooo000000Cooooo0_l00008ooooo`05o`000?oooooo0000ooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000005
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooool000000_ooool5o`0000;ooooo00Co
0000oooooooooooo00000_ooool2o`000005ooooool0003o0000o`000?ooool00_l0000Tooooo`03
o`000?oooooo000000?o000000?oooooo`000?l000000_ooool01ol0003oooooooooool0003ooooo
o`000?ooool00_l000001?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooo`000?l00009ooooo`;o00001?ooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Go000000?ooooo
o`000?l000000ol0000Cooooo`40000000000`00003oooooooooo`0Booooo`03o`000?oooooo0000
00;o00000oooool2o`000004ooooool0003o0000ooooo`?o00000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000ooooool0
003ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o00000_ooool01Ol0003oooooooooool0003ooooo00;o00000oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000_ooool2o`000003oooo
ool0003o000000;o00009_ooool4o`000004ooooool0003o0000ooooo`Oo000000?oooooo`000?oo
ool01Oooool00ol0003oooooooooo`02ooooo`?o00000oooool01?l0003oooooo`000?l00008oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l0
00001?oooooo0000ooooool00003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00So0000ooooool0003oooooo`000?oooooo0000ooooo`;o000000Koooooo`000?l0003o0000
ooooool00002ooooo`Co000000?oooooo`000?ooool04oooool10000000000<00000ooooooooool0
4_ooool2o`0000;ooooo00Co0000ooooool0003o00003Oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<oooo
o`;o00001Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000009_ooool5
o`000003ooooool0003ooooo00Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00oooool2o`0000kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`0<ooooo`;o000000?oooooo`000?ooool00_l0000Eooooo`40000000000`00003ooooooooo
o`0Cooooo`Oo000000?oooooo`000?l000000_ooool00ol0003oooooo`000003ooooo`;o00001_oo
ool00ol0003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool2o`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`;o000000?oooooo`000?l000000_ooool2o`00
00Gooooo00?o0000ooooool000000_ooool2o`0000Cooooo0_l000000ooooooo0000ooooo`02o`00
0004ooooool0003oooooo`0000Cooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo
oooo00;o00009oooool3o`000004ooooool0003oooooooooo`?o000000?oooooo`000?ooool01?oo
ool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003o00001?ooool01ol0003o
oooooooooooooooo0000ooooool000001Oooool2o`000003ooooool0003o000000;ooooo0_l00002
ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool0
00000_ooool01_l0003oooooooooool0003oooooo`0000Kooooo0_l00002ooooo`04o`000?oooooo
ooooo`0000;ooooo0ol000000ooooooo0000o`000004o`0001Gooooo0@000000000300000?oooooo
oooo01?ooooo0_l00002ooooo`03o`000?oooooo000000?o000000Goooooo`000?l0003o0000oooo
o`03o`000005ooooool0003oooooo`000?ooool00_l00004ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?oooooo0000ooooool000000oooool00ol0003ooooo
ooooo`02ooooo`;o000000Goooooo`000?ooooooooooo`000006ooooo`Go000000?oooooo`000?l0
00000_ooool7o`0002Wooooo1ol00003ooooo`;o000000Koooooo`000?l0003o0000ooooool00005
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00004ooooo`06o`000?ooooooooooooooool0003o
oooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooool000000ol000001?oooooo0000o`000?ooool2o`000005oooo
ool0003oooooo`000?ooool00_l0000Fooooo`40000000000`00003oooooooooo`0Dooooo`?o0000
0_ooool2o`0000;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02o`0000[ooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000Gooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool02?l0003o
ooooooooool0003oooooo`000?oooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooooooool2o`0001Oooooo0@000000000300000?oooooooooo
01Gooooo1_l000000ooooooo0000o`000002ooooo`07o`000?ooooooooooo`000?oooooo0000oooo
o`02o`000005ooooool0003oooooo`000?ooool00_l00004ooooo`05o`000?oooooo0000ooooool0
00001oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`;o000000?oooooo`000?l000001?ooool2o`000005ooooool0003oooooooooool000001Ooo
ool00ol0003oooooo`000004ooooo`05o`000?ooooooooooo`000?ooool01?l000001?oooooo0000
o`000?l0000[ooooo`Co000000?oooooo`000?l000000_l000001Ooooooo0000oooooooooooo0000
00Cooooo0_l00006ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool2o`0000;ooooo0_l0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l00007ooooo`;o0000
0_ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool01?l000001?oooooo0000
ooooool00002ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000001?l0000Gooooo`40
000000000`00003oooooooooo`0Fooooo`Co000000Coooooo`000?l0003ooooo2?l00006ooooo`;o
00001?ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00So
0000oooooooooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooool000001Ol000001?oo
oooo0000o`000?l00002ooooo`Go0000;Oooool2o`000004ooooool0003o0000o`0000;ooooo1?l0
00001?oooooo0000o`000?ooool2o`000005ooooool0003oooooo`000?ooool00_l000001Ooooooo
0000oooooooooooo000000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooooooo0_l000001?oooooo0000oooo
ool00006ooooo`;o00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Go0000
0_ooool2o`000003ooooool0003o000000;o00006?ooool10000000000<00000ooooooooool05_oo
ool00ol0003oooooo`000002o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool02Ooo
ool2o`0000Cooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0000oooooo00?o0000ooooooooool02oooool2o`000003ooooool0003ooooo00?o0000
;_ooool2o`0000;ooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0<ooooo`05o`00
0?ooooooooooooooool000002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Co
oooo0_l0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_l000000ooooooo
0000o`00000Hooooo`40000000000`00003oooooooooo`0Gooooo`;o000000Coooooo`000?oooooo
oooo0ol000000ooooooo0000ooooo`04ooooo`?o000000Coooooo`000?oooooo00000_ooool00ol0
003oooooooooo`02ooooo`;o00000oooool01Ol0003oooooo`000?oooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooo`000?l00005ooooo`;o00000oooool00ol0003oooooo`000002oooo
o`;o000000?oooooo`000?l000001Ol0000`ooooo`Go000000Coooooo`000?l0003o00000oooool0
0ol0003oooooo`000002ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`02o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`;o00001?ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooo000000;o00001Oooool00ol0003oooooo`000002o`000003
ooooool0003ooooo00?o00006Oooool10000000000<00000ooooooooool06?ooool5o`0000?ooooo
1?l000000ooooooo0000o`000007ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool2o`00
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool2
o`0000Gooooo00?o0000ooooool000001?ooool2o`000004ooooool0003oooooo`0000;ooooo0_l0
00001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`000?ooool00_l0000booooo`?o0000
00?oooooo`000?ooool02?l000001?oooooo0000ooooool00002ooooo`Co00001?ooool00ol0003o
ooooo`000005ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`;o00001?ooool01_l0003oooooooooool0003oooooo`0000Oooooo
1?l000000ooooooo0000o`000003ooooo`Ko00006_ooool10000000000<00000ooooooooool06?oo
ool2o`000006ooooool0003oooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`04
o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`02oooo
o`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ool000000oooool2o`0000kooooo00Co0000oooooooooooo00000_ooool2o`0000;ooooo0ol0000b
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000kooooo0_l0
0003ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000002ooooo`03o`000?oo
oooo000000Cooooo00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo00?o0000oooo
ooooool06Oooool10000000000<00000ooooooooool06Oooool3o`000003ooooool0003o000000;o
000000Goooooo`000?ooooooooooo`000004ooooo`;o00001_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`04o`00
0?ooooooooooooooo`;o000000?oooooo`000?ooool00_ooool2o`0000Cooooo0ol00002ooooo`?o
000000Coooooo`000?oooooo00000oooool01?l0003oooooo`000?l00003ooooo`Co0000=?ooool4
o`0000;ooooo0ol000001Ooooooo0000oooooooooooo000000;ooooo00?o0000ooooool000000_l0
00000ooooooo0000ooooo`02o`0000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`02o`0000?ooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00?ooooo00Oo
0000ooooooooooooooooo`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000004ooooo`05o`000?ooooooooooo`000?ooool01?l000001?oooooo0000o`000?l0000K
ooooo`40000000000`00003oooooooooo`0Jooooo`Go00000_ooool01Ol0003oooooo`000?l0003o
oooo00;o000000Koooooo`000?ooooooooooo`000?ooool5o`0000?ooooo00?o0000ooooool00000
1Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooo000000?ooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo2?l00002oooo
o`;o000000Coooooo`000?l0003o0000=_ooool6o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00001Ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooo000000?o000000?oooooo`000?ooool00_l000000ooo
oooo0000o`000005o`0000;ooooo1Ol0000Looooo`40000000000`00003oooooooooo`0Jooooo`?o
00000_ooool2o`0001?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`06ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`0000[ooooo00Go0000oooo
ool0003oooooo`000004ooooo`03o`000?oooooo000000Wooooo0_l000000ooooooo0000ooooo`0f
ooooo`;o000000?oooooo`000?ooool02Oooool00ol0003oooooo`000003ooooo`06o`000?oooooo
ooooo`000?oooooo00002_ooool2o`000003ooooool0003ooooo00;ooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooooooo`;o00005?ooool01?l0003oooooooooooooool2
o`0001gooooo0@000000000300000?oooooooooo01_ooooo1Ol000001?oooooo0000o`000?l00002
ooooo`05o`000?ooooooooooo`000?ooool00_l000000ooooooo0000ooooo`02ooooo`?o00000ooo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00002ooooo`05o`000?ooooooooooooooool0
00001_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooo`000?l00006ooooo`03o`000?oooooo000000?o000000?oooooo`000?ooool00_l0
000hooooo`;o000000?oooooo`000?ooool00_l000001?oooooo0000ooooool00005ooooo`Co0000
1?ooool01?l0003oooooooooooooool3o`0000;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0ol00003
ooooo`;o000000Koooooo`000?oooooo0000ooooool00003ooooo`04o`000?oooooo0000ooooo`Go
00007Oooool10000000000<00000ooooooooool07?ooool3o`000005ooooool0003o0000o`000?oo
ool00_l000003?oooooo0000o`000?l0003oooooo`000?oooooo0000ooooool0003oooooo`0000Co
oooo00So0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool00000
0_ooool2o`0000Cooooo00Go0000ooooool0003o0000ooooo`04o`0000?ooooo1Ol0000jooooo`Go
00000oooool01Ol0003oooooo`000?l0003ooooo00?o00001Oooool2o`000005ooooool0003ooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0_ooool03?l0003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`;o0000
1?ooool00ol0003oooooo`000002ooooo`05o`000?oooooo0000o`000?ooool02?l000000ooooooo
0000ooooo`02o`0001kooooo0@000000000300000?oooooooooo01gooooo1_l00002ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001oooool02_l0003oooooooooool0003oooooo`00
0?oooooo0000ooooool0000looooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Ko00007oooool1
0000000000<00000ooooooooool07Oooool4o`0000;ooooo0ol000001_oooooo0000oooooooooooo
0000ooooo`Co000000Koooooo`000?oooooo0000ooooool00004ooooo`;o00000_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000?ooooo00Co0000oooo
ool0003ooooo0_l00005ooooo`?o000000Coooooo`000?oooooo00000oooool8o`0003gooooo1_l0
00000ooooooo0000o`000002ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000001?oo
ool01?l0003oooooo`000?ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooool0003oooooo`000004ooooo`08o`000?oooooo0000
ooooool0003oooooo`000?ooool2o`000006ooooool0003oooooooooool0003ooooo0ol00002oooo
o`Co00007oooool10000000000<00000ooooooooool07_ooool6o`0000;ooooo0_l000000ooooooo
0000o`000002o`0000Gooooo00?o0000ooooool000000_ooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000001?oooooo
0000ooooool00003ooooo`?o00000_ooool01?l0003oooooo`000?ooool2o`000005ooooool0003o
0000ooooool000000_ooool00ol0003oooooo`000002o`0003kooooo0ol000001?oooooo0000oooo
ool00002ooooo`?o000000Woooooo`000?oooooo0000ooooool0003oooooo`000?ooool00_l00003
ooooo`04o`000?oooooo0000ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo0_l00006ooooo`;o000000Go
ooooo`000?l0003oooooo`000002ooooo`Ko00008?ooool10000000000<00000ooooooooool07ooo
ool2o`0000?ooooo0_l00008ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`03
o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l000001?oooooo
0000o`000?l00010ooooo`?o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004
ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000008ooooo`;o0000
0oooool2o`00027ooooo0@000000000300000?oooooooooo023ooooo1_l000000ooooooo0000o`00
0002ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00oooool01?l0003oooooo`00
0?ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`08o`000?ooooooooooo`00
0?oooooo0000ooooool00003ooooo`;o000000Goooooo`000?oooooo0000ooooo`06o`0000?ooooo
1?l000000ooooooo0000o`000002o`00047ooooo1Ol000001?oooooo0000o`000?l00004ooooo`Go
00000_ooool01Ol0003oooooo`000?oooooo000000Cooooo0_l000000ooooooo0000ooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03ooooo`06o`000?oooooo
ooooo`000?oooooo00001?ooool2o`000008ooooool0003oooooooooool0003oooooo`000?ooool4
o`000004ooooool0003o0000o`0002;ooooo0@000000000300000?oooooooooo023ooooo1?l00000
0ooooooo0000ooooo`02o`000009ooooool0003o0000ooooool0003oooooo`000?oooooo000000;o
oooo00?o0000ooooool000000oooool01?l0003oooooooooooooool2o`0000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`;o00001ooo
ool2o`000003ooooool0003o000000;ooooo1Ol00013ooooo`Ko00000_ooool5o`0000Oooooo0_l0
0003ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o0000
0_ooool2o`0000?ooooo00Co0000oooooooooooooooo0ol000002?oooooo0000oooooooooooo0000
ooooool0003ooooo1Ol000000ooooooo0000o`000003o`0002?ooooo0@000000000300000?oooooo
oooo027ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2
o`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`12ooooo`05o`000?oooooo0000ooooool00000
1oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`000008ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`?o00008oooool10000
000000<00000ooooooooool08_ooool4o`0000;ooooo0_l000000ooooooo0000o`000004o`000006
ooooool0003oooooooooool0003ooooo0_l000001?oooooo0000ooooool00002ooooo`08o`000?oo
oooo0000ooooool0003oooooo`000?ooool2o`0000;ooooo00Co0000oooooooooooo00001?ooool0
1_l0003ooooooooooooooooo0000ooooo`?o000000Coooooo`000?l0003ooooo0ol000001Ooooooo
0000ooooool0003ooooo00;o0000A_ooool2o`000003ooooool0003o000000;o000000Coooooo`00
0?l0003ooooo1_l000001Ooooooo0000oooooooooooo000000Cooooo00ko0000oooooooooooooooo
o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooo`;o00000oooool01?l0003ooooo
o`000?ooool2o`000004ooooool0003oooooooooo`;o000000Coooooo`000?l0003ooooo0_l00000
0ooooooo0000o`000002ooooo`Co00009?ooool10000000000<00000ooooooooool08oooool6o`00
00;ooooo00?o0000ooooool000001Oooool00ol0003oooooo`000004ooooo`;o000000Coooooo`00
0?oooooooooo0_l000000ooooooo0000ooooo`02ooooo`04o`000?ooooooooooooooo`?o00000_oo
ool2o`000003ooooool0003ooooo00?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo
0_l000000ooooooo0000o`000003o`0004Sooooo1?l00002ooooo`0<o`000?ooooooooooooooool0
003oooooo`000?oooooo0000ooooool0003ooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo
0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo0_l000001Ooooooo0000oooooooooooo0000
00Cooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00002ooooo`Ko00009Ooo
ool10000000000<00000ooooooooool09?ooool2o`0000?ooooo0_l00005ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o0000
00?oooooo`000?l00000Boooool01?l0003oooooo`000?ooool2o`0000;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooo000000;ooooo0ol0000Vooooo`40000000000`00003oooooooooo`0Toooo
o`_o000000?oooooo`000?l000000ol000000ooooooo0000ooooo`02o`0000;ooooo1?l00002oooo
o`05o`000?ooooooooooooooool000000_ooool3o`000007ooooool0003oooooo`000?oooooo0000
ooooo`02o`0000Cooooo1Ol000000ooooooo0000o`000003ooooo`Co0000B_ooool4o`0000?ooooo
1_l000000ooooooo0000ooooo`03ooooo`?o00000_ooool2o`000003ooooool0003ooooo00;o0000
0_ooool00ol0003oooooooooo`02o`0000;ooooo0ol00003ooooo`?o00000_ooool6o`000004oooo
ool0003o0000ooooo`Ko00009oooool10000000000<00000ooooooooool09_ooool4o`0000;ooooo
00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo00Co0000ooooool0003ooooo0_l0
0004ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000Gooooo0_l00004oooo
o`?o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`05o`0004gooooo1_l00002oooo
o`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00004ooooo`;o00001Ooo
ool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`09o`000?oooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo00?o0000ooooool000000_ooool01?l0003oooooo`000?oo
ool3o`0002Sooooo0@000000000300000?oooooooooo02Oooooo00?o0000ooooooooool00ol00000
0ooooooo0000ooooo`03ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
oooo0000ooooool000000_ooool2o`0000?ooooo0_l0001?ooooo`03o`000?oooooo000000;ooooo
0_l00002ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool2o`0000Cooooo0_l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool2o`00
00Gooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo02Oooooo0@0000000003
00000?oooooooooo02Oooooo1?l00002ooooo`Ko00000_ooool00ol0003oooooooooo`03o`000003
ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`02o`0000;ooooo00?o0000oooo
ooooool00_l00004ooooo`05o`000?ooooooooooo`000?ooool00_l000001Ooooooo0000o`000?l0
003ooooo00Oo0000D?ooool5o`000003ooooool0003o000000?o000000Koooooo`000?l0003ooooo
o`000?ooool2o`0000Cooooo00[o0000ooooooooooooooooo`000?oooooo0000ooooool0003ooooo
0_l00002ooooo`;o000000?oooooo`000?ooool00_l00003ooooo`03o`000?oooooo000000Ko0000
00?oooooo`000?ooool00ol0000Yooooo`40000000000`00003oooooooooo`0Yooooo`Go000000Go
ooooo`000?ooooooooooo`000003ooooo`;o00001?ooool2o`000008ooooool0003oooooo`000?oo
oooo0000ooooool00003ooooo`;o00000oooool2o`000005ooooool0003oooooo`000?ooool00_l0
00001?oooooo0000ooooool00002ooooo`;o000000Coooooo`000?oooooo0000Doooool3o`000004
ooooool0003o0000o`0000;ooooo00Co0000ooooool0003ooooo0_l000001Ooooooo0000ooooool0
003ooooo00;o00000_ooool00ol0003oooooo`000003ooooo`06o`000?oooooo0000o`000?oooooo
00000_ooool2o`0000Cooooo0_l00003ooooo`03o`000?oooooo000000;ooooo1Ol0000[ooooo`40
000000000`00003oooooooooo`0Yooooo`03o`000?oooooo000000;ooooo1?l000000ooooooo0000
o`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000003o`0000;o
oooo1?l0001Dooooo`Co00000_ooool5o`0000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o
000000?oooooo`000?l000000oooool2o`0002cooooo0@000000000300000?oooooooooo02[ooooo
1Ol00002ooooo`03o`000?oooooo000000;ooooo00Co0000ooooool0003o00001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`000003ooooool0003o
oooo00;o000000Coooooo`000?oooooo00000_ooool01ol0003oooooooooool0003oooooo`000?oo
ool00_l0001Fooooo`;o000000Coooooo`000?l0003o00000_ooool00ol0003oooooo`000002oooo
o`Go00000_ooool2o`000004ooooool0003oooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo
000000Cooooo0ol000001ooooooo0000oooooooooooo0000ooooool000000_ooool5o`0002cooooo
0@000000000300000?oooooooooo02_ooooo2?l000002Ooooooo0000o`000?l0003oooooo`000?oo
oooo0000ooooo`02o`0000?ooooo0_l00003ooooo`04o`000?oooooo0000o`0000;ooooo1?l00004
ooooo`co0000FOooool7o`000004ooooool0003o0000ooooo`;o00001?ooool4o`000006ooooool0
003oooooo`000?oooooo00000oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`05o`000003
ooooool0003o000000Go0000;_ooool10000000000<00000ooooooooool0;Oooool00ol0003ooooo
o`000004ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003ooooo
o`0000Gooooo00Co0000ooooool0003o0000Foooool2o`000003ooooool0003o000000Gooooo00Co
0000ooooool0003ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`00000_ooooo`40000000000`00003oooooooooo`0]ooooo`So000000Coooooo`000?l0003o
oooo0ol00002ooooo`;o000000Coooooo`000?oooooo00000oooool01Ol0003oooooooooool0003o
oooo00;o000000Goooooo`000?oooooo0000ooooo`02o`000003ooooool0003o000000?o000000?o
ooooo`000?l00000G_ooool2o`000003ooooool0003o000000Oo00000_ooool01Ol0003oooooo`00
0?oooooo000000?ooooo00?o0000ooooooooool00_l000002?oooooo0000o`000?oooooo0000oooo
ool0003ooooo3_l0000_ooooo`40000000000`00003oooooooooo`0_ooooo`Go00000_ooool01?l0
003oooooo`000?ooool4o`000004ooooool0003oooooooooo`;o000000?oooooo`000?ooool00_oo
ool3o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00?o0000ooooool00000
0ol0001Pooooo`Co000000Coooooo`000?oooooo00000oooool01?l0003oooooo`000?l00002oooo
o`?o00000_ooool2o`000003ooooool0003o000000;ooooo00Go0000ooooool0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo1Ol0000aooooo`40000000000`00003oooooooooo`0`oooo
o`04o`000?ooooooooooooooo`;o000000Goooooo`000?l0003oooooo`000005ooooo`06o`000?oo
ooooooooooooool0003ooooo0_l00003ooooo`03o`000?oooooo000000;ooooo1?l000000ooooooo
0000o`000002o`000003ooooool0003o000006;ooooo1Ol000001?oooooo0000o`000?ooool3o`00
0004ooooool0003oooooo`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;o00001Oooool0
0ol0003oooooo`000004o`0000;ooooo0_l0000booooo`40000000000`00003oooooooooo`0aoooo
o`Co000000?oooooo`000?l000000_ooool00ol0003oooooo`000003o`0000;ooooo00[o0000oooo
ool0003oooooo`000?oooooo0000ooooool0003ooooo0ol00002ooooo`04o`000?oooooo0000oooo
o`Go0000IOooool6o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`000007ooooool0
003oooooo`000?oooooo0000ooooo`03o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo
00;o00000_ooool4o`0003?ooooo0@000000000300000?oooooooooo03?ooooo1?l000000ooooooo
0000o`000004o`0000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00?o000000Goooooo`00
0?oooooo0000ooooo`03o`000003ooooool0003o000000Co0000J?ooool:o`000007ooooool0003o
ooooo`000?oooooo0000ooooo`03o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool0
0_l000001?oooooo0000o`000?ooool4o`0003Gooooo0@000000000300000?oooooooooo03Cooooo
1?l00002ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`03o`0006[ooooo0ol000000ooo
oooo0000ooooo`03ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool00ol0000gooooo`40000000000`00
003oooooooooo`0fooooo`Wo000000Coooooo`000?oooooo00000_ooool2o`000003ooooool0003o
000000;o00000_ooool9o`0006cooooo2Ol000000ooooooo0000o`000003o`000004ooooool0003o
0000ooooo`Co000000Goooooo`000?l0003o0000ooooo`05o`0003Sooooo0@000000000300000?oo
oooooooo03Oooooo2Ol000000ooooooo0000o`000005o`000004ooooool0003o0000ooooo`So0000
LOooool8o`0000;ooooo1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Oo0000
>_ooool10000000000<00000ooooooooool0>_ooool5o`000009ooooool0003o0000ooooool0003o
ooooo`000?oooooo000000;ooooo2?l0001fooooo`Oo00000oooool01_l0003oooooo`000?oooooo
0000ooooo`?o000000?oooooo`000?l000000_l0000looooo`40000000000`00003oooooooooo`0l
ooooo`Wo000000?oooooo`000?l000002Ol0001hooooo`Oo000000?oooooo`000?l000000ol00000
0ooooooo0000o`000005o`0003kooooo0@000000000300000?oooooooooo043ooooo3Ol00020oooo
o`go0000@_ooool10000000000<00000ooooooooool0oooooolMooooo`400000003o000002400000
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000l0020P820
P820P81oOgmoOgn0P820PH61P81oOgmnOWioOh20PH61PH60P7mnOWenOWn0P862
PX:2PH1oOWemOGenOh21PX>3Ph:1OgimO7alOGj0PH>4Q8B3PH1nOGakNgamOh63
Q8F5Q8:1OgekNWYkO7j0PXB5QXF4PWmmNgYiNW]mOh:4QXJ6QH>0OW]jNGUjO7j1
Q8J7QhJ4PWmlNWQhNG]mP8>6QhR7QX>0OGYhMgMiO7n2QHR9R8N4PGijN7IfN7Ym
PHF7RHV8QX=oNgQfMGIiO824QhV:RXR4P7aiMWEeMgYnPXJ9Rh^9QX9nNWIdM7Eh
O865RH^<RhR4Og]gM7=dMWYoQ8R;SHb:QX5lN7AbLWEhOH:7Rhf=S8R4OWUeLW5c
MW^0QXZ=SXf:QX1kMW9aLGAhOXB9SHn?S8R3OGMcL71bMWb2R8b?T8j:QGmiM71_
L7AiOhJ;Si6@SHR1NgEaKVmbMWf3RXjATHn:Q7egLFi]KgAjPHR=TI:ASHN0NG=^
KFiaMgj5S96CThn:Pg]dKfa/KgAkPhZ@TiBBSHInMg1/JfeaN828SY>EThn9PGUb
KFY[KgEmQHbBUIFBS8AlM6iZJVabNH::TIFFU8n8OgM_JVUZKgInQhnDUiJBRh=j
LF]XJ6abNhB=TiNHUHn6OGA]J6MZKgN1RY:GVINBRX5gKfUVIfadOHN?UYVIUHj4
Ng5ZIVIYL7V3SIBIVYNAR7idK6MUIfaeOhVBV9^JUHb2N6iXI6EYLG^6SiNKViR@
QWaaJFASIVegPXbEVifJU8^0MFaUHVAZLWf9TYZMW9N?Q7U^IV9RIViiQ8nHWIjJ
ThUmLVUSHFAZM82<UYbOWIN=PWI[I61QIg1kQi:KWinJTXIjKfIPGf=[MX>?VInP
WIJ;Og=XHEiQIg9nRiJNXJ2JT8AgJf=NGVA]NHJBW:6RWIF9O6mUGeePJ7B1SYVP
Xj2ISX5dJ61LGVA_O8VFWj>SWI>6N6aRG5aQJWJ4TYbSY:2HS7i`IEeKGFEaOhfI
XZFSW963MFQOFU]QK7V8UJ2UYJ2FRGY/HEYIGVMdPY6MY:NSVhj0LFALF5YRKWf<
VJ>WYYnDQWIXGUQHGVUgQYFPYjRSVHalKF5IEeYTLH2@WJJYYYjBPW=UFeIHGf]j
RYRSZJVSUhQhJEeFEU]UM8BDX:RZYYf?OViQF5AGH6inSYbWZjVRUHEdIEYDEEaX
MhRHY:^/YY^;NVYMEE=HHW62TZ2Z[JVPTX5`HEMBE5eZNhbLYjf/YIR8MVIIDU9H
I7B6UjB/[ZVNSge/GEAAE5i]Oi6PZjn]Y9F4LV9FD55IIgR:VjR_[jRLRgUWFE5?
EF5aPiFT[[6/XY:0KEiCCU5KJWb?Wj^a/:NIQgASETm?EV=eR9ZX/;:/WhikJEU@
CE9MKH2CY:nc/:FFPfmNDTa>EfIiSIj//k:[WHYfI5E=C59OLHFHZ;:d[j>BOVYJ
Cd]>FFYmTJ>_]K>YVHIbGe9;BeARMHZM[;Be[Z2>NFEFC4U?G6j2UZNc][:WUX5]
Fdi9BeIVNXnR/;Nf[If9M65ABDU@Gg:7Vjbf^;:TTWaWET]7C5QZOiBW/kVfZiZ5
Kea>AdQBHWN<XK2h^;2QSGMRDTQ6CE]^Q9Z[]kZeZ9EoJUM:ADQDIWbBY[Bj^JjN
R79MCDE5CUicRYn`^[^dYI5jI597A4UGJX6GZ[Nl^:bIPfaHBT=5D69hSjBd_;bb
XXaeGdi4@dYJKhJM[k^m]jVEOVICAT56DfImUJVh_[^`WXM_FDU1@TaNM8bR];fn
]ZJ@N65>@d17EV^3VZjk`;^]VH5YE4Ho@dmRNI:X^<2n]::;LU]:@418FG29X;>o
`KZZU7]SCd8n@e9VOiR]_<:n/If5K5I5?Sm;GGF?Y[S1`KRVSgEMBSlmAEE/QIjb
_l>m[YUoIU12?41=HW^E[;c4`KJRRFmHAS`mAeUaRjBg`/BlZi=iH4/n>d5AIh6K
/L35`K>MPfUB@CXmBEigTZZlaLBjYXicFTHk>T=EKHNQ]/?6_jnHOF=<?SPnC6=m
V:o0alBgXXQ/E48i>TEILXjW^lK7_J^BMea7>SLoD6R3W[G4bL>cW85VCSdg>TQN
NIF]`<W7^jJ<L5I2=cM1E6j:YK[7b/6`Ug]OB3Xe>daSOi^ca<_6^:66JE0n=CM4
FGBAZko:b[n[TGAI@cHd?E1YQZ:ib<c5]9aoHTXj<cQ7GW^H/LC<b[bVRVeB?S@d
@5A_SJRnblc3/9IhG4@f<SU;I8:O]lS>bKVPQ6I<>S8e@eYfU:o3cLg0ZhmaEClc
<Ca@JhVU_L_?akFJOEm6=S0fAUmmVkG8d<bmYHQZCSX`<SiELI2/`/k?aK2DMEQ1
<RlhBfJ4X[_<dL^iX85SB3H^<T9JN9Ncam7?`ZZ=KU4k;bljD6b<ZL7?d/VeVGYK
@S8]=4IPOinibm?>_ZF6Id/f;BlmEG>C/<KBd/J`TW9D?Bh/=T]WQjJocmC<^Yio
Gd@b:c11FgZK]l_DdL:ZRf]==b`/>E1^Sjg5dmC:]IQgF3h^:S96HX:R_LoFd;jT
Q6=7<RX]?EIeU[C:eMC7[i1_D3T[:SE;JHZZ`m?Gc[ZMO5]0;RP_@EamW[_?em?3
ZHUWBC<X:SQAL9:abMKGbkBFM5@j:bLaAV>5Y/7CfM:oXX5P@blV:caGN9Zhc]WF
b:j>K4de9bLdBf^=[LOGfLniVgUH?2/U;D5NP::odm[E`jR6I4D_9BPgDW:E]LgJ
fLbdU75@=RLU<4IUR:W5emcC_j5nG3l[8bTlF7ZM_=;Lf<R]S6U9<B@U<da]T;7;
f]c@^IUfE3PW8ba1Gh>U`mKMelBVQ612;28V=e=eV;WAgM_=/i9^C38T8Rm7Ih^]
bM[Ne;jONePk9b4X?5YmXL3Fgm[8[8UUABdQ8c9=Ki>ecmgNdKRGLe0d920Z@F66
ZLOJh=S3YH5M?RPO93MDMibme>3McK:?JTP^820^AfV>/LgNh=FnWGQD=b@N9caK
P:G4fN;Lb:^7HD4Y7R4bCW:G^M?Ph=:gUFm<<20N:T9SRJg;gN;I`j=nFCXT72<g
EGZP`MSSglf`S6M4:adN;DQ/T[GAhN?F_I]eD3<P72HmGH>Xb=gTgLRYQ5hm9A/P
<U1dVkgGi>;B]Y9/B2dM72U3IXbac^7Uf/:QNeDf8AXR=eMmXlGLiN3=[hYS@2LJ
7Be:KYFieNCUekbILTd_7AXU?En6[<cPimk8Yh5J>B8I7S9AMik1f^KTd[F@J4@Y
6QXYA6R@]M;Tim_2WgMA<QhH8CQIP:O9gnSRcJf7Gc`S61/]Bg6I_MSWi]NkUVi9
:aXH93iRR[3@hnWOajEmESDN5QdcDgZRaMkYiM:cSFE09ALH:4E[TkWFinWK`Iad
CBhJ5R0iFhB[c>?Zhlf[Q5/h81DJ;DedWL7Lj^SG^I=ZABLG5R@oI8fddnO[glJS
NU8a6a@L<eEmY/WQjnKB/HYQ?28D5bU7KINmf^[ZfknJL4TZ5a@P>Uj7[m3Vk>?<
ZH1H=A`C6Bi?Mj35h>cYekR@Id4T51@T@FNA^=OZkN35X7M>;APB73AGPJ[=iNkW
dJn7GCPN4QHYBG2K`Mg/k=^nUfe59Q@B7c]PRk?DjNkTbjMmE34I4AP_DGZTbN?_
j]JfSF<m818C94=ZU;cKk>kPa9ecBRTE41/eFXB^dNS`j=2]PeTe6a0E:D]dW/GQ
kngK_9AY@B<B4B0mHhjgf>c`i<VTNE0]5PlH<5=nZ<gVlN_E]8YO>Ad?4RE4KIS0
g^o_h<:KKdHV4PlK=ef8/]C[l^S?Zh1E<AP>52Y=Mj;8i?7^fkZAICdO3`lP?VJB
^m__l^C8XGI<:A<=5c5FPJcAjO?[eK67FcDJ3A4UAg2La>;alMo0V6a28Q0=6cQO
RkKHk_?XcZQlDBdE31@[CgZVc>OckmZhSV4j70d>841YU[oOlO?TaYibB2H@2aLb
FHF`e>cdk=>_PeLa5P/@9TUcX<SUm?7O_YAX?al=31`jHXnjg?3ej<bUNDdY4PXD
;E9nZ]3ZmNoI]HYM=QT;3R52KI[3h_?dhlBKKT@R3PXH=5b8]=S_m^cB[81C;A<9
42M;MjC<j?Kbg[bAI3/K2`/L?6JC_Mocm^S:XWE99Pl952iEPZkDkOO_ek>7FS8F
2@dRAG2ManGfmN?2V6Y07`/963IOS;SKl_O/d:UlCbXA210YCW^Xcn_gl]fiSV0g
60T;7CiYUl7RmOOWb9maAR8<1a@`F8Fbeo3hkmJ`PeH^4`L=8dMcXL[Yn?GR`9EW
?1/921ThHY2lgoChjljVN4/V3PH@:U5n[=?^nO;K]hYL<aD72Qi1K9_5i_Ogi/JL
KD8O2PLD<U^9]]_cn^oD[GmB:a063BE:MjG>k?Weh;fAHcPH1`PJ>VFD`>;fnN[<
XgA88``54BaDP[3FlO[bf[B6F2lB1@XP@g2ObNWin>G4V6Xn70P65CANSK[NmO_^
dZYlCRL=10dWCG^Yd^kkmMnkSUle5@H76ceYV<?Un?[ZbZ1aA209114^EhJdf_?l
l]RaPe@/40@:8DIdXlg[noST`IEV>QT61AHgHI6nhOOkk]2WN4XT2`<>:E1o[MGa
o?GM^8YK<A<41aa0K9c7j?[jj<NLKD0L1`@B<EZ:]mgeo?7F[Wm@:0d32R=9MjO@
k_chh[jAHSHF1@DH>FFE`NCio>g>XgA68@T33R]CP[7IlogefkF6Ebd@0`PN@W2P
bn_ln^O5VFTl6@H34c=NS[_Pmog`e:YkC2D;0P/UC7^Ze?7mn>2kSUhc4`<56CaY
VLGWnoc[bj1`@Qd70Pl]EhJeg?Gnm=VaPU<Z3P8884IdY<k^oO[U`YEU>AL40aDf
HI6ohoWmkm6WMdTR2@4<9e1o[]Oco_OO^8YJ;a421Q/oK9g9j_clj/RLK3lK1@8A
<5Z:^Mogo_?G[Wm?9`/12B99N:OBl?kji;nAHCDD0`<F>6FE`nKko^k>Xg=57`L1
3BYCPk;JmOofg;F6ER`>0@HM@W2Pc>gmo>S5VFPk60@24S9NS[cRnOobe:]kBb@9
00XTC7^[eO;onN6lSEdb4P4463]YVLKYo?g/c:1_@A`50@h/EhNfgOOomMZbPU8Y
30077dEdY<o_o__V`YET=aD30Q@eHI;0iO_ol=:WMdPQ200;9dmo[mSdooSO^8UI
;Pl111XoKIg:jogmjlVLJchI104@;eZ;^^3iooCG[Wi>9PX02259N:SClOoki;nA
H3@C0P8F>6FFa>Olono?Xg=47PH032UCPk?Km_oggKF6EB/=00DL@W2QcNknoNW6
V6Lj5`<14S9NSkgSn_obeJYjBb<900TTC7b/e_?on^:lSE`a4@4363]YV/OZoOk]
c:1_@1/500h/EhNgg_Som]ZaPU8X2`067dEdYM3`oocV`YAT=aD20Q@eHY;1iO_o
lM:WMTLP1`0;9e20/=WeooSO^8UI;Pl011XoKIk:k?kmjlVLJcdI100@;eZ;^^7i
ooCG[Wi>9@X02259N:WCl_oki;nAH3@C0@8F>6JFa>Slono?Xg947PH032YCQ;?K
m_oggKF5EB/=00DM@W6QcNkno>S5V6Lj5`<14S9NSkgSn_obe:YjBR<800TTC7b/
e_?onN6kSE`a4@4363aYV/OZoOk/bim^@1/500h]EhRgg_SomMZaPE4X2`077dIe
YM3`oo_V`YAS=aD20Q@fHY?1iO_ol=6VMTLP1`0;9e20/=WeooSO^8UH;Pl11A/o
KIk:k?gmj/RKJcdI104@<5^;^^3ioo?G[Ge>9@X02299NJWClOojhkj@H3@C0P<G
>FJGa>Olo^k>XW947PH13BYDQ;?Km_ofg;B5EB/>0@HM@g6RcNgno>S4UfLj5`@2
4c=OSkgSnOkadjUiBR<90@XUCGf/e_;on>2kS5`a4@856CeZV/OYo?g[bYm^@1`6
0@l^F8RggOOom=V`PE4X304884MeYM3_o_[U`I=S=aD30aDgHi?0i?[mkm2VMTLQ
204<:560/=Sdo_KM]hQH;Q021Qa0KYk:jockjLNKJSdJ1@8B<Eb<^^3go_;E[7e>
9P/22RA:NJWBl?ghh[f?H3@D0`DH>VNG`nKjo>c=XW947`P23baEQ;?Jm?gdf[>4
EB`?0PPOA7:Rc>cln^K3UfLk60D453EPSkgQn?g_dZQiBb@;0P`WCWf/eO7mm]ni
S5`b4`@66ci[V/KXn__ZbIi^@Ad70a4_FHRfg?Gml]N_P58Z3P<:8TQfYLo]o?SS
_i=S>1L51ALhI9?0hoSkkLjUMDPR2P<?:U:1[mObo?CL]XQI;a8421i2Kik9jO[i
ilFJJShL1`DD<ef<^Mkeno3CZge?:0d432E<NZSAk__fh;b?H3DF1PLJ?6RG`^Ch
n^[;XG9580X54BiFQK;Il__bf;:4EBdA1@XQAW:Qbn[jmnC2UVLl6PP65cIQSkcP
mO[]d:MiC2H=1@lYD7f[dnojm=fhRe`c5@H97D1[V/GVn?SWaie^@Ql:1Q@aFXRe
f_;jkmF^P58[40H=9DUfYLg[nOGP_Y9T>AT821XjII>ohOGhj/bSMDTT3@HA;5B1
[mG_nO7I]8MI<A@72b54Kig7ioOfi<>IJd0N2PPG=Ej<^=cbn>gAZWa?:A073bQ=
NZS?joScgKZ>H3LH2@XM?VVF`N;emnO9Wg968`d8531HQK7GkoS_e[23ERlD20hT
Ag>QbNOfm>6oUFLm7@/:6SURSk_Ml_OZcJIiCBP@218/DGj[dNcgl=ZfRUde60X=
849/V/?Sm?GTaI]^A28=2QLdFhRdf>ofk=:/P5<]50T@9d]gY<_XmO;M_95T>a`<
31dmIY>mg_;eilZRMDXW40XE;eF1[M?/mNkF/XMJ<aL;3bA6L9g5i??bhL6HJd4Q
3P`J>5n<]mW_m>W>Z7aA;1@;4b]?NjO=j?C_f[R=HCTL3@hP@6ZF_moaln?6WW98
9Q4<63=IQK3Dk?C[dZj3Ec8G318WBWBPanCbl=fmU6Po80l>7SaSSkWJk_;VbZAi
CR/D3AH_DgjYc^Sbk=JdRUhg6`hA94A]VL7Pl?3P`YY_ABDA3Q/gGHRbeN_bj<nZ
OeD`5`hE:dihXlWTlNgJ^I1U?B0@424oIi:kfng`hlNPMD`Z50lI<eN2[=3XlNWB
/8IK=Q/?52Q8LIc3h>o^gKjFJd<T4Q0O>f6<]MK[l>G;YWaB;aP@62mBNjG:i>oZ
e[F<HS`O4A<U@f^E_M_/k]o3W79::ADA73IKQJkAinoVcjb2FCDL4AH[C7FOa>3]
jmVjTfQ291@C8SmUSkOFj^gQaj9iD2hH4Q/cEWnXbnC]im:aRElj81<F:4M_V;kK
jn_L_iU_B2TF4b0jGhR`dNK]hl^XOeHd71<J;e1hXLKPk>SE]XmV@2@E5RI3JI:h
enS[g/>NMDh^6A@N=UV2Z/cSjnC>[HEM>B0E6Ba;LY_0fn[Xf;^EK4HX61HS?V>;
/];Uj^37Y7aD<adE7C=DO:C7gn[UdK:;HclT5aPYAfbE^]OWj=ZoVg9<;AXF8SYM
QJc=h^WQbZV2FSPP5a``CgJN`M_XiMBgTFU5:1TI9d9WS[CBi>SL`j1iDS8N5b0g
F7nVb=kXh/j^R64n91PK;D]`Uk_GiNGG^iM`BRdL6BDnHHR^cN7WgLNUOePh8ATO
=5=iX<;Ki^;@/hiW@bTK6b]6JY6fd^?Uf;nLMU0b7aXT>eb2Z<SNiMk:ZXEN?BDK
7c5?LiZme^CRdkNCKDT]7A`Y@VF;/<gPi=[3XWaF=b8K8cQGO:;3f^COcJn:I48Y
7Al_BVjD]m;Qh]FkVG=?<R0M9cmPQJ[8g>?KaZJ1G3`V7B8eDWNL_MKRglncT6Y8
;QlO;DIXS[7=g^7F_iiiECLT7RHlFgnT`mWQg<V[Qf92:QlR<TiaU[SAgmoA]iE`
CS8R82]3HhR[b=_Pel:SOUXl9alV>EIjW[kEgmc;[heXAbhQ8S1:K92bcMcNd[^J
MU<g9B4Z@5n2Y/CGgmS5YhAP@B/Q9CIBM9RidMgLcK>BKTdc92<_AfN;[LSIgMBn
WgaI?2TR:CeJOJ2ne=gHaj^9ITH_92DdCVnC/lcJflngUg=B=bLT;TARQJO4e]cD
`J>1Gd4/92TjEWRJ^M3Kf<V_SVa<<bHV<d]ZSJk8em[@^Y]iF3`Z9Be1GX2R_m;J
eL>XQVA6<2HY>59bUKC<f=S;/i=aDCPY9c57IXRX`mCIdKfPOUe1;RL/?UYjW;[?
f=G5Zh]ZBc@X:CM?KXn_amGGc;JHMeHl;2PaAF62XkkAem6oY8=RAS4Y;3aFMYNd
bmKDajn@Ke0i:bXeBfV:ZL?Be/fiW7aL@BlZ<49MOIjjcMGA`JR8J4/e:bdkDW6A
[lKCe<RbUGAF?Bh[=4UUQJBncmC=^j21HDHc:c10FWRH]LWCdL>[SFe@>Rh]>Dm/
S:[2d=?9]IUiFd8a;CA6HH2O^L_BcKfTQVI;=bh`?eIdTk35dM34[Y5bECh`;SQ=
J8NU_/gAb[NMOV16=BhdA5ekV[G8d<foYhY[D3/`<CeCKhj[`Lk?aK6FMeY2<c0h
BVB2X;W:clZiX8=UBcP`=4=JMiF`a<k=`:Z>L5@o<c8lD6^9Y[g;c/JcVGaOAcLb
>4QQOY^da/g9^jB7JU0l<cE1Eg:@Zl3;c<6]TWEI@cHc?4iXQJ6halc6]If0I4/j
=3Q6GGVF/<;;bKbWRfmD@3Hf@5A^RjJlb<[2[iIjGTPi=Ca<I82L]<C:a[NPQFU@
?SHhAE]eTJ^nb<RmZHmcFD@h=d1BJhNQ]lG9`[6JOV=<?3LlBV5lUjo0b<FhXhU]
E48h>DAHLHfV^/K7_ZbCN5i9>cPoD6N2WK?2al:cWH9XD40i?4UNN9>[_LK4^JJ=
LUU6>cY4EVj8X[K3aKj]UWaRCClj@4iTOYR__/G1]:26K5E4>ce8G7B>Y[W3`kZX
T7IMBShl@eA[Q9fb_lBn[iV0Ie52?41=HWZDZ[_2`;FRRW1IAchnB5UaRZ:e`<:j
ZY=jHTi1?TABJ82I[[c1_K2LQ6]EASm1C5mgT:Jg`;nfY8eeGD]1@4MHKHJN/Kg0
^Z^FOVIBAD14DFEmUJZi_kfaWhM_FTU1@TaMLh^R/kfn]ZJ@NF9?A458EV^2VJfj
_[V/VH9ZETQ2AE1SNI6U]Kfl/Z6;Lei=A4=;Fg28WZnj_;JWTgaVDdM3B5EXOiFY
][bi[I^5KUY;A4I@HGJ=XK6j^[:RSWMRDDM5C5Y^Q9Z[]kZeZIJ0JUM:ADUDIW^A
YK>i^:jMR79NCdM7CemcRIf^]kVbY91kIUE:AdaIJh2FZ;Bh]JVHPfiKCTQ:E6Ah
SJ6_]kJ^Wh]fHU=:BE1ML8FIZ[Bg/JFCOVYICDU=F6UmTZB`][BZVXIbGe5:Be=R
MHZM[;Be[Z2>NFIFCD]@G6j2UZJa]K6VUH5]G51;CUMWNXjP[K>bZY^9MF=ECDeD
HG>6VJRa/jfQT7eZFU1=DEa/Oi:R[[:`YYN4LF1DCTmGIWR;W:Va/JZMRgQVF51>
E61aPiFT[[6]XY:0KEiCCe9KJWb?WjZ`[ZJHQgATEe1AF6AeQiVV[ZnYWXikJUaC
D5EOKh2BXJ^_[::DPW5QEU5CFfUjRi^W[JfVVHUhIeYCDUQTLhBEXj^]ZIj?OVeO
EU=FGfenSifX[:ZRUHEdIEUDE5]XMhRHY:^[YIZ;NV]NEUAIHg62TYnXZjRNTH5a
HeUEEem/NhbJYJZYXYJ7MfQMEUILIgF5U:2XZJFKSGe^HEUFFV=`OhnLYJVVWY:3
M6ILEeQOJgV9Uj6WYj6GRGY[H5UHGFIdPi6MYJNTVhj0LFALFE]SKgf<VJ:VYIjC
QGMYGeYJH6YgQYBNY:FQUh]lKV=LFUiVLX2>VZ:UXY^?PWAXGe]MHfikRIFOY:>N
U8MiK69MG65ZMXBAVj:SX9N<OW5VGeaOIW5nRiNOXZ6JT8AfJf9NGVA]NHJBW:6Q
WIB8O6mUGeiRJWF1SYROXIjGSH1dJF9OHFMaO8VDW:2OVY65NFiUH61UKGR4T9VN
WibDRWibJ69PHfYdOh^EW9nMUhj2MfaUHF9WL7^6TIVMWIVAQg]`J6=RIVegPXfF
VifJU8YoMF]UHfEZLgj9TYVLViJ>Q7U_J6ATJ71jQ8jFVi^HTHQmLf]VI6M]MX2:
TiVKVI>;PGM^J6EVJg=lQXnFVYVESXEkLV]WIVU`NH:<TiRIUY68OgE^J6MYKWIo
R92FV9NCRh9iLF]XJ6acNhB=TiNGU8j6OGA]JFQ[L7R1RI6EUiF@RH1hL6]YJVme
OXJ>TiJETX^3Ng=]JVY]LgZ3RY6DUI>=QWifL6a[K75hP8N>TiBCShV1NW=^K6a`
MGf4Ri2CTi2;Q7efL6e/Kg=jPHR>TY>ASHN0N7=_KFibN7j5S92BTHj9PW]eL6i^
LGIlPhV>TI6?RXEnN7=_Kg1dNX26S8n@Shb7P7YeLFm`LgQnQ8V=Shn=R8=mMg=a
L79fO867Rhj?SHZ5OgYeLW5bMGYoQHV=SXf;QX5lMgAbLWAhOH:7Rhf=RhR3OWUe
Lg=dMgb0QHV<S8^9QH1kMgEcM7IjOh>7RX^;RHJ2OGUfM7AfNGf1QHR:RhV7Pgmk
N7IeMWQlP8B7RHZ9QhB0OGUgMWIhNgj2QHR9RHR5PWikN7MgN7YmP8B6R8R7QX>0
O7YhMgQjO7n2QHN8QhJ3PGikNGQhNWanPH>5QhN6Q89oOG]iNGYkOH22Q8F6QHB2
P7ilNWYjNgeoPH>4QHF4Ph5oOG]kNg]mOX22PhB4Q8>1OgimO7]lOGj0PH:3Q8>3
PH1oOGelO7enOh21PX>3PX60OginOGemOWn0PH62PX:1P81oOWinOWioP821PH61
PH20OgmoOgmoOgn0P820P820P820OgmoP820P820P7moOh20P820P820P81oOgmo
OgmoOh20PH61PH60P7mnOWinOWn0P862PX:1PH1oOWemOGinOh21PX>3PX60Ogim
O7amOGn0PH>3Q8>2PH1nOGakO7enOh63Q8B4Ph:0OWekNg]kOGn1PhB5QHB3PGmm
NgYjNWanP8:4QHJ5Q8:0OG]jNGUkOGn2Q8J7QhF3PGilNWQhNG]nPH>6QhR7QH9o
O7YhMgQjO823QXN8R8J4P7ejN7MgN7]nPXF8RHV8QH9nNgQfMWMiOH24QhV:RHN4
P7ahMWEfN7]oPhN9RhZ8QH5mNGIdM7IiOH:6RH^;RXN3OgYfM7=eMg^0QHV;S8b9
QH1lMgAcLgEiOX>8Rhf=RhN2OGQdLW9dMgb1QX^=SXf9QGmjMG9aLWEjOhF:SHn>
RhN1O7IbL75cMgf3R8f?Shf9Q7ihLg1_LGEjP8N<Si2?S8J0NWA`KfmcN7j5RXnA
THj9PgafLFi^L7EkPXV>TI:@S8EnN79^KFmcN827SI6CTXj8PGYcKfa]L7ImQ8^@
Ti>@RhAmMG1/K6icNX69Si>DThj7P7QaK6]/L7InQXfCUIBARX=jLfeZJVecNh>;
TYFFThj6OWE_JVU[L7R0RI2EUiFARH5hL6]XJFedOHJ>U9NGThf4Ng=/J6Q[LGV2
Ri>GV9J@R7mfKVUWJ6ieOhRAUYVHThb2NG1YIVM[LW^5SYFIVYJ?QWacJfIUJ6ig
PH^CVI^IThZ0MVeWI6I[Lgf8TIRKViJ>Q7Y`J6ATJ6miQ8jFVibITXUnLfYUHfE[
MGn:U9ZMViJ=PWM]IV9SJ71kQi6IWIfITHIkL6MRHFE/Mh:>UifOW9F;OgAZHf1R
J79nRYBLWijIT8AhKFEPH6E^NHFAVYnPW9B9O75WHEmRJGB0SINNXInHSX5eJV9N
GfE_O8RDWJ6QW9:6NFeTGUiRJgJ4T9ZQXYnGRgiaIUmLGfIaOXbGX:>RVi64MVYQ
G5eRK7V7U9jSY9nERG]^HeeKGfQdPXnKXZFRVXj0LVINFUaSKWb;Uj6UY9jDQWMZ
H5YJGfUgQI>NYJJRVHamKf=KFEaTLH2>VjBWYIfAPgAVGEQIH6]jRINQYjNQUhUi
JemHEeaVM8>BWZJYYIb?Og1SFUIIHFimSI^UZJRPU8EeIeaFEUeXMhNFXZVZYIZ<
NfaOEeEIHg61TIjXZjROTX9aHeUDEUi[NX^JYJ^[Y9R8MfQKE5AIIGB5UJ:Z[:RM
Sgi]GeICEUm]OXnNZJf[XiF4LfAHDU=JIgR9VJJ][JNKRgYYFe=AEV5aPYBR[:n[
XI:0KemED5=LJW^>WZV_[ZJIQgETF55@EfAdQiRV[[2ZWhmlJU]BCe=NKH2BXZfa
[ZBEPg5PE4i@F6IhRifZ/K6YW8]hIUM?CUAPLHBGY[2b[Z:BOfaLDDe@FVYmT:6]
/k6XVHIcHEA=CEESMHVKZ[:c[J2>NVMGCT]@G6f1UJJa]K6VUX9^G51;CEIVNHjP
[[Fd[9f:MF9CBdYAGg:6VZZd][2TTWeYF4e9CEUZOY>U/KNdZYV5L5e@BDYCHWJ;
Wjjf]jnQSGQTE4Y8CU]^PiRY]KRdZ9J0JeU<AdYEIW^@Y;:i]jjMRG=OCdM7Ceib
R9f^^;VcYI5kIUA9ADYGJX2FZKFj]j^JQ6iJC4E7DF9gSZ:b^[ZaXHefHE16A4]J
KXFK[KVl]ZVEOfQEB4=7DfIlTjNf_;Z_WXQ`Fd]3A4eNLh^Q/[bm]JFANF=@AD98
EVZ2VJbi_[Z]VH9[ETQ1A4mRNI2V][jm/j:;Lee<@T59FVn7Wk6m_kVZUGeUDDA0
AE9VOYJ[^/2m/Ij6KEQ7@45;GGF=Y;Jo`;NVT7MOC44oAUE[Q9b`_L6l[YV0J594
?T5>HWZCZ[[2`;FRRW5IB3hnAeU`RZ:e`<:kZYAjHTe0?49AIh2I[kk4_k:MQ6]D
@c`nBUefT:Rj`l>iYXidG4Pm>dAEK8JP]<75_ZnHOVA>@3XoCF9lUZfnaL>fXXQ^
ET@j>dIILXfV^LC6_J^CN5i9?3U0D6R2WK?2al:cWH9WD3lh>dUNN9>/_/O6^ZJ=
LEQ4>CQ2E6f9XkS5b<2_UgaQBS`g?4aSOYZa`/W5]j67Je90=cQ4FG>?ZKg8b;j[
TGEKACPf?U1YQJ2ga/[4]9b0I4`l=CU8GWZF[l;:b;bVRfiD@3Hf@5A_RjNlbL_2
/9IiGDHh=3Y;I82M]LK<akRQQFQ>?3<f@eUeTZg1c<_0Zi1bEd4e<ca@JXNT^lW=
a[BKOV58>38gAemlVK?6c/^mYXU[D3`b<cmDL8jZ`<g>a;2EMeY3=30hBfF3X;W:
clZiX89TBSP`<d9JMiJaaLo>`J^>Ke<m<C0kD6^:Yko=d<ReVW]MA3@^=DIPOYfg
b]7=_ZF7J4dh;S0nEG:A[/C@dLF`TgAF?c0^=d]VQZBmcM;;^In0HDHd;C52FgVI
]LWCd<:ZS6a?>Bd^>U1]SJ_3dM?9]IQhFT0`:c=6HH6P^lgDckjTQFE9=2/^?EId
UK;8e=?6[i5aDS/]:cE;J8RX`M7EcKZNOEe2<2X_@EalW;W=e];3ZHYYBcDZ:cU@
Ki2_amCFbkBGMUHl;2TaAV:3Y;oAem6nXh9QAC4X;3aFMiRfc=OEajn?KTlg:BPd
BfZ;ZlGEf<njW7YJ?R`W;T5MOZ2mdMWD`jR8ITLa9bThDG6C/l_Hf<bdUG9B>2TV
<4ITQZS3eM[B_j:0GT4]9BXlF7VK^]3JelR^SFY;<bHV<da/SZo9f=_@^IYhESXY
92a1Gh6S`MCLe/BWQF94;R@W=e9cUkO?fm[</i=_CS@U92m6IXV[amSMe;jPOEXm
:B8Y?5UlWkkDgMW8[H]WAblS93==KY:ccMcMdKVHM58f9B4[@F24YlGHgmO4YX9O
@2XQ9CMCMYZkd]kLcK:@K4X`8R4^AfR=[l_LgmFnWWYF>BHO9caJOZ?2en3Kb:^8
Hd<[828bCW2E]m7Ogm6hUW5><R8O:T9RQj_9g>7I`jAoFc`V7R@gEGVN_mKQg/fa
SVQ6;AlO;TQZT;??gn;F_IagDSDR7BHlG86Va]_Sg<RZQF0o9adP<TmcVK_Eh^7B
]iA^BRlO7BU2I8Z_cMoTf/>RO5Lh8a/R=eIlX/?Ji>3=/8]U@RTL7Be9KI>gdn;T
e[fJLdla7a/U?Ej5Z/[NiMk8Z89L>b@J7c9@MYbof>GSd[JAJTH[6a/Y@fN>/m3R
i]_2X7UC=1lI8CQHOjG7gNOQcJj8HChU6A`]BW2G^mOUiMNkUg1;;A/H93iQR:k>
h^SNb:IoF3LP5ahbDWVP`mcXi=:dSVM29aTI:4EYTKODiNSK`IifCc0L5b0hFX:Y
b^7Yh/f/QEdj8QHJ;DabVkoJj>OG^YE/AbTH5b@oHh^bdNGZglNTO5@c7ADM<eAl
Y<OPj^GB/X]S?R<F62Q6K9Fkf>SZfl2KLT//6ADP>Ef5[LkTjn?<ZX9I=QhD6Bi>
MIk3g^_XekRBJD<V5QDT@6J?]]GXk>36XGQ@;aXC73AFOjS;hngVdK28GcXP4aHY
B6nI_mc[jm^nV6m7:1HC83YORK7BingTbjQoES<K4QP^D7VRan7]j]JgSfDo8Q<D
949XTk[IjngPa9meC2/F4A`eFH:/cnK_im6^QE/f714E:DYbW<?Ok^cK_IE[@bDC
4AllHXbee^[_i<ZUNe8_610H;e9lY/_Ul>_F]HaQ>al@4RA3JiJngNk_h<>LLDPX
50lK=U^6/=;YlNS@[89G<aT?52Y<MJ37ho3]fk^BIclQ410P?FF@^M[]lNC9XgQ>
:aD>5c1EOj[?j?;[eK:8GCLK3Q4UAFnJ`^3`l>31VFe4914>6cMNR[CFk?;XcZUn
DblF3A@[CWVTb^Kbk]ZiSf<l7Ph?83mXU;gMl?;Taj1dBRLB31LbEh>^d^_dk=B`
QETc60`A9TQbW/KSlo7O_iIZ@20>3A`iHHfhf^odj<fWNdl[4`/D;55lZ<kYm>oI
]haO>1X<3R51JiS1hO;ci<FML4HT3`/G<eZ7/]K^mNcC[H5E;aD:42M:MJ;:ioGb
g[fCISdM30`L>fBA_=gbmNS;Y7M;9a0952eCP:cBk?K_f;B8Fc@G2PdRA6jKaNCe
m>?3VVa280d:63EMR[KJl?O/dJ]nDB`B210XCGVVcN[gl]fkSf8i6PX;7CeWUKoQ
m?KWbJ5cAb@>21@_EX>`e^ohkmNaQEP`50P=8dIbWlWWmoGR`IIY?Qd:2APgH8jj
gO?hjlnXNTdX3`L@:DmlZ]7]n?;L^8aN=AL82Qi0JiW3i?KgilNMKd@Q2`LD<EV7
]=WanNoE[h5D;1463BA9MJ?<j_SehKnCICXJ20PI>FBB_^3enN_=YGI99@d642]B
P:kEko[bf[F8FS4D1PXO@VjManOhn>K5VV]07@T65C=LRkSMm?[_dj]mD2T?1@dV
C7VWd>gjmN2lSf4f5`H86SaWU/;Tmo[Zbj5bAR4:1A4]EHBbf?;kl]VbQEH^4@D:
84EbXL_Zn_ST`YMX?1X71QHeH8nlh?Kkk]6XNT`U30@=:4mmZm?`noGN^HaM<a@5
1a`nJY[5ioWjjLVNKd8N20@B;eV8]]cdo?;G[h5B:Pl32R98MJG>kO_hhl2CI3PG
1@DG>6>C_n?ho>g?YGI88PX33RYBP:oGl_geg;J8FBlA0`LM@FjNbN[kn^S6VV/n
6`H44c9LS;WOm_gaeJamCRL<0P/TBgVXd^omn>6mSf0e50@563]WUl?Vn_c/c:9b
A1l80Pl/EHBcf_Cmm=ZcQ5D/3`887dAbX/g/o?[V`iMW>QP50a@dH8nmh_Sml=:Y
NDXT2P8;9Tim[=Gbo_OP^XaL<A821AXmJY_7jO_ljlZNKT0L1P8@;UR8]mgfo_CH
/81A:0`12257MZK@kogji<2CHcLE0`<E=f>C`NGjo^o@YGE780P132QAPK3Im?og
gKN8F2h?0@HL@6jOb^_mo>W7VVXm6@D24C5LS;_Pn?obeZamCBD:0@TSBWVYdo7n
nN>mSelc4`845cYWUlCXo?k]cJ9a@ad60@h[EHFdg?Kom]^cQ5@Z3@467TAbX/k^
o_cWa9MV>AL30Q<dH92nho[olM>YNDTR200:9Dim[MOcooWP^X]K<10111TmJi_8
j_gmk<ZNKClK1@4?;UR9^=ohooGI/81@9`/01b17MZKAl?okiL6CHSHD0P8E=f>D
`^Kkoo3@YGE67`L02bQAPK7JmOohg[N8Ebd>00DK@6jObncnoN[7VVTl60<14C5L
SK_QnOoceZalC2@900PSBWZZe?;on^>mSehb4P435cYWV<GXo?k^cJ5a@Qd500d[
EHFegOOom]^cQ5<Z30067TAbXlo_oocXa9IV>1H20A<dH96oi?_ol]>YN4TQ200:
9Din[]OdooWQ^X]J;a0011TmJic9jognk<ZNKClJ100?;UV9^=ohooGI/81@9`/0
1b17MZOBlOokiL6BHSDD0P8E=fBD`^Kloo3@YGA57`H02bQBP[7Jm_ohg[N7Eb`>
00DK@6nPc>gnoN[7VVTk60<14C5LSKcRn_oceZalC2@900TSBgZZeO;on^>mSehb
4P435cYWV<KYoOk^cJ5`@Q`500d[EHJegOOom]^cPe<Y30067TAcXlo_oocWa9IU
>1H20Q<dH96oi?_olM>XN4TQ200:9Tin[]OdooWP^X]J;a0111TnJic9jogmjlZM
KClJ104?;UV9^=ohooCH[gm?9`/02258MjOBl?okiL2BHCDD0P<E=fBE`^Kko^o?
Y7A57`L032UBP[;JmOoggKJ7Eb`>0@DL@FnPc>cmo>W6VFTk60@14S9MSKcQnOob
eJ]kC2@:00TTBg^[e?;onN:lSUhb4P8463]XVLGXo?g]c:1`@Qd60@h/EXJeg?Ko
mMZbPe<Z3@477dEcXlk^o__V`iEU>1H30a@eHI6oi?[nl=:WN4TR2@4;9dmo[]Oc
o_OO^HYJ<1421A/oK9c8j_clj/VMK3lK1P8A;eZ:^=ogo_?G[Wm@9``12B99MjOA
kogihknAHCHE0`@G>FFE`^GjoNk>Y7A680P23RYCP[7Im?keg;F6Ebd?0PLM@W2P
bn_lnnO5VFTl6@D34c=NS[_Pn?gae:YkC2D;0P/UC7^Ze?3mmn2kSUhc4`<66CaY
VLGWn_c[bj1`@Qh80a0]EhJefoGmlmVaPU<[3P<98DIdXlk]o?WT`IEU>AP51AHf
HY6nh_Slk]2WMdTS2P<=:51o[]Kao?GM]hYJ<A841aa0KIc7j?[jj<NLK40L1`@C
<E^:^=geo?7E[Gm@:@h32bA:N:O@k__ghKjAHCLF1@HI>VJE`NChnn_=XgA68@X4
42aDPk7Hl_ccf[B6EbhA10TPA76Pb^[jn>G3V6Tm6`L65CEOS[_OmO_^dZUkCBL=
10dWCWbZd^kkmMjjSEhd5@H873iZV<CUn?WYbIm`@b0:1A8_F8Jdf_;jlMJ`PU@/
4@D<8dQdXlcZnOKR`9AU>QX81aPhHi6mh?Gik<jUMdXU3@H@:e9o[MC_n_?K]XUK
<Q@72Qm2KIc6i_Ogi/FKK44N2PLE<eb:]m_bnNkC[7iA:Q063RI;N:K>joSdgkb@
HSPI20TK?6NE`>;en>W:XG=78`d74biFPk3FkoS`ek:5F30D1``RAW6Ob>OgmN;1
UfTn7@/963MPS[WMl_O[cjQkCRT@214ZCgbYd>cgl]^hS5lf60T;7d1ZV<;SmOKU
aie`AB8=2AHbFXNcenogkMB^PUD^50T?9TUeX/[Xm_?O_I=V?1`;2a/kI96lg_;f
j<bTMd/W40TC;E>0[=;/m^oH]8QL=1P:3R94KY_4hoCch/>JKD8Q3P/I=Uf:]MW_
mN[@ZWiB;A@:4RU=NJG<j?G`g;Z?HSXL30dO?fRD_]oam>G8X7=99Q0;5S5GPjoC
k?C/e;25FC8G2a0VB7:Na^CclMnoUVU080h=73YQS[SJko?Wc:IjCb/D31D]DGbX
c^Sck]RfRelh6`d@8T9/V<3OlO7Ra9a`AbDA3AXeFhNaeN_cjM6/PEHa5`dC:Daf
XLSTl^oK^i9V?R0?3almII6jfnkai<RRMddZ50hH<EF0ZloXl^_D/XQM=a/?4RI6
Ki_2h>o_g/2HKD@U4PlM>En:]=G[lNK=Z7iC<1P?5Re@NJC9i?3/f;N>HcdP4A8S
@FVD_=_]kn75WWA;:AD@6cEIPjg@j?3XdJj4FSDK41DYBW>Ma>3^k=^lU6Y391<B
83eSSKKFj^oSbJAjDBlH4ATaE7fWbnC^jMBcRf0k7a8D9TE]UkkKk>cM`I]`BBTF
4QhhGHN_dNO^iLfZPELd718H;DigX<GPkN[G^95W@B@D52A1Ii2henW/h<FPMdl^
6A<L=ER0ZLcSk>K@[hMN>R0D5bY9L9Zofn[Zf[fGKDLY5a@R?66:/M;Vjn79YWeE
<a`D6c5BNZ?6gn_WdkB=I3lT5QLWAFZC^MOXj]c1WGA=;AXE83QKQ:_=hn[Sc:^4
FcTP5QX^CGBL`M_YimJiTf]5:1PG9D1USK?BiNWNaJ9jDc<M5QheEWfUamoYhm2`
RV8n91PJ:dU^U[_Gi^OH_IUaBbdK62<lGhN]cN;XglVWP5Th8APN<U5gWl;KinCB
]I1XA2TJ6RU4J92ed^CVf/6NMe4b7QTR>EZ1YlSNin3<[8IO?BDJ7Bm=LYVlenGT
eKVEKTX]7AXW@6>:[lgPiMc5XgeG=b8J8CIENj72f^GQc[6<IT<Y71d]B6bB]];R
i=NmVgA@<R0K9CeNQ:W8gNCMb:R3GCdV720cD7FK_MKShM6eTVa8;AhM:dAWS;3=
gn?H`J1jECLS72@jFGjS`mWRgL^]RF=2:QhP<4a_UKOBh>3C^IMbCS8Q7RU1HHN[
b=cRfLBUP5/l9ahT=eAhWKkEh=k=/HiYAbhP82i8JXnbcMgPe;fLMe@g91lX?Uf1
YL?Hh=[7ZHIQ@BXP93A@LiNhdMkMckFCKddb8b4]AFF9[<SJgmK0XGeJ?2PQ9c]H
Ninne=kJbJf;IdL_8R@bC6jB/lgKgM6iV7EC=bHR;49PQ:K4emgF`jF3Gd4/8bLh
E7JI^M3Lf/^aT6e<<bDT<DUYS:g8f=cB_9ejF3`Y8b/oG7jQ_m?LelFYR6E6<2DW
=U1aU;C<fM[=]IEbDSLX9Bm5I8JX`mGJdknRP5i1;BD[?5QiVkW?fMO7[He[Bc@W
9cE=K8j^b=KIc[RJN5Ll:bH_@f21X[oBfM?1YXESAS4W:cYDM9JdbmOFbK6BL54h
:RPcBFN9ZL?CelnkWWeL@BlX;T1KO9fjc]OC`jZ:JD/e:R/iD6n@[lODeLZdUWEF
?BdZ<TMSQ:Bnd=K?_J:2HTHb:RhnF7NH]L[DdlF]Sfi@>B`/=de[Rj[2dMC;]i]j
Fd4`:c94GgnN^/cDcknVQfM;=R`^?EAbT[36d];6/9=cECd_;CI;IhJU_/kCbkVO
Of16=2db@U]jVKG9d/o1ZHa/D3X_;c]AKXfZ`/oAak>GN5Y2<RhfB6>1X;W;dLbk
XXAVBcP_<T5HMIB`aLo>`Zb@LEDn<S0jCVZ8YKg<d<ReVgeOASH`=TIOOIZealo;
_JF9Je0l<C<oEG6?Zl3=cL>_U7IJ@cDb>TaVQ:2ibLk8]in2I4/i<SI4G7RF/<?<
bkjXSFmD@3@d?U9]RZJlb/c4/IQkGTLh<cY:HWnL]<G<b;VRQVU@?C@f@eUdTJ^o
b/ZoZi5dFD@g=Ci@JHJQ^<K;a;>KOf=<>cDjB5mkUk31b/NjYHY^E44g=d9FL8bV
^lO9`:fENEi8>SLmCVJ1W;?3bLBeWX=XD3lg>TMLMi:[_LO6^jN>LUU5>SU2E6b8
X[O4al2_V7eSC3hh?TaSOIR__lK3]Z67KEE3>S]6FW>>Y[[4aKbZTWMNBCdj@E9Y
Pifc`LG0/I^1Ie51>ci;H7VCZkc4`[NTRg5IAcdlAUQ_RJ:f`LBl[9EkHTe0?49@
IWnI[[g3_k:NQFaEACdoBUeeSjJh`L6hYXmeGD/o?TEFK8FM/Kk2_:fHOfIB@ci2
Cf=kU:Zj`KncX8U`FDQ0@4YKLX^R];k0^:RBNF9?@cm6E6V1VJfk`;^^VX=[ETM0
@diQN92V][jm]::<M5i<@T59FFn7W[2k_[RYUGeVDdI1AU=VOYFY]kfk[if6KeY:
@dA>GgF<X[:l_;BTSgQRD4E3BUQ/PiV/^;bgZYN1JUM9A4MBI7ZAYKBk^[2ORW=N
CTE5CEebR9j^^KZdYY9lIUA8ADYGJWnEZ;Fj]j^JQ6iKCDI8DV9gSJ6`^;R`XHag
HU98AdiLKhFJZkJi/jNDOfYHC4M;EVMlTZBb^;J/VhMbGe19BE5QM8VM[KJg/::?
NVIFBdU>Fff1UZNb][>WUX9^G4m9C5IUNHjP[[Fd[9f:MF9DBd]BGg:6VJVc]JnS
TGeZFDi;CeYZOY:S[kBbZ9R5LEmBC4eEI7J:WJ^b/jbNSGUVEdi<DUi_PiJU/;>_
Y9>0KEeBCE1IJG^>Wjbb/:RJR7ESETm?EV=dQiVW/;6[WhmlJU]ACU=NKH2BXZba
[ZBEPg5QEDmAFFMiRibX[jnXVhYhIeUAD5IRLXBEY:f_Zj2AOfeNE55DGFamSijY
[ZbTUhIdI5QBDUUVMXRHYJb]Yib<NfYME59GHG21TZ2Y[JZPTX9aHUQCEEeZNX^K
YZb[Y9R8MfQLEEAJIGB5UJ:YZjNLSWi^H5MDF65^OXnMYZZXX9B4M6EKEUIMJGR8
Uj>YZJ>HRWY[GeQFFfEcPY:NYZVVWI20LFAJEeUQKGb<VJ>XYj2EQWMYGUQHGVQf
QYBOYZNSVHamKV9JF5aTLH2>Vj>WY9fAPWAWGUUJHFajRIJPYJFPUHQiK65KFUmX
MH>AW:>UXYV=Og5UGE]MIG1nS9RPY:>LTXAfJV5LG69/N8JCWJ>SWiJ9O6mTGUaP
J7B1SYVPXj2ISX5dJ61MGfE_O8VEWJ:QW9:6NFeTGUiSJgN4T9ZPXIjFRgibIf5N
HFQcOh^FWJ2OVHn3MV]SGf1VKgZ6TYZOWi^BQg]`If5PI6]fPXfGWInLUXb0M6YT
HF=YLWf9TiZNWIR?Q7U^IV9RIViiQ8nGW9fJTXUmLVYTHVE/MH2;U9ZMViF<PWM]
IV=TJG5lQY2HVi^GShIkLFUUI6Q^N8:<UIZKV9:9OgE/IfEWK7AnR96GVYVDSH=i
L6UVIVYaNhB>UIVIUXn7OGA/IfIYKgN1RY:GVINBRX5gKfYWJ6edOHJ?UIRGThf4
Ng9/J6Q[LGZ3Ri:FUiB?QgifKfYYJVmgOhR?U9JETHZ2NG9/JVY^M7b4S9:EUI:<
QGeeKf]ZKG9iPHV?TiFCSXR0N75]Jfa`Mgj6SI:DTi2:Pg]dKfa/KgAkPhZ?Ti>A
S8EnMg5^KFicNH27SI6BTHf8PGYdKfe^LGMmQ8Z?TI6>RX=mMW9_KW5eNh68SI2A
Sh^6OgUdL6m`M7UoQHZ>T8n<R89lMW9`L7=gOH>8S8n?SHV4OWQdLG5bMW^0QXZ=
SXf:QX1kMW=aLWEiOXB8S8f=RhN2OGQeLW9dN7b1QXZ<SH^8Q7mjMWAcM7MkOhB8
Rhb;RHF1O7QeM7AfNWj2QXV;RhV6PWijMgEeMWUlP8B8RXZ9QhB0O7UfMGIhNgn3
QXR9RHN5PGejN7IfN7YnPHB7R8V8QH9oO7UgMgQjOH23QXN8QhJ3P7ekNGQhNWao
PXB6QhN6Q85nO7YiNGYkOX23QHJ6QXB2OgekNWUjNgeoPXB5QXF4PX1nO7]jNW]m
Oh62Q8F5Q8>1OgelNg]lOGj0PH>4Q8B3PH1nOGalO7enOh62Ph>3PX60OgimOGem
OWn0PH:2PX:1P81oOWimOWioP821PH61PH20OgmnOWioOgn0P861PH20P81oOgmo
Ogn0P820P820P820\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Speech signal", "Subsection"],

Cell[CellGroupData[{

Cell["Import wav file", "Subsubsection"],

Cell["\<\
Adjust the directory setting and input file below to your system \
configuration.\
\>", "Text"],

Cell[BoxData[{
    \(\(dir = "\</Users/nechyba/public_html/eel3135/data\>";\)\), "\
\[IndentingNewLine]", 
    \(\(file = "\<Speech.wav\>";\)\)}], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetDirectory[dir];\)\), "\n", 
    \(\(wav1 = ReadSoundFile[file, PrintHeader \[Rule] True];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Format: "\[InvisibleSpace]"Microsoft PCM WAVE \
RIFF"\),
      SequenceForm[ "Format: ", "Microsoft PCM WAVE RIFF"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Duration: "\[InvisibleSpace]3.8333782690752223`\
\[InvisibleSpace]" seconds"\),
      SequenceForm[ "Duration: ", 3.8333782690752223, " seconds"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Channels: "\[InvisibleSpace]1\),
      SequenceForm[ "Channels: ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Sampling rate: "\[InvisibleSpace]11127\),
      SequenceForm[ "Sampling rate: ", 11127],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Bits per sample: "\[InvisibleSpace]8\),
      SequenceForm[ "Bits per sample: ", 8],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Data size: "\[InvisibleSpace]42654\[InvisibleSpace]" \
bytes"\),
      SequenceForm[ "Data size: ", 42654, " bytes"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of samples: "\[InvisibleSpace]42654\),
      SequenceForm[ "Number of samples: ", 42654],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(sampleRate1 = 11127;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Listen to wav file", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlay[wav1, SampleRate \[Rule] sampleRate1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
11127 42654 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`00000Q
0000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`07ooooo`Go
000000?oooooo`000?ooool03Oooool:o`0000kooooo0ol00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool3o`000003ooooool0003o000000;o00007Oooool5o`0001;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`Ko00000oooool00ol0003oooooo`000008o`00
03Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooool00000;?ooool10000
000000<00000ooooooooool01oooool2o`000003ooooool0003o000000;o00000oooool00ol0003o
ooooooooo`08ooooo`_o00003Oooool7o`000003ooooool0003ooooo00co00007?ooool8o`0000oo
oooo0ol000001?oooooo0000ooooool00002ooooo`;o00004Oooool7o`0000Gooooo2ol0000eoooo
o`04o`000?oooooo0000ooooo`Ko0000;Oooool10000000000<00000ooooooooool01_ooool9o`00
0004ooooool0003oooooo`0000Sooooo00?o0000ooooool000002ol0000:ooooo`;o000000?ooooo
o`000?l000004ol0000Kooooo`Wo00003_ooool7o`000003ooooool0003o000000Co00003Oooool9
o`0000?ooooo3?l0000Oooooo`03o`000?oooooooooo01?ooooo1Ol000000ooooooo0000o`000004
o`0000kooooo00Ko0000ooooooooooooooooo`000?ooool3o`0001Cooooo0@000000000300000?oo
oooooooo00Kooooo3Ol00007oooooa3o00002OoooolIo`0001Wooooo2_l0000=ooooo`?o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000004o`0000cooooo2ol00002ooooo`go00006ooo
ool00ol0003oooooo`000002o`0001?ooooo3Ol0000=ooooo`co000000?oooooo`000?ooool03ooo
ool10000000000<00000ooooooooool01_ooool>o`0000Kooooo4?l00009oooooaWo00006_ooool:
o`0000_ooooo4Ol0000;ooooo`_o00000_ooool=o`0001[ooooo1ol0000Aoooooa3o00002_oooolA
o`0000kooooo0@000000000300000?oooooooooo00Kooooo3ol00005oooooa7o00001ooooolJo`00
01Wooooo2ol00005ooooo`05o`000?ooooooooooo`000?ooool04_l00009ooooo`go00000_ooool?
o`0001Cooooo3?l0000?oooooa7o00002_oooolAo`0000kooooo0@000000000300000?oooooooooo
00Gooooo4Ol000001?oooooo0000oooooooooolAo`0000Oooooo7?l000000ooooooo0000ooooo`0D
ooooo`co00001?oooolGo`0000Sooooo8?l0000Cooooo`ko00003OoooolBo`0000Wooooo4_l0000=
ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000000000<00000ooooool0
0000ool0000Lo`00007ooooo0@000000000300000?oooooooooo00Gooooo4Ol00004oooooa7o0000
1ooooolKo`0001Sooooo3?l00004oooooaOo00002?oooolPo`0001;ooooo3Ol0000?oooooa;o0000
2OoooolBo`0000gooooo0@000000000300000?oooooooooo00Kooooo3_l00006oooooa7o00001ooo
oolJo`0001Wooooo3?l00005ooooo`?o000000?oooooo`000?l000004?l00008ooooo`03o`000?oo
oooooooo00_o00000_ooool>o`0001Gooooo2ol0000Aooooo`oo00002ooooolBo`0000gooooo0@00
0000000300000?oooooooooo00Kooooo3Ol00008ooooo`oo00002OoooolHo`0001[ooooo2ol0000;
oooooa7o00002oooool;o`0000;ooooo3Ol0000Gooooo`03o`000?oooooooooo00?ooooo0ol0000B
ooooo`oo00002oooool=o`000004ooooool0003o0000o`0000kooooo0@000000000300000?oooooo
000000Kooooo3Ol00007ooooo`oo00002_ooool6o`000003ooooool0003o000000;o000000?ooooo
o`000?l000002ol0000Iooooo`[o00003Oooool?o`0000gooooo2_l00002ooooo`go0000<_ooool0
0ol0003oooooooooo`02ooooo`Wo00003_ooool:o`0000;ooooo00?o0000ooooooooool03_ooool1
0000000000<00000ooooooooool01_ooool9o`000004ooooool0003o0000o`0000Sooooo3ol00009
ooooo`Co000000Koooooo`000?oooooo0000ooooool00002ooooo`;o000000?oooooo`000?l00000
1?l000000ooooooo0000o`00000Kooooo`So00003oooool7o`000003ooooool0003o000000?o0000
4?ooool7o`0000?ooooo2ol0000eooooo`03o`000?oooooooooo00Cooooo1?l0000@ooooo`03o`00
0?oooooo000000Go00005Oooool10000000000<00000ooooooooool01oooool8o`0000kooooo1ol0
0002ooooo`?o00002oooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool000001Ol0000@ooooo`Co00001?oo
ool3o`0001;ooooo1?l000000ooooooo0000ooooo`05ooooo`Wo0000=?ooool00ol0003ooooooooo
o`0Hooooo`So00005Oooool10000000000<00000ooooooooool02?ooool2o`000004ooooool0003o
0000o`00017ooooo00Co0000ooooool0003ooooo1?l0000=ooooo`?o0000;oooool01Ol0003ooooo
o`000?l0003ooooo00?o00003oooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo013o
oooo1_l00004ooooo`?o000000?oooooo`000?l000001Ol0000mooooo`03o`000?oooooooooo013o
oooo0_l00002ooooo`;o00005oooool10000000000<00000ooooooooool0oooooolMooooo`400000
003o00000240000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo
00Kooooo3_l00007ooooo`03o`000?oooooo000000So00003OoooolEo`000003ooooool0003ooooo
01_ooooo00?o0000ooooool000001?l0000Aooooo`03o`000?oooooooooo00?o00000_ooool5o`00
00gooooo2?l00004ooooo`_o00007Oooool6o`0001;ooooo3_l0000=ooooo`Wo00005?ooool10000
000000<00000ooooooooool01oooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Co
00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo0ol00003ooooo`04
o`000?ooooooooooooooo`;o00000oooool2o`0000?ooooo0_l0000Looooo`;o000000?oooooo`00
0?ooool00_l0000Dooooo`?o00000_ooool4o`0000kooooo1?l000000ooooooo0000o`000002o`00
00?ooooo00?o0000ooooool000000ol00002ooooo`?o00007Oooool00ol0003oooooooooo`0Foooo
o`Co00000oooool4o`000003ooooool0003ooooo00kooooo0_l00003ooooo`;o00005?ooool10000
000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`07ooooo`03o`00
0?oooooooooo00Co000000Coooooo`000?l0003ooooo0_l00007ooooo`;o000000Goooooo`000?oo
ooooooooo`000004ooooo`03o`000?oooooooooo00_ooooo00Co0000ooooool0003ooooo0_l00002
ooooo`04o`000?ooooooooooooooo`?o000000Coooooo`000?l0003o00008oooool4o`0001Gooooo
00?o0000ooooooooool01?l0000?ooooo`Oo00001?ooool2o`000003ooooool0003o000000?o0000
00?oooooo`000?l000007?ooool7o`0001;ooooo1Ol000001?oooooo0000o`000?ooool3o`000003
ooooool0003ooooo00cooooo0_l000000ooooooo0000o`000002o`000003ooooool0003ooooo01?o
oooo0@000000000300000?oooooooooo0?oooooo7Oooool10000000000<00000ooooooooool0oooo
oolMooooo`40000000000`00003oooooooooo`06ooooo`Go00000_ooool4o`000003ooooool0003o
oooo00Oooooo1?l00003ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`03
ooooo`Ko00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo000001_ooooo00Co0000
oooooooooooooooo0ol0000Eooooo`;o00000_ooool5o`0000gooooo00?o0000ooooool000001_l0
0003ooooo`;o000000?oooooo`000?ooool00_l00003ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooool000000ol0000Aooooo`03o`000?oooooo000000Co00000_ooool01?l0003oooooo`00
0?l0000@ooooo`?o000000Coooooo`000?l0003o00005Oooool10000000000<00000ooooooooool0
oooooolMooooo`40000000000`00003oooooooooo`06ooooo`Wo00001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;o00001Oooool00ol0003oooooooooo`0<ooooo`;o00001?oo
ool2o`000006ooooool0003oooooooooool0003ooooo1Ol00003ooooo`03o`000?oooooooooo01Wo
oooo0_l00002ooooo`04o`000?oooooo0000o`0000oooooo00Co0000ooooool0003ooooo0ol00002
ooooo`?o00003oooool8o`0000Cooooo0_l000000ooooooo0000ooooo`03o`000003ooooool0003o
000001cooooo0_l00002ooooo`Co00004Oooool3o`0000;ooooo1Ol000000ooooooo0000ooooo`0>
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00004oooool10000000000<00000
ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`3ooooooagooooo0@0000000003
00000?oooooooooo00Wooooo0ol000000ooooooo0000o`000003o`0000Wooooo0ol00002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000003?ooool2o`0000?ooooo1?l000000ooooooo
0000o`000002o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000006_ooool2o`000004
ooooool0003o0000ooooo`;o00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?o000000?oooooo`000?ooool02oooool:o`0000Cooooo0_l000000ooooooo0000o`000002o`00
0003ooooool0003ooooo01cooooo1ol0000Booooo`;o000000?oooooo`000?ooool00ol00002oooo
o`03o`000?oooooo000000;o00003?ooool8o`000003ooooool0003ooooo01;ooooo0@0000000003
00000?oooooooooo0?oooooo7Oooool10000000000<00000ooooooooool01oooool00ol0003ooooo
o`00000:o`0000Oooooo0_l00004ooooo`Oo00003?ooool00ol0003oooooo`000004o`0000;ooooo
1?l00002ooooo`Go00007_ooool00ol0003oooooo`000004o`00013ooooo00Go0000ooooool0003o
0000ooooo`02o`0000;ooooo1?l0000>ooooo`Oo000000?oooooo`000?ooool00oooool7o`0000?o
oooo00?o0000ooooooooool06Oooool5o`000003ooooool0003ooooo013ooooo1?l00002ooooo`Oo
000000?oooooo`000?ooool03?ooool5o`000003ooooool0003o000001Gooooo0@00000000030000
0?oooooooooo0?oooooo7Oooool10000000000<00000ooooooooool0oooooolMooooo`4000000000
0`00003oooooooooo`07ooooo`[o000000?oooooo`000?ooool01oooool7o`000003ooooool0003o
000000;o00003Oooool2o`000004ooooool0003oooooooooo`;o00000_ooool9o`0000?ooooo00?o
0000ooooooooool06Oooool2o`000004ooooool0003o0000ooooo`?o00003Oooool2o`0000Cooooo
0_l00002ooooo`?o00003_ooool00ol0003oooooo`000003o`000003ooooool0003o000000;o0000
0oooool;o`0001_ooooo0_l000000ooooooo0000ooooo`02o`0001;ooooo00Co0000ooooool0003o
oooo1?l00002ooooo`;o000000?oooooo`000?ooool02oooool4o`000004ooooool0003ooooooooo
o`;o00005?ooool10000000000<00000ooooooooool0oooooolMooooo`40000000000`00003ooooo
ooooo`3ooooooagooooo0@000000000300000?oooooooooo00Kooooo1Ol000000ooooooo0000o`00
0002o`0000gooooo00?o0000ooooool000001Ol000000ooooooo0000ooooo`0<ooooo`;o00000_oo
ool5o`0000;ooooo00?o0000ooooooooool01Ol0000Oooooo`;o00000oooool2o`0000oooooo2Ol0
00000ooooooo0000o`000003o`0000cooooo00?o0000ooooooooool00ol00007ooooo`Go00000_oo
ool4o`0001cooooo1ol0000Booooo`Ko000000?oooooo`000?l000001_l0000<ooooo`?o000000?o
ooooo`000?ooool00_l000000ooooooo0000ooooo`0Booooo`40000000000`00003oooooooooo`3o
oooooagooooo0@000000000300000?oooooooooo00Kooooo0ol000000ooooooo0000ooooo`04o`00
00;ooooo0_l00008ooooo`Go000000?oooooo`000?ooool00oooool2o`0000_ooooo0_l000000ooo
oooo0000ooooo`02o`000009ooooool0003o0000o`000?oooooo0000ooooool0003ooooo00;o0000
00?oooooo`000?l000000_ooool00ol0003oooooooooo`0Hooooo`Oo00003_ooool00ol0003ooooo
o`000006o`0000Kooooo00?o0000ooooooooool02oooool8o`0000Gooooo0_l00002ooooo`Ko0000
7?ooool00ol0003oooooo`000005o`00017ooooo1_l00002ooooo`Ko00003Oooool6o`000003oooo
ool0003o000000;o00004_ooool10000000000<00000ooooooooool0oooooolMooooo`4000000000
0`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo00Kooooo1ol00002oooo
o`;o000000?oooooo`000?l000001oooool3o`000005ooooool0003o0000o`000?ooool00_l00000
1?oooooo0000ooooool0000:ooooo`?o000000?oooooo`000?l000002ol000000ooooooo0000o`00
0004o`0001[ooooo1?l000000ooooooo0000o`000002o`0000kooooo00?o0000ooooooooool01Ol0
0002ooooo`Go00003_ooool3o`000005ooooool0003o0000ooooool000000oooool<o`0001Sooooo
00?o0000ooooool000000ol000001?oooooo0000o`000?l0000Aooooo`?o000000Goooooo`000?l0
003o0000ooooo`06o`0000gooooo1ol000001?oooooo0000o`000?l0000Cooooo`40000000000`00
003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo00Sooooo3?l00007ooooo`;o
000000?oooooo`000?ooool01?l00002ooooo`03o`000?oooooooooo00_ooooo0_l000001_oooooo
0000o`000?oooooo0000ooooo`Co00000_ooool5o`000003ooooool0003o000001_ooooo2Ol0000=
ooooo`So000000?oooooo`000?ooool01Ol0000<ooooo`So000000?oooooo`000?ooool00_ooool2
o`000003ooooool0003o000000Ko00006Oooool6o`000003ooooool0003o000000;o00004Oooool9
o`000003ooooool0003ooooo00;o00003Oooool6o`0000;ooooo0ol0000Booooo`40000000000`00
003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo0?oooooo7Oooool100000000
00<00000ooooooooool01_ooool4o`000003ooooool0003o000000Oo00002?ooool3o`000004oooo
ool0003oooooo`0000;ooooo0_l0000=ooooo`;o000000Coooooo`000?l0003ooooo1Ol000000ooo
oooo0000o`000006o`000003ooooool0003o000001[ooooo0_l000000ooooooo0000o`000004o`00
00gooooo1Ol000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000003?ooool2
o`000003ooooool0003o000000Go00000oooool<o`0001Sooooo2ol0000@ooooo`Co00000_ooool4
o`000003ooooool0003o000000?o00003?ooool;o`0001;ooooo0@000000000300000?oooooooooo
0?oooooo7Oooool10000000000<00000ooooooooool01_ooool6o`0000;ooooo00?o0000ooooool0
00000_l00008ooooo`Oo00001?ooool00ol0003oooooo`00000:ooooo`;o000000?oooooo`000?l0
00001_l000000ooooooo0000o`000007o`000003ooooool0003o000001_ooooo0_l000000ooooooo
0000o`000003o`0000gooooo1_l000000ooooooo0000o`000007o`0000cooooo2_l00003ooooo`Co
000000?oooooo`000?l000001Ol0000Hooooo`Ko000000Coooooo`000?l0003ooooo0_l0000@oooo
o`;o000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`0000_ooooo2Ol000000ooo
oooo0000o`00000Booooo`40000000000`00003oooooooooo`3ooooooagooooo0@00000000030000
0?oooooooooo0?oooooo7Oooool10000000000<00000ooooooooool01oooool:o`000004ooooool0
003o0000o`0000Gooooo2_l00002ooooo`;o00002oooool=o`000003ooooool0003o000000Oo0000
7?ooool8o`0000gooooo4Ol0000;ooooo`[o00000oooool2o`000003ooooool0003o000000Co0000
00?oooooo`000?l000006Oooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooool00000
3oooool01_l0003oooooo`000?oooooo0000ooooo`Go00000oooool00ol0003oooooooooo`09oooo
o`So00000_ooool3o`0001;ooooo0@000000000300000?oooooooooo0?oooooo7Oooool100000000
00<00000ooooooooool01_ooool>o`0000Kooooo3Ol0000<ooooo`?o000000?oooooo`000?l00000
4?l000000ooooooo0000ooooo`0Iooooo`Oo000000?oooooo`000?ooool02oooool>o`000004oooo
ool0003o0000o`0000_ooooo2ol00002ooooo`_o00006Oooool4o`000004ooooool0003ooooooooo
o`Co00003oooool2o`000003ooooool0003o000000Co000000?oooooo`000?l000001?l0000;oooo
o`Ko000000?oooooo`000?l000000ol000000ooooooo0000ooooo`0?ooooo`40000000000`00003o
ooooooooo`3ooooooagooooo0@000000000300000?oooooooooo0?oooooo7Oooool10000000000<0
0000ooooooooool01_ooool8o`000003ooooool0003ooooo00?o00001_ooool8o`000004ooooool0
003o0000ooooo`Co00002_ooool3o`000003ooooool0003o000000?o000000?oooooo`000?l00000
0_l000000ooooooo0000o`000007o`0001Wooooo2_l0000;ooooo`Oo000000Coooooo`000?l0003o
oooo1_l0000<ooooo`03o`000?oooooo000000So00000_ooool<o`0001Sooooo1ol00002ooooo`Co
00003_ooool4o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol0000;ooooo`go
00004Oooool10000000000<00000ooooooooool0oooooolMooooo`40000000000`00003ooooooooo
o`3ooooooagooooo0@000000000300000?oooooooooo00Gooooo4?l00005ooooo`[o000000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`07ooooo`Wo000000?oooooo`000?ooool03?l0000J
ooooo`[o00002oooool5o`000003ooooool0003o000000So000000?oooooo`000?ooool02_ooool;
o`0000;ooooo2Ol000000ooooooo0000o`00000Hooooo`go00003_ooool@o`0000[ooooo1ol00000
1?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00oooooo0@000000000300000?oooooo
oooo0?oooooo7Oooool10000000000<00000ooooooooool01_ooool>o`0000Kooooo2ol000000ooo
oooo0000o`000002o`0000[ooooo1?l000000ooooooo0000o`000008o`000003ooooool0003o0000
00Ko00006Oooool:o`0000_ooooo1Ol000000ooooooo0000o`00000:o`0000[ooooo3?l00002oooo
o`co00005oooool8o`0000;ooooo1?l0000>ooooo`;o000000?oooooo`000?ooool00ol00003oooo
o`Go00002_ooool6o`000003ooooool0003o000000Ko000000?oooooo`000?ooool03Oooool10000
000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`06ooooo`?o0000
00?oooooo`000?ooool02Ol00005oooooa3o00002Oooool7o`000003ooooool0003o000000;o0000
0_ooool;o`0001Wooooo2_l0000;ooooo`So000000?oooooo`000?ooool01ol0000;ooooo`_o0000
0_ooool<o`0001Oooooo1_l00002ooooo`03o`000?oooooo000000?o00003_ooool@o`0000[ooooo
0ol00002ooooo`co00003_ooool10000000000<00000ooooooooool0oooooolMooooo`4000000000
0`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo00Kooooo3ol00006oooo
o`oo00002_ooool7o`000003ooooool0003o000000go00006oooool3o`000003ooooool0003o0000
00Co00002_oooolBo`0000[ooooo6ol0000Fooooo`Go000000Coooooo`000?l0003ooooo1Ol0000>
ooooo`co000000Coooooo`000?l0003o00002oooool?o`0000oooooo0@000000000300000?oooooo
oooo0?oooooo7Oooool10000000000<00000ooooooooool0oooooolMooooo`40000000000`00003o
ooooooooo`06ooooo`Go000000Coooooo`000?oooooooooo1ol00004oooooa3o00002Oooool00ol0
003oooooo`00000Eo`0001cooooo2?l000000ooooooo0000ooooo`08ooooo`go000000?oooooo`00
0?l000000_l00009ooooo`go000000?oooooo`000?l000001?l000000ooooooo0000o`000005o`00
01Kooooo1?l000001Ooooooo0000o`000?l0003ooooo00;o000000Coooooo`000?l0003o00003?oo
ool3o`000003ooooool0003o000000_o00002_ooool3o`0000;ooooo0_l000000ooooooo0000o`00
0002o`000003ooooool0003o000000;o00003_ooool10000000000<00000ooooooooool0oooooolM
ooooo`40000000000`00003oooooooooo`06ooooo`Oo000000?oooooo`000?l000000_l000001?oo
oooo0000o`000?l00004oooooa3o00002Oooool7o`000005ooooool0003oooooo`000?ooool01Ol0
00000ooooooo0000o`000004o`0001[ooooo1ol000001?oooooo0000o`000?l00008ooooo`03o`00
0?oooooo000000co000000?oooooo`000?l000000_l00009ooooo`Oo000000?oooooo`000?l00000
1?l000000ooooooo0000o`00000<o`0001Gooooo1Ol000001?oooooo0000ooooooooool6o`0000go
oooo4?l0000:oooooa7o00003_ooool10000000000<00000ooooooooool0oooooolMooooo`400000
00000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo00Gooooo2ol00000
0ooooooo0000o`000003o`0000?ooooo2_l000000ooooooo0000o`000005o`0000Oooooo3_l00000
0ooooooo0000o`000009o`0001Wooooo1_l000000ooooooo0000o`000003o`0000Oooooo00?o0000
ooooool000003?l000000ooooooo0000ooooo`02o`0000[ooooo2Ol000000ooooooo0000o`00000@
o`0001Gooooo3ol0000=ooooo`;o00000_ooool7o`000003ooooool0003o000000;o00002_oooolA
o`0000kooooo0@000000000300000?oooooooooo0?oooooo7Oooool10000000000<00000oooooooo
ool0oooooolMooooo`40000000000`00003oooooooooo`06ooooo`Wo000000?oooooo`000?l00000
1_l000000ooooooo0000o`00000@o`0000Oooooo6ol0000Hooooo`_o00001Oooool2o`000003oooo
ool0003ooooo00co000000?oooooo`000?l000000ol00008ooooo`03o`000?oooooo000001co0000
4oooool@o`0000gooooo00?o0000ooooool000003_l00009oooooa7o00003_ooool10000000000<0
0000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`05ooooo`So000000?ooooo
o`000?ooool06ol00007oooooa_o00000_ooool00ol0003oooooooooo`0Cooooo`co00001?oooolC
o`000004ooooool0003o0000o`0000Sooooo00?o0000ooooool000007?l0000Dooooo`oo00003?oo
ool;o`000003ooooool0003o000000?o00002_ooool6o`000003ooooool0003o000000Wo00003Ooo
ool10000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`05oooo
o`?o000000?oooooo`000?l000000ol000000ooooooo0000o`000008o`000005ooooool0003o0000
o`000?ooool03Ol00007ooooo`;o000000?oooooo`000?l000005_l00002ooooo`03o`000?oooooo
oooo01?ooooo2ol00005oooooaCo000000?oooooo`000?l000002?ooool5o`000003ooooool0003o
000001Oo00004oooool@o`0000cooooo3?l000000ooooooo0000o`000003o`0000Wooooo4_l0000=
ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo0?oo
oooo7Oooool10000000000<00000ooooooooool01_ooool4o`0000?ooooo7_l00007oooooaco0000
00?oooooo`000?ooool05?ooool<o`0000Cooooo5ol00008ooooob7o00004Oooool6o`000003oooo
ool0003ooooo00?o000000Coooooo`000?l0003o00003?oooolBo`0000Wooooo2_l000000ooooooo
0000o`000005o`0000gooooo0@000000000300000?oooooooooo0?oooooo7Oooool10000000000<0
0000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`05ooooo`Wo000000?ooooo
o`000?l000006ol00004ooooo`Go000000?oooooo`000?l000006?l0000Eooooo`;o000000?ooooo
o`000?l000001ol00005ooooo`Go000000?oooooo`000?l000000ol000000ooooooo0000o`000008
o`0000Sooooo1_l00002oooooa[o00001_ooool01Ol0003ooooooooooooooooo000000Gooooo3_l0
00000ooooooo0000o`000005ooooo`;o00000_ooool5o`000003ooooool0003o000000So000000?o
ooooo`000?l000000_l00008oooooa;o00003Oooool10000000000<00000ooooooooool0oooooolM
ooooo`40000000001000003oooooooooooooool2o`0000;ooooo3_l000000ooooooo0000o`00000H
o`0000;ooooo4ol000000ooooooo0000ooooo`0:o`0000?ooooo0_l0000@ooooo`co00001?oooolL
o`0000;ooooo2ol000000ooooooo0000o`000006o`000003ooooool0003o000000go000000?ooooo
o`000?ooool00_ooool2o`0000;ooooo0ol00002oooooaCo00000_ooool3o`0000;ooooo1Ol00000
0ooooooo0000o`00000=o`0000;ooooo0_l000001?oooooo0000oooooooooolCo`0000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooooooool10000000000<00000ooooooooool0oooo
oolMooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooo0000
01;o000000?oooooo`000?l00000??l000000ooooooo0000o`000002o`0000;ooooo1_l000000ooo
oooo0000o`00000ao`000003ooooool0003o000002Co00000_ooool9o`000003ooooool0003o0000
02[o000000?oooooo`000?l000005Ol000000ooooooo0000o`000005o`000003ooooool0003o0000
00?o000000Goooooo`000?l0003o0000ooooo`010000000000<00000ooooooooool0oooooolMoooo
o`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooo000000Wo0000
00?oooooo`000?ooool0<?l000000ooooooo0000o`000006o`000003ooooool0003o000001oo0000
00?oooooo`000?l000000_l000000ooooooo0000o`00000Ho`000003ooooool0003o000001Co0000
00?oooooo`000?l000002?l000000ooooooo0000o`00000io`0000;ooooo7?l000000ooooooo0000
o`00000Eo`00007ooooo0@000000000300000?oooooooooo0?oooooo7Oooool10000000000<00000
ooooool00000R?l000000ooooooo0000o`00000=o`000003ooooool0003o000000;ooooo0ol00000
0ooooooo0000o`000013o`000003ooooool0003o000003;o00000Oooool10000000000<00000oooo
ooooool0oooooolMooooo`40000000000`00003oooooooooo`3ooooooagooooo0@00000000030000
0?oooooo000000_o00000_oooomio`000003ooooool0003ooooo017o000000?oooooo`000?l00000
;ol000000ooooooo0000o`00000Do`000003ooooool0003o0000027o000000?oooooo`000?l00000
4Ol00001ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooo
000000ko000000?oooooo`000?l000003Ol000000ooooooo0000o`000015o`000003ooooool0003o
000000Go000000?oooooo`000?l000009ol000000ooooooo0000ooooo`0;o`000003ooooool0003o
000007;o00000Oooool10000000000<00000ooooooooool0oooooolMooooo`40000000000`00003o
ooooooooo`3ooooooagooooo0@000000000300000?oooooo000002oo000000?oooooo`000?l00000
3_l000000ooooooo0000ooooo`0Co`0000?ooooo1?l000000ooooooo0000ooooo`04o`000003oooo
ool0003o000000;ooooo0ol000000ooooooo0000o`000004o`000003ooooool0003o000001So0000
00?oooooo`000?l000005?l000000ooooooo0000o`000005o`000003ooooool0003o000000Wo0000
0_ooool9o`000003ooooool0003o000001ko000000?oooooo`000?l000004Ol000000ooooooo0000
o`00000?o`000003ooooool0003o000000?o000000?oooooo`000?ooool01ol00001ooooo`400000
00000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo00Gooooo0_l00000
0ooooooo0000o`00000Qo`000003ooooool0003o000000?ooooo8?l0000;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02ol00005ooooo`Oo000000?oooooo`000?l000002Ol00000
0ooooooo0000o`000002o`0000Oooooo1Ol000000ooooooo0000o`00000=o`000003ooooool0003o
000000[o00001_ooool2o`000004ooooool0003o0000o`0000?ooooo4_l000001?oooooo0000oooo
ooooool3o`0000;ooooo00?o0000ooooool000004_l00004ooooo`04o`000?ooooooooooooooo`Wo
000000?oooooo`000?l000001ol0000:ooooo`7o00000Oooool10000000000<00000ooooooooool0
oooooolMooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooo
oooo00Gooooo1ol000000ooooooo0000o`00000Lo`0000Oooooo0ol000000ooooooo0000o`00000<
o`000003ooooool0003o000000[o00005?ooool<o`0000Cooooo4ol000000ooooooo0000o`000002
o`0000Oooooo2ol000000ooooooo0000o`00000Do`0000[ooooo0_l00004oooooa7o000000?ooooo
o`000?ooool01_ooool00ol0003oooooo`000002o`000003ooooool0003o000000co00002OoooolB
o`0000gooooo0@000000000300000?oooooooooo0?oooooo7Oooool10000000000<00000oooooooo
ool0oooooolMooooo`40000000000`00003oooooooooo`05ooooo`Oo000000?oooooo`000?l00000
0_l000000ooooooo0000o`000007o`000004ooooool0003o0000ooooo`_o00002?ooool2o`000003
ooooool0003o000000Wo000000?oooooo`000?l000002_l000000ooooooo0000o`00000Eooooo`?o
000000?oooooo`000?l000001_l00004ooooo`So000000?oooooo`000?ooool02?l000001?oooooo
0000o`000?l00008ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000008
o`000003ooooool0003o000000Wo00004_ooool@o`0000cooooo0ol000000ooooooo0000o`00000<
o`0000Wooooo3ol000000ooooooo0000o`00000=ooooo`40000000000`00003oooooooooo`3ooooo
oagooooo0@000000000300000?oooooooooo00Gooooo6?l000000ooooooo0000o`000004o`000006
ooooool0003o0000o`000?oooooo00002?oooolJo`000004ooooool0003o0000o`0001Gooooo2ol0
0005oooooaOo00002?ooool:o`000003ooooool0003o000001;o000000?oooooo`000?ooool04Ooo
ool7o`000005ooooool0003o0000o`000?ooool00ol0000<oooooa;o00002OoooolBo`0000gooooo
0@000000000300000?oooooooooo0?oooooo7Oooool10000000000<00000ooooooooool0oooooolM
ooooo`40000000000`00003oooooooooo`05ooooo`go000000?oooooo`000?l000005_l00007oooo
oa?o000000?oooooo`000?l000001Ol00002ooooo`03o`000?oooooooooo01?ooooo2ol00006oooo
oaKo00002Oooool02Ol0003oooooo`000?l0003oooooo`000?oooooo0000ooooo`06o`000003oooo
ool0003o000000go00004_ooool@o`0000cooooo2_l000000ooooooo0000o`000005o`0000Wooooo
0_l000000ooooooo0000o`00000=o`0000gooooo0@000000000300000?oooooooooo0?oooooo7Ooo
ool10000000000<00000ooooooooool01_oooolBo`000003ooooool0003ooooo00oo00002?ooool2
o`000003ooooool0003o000001Go00000oooool00ol0003oooooooooo`0Cooooo`So000000?ooooo
o`000?l000001_ooool01?l0003oooooooooooooool3o`000003ooooool0003o000000co00002?oo
ool9o`000003ooooool0003ooooo01Co00004oooool?o`0000gooooo2Ol00002ooooo`03o`000?oo
oooo000000;o00002_ooool;o`000003ooooool0003o000000Co00003Oooool10000000000<00000
ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`3ooooooagooooo0@0000000003
00000?oooooooooo00Gooooo2?l000000ooooooo0000o`000006o`000003ooooool0003ooooo00Ko
000000?oooooo`000?l000001Ol000001?oooooo0000o`000?l00007ooooo`Ko000000?oooooo`00
0?l000002Ol000000ooooooo0000o`000004o`000003ooooool0003ooooo01Oooooo0_l000000ooo
oooo0000o`000006o`0000Gooooo0ol00002ooooo`Co000000Coooooo`000?l0003o00000_ooool4
o`000003ooooool0003o000000_ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o000000?o
ooooo`000?l000002_l000000ooooooo0000o`000004o`0001?ooooo3ol0000<ooooo`?o000000?o
ooooo`000?l000000ol000000ooooooo0000o`000005o`0000[ooooo3_l000001?oooooo0000o`00
0?l0000=ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooo
oooo00Gooooo4Ol00004ooooo`?o000000?oooooo`000?l000002ol00008oooooaOo00006oooool9
o`000003ooooool0003ooooo00Gooooo00Co0000ooooool0003ooooo1?l000000ooooooo0000o`00
0004o`000003ooooool0003o000000?o00003?ooool2o`000003ooooool0003ooooo01;o000000Co
ooooo`000?l0003ooooo0_l0000Cooooo`Ko000000?oooooo`000?l000001_l0000=ooooo`Wo0000
0_ooool5o`0000[ooooo4_l0000=ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@00
0000000300000?oooooooooo0?oooooo7Oooool10000000000<00000ooooooooool01_ooool5o`00
0003ooooool0003o000000So00001?ooool5o`000006ooooool0003o0000ooooool0003ooooo0_l0
00000ooooooo0000o`000009ooooo`ko000000?oooooo`000?l000002?l0000Iooooo`Co00000_oo
ool5o`0000_ooooo0_l000000ooooooo0000o`00000<o`0000[ooooo1Ol000001Ooooooo0000o`00
0?l0003ooooo00;o00000oooool>o`0001Gooooo1Ol000000ooooooo0000o`000005o`0000kooooo
00?o0000ooooool000003Ol0000:oooooa7o00003_ooool10000000000<00000ooooooooool0oooo
oolMooooo`40000000000`00003oooooooooo`06ooooo`;o000000?oooooo`000?l000002ol00004
oooooa3o00002Oooool>o`000003ooooool0003o000000So00006Oooool4o`000004ooooool0003o
0000o`0000gooooo0ol000000ooooooo0000o`00000<o`0000[ooooo0ol000000ooooooo0000oooo
o`02o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000ooooo`08o`0001Kooooo
1?l00002ooooo`So00003Oooool@o`0000[ooooo0_l000000ooooooo0000o`000009o`000003oooo
ool0003o000000kooooo0@000000000300000?oooooooooo0?oooooo7Oooool10000000000<00000
ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`06ooooo`Go000000Goooooo`00
0?l0003o0000ooooo`06o`0000Cooooo2?l000001?oooooo0000ooooooooool4o`0000[ooooo0_l0
00000ooooooo0000o`000008o`000003ooooool0003o000000Oo00006_ooool4o`000003ooooool0
003o000000?o00002oooool4o`000003ooooool0003o000000Co000000?oooooo`000?l000000ol0
000;ooooo`Ko000000?oooooo`000?l000000_l000000ooooooo0000ooooo`04o`000003ooooool0
003o000000Go00000_ooool00ol0003oooooooooo`0Cooooo`go00003_ooool>o`000003ooooool0
003ooooo00Wooooo2ol000000ooooooo0000ooooo`03o`0000kooooo0@000000000300000?oooooo
oooo0?oooooo7Oooool10000000000<00000ooooooooool0oooooolMooooo`40000000000`00003o
ooooooooo`05ooooo`Co000000?oooooo`000?l000002Ol00005ooooo`;o000000?oooooo`000?l0
00002ol00009ooooo`;o000000Goooooo`000?oooooo0000ooooo`0Bo`0001Wooooo0_l000000ooo
oooo0000ooooo`03ooooo`?o00002_ooool4o`000003ooooool0003o000000Ko000000Goooooo`00
0?l0003oooooo`00000;ooooo`;o000000Coooooo`000?oooooooooo0ol000001?oooooo0000o`00
0?ooool4o`000003ooooool0003o000000;o000000?oooooo`000?l000000_l0000Fooooo`Ko0000
00?oooooo`000?l000000ol0000?oooooa3o00002_ooool6o`0000?ooooo00?o0000ooooooooool0
1Ol0000>ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooo
oooo00Kooooo3ol00005ooooo`03o`000?oooooo000000Ko000000Goooooo`000?ooooooooooo`00
000;ooooo`05o`000?oooooo0000o`000?ooool01ol000001?oooooo0000o`000?ooool3o`000003
ooooool0003o000000?o00006Oooool2o`0000;ooooo00Go0000ooooool0003o0000ooooo`02o`00
00[ooooo0ol00002ooooo`Co00001?ooool5o`0000_ooooo1?l000001?oooooo0000o`000?ooool3
o`000005ooooool0003o0000o`000?ooool02ol0000Fooooo`Co000000?oooooo`000?l000001_l0
000=ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000_l000000ooooooo0000oooo
o`04o`0000cooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00?o0000
3oooool10000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`06
ooooo`Oo000000?oooooo`000?l000001Ol00005ooooo`;o000000Goooooo`000?l0003o0000oooo
o`03o`000003ooooool0003o000000?o00002Oooool01Ol0003oooooo`000?l0003ooooo00Co0000
00?oooooo`000?l000001_l000000ooooooo0000o`000004o`0001Wooooo00?o0000ooooooooool0
0ol000001?oooooo0000o`000?l0000;ooooo`?o000000?oooooo`000?ooool00_l000000ooooooo
0000o`000004ooooo`03o`000?oooooooooo00_ooooo0ol000000ooooooo0000o`000005o`0000;o
oooo2ol000000ooooooo0000ooooo`0Fooooo`Ko000000?oooooo`000?l000000ol0000?ooooo`03
o`000?oooooo000000?o000000?oooooo`000?l000001ol0000;ooooo`Co000000?oooooo`000?l0
00001_l000000ooooooo0000o`00000>ooooo`40000000000`00003oooooooooo`3ooooooagooooo
0@000000000300000?oooooooooo0?oooooo7Oooool10000000000<00000ooooooooool01_ooool6
o`000003ooooool0003o000000?o000000?oooooo`000?l000001Oooool:o`000003ooooool0003o
000000;o00002_oooolFo`000003ooooool0003o000001[ooooo0ol00002ooooo`;o000000?ooooo
o`000?ooool02oooool2o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`Co000000?o
ooooo`000?ooool02_ooool6o`000004ooooool0003o0000o`0000?ooooo1_l000000ooooooo0000
ooooo`02o`000003ooooool0003ooooo01Kooooo1?l000000ooooooo0000o`000006o`0000kooooo
00?o0000ooooool000003Ol0000;ooooo`;o000000?oooooo`000?l000000ol000001Ooooooo0000
o`000?l0003ooooo00;o00003oooool10000000000<00000ooooooooool0oooooolMooooo`400000
00000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo00Kooooo0_l00002
ooooo`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000ooooo`05ooooo`Wo00000_oo
ool3o`0000kooooo1_l000000ooooooo0000o`000004o`0000;ooooo1Ol0000Kooooo`Oo000000?o
ooooo`000?ooool02_ooool3o`000004ooooool0003oooooooooo`Ko000000?oooooo`000?l00000
0_l0000:ooooo`;o000000?oooooo`000?l000000_l000001Ooooooo0000oooooooooooo000000;o
oooo0ol000001?oooooo0000ooooooooool3o`000003ooooool0003o000001Sooooo3?l0000>oooo
o`So000000?oooooo`000?ooool01Ol0000;ooooo`;o000000?oooooo`000?l000001?l000001ooo
oooo0000oooooooooooo0000ooooool000003_ooool10000000000<00000ooooooooool0oooooolM
ooooo`40000000000`00003oooooooooo`06ooooo`Oo000000Coooooo`000?l0003ooooo0ol00006
ooooo`03o`000?oooooo000000?o000000Coooooo`000?l0003o00000oooool2o`0000_ooooo2Ol0
00001_oooooo0000o`000?l0003oooooo`0000;ooooo00?o0000ooooool000000_l0000Looooo`03
o`000?oooooo000000?ooooo0ol0000;ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`00
0004ooooool0003oooooooooo`;o00003?ooool4o`000006ooooool0003oooooo`000?oooooo0000
0oooool2o`000004ooooool0003o0000o`0000;ooooo0_l000000ooooooo0000o`00000Hooooo`Co
000000?oooooo`000?l000000_l0000Aooooo`Go000000?oooooo`000?ooool01?l000001?oooooo
0000o`000?l0000;ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`0000;ooooo1?l0000?
ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo0?oo
oooo7Oooool10000000000<00000ooooooooool01oooool9o`000003ooooool0003o000000;o0000
1Oooool3o`000004ooooool0003o0000o`0000?ooooo00Co0000oooooooooooo00002oooool01?l0
003oooooo`000?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?ooool01ol00002
ooooo`;o00006_ooool5o`000004ooooool0003oooooo`0000cooooo1?l000000ooooooo0000o`00
0004o`0000;ooooo1?l0000;ooooo`03o`000?oooooo000000;o000000Coooooo`000?oooooooooo
0_l00003ooooo`?o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`0Gooooo`Co0000
00?oooooo`000?l000000ol0000@ooooo`Go000000?oooooo`000?l000002?l0000<ooooo`05o`00
0?oooooo0000o`000?ooool00ol000001Ooooooo0000o`000?oooooo0000013ooooo0@0000000003
00000?oooooooooo0?oooooo7Oooool10000000000<00000ooooooooool0oooooolMooooo`400000
00000`00003oooooooooo`06ooooo`?o000000?oooooo`000?l000001Ol000000ooooooo0000o`00
0007ooooo`03o`000?oooooo000000?o000000Coooooo`000?l0003o00003_ooool01ol0003ooooo
ooooool0003oooooo`000?ooool01?l000000ooooooo0000o`000002ooooo`?o00000oooool2o`00
01[ooooo0ol00004ooooo`03o`000?oooooo000000kooooo00?o0000ooooool000000oooool9o`00
00[ooooo0_l000001_oooooo0000oooooooooooo0000ooooo`Co00000_ooool2o`000003ooooool0
003o000000Go00000_ooool00ol0003oooooooooo`0Fooooo`Wo00004Oooool4o`000003ooooool0
003o000000;o000000Goooooo`000?l0003o0000ooooo`02o`0000cooooo0ol000000ooooooo0000
o`000002o`000003ooooool0003ooooo00?o00003oooool10000000000<00000ooooooooool0oooo
oolMooooo`40000000000`00003oooooooooo`06ooooo`Ko000000?oooooo`000?l000001Ol00006
ooooo`Ko00000_ooool3o`000004ooooool0003oooooo`0000cooooo00?o0000ooooool000000ol0
00000ooooooo0000o`000009o`0001kooooo1?l00003ooooo`?o00002oooool2o`0000Cooooo00?o
0000ooooool000001Oooool00ol0003oooooo`00000>ooooo`;o00000_ooool3o`0000Cooooo0_l0
00000ooooooo0000ooooo`04o`0000;ooooo00?o0000ooooooooool05_ooool01?l0003ooooooooo
ool00003ooooo`?o00004_ooool3o`0000;ooooo0ol000000ooooooo0000o`000003o`0000cooooo
00?o0000ooooool000000_l000000ooooooo0000o`000003ooooo`?o00004?ooool10000000000<0
0000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`06ooooo`Oo000000?ooooo
o`000?ooool00_l000000ooooooo0000ooooo`05ooooo`;o000000?oooooo`000?l000000ol00004
ooooo`?o00002_ooool00ol0003oooooooooo`08o`000003ooooool0003o000000Co00001Oooool0
0ol0003oooooooooo`0Iooooo`?o00000_ooool01?l0003oooooo`000?l0000<ooooo`?o00000_oo
ool7o`000003ooooool0003ooooo00;o00002oooool2o`000003ooooool0003o000000?o000000?o
ooooo`000?l000000_ooool4o`000003ooooool0003ooooo00;o00006oooool5o`000003ooooool0
003ooooo00?o00004?ooool3o`000003ooooool0003o000000?o000000?oooooo`000?ooool00ol0
000<ooooo`;o00001Oooool4o`000003ooooool0003ooooo013ooooo0@000000000300000?oooooo
oooo0?oooooo7Oooool10000000000<00000ooooooooool0oooooolMooooo`40000000000`00003o
ooooooooo`07ooooo`?o00000_ooool8o`0000Oooooo00Co0000ooooool0003o00000_ooool2o`00
00;ooooo00?o0000ooooool000000_l00009ooooo`03o`000?oooooo000000?ooooo1?l00002oooo
o`?o00000_ooool3o`000003ooooool0003o000001_ooooo1_l000001?oooooo0000ooooool0000=
ooooo`04o`000?oooooo0000o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`0000gooooo
0ol000000ooooooo0000ooooo`03o`0000Cooooo1Ol00002ooooo`;o000000?oooooo`000?ooool0
6Oooool4o`0000;ooooo0ol0000Aooooo`So00000oooool01?l0003oooooo`000?l0000<ooooo`;o
00000_ooool01Ol0003oooooo`000?l0003ooooo00?o000000?oooooo`000?ooool03oooool10000
000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`3ooooooagooooo
0@000000000300000?oooooooooo00Oooooo1?l000000ooooooo0000o`000006o`0000Kooooo0_l0
00001?oooooo0000o`000?l00002ooooo`04o`000?ooooooooooo`0000gooooo0_l000001_oooooo
0000oooooooooooo0000ooooo`?o00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo
00?o0000ooooool000006_ooool01_l0003oooooo`000?oooooo0000ooooo`?o00002oooool9o`00
0005ooooool0003oooooo`000?ooool00ol0000=ooooo`?o000000?oooooo`000?ooool00ol00003
ooooo`;o000000?oooooo`000?ooool01?l000000ooooooo0000o`00000Kooooo`Co000000?ooooo
o`000?l000004_ooool7o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool03Oooool2
o`0000;ooooo1?l000000ooooooo0000o`00000Aooooo`40000000000`00003oooooooooo`3ooooo
oagooooo0@000000000300000?oooooooooo00Kooooo0ol00002ooooo`Co00000_ooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo00?ooooo0_l0000;ooooo`?o00000_ooool4o`0000;o
oooo00?o0000ooooooooool01Ol0000Nooooo`?o000000Coooooo`000?oooooooooo0_l0000=oooo
o`Co000000?oooooo`000?ooool01ol0000@ooooo`?o000000?oooooo`000?l000000_l00003oooo
o`05o`000?ooooooooooo`000?ooool00_l000000ooooooo0000o`000002o`0001Wooooo00?o0000
ooooooooool01_l0000Booooo`03o`000?oooooo000000Co000000?oooooo`000?l000004?ooool0
0ol0003oooooo`000002ooooo`04o`000?ooooooooooooooo`;o00004oooool10000000000<00000
ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`3ooooooagooooo0@0000000003
00000?oooooooooo00Kooooo0ol00003ooooo`Oo00002?ooool2o`000008ooooool0003o0000oooo
ool0003oooooo`000?ooool2o`0000gooooo0ol00002ooooo`03o`000?oooooo000000;o00000_oo
ool00ol0003oooooo`000004o`0000?ooooo00?o0000ooooooooool06Oooool3o`0000;ooooo00Co
0000ooooool0003o00003?ooool00ol0003oooooo`000009o`0000;ooooo0_l0000<ooooo`?o0000
0_ooool00ol0003oooooo`000002o`0000?ooooo00Co0000ooooool0003ooooo0_l00002ooooo`?o
00006_ooool00ol0003oooooo`000003o`000003ooooool0003ooooo01;ooooo0ol000001Ooooooo
0000o`000?l0003ooooo00Co000000?oooooo`000?ooool03Oooool01Ol0003oooooooooool0003o
oooo00Co00004oooool10000000000<00000ooooooooool01_ooool>o`0000Kooooo3ol0000:oooo
oaSo00006_ooool:o`0000cooooo4Ol0000;ooooo`_o00000_ooool<o`0001Wooooo2Ol0000Boooo
o`ko00003Oooool;o`000003ooooool0003ooooo00oooooo0@000000000300000?oooooooooo0?oo
oooo7Oooool100000000o`00000Q00000000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@00000002VWR]g000000000000000l002:QXJ:
SXj:QX:2QXZ:QX:2QXJ:RXJ2PXJ6QXJ6PXJ6QX:2PX:2PX9mOH:2QXJ6PX:6RXj>
RXZ6RXZ:RXZ:RXZ:RXZ6QXJ6QXZ:QXJ6QXJ:QXJ2PXJ:RXJ2PX:6RXJ2OGf2QXZ6
OGf2QXZ>RXJ6RXjCSXZ:RXZ>SXZ6QXZ:SXZ6QXJ:SXZ6PX:6RXj:QX:6QXZ>RX:2
PXZ:QX:2OH::RXZ6QX:6RXZ:SXZ:RXj>SXj>SXj>RXZ:SXZ:RXZ:RXZ:RXJ6RXZ:
RXJ6QXJ2PXJ6QXJ2PX:2QXJ2OGf2QXJ6QX:6RXZ:RXZ:RXZ:RXZ:RXZ6QXJ:SXj:
PX:6RXj:QX:2QXZ:RX9mOHJ:RXZ2OGf2QXJ6PWemQXZ6QX:2QXZ>RXJ2RXjCSXZ6
QXZ>SXZ6QXZ>SXj:QXJ:RXZ6QXJ:QXJ6RXZ6QX:6QXZ6QX:6QXZ6PXJ6RXZ:QXJ6
RXj>RXJ:SXjCSXZ:RXjCThZ6QXZ>Thj6QXJ:SXj>RXJ2QXJ:RX9mOH:6RXImOH:6
RXJ2OH:6QXJ2PWf2QXZ:QXJ2RXj>RXJ6QXj>SXZ6QXJ>SXZ2PX::SXZ2OGf6RXZ6
OGV2RXZ6OGf2RXZ6PWemQXZ:PWemPXJ:QXJ2PXZ>SXj:QXJ>SY>>SXZ6QXj>SXZ6
QXZ>SXZ6PX::SXj6PX:6RXZ6QX:6RXZ6PX:2QXJ6PX:2PXJ:QXJ6QXZ>SXj>RXZ:
SXj>RXZ:SXj>RXJ6QXj>RX:2QXZ>RX9mPXZ>RXImOH::RXImNGV2QXJ2OGUmQXZ:
QXJ6PXJ>SXj:QXZ:SXj:QXJ6RXj:QXJ6QXZ:RXJ6QXZ:RXZ6PXJ:RXZ6PX:2QXJ6
PWemPXJ:RXJ2PXJ:SY>>RXZ>SY>CSXZ:RXjCSXZ6QXZ>SXj6QXJ>Thj:PXJ6SY>:
QX:2QXZ6QX9mPX:2QX:2PX:6QXZ:RXZ:QXZ>Thj>RXJ:SXj>RXJ6RXj>RX:2QXZ>
SXJ2QXJ>RXJ6PX:6QXJ2PX:2PX:2OGf2PX:2PXJ6QXJ6QXZ:SXj:RXZ:RXj:RXJ6
RXZ:RXJ6PXJ:SXZ6PX:6RXZ6PX:2PXJ6QX:2PX:2PX:2OGf2PX:2QXJ6QXJ6RXZ:
RXZ:RXZ:RXj:QXZ6RXj:RXJ6RXZ:RXZ6QXJ:RXZ6QX:2QXJ6QX:2PX:6PX:6PXJ6
QXJ6RXZ:RXJ:RXj>SXZ>SXj>SXZ:RXZ:SY>>RXZ6QXZ>SXj6QXJ:RXJ6PXJ:RXJ2
OH:6RXJ2OGf6RXZ6PX:6RXj>RX:6RXZCSXZ6PXZ:RXZ6QXJ:SXZ6PX::RXj:OGf2
RXZ6PWf2QXJ2OH:2QXImOGf6RWf6OH:>SXj6OH:>Ui^CSXJ2QXJ:RXZ>Uhj6QXJ2
OGf6UjBPQWE/NI>KUi>6NGEiMFb>Z;FXUfQ6H7VTa[6CMF1XNINXZ:2GTh:6NGf>
TjBTVhI/LGf6[;FGQVA6I9NX^H://FbTBT9PY;W2`WUGI6aKSVRT`XjG@XjGNKea
MHj>]J2GMEMXX<[C[2@T3U?Xj==e=JAT/HXaEgWGc[5P95^ic/8e03EKooVT862C
NOe:@UN>k=^CCS5/k<kG:00XEoo/ddX0_Fc6`R0mR/;T`TXeB/K2/B@:BXkok60e
_DK:_@i/LL[mY4I:BUOCmJ`a03emoonP6eMmR_m6H4J6ol:P93Vafi]T01NKmOn/
1[EaQ_d2J4:iokfC3WFCX8Y26e_Tj?mP1/YXc_TPK6c2h8::QZAaJ2@eFm?/^E]i
k7W6=@8Gc_nTe`0eK5^aBVaab[eTJ6SaK:RP04j2ohk>]@96DgFPfmNmSRP:B_oe
mJP089?>LL:GJ7DX6a^Toomea/h0RPYPQ_ooQV@0077KonRCEcdeTk5>Um?ToJ`m
001>k?VeUb0iooni8000^OooQP00Dl;oocETnM>i900008Kooom6000//OgolJ1:
034mThJKZ8k2Uj0T/Ommm@i:J<[e>GD0@Zbah77oP]]C03T0okW>T`22H9?oh;G6
:3T0FgV6oi>iQPYGS_oak48:6e>mR/9XOF0mB_oomKd0003XmNca03E2@VBaon32
RP9C5jAPVliioeMT3T[oc_mX<@X2Z63XUfAK0<koool00012fkWoTfAm0>Ri[=</
X1>aVcFe>I>iOJSX_K66@R0CQXJmogFG;3WoY?me?DXPmDJXLBR/A_oob^`04`1T
di_oogUeFd;o]K565fQeoj1/800eTooood8000kXi>bmBXj2ODi>S]?ooiL6001T
j?oTK1Nek>3C3Ph0X<je`PXCQ_oom@X00VCoekd/0:R:oom:@P2GVnc::5LmX<:m
K6BPY=>KCSE6RY>XOGeCK3Deooooo`0004:K]OnGZ7TKdgF/RX:P>GUKH:B/Y8Zi
_K6mCSTXFkG:aV@T0=_oool>2P1X^JSoAVQ2Voo6j000?FcodjPG06BToonXAP1C
OKFKDfae[6R6oi?PX3e:0:QKX<Xm>FQXonCo>@063_o>ogT0MBSook6G06QCa/Y2
FcVK[;GKTgf>I:A:Ff1:[8im;?oPeoT0=@2>c[go<E<iMOnTfa/CK6coZ7D/;4;:
oncK;00CA/ZX]GTa?Ooofk4000:aom_/6bQ:K?nXaU</;9=/h8ICBT9GY?oah6`0
90jTUjRmK4YeolKmCP0i0?oKi<X>H1OooL;2060X_N1/PPiCFooo`Z`0<ANenGfX
:1]PooomPP0K0<ko[;4>H9Ooohi204J>oon2;00X]Ooo`RP0>GW/^GDi;2a/J?oo
]K40BRAT^FRaODiiooGKY00K1ZCi_KDK3YOoooDP000mooooM@8T9:cPnJaaPVbe
MCdC97fmnGV:dh;o]D8605>Ch?n>[=NTaQ<24d[ooon601]>j?ViPS5/VkVT@R`T
Dh;ooo7a`P0204jib_nK4h[oa_lG000GooooU`80H?oedcT0DhKoogD>06Ceoon2
001CUoo6APX/oooo]@00063TonQPZ7Gmi20C04JPoon/QT8GOE>2PWW:em>T;3e>
J=NXaZ1XX5=iDcEPC_oooncmAST05h:6c[5KX?oGmDh000k6ooFa5bbPeon2=@0a
[?WoQS40LNSiofPT84jiaXYT;1>KooGoL@0G09_2`]</NOgKohH0001moooGI35a
b_6GBP0/TncoY356>KGoVi/G>H:/j88KBTZGb_o>H0X0<JS:h8Xm_M_oi2`001O/
oo6i<Fb>aZAC6baefonm?DY6P_nKUcTPOIOCY34PX;Goof`m002GX=^XFkVeom]:
1P0P_Ooa[2a/P^3CFb`:A/[mfeM2H6co/Hi60V2CbZ`i[:amdomiH000H;gXj7ei
VkGPQRPT:8koi==C88YmmJaCAR22flj/:026VoooRTh00WfC_G5Cfj3omE/G01>:
b_niQZR/mJ0m2PYCj?ooX4Y>DjbCOGUCVk6/NCV:J=?GK7dXCXj2VgDKY<K6i?ma
AQL0PXjTaU^X`]OeJ2`C::3TekE:X9?2odiG4cFma]Ma0:AioomTD`06Ti_CMDja
VooGCQL0;9?>oH:GUjSoI3T:09?Com=i[4K>Y5=X4g72a_5:SXJ2ofaX:0::TlZe
Fkemk<Y:BSd0<J2ioi]CZ63G]CeC0UNma^aCFkE/oi]P?@26[=?a;9=i^OnGN@00
H8[ah6RTLM_XK3d04fc2okEiRU?6VeM60UNC_N1aaWFah5Ma0Rb>R^RiElZ6oOUm
CP0GNJSe]EN/Q^SoI5L04a=mZ?n>EjAComMaBP0aI;7oJ8J2EonmVcD0@U?>ohjC
MGgoejQT03EK/NR>QY=ion2/I00/BYO2DhJPTooKY3405cfah7UPJ8;ookU/0016
Vo6/I8iGmOo>/ALT@W76PVbPC_goh<8K6aLGDkEiMI]Ci?oTeb`:2RbGPVaiK;7o
j<i/;492PX8mEgVGoooeUc4a96b:BTj:K?ooomLX1P0eX8Z>H4jKoOoobTH:5cUP
NDhiPY_ooonm:0X05fAGDiNKb_oooj0K0P0eCW6e/KGomOoXj6`m01LaH:Qmb^2i
lLZGK4I6@V1X<HZXZ?oT[7DT92aeOG5KJ9NioooXRR`6:62>[8YPQXKPooo6J2@>
?FR6OHJGOL[aj=>>?B`m?E]XSY^C`/[2aX9>ASU6FfATUi>ih<k6Y7eXI6aX@T96
PXk6nM_6Z61GH6QXDcUTP[7elNc2LDXa?FAKI5]aX;g/h;6:ASUCI8iiI7EeX<kC
cZQXDdiCLGU/ViNTelK6[6aKAU=eMHiiJ9>P_M>iZ7eTEe=/LGUiNI>P]Kf/TfaG
De=/K6AmTjRX`/ZmX8ieK75eNH9mMG6:X;G2_JRCLFAXMGf6LG62Tkg>`ZQeFe=T
LFaXDgfKZ<Ji^K6>PV1CCUMmQXJ6OINX`/jeVfaTK76:RWUeOIN/^KFTTgeaK6AT
LGEmTi>CX;6eX8Y/FeMKMGUiMFaXOHZK]KFeUge/FfR2SYN2LG62Vjc2_I]mH5]/
QY>6OH:6SXjK/JRCOFAPLI>KSWUKFfamTiNKUhj:NFa/NHZCRWeXJ8:CY:RKQWUm
QYNGSXZ:QY>KQWV>Ui>>RXJ6Ui^KTgUiPWemOGeiNHZGSXJ2NHZGSXZ6NGEmOH:6
RXjGThZ6PX::TiNGSX::Uhj>Vhj:SXj:RXJ:UiN:OGUmPXJ>RWeiQY>PVhj:QXJ6
QWe/J6AiSXImRXIePXjCVjBPViN6PX9mNHJ:PWf2NGEmQX:2RXZ:UjBPX:2>QXZ6
NGUeLGEaOGUTJ7emNHJ:SZ2XZ:RGPXZ>PXJCQWUmNGf>OFaiOGF2ThjCZ:BP[9=m
SXIePWeaNH9iPXITI8:2NHZ>PYNXVjRXPXZKPWf:OG5mMG6>PVb6SW5iThjC[:2P
UjBCQY^CNHJ:MGf2J6b6MFb6QW62UhZGZ9>CY9>:X9=iRXimQXIXLHieLHj6LHJG
SZ2aUiNXThJKSWF6QWUmNFAaSWUXQX9aPYN:TjBGUjRGQY>>OHZ>OH9mK76:RW62
RWf2Ui>CZ:BGUjBPQXZGPWf6NGUmMFamQW5aRX9iPXZ6VjRGUj2:PYN:NGemMGUi
K766PW66SWf2ThjCZ:2GX9N6RYN2OH9iNGEaJ766NG66QWF2ThjKY9NCVi>6ThYe
OHIiOGUaJ8:>NGf:PWfCX9NXZ:RGY:RCSY^:NH:2NGUiK6b:QW62RWemThj>Z:BG
X9^6SYN2NH9iMGUeJ6b6OG66SX:2TiNK[:RKY9^6Ti^2OHImNGUeJ76:NG66QWF2
ThjG[:2GY9^6Ui=iOHImMGUaI7F:OGF6QWf6Ui^KX;6TX:RPTi^GPWf6OGeiLF1a
QWeaQX9eOI>CVjbKTi^GRY>COGV2OGUiLF1XOH9ePXImOI>PX:RXVjBTSY>GQWf6
QWeeLFQTOH9eOHIiMHZGUjBTTi^PSXZGPWV6PW5eMF1TPWeePX::RXJ6X:BX]JBa
Z8jGQWEiJ7EeI7ETH9^TZ<:KRXIXPXjGX8::QWFKRVaXATYXLHImK:2i/M>mRXIX
K8jKY8jCUgfTVgEeI5]aOGEXEjSK_NRmEfa>J:RXX6QeSWFmY4Y>?DJ6VhiT>H[P
h<kedd9>BV2ea[e/I9Meb/YXI49GPY^KFcUXk?oTmD8:CU>mdk5X;9NC]N16:2a2
VjRXE`hmc_ooef`0;8[>oJaK5fceenR202aP`]>CF`0CZ?oo]H800:CTj:Q26cWa
ojB:1P1P/MNG@T8G1WgoomM:6`1Ponb>Ed9PeonmFd8eLLKPQSTi?Gg2oome@V@>
OMNGK76>Q/kTFd9K?G6KVfQCI5MiVoooODiP1VcP^Hj:SXK6j6Q6OG6:_JaKAVa/
PZ3PokTmK1<adl:KRXiaP]Mm<GUiEe^KTg5KLFQ/P[7ooC5CCQ>eoi]iX9>2ejPT
K:b2Z;UP=G62NJRKeonC5e/C@^3KVgF6I7W2LCVCNE^>UfA:I75iTj3ooaLKI0ZK
oke/SYMX/KD/J=>:NJAT:76PPZ2aQ_oo1PI/:9_oolY>FhYPUkE6J;eeFh9aAVRP
PXZ6S_oa02Qi9=OoVcV>UfC>[22:k7eaUeLiTk5mThIGool02WdCZ?o6:62P@[7T
<D[XNDj>RSV2/GEe`V26olh0B[4m`_n26k6/ElJi98koOE=mCTJ//K62RXI2k?m6
08IKFooe83VmH77/J2CXfdIGLCETbZaaZ88ioolX0;UmI?oT4e?CJ7WoTcW2Z2QG
RVRCcY=PQV@/lOmK09M/9?7e6eOTK5OTL@ZmoFAGJ3UG`ZQmVi<ab_m/09NX<O7o
92`/h896lJ`KY>a>BWe6H<JXI8:2=F3oo`02^CUToj@6UlHiR]]6Eona=E=PCZcG
UfQmNCgmocd0_HHeoN@>MNaPEn1e=M?/DdYX@VC:Y6b2QSEeon00B/XKTomK9=N/
?KG6CX[XPTj6PVB>SZb:RZaX9>coI02XRQ_/obAKmFa2`YMG[<ieFf16Fj2KSWUa
=H[o_@1eRPkeoeMGi7E6cXXma_nGFdiCDi^eZ9N>EbRXohh0Y7d>oODPI=]XDmMm
@[G:J75XDfR6RWfCTd9:ool0I:`0dm?oPSgXQQ^P[6C>k6PeBXj2SYNGSY]mDbB>
on0>J60>_Na/NM^2>H::Dl;GH3eXH7Ve^I^:ODXmoolX8<8TJ?nK@/;6@X[6=G7P
LDj:PVb:PWFKVgU6C_oo02Re4gWoODKGY2b>TcfPoonPBUMPI:2XX9^CFbS/ob`0
bU=6ol8PX=<aK;UTR^BmLDY6EgFT]JRCJ2`Ki?m60;T/Eon/>J3GEh:aDiOPThia
LHJ6NI>TUhiaCU=Xool08;DKUon2@]^X5hJGDk7KTfQCH6aiVk6KRW5aDdi/ool6
8<I2R_n:@]>m?HJKJ:C:UgUTJ75mRY^PSVAGAX;ocP1//ANmk4YGlHH/VgeT_Hj6
X7E/MEMi]JbGTe]CI?Wo?@3GLCWa/CG2fba>/GFP^GF6PTiaOG6:VhJ6I4hifolm
0=MCDa_m/Cg2fbQC/F2TbWVPVfR6OENG_I>TRU]>VonX0:Be4l[C?HKeFc6aMGgK
MFbGEfRCK8:aRWF6H7U/I?oT07g>2ZCXH8;oTcVTPVc6SYNaFeN>PY>/NHJGI5]K
ool0DlXGR]]/FmN/>CV>OE>aPWfXPV1TFhJmPXJ/Fe]>i?lP>NPTK>B>J>C:?HJP
H:BCPZ2>H6aTH<JXMHiPEd[ao`0/mBA6dg5Kj;d/QZ1GVi=aRX9XSY=iZ8ImY75i
I8ko^@2i[02e_ENioFQ6[6AXZ6R>/GUiJ6`iQ[eeSXY:?Ooo02So6dkCK7WK/D:6
VgFCOI^XQX:2CVBeUj2TFdKoo`0/ob1TaVQmekE2NHYaX7emUge/LDia/GFKUe=G
I?o>0<:i5j2>K9_TSVbXRX:KNGVTUgV6CXjTX:1TBW7ook40j;42Ui=PX>1PLKf2
MFaiPX9iTgU2Ui=iPVQ:ool0J?lGH:1XVnRCOKf:UgUPTi=mOJQKLK66OGe:Vom>
0?mi89MXK<JPH:b/QXYPI8YeCZQeJ:R6QXI>S_mP0?n66keeJ<ZXLK6mRXZ2PWV6
QUNPQVBCLGf2?NCo063o:3f>H7FaSWFm]GF:LE^CJ5>XH7fPQXj:EhkoI03oX1>K
RW6/Y6bXaXimSX9mK5NGLF2KNFb:Dooo09Oo5dJ2H7FTMH;C/GV6SV22FfRKJ8JG
OIN>Q_ooX03o[0j:SVR>UgFacZ2>QWUaODj2MEN6PW6CJ?Gm0;Go2TJ2H76:K9^i
Y:BGVgEeDgF>I7fGMH::lOl>S_la?I=/LGEXVkfaZ:b/I75aFfQ>J8IKJ8JKof@K
ohH0NGUKI4j>^K6eY=OGUf22OGUCH8iiEgW6of@iojP:QX9PEcV>]J2XY>RKDhim
Fd9CNF`aFi_oPR3ocPIiTfQ>:7faPYO2oJAX]IM/FfR:H3EXY?mP?OoC::2aK48K
QZ1>Q[7>QWVmSU]CLH9::5OX[0[/of1eML:KNCEKVf1GVlJTK;6eRWF6Tf`/_LHG
^Oe/Q/JGUgEGSVACPY=mI7fCUg5ePW5:dj0CfkdiY<J6SVAeX6AeUiN>NI>TVfR6
Uh9>OOm>@_nXH;FeVgeCY8Y:K8Z:LGFKTfAPRXYTEn1e92Ca]DZX[7fCJ8ZPEfbK
Tgf2Uj22MI>>K5_>_BC2k6B>bZ2CJ8:XEfBCPW5aRYMeLHImK5>KcQNCnDieeiN2
NHJ/Ee^PQV1mX9=eSY>2OG6CfcEiofaGfkEmPYNiEe^POEMiRX9TPXYaMGUiMMM:
C_m/@]>aJ8:P[5=/]GeCQYMeI9^CJ8JCLMMaC_n2@]_>H8JeZ5=/^GU>SY=TJ9Mi
Dgf6EkVC9?6X=Kg>H8:XVfA/[7UCRYMXMJ26FiNCFiOG::3iCX[XVfbX_H9KZ9M>
MJQXH9>>SU>2Tf1KaWTTk9Le_L9/OKFPFgVaLE^CTdii[7EP[8ITP/ii@_6CB/K6
MGW2X5^C`V1T[8Y6SZQCI:aaEhZCTdZGaT:6_HYCZ;5PK<:2CZbKCX:aI6bXSVBG
UgVTRWFiMHJXTgFKX7V6Y:B:LJR:NH:>MGf6RWF:PWUiZ6QT_FAXZ8iGQZAeMJbC
J:2XMHJeNG6XVg6KZ75mVi]XRZaKNJb2I:BKJ8JaQVRXVfR:]F1a]H9XVhITPY=/
PWe/QW6:RX9mSXZ:Ui^:RYN>UiNCQXjCUh:2SY=iQXYiOHYaOI=iNHj2MI>CNH:G
QX:CSWemTh9mSXImQXZ6PXj2OHj:OHjCOHjGQXJKSXJGTh:>UhZ6ThYmSY^6RXj2
QXj:OH:2OH::OGEmPX::RWUeQXZ:RXYmPYNGSY>:RXjGUhj:RXJ2SY>2PWemQXZ:
OGf6RXj>QX:6SXj:QX:6SXj6PX:2QXYmMGUmPX:6OGV2RXZ:RXJ6SY>>SXj:SY>C
RXZ:RXj>QXJ6QXJ:QWf2QXJ2OGf2PXJ2NGf6QXJ2OGf2RXZ:QXJ:SY>>RXZ>SXjC
SXZ6QXZ:RXZ2PXJ>SX:6QXJ>ThZ2QXZ>SXZ6PXZ>SXJ2NH:6PWeiNGf2QXJ2PXJ:
SXj>RXjCTi>CTi>>Ti>CRXJ>SXZ:QX:2RXj6OGemPXZ:PWemQXZ:QWemQXZ:RX9m
PXjCSXZ6QXJ:Ti>>RXZ6RY>>RXZ6QXZ>RXJ6QXJ>SXZ6QXJ>SXZ6PXJ:RXJ2OGf2
QX9iNGUmPXImNGemQXZ:QXJ6SY>GThZ>SXjCThj:QXZ:SXZ6PX:2QXJ6OGemQXJ2
PWemPXJ6PWemPXZ:QX:2PXZ:SXj:QXJ6RY>CRXZ6RXj>SXZ6PXJ>SXZ6PX::Ti>:
QXJ:Ti>>PX:6SXZ6OGf2QXJ2OGUmPXJ6PX:2QXZ:RXZ>SY>CSXjGUi>CSXjCTi>>
QXJ6RXZ:PX:2QXZ6PWemPXJ6PWemPXJ:QX:2PX:6RXZ6PXJ6SXj>RXJ6SXj>SXZ6
RXZ:RXJ6QXJ6QXJ:QXZ6RXJ:RXZ6QXJ6QXJ6QX:2PX:2PX9mOGf2PX:2PX:6QXZ:
RXZ:SXj>SXj>SXj>SXj>RXZ:RXZ:RXJ:RXJ6QX:2PX:2PX:2PX:2PX:2PX:2QXJ2
PXJ6RXZ:RXZ>SY>>SXZ>SXj>RXZ:RXZ:QXJ6QXZ6QXJ6QXZ:QX:2QXJ6QX:2PXJ6
PX:2PX:6PX:2QXJ6QXJ:RXj:RXZ>SXj:RXZ>RXZ:QXJ:RXZ:QXJ6QXZ:QXJ6QXJ6
RXJ2PX:2QXJ2PX:2QXJ2PX:6QXJ:QXJ:SXj>SXZ>SXj>SXZ:RXZ:RXZ:RXJ6RXJ:
QXJ6QXJ6QXJ2QX:6QX:2PX:2QX9mOGf2QXJ6QXJ6RXZ:RXZ>SXj:RXj>SXZ:RXZ:
RXZ:QXJ6RXZ6QXJ6QX:6RXZ6PX:6QXZ6PWf2RXZ6PX:2RXZ>RXJ6RXjCSXj:RXjC
SXj>RXj>SXZ6QXZ>SXZ6QXZ>SXZ2QXJ>SXImPXZ>RX9iOHJ>RX9iPXJ>SXZ2PXZC
Thj6QXZCThj:QXJ>Thj6PXJ:SXj>QWf2RXj:PWUmRXj:NGEmRXj6NGEiQXj6NGEi
QXj:PWf2QXj>QXJ6RXj>RXJ6RXZ:QX:2QXj:QX:2RXj:PWf2QXZ:OGUmQXj6NGEm
RXZ6NGEiQXj:OGUmRY>CRX:6RY>CRXJ2RY>CRXZ2PXJ>ThZ2PXZCThZ2PXZCSX9m
OHZ>RX9iPXZ:QWeiPXZ:QX9mQXj>SXJ6RXjCThj:SXjCSXZ6RXj>RXJ6RY>CSXJ2
RY>GSWeiQY>CRWUePXjCQWEeOHjCQWUeOHjCThJ2QXjGUhj:QXj>TiNCQX:6Ti>K
OGfGNH:aPV2/OFbXRVRCPWVPMHZ6I9N2MI=eNHiaOJ1eNI=mRXjCSX::QY>KQX:C
RXJGQXJ>SWfGVgF6SX:GRWfCQWFCQWf>OHJ:OHJ:PWF6SXJ6OGf6PXJ:QX9mRXJ>
SY=aTja/SZAiQXZCRXZ/MGVGOHj2X89XVgV6RW6:NH:GOHJ:NGf:MJ2>J9>6OGVC
SW6CRWfCRX::OGfCPXJ:NH:6QXimRXimRY^CSY>GTiNKOHImLHj2K7EaLI=TNI]X
RWVG[7F6^I>CY:BGZ6b2Uf2:J76K?J2X:;6GPYMih9Madk6>Y;FmMGFXH5MiFeLm
H<He>LjGMEOei62/h<Z:Vlj>FfB6EceGCThX[:@0[?6TA_7oRX[/ohZ2Y;e64gV2
0RaK@P32`P2iok4/oon2MOgiDdI6Z8H05f1X02Q>98[o3WWoobc2okTX^Om:08Ze
001CVa<GBVSif`3CokT:oom60?Gi002iRP0KLI<T>Cgmo`I>ool0P_na06SoQP1a
_FPeDjQmFcVGohX0oom>9?oi<@jKdf@ePZAm=G6KVgTi9?oo06CoaPZ2oi<PDhja
NEMm^HHmK;66;3goo`2Poj`TR_6C<E]aZ:QTK<ZG:5^ePSTafol>Foo:;632[3U:
BY?CNE>m]CdiTj123X;oQP;oofaCX;5GBTJ2nKUTOK5/>E^GCTHmh>3o83godcU6
QWU2J6B/j8im[6P/>F1iBT92ool0R_n:4cVCK6BGNO7mY5]>EdI>QZ1K:6coo`3>
oa/CI9MTZ:bGokU:>CEKH7FCNE=:mOle0?nK5cFPZ8Ki^KG6@U<eCY>PY9^2K8;o
o@00MNa2AWg>UkWTMHI>@WE>PZb/Vg5KFoWo03W>I7V2Y:2:fh9KSV1XI7fX[:Ae
Dg7Cof`6/HY/SX:GTkfXK7UTNFa:S[FKNFQaToo:05^iH7F6QXj/dhY2FfaeK8Z/
Y9=iEhkoaP9/]F1PQYNGR[7KMBA/X75PY:B:Ug4iNOo/=DZiH62CQWVKfj0aLIMC
?HJXY:b>BWgoh1]6Z6b>^I^2X<9X99^aI6RCQXJPSSUmom/GA[5aMJbCTkUe;8JX
EfBKQWfKX6ACP/:e]JPmAXj6VnSCdf`eEfAaY;6CSVATI6CGog40NKeeQXI/Q/:>
Fe]XA]Oo[00XDdjTdi=CLE_Xob@0P^2/djQaNI<m?H[6^JRKJ7FTY616VljXNE=P
VkFGMFa/FfSXoh9>K34XY<ZPVhX/;>3oFaNXcX:TPSEG[:R:VhYiPZBTh;UaDdiK
VmNiSWE/FfQmc_nm<@HiP/[CY75iLDHmR_oTI5=65hK:]HJCUeMGFh[Xom=203FG
dnc2LEMPCW6ij=^TEb0aQ/[:[8YaFf1/MGWCojPG4dIa]M>PME]aASFGonaiJ1LC
S_W>cY]/I5]TOJSXlILP05NaenRaDcECJ8JamOF:1P1>_NS2PTYCK6QKP_oiMB00
=IOofjA>5eMa_Og/RTiC977:ei^6SU=KNGV>eon/1P1:[=OibV0m@TYmeooXM@00
I=_a^Fa>?GV:I:3oj>PiAT96P_o>MI=6@WfKdooi:00P[?Wa_G4/:6R/_KVidh8G
4gW:c/J6Dd9GMHjK`_nG001ei=OKK2AGPZBGTgfGom<:077:a^2>ATYPOGfTk?na
0P1ClOo2PU<P?INi]L;GPPhCLM?T`WEe6cEi]Kf>H9?XQSUGRZ2/^FQPPXJKNFA/
oolG03G6c/;C835XOKF>]M_XJ00>`_oTUc42DjS2X9?2Y3TCEkgPaXHi?H:i_HiK
Fn3oNA<COL;GcU]6I62:QZ3Coj`006Smk:a/@TYTTj2TY=?/E`0>X?oiX340Fk7:
^H:C^J0m:8KKcZAT?FBK]JQmJ5]PnOm>04;:ViOPK4Y:LI=iY<[oV`00MOGTNDYT
J6BTVggafcd0?M?efk4e2VC6cY^K/J1T=DJGfkeiI5]XVjAmFiOo^CTP6a^TnKei
DdYPOHIeh?nG:00alOg2LCE:MJBKTk7TaR06J<[odgDe<GFKX>3oJ00CC_We/I<C
=J2GZ:bCQXZ:I6b:Z8i/OFamOHJeJ4[/of`6=JBmk<8m<E>KflZKZ9<i@Wg6bZbG
BS5iY:BTQY_oY00XML[PSVPeDjRTZ8hm9=OoH0HaH>RiVhXTEjBCRWgoob`02X[o
oHiC@U=e/L:TTj22CUN:^JbKPTYCUi^GPXK6RU=aLFbG[8i/MG5iSW5eMKgoE`1X
FlkXVg4XI:RPY8iiUoGeT`he[>2iNDhXK<k2NI?2EbaTS[ViZ7DGAZ2XVgF:mI<0
:7gTj89a>CVe^INCCVcmj6a6?GW:]JAX<G6PVk6:P^bT2RRKdlJ>H6A/RZ26NHJ/
^I]:97VX/Kf2BTjG^Hi/P]_>BTj>R[Ve]F1/Z9MmLEMTVooo5`8/VooKRS4iSZ2m
/FPXUonK2TZGVjR/LDimOFBTok4CEfa/fm]iDfR2UjbTK8;o_@12/Jc:Ud9iSVAm
Vf`moolX03UPdmNGJ49mQVb2NG7Xob@0LMO:fi/a>HZCNGVmokD02WG6om]T6fRX
SZBaI6c2eeM2[7V:Vf2>UfaXH7V:^On>001mlOnX:1>:/K6KH5^>fn1a=F2G^KVP
J5]mNGWoo`XPVgV>h:a:@Vb6_K5G>E_oob`e>EO/df0iDgF2VjQGUomi02`/a^R/
OGe/NI]mONCPH2QKUlkTY4H/I:BmY9OP]@8CTkW2/GUCEg62ThIefmLG?HJ:`Xhm
K8j:MG6PVoWo6`1Kh?niI216[=?2I;W::4ZGVl[2PT9:Vi^6OI_TRRQaMGg6RTIX
RYNTNDY/K8K>oDXXQVRefg5KNGV6RXj2i?mG037Com=/=D9a/Nb:_N@G3WfeenR>
1QNK_KfKAXKaI1^:VkFi<BRX[8ZXRU=CQ_ooDce6FlkGRWeaBUN6Y<;ocP00NOoo
SR@CBXk:a_n/001Tb_ooEeL00:c/fi]6BVR>aY]iOEM6VmN/LDYGRZcGdfA:LDJG
k:1PJ6amMGF6lOmT1P1/oomi:3E2MMOPok4005_eonQG01>2dmN/dhH0<JCGk;EG
:5^GZ9NKolX01Y?6omLi6gV>TjAmQ]N/@UMGLI?CRSE/ThYmJ8;>ohH04h[eh7E2
BU>>c/koJ00aR]Ook4h0?J3:cXYT[9M6K:Ra]F@KOLJKRWUCCZCo/DIC=GWKZ7EX
H7U/CZ3ocPhT2Xkoj6P/<E>/k?oo=@0KX?oo`S40=Jc/ekVa/CD0LLK/h6P><HJi
[7VGh6`PK6RKfhiTLFaaQWeXnOlX>FaPh=M>AX::K8jTool/03gPokda6diidm_o
Z000K=?ooGT01Vbej;6:ddX0I=?ifcT0H<JaY88mQ_neDceG^Lj2FhJPFf1TI>co
>BaX=L;oRSUCMF2Kc_oP001Kdoo:DaLmOK7>okT006Rmoon60P1K^LKToh804hkX
okTa85>C_Jb:nJ@XCRReoiLa?FB2OJCoea/06k7oi4h>85>ek?oP000m`_oiI0hi
LK7CVm?C820PMKGmde/eEg66Tooo<@12K>CoX5</AXZXQ]?oCQM6C_WiFcE>LHZ6
]OnT90XTh?nm>@heLLKood8097gaonAC00iak>bX]FP2EjC:mH86AXj:UfC2odH2
<DkanHI6@VAmTfceoa]:>Di>on1PBTiiQY?/og4T3UOoohXa84::c_oo0012X?oo
^B00@YOP_M?>1P1e]Oo:?CETNI>>R_o63STPY?niEf2:I766j?lm=Dh/ooeaBTYT
MJcmoF0G6f3mohX/;4:Cdooo0012Q_oo]@H0062Gfkg6h1L0OKgofb`XJ8K2X5?o
o`hG99_o^DYKLEMPdom/6i<PMOn/TeLP>HKKolH004KTok5P=C5:R_oo;00XC_7o
lFP086S6b^So>@16TooiI3eCEhj:Uona@ST0VoneJ4Y6I6CXoolX=E/KdnRPQT8/
Ejciof`0<G7Ph:A/@VB:UhkonB06CXkelIM:;49PlOmTBX8/Dkg6/Gdi?E^Toi/X
M@j6j8jGQTiCEooo:5=>FnRiRZa/BWV2eomi>CUX_JRT^GeC?D;moe<eH62G[:b/
Z60m?EOooeM:BS6T]J2/MCeKDlKoLE=T6kG>RZ1mDe^:okT6OFR6dgf2QTIPSZCo
Y00mMJc2Ti]aDdiTTn3mBQMaOJR/QXY/H5MXooliATYT`[fTTg5KAU_ooaM6<HKK
SZBXASETeomXJ01PMKfKPZaX:5NKfomK05Mm[=>eQU/iBVcoobPTPVRaVj32I4IP
Dooo94HmLLj6Y;U>AT[>odi2NDZ/UfbiMD9/P]_PDdi>I:2//IMXAT9iom/iLGei
PWg6aW5>@WWobT:>H6R6K:R/LG5i>GGoMBRP@Y>XAYN:BWf2lM/CEgUe/Gf:X5]P
LJ3oZ3U/Fh[2^KVKH4i>Q_o>BXYiI6Qma[5TLE=Xoj@TY5N6RTjXVfB2C]Oo2VR>
B/Z6K;5KDhJGoo4/DhJCSWfi]Fb:NHkoFdZ/MGFCTh:mX4YGK:CoOE>/J61POJb6
K7dma_l2H;5:VgEX[5MTMI?oMA>PEhZKQ]>6BVaP]OmK::amH6bicX92EfSTo`9P
fgEXFi^/BUMaDooT08Z6EiMT/KDaK5]GoiL0bW5aNG7KRTJPUkfmlC5XZ5^6PY^m
PV1TP_n>;:BCLG5i_I]CH5>Goe<ifgETCVc2NE>KAZSo:5>iFgeGR]MeK8:modXi
aWEXRXk6NDj2UoF:>K6>BWV//IMXLFa/i9/e[:Q/I6bKQUN2OG7oZ3G:PTYeK8j:
RWVTFnco3Y^T=HiXTlY2QXK6o`Y6i6AGLI_:K7VGH8[CJ5>/QVb6LI^:CVQTk<hX
Z;eGH5N>Y4J6OJ3oJ4KTDdIiH;U/FjRKoi<C^HXaLGf/Te>XTlK26gV/AVbKTk5/
I7VGi4Y2h89KQXIm/G56Tf2CofaCoHYGLENTI4JPJ=Oo@X;/DdIKNJ@mLKVGmJQ2
aY<TH7VCRTj>TkW>CY?CBTjGOHYaJ6bXh8:>bXimLFbGOFa/LKVmMJ2/ThiTNJ1a
K8ImTj1eRZB>PWF2UgEeRWF2VgemQY^6NHJ>PX:>PWf:UjB:PYNCQWf2UhImRXJ:
Y8YaTiMmNH::RWV6RWfKUf2:UgemOGf:MHZ>QXJGMGFCTgUiPXZ:RY>>RY>>OIN>
OH:>RY>>RX9iSZQeNI>>NH:6SX9mPW5m/GUTViN2PWeePXIiRWEiZ7U/Z9^2OGf6
SXJ>PWfPUh:KUhj2OHZCOHIiOJ2COHj>QX:2SXIiPWemPZ26LHZ>RWUiPXZ2RWei
Tj1XPY>:QX:2SXZ>QX::Z8YiVhjCSX:6RXJ>QXZ:Uh:2ThZ:OGUmRXZ:RX9mPY>:
PX:6QX:2QXJ6QX:6RY>>NHJCUhJ6RY>>SXj:QXjTPX:CSX:6RXZ2QXJ2QXjCLHZ:
RXJ6OH:2RXJ2PXZGMHJCRXJ2OHZ6RXj2QXZKPXJGSXj6QXZCSXZ2RXZ>Uh:2QXj6
QX:2PX:6QX::QXZ6PXJ2QX9mPXJ6PXJ:QWf>QWV6RXj6OHJ>RXj:RXJ:Uh:>SXj:
PXJ>PXJ:QXZ2RXiiPXJ:RWUmQX:6QXJ6OH:>PWf6RXYiOHZ2PXJ2RX:6Thj6QXjG
QX:CRXZ>SXj6QXZ:UhJ2QY>CNHJ>OH::QXZ2PXZ:QXZ:UgUeRXJ2PX:6PX:2SXim
QY^KOH:>QXJ6SXZ6QXJTQXJGY9MiSXj6QX:6RX9iPZ22NI>PTgf2PWV2OH::MGF2
VhImUi^KPXj2NGeiRXYiOGfGThZGUi^TRY>CQWeaPXJ6PWV2Ti>>UjBPPXJ2PWU/
MGemMGUiRY^6SZR/RWf:OGUaMGV2MG66SYN>SZ2/X8Z>QWe/MGemOGUmQXJKX8jK
[:26QXImJ6QaMGeiNH9mQZ2CTi^PThZ>QWE/MG5mPX9mPX9mRZ2PSY^TX9>CQWee
K7V2QWf2QXJ:TiNCTiNKThZ:PWeeMGeiOH:2QXJ6QXjCThjCVi>:SXZ6OGf6PX:2
QXZ6RXj:RXjGUi>KUhj>ThZ2PX9mQXZ2PXJ6QXJ:QXJ:RXZ:SXZ:SY>CRX:2OHJ2
PXJ2OH:2PX:6QXZ>SXj>ThZ:SXZ6QXImPX9mPX:2PXJ6QXJ6PXJ6QXJ6QX:6QXJ6
QX:2RXZ6PXJ6QX:6QX:6QXJ6QXJ6RXj>RXZ>RXj>RXJ6QXJ:QX:2PXZCRXJ6PXJ:
RXj:RXJ6QXZ:RXj:QX:6RXZ:RXZ6PXZ>SXZ6PX:6RXZ:RXJ2QXZ:RXZ6QXJ6QXZ>
RXZ2PX:6RXJ:QX:2QXZ:RXJ2PXJ:RXZ6PX:6RXj>QXJ6RXZ:RXJ6QXJ6RXZ:RXZ6
QXZ:SXj:QX:2RXZ:QXJ2PX:6RXJ2PX:6RXZ:QX:6QXZ:RXJ6QXZ:RXZ6QXJ6RXZ:
RXZ6QXJ:RXj:QXJ2QXZ>RXJ2PXJ:RXZ6PX:6QXZ6QX:2QXZ:RXJ6QXJ:RXZ:QXJ6
RXZ:RXJ2QXJ>SXZ6PXJ:Ti>>QX:6RXj>SXZ2PX::RXJ6QXJ6QXJ6RXJ6PX:6RXj:
PX:6RXj>RX:2QXj>SXJ2OHJ>SXj:PX:6SY>CRXJ6QXZ>SXJ6PX:6RXZ:PWemQXZ>
RX9mPXJ:RXJ2OH::SXZ6PWf2RXj:QX:2QXZ>SXZ2PXJ>SY>CRXJ2QXjCSXImOH::
SXJ2NGf6SXZ2OGf2RXj:PWemQXj:QX9mPXZ>RXJ2PXJ:SXj:QXJ6RXjCSXZ6QXZC
Thj6PXJ:Thj6OGf6RXj6PWf2QXZ6PWemQXZ:QWemPXZ>QX:2PXZ>SXJ2PX:6SXj>
RXZ6RXjCThj:QXZ>Thj:PX:6RXj:PWemQXj:QWeiPXZ>RX9iOHJ>SXJ2OH::SXZ6
PX:6RXj:RXJ:RXZ>SXj:RXZ:SXj:RXJ6QXJ:QXJ2PXJ6QXJ2PX:6QXZ6PX:2QXZ:
QX:2QXJ:SXZ6PX::RXj:RXJ:RXjCThj:RXZ>SXj:QXJ6QXZ>RX:2PXJ:SXZ2OH:2
RXZ:QX:2PXJ>RXJ2PXJ:SXj6PX:6RXj>SXJ2QXZCThj:QXJ:SXj>QX:2QXZ:RXJ2
OH:6RXZ6PWemPXZ:RX:2OGf6RXZ6PX:2QXZ:RXJ2PXJ:SXj:QXJ6RXj>SXJ6QXZ>
SXZ2PX:6QXZ6QX:6PXJ6QXJ6PWf2QXZ:QX9mPXZ>SXImOH::SXj6PX:6RXj:RXZ6
QXZ:SXj>QXJ6QXJ:RXJ2PX:6RXZ6PX:2PXJ6QXJ2PX:6RXZ:QXJ2QXZ:RXJ6PXJ:
SXj:QXJ6RXj>SXZ6QXJ>SXj:QXJ6RXj>RX:2PXJ:SXZ2PX:6RXZ:QX:2QXZ>RXJ2
PXJ>SXZ6PX:6RXj>RXJ6QXZ:RXj:RXZ6RXZ:RXZ6QXJ6RXZ:RXJ2PXJ6RXZ6PX:6
RXZ6QX:2QXZ:QXJ2QXJ:RXZ6PX:6RXZ>RXJ2QXZ>SXj:QXJ:RXj>RXJ6QXZ>RXJ2
PXJ:RXZ6PX:6RXj:QX:2QXZ:RXJ2PXJ:SXZ6PX:6RXj>QXJ6QXZ>SXZ:QXJ6RXZ:
RXJ6QXJ6RXJ6QXJ6QXJ6QXJ6QX:2QXZ6QX:2QXZ:QX:2PXJ:SXJ2PXJ:SXj:PX::
SXj:QX:2QXZ:QXJ2QXJ:QXJ2PXJ6QXJ6PXJ6RXJ6QXJ6RXZ6PXJ6RXZ:QXJ6RXj>
SXZ:RXZ>SXj>RXZ6RXj>SXZ6QXJ:RXZ6PXJ6RXZ6QXJ6RXZ:QXJ6RXZ6QX:6QXZ:
QXJ6RXZ:RXJ6RXZ>SXj6QXJ:SXj:PX:2RXj:PWemQXZ:QWemPXJ:RX9mOHJ6QXJ2
PX:6QXJ6QXJ6RXZ:RXZ:SXj:RXZ>SXZ:RXZ>RXZ6QXJ:RXJ6QXJ6QXJ6QXJ:QXJ6
QXJ6RXJ6PX:6RXZ6QX:6RXZ>RXJ6RXZ>SXj:RXZ:RXZ:QXJ6QXJ6QX:2PX:6QXJ2
PX:6QXJ2PX:2PXJ2PWf2QXJ6PX:2PXJ6QXJ:RXJ6RXJ:RXj:RXZ6RXZ:RXJ6QXZ:
QXJ2QXJ6RXJ6QXJ6RXZ:QXJ2QXJ:RXJ2PXJ:SXZ6PXJ:SXj>RXJ6SY>CThj:RXj>
SXj:QXJ6RXZ:QXJ2QXZ:RXJ6QXJ6RXZ:QX:2QXZ:RXJ2PXJ6RXZ:QX9mQXZ>SXZ6
QXJ:SXj>RXJ6QXZ:RXZ6PX:2QXJ6QX9mPX:6RXZ6PWf2QXZ:QX9mPXJ:RXJ2PX:6
RXZ:QXJ6QXZ>SXj:RXJ:SXjCRXJ6QXZ:RXZ6QX:6RXZ:QXJ6QXJ:RXZ6QX:6QXZ>
SXZ6QXJ:RXj:QX:2QXZ>SXj:QXJ>SY>>RXZ:RXZ:RXZ:QXJ2QXZ:RXJ2OH::SXZ6
OGf2RXj>QWemPXZ>RX:2PXJ6RXZ:QXJ6QXZ:SXj:QX:6RXj>RX:2PXZ:RXJ2PX:2
QXJ2PWemPX:6QXImOGf2QXZ6PWf2QXZ:QX9mPXZ:RXZ6QXJ:SXj>SXZ6QXZ>SXZ6
PX:6RXZ6PWf2QXj:QX:2PXZ:RXJ2PXJ:RXZ6PXJ6RXZ:RXJ6QXZ:SXj:QXJ:SY>C
SXZ2QXZ>SXZ6OH::SXZ6OGemPXZ:QX9mOHJ:RXJ2PX:6RXj:QX:6RXj>RXJ2QXZC
Thj:QXZ>TiNCRXJ6SY>CSXJ2PXJ:SXJ2PX:6RXZ:QX:2QXZ:RXJ6PXJ:RXZ6QXJ:
RXZ:RXZ:SXj>SXZ:SXj>SXj>SXZ:RXZ:RXJ6QXJ6QXJ6QXJ2QXJ6PX:2QXJ6QX:2
QXJ:QX:2PXJ:RXZ6QXJ:SXj:RXZ:SXj>RXZ6QXZ:RXJ6PX:6QX:2PX:2PXJ6PWem
OH:2PX9mOH:2PX:2PX:2PXJ6QXJ6QXZ:RXZ:RXZ:RXZ:RXZ6QXJ6PXJ6PX:2PX:2
PX:2PX:2PX:2PXJ2PX:2QXJ2PWf2QXZ:RXJ2QXZ>Thj:RXZ>Ti>CSXZ6RXj>ThZ6
PXJ:SXj:PX:6RXj:QX:2QXZ:RXJ6QXJ:RXZ:QXJ6RXj>SXj:SXjCTi>CThj>Ti>C
Ti>>SXj:RXj>RXZ:RXJ6RXZ:RXJ2QXJ:RXJ2PXJ6QXJ6PX:6QXZ6QXJ6QXZ:RXZ:
RXZ:SXj>SXZ6QXZ:RXZ6PX:2RXZ:QX:2PXJ:QX9mOGf6RXJ2OGf2QXZ:QWemPXJ:
RXJ2PXJ6SXj>RXJ6QXZ:RXZ:QXJ6QXJ:RXJ6PX:6QXJ6PX:2PXJ6QX:2PXJ6QXJ2
PX:6QXJ6QXJ2QXJ:RXZ:QXJ:SXj>SXZ:RXj>RXZ:RXZ:RXJ6RXZ:QXJ6RXZ:RXJ2
QXZ:RXZ6PXJ:RXZ6QXJ6RXZ:RXZ:RXZ:RXj>SXj:RXZ>SXj>RXJ6QXZ:RXJ2OH:6
RXZ6PWf2QXZ:QWemPXJ6QXJ2PX:2QXJ6QXJ2PXJ6RXZ6QX:6RXjCSXZ2QXJ:RXZ6
PWf2PXJ6QX9mPX:6QXJ2OGf2PXJ6PWemOHJ:QXJ2PX:2QXZ:QXJ2QXZ>SXZ:RXZ:
RXj>RXZ:RXZ:RXZ6QXJ6RXZ:QXJ6QXJ:RXJ6QXJ:RXZ6QXJ6RXj:QXJ6RXj>SXZ:
RXjCThj>RXjCThj>RXZ:RXZ:QXJ6QXJ6QXJ6PX:6QXZ6QX:2PXJ6RXJ2PWf6RXZ:
PWf2QXZ>RXJ6QXZ>Thj:QXJ:SXj>RX:2QXZ:RX9mOH:6RXJ2OGf2QXJ6PWemPXJ:
QX9mOH:6RXJ2PX:6SXj:RXJ6SXjCSXj:RXZ>SXj6QXJ6RXZ6QX:2PXJ6RXJ2PX:6
QXZ6QX:2QXZ:QX:2PXZ:RXJ2QXZ>Thj>RXj>TiNCSXj>SXj>SXj:QXZ:RXZ:QX:6
RXZ:QX:2PXZ:RX9mOH:6RXJ2OGf2RXZ6PX:2RXj>SXZ:RXj>Thj>RXZ:RXj:RXJ6
PXJ6QXJ2PWf2PX:6PX9mOGemPX:2OGemPX:2PWemPX:2QXJ6QXJ:RXZ>SXZ:RXZ:
SXj:QXJ6QXZ:QXJ2PXJ6QXJ2PX:2QXJ6PX:2PXJ6QXJ2PXJ6RXZ6QXJ:RXj>SXZ:
SY>CTi>>SXj>SXj>RXZ>RXZ:RXZ:RXZ6QXJ6RXZ:QX:2PXJ6QX:2PXJ6QX:2PXJ6
RXZ:RXZ:RXj>SXj>SXZ>RXj>SXZ:QXJ:QXJ6QXJ6QX:2PX:2PX:2PXJ2PX9mPX:2
PX:2PX:2QXJ:RXJ:RXZ>SXj:RXZ>SXj>RXZ:QXJ:RXZ>RXJ2PXJ:RXJ6OGf6QXZ6
PWemPXJ6QX:2PXJ6QXJ6QXZ:RXZ:RXZ>SXj:SXj>SXj:RXZ:RXZ:RXJ6QXJ6QXZ:
QX:2QXJ6PXImOHJ6QXJ2OH:2QXZ:QX:2RXj>SXj6QXZ>SXj>RXZ:RXj>SXj:SXZ>
RX:2QX9mPWf6RX9mOGf2SXj6QX:2PX9mOGeiNGf2RX:2PX::SYNKUi>CSXJ2QXJ:
QWf6ThJ2RXJ6Ui^CY:2:QWU/NGUaLGE/UhYiOHJCVjR2Vk6KPW5KI7eXH6aTVk6C
SXjG]KW:TiO6/H9PBTiiH4I>FkW>ViNTb/k6J8ZmUf@m:49/?BPaOOo>Z9_:i>R>
BZbXOD8/<FQP;35Pooo2^L;anJ@CR[66CRPPJ74T:4[ookfe/N3XV`1a[7e2:1]X
OALTDooo^Jbej=_KPP22]HI2<D:CPQ<eMOooVjC6j<I60:bmJ2a2CZ1K0RRCooUi
Vm_G[000di/m94ia]CT2=M?o^G72lLZ6063oQR@iI9NX5bAPoOn2ONC/X5<0X>A>
5f1iTgT>:7gooCg2lKf:2Pke[1<m?GU/Vd8XMIOoedkPoiMa6d[aQRAiX6R6=BaC
nOmKUog2QU/2Y>0/:8iPJ7deI6SGoe]ik:QPH0j:df1C^HYTNB0iJ?ooA^3aZ8Y2
;>BP3TZXK6ACAWUmoodeh==KFcDidgdmX;U6NDhPBTZ6okePj=N6J49ide/XQXiG
SVQ2J=OoLF3oY5=G:;GC?EO2QU=i=FQK_OmTQ_VKDfPmY:`i@Y]iJ8HiK6cooa>e
ofQ>H4KP[366de=>PTIiDooo<L;mOFAT?MNG96biI6Q/@WeTooD0k>SX<E]TEo5e
9:S6:626CVQ:oolTeoEXI5]XffPiS[5XMFATPXKoY2Co^BQaLH;CAT:eSSUiI5MC
MOn:;?ne>G5>Vl8XCZb:Dh9XK5O>oaN2of0mRU>m/Bb:aTi:SU=:Eoom4mOiFe]P
NKE6AS6>Y6QPMGE:Y?mP>On:989XTja2K:aaCXIiFd[Poc5aohi2OFRXPS5i/GeP
MHI:LOne0_o:6gUmQZa2FjB6Eh9mJ3fXoeLioj0/QW6XSSEiZ7UXNHYaB_oo0=Oo
?FBCLKETH:R>FgUmLG5:Q_nK4oo>=GF2UhHaJ:B6J7F2K3WaoaN2oeL/TgVTLDj6
SVa/PXIGA_oo0=Oo=ENCNJQCDjB6BVR6NCW2odi:oiLTSW62LD9/X7UPOGePDooo
0:So<D:/MJ1T@Y>KEfb:MCf>oi</ooo>3XZ6NI=2H:A/Dhj2K3gao`Z2oe/K]FBG
NCVCVdI/RX9PA_oe0>3o:62TJ;5CDkF:AWf>NDJ/of@/okdGZ89mQS62/E]KSX9K
C_oo1YOoEcfaMIMK?J2CDgfGLDY/om<0oolCLKUi/CTiEke/AYNKJ3Faoe/iokTG
Uh:CQR22Z4IGUhIC?Ooo0YOoEc6TK:QC;;6:=G6TPU=>ool0b_liCZAi^C52egTT
OJAX?FSo_@3mobaTUhjG2U_:Dbb6X5]2J?nm0?oo2VRTUjP2J>aC::BTY5<P[?m6
=OoC;8jC`WD6X;DPBZb>CT:Pof06ooT0NJbTK02Tda//_JQ2@ZSoI0;oo`Yi_K5e
0;7K83W2Vc4/mOl>J?ni:9^i]DXG`Z06B[ei;4ZaocTKooD2Q]>PAP[2/@9>bWdT
@_7o2PY/okDG[<ZP=C7GO@9/`W4/Ekgo=DKoea>Gh9Li;<im06BmH2A>b_l:I?nm
6kWXSSU2i7D0OKUC:7V>ohX>ool/J?nK@SFiZ0I6aWD>Fi_oK0kooc5/oj0iA[FC
1UNaI1]/QYOi?J3oY34anNa:J7fKDbR>UbQ6SUOXTbcomCfCofaPSXii<F2PCRR2
Fe?oH5?o`Sg>mEN6SXYm@WfK@U>2BVcmFeOoaSg>mE^:Y8Y/DhJ6AUMiCU?KUbSe
j4JTogV2^H9iLG62DdYeH4:>j2aaoh9PH?GPJ;VaUhIXQWe6J756Dh[66iOoI6cm
fdkCbWEaY7eKEgUP@VQ/[4I/mGU/do5X`/j2OJQeJ7e/Fe=aH:1i@^2XH;WoLIOT
QVbTPU]iEeMKH5]/[4J2fgUej<9Xb[UTRZACI7eKAW5iFe^2[5>GefbGk9]ah:1C
Z:A2J89GI7eeI7FXH77XLFSC^DZaeeMi`U]>TfQPThYCPY>:J9?:I7g6Te_6]F2>
^E]a[7UaThYaOH:>LG6TMFbTX6R>/HIi/I]PRXimOHj6J89mMHiaRY=/QZBTPXZ/
Uh:PY7V6Vhj6RXYmPXiePXi/TiMaQZAeNJb6PZ2>LHj:UhimUhiaSXZ2RWEeSX9a
ThYaSY^2VjR6RZBKTi^KRX:6PWV>NGUaNGemPXj6OHZKTiNGQXJ:Th:2VfQaX6QG
VhIPQXJ6MHZ6PXjCPXjCQXjCRXJCQX:KPX:>PXimNHiiLH:6NGF6QWf6RXJ2RXj:
PXj>QXJ>TgEmVgEiTg5eRWF2SX9mSXZ:SY>:QY>>RY>>QXZ:QXj>PXJ6OHJ6QWf2
PWf6QXJ2QX:6SXj:RXZ6QXjCSXZ>RXJ>SXZ>RX:6SXj:SXj6RXj:RXj:RXJ>SY>>
SXj:SXjCSXj:QXZ:RXJ2OGf2RX9mOGemQXZ6QX:6RXjCThj>SXZCThj>SXJ6RXJ6
QXImOH:2PX:2OH:2PX:6PXJ6QXJ:RXJ:RXZ:RXJ6QXJ2QXImPWf2QX:6QX:6RXZ:
RXj:RXZ:SXZ:SXZ:RXZ:RXZ6QX:2QXJ2OGemOH:6PX:2OH:6PXJ2OH:6PXZ:QXZ:
QXjCSXj>SXj>SY>:SXZ6QXJ6QXJ2PX:2PXJ6PWf2PX:6RXJ6QXJ6QXZ:QXJ6QXZ:
RXJ6QXJ:QXZ:QXJ6RXZ:RXZ:RXZ:RXZ:RXZ:QXZ:RXJ6RXJ6QXJ2PXJ6QXJ6QX:6
QXZ6QXJ6RXZ:RXJ2QXj:RXZ:RXZ>Ti>>RXj:SY>>SXZ6RXZ6RXJ2PX:2QXJ6QXJ6
PX:6RXJ6QXJ2RXZ6QXJ6QXZ:RXJ6QXZ:RXZ:RXZ6RXZ:RXZ:RXJ:RXZ:QXJ2QXJ6
QX:2OH:2QXJ2PX:2QXJ6QX:2PXJ6QXJ6QXJ6QXJ6QXJ6RXZ:QXJ:RXZ:RXZ6RXZ:
RXJ6PX:6QXJ6PWemPXJ6PWemPXJ:QX:2PXJ:RXJ2PXJ:RXJ2PXJ6RXZ6QXJ6RXZ:
QXZ:RXj>RXJ6QXZ:RXJ2QXJ6RXJ2PX:6RXZ6PX:6RXZ:PX:6RXj>QX:6RXjCSXZ6
RXjCTi>:RXZ>Ti>>RXZ:RXj>SXZ6QXJ6QXZ:QX:2QXJ6RXJ6QXJ6QXJ6QXJ6QXJ6
QXJ6QXJ:RXj:RXZ:RXj>SXZ>RXZ:SXZ:QXJ6QXJ6PX:2QXJ6PX:2PXJ6QX:2PXJ6
QX9mPX:6RXJ2OH:6RXZ:QXJ:SY>CSXZ6QXjCThj:PWf2QXZ:PWemPXJ6QX:2PXJ6
QXJ2PX:2PXJ2QX:2QXJ2QXJ6QXZ:RXZ>SY>CSXj>SXj>SXj:RXJ:RXZ:QX:2QXJ:
QX:2QXJ6RX:2PX:6QXJ2PWf6RWf:QWVGNHZGOI>>PY>CQYNKVh:>Uh:CThJCQX:>
RX:CRX:2RWfCOHZGI:AiLK5XNJ1aOJB6J8j2K9N:NHimQXimThj:SWVaSVB/VgfG
X6b6UgfPTfR:RWFGSX:2OGf:RXYiQXZ6MHJCMGV2MHZ>J8J:LH::QXJ6RXimPX:X
QXZ6Tj2>NHJeOGFCPXjCPX:6MGfXMI>CK8IiNIMiLIMeQXiaUh:6Ug6>SVb6QX:6
QX:>OI>KMI>GNJB:PZaeTiMiTi>KQWf2QXiiSX9mVfb2SW6:PX:CPXieOHYaPWf2
Tfb:QVbCRWUiR[5eNJ1eY:A/SYNGRZ22Z8YiThJCPY^6PXiiTgemTgf>RWF:OHJ:
OHJ>QWemPY^6J9=mK;66OI]iPWf2VjRGSXj6OI>:Ti^2PZ26PZR2RY>:SXJ:MI]e
NJQ/RXYmPYN>OH9eRXZ2TgEmOIMmOHJGOH:KNI>COI>6PZB>PZB>QXj6TiN6OHYm
ThZ>NGf>OH::SVR6Tg6GRWUaMJATRX9PRWUmMJQaOI=mSYN6PWfCY7FGY6b>QYNG
RXj>PWVCVh:2SWF2Tgf:RXJ2PXimNHJ6RXJ:OGemOH:>NHYiLI>2NHZ>QXZ>SXia
UjA/VkEa]I^2UgVKLH:2NHIaOGV>NHZ>SX:2X7F>Vg5iY7eXX8YKQY]iPXYmPXIm
ViM/Tj1eTj26RX:KSX:KQXZ2QYMmSY=/Y8IeUh:2QXZ6MHJ6NHZ:PWeeQWemTgem
QXYmPYMiMI^:PYNCSXj>SY>CQZ2:PZR>NHZTOH:>RX:2QX:KLHj:OHZ6Ug5eY7EX
Y8Y/PYMmOHj2LHj6NHj:PXYmQY^GMI>XMHZXQWf>Th:>Uh:>RX:CTgf6SWf:QWF2
PXIaK9=mI8YXOHY/LHJ>NHJPY8jG/J2GRZ2>LHZ:OG62NFQaMH9iNHJ:QXjPTiN/
Z:bmZ9>PSWEmOFAGJ6QGFfQTFfR:Ufb6`YN6c/JK[=NeTjBTLFAmNE]KMF1>J7UX
LI^>Q[FeX<;:X:2/fjb2Y9=>EgUG?E=KBTYKEfR:OH:e_I>mmK6Kj=N>Uk62CVAe
DceKJ496J6B2VhJKc[fXh>2T^M>XPXZ2DdI:CT8iDdhiEe]a[7f6h=NTc_g2X=OC
PX:GI3e>Edi2CUM>CU^T^ENXooo:TncoY9OX^F1aQTXT?Dhi94YGATYX_HiPh?f/
/OoXR/K/SVB>NC4eDe<i?E]GBU^e/FS6olJ/ooV>a^R:OHI/AS4i?Cd/@UM:AW72
PX;ek:cKoLJaek6CRVQTDcDmCT8iDe]KA/k6A]_KokFaooFC^N2>PVaPDb`PCTXP
=E]K=JCPDjSocY_inI>abXJ:J5=P@Q]:FcDaH6Q6[==T_Oo2VooaQ[GGOGemDe=:
6dIK>BaGJ4:eddjiokf6oomXY>1/LGUGEdhPBVQ:=E]eEljeJ>coojbCoo5TZ=]i
J7EPI5<PEgE6:6QXK>22LOoaOJ3obTj/aVaTI61X?A]TOD8/LFaek89mooEi]Oo6
C[G6K6aXI7E696b2ASEaJ8;eFggoh5NeojQ:Z;E/Ee]TLCdTK8Hm<GEXUoEGQ_oT
EeO2ojAC]KEaJ61aPTH/OHiC?GU/MOmeDooiDi?o`V26Y89/>FB6E`iTSVPiH6aK
oK4CoomXDoo/J9>TOHi6Ei>:5e>KQTYCOE^Gob22okTidon6MJaPSV`/H:0m98:>
EdiPMDKa_@3eogUiJ?WPQZ2CFjaG=GfX=Dj>SVQPEhIKohhPooeaR_G>RYM/J:@m
=GVC=EN6RW5GBWeTof@aooE/S_GGUi]TPZA2?I>G@VR6Vh9GEhi>ohhPoon2Tn3>
ViMGJ:@m;7fCDfAXThI:AY/adm<00=_oVhK>cZBTJ4j/DceeVfQiJ9>CI4:>>K7o
3ZSo/HK6bZbXI2bKJ3eKQW62I7FKMD9/@VCo@U?odi?2_K7:UbAmSTiPNGf>OFBK
RU=PI2So_AOTmJS2^I_6]CU2QTiTJ6QiUf26RUMCNGTTQ_laP_ni`]^KZ<Im;7UT
J7e/LIN6QXiPEg5K;?nT=Og6/O6XR[VG?DiT@WeeLG6:OHi/De=X8;gT;=?XZ>c:
P[FaI49XAWEmPWVCPXj6FdiaBSGoNE?o[<[mQXJaOCeC@TJ2OH9iPX:2TfQ:Eg4G
c]/TmN2Xol9e]I]KEe<iRXJKQWf6UgePCV0/MOm6VonKnOETVjQKEdXGMHj>Y6Ae
X9MTEd9C=One>Onia_nCK<9XFfPXBZQm`XI/Ti]eK4968>3/?OFmZ?neFkETDgDX
8:BTOLZPAWVKRWdi?B2:oe^ek8[ooe^PPTZ2D`j:Ul;:De^>Ti=K<@iKohZCmGWe
of2:NC62L@9XVjcGH3eiQY]X;022ogW:bU_oof2XBR2XH22>P/;>DeMaK;5/902T
oh[mX6Coh7fm3RbKVdIG[76eX4i/LI>CJ08Xoi_2ocfiofS2SP1mOBbeVgW6Ee>:
FhZ6?@2XoH;oZ5OobW7C5bRCAVcKLIN6=GF6J9MP08;oOOo6@_7GK=/a6hiGJ>26
PXhiEhYXVgD0[?n2okTmlL9adb@iSU^KegF2I3eaOGEeY4H0k=^TogEGlHZXZ09X
LFcK`VAe:4Z6MHjG3VCo[>c/?HkKJ;eT87V:X?FCAU</J9MiPV0:nOfeogE6dgfC
TaMPPZcX_D8e94Z2RWeC6ogoh?mTEkEeZ7TCMFc>ojaC<A=XPWemBQOmoOoKof@m
_FbGT`1POM?o^CT:3U^GUg4:A_oaon`PI8iKi4XTK7GoohI20RRGUjAP0;goh?n:
6i=CR^`CFe>Pom=a901CSY>e05Oo^Ooi=F1K@^AKCWEeh=]iEa<mVhj/CPKoa_oo
I5Mi@T:mTcUeLL;GVe<P:8:6X4iTi;gok89XBU^:I7eTUkV>NE/eJ8iiTbaimL;o
efaiAW6PFhi/R/J2MELPI7F6LGG/Y?oPSY]6?HXiVj26aV1CH3eiSVR2;9_ec_na
J7TiNI]G/G6>[5]TFcdmOGUeI;7i_On/NH8mI7E:]Gf/]DITFdImJ61:[?g>ojQm
K4IPLE>/OJRPBU]CH8YiK4K>oM_oTfQXAWeaJ:ae[9=2K5=TOGUGB_WPoon2LDi:
RVB>SV2CFeM/J89aNDjPomOo/FaTCWVCTg6aOFB2BV1eMGU/H6SolOo/LGE>FiMi
UjAPMDY6H7F:Fg5Gk?oaofaPCSfCVhJmI6A>AW5mQVQCB_7ooOmKDdXeZ:bC^E=G
BT:2NGeTAT;ToogoH3UC>K76OJa6?F16PWeXH4Y:oooooole@U<ifkF6[2aPLDjC
LF1KAU_ooooo6f0m=NbTUkTGEdhmTfaCEaO2oogoQPi:1YOaOM=C:756QXi>DcEC
oooooa<m=D;o]Jb/5eMKH:1XAThPi?oeoeL:CP;2nH;G<A]iDjRG=DX:Q_oooon/
02`KMOnK`WD2OG62/D8i84Kooooe3R0XA_nmZ9L6FgEmaV`e>A?ooooo800X<OWT
Tj`2>Him`XX/=@32ooooJ00a:<[oTkDP3Vae`Za:AP:XooooM@0G4kGoVkTa07Um
^KTe;000LOoooiL02Q^GojBTAP1TNK72ASd:S_ooohH61Q>Xok6e@PYTOKVaCSTC
LOoooj022R2:okfKD`1>LJReCTH>ToooogD>00Z/ol:a>@ITNM?2CT80X?ooog40
01Nmol:/;01KK;fe@RP61^3ooom63P0Ka_o:Y0X6EggX_DhX0=Oooom6000Ph?o6
[080H7gP[4HC=OooonQ60P1Gi?W6M@0iI:ciPT80H?ooojPG001ioo76BP1:H;WC
H2P2a_ooog4/01?2on2/1Q=CP_6eI1<ek>ceon1:001>mOoPO@0eCZCXNDX0S^So
oi=6002:onC6<@92Fm>mOB`Xi=OooG4X03G:mM^K2SU>R^B2E`::eoooX5/007ga
em<i2Ti6b[Ue;2S:b_oePS408;gPfk4:BT9eh8iT::2mooooY7T01VS>c]]2=E=:
aZ22<E>mdooCVaL0:;W>h9<:BRb>]HiC::bPooneI00GMM?2dba:BVS>UhHPSZSe
okVK0PHma[GPJ35T?K6GQR1mY<;o_L8m036PUm^287D/X:b2Fd;2Y?oebVP:2RAi
`[G::752P[66MBRaTooo`YLC:5>iVmLmDe=G/H:698j>j?o2_BPP::R>egTiI3fT
SXi:J;6XonCPI3DPRYNaZ2aX=HJCTdiGZ8Kok=^>>B1aQYNi;6@eK9^>J3F6NOgo
h;U:>DZXQXKGDf1:I9^GPSemNL[oi=M/DcVGOKUeCUMCRXj:De=eR^cTdiMPBVbK
SZA6J5>2RY=XDf1mZ>36_GeiFjRK^HYXOH:GSXiKK6B>SZbGUgF2K9^G[8j6QYN>
RXYXNFb6OH9eOGEeOGVKX:RXX9^CUiN>ThJ>QX:2NGUiOGV:RYNXX:2CUhjGSXj2
PWemNGEeK75iQXj>RXJ:RYNCThZ6PX:2PWeiOGf6RXZ>RXZ>SXjCTi>CSXj6PWf2
RXZCRXZ6PXJ6PX9mOHImRXImOGf2RY>>RXJ6QXJ>RX9mNGemPXJ2PWf2RY>GVi>>
SXjGSXj6QX:2PX:2OGemPXJ:RXZ6PXJ:RXZ6PWf6PXJ2PWf2PXZ:SXZ2PX::SXZ:
PX:2RXj>RXZ:RY>CUi>:QXJ6RXj:QWemOHJ:RXZ6QXJ>Thj6QXImPXJ:QXJ2NGf2
RXj>RXJ:RY>CThZ6PXJ6SXZ6PWf2QXZ>Thj:RXJ>SY>>QX9mPXZ:QX9mOH::Thj:
PX:6RXj:QX9mPXJ>RXZ6PX::RY>>RXJ2QXJ:RXZ2PWf2RXZ>RXJ6QXZ>ThZ6OGf2
PXJ:QX9mOH::RXZ6QXJ2RXZ:RXJ2QXZ:RXZ6QX:6RXj>RX:2PXJ:RXZ6PX:6QXZ:
SXJ6QXJ>SXj:QX:2QXZ>QX9mPXJ:RXZ6PXJ:SXj:QX:2QXZ:RXJ2PXJ:RXZ:QX:2
QXZ:RXZ6PXJ6QXj>RXZ6QXJ:SXj>QX:2QXZ>RXJ2OHJ:SXj6QX:6SXj>RX9mPXZ>
SXImNH:6SXj6PWf2RXj>RX:2PXZ>SXZ6PXJ6RXZ:RXJ6QXJ6QXJ6QX:2QXZ:RXJ2
PXJ>SXZ2OH::SXZ6NGf2SXZ6QXiiNHJ>Thj:RX:2SXj>RXZ6QXZ6RXZ6QX:6QXZ:
RXJ2PXZ>SXZ2OH::Thj6OGUmRY>>QWUiPXjCSX9iOHZCThj2OH::Ti>:PX:6RXj>
QX:2QXZ>RX:2PXZ>RXZ2PXJ:RXZ2PXJ:RXZ2OGf2QXZ>QX:2QXZ>SXZ6QXJ>SXZ:
QXZ:SXj:QXJ:RXj:QX:6RXZ:RXJ6RXZ:QX:6RXZ:QX:2QXZ:QWemPXZ>RXImPXJ>
Thj6PXJ:SY>>QX:6RY>>RXJ2PXJ>SXZ2OH::Thj:PWf2SXj>QWemOHJ:SXZ2NGf6
SXZ6PWf2RXj>QX:6QXj>SXJ6QXZ>SXZ6PXJ6RXZ6PX:6RXj:QX:2PXZ>RX9mOHJ>
RXImNGf6RXZ6OGemQXZ>RX:2PXZ>SXj:QXJ:RY>>RXJ2PXZ>SXJ2OH::SXj:PWf6
QXZ>RX9mPXJ:RXImOH::SXZ6OGf6SXj:QWf2RXjCThZ2PXZCTi>:PX:6SY>>QX:2
QXZCSXZ2PXJ:SXj6PWf2QXZ:QX9mPXZ>SXZ2OH:6RXj:QX:2QXj>SXZ6QXJ:SXj:
RXJ6QXZ>RXZ6PX:6QXZ:RXJ2PXJ6RXJ6PX:2QXZ:QXJ2PXJ:RXZ6PX:6RXj>RXJ2
QXZCThj:QXJ:SXj>QXJ6QXZ>RXJ6PXJ:RXZ6QX:6QXJ6QXJ2PXJ6QXJ6QXJ2PXJ6
RXZ6PXJ6RXj>RXJ6RXjCThZ6QXJ6RXj>RXJ6QXZ:RXJ6QXJ6QXJ6QXJ6QXJ6QXJ6
QXJ2QXJ6RXJ2PX:6RXj:QXJ6RXj>SXZ6QXZ:SXj:RXJ6QXZ:RXJ6PXJ6QXJ6QX:2
QXJ:QXJ2PXJ6RXJ6PX:6RXZ:QX:2PXZ>SXZ6PXJ6SY>CSXJ2QXjCThZ6PX::SY>6
PWf2QXj>QWemOHJ>SXImNH:6SXj6OGV2RXj>RX9mPXZ>SXZ6QXJ:SXj>SXZ:RXZ>
SXj:QXJ6RXZ:QX:2QXZ:QX9mPXJ:QX9mOHJ:SXJ2OGf6SXj:QX:2PXZ>Thj6PX::
TiNCRX:6SY>KSXimLI>2PY^2K8:KOG6TSVb:RY^6PY]eNHj2Y8ITX7U/X8J6RX:>
PXJ:PXJCSXZ>PXj:QXj>PXZCPXZCNHj6LI^2MJ22K9^:J:b6I:A/J:AaSYMTSX:2
RXZ2PWf6RXZ>OHZ6PY^6SY^2RXJ>QXJGRY^KLHj:NI>6SXZ:PWVKNH:GMHimRY]/
UhI/SZAmNJ1aLH9mVhZ2SVamSWfKUh:GQWVCThJ>SXJ>Th:KUfbCVgFCVhIiQY=i
SY>>PWfCOHj6OJBTK7FKNGFCRXJ:PY>COHZCPY>6QZ1KSZ1aRZR>MJbPEiN>LJ22
PYN6LI>:MI>6QXYeThIeThZ2PXZPNGVPRWF6PXiiQY=/QXJ6Uh:>SXJ:PY>GOI=m
QY^2SXj6RXImRXiiRXZ6OH::QWf:RWeeUhZ:QX:>MHJ:MHZ:NGf:QX:2RXZ2PXZG
OH:KQX:>SWfGVh:CQXZ6SY=aSWeiUgUeSWeaSYN6SY^6RZB>RY>6MG5mMGUeNFQG
NH:GRXjm`Zb/_JAiMHZ2H7EiH5MKK6B6Ui>aY:cT^KVTei=TThIGJ75CBU=TH5Mm
Tj2/Y<KTfkFa^HIKMGUCAVQG>EMPDhZKTlZi_OoPX=NTCX9eAVAGATY2CTiiTi_2
Z<[oehKmZ1]mRTI>BTXm;5]/LH:TelK6oo6:^JACK6aPFcU6DcE>NGEeS[7Ka^3o
dg7CUb1XOE<m<Di>84Z6QXkKh>coh9>mQRaTMDi:AT92;4IaS[7>h?oo_I?:J1=e
RTi:Ef0m;5^2Y:belOoeOKg22QNPMCUCK5<T?GfG]LK2oon:OLXe06b:H4IPK4I6
NJBT`[VioonCH;e>062GH4iKMFa>Tm^eX?7off1aLA<:J8YTCV1iOJS>`]?molHe
I6P03W5XDe>2Vjc>b/[oolYKK7d206Qi?C5eX8ZmooomokDCFdh0961PFe=e[<:e
b^cooi/TJ4h097EKFcU:Q/kei=?oogT0ME/03VAaDf3GonRTh?na4cV2;00iMEM:
Y?oedoGo`ULT>@h0949KNI_iolZ/oomi5bAC5`0eJ4YG^OoooOoo/CdK=B@25eMe
I8;aoo6/ooma05=i001KRTi6foooSXkPohH05i<i04JaQPimoomCb_o>00Ii@P0G
RY]adoooMOgoDaLXEe<>@XIPFkgoom_omDH03S4T4dJ2TgfToomTeom>021>?@8C
OJAmdooo_Oo64`866b`/J;6/LOWoh7WoaP006cTX3TY:Vj2moonaenQC2PHP=BaG
K61mfooo[?oK00Hi6a=6PZRG>KGomA_oobP05f0a0T[:aU^moom/k?D/01MCARQ:
Vk5CQ_ooB^co:002@TXGB/:i=Jcok0koo`00BTi295_2UgWoofb/og4000XiFdHi
OJamY?ooS^ca3P0a6c5/PZ2GAZ3oh0[oo`H095]:4fSaef1ToolaJ?nT001PLCTi
Vm>:?Ooo99_oO@0>AWTe5iOPPRcoocF:oe<0>CeCFcFCcUNCooTGool202aGOCda
/J2/ooooH?o/00i/84YTOL:C@_ooI2So/@0G=EM/AX;ebR2Xohh:oN`P3S5TK3UP
bZ`KdomX9?o>01LiBVa2UoGCMF3oo`HeogT:=C6KY2A/bX80i?lK=Oni01Li?F@K
OOF>B_ooDj3o00224cDeZ7V>i9?moe<Kohh0AU=TZ75PThZPolY>ooD0061>H7Em
^KdTVone0?om01/a5jRGDm_oO@[GocD/okU:?@1/ee=>elXa0?oo1U?o^@025fb6
3X[o/D;ood9KoaL0NCEGbXYeaX[>oeL00?7/035aBY=T;9^KDooo;>3o:00i:5Mi
LKgoY3Goob@mnCd:QT9PcXIX]I=6ool6OOnG02`aH88mK>2:0?ooEdkoM@0m:4Jm
RX;a^C7oo`12odX0RT9K]GUX^IMGoolCQ_mi02A:AXiiNGgX`Q?Xod8XohX0FdHi
]G5:aZ`aool:MOli07ECDk6:R_VCH?oX4i_G2SFK<F36SU]aToo/:8koU`0GCWEX
Dfc>SU_oocemo@h0K4iTdjQaelH/Q_n:0?G/<Ba>6jb/DiOa?@3oo`I/oon/02@0
C^A2C_WK1_oo?BCoL@1aEcG>QTk>ejco^ANKm@0:X7EPVgECR_ooI7g/`P80?FRC
OGfX/H[oofQTdfP0CVQXZ:AmSXiCnOliJ?nC03ECBXJ:P]?C95Ool@2aoe/>=@JP
aTi/nG5a0?oo4fCoPP1T3RC6J3g>`TKood9XmCd0PSU6]HiG_JRmojA2Z?Da0U=/
MG52EfcTok5anOd>03dmRVaTX?nGP_omFe^aFeMe?FBeNDimP^SoJ6CobPXTCUMm
ME^>X1_Pog5Ton@2>DXK6jb>CZCT>Dkood:enF`iBPYa^DI6]Famol8/_Om>5g4/
H7Dm?JS>olZG_Lim4fACFf22MHZTS/kTX9?PUcUTJ4iXNFA/J5_ooF2GokdXBS5P
NCdmRWV:onbC^Oei;60aEh9aBY^XP]_>PX:GfhYGSVQCMG4iI7UmnM>:Y?FTBULe
H7eG:6AeJ?o/OKWo]A]CATj:K3f2bU]Pi<ie_LI/NJA2@Y]TBXI/LMNeLJ3//E]X
EhZ6Ed9TPZ2mUhZeh9MTLG62NGEPSZAaLJbPSZBaSW6KOHJ6RW5XMG5TY9MaTkfm
SXIaNHimLFQeJ8ZeRXjPaY^6RWVCSWUXOI=aQZB2SZRiRXZCPY>>LFAeLH:TOFb:
]JRKRW66RVaKK75eX9=aTl[6ThIiTjb6FfR:SW6CSWVC[:b2Thj>UgE/LGe/K8:K
K7FK_I^:MGF:NE=KMFaaUhYiVl:aSXJ2Uj1iH7VCOGVKOGVK]I^6ThJCTg5aOGUa
ThI/R[FaRX9eQXiTDfQaI8:KK7fXaZ2:PWfTTfQ/OI=iQY]eTj2aThJKRY^:J7em
OFb>SVbC/K6/RXJ2PY=/DfQaMHJCK7FXbZB6PX:PSVQTPXieQY=mTjRaRY>PTj2:
K7f2OGFGOFbK]JR:PWV>TfAPNG5TOJ1aOJ2e[9>:QZB:H75mRWU/UgV2VjRXRY^6
UjAeOGemMFbTLGVTZ:b:RXYiSXiCI7E/OHJ6K8Zm]IMmOJBTNEMTNGfCSVaiVjRK
QXZ>Y8i/NH:2OHieK9^m/HYmPY^KLF1aNFaXX7EX/KF/RYNCTi]PI8IeK3V>cV2G
`[fmTgeG_HH/QVAXDd;TVhZmdo5iPVAePPX:DfAK/JB:Q_goRY=mOHHX:5]TOKEm
R_GCH8JeLI>2AWf2=CVa_GFP]L[:NE>2TcdmPW56>DK/k4KKonQTMHieQP1C_F16
@W76od9:oom6C/iaK0h0k8h088kmeeMaool0B_Ua0PIK/DXa<M_P^MOa]JR2>IMX
;5MT?HKoOG7odgFa/F2GH1NKH0ICVk62X>CobTZ>Z4HT@VaG;23CobB2oomKLM]a
@P1GcTHTNJR:bYNKok4i`^PK>F`XPSd:LNc>4oGoZ6RG^DHi1WF:02bPohX>oooo
/B3GlB@0=L9T04jPVjaeZ?oT=JCoBPYaCW4X6hjiaTK6ol9TUmM::4Y:RR@XONc>
4m?o`SFioBPKAXYm04ZPI9?PLMOoUe_m[01GAT:2:5N6LOnaLOooCX;o@Q=m6gUT
<GV2TlJ/^Oooh4Je_B12Ec5CARRaofAPoom:Y>aK5e]GMBPKP]O6C_7oQU_PebQ>
NFAP<FQiNJRK/OgoUi>iFc5PDe]GJ8I/EfSo^AOooceXof@2Dc6XBQN/PP2To`1i
og5Coj@6V`iC`P2>j4hmX?nm_Fc>oi<6]K4:;6R>EcV2RX[TQZ3obSfX`PHeEceP
<C7CobRColh/_OU25e^:D`9//FR>fjcKnHjXaU]:ODY6J5MXJ7FT]LJKk?62OJAX
5f1XFfaPSW5CUommEooK@ZcC=BQCEhh/J<9>823io`36oge:k;TK@SfCI0ZmcU=T
[;7eOCgoh02Koa/GUgF6>FS:I0ImohXifommH<ji?DYeQV16TiLmFhjT^I^eolYe
_K4iDgEKH76>VgV>[9=iZ9MeY89/TgUXS[UiP/jGEeN:EcUKPXJ6I7FGoJ@Xoo4/
NO5e?GemTceK^FPaMG5PodhCoi/6folPR]MPcSeX[5/iJ:PXH3WTo`3Koa<Xolh2
Z7GTV`3o^@0mdd8CSSeiocD/oj00mOlCML9/k02Co`XTcZP0QZ@>fod0[?lKC_oo
Y0KPH:c60?g20VC:BQ>/@SfaoaMeoe=6j>0/VhZP^AOP`RQXY60eVf1:a_d0Toli
C_o24kF:[;DCk:0TMJQP<I=>Fggo?BCoK1?XnA>C/G7C<KWC<E^TK1^PI4Ieohh0
olXK]OmCC/YmOL96Vn@aK9>:=HIiCVB6o`IXoe<XmN@GX:BGZ3GPUcU/VeLaQU=>
C_me1_na>JcoFg6/S/XX^LI2H8Z2>HIaJ5]:ocd>ok40b_lXI<:GZ3G2cRAPY6@X
OFQP?Ggo05?oI1OonA>G]J2C=CGXX2Am[60mX75/AY_o06SoEa_om@jT]INC?NRC
:7fX@SF/Fe]PH?la2_nX0>3o97g6UjP/_LXXJ;UT;:AmFfa>ogT0ooD0VomKB/jC
^BbKi3E>^GTXUhiCNBcTj02mo`16oiLKbZBKFeMGoe/X`Y<XNJa6LDJ6o`1:oeLC
oolPY<JCRSWaUaNP/CeG^F1KMDk2e`2eo`I/ojPCejR2K5_aCT:mQS5aX4YeFfCX
RP3ok0JmofQ2j8Z>CY_C976iI4JGQUMeDggXH0koU`KXocEXk6b6QTjmZ22CVe<m
Vfa>LDj6j4HXogDKooTPVnAGTeO6TcF/Y4iK_E=TOE]XcY<2ok4Ti?mCMNAKVeNX
X3V>VfA>Y61TNE]iEolKNOmXH?GX8<ZTRX9Kfg5TVjA>J:aKOE^:@/:m0?oT9;Go
EeMPnE^CDjBa?HJXK36iJ4YiH6Q>oC5Pof1PlNP/`ZQ/RUOGJ62GX3ei_CemK7U:
NOl2Q_mTDooK3/jKQW5TediGZ:0PPZPTPVQi=GGo08[oI3gobPkGUgUXNLiCK:RK
99^/<HIeND9eoc4aEon>;?oi9:RmNFQ/fe]>X:@XP[DaJ7e/FdkTV`3io`:/oe<a
oHIPJ<::=JBiBTkGEcf/OFA>VnAC;?n:4ooo1ZCmDe^>de=G_ILTP/hKK:QK@W6P
bR2:obAPojP2lKTeMK6/99^iH3W>cY<K[9MT@[UK_Hh/oh92lOl6[?DXRYNa?HJX
ODZC_@jGZ4iCZ4Ian@3:oBBGofa2oe]/OJB6H:2CK5_CDfbiI6aiUc76`P[>oC6>
ofA>mGUTP[eaDjRGDgW>>FbXI61mRRb>da^:od9PH?n:>O6CEhJ/OF2XUfaebU]T
^FQPSXY>I9_25j3o:8;oSS7eVdZ:_GUG[8iTK<IKH:1/EgFC@V22_A^6ocEioj0a
mJQCUkf2El:CJ7g:FfBiI5^:Td:2LGV/AZSGCXkoMF3iOF2T/F22[:amH8Z/AWVK
FeN>NDimK5^TPTkPTe_PbUO6`VRK]HieZ8j2I;5iDiN:CWVKEfb2LE>PX3Vm_E^X
j7Emfh9eVk5PSY]eJ9>:DhZ2H7F>LFb6MFQe[7eGfjQPb^APX>AeNLJPFk6KLG6/
LE]KUhIKPY=KMH9aJ7UaX5^2ffamfi=KdjATVkEeP[V2MHZKH7fCJ6bCK6b>LFb2
NF2KVe?6]FBedfbCbWV6Z:ATX8iiLIMeFh9iH7F2Eg5mK6b2I6R2X5^PbW6:eiMi
cZ1eUkeiQ[66I9^CTfB6Tf1XSW5ePWeTNH9/LGVGLGW:RVRmZ6ba/GV>/I>2Z9]e
OJ1eMI=iFhYmJ8Z2K7F6NGV:OHZGLKfaNJbiNJC6QYNaUgfaRWV2RWEiQW5XMGUT
OGUXK7eeMHIeMGVPSW76Ug6m^GVa^KV2TkVGQZB6OHZ>OGeiLFb2NG5eNFaeQWEe
NGEiPX:KJ8ZaLI>iQWVmThJ/Y76CUgV2UgE/RWU/OH9TNGeeK8YeLHJ6NHZ:MHjT
MI?2MHjiSXJ/TgfKX7f:TgEeSWeXPWETNGeXOGEeNHJ6OH:2QX::SXJ:QY>COJbT
MJbXPZBeQY>/ThZTTgV6SWUmRWEXOGEeOGeaNGemOH:2NHJ6QXJ>OI>GMK6TNJRa
PZ2eTi>/UhJPVh:6UgUmRX9aQWUePX9eOH9eOH9mNH9mOH:2OGf2TgV2P[5iRZbK
Q[FPRZ2XSY>KSX::SWemPWUaOGUiMGeeNGV2OGf2PX:6RX:2QXJ2RYN2OJR2QZRG
OINPQY>PSX:CTgf2TgUeQWeaQX9eNH9mOH:2OH:6PX::QX::RX::SX::X7f:[8:6
Z9>2X:2KQY>KRXJ>RWemQWUiPWeeNGUiNHImOGf2PX:6QX:2QX:2SX:2RX:2SY>>
PY^GPY^TSXZTThZKUhJ:ThIiQXIeNH9eLH9iLGf2NGf6OGf:QX:6SX:6SXZ2RXZ2
RXj6QYN6RZB>RY^KSXjGY9NCUiN:RY>6NHJ2MGemMGEmOGEiOGUmQX9mQXJ2QXZ6
PXJ:QXZ:QXJ:RXJ:RXj>RY^GSYNKTiNKVi>CUhZ:ThYmQXIiOH9iNGemOGemPWem
PXJ6QXJ6RXJ:RXJ6QXJ:RXZ:RXZ6RXZ:RY>>RYNCSYNKSXZGThZCUhJ2RXImQXIi
NH9mNGemMGUmPX:2PWf2QXJ6QX:2PXJ6QXJ6QXZ:RXJ6RXZ>SXZ6SY>>Ui^:RYNC
RY>CQX:CSX:2QWUiQX9iNGemOH9mNGUmPX:2PX9mPXJ6QX:2PX:6RXJ6QXZ:RXj:
RXj>SXj:RXZ>Thj:SY>>Ti>>QXZCSXJ:QWf6RX9mPX9mOHJ2NH:6QX:6QX:6SXZ2
QXZ:RXj:QXJ:RXZ>RXJ:Ti>>RXZ:SY>CRXJ:SXj>RXJ:RXj>RXJ2QXZ>RXZ6OGf6
RXJ2OH:2QXJ6PWf2RXJ6QX:2PXJ6PX:2QXJ6QXJ6RXZ:RXJ:SXj:RXJ6RXj:QX:6
QXJ:QX:2QXZ:RXJ6RXj>RXZ6QXJ:RXJ2PX:2QXImOGf2PX:2PX:2QXJ2PX:6QXJ6
QXZ:RXZ:RXJ:SXZ:QXJ6RXj:RXJ:RXj>SXZ:RY>CSXZ:RXZ>SXZ6QXZ>SXZ6QXJ:
SXZ6PXJ6RXZ2OGf6RXJ2OGf2RXZ2OGf2QXj:PX:2RXj>SXZ6RXjCThj:RXj>SXj>
RXZ:SXj>RXZ:QXZ>RXZ6QXJ:RXZ6PX:2RXZ6PWemPXJ6OGUiOH:6PWeiOH::RXZ6
PX:6RXj>QXJ2QXjCSXYmOHJ>SXJ2PX:>Thj6PX::Thj6OGf2RXZ6PWemQXZ6PWem
PXJ:RXJ2PX:6RXj:QXJ6QXZ>SXZ6QXZ>SXj>RXJ6RXjCSXZ6QXZ>SXj:QXJ:RXZ:
QXJ6QXJ6QX:2PX:6QXJ2PXJ6QXZ:RXJ6QXZ>RXZ:RXJ:RXj>RXZ:RXj:SXj:RXZ:
RXj:RXJ6QXZ6QXJ6QXJ6QXJ2PX:6PXJ2PX:6QXZ:QXJ6QXZ:RXj:QXJ:SXj:RXZ:
SXZ>RXZ>SXj:RXZ:RXZ:QXJ6RXJ6QX:2QXJ6PX:2PXJ6QX:2PX:6RXJ6QXJ6RXj:
RXJ6RXZ:RXZ:RXZ:SXj:RXZ:RXj:RXZ6QXJ:RXZ6QXJ6QXJ6PX:2PXJ2PX:2PXJ6
QXJ6QXJ:QXZ:RXZ:RXJ:RXZ:RXZ6RXZ>SXj6QXJ:RXZ:QXJ6RXZ:QXJ6QXJ6QXJ2
QX:2PX:2QXJ6QXJ6QXZ:RXZ6QXJ:RXZ6PXJ6RXZ:QXJ6RXZ:RXZ6QXZ:RXZ6QXJ6
RXJ6PX:2PXJ6QX:2QXJ6QXJ6RXZ:RXZ6RXZ:QXJ6QXJ6QXJ6QXZ:QXZ:RXZ:RXJ:
RXj:QXJ6RXj:QX:2QXZ:QX:2QXZ>SXZ6RXj>SXj:QXZ:RXZ6QX:6QXJ6PX:6QXZ:
QX:6QXZ>RXJ2QXZ>RXImOGf6SXZ6PWf2RXj>RXJ6RXjCSXZ6QXZ>SXZ6QXJ6QXJ6
PX:2PXJ6PX:2QXZ6QX:6RXZ6QX:6RXj:PX:2QXZ:QX:2QXjCSXZ6RXZ>Thj:QXJ:
SXZ6PWf2QXZ6OGUmPXj:PWUiPXZ>QWeiPXZ:SXZ2OGf:SXj6OGf6SY>>QX:6SYNG
ThZ6RXjCThZ2PXJ:SXImNH::SXYmNGf6SXYmMGV6SXZ2NGV2RXj:OGf2RXj>QX:2
RYNGThZ6RY>GUi>6QXZ>Thj6PWf6RXZ6PWf2RXZ:PWemQXZ6QX9mOH::RX9mOHJ:
RXJ2PXJ>Thj:QXZ>UiNCSXZ:SY>CSXZ6QXZ:RXJ2OH::RXJ2OGf6RXJ2OGf2QXJ2
NGV2QXZ6PWf2QXZ:RXJ6RY>CTi>>SY>CTi>>SXZ:RXZ:RXJ6QXJ:QXJ2PX:6QXJ2
OGemQXJ2OGemPX:2PWemPXJ6QXJ6QXZ:SXj>ThjCSXjCTi>>RXZ>SXj:QXJ6QXZ:
QX:2QXJ6QX9mPX:6PX9mOGf2QXJ2OGf2QXZ6PX:6RXj>SXZ:SY>CTi>>SXj>SXj>
RXZ:RXZ:RXJ6QXJ6QXJ6QX:2PX:6QX:2OGf2PX:2OH:2QXJ6QX:6RXZ>SXZ:SY>C
Thj>SY>CSXZ:RXZ:RXJ6PXJ6RXJ6PX:2QXJ2PWf2PX:2PWemPX:2PX:2PX:6QXJ6
QXj>SXj:SY>GThj>SXjCThj:RXZ:RXj:QXJ6QXJ6QX:2PX:2PX:2PX:2PX:2PX:2
PX:2PX:2PX:6RXZ:RXZ:SXjCThj>SY>CThj:QXZ>SXj6PX:6RXZ6PX:6QXZ6PWf2
QXJ2OGemPX:2OGf2PXJ6PX:2QXZ:RXJ:SXjCTi>>SXj>TiNCSXZ:SY>>RX:2RXZ:
QX:2PXZ:QWemQXZ:PWemQXZ6OGUiPXZ:PWeiPXZCSXJ2QXjGUi>:QXZCUiN>RXZ>
Ti>>QX:6RXj:PWf2RXj:PWf2RXZ6OGUmQXZ6OGEiQXZ:OGEiQXJ>SXImNH:>Ui>:
PXJ>UiN>RXJ:TiNCRX:2RXj>QWemQXj:PWemQXj:PWUiQXZ6OGEiQXj:OGEiQXj>
PWUiPXjCSX9mPXjGUhj6PXZGVi>6OH:>Ti>6NGf:Ti>6NGV6Thj2NGV6SXj2NGUi
PXj>QWeiPXjCRWeiOHjCThj2PXjGViN>RXZCVi^CRXJ:TiNCRXJ6SY>>QX:6RXj:
QWf2QXZ:PWemQXZ6PWemQXJ:QX9mQXZ>RXZ6QXZ>SXj>RXZ:SXj>RXJ6RXj:RXJ6
QXZ:QX:2PXJ6QXImOGf2QXJ2NGUmQXJ2OGUmQXZ:QX:2QXjCSXZ6QXZ>Thj:QXZ>
SXj:QXJ:SXj:QXJ6RXZ6PX:2QXJ6PWemPXJ2OGUmPX:6PWf2PXZ:RXJ6RXj:RXZ:
SXj>RXZ:RXj>QXJ:RXj>RXJ6RXZ>SXZ6PX:6RXJ2PX:2PXJ2PX:2PX:2QXJ6QXZ:
RXZ:SXj>SXZ:RXj>SXZ6RXj>SXZ:QXZ>SXZ:RXZ:RXZ6QXJ:QXJ2PX:6QXJ2OH:6
QXJ6QXJ:SXj:RXZ:SY>>RXZ:RXj>RXJ6RXj:RXJ6QXJ:SXZ6QXJ:RXJ2PX:6QXJ2
OGf2PX:2OGemPXJ6PX:2QXJ:RXJ6QXZ:RXJ6QXJ6QXJ6QXJ6QXZ6QXJ6QXJ6QXJ6
QXJ6QXJ6QXJ6PX:6QX:2PX:6QXJ6QXJ:RXj:QXZ:SXj>RXZ:RXj>SXZ:QXZ:SXZ6
QXZ>SXZ:RXZ>SXZ:QXJ:RXZ6PX:6RXZ6PX:2RXZ:QX:2QXj>RXJ6RXj>SXZ6QXZ>
SXZ6QXJ:SXZ6QXZ>SXj:QXJ6RXj6QXJ6RXZ:QX:2QXJ6QX:2PXJ:QXJ2QXJ6RXJ6
QXJ6RXZ:QXJ6QXZ6QXJ6QXJ6QXJ6QXJ6QXJ6QXZ6QXJ6QXJ6QXJ6QXJ2PX:6PX:2
PXJ6QXZ6RXZ:RXZ:RXZ:RXZ:RXJ6PXJ6QXJ2QXJ:RXZ:QXZ>SXZ:RXZ:SXZ6PX:6
QXJ2OH:2RXJ6QXJ6RXjCThj>SXj>RXZ:QXJ2QX:2PX:2QX:6RXZ:SXj:RXZ>SXj:
QX:6QXImNGUmPXJ2OHJ:RXjCSXj>Ui>>Thj6RXJ2OH9mOGV2PWV6SXJ6RXj:SYN>
QXj>QXJ6NGEmOGeeOGeeQXj6QXj>ThZCVi>>Uhj6RXj2NH:2NGf:OGV6SXZ>Ti>>
Ui^CThj6PXZ2NGUmLGF:OGV6QXZCTi>CTi>PUhj:QXJ2PXJ6LGf>OH:CRXZGUi^K
Ti^GRXj:OGeeMHI/LHIeMHZ6PY>>Vi^>Vi>6RXYeMGUaNGeTRX9/QY^:SZRKUj2X
Vi>CQWUmOH9aI89eLHj>OHZGTiNKVhj6PX9iMGF2Ffb>K6b>RWfGVi^GUj2GRXZ6
NGVCOFBGQVbCY8JGVj2PTi^PPWF:MFB:NE>6QW66VhJKUi^/SXJKQXITOGUGPVQG
Th9eVjRC]JB/]I^KY89aQVAaSTYiTfQm]INK/J2aViNGSVaaK5>:CTZCK62K[8jK
Y;6CSYN:MFaeI8IGDjB2I:BmX9^i^JB:SY]aFg5ePT9XZ7EK[<:>R[FaPWf6RU]:
J8J6H36CZ5]aa/9iR/JTH8:GNDYKOI=2J<:KK:SX/H:XbXiGQY]C=GVTCTJa/Gf:
dlj:P[VGEe^6J2QGX6@mX;V>Tl;>Y7FTY616OGD/K:QKNKFeY<k>`ZR6UgeXEfa6
AYM/J;G2Vjc/_J2CThi/FdYCDc5mJ5^Kb[FPk=NGQXimDdi6Ed9eJ7Fea[g2om>P
X8ieI4Y2FfAXH8k6^JSTlJaiQXI/?CETFe]>RZb//M?GQXiiK7EK;5>:Fe>XejR2
b/I/I:B>FfAeThj6TljeK9^TFf2:J6QPOHJCTkFm]H:>Ve<eEfA2BW6XX8ZmoKEm
[6`a@TXiFeM/[;W6nO6K_I]6CU/e?E=iRZ3KnN2i_HYKFe<e<DIXOHk:lMNm^GeP
K5Le=CePRYN/lM>K/H9GMFPiCW66TjSPk<jeUfaTJ4i>@TYXSZR/i?o>[8iPH6@m
<D9KRY^alO72X7EPNF@X=EMXQYO6i=>eSVQiSVA:Fg6:[:S>fkfKFdZ2SU=:K8JK
[<KP`ZA/?EN:K49:J:2m/LK2Z8Y6=G5iEdiXS[6ib/JeVeL/J9=eI6a/P[7:a]>e
Tf@e>H::LFAaX<[Pej26Fb`eLGE/LH:/_LK:Z9=P;21>LGEiRZC>i>C6RU/X85=e
MHjKZ<KPi;VTJ0hGAVQiMGfPh?gXh8He6b0mJ61/Vl;Kh=^TY7T>4cUKI75iZ?7o
k=^>ST8/<CEPMGfC`^CTfjbXN@h6?FQiQWfGlOoeaV@X82A:LFb2X;gGmN2KQT80
6f1ePXj2]OoonJ@e4bQ2J6QTVl;KlOViQWTK0SEPJ8:KX>3ooliX80h/BVAPOK7G
k>cKVh9601M2I7VP]LKooofP=@X:=GEeMFbTeo7moK5XH0X0<F1eTjR/lOooaTH0
01]GPWF2/M_oonB2BPH085MeSZRei?oooH820012QX9mZ=OooonKCQ<03UMPMINa
i?oomHhT000/J7EiUlKioonXDaL01TYKMIN/i?oooi/e=@0096QmPZC6nOoocVPP
0012H6R:Y<kooon/AP004e=XK8jai?ooeg4X000mFfR2Ul;oooo6H0004eMiQYNa
i?oooI<i000aH766Uk7mooo:I0001TIXLHJPdooooI<i000aFg62TjSeooooegTC
00I:LHJGZ<[ooonaE`00861mRYNPi?ooi7TC0012MH:6TkGooon/AP006fAmQXZG
eoook7dC0012OHj:UkGmooniD`006fB2RXjCb_oonI<K000aJ8j6RZ3KoooKK0H0
04Z2Ti>CSZceooneBP0086RCX9N>`_oooi<K0012SZRKQY?PoooCJ0002U>CX8Ym
X?GookdT000GOK6PRWfeoooiRQ<004J>]JR2P/[oooUX0000J<;:Y7V6fooocTH0
021i_Kf6I9?Xoon/2P0002RPdkF:I9OiooVC1P00CZCK^GE//Oooog40001XdnBe
NFbioooPH0003WGGfi]TLL;oolha000GUnCCVf1ab_oo^C4002bGi=>CI7W6oone
9000=KGai:QTK<Kool8a000eX?7TUf1//K7ooj`X000a[>cPVf1//OGi/B`003fT
h=>PMGFamOfa?@00?JCXj;EeK:CPlLIC000XP]O/^H9PNL;acV`600iec_7CQU]/
Z=_GRR002U^mk=NKJ6RTi>BK?@0:I;Wak:aaI8[2fkeG3PX:=HkKi;eiEfB/i<Z2
900KMLKacWe6Ei?>h:0e1Q=K_NcGTe=GTnSi^EL:1U>Xk>BTH4Ymb_7GNAL6<H;>
h;EaBV2XlNBP@P0>Fk7KaWe6CXkGmLIP5a=6VmOCVf1CP]Ooj9Lm3Rae^M?C]GUC
J:STmLY/:1/mQ[fiTfAKNL;XfjA>3Q]>R[F/OF1XTlk/dhY2835/Z;FTPVb2^Nca
bW4X849i/K6CLFb:a^cX[5/T84ImY:B6J76GdnSCRST>95>>Z9MiJ7feh>c6OCdT
?FRCX9>6QX:Ga^3G[6Pe<DI/RYNCRXZK]L[:Z7E2;3EKPYNGQX:G^L[:X60/;49/
UjRGQWfC]M?G^H9>=CePQY^PSXJG^Lk>/GU:@TYXRZ2GQWV:Z<[G^HIC=CeKOHZ:
OGVG_Lk>]GeCBU=TOHj6PX:2UkGCelJKK4Y6DfQiPX:6Vkg:c/:KK5]>Df1/MGf6
Tjbmb/JaQU/m>DIPMHJ:SZRmb]>mSVQCAU=TMHJ>SZBib]?:Y7E:>CUCK8:>SY^a
`/k>[7UG?CU:FfamQY>/`/[:^HiTASDmCVQXOHZC[<;CelZPME<m@U=PMHJ>X;W>
elZ/OEM2?DYKK7f:VkG:dljaRV16>D9GK7f:UjBib/k2Vg5>@T9CJ7F6UjC2dmO:
[89PBTI6EfQiTjBa_L:m]JB2I4i2AUM/QYNX]Kfm]JB6J5=>CTiKK7f>X:ba]KVa
Vh9XBTICJ8:CVi^T/Kg2_J1mFdI2CV1aQYNT/KFa/JRTTgUPCTY>H76>X;6eZ8im
LFQaPXZ>SX:2RYNPZ9^2J5=:Efb2Vk6e/K6PUi>CSXj2K61CCU=PK8ZT/KfmZ:RG
Th9mOGEeOH9mPX9iNGE/NGf6TjBPY:2GUi^KX:2CPWEXEeMKH7F:Vk6m]KF/VhZ6
NGf6QX9iK6AaMGV2PXZKY:2PSX:2RXjGX9^>RWEXK6a/NHJ:VjbX[:RGRX9iOHZ>
RXYiK7V6OH:2QX::TiN>SXJ2PWeiQY>GVi=iJ7EmOH9mOHJCX:2KSX9mOH:6SY>G
Ui>2MH:6RXZ:QX:6RXZ2NGEeOHZ>SXjCUi>2MH:2QXZ2NGUmQXj:PWUmPXjCSXjC
Ui^GSXj>RXZ6NGEiOHJ6OGUmOHJ>SXj6RY>GSXJ2PXJ6PWeiOHZ6PWUeNH::RXJ6
QY>KViN>RXjCThj6OH:6QX:2PXJ:SXJ2PXJ>SXj6QXJ>SXZ2OH:6QWeiNGf6QWem
NH::SXj>RXjCTi>:QXJ>SXj:QXJ:RXj:PWf2PXZ:QXJ6RXj>RX9mPXJ:QX9mOHJ6
PWemPXJ6PWemPXZ:RXZ6RXjCTi>CThjCSXj:RXJ6QXJ6QXJ:RXZ:RXZ>RXZ6PXJ:
RXZ6PX:6RXJ2OGUmPXJ6PX:6SY>CSXj:SY>CThj>SXj>SXj:QXJ6QXJ6QX:2RXj>
SXJ6QXZ:RX9mPXJ6QWeiNH:2QX9mOH::RXj:QXZ:Ti>CSXZ:SY>CSXJ6QXZ>SXJ2
PXJ:RXZ6PXJ:SXJ2NGf2QXJ2OGf2QXJ2NGV2QXZ6OGUmQXj>RXJ2RY>KUhj:QXZ:
SYNCRX9mQXj>RX9iOHJ>SXImOHJ>SXImNH::RXImNGf6RXJ2OGf6RXZ:PX:6SXjC
Thj>SY>>SXj>RXZ:SXj:RXZ6QXZ:RXJ2PXJ:QX:2PXJ:QXJ2OH:6RXJ2PX:6SXj:
QX:6RXj:RXJ6QXZ>Ti>>SXj>SXj>RXZ:RXZ:RXZ:RXJ6PX:2PX9mOGf2PX:2PX:6
QXJ6QX:2QXZ:RXZ6RXZ>SXZ:RXZ:RXZ:RXZ:RXj>RXZ:RXZ:RXJ6RXJ6QXJ6QXJ2
OGemPX:2PX:2PXJ6QXJ6QXJ:RXZ>RXZ:SY>CSXZ:RXj>RXJ6QXJ6QXJ6QXJ6RXZ:
QXJ6QXJ6QX:6PX:2PX:2PWemPX:2PX:2QXZ:RXJ6RY>CSXZ:SY>>SXZ6RXj>RXJ2
QXZ:RXJ2PXZ:RXJ2PXJ:RXJ2OH:6RXJ2OH:6RXZ:QX:2QXZ:RXZ:RXjCSXj:RXj>
SXZ6QXZ:RXZ6QXJ6QXJ6QXJ6QXJ6QX:2PX:2QX:2PWf2QXJ6PWf2PXZ:QXJ6QXZ>
SXZ:SXj>RXJ:RXZ:QXJ6QXJ:QX:6QXJ:RXZ6QXJ6RXJ6PWf2RXZ6QX9mPXZ:RX:2
QXZ>SXZ6RXjCThj>SXj>SXj:RXZ:RXZ:QXJ:RXZ6PXJ:SXj6PX::SXj2OH::Thj2
NGf:Thj6OGf:Ti>>PXJ:TiNCRXJ:TiNCRX:6RXj>QWf2RXj:PWf2RXj6OGUmRXj6
NGUeOHZ>QWUeOHZ>RWeeOHZ>SX9mPXZCSXJ6QXj>SXJ2QXZ>RX9mOHJ:QWeiNH:>
RX9iNHJ:RX9iNHJ>RWeeNHJ>RWeiOHZCSXImPXZCUhj6QXjCUhj6QXZ>Thj6PXJ:
SXZ2OHJ:RXJ2PX:6SXZ2OH::SXJ2OH::SXYmOH::SXZ6PXZCThj:RXjGUi>>RXZC
Ui>:PXJ>Thj6OGf:Thj6OGf:Thj2NGf:ThYmMGf:ThYmMGf:Thj2OGf:TiN>QXJ:
UiNCRXJ:TiNCRX:6RXj>QWemQXZ:SXImOH::RXImNGf6QX9mOGf2QX:2OGf2QXZ6
QXJ6RXjCThj:RXjCTi>:RXZ>SXj:QXJ6RXj6QX:6RXZ6PX:6RXZ2OGf2QXJ2OGf2
QXJ2OGf2QXZ:RXJ6RXZ>SY>>RXZ:SY>CRXJ6QXZ>SXZ6PX::RXJ6PX:6QXJ2PX:2
PX9mOGf2PXJ2OGf2QXJ6QXJ6RXZ:SXj>SXj:RXjCSXZ6QXZ>SXJ2PXJ:RXJ2PXJ:
RXJ2PX:6RXImOGf2QXJ2OGf2QXJ2PX:6RXZ>RXZ:SY>>SXj>SXj>SXj>SXj:RXZ:
RXZ:RXJ6QXZ:RXJ6QXJ6QXJ2PX:2QXJ6PX:6QXJ6QXZ:RXZ:SXj>SXj>Ti>CSXj:
RXj>RXZ:RXZ6QXJ:RXZ6QXJ6QXJ6PX:2PX:2PX:2PX:2PX:2PX:6QXJ6QXZ:SXj>
SXj>SXj:RXZ:RXZ6QXJ6QXZ6PX:6QXJ6QX:2PX:2PX9mOGf2PX9mOH:2PX9mOH:6
RXJ6QXJ:SXj:RXZ>SXj:RXZ:SXj:QX:6QXZ:QX:2QXZ:QX:2QXJ6QX:2QXJ6PX:6
QXJ2PXJ6QXJ2QXZ>SXZ:QXZ>Ti>>SXZ>Ti>>RXZ:SXj:QX:6Ti>>PWf6SYN>OGV2
SYN>OGF2SY>:OGV2SY>:OGV2SY>>PWf6Ti^CRX:6Ti^GRX:6TiNCQWf2SYN:PWf6
SY>6OGV6Thj2NGf6ThYmMGf6SXIiMGEiQXj:OGEmRY>>QWf2RY>CRX:2RXj>QX:2
QXj>PWemRXj:PWemRXj:OGV2RXZ2NGV2RXZ2MGV2RXJ2NGV6RXZ6PX::SY>:QXJ:
Ti>>QXJ:SXj:QXJ:SXj6PXJ:ThZ6PXJ>SXJ2PXJ>SXJ6OGf6SXj6OGf6SXj:PWf6
Ti>>RXJ:SY>CRXZ:SXj>RXJ:SXj>RXJ6SXj:QXJ6SXj6PX::Thj6QWf2RXj2K75e
OHImNH:6RXjCSXjKY:2GThZCUi>>PWUePXImMGEeNHJ6NG5mRYNXTgUiOINCThZ:
PXZ:QXJ6SXj>RWeeNH:2OGeeNHJ>SX9mOGUiPWV:QW5aPY>>TjBGUk6XPWf>QWFX
bX9/X:QmNHYmRYMaJ8jCNHZGJ6R6RX9mPWf:SYN>NGf2QX:6Y6aGPXJ2LI^GK9^m
Y7F2PX9PMI?PUfbX[:B>Z7em^F`mEi=PDkFiK5NKVh:X/GUmZ6aGUiM>FnB/AWFP
PVS>[4j6X7EC^FQ6h;UP>KFTMLJTK5^XH3VGI:S2UfaadkF/QV1>I9=>CY>mPXKG
QXK2Y4iaUg72_F0XH612EmOPLFC/fj2PX7eaD`XaK9>CUkWGfmO2I1LaJ4YKUhj>
do6CSXhmDg5>H:bP/NS6SW5C@X9e=GW:[:3ej7eGATYXDa^>ojbeoiL>MHH0Ei]i
X?oPRZa/02cmX0im`ZCPi89iRPh>RYNGNI>mfoGTJ2@T1S5mOI_aoo7Gh74001<X
BZSKh?ooedhC000m01OKooooonam0000?CEGnOoooolC0200035Kb_oooooo6`00
02aXUogoooo/CP000012R]OooooobP00000TOKgooooookT0000098[GoooooKEK
0000:77>h?oooj@i0002:6C:ooooojPC0000<H[2j?oomIL/000:;8kaoooooe<0
000:FkGaoooo[6`>000eLKGooooofb0000HeQ^Soooo6Db0001MX]OoooOgoi340
00I6Q]?oooo:AP00021T^OoooonT;000076C]OoooliG0006;7F/mOoooi/20082
FkG2j?oo/B`000YTUkGeooo>80066djPelkKnOne2P0>?GgCdlK>cVaTLB`aX:1i
[:AeZ:RXAW76UdiC?DZemO7PSTI>I4IXUiN>_L[>fhhT5dYXUlkGdhXmAWUT/MMG
NKea@Y>:J8jTZ=NC90XmEjcmj>BeJ0X::6SClMNGP_oK0P0iI9_ok:Baof00061a
eoGCVe]m[7D6=I_Cc]>>SU/eCU]mQU^iomLC;61aa[UaP[UmDfbP`YMiEi^iVgFC
NGf/Y7VCSP8eToooSSdPOG5PZ9OGaXHT97VGZ9?CdgETEeMCMHj/nJ2:aV@C1Vb>
k?niSU=C;5^PQ[feVgEimJ@0AXjKY>2PX61XBU^CUfBiojP6;7EG^M>KSW5/K9_T
K5>:Z75aZ8JXOKGmQSDmEa^CooomJ080AWW6mNb2A/K26`Y6/LKiddh0CZbmRX:a
Tge/EdIi/JAac^a/@WePBW76`/J2El[2921eSXk6aWemY:BPEdYaRXYaRY=mOLk:
I3eCPZ2>I4jeY6SGdf1:@UM:I>c>lOUe:00/Vkg:[:cafb@06hZek?fG3RRGY9^T
aX9aLE=GEj3:X9?TecDC;3ei_OoTPWFmK00:Uoo2/NbPEbA>TjBK[>2mH34a<FbP
S_7oY3dG83UX`^c/Z?62000iUgW:lOom2P00OI_PoJ1>J?m602bKolK/i60006Ce
djCoh0i203U/`_oXVgF6F`00P_ooj:AT@R@T?KWij=Ma91M:J8Jaa_oaD`0KNJbm
`Zb6I7WoohhGEgUeUm?2j5^2H362K:b6K6com@063ZS6k?G6001XQ^S2VkEaEcT/
MLZah?6:AR`iEgg:on2>Y600>JSClHiaUf@a@ZCobV1eCV1TK;g2RXJKY5/eDhZG
RY^CI7WGVceiOI=aDhJ/X:2anG5PBUN2Tgf6b_oo?@0KC[GT_JRik4h04h;>oOn/
6`0eS/;oj3UXH3UPI9>efh[>Y2a>@VRK]M_PY9=/84IP_NbP_JQC?C5Gi?nXEdie
`Y<aNG5iUe_oob`05fRG]KG:^On:00Ii^JBTVnc>^IL>1VBTk=^TLHko?@12ON3/
i==C02R/]N3oVdiC075mFlkoY:RK=A<mVkG6[;VG5dJTVi>KMI>COJB6Fh;2Z:B2
K7VCLFBCX89PUoVm<DiPEf2:h<::aY/a94IeQVS2ool/001CDk7momL/0?mm089/
dmNPaY/02[fieonT5d8aLM>2S/iiH=^C<EMTP/JTQ/9C88;2`WemLG6:Fi^iPV2G
diMGK75/SWfa/ENToGE6QVR:OFRmaVbPcVaeI4J>AVSmom<200jK`^3PU`himOFT
H61Pdi^KY7d::;VmZ?na3X8eFli/VoUa>OVGH7T6LN2iX<:6RV@0Fkg6bY]aNELm
Dh[/oi<iH5MKaXjPRR22K=?oF`iKDf2>Um^iFogm3P0XLHZXooo:000XNN3Xolh2
05_Xi6AiPX:KViMKFcF2j8jTfiMP>AMeUjC6oli6E`1>X9_2h9=KQ[Ui5gVaa[VG
X7dT=I>CVogoCPIPEfb:Q_W>ATko^@XK89_Cfooa92@a4kWP]K5TFiOaEbaaTm>a
SYMm5e>GUl;ocTIeBRQmQYNGi8iioK4a1PIa]NSGom/00PIefm?aoe<0:4;omCfm
RVR>NG6XDe>/Uh[Xoc56LB2GQZ3XTc7KodXe04ZaY>Ceob@0;2C2`[7mTa]:c[Te
OH:a^I^6SSd:QW6aooma84XXJ9^GmLI2P^bKVf@P=HjGX;go^C4X2Wf:Tm?PSUMK
_H8eNG76aZRaLA/PFh;6^Onm<F00AYNCh<:CQ]?TAP80PXkCk?oo0PH:C[FXenaa
<EO>Y35aMM>KTk5mCQLmML;2olhXL@hTMI?PY6R:oNa>3PiGBTZTj?ooK0X0?E^:
h>bKFgWoRPY6A[fe]L[2:0I>K?oePZB6J2PTH<;>OOoKUh80:5=aY=?ooj@X4a<a
LJcXfm?GcSD04g6:/NcKPWU/OI=XFh:iX7UXTi^PQXJeRUMPJ5]i/M?oZ756CSdm
FjBmY8:ab_56AU]PI5^>b]O6h6QaEb16K:2:`/KoZ6Q>:3DaY;VGek7/`R@aAVPm
Z9O2fi?PUiLa;3ECUfcXooneH5<P;36:^I?:fn3>@RA2BRRC/IOG_NBXNCTe83F>
LLKemN22CSd/;1]T[8JTlN3X/DY2?@9CVgWCi>SoY4Ha5a=CLJ3aooFiSWDT03Ei
UgVTooo:NFa>1P1PVi?Pi<[/]ELa82AXK7WGk>3:/K5X01MPLFRKfoom[8j2908/
FhJedn3G^I>2Db@aJ6Qa_K76c/j/^HY2>CDmLI>ac[Fea[ei@U=C@U^6Z;W6_M_:
J4I2<DYPR[VmY=?CUi=>AU=2H7UiVlk2h<ZKK34a?Di/QZ36i=NiY9<e4dYTH6bT
c]>/[<JPBR1GK61aQ[W:/I>e^FaGBV2:J7fXZ9NGRXZXUfAmMG6KPX9mOHJ2PZ2a
SY=mNJ1aJ7EiRW5i[;fKQY^6NG5aNGEeRZ2P]JRCUfQePU]iQXJ>RY^eY8J:MFAe
NHJ:OHjKSY^TQWeiI9N>LHYiQXj6TjBGOGf2RXYTQYN6QXJPZ9^KRXZCMFb6OHJ:
MHZCTjBKRXITLHIaQXj2RYNCViN2OG5aOHJ:PXimOHj:QXj:QXYeQY>6QWf>QWfG
TiNKSXJ:NHJCOGf:OGfCUi^PQWf2NGf2LH:2PYNGViN6OGUmOGEmPWf:RYNKSXZ2
PWf2PXZ>RXJ>SY>CSXZ6PX::SXj>RXJ2PXj6SXj6QXJ6SXZ6QWEePXJCUhj2PWf:
RXJ2OGV2QY>CRY>:QXj2QXZ>RXZ:RY>CThj6OGV6RXjCSXZ:RXJ>RXImNGemRXZ6
RX:2QXj:SXYmNGUmOHZ2QXYmPXZ:SXj6QX9mQXZCSXjCRXZ:RXZ:QWemPXJ6Thj6
PX::RXZ6PX9mQXjCRXImOH:2PXYmOH:2QXZ>RXZ6PXJ2RXZ:QXJ6RY>:Thj6QX:6
RXJ:SXZ2PXZ>Thj6OH:2RXj:RXJ6QXJ6RXJ2QWf2QXJ>SXZ2PWf6RXj>QXZ6PXjC
QXj>QXZ:RXZ>RXZ:QXZ:RXZ:PXZ6RXj:QXJ2PXJ:RXJ6PWf:QXJ2PX9mPXj>QXZ2
PXJ6RXj:PXZ:RXj:RXZ6RXJ6QXZ>RXZ6QXJ:RXZ6QX:2PXZ>QX:2OHJ6SX:2PWf6
RXZ6QXJ2QXJ:QXZ6QXZ:RY>>RXZ6QXZ>RXj6QXZ:SXj:QXJ6PXZ:RXJ6QXJ>QXJ6
OGf2QXj:RXImPXZ>QXZ2OH:6ThZCQXJ6QXj:RXZ6QXZ>RXj:QXJ6QXJ6SXJ:RXJ6
RXJ:PX:2PXZ:QXJ2PXZ6RXJ2PX:2RXj:QXZ2QXZ>SXZ6RXJ>SY>>QXj2RXZ>SXZ6
QXj2RXj6QWf6QXZ:QX9mPXJ>RX9mNH::SXZ2NH:6RXZ:PXJ2QXZ>SXZ:QX::SY>>
RX:2OHZ:SXj:RWf2RXj>PWemPXJ>RX9mOHZ6PXYmPX:6RXJ6PX:2RXZ:QX:6RXZC
SXZ:QXZ>SXZ:QXZ>SY>>RXJ2PXj>RXZ2OHJ>RXJ2NH:6SXj2OGV6QXj6OGeiQXZ>
QX:2PXZ>SXj:QXZ>SY>CRXZ>RXj>RXJ>QXZ>RXZ6PXJ:RXJ6PX:6RXZ6QWV2QXZ6
QX9iQXJ:RX:2OHJ:SXZ6RX::SXj>SXZ:SXj>SXj:QXZ:RXj:QX:6SXZ6PWf2RXj6
QX9mRXZ:QX9iOHJ:QX9mPX::SXJ:RXJ6RXZ>SXj:RXZ>Thj:RXJ:RXj:RXJ6RXZ:
RX:6QXZ:QXJ6QXJ:QX:6PXJ6QXJ2QX:2PX:6RXJ6PXJ6SXj>RXJ6RXjGSXZ6QXZ>
SXj6QXJ:RXZ6QXJ6QXJ6QXJ6QXJ2QXJ6PWf2PXJ6PX:2OGf2QXZ6QX:2QXZ>SXZ6
QXZ>SXj:QXJ6RXZ:QXJ6QXZ:RXJ2QX:6RXJ6QX:2QXJ6QX:2PX:6QXJ2PWf2QXZ>
RX:2QXZ>ThZ:QXJ:Thj>RXJ6RXZ:RXZ6QXJ6RXj:QXJ2PXZ>RXZ2OH:2QXZ:RX9i
OH::SXZ2OGf6SXj:RXJ6RXZ>SXj:QXJ6SXj>RXJ2PXZ:SXZ6PX:6RXj>QX9mPXZ>
SXJ2NH:6SXZ6OGf2QXZ:RX:2PXJ>SXj:QXJ:RXjCSXj6QXJ>SXj>QX:2RY>CRX9m
PXZ>SXj:PWf2QXZ:QX9mPX:6RXJ2OH:2QXZ6QX:6RXZ:RXZ>RXZ:QXZ>SXj:PXJ:
SXj>QWf2QXj>RX9mPXZ>RX9mOHJ:RXJ2OH:6QXJ2PX:2PXJ6QXJ:RXJ6RXZ>SXj:
QXZ:SXj:QXJ6RXZ:RXZ6QXJ6RXZ6QX:2QXZ:QX9mPXJ:RX9mOH::RXImOH::SXj:
QXJ6SY>CSXZ6RXjCSXj:RXZ6RXZ:RXJ6QXJ6QXJ6QX:6QXJ6QXJ2PX:6QXJ2OH:2
QXJ:QX:6RXj>SXj6RXZCThj>PXZ>SXj>RXJ2QXZ>RXJ6PXJ:RXJ6PX::RXJ6OH:2
QXYmPXImQXJ:PXJ6QXj>SXZ:SXJCTi>:RXj6Ti>CSX::QXZ>RXZ2RXj>RXJ:QXJ>
SX:2PXZ6PX:2PWf6RX:2PXJ6QXZ6RXimRY^:PXZ:RXj:RY>GQXZ>QXJ:QYN2LI^:
MHJ2PXZ2PZ22MHYmNH:2UgE/UhI/OH:6SWf6[89aSXYeNI>TLHJTSX:2RZbCOI^a
MG6>OG5XZ7ePY8IiSWFK]Gea`XiKMGeiFiN2EjaiK9^CQ[6XMKVaI89aLG5TVi=:
]I=/UjBa/Hiia[4iMHi>AZAaC[eiJ:RXUj2XRY]eFg5KCVbG@VbeQY>KaZB2Z:BG
FgeXAU]i[5MmaZBPVm?GX7EiZ4hiEdieVdY/el:>UoW/I4JGTbPeBY^>:8[2cZQi
lL9XFe^XQSfGK6BTRX9afl9P[:bPTjR:MJQ:6fB/[5Mmdlj2OKVeUe=6QWU:AVRa
Uf2/j<J6QW5:H61/H8ZCUkfTk;U>LGUP=G5iR/Z6Tm_o]BQKOELC<H:6^HJ2fooo
J3fGLAL0CVQG^J1iooooLFCTI0ieDf2PX;6KaW4>R_6C=K7KSWF>Y8ZCRWFC[7DG
@XITI?oPR/;KX2b2Ed9eK89TPSU/oon>B^CGAR16PXImK8[GaTX0fomK:;GPLDYK
Fm?>PTJGk6@06ooo@W7>dh:2>D:eaWE:BZbK:0HTa_nTLL[TQTY2@W6eZ7FC]GDC
97WooF2aj9MaJ2`XVkf:S[f>920mZ?nmFjBeUfQ296ReUhZTVgE:01_oogUi]I>6
ODXaSZb6PYNXRSD:i?nCH:RXI75P:9O>X7Ee]GT62_ooH61/_HiPMF@PUoVXK8:T
>@0G[?o6Ul:PMF1P:4K:`[6TY7Te6bceohjC^HYXI5<GP^ReUhJPFbP:K?oTOJRC
PVQC:4K>/JbGSWU691OXoi^6/J1iOFPKMM>X/HJXMC40R_o>I9^:NG66>DY:ejBa
PZB>;00moom/Y9]eI89K:;faVhJCY48:<OooPZS2NF1eLBbKaZ2KUk5T80:/ok5e
]HiTJ88aH>2aTfb/J0h2P_oKML:>I61aASg6Y:BG^HXi4a_eoi^K/HYTLG4eP[FK
ThZXH2@20/;oX76iPU=TQSUPaYN:OK5a5`1eomMa]IMGFge6C/ZTPWFmUbP0OOoP
Ek6XEdj2EdJm_HYe[9/e02cooh:>]GE>K6@aP[FCNI>TFaL6`_nGI;6GFfam@Wg:
[7f2aX8G0;Go_FBiX5]PPX8iMNRmJ632PRP0NOoaK;faI3eX?D[CdjAmVh9>4`Zi
ol:6_I]/LG4mK<:e/J2aQU<68?ooNHZaSVAeK3fK/K66NK66:02/ojaPZ9MPH8Xi
I<ZaTfBXTcT0H?omFjBTLENCDcWKcZ1GUk6aAP0GnOn>UjaeFfA/4hkT]I^6Ug4T
02coohj>VhieK3dKQ]>e/Hj>MBP0<OooMGVXX8YPASFG_JbPQZR:6`1Koom>OJbK
OE]2@[WGX75eZ7400;7ocTjKX8YaCRaKi=NGNI>KCP0CmOooVe^i[8IXCRAelM>>
MJ2C>@0Xoon>K<:XNE/e=I?T^IN>VhHe037eoiMX`[F2Dc5>P]NeTi>TUcT0B_oo
MFRmVgUK@TZ/j9=TR[Ee2P1ioom/OJb6K48aC/kPVh::PV@C1W7oogV2]IM/K48/
FjcT[:2>NGTT063oog5T^I=TAT9GVm^aOFbGQQ<0FoooK76eRU]:ATjXi;V2K8im
80I2mOnKI;FXLDi2AXkacZamMHI:5b2Pon1>UkVCFce2H=_GX7E/[74:2X[ooDZ6
]IMaBTICdm?XX75TX8hP3T[oohIXY:RCEcE:]NbaUf2CZ4H01/[o`TJ6_JAP?C5i
ekfCEhK2L@00Tooa@Vbi[6A6=FS:cZ1POLZ>5`16oon>EjS2ODhXCZCG^H9T[;EK
002>ooeCK=NaI34aJ;W>SVATR/jC6`0moon6B[GKRThaCY_P`W5T^KEP00ZTona6
MN2eJ2PeNKgKX6b>/HXT03FmolY2X>BKDb1:P/:mRWfXY7TC04KoohI>fnb6?C5P
Q]_2PX:a[6000VcooeM/mLI/93EKX>BPLHje]I<m00IeoomCP_W2Fa/iI;G>SXjT
_HHi01^Koo5PUon/Db`iK;FiSXJG]Gd/01^TonaGQ_FTEbPaK:beSWfC[7TX02BT
ooE:Q_faH2Q2MKG2Uh:P/H8T03VXooeGOOV/J2PmNJRaOHJP[:b2>@0aS_ooCWGe
/FP/>GVP_H9mUkF6CP92MOooQU_adgd/<H:C[8jGTjb2J1/TDjSoh4jik9]:4fQe
UiNCQZ2XOCd>@WGiogUmoKee94imVk6:OI>eQW4X;5OPoj1Ch>1m=C62MJ2>QWUi
]I]/935CP_o/Ej3/VeLPK6b:ThZ:Z:QeH2a2B[WodeO:djA2>FaaX9>2R[FKQULX
;5_ToiMGb/jG84ITQY=mOINiSVQC;2Q/lOmmH>3GPRA:LHJKSWfabZ1XBR`mMLKo
/FS6j8hT=G5iNH9eS[VmVfA>=C5XR_oeI8kaZ3TTI8YaMI>a`ZQPI60mCW7Pohi/
fl9a;5^6I8jTX:bTPVQKDceKP_ooH77K[4X/J75iVi>:QZR:Fe/m?GVaokdm/N2>
AT:2QY>GLINiVgEPH4IPTn3ooh9Pdl9X;62>QXYaQZRaTe=PH3eeMLkoPVS2]GTi
K9=aNGfPY:2PMFa/CWFCZ?FaH:c6Ue]KSWf2MH:KX:QmI6QTJ89i^NQaOLJ/MD:2
RVaaMJ2CUi]aPWeKH7Eac^AaR/K6MDZCSWUPNGV/TkFGLH9/Fe=mOJCTPWFm^GU:
OHi/FhJaQXjGMFaTFe^2NIO/SWfe/HY:PYMmOGfXRXj/MGV2I4iaRW7:ffAm_Kea
Ei>CLFB:SWFKRW5aK6AXRVa/fl9KNKW:J6RKSWU/RXieY89eMG5aQWf6NF3:i61e
a^1XBZbPJ61iUfRKSW66X7dmFjQXA^B/I9OP`U=m^GUKFiMTLJR2QXJPLE>:Vf1i
i;EK[>2iH7fPOFQePVB2Y7f2RY]KCXJ:I4kKlEMidmMKFjaiH6B2NG6eQW66Z8I6
AW6XSTieojaCZ>RG?INaMFAiTf2:UfAeUjQ>FiNKME>Gi8iGR/j>FhJTPWE/QW62
PW66Y9=/NIN>OGUa/M=eK;gCOENX[7EGRY]/NGV>SXj2LI>6LGUmNJC2Dfc2aVaX
^JQaH9NGI8Y/QXJ>SXZ:Y7UaSXIiNM^6H;G:QVRm_FAiSYMTOGUaSXj6OI>CJ8:6
NENXde]/`[UPJ=>KEfbGRTj2RWf:QXZ2X8iXPY>2EjC>Fg76^E]TeiMGNJBGBX:>
NHImSWf:RVR:OGUPK<iiBZRmODi>^KUTNHjXFf2KOH9aTj1eTh:>K6b>J7FiPVRG
aWeP]KE/K9>eFfBPSVaaZ9MPOHZ6EgFCJ62eTe^CaXIPY;eaNJ2aJ6R/SWF2X8iT
SY>2J8:CMF2>^Fai`Y]XQ[fCLINTTfRCY7f2QXYaLGVCPWUaNGUaOINTJ8ZaRX:C
]IMmUi^POINTPWUmSWeiSXI/K8YmLHJ6X7U//J22RZBPMINTUhZ2VhYiRXZ6J7f:
MGV2PWUXPWfKSVR/TgFGX:R6SZB>TgfPUg62RXIaOI=aK8:2MG6:OGeeQXieSY]m
RXZ:ThJCSXZ2QYN>QXZ:QWV2RX9iOHJ2OH:>QWf2SWeiThZ2QX:6RXZ>ThJ6SXZ>
RXj6QXZ6SXJ6QWf6PXZ:OGf2OH::RWemPXZ6SXj:PXZGSXjCSXZ6Thj6SXZ2OHjC
QXJ6RXImPY>:NGf6PWf:SX9iPXJ:RXj:PX:>SY>>SXZ6SY>CSXj>QXZ>SXj:RX:2
QXZ:PX9mOH:6RX9mOH::RXZ:QX::SY>>RXZ6RXj>QXJ:QXJ6SXj6QX:6QXZ>QX:2
PXJ6RXJ2PX:6RXZ:QXJ6QXZ>RX:2QX:6RXZ2PX:6QXJ:QWemPXZ:QX:2PX:6RXZ:
QXJ6SY>>SXj:RXjCThj6QXJ6RXZ:QX:6RXJ:RXImOHJ6QX:2OGf2QXJ2PX:2PXJ:
RXZ:RXZ>Ti>>SXZ:RXj>RXZ6QXJ6QXZ6QXJ2PX:6QXJ2OGf2QX:2PX:2PXZ6PXJ6
QXJ:RXJ6RXZ>RXj>RXZ>SXj:RXZ:QXZ:QXJ6QXJ6QXJ6PXJ6QXZ:QXJ6QXJ6QXJ6
QXJ6QXJ6QX:6RXZ:RXZ:RXj>SXZ:RXZ:SXZ:QXZ:RXZ:RXJ6QXZ:RXJ:QXJ6QXJ6
QX:6PXJ6PXJ2PX:6QXJ2QXJ6QXZ:RXj>RXZ:SXZ:RXZ:QXZ6QXJ:QXJ:PX:6QXJ6
QX:2PXJ6PX9mOH:2QX:2PX:2PX:6QXJ6QXJ:RXj>SXZ:SXj:RXZ:RXZ:RXZ:QXJ6
QXZ6QXJ6QXJ6QXJ2PX:6QXJ2PX:2QXJ6QX:2QXZ>SXZ6QXZ>Ti>>RXJ:RXj>RXZ6
RXZ>SXj:QXJ:RXj>RXJ6RXJ6QXJ6PXJ6QXJ6QX:6QXJ6QXJ:RXj>RXJ:Thj>SXZ6
RXj>SXZ:RXJ:RXZ:RXJ6RXJ:RXZ:QXJ6PXJ6QX:2OH:6PXJ2OH:2QXJ6PX:6RXZ:
RXZ:RXj:RXj:QXJ6RXJ6QXJ6PXJ:QXJ6QXJ6RXJ6PX:2QX:2QWeiPX:6PWf2PX:6
RXJ6QXJ:RXZ>SXZ:RXZ:SXZ:RXJ6QXZ:RXJ6QXJ:SXj:QXJ6RXZ:QXJ2PXJ6QX:2
PX:2QXZ6QXJ6RXj>SXj>SXj>SY>>SXZ:RXZ:RXZ:RXZ:RXZ:RXj:RXZ:RXZ:QXJ2
QXJ6QX:2OH:2QXJ6QX:2QXZ>SXj:RXZ:SY>>RXJ6QXJ:RXJ2PX:6RXZ:PX:2QXZ:
RX:2PX:6QXJ2OGf2PX:2PX:2PX:2QXJ6RXZ6QXZ:SXZ:RXJ6RXZ6QX:2PXJ6QXJ2
PXJ6RXZ6QX:2QXZ:QX:2PX:6QX:2OH:6QX:2PXJ:RXZ:QXJ:RXj>RXJ6RXj>RXJ2
PXJ>SXZ6PX:6SXj:QX:2RXj>RXJ2PXJ:SXJ2OH:6RXZ6PX:6RXj>SXZ:RXjCThj>
RXZ>SXj:QXJ6RXj:QXJ6RXZ:RXJ6QXZ:RXJ6PXJ6RXJ2OGf2QXZ6PWemOHJ:RXj:
QXJ:SY>CSXZ6RXZ>SXj6PX:6RXZ:QX9mPXZ:RXJ2PX::SXZ6PWf2QXZ6PX9mPXJ6
QXJ6QXJ:RXZ:RXZ:RXj>SXj:RXJ6RXZ6QX:2PXJ6QXJ2PXJ:RXJ2PXJ6RXZ6PX:2
QXJ6PX:2PXJ6QXJ6QXJ6RXj>SXZ:RXj>Thj:QXJ:RXZ:QX:2PXJ6QXJ2PX:6RXJ6
PX:6QXZ6PX:2QXJ6QX:2PXJ6QXJ6QXJ:RXZ:RXZ>RXZ:RXZ:RXZ6QXJ6QXJ2PXJ6
QXJ6QXJ6QXJ6QXZ6RXZ6QXJ6QXZ:RXJ2PXJ6RXj:RXJ6RY>CSXj:QXjCThj:QXJ6
RXZ:RXJ2PXJ:SXZ6PX:6SXj:QX:2QXZ:RX:2PXJ:RXZ6PXJ6RXj:RXJ:RXj>SXZ:
RXZ:RXZ:RXJ6QXJ6QXJ6PX:6QXJ6QXJ6QXJ6QXJ6QXJ6PX:2PXJ6PX:6PXJ6QXZ6
QXJ6RXj>RXZ6RXZ>SXj:QX:2QXZ:QX9mPXJ:RXJ2OH::SXZ2OGf:SXZ2NGV2RXZ6
OGUmQXZ:RX:2PXZ>SXZ6QXZ:SXj:QX:6RXZ:PX:2QXJ6QX:6RXZ:RXJ2QXZ:RXZ2
PX:6RXZ6PX:2RXj:QX:6RXjCSXZ:RXjCTi>>QXZ:SXj>RX:2RXZ>RXJ6QXj>SXZ6
QXJ:RXJ2PXJ:RXJ2PXJ6RXZ6QXJ6RXj>SXZ:RXj>SXj:QXZ:RXZ6QX:6QXJ:QXJ6
QXJ6QXJ6QXJ2PX:2QXJ6PWemPXJ:QWemOHJ:SXZ6PXJ:Ti>>RXJ:SXj>RXJ2PXJ:
QXJ2OHJ6RXJ6PX:6RXZ6PX:2QXJ6OGf2QXJ6PX:2QXZ:RXZ:RXj>Ti>>SXj>SXj>
SXZ6QXJ:RXZ6PXJ:RXZ:PX:2QXZ:RXJ2PXJ6RXImOH:6QXZ6PX:2RXj>SXZ:RY>C
Ui>>RXZ>SXj:RXZ6QXJ:RXZ6QX:6RXZ:QX:2QXJ:QX9mOH:6QX:2OH:2QXJ2PXJ6
RXZ:RXj>SXj>RXj>SXZ:QXJ6QXJ6PXJ6QXX\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]],

Cell["\<\
Click on the sound plot above to hear the speech signal.\
\>", \
"Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize wav file", "Subsubsection"],

Cell["Normalize wav sound file.", "Text"],

Cell[BoxData[{
    \(\(normalized1\  = \ wav1/\((2. ^15)\);\)\), "\[IndentingNewLine]", 
    \(\(sound1 = FixTime[normalized1, sampleRate1];\)\)}], "Input"],

Cell["Plot entire wav sound file.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[sound1, PlotRange \[Rule] All, \ 
        PlotStyle \[Rule] Blue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0237872 0.24845 0.298276 0.549936 [
[.02379 -0.0125 -3 -9 ]
[.02379 -0.0125 3 0 ]
[.27224 -0.0125 -3 -9 ]
[.27224 -0.0125 3 0 ]
[.52069 -0.0125 -3 -9 ]
[.52069 -0.0125 3 0 ]
[.76914 -0.0125 -3 -9 ]
[.76914 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0783 -24 -4.5 ]
[-0.0125 .0783 0 4.5 ]
[-0.0125 .18829 -24 -4.5 ]
[-0.0125 .18829 0 4.5 ]
[-0.0125 .29828 -6 -4.5 ]
[-0.0125 .29828 0 4.5 ]
[-0.0125 .40826 -18 -4.5 ]
[-0.0125 .40826 0 4.5 ]
[-0.0125 .51825 -18 -4.5 ]
[-0.0125 .51825 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02379 0 m
.02379 .00625 L
s
[(0)] .02379 -0.0125 0 1 Mshowa
.27224 0 m
.27224 .00625 L
s
[(1)] .27224 -0.0125 0 1 Mshowa
.52069 0 m
.52069 .00625 L
s
[(2)] .52069 -0.0125 0 1 Mshowa
.76914 0 m
.76914 .00625 L
s
[(3)] .76914 -0.0125 0 1 Mshowa
.125 Mabswid
.07348 0 m
.07348 .00375 L
s
.12317 0 m
.12317 .00375 L
s
.17286 0 m
.17286 .00375 L
s
.22255 0 m
.22255 .00375 L
s
.32193 0 m
.32193 .00375 L
s
.37162 0 m
.37162 .00375 L
s
.42131 0 m
.42131 .00375 L
s
.471 0 m
.471 .00375 L
s
.57038 0 m
.57038 .00375 L
s
.62007 0 m
.62007 .00375 L
s
.66976 0 m
.66976 .00375 L
s
.71945 0 m
.71945 .00375 L
s
.81883 0 m
.81883 .00375 L
s
.86852 0 m
.86852 .00375 L
s
.91821 0 m
.91821 .00375 L
s
.9679 0 m
.9679 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0783 m
.00625 .0783 L
s
[(-0.4)] -0.0125 .0783 1 0 Mshowa
0 .18829 m
.00625 .18829 L
s
[(-0.2)] -0.0125 .18829 1 0 Mshowa
0 .29828 m
.00625 .29828 L
s
[(0)] -0.0125 .29828 1 0 Mshowa
0 .40826 m
.00625 .40826 L
s
[(0.2)] -0.0125 .40826 1 0 Mshowa
0 .51825 m
.00625 .51825 L
s
[(0.4)] -0.0125 .51825 1 0 Mshowa
.125 Mabswid
0 .1058 m
.00375 .1058 L
s
0 .1333 m
.00375 .1333 L
s
0 .16079 m
.00375 .16079 L
s
0 .21579 m
.00375 .21579 L
s
0 .24328 m
.00375 .24328 L
s
0 .27078 m
.00375 .27078 L
s
0 .32577 m
.00375 .32577 L
s
0 .35327 m
.00375 .35327 L
s
0 .38077 m
.00375 .38077 L
s
0 .43576 m
.00375 .43576 L
s
0 .46326 m
.00375 .46326 L
s
0 .49075 m
.00375 .49075 L
s
0 .0508 m
.00375 .0508 L
s
0 .02331 m
.00375 .02331 L
s
0 .54575 m
.00375 .54575 L
s
0 .57324 m
.00375 .57324 L
s
0 .60074 m
.00375 .60074 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02379 .61178 m
.02379 .61803 L
s
.27224 .61178 m
.27224 .61803 L
s
.52069 .61178 m
.52069 .61803 L
s
.76914 .61178 m
.76914 .61803 L
s
.125 Mabswid
.07348 .61428 m
.07348 .61803 L
s
.12317 .61428 m
.12317 .61803 L
s
.17286 .61428 m
.17286 .61803 L
s
.22255 .61428 m
.22255 .61803 L
s
.32193 .61428 m
.32193 .61803 L
s
.37162 .61428 m
.37162 .61803 L
s
.42131 .61428 m
.42131 .61803 L
s
.471 .61428 m
.471 .61803 L
s
.57038 .61428 m
.57038 .61803 L
s
.62007 .61428 m
.62007 .61803 L
s
.66976 .61428 m
.66976 .61803 L
s
.71945 .61428 m
.71945 .61803 L
s
.81883 .61428 m
.81883 .61803 L
s
.86852 .61428 m
.86852 .61803 L
s
.91821 .61428 m
.91821 .61803 L
s
.9679 .61428 m
.9679 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0783 m
1 .0783 L
s
.99375 .18829 m
1 .18829 L
s
.99375 .29828 m
1 .29828 L
s
.99375 .40826 m
1 .40826 L
s
.99375 .51825 m
1 .51825 L
s
.125 Mabswid
.99625 .1058 m
1 .1058 L
s
.99625 .1333 m
1 .1333 L
s
.99625 .16079 m
1 .16079 L
s
.99625 .21579 m
1 .21579 L
s
.99625 .24328 m
1 .24328 L
s
.99625 .27078 m
1 .27078 L
s
.99625 .32577 m
1 .32577 L
s
.99625 .35327 m
1 .35327 L
s
.99625 .38077 m
1 .38077 L
s
.99625 .43576 m
1 .43576 L
s
.99625 .46326 m
1 .46326 L
s
.99625 .49075 m
1 .49075 L
s
.99625 .0508 m
1 .0508 L
s
.99625 .02331 m
1 .02331 L
s
.99625 .54575 m
1 .54575 L
s
.99625 .57324 m
1 .57324 L
s
.99625 .60074 m
1 .60074 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .29828 m
1 .29828 L
s
0 0 1 r
.5 Mabswid
.02381 .29828 m
.02383 .29398 L
.02385 .29398 L
.02388 .29828 L
.0239 .30257 L
.02392 .30257 L
.02394 .29828 L
.02397 .29398 L
.02399 .28968 L
.02401 .28968 L
.02403 .29398 L
.02406 .29828 L
.02408 .29828 L
.0241 .29398 L
.02412 .28968 L
.02414 .28968 L
.02417 .29398 L
.02419 .29398 L
.02421 .29828 L
.02423 .29828 L
.02426 .29398 L
.02428 .28968 L
.0243 .28968 L
.02432 .29398 L
.02435 .29398 L
.02437 .29398 L
.02439 .29398 L
.02441 .29398 L
.02443 .28968 L
.02446 .29398 L
.02448 .29398 L
.0245 .29398 L
.02452 .28968 L
.02455 .28968 L
.02457 .28968 L
.02459 .28968 L
.02461 .28968 L
.02464 .28968 L
.02466 .28968 L
.02468 .28539 L
.0247 .28539 L
.02472 .28968 L
.02475 .28968 L
.02477 .29398 L
.02479 .29398 L
.02481 .29398 L
.02484 .28968 L
.02486 .28968 L
.02488 .29398 L
.0249 .29828 L
Mistroke
.02493 .30257 L
.02495 .30257 L
.02497 .29828 L
.02499 .29828 L
.02502 .29398 L
.02504 .29828 L
.02506 .29828 L
.02508 .29828 L
.0251 .29828 L
.02513 .29828 L
.02515 .29828 L
.02517 .29828 L
.02519 .29828 L
.02522 .29828 L
.02524 .29828 L
.02526 .29828 L
.02528 .29398 L
.02531 .29398 L
.02533 .29398 L
.02535 .29398 L
.02537 .29398 L
.02539 .29828 L
.02542 .29828 L
.02544 .29398 L
.02546 .29398 L
.02548 .29398 L
.02551 .29398 L
.02553 .29398 L
.02555 .29828 L
.02557 .29398 L
.0256 .29398 L
.02562 .28968 L
.02564 .28968 L
.02566 .29398 L
.02569 .29828 L
.02571 .29828 L
.02573 .29398 L
.02575 .28968 L
.02577 .28968 L
.0258 .28968 L
.02582 .29398 L
.02584 .29828 L
.02586 .29398 L
.02589 .28968 L
.02591 .28539 L
.02593 .28539 L
.02595 .28968 L
.02598 .29398 L
.026 .29828 L
.02602 .29398 L
Mistroke
.02604 .28539 L
.02606 .28539 L
.02609 .28968 L
.02611 .29398 L
.02613 .29828 L
.02615 .30257 L
.02618 .29828 L
.0262 .29398 L
.02622 .29398 L
.02624 .29828 L
.02627 .30257 L
.02629 .30687 L
.02631 .30257 L
.02633 .29828 L
.02635 .29828 L
.02638 .29828 L
.0264 .29828 L
.02642 .30257 L
.02644 .30257 L
.02647 .29828 L
.02649 .29398 L
.02651 .29398 L
.02653 .29828 L
.02656 .29828 L
.02658 .30257 L
.0266 .29828 L
.02662 .29398 L
.02665 .29398 L
.02667 .29398 L
.02669 .29828 L
.02671 .30257 L
.02673 .29828 L
.02676 .29398 L
.02678 .28968 L
.0268 .28968 L
.02682 .29398 L
.02685 .29828 L
.02687 .30257 L
.02689 .29828 L
.02691 .29398 L
.02694 .28968 L
.02696 .29398 L
.02698 .29398 L
.027 .29828 L
.02702 .30257 L
.02705 .29828 L
.02707 .28968 L
.02709 .28968 L
.02711 .28968 L
.02714 .29828 L
Mistroke
.02716 .29828 L
.02718 .29398 L
.0272 .28968 L
.02723 .28968 L
.02725 .28539 L
.02727 .28968 L
.02729 .29828 L
.02732 .29828 L
.02734 .29828 L
.02736 .29398 L
.02738 .29398 L
.0274 .28968 L
.02743 .29398 L
.02745 .29828 L
.02747 .29828 L
.02749 .29828 L
.02752 .30257 L
.02754 .29828 L
.02756 .29828 L
.02758 .29828 L
.02761 .30257 L
.02763 .30257 L
.02765 .30257 L
.02767 .30257 L
.02769 .30257 L
.02772 .30257 L
.02774 .30257 L
.02776 .30257 L
.02778 .29828 L
.02781 .29828 L
.02783 .29828 L
.02785 .30257 L
.02787 .29828 L
.0279 .29828 L
.02792 .29828 L
.02794 .29828 L
.02796 .29828 L
.02798 .29828 L
.02801 .29828 L
.02803 .29828 L
.02805 .29828 L
.02807 .29398 L
.0281 .29398 L
.02812 .29828 L
.02814 .29828 L
.02816 .29828 L
.02819 .29828 L
.02821 .29398 L
.02823 .29398 L
.02825 .29398 L
Mistroke
.02828 .29398 L
.0283 .28968 L
.02832 .28968 L
.02834 .29398 L
.02836 .29398 L
.02839 .29398 L
.02841 .29398 L
.02843 .28968 L
.02845 .28968 L
.02848 .28968 L
.0285 .28968 L
.02852 .29398 L
.02854 .29398 L
.02857 .28968 L
.02859 .28539 L
.02861 .28539 L
.02863 .28968 L
.02865 .29398 L
.02868 .29398 L
.0287 .29398 L
.02872 .29398 L
.02874 .28968 L
.02877 .29398 L
.02879 .29828 L
.02881 .29828 L
.02883 .29828 L
.02886 .29828 L
.02888 .29828 L
.0289 .29828 L
.02892 .29828 L
.02895 .29828 L
.02897 .29828 L
.02899 .29828 L
.02901 .29828 L
.02903 .29828 L
.02906 .29828 L
.02908 .29828 L
.0291 .29398 L
.02912 .29398 L
.02915 .29398 L
.02917 .29828 L
.02919 .30257 L
.02921 .30257 L
.02924 .29828 L
.02926 .28968 L
.02928 .28968 L
.0293 .29398 L
.02932 .29828 L
.02935 .30257 L
.02937 .29828 L
Mistroke
.02939 .29398 L
.02941 .28968 L
.02944 .28968 L
.02946 .29398 L
.02948 .29828 L
.0295 .29828 L
.02953 .29828 L
.02955 .28968 L
.02957 .28539 L
.02959 .28539 L
.02961 .29398 L
.02964 .29828 L
.02966 .29828 L
.02968 .29828 L
.0297 .28968 L
.02973 .28539 L
.02975 .28539 L
.02977 .28968 L
.02979 .29398 L
.02982 .29398 L
.02984 .29398 L
.02986 .28968 L
.02988 .28539 L
.02991 .28539 L
.02993 .29398 L
.02995 .29828 L
.02997 .29398 L
.02999 .29398 L
.03002 .28968 L
.03004 .28968 L
.03006 .29398 L
.03008 .29828 L
.03011 .30257 L
.03013 .29828 L
.03015 .29398 L
.03017 .28968 L
.0302 .29828 L
.03022 .30257 L
.03024 .30687 L
.03026 .30257 L
.03028 .29828 L
.03031 .29398 L
.03033 .29398 L
.03035 .29828 L
.03037 .30257 L
.0304 .30257 L
.03042 .29828 L
.03044 .29398 L
.03046 .29398 L
.03049 .29828 L
Mistroke
.03051 .30257 L
.03053 .30257 L
.03055 .30257 L
.03058 .29828 L
.0306 .29398 L
.03062 .29398 L
.03064 .29828 L
.03066 .29828 L
.03069 .29828 L
.03071 .29398 L
.03073 .29398 L
.03075 .29398 L
.03078 .29828 L
.0308 .29398 L
.03082 .29398 L
.03084 .29398 L
.03087 .29828 L
.03089 .29828 L
.03091 .29398 L
.03093 .29398 L
.03095 .28968 L
.03098 .29398 L
.031 .29398 L
.03102 .29828 L
.03104 .29398 L
.03107 .29398 L
.03109 .28968 L
.03111 .29398 L
.03113 .29398 L
.03116 .29828 L
.03118 .29398 L
.0312 .28968 L
.03122 .29398 L
.03124 .29398 L
.03127 .29828 L
.03129 .29828 L
.03131 .29828 L
.03133 .29398 L
.03136 .29398 L
.03138 .29398 L
.0314 .29828 L
.03142 .30257 L
.03145 .30257 L
.03147 .29828 L
.03149 .29398 L
.03151 .29828 L
.03154 .30257 L
.03156 .30257 L
.03158 .30687 L
.0316 .30257 L
Mistroke
.03162 .29828 L
.03165 .29828 L
.03167 .29828 L
.03169 .30257 L
.03171 .30687 L
.03174 .30687 L
.03176 .29828 L
.03178 .29398 L
.0318 .29398 L
.03183 .29828 L
.03185 .30257 L
.03187 .30687 L
.03189 .30257 L
.03191 .29398 L
.03194 .29398 L
.03196 .29398 L
.03198 .29828 L
.032 .30257 L
.03203 .30257 L
.03205 .30257 L
.03207 .29828 L
.03209 .29398 L
.03212 .28968 L
.03214 .29398 L
.03216 .29398 L
.03218 .29828 L
.03221 .29828 L
.03223 .28968 L
.03225 .28539 L
.03227 .28539 L
.03229 .28968 L
.03232 .29398 L
.03234 .29828 L
.03236 .29398 L
.03238 .28539 L
.03241 .28539 L
.03243 .28968 L
.03245 .29398 L
.03247 .29828 L
.0325 .29398 L
.03252 .28968 L
.03254 .28539 L
.03256 .28968 L
.03258 .29398 L
.03261 .29398 L
.03263 .29398 L
.03265 .28968 L
.03267 .28968 L
.0327 .28539 L
.03272 .28968 L
Mistroke
.03274 .29398 L
.03276 .29828 L
.03279 .29828 L
.03281 .29398 L
.03283 .29398 L
.03285 .28968 L
.03287 .29828 L
.0329 .30257 L
.03292 .30257 L
.03294 .29828 L
.03296 .29398 L
.03299 .29398 L
.03301 .29398 L
.03303 .30257 L
.03305 .30257 L
.03308 .30257 L
.0331 .29828 L
.03312 .29398 L
.03314 .29398 L
.03317 .29398 L
.03319 .30257 L
.03321 .30257 L
.03323 .29828 L
.03325 .28968 L
.03328 .28968 L
.0333 .28968 L
.03332 .29828 L
.03334 .30257 L
.03337 .29828 L
.03339 .28968 L
.03341 .28539 L
.03343 .28539 L
.03346 .29398 L
.03348 .29828 L
.0335 .29828 L
.03352 .29398 L
.03354 .28539 L
.03357 .28109 L
.03359 .28968 L
.03361 .29828 L
.03363 .29828 L
.03366 .29398 L
.03368 .28539 L
.0337 .28539 L
.03372 .28968 L
.03375 .29828 L
.03377 .29828 L
.03379 .29398 L
.03381 .28968 L
.03384 .28539 L
Mistroke
.03386 .28539 L
.03388 .29398 L
.0339 .29828 L
.03392 .29828 L
.03395 .28968 L
.03397 .28539 L
.03399 .28539 L
.03401 .28968 L
.03404 .29398 L
.03406 .29828 L
.03408 .29398 L
.0341 .29398 L
.03413 .28968 L
.03415 .28968 L
.03417 .29828 L
.03419 .30257 L
.03421 .30257 L
.03424 .30257 L
.03426 .29828 L
.03428 .29398 L
.0343 .29398 L
.03433 .30257 L
.03435 .30257 L
.03437 .30687 L
.03439 .30257 L
.03442 .30257 L
.03444 .29828 L
.03446 .29398 L
.03448 .29398 L
.0345 .30257 L
.03453 .30257 L
.03455 .30257 L
.03457 .29828 L
.03459 .29398 L
.03462 .29398 L
.03464 .29828 L
.03466 .30257 L
.03468 .30257 L
.03471 .29828 L
.03473 .29398 L
.03475 .28968 L
.03477 .28968 L
.0348 .29828 L
.03482 .30257 L
.03484 .30257 L
.03486 .29398 L
.03488 .28968 L
.03491 .28968 L
.03493 .29398 L
.03495 .29828 L
Mistroke
.03497 .29828 L
.035 .29398 L
.03502 .29398 L
.03504 .28968 L
.03506 .29398 L
.03509 .29828 L
.03511 .29828 L
.03513 .29398 L
.03515 .28968 L
.03517 .28968 L
.0352 .28968 L
.03522 .29398 L
.03524 .29398 L
.03526 .29398 L
.03529 .28968 L
.03531 .28968 L
.03533 .28968 L
.03535 .28968 L
.03538 .29398 L
.0354 .29828 L
.03542 .29398 L
.03544 .29398 L
.03547 .29398 L
.03549 .29398 L
.03551 .29828 L
.03553 .30257 L
.03555 .30257 L
.03558 .30257 L
.0356 .30257 L
.03562 .29828 L
.03564 .29828 L
.03567 .29828 L
.03569 .30257 L
.03571 .30257 L
.03573 .30257 L
.03576 .29828 L
.03578 .29828 L
.0358 .29828 L
.03582 .30257 L
.03584 .30257 L
.03587 .30257 L
.03589 .29828 L
.03591 .29398 L
.03593 .29398 L
.03596 .29398 L
.03598 .30257 L
.036 .30257 L
.03602 .29828 L
.03605 .28968 L
.03607 .28968 L
Mistroke
.03609 .29398 L
.03611 .29828 L
.03613 .30257 L
.03616 .29828 L
.03618 .28968 L
.0362 .28539 L
.03622 .28968 L
.03625 .29828 L
.03627 .30257 L
.03629 .29828 L
.03631 .29398 L
.03634 .28539 L
.03636 .28539 L
.03638 .28968 L
.0364 .29828 L
.03643 .29828 L
.03645 .29398 L
.03647 .28539 L
.03649 .28109 L
.03651 .28109 L
.03654 .28968 L
.03656 .29398 L
.03658 .29398 L
.0366 .28968 L
.03663 .28539 L
.03665 .28109 L
.03667 .28539 L
.03669 .29398 L
.03672 .29828 L
.03674 .29828 L
.03676 .29398 L
.03678 .29398 L
.0368 .29398 L
.03683 .28968 L
.03685 .29398 L
.03687 .30257 L
.03689 .30257 L
.03692 .30257 L
.03694 .29828 L
.03696 .29398 L
.03698 .29828 L
.03701 .29828 L
.03703 .30257 L
.03705 .30257 L
.03707 .29828 L
.0371 .29398 L
.03712 .29398 L
.03714 .29398 L
.03716 .29828 L
.03718 .30257 L
Mistroke
.03721 .29828 L
.03723 .29398 L
.03725 .29398 L
.03727 .29398 L
.0373 .29398 L
.03732 .29828 L
.03734 .29828 L
.03736 .29828 L
.03739 .29398 L
.03741 .29398 L
.03743 .29398 L
.03745 .29828 L
.03747 .29828 L
.0375 .29828 L
.03752 .29828 L
.03754 .29398 L
.03756 .28968 L
.03759 .29398 L
.03761 .29828 L
.03763 .29828 L
.03765 .29828 L
.03768 .29398 L
.0377 .28968 L
.03772 .28968 L
.03774 .28968 L
.03776 .29398 L
.03779 .29398 L
.03781 .29398 L
.03783 .28968 L
.03785 .28539 L
.03788 .28539 L
.0379 .28968 L
.03792 .29398 L
.03794 .29828 L
.03797 .29828 L
.03799 .29398 L
.03801 .28968 L
.03803 .28968 L
.03806 .29398 L
.03808 .29828 L
.0381 .30257 L
.03812 .30687 L
.03814 .30257 L
.03817 .29828 L
.03819 .29828 L
.03821 .30257 L
.03823 .30257 L
.03826 .30687 L
.03828 .30687 L
.0383 .30257 L
Mistroke
.03832 .29828 L
.03835 .29828 L
.03837 .29828 L
.03839 .30257 L
.03841 .30687 L
.03843 .30257 L
.03846 .29828 L
.03848 .29398 L
.0385 .29398 L
.03852 .29828 L
.03855 .30257 L
.03857 .30257 L
.03859 .30257 L
.03861 .29398 L
.03864 .29398 L
.03866 .29398 L
.03868 .30257 L
.0387 .30687 L
.03873 .30257 L
.03875 .29828 L
.03877 .28968 L
.03879 .29398 L
.03881 .29398 L
.03884 .30257 L
.03886 .30687 L
.03888 .29828 L
.0389 .29398 L
.03893 .28968 L
.03895 .28968 L
.03897 .29398 L
.03899 .29828 L
.03902 .29398 L
.03904 .29398 L
.03906 .28968 L
.03908 .28539 L
.0391 .28968 L
.03913 .28968 L
.03915 .28968 L
.03917 .29398 L
.03919 .28968 L
.03922 .28968 L
.03924 .28968 L
.03926 .28968 L
.03928 .29398 L
.03931 .29398 L
.03933 .29828 L
.03935 .29828 L
.03937 .29828 L
.03939 .29828 L
.03942 .29828 L
Mistroke
.03944 .29398 L
.03946 .29828 L
.03948 .30257 L
.03951 .30687 L
.03953 .30257 L
.03955 .30257 L
.03957 .29828 L
.0396 .29398 L
.03962 .29828 L
.03964 .30257 L
.03966 .30257 L
.03969 .30257 L
.03971 .29828 L
.03973 .29398 L
.03975 .29398 L
.03977 .29828 L
.0398 .30257 L
.03982 .30257 L
.03984 .29828 L
.03986 .28968 L
.03989 .28968 L
.03991 .29398 L
.03993 .29828 L
.03995 .30257 L
.03998 .30257 L
.04 .29398 L
.04002 .28968 L
.04004 .29398 L
.04006 .29398 L
.04009 .30257 L
.04011 .29828 L
.04013 .29398 L
.04015 .29398 L
.04018 .28968 L
.0402 .28968 L
.04022 .29398 L
.04024 .29398 L
.04027 .29398 L
.04029 .28968 L
.04031 .28968 L
.04033 .28968 L
.04036 .28968 L
.04038 .28968 L
.0404 .28968 L
.04042 .28968 L
.04044 .28539 L
.04047 .28539 L
.04049 .28968 L
.04051 .28968 L
.04053 .28968 L
Mistroke
.04056 .28968 L
.04058 .28968 L
.0406 .29398 L
.04062 .29398 L
.04065 .29398 L
.04067 .29398 L
.04069 .29398 L
.04071 .29398 L
.04073 .29828 L
.04076 .29828 L
.04078 .30257 L
.0408 .30257 L
.04082 .29828 L
.04085 .29828 L
.04087 .29828 L
.04089 .29828 L
.04091 .29828 L
.04094 .30257 L
.04096 .29828 L
.04098 .29828 L
.041 .29398 L
.04102 .29398 L
.04105 .29828 L
.04107 .29828 L
.04109 .29828 L
.04111 .29828 L
.04114 .29398 L
.04116 .29398 L
.04118 .28968 L
.0412 .29398 L
.04123 .29828 L
.04125 .30257 L
.04127 .29828 L
.04129 .29398 L
.04132 .28968 L
.04134 .28968 L
.04136 .29398 L
.04138 .29828 L
.0414 .29828 L
.04143 .29398 L
.04145 .28968 L
.04147 .28968 L
.04149 .28968 L
.04152 .28968 L
.04154 .29398 L
.04156 .29398 L
.04158 .29398 L
.04161 .28968 L
.04163 .28968 L
.04165 .28968 L
Mistroke
.04167 .28968 L
.04169 .28968 L
.04172 .28968 L
.04174 .28968 L
.04176 .28968 L
.04178 .28539 L
.04181 .28539 L
.04183 .28968 L
.04185 .28968 L
.04187 .28968 L
.0419 .28968 L
.04192 .29398 L
.04194 .29398 L
.04196 .29398 L
.04198 .29398 L
.04201 .29398 L
.04203 .29398 L
.04205 .29828 L
.04207 .29828 L
.0421 .29828 L
.04212 .29828 L
.04214 .29828 L
.04216 .29828 L
.04219 .29828 L
.04221 .29828 L
.04223 .29828 L
.04225 .29828 L
.04228 .30257 L
.0423 .29828 L
.04232 .29398 L
.04234 .29828 L
.04236 .29398 L
.04239 .29828 L
.04241 .30257 L
.04243 .29828 L
.04245 .29828 L
.04248 .29398 L
.0425 .29398 L
.04252 .29828 L
.04254 .29828 L
.04257 .29828 L
.04259 .29828 L
.04261 .29828 L
.04263 .29398 L
.04265 .29398 L
.04268 .29398 L
.0427 .29828 L
.04272 .29828 L
.04274 .29828 L
.04277 .29398 L
Mistroke
.04279 .29398 L
.04281 .28968 L
.04283 .28968 L
.04286 .29398 L
.04288 .29398 L
.0429 .29398 L
.04292 .29398 L
.04295 .28968 L
.04297 .28968 L
.04299 .28968 L
.04301 .28968 L
.04303 .29398 L
.04306 .28968 L
.04308 .28968 L
.0431 .29398 L
.04312 .28968 L
.04315 .29398 L
.04317 .29398 L
.04319 .29398 L
.04321 .29398 L
.04324 .29398 L
.04326 .29828 L
.04328 .29828 L
.0433 .29828 L
.04332 .29828 L
.04335 .29398 L
.04337 .29828 L
.04339 .29828 L
.04341 .30257 L
.04344 .30257 L
.04346 .30257 L
.04348 .29828 L
.0435 .30257 L
.04353 .30257 L
.04355 .30257 L
.04357 .30257 L
.04359 .30257 L
.04361 .29828 L
.04364 .29828 L
.04366 .29828 L
.04368 .29828 L
.0437 .29828 L
.04373 .30257 L
.04375 .30687 L
.04377 .30257 L
.04379 .29828 L
.04382 .29828 L
.04384 .29398 L
.04386 .29398 L
.04388 .29828 L
Mistroke
.04391 .30257 L
.04393 .30257 L
.04395 .30257 L
.04397 .29398 L
.04399 .29398 L
.04402 .29398 L
.04404 .29828 L
.04406 .29828 L
.04408 .29398 L
.04411 .29398 L
.04413 .28968 L
.04415 .29398 L
.04417 .29828 L
.0442 .29828 L
.04422 .29398 L
.04424 .28968 L
.04426 .28539 L
.04428 .28968 L
.04431 .29398 L
.04433 .29828 L
.04435 .29398 L
.04437 .28968 L
.0444 .28539 L
.04442 .28539 L
.04444 .29398 L
.04446 .29828 L
.04449 .29828 L
.04451 .29398 L
.04453 .28968 L
.04455 .28968 L
.04458 .29398 L
.0446 .29828 L
.04462 .30257 L
.04464 .30257 L
.04466 .29828 L
.04469 .28968 L
.04471 .29398 L
.04473 .29828 L
.04475 .29828 L
.04478 .30687 L
.0448 .30257 L
.04482 .29828 L
.04484 .29398 L
.04487 .28968 L
.04489 .29828 L
.04491 .29828 L
.04493 .29828 L
.04495 .29828 L
.04498 .29398 L
.045 .29398 L
Mistroke
.04502 .29398 L
.04504 .29828 L
.04507 .30257 L
.04509 .29828 L
.04511 .29398 L
.04513 .28968 L
.04516 .28968 L
.04518 .29828 L
.0452 .29828 L
.04522 .30257 L
.04524 .29828 L
.04527 .28539 L
.04529 .28539 L
.04531 .28968 L
.04533 .29828 L
.04536 .29828 L
.04538 .29398 L
.0454 .28968 L
.04542 .28539 L
.04545 .28968 L
.04547 .29398 L
.04549 .29398 L
.04551 .28968 L
.04554 .28539 L
.04556 .28968 L
.04558 .28968 L
.0456 .29398 L
.04562 .29398 L
.04565 .28539 L
.04567 .28539 L
.04569 .28539 L
.04571 .29398 L
.04574 .29828 L
.04576 .28539 L
.04578 .29398 L
.0458 .28539 L
.04583 .28968 L
.04585 .30257 L
.04587 .30257 L
.04589 .30257 L
.04591 .29398 L
.04594 .28539 L
.04596 .28968 L
.04598 .30257 L
.046 .31117 L
.04603 .31546 L
.04605 .30687 L
.04607 .30257 L
.04609 .29398 L
.04612 .28968 L
Mistroke
.04614 .29398 L
.04616 .29398 L
.04618 .29828 L
.04621 .29828 L
.04623 .29828 L
.04625 .30257 L
.04627 .31117 L
.04629 .30257 L
.04632 .29398 L
.04634 .29398 L
.04636 .29398 L
.04638 .28968 L
.04641 .28539 L
.04643 .28539 L
.04645 .29398 L
.04647 .31117 L
.0465 .32405 L
.04652 .31976 L
.04654 .29398 L
.04656 .27679 L
.04658 .2682 L
.04661 .28109 L
.04663 .30687 L
.04665 .31546 L
.04667 .31117 L
.0467 .30687 L
.04672 .29398 L
.04674 .28109 L
.04676 .27679 L
.04679 .28109 L
.04681 .27679 L
.04683 .2682 L
.04685 .30257 L
.04687 .32835 L
.0469 .34124 L
.04692 .32835 L
.04694 .31117 L
.04696 .26391 L
.04699 .22953 L
.04701 .25531 L
.04703 .28109 L
.04705 .32405 L
.04708 .35843 L
.0471 .33694 L
.04712 .30687 L
.04714 .27679 L
.04717 .25531 L
.04719 .26391 L
.04721 .28109 L
.04723 .31117 L
Mistroke
.04725 .32835 L
.04728 .32835 L
.0473 .31976 L
.04732 .31117 L
.04734 .30687 L
.04737 .28968 L
.04739 .29398 L
.04741 .28109 L
.04743 .28539 L
.04746 .30257 L
.04748 .30687 L
.0475 .32405 L
.04752 .32405 L
.04754 .31546 L
.04757 .29398 L
.04759 .2682 L
.04761 .2725 L
.04763 .28539 L
.04766 .29398 L
.04768 .33265 L
.0477 .34124 L
.04772 .31117 L
.04775 .29398 L
.04777 .25961 L
.04779 .22953 L
.04781 .25961 L
.04784 .31117 L
.04786 .32835 L
.04788 .34554 L
.0479 .28968 L
.04792 .33265 L
.04795 .33694 L
.04797 .2682 L
.04799 .32405 L
.04801 .23383 L
.04804 .22524 L
.04806 .25531 L
.04808 .32405 L
.0481 .34554 L
.04813 .35413 L
.04815 .35413 L
.04817 .28109 L
.04819 .24672 L
.04821 .25961 L
.04824 .2682 L
.04826 .25102 L
.04828 .30257 L
.0483 .26391 L
.04833 .32405 L
.04835 .35413 L
Mistroke
.04837 .30257 L
.04839 .31117 L
.04842 .22524 L
.04844 .30257 L
.04846 .31117 L
.04848 .28109 L
.0485 .34983 L
.04853 .2725 L
.04855 .27679 L
.04857 .30257 L
.04859 .30257 L
.04862 .34124 L
.04864 .31976 L
.04866 .31117 L
.04868 .27679 L
.04871 .24672 L
.04873 .26391 L
.04875 .31976 L
.04877 .36272 L
.0488 .37131 L
.04882 .33265 L
.04884 .19516 L
.04886 .19516 L
.04888 .17368 L
.04891 .24242 L
.04893 .3928 L
.04895 .3928 L
.04897 .37131 L
.049 .27679 L
.04902 .21235 L
.04904 .32405 L
.04906 .25961 L
.04909 .33694 L
.04911 .29828 L
.04913 .20805 L
.04915 .24672 L
.04917 .28109 L
.0492 .37561 L
.04922 .36702 L
.04924 .33694 L
.04926 .25531 L
.04929 .19516 L
.04931 .25102 L
.04933 .34554 L
.04935 .36702 L
.04938 .35413 L
.0494 .21235 L
.04942 .14361 L
.04944 .21235 L
.04947 .25102 L
Mistroke
.04949 .41857 L
.04951 .40998 L
.04953 .32405 L
.04955 .19087 L
.04958 .25531 L
.0496 .30687 L
.04962 .28109 L
.04964 .41428 L
.04967 .23383 L
.04969 .22524 L
.04971 .24672 L
.04973 .30257 L
.04976 .39709 L
.04978 .37991 L
.0498 .30687 L
.04982 .23813 L
.04984 .20805 L
.04987 .2682 L
.04989 .39709 L
.04991 .36702 L
.04993 .37561 L
.04996 .19946 L
.04998 .1479 L
.05 .19946 L
.05002 .24672 L
.05005 .43146 L
.05007 .39709 L
.05009 .37131 L
.05011 .23383 L
.05013 .1565 L
.05016 .34983 L
.05018 .2682 L
.0502 .35843 L
.05022 .35413 L
.05025 .19087 L
.05027 .22094 L
.05029 .29828 L
.05031 .35413 L
.05034 .3885 L
.05036 .35413 L
.05038 .23383 L
.0504 .21235 L
.05043 .23383 L
.05045 .35843 L
.05047 .35413 L
.05049 .33694 L
.05051 .19516 L
.05054 .16938 L
.05056 .23383 L
.05058 .30257 L
Mistroke
.0506 .42287 L
.05063 .39709 L
.05065 .25531 L
.05067 .21235 L
.05069 .34983 L
.05072 .22953 L
.05074 .36272 L
.05076 .34983 L
.05078 .17368 L
.0508 .2682 L
.05083 .2725 L
.05085 .36272 L
.05087 .41428 L
.05089 .32405 L
.05092 .22953 L
.05094 .23383 L
.05096 .23383 L
.05098 .24672 L
.05101 .37131 L
.05103 .40569 L
.05105 .33265 L
.05107 .20805 L
.0511 .13931 L
.05112 .22094 L
.05114 .28539 L
.05116 .46154 L
.05118 .46154 L
.05121 .31976 L
.05123 .18657 L
.05125 .24672 L
.05127 .28539 L
.0513 .29828 L
.05132 .44435 L
.05134 .22953 L
.05136 .25531 L
.05139 .22953 L
.05141 .29398 L
.05143 .42717 L
.05145 .35413 L
.05147 .31976 L
.0515 .19516 L
.05152 .21664 L
.05154 .33694 L
.05156 .37991 L
.05159 .31546 L
.05161 .25961 L
.05163 .14361 L
.05165 .18227 L
.05168 .31546 L
.0517 .40569 L
Mistroke
.05172 .44006 L
.05174 .33265 L
.05176 .16509 L
.05179 .34124 L
.05181 .2725 L
.05183 .29398 L
.05185 .41428 L
.05188 .16079 L
.0519 .26391 L
.05192 .22524 L
.05194 .34554 L
.05197 .43576 L
.05199 .34983 L
.05201 .30687 L
.05203 .17368 L
.05206 .27679 L
.05208 .30687 L
.0521 .31976 L
.05212 .29828 L
.05214 .22524 L
.05217 .18657 L
.05219 .25102 L
.05221 .3885 L
.05223 .3928 L
.05226 .42287 L
.05228 .25531 L
.0523 .16509 L
.05232 .36272 L
.05235 .26391 L
.05237 .36702 L
.05239 .40998 L
.05241 .19087 L
.05243 .2682 L
.05246 .2682 L
.05248 .35413 L
.0525 .3842 L
.05252 .28968 L
.05255 .29828 L
.05257 .29398 L
.05259 .32405 L
.05261 .2725 L
.05264 .26391 L
.05266 .19516 L
.05268 .21235 L
.0527 .25102 L
.05273 .37131 L
.05275 .39709 L
.05277 .34554 L
.05279 .25102 L
.05281 .28109 L
Mistroke
.05284 .39709 L
.05286 .28109 L
.05288 .35843 L
.0529 .21235 L
.05293 .16079 L
.05295 .18227 L
.05297 .36702 L
.05299 .51309 L
.05302 .32405 L
.05304 .37561 L
.05306 .1522 L
.05308 .21235 L
.0531 .2682 L
.05313 .25102 L
.05315 .33694 L
.05317 .23383 L
.05319 .2682 L
.05322 .2725 L
.05324 .36272 L
.05326 .34983 L
.05328 .25961 L
.05331 .26391 L
.05333 .26391 L
.05335 .40139 L
.05337 .2682 L
.05339 .32835 L
.05342 .31976 L
.05344 .1565 L
.05346 .23813 L
.05348 .28968 L
.05351 .45724 L
.05353 .30257 L
.05355 .36702 L
.05357 .34124 L
.0536 .16079 L
.05362 .22953 L
.05364 .24242 L
.05366 .27679 L
.05369 .31976 L
.05371 .37991 L
.05373 .37561 L
.05375 .34983 L
.05377 .30257 L
.0538 .19946 L
.05382 .16938 L
.05384 .23383 L
.05386 .44865 L
.05389 .40569 L
.05391 .40569 L
.05393 .32835 L
Mistroke
.05395 .13072 L
.05398 .19087 L
.054 .30687 L
.05402 .36702 L
.05404 .2725 L
.05406 .35413 L
.05409 .31117 L
.05411 .26391 L
.05413 .27679 L
.05415 .19946 L
.05418 .18657 L
.0542 .18657 L
.05422 .32405 L
.05424 .41857 L
.05427 .44865 L
.05429 .27679 L
.05431 .35843 L
.05433 .36702 L
.05436 .14361 L
.05438 .29828 L
.0544 .16938 L
.05442 .25531 L
.05444 .29398 L
.05447 .44435 L
.05449 .47013 L
.05451 .29398 L
.05453 .25961 L
.05456 .0362 L
.05458 .1522 L
.0546 .2725 L
.05462 .37991 L
.05465 .49161 L
.05467 .3928 L
.05469 .30687 L
.05471 .24672 L
.05473 .22094 L
.05476 .21235 L
.05478 .30687 L
.0548 .33694 L
.05482 .23813 L
.05485 .31117 L
.05487 .37131 L
.05489 .3885 L
.05491 .41428 L
.05494 .33265 L
.05496 .22094 L
.05498 .13931 L
.055 .13501 L
.05502 .23813 L
.05505 .39709 L
Mistroke
.05507 .40998 L
.05509 .34124 L
.05511 .31117 L
.05514 .19087 L
.05516 .21664 L
.05518 .53458 L
.0552 .44006 L
.05523 .34554 L
.05525 .19087 L
.05527 .01472 L
.05529 .1565 L
.05532 .34554 L
.05534 .56895 L
.05536 .45724 L
.05538 .29398 L
.0554 .05768 L
.05543 .0319 L
.05545 .24242 L
.05547 .35413 L
.05549 .50021 L
.05552 .43576 L
.05554 .21235 L
.05556 .25961 L
.05558 .40998 L
.05561 .37131 L
.05563 .34554 L
.05565 .19516 L
.05567 .05768 L
.05569 .05768 L
.05572 .10494 L
.05574 .29398 L
.05576 .49161 L
.05578 .49161 L
.05581 .43576 L
.05583 .22953 L
.05585 .09635 L
.05587 .14361 L
.0559 .20376 L
.05592 .33694 L
.05594 .41428 L
.05596 .48302 L
.05599 .40139 L
.05601 .31976 L
.05603 .23383 L
.05605 .13931 L
.05607 .20805 L
.0561 .22094 L
.05612 .30687 L
.05614 .29398 L
.05616 .31546 L
Mistroke
.05619 .32835 L
.05621 .30257 L
.05623 .35413 L
.05625 .31117 L
.05628 .31976 L
.0563 .19516 L
.05632 .33694 L
.05634 .44006 L
.05636 .28539 L
.05639 .40569 L
.05641 .17368 L
.05643 .23383 L
.05645 .26391 L
.05648 .36272 L
.0565 .40569 L
.05652 .21664 L
.05654 .27679 L
.05657 .09205 L
.05659 .22524 L
.05661 .33265 L
.05663 .33694 L
.05665 .3842 L
.05668 .2725 L
.0567 .53458 L
.05672 .28968 L
.05674 .37991 L
.05677 .24242 L
.05679 .0319 L
.05681 .21664 L
.05683 .1479 L
.05686 .5045 L
.05688 .34554 L
.0569 .36702 L
.05692 .30687 L
.05695 .08775 L
.05697 .28968 L
.05699 .25531 L
.05701 .30687 L
.05703 .47443 L
.05706 .3842 L
.05708 .34124 L
.0571 .35843 L
.05712 .19946 L
.05715 .21664 L
.05717 .14361 L
.05719 .25102 L
.05721 .28109 L
.05724 .29398 L
.05726 .45295 L
.05728 .30687 L
Mistroke
.0573 .34554 L
.05732 .29398 L
.05735 .16938 L
.05737 .24672 L
.05739 .30257 L
.05741 .44865 L
.05744 .40139 L
.05746 .39709 L
.05748 .22524 L
.0575 .16938 L
.05753 .18657 L
.05755 .24242 L
.05757 .34983 L
.05759 .29828 L
.05761 .35413 L
.05764 .26391 L
.05766 .28539 L
.05768 .25531 L
.0577 .22094 L
.05773 .23383 L
.05775 .46583 L
.05777 .49591 L
.05779 .40569 L
.05782 .34983 L
.05784 .04909 L
.05786 .11353 L
.05788 .13072 L
.05791 .3928 L
.05793 .40569 L
.05795 .39709 L
.05797 .40139 L
.05799 .14361 L
.05802 .21235 L
.05804 .22524 L
.05806 .22524 L
.05808 .25961 L
.05811 .33694 L
.05813 .48732 L
.05815 .3842 L
.05817 .35413 L
.0582 .29828 L
.05822 .16079 L
.05824 .24242 L
.05826 .18227 L
.05828 .32405 L
.05831 .25531 L
.05833 .31546 L
.05835 .36702 L
.05837 .28109 L
.0584 .42717 L
Mistroke
.05842 .24672 L
.05844 .25961 L
.05846 .17368 L
.05849 .23383 L
.05851 .45724 L
.05853 .36702 L
.05855 .48732 L
.05858 .26391 L
.0586 .20805 L
.05862 .16938 L
.05864 .16079 L
.05866 .32835 L
.05869 .25531 L
.05871 .3928 L
.05873 .31117 L
.05875 .25961 L
.05878 .25102 L
.0588 .10494 L
.05882 .36702 L
.05884 .52169 L
.05887 .42717 L
.05889 .5088 L
.05891 .1522 L
.05893 .09635 L
.05895 .0319 L
.05898 .22524 L
.059 .37991 L
.05902 .34554 L
.05904 .54747 L
.05907 .30687 L
.05909 .25961 L
.05911 .28539 L
.05913 .12212 L
.05916 .3928 L
.05918 .34554 L
.0592 .33265 L
.05922 .37131 L
.05924 .20376 L
.05927 .31976 L
.05929 .17798 L
.05931 .33694 L
.05933 .31546 L
.05936 .21235 L
.05938 .34124 L
.0594 .21664 L
.05942 .30687 L
.05945 .34554 L
.05947 .28539 L
.05949 .32835 L
.05951 .3928 L
Mistroke
.05954 .34983 L
.05956 .33694 L
.05958 .29398 L
.0596 .22524 L
.05962 .19087 L
.05965 .17798 L
.05967 .29398 L
.05969 .29398 L
.05971 .34983 L
.05974 .41857 L
.05976 .27679 L
.05978 .31117 L
.0598 .20376 L
.05983 .21664 L
.05985 .46154 L
.05987 .32405 L
.05989 .43576 L
.05991 .27679 L
.05994 .22094 L
.05996 .23383 L
.05998 .19087 L
.06 .40569 L
.06003 .22953 L
.06005 .32835 L
.06007 .2725 L
.06009 .19946 L
.06012 .33265 L
.06014 .22953 L
.06016 .44435 L
.06018 .51309 L
.06021 .36272 L
.06023 .39709 L
.06025 .13501 L
.06027 .17798 L
.06029 .10924 L
.06032 .25961 L
.06034 .37131 L
.06036 .31546 L
.06038 .46154 L
.06041 .46154 L
.06043 .28109 L
.06045 .27679 L
.06047 .25102 L
.0605 .22524 L
.06052 .45295 L
.06054 .34124 L
.06056 .33694 L
.06058 .22953 L
.06061 .18227 L
.06063 .26391 L
Mistroke
.06065 .27679 L
.06067 .46154 L
.0607 .31976 L
.06072 .2682 L
.06074 .19087 L
.06076 .11353 L
.06079 .21235 L
.06081 .30687 L
.06083 .55176 L
.06085 .49591 L
.06087 .42717 L
.0609 .22524 L
.06092 .05338 L
.06094 .12212 L
.06096 .17368 L
.06099 .3928 L
.06101 .3885 L
.06103 .39709 L
.06105 .34983 L
.06108 .23383 L
.0611 .30257 L
.06112 .28968 L
.06114 .28539 L
.06117 .23813 L
.06119 .23813 L
.06121 .30257 L
.06123 .37131 L
.06125 .44006 L
.06128 .42287 L
.0613 .31117 L
.06132 .16509 L
.06134 .10064 L
.06137 .1522 L
.06139 .25961 L
.06141 .3928 L
.06143 .42717 L
.06146 .3885 L
.06148 .2682 L
.0615 .18227 L
.06152 .34124 L
.06154 .39709 L
.06157 .3842 L
.06159 .37131 L
.06161 .17368 L
.06163 .17368 L
.06166 .14361 L
.06168 .31976 L
.0617 .36702 L
.06172 .34124 L
.06175 .35413 L
Mistroke
.06177 .16938 L
.06179 .17798 L
.06181 .29398 L
.06184 .51739 L
.06186 .43576 L
.06188 .40569 L
.0619 .16938 L
.06192 .04909 L
.06195 .16079 L
.06197 .25961 L
.06199 .50021 L
.06201 .37561 L
.06204 .34983 L
.06206 .20376 L
.06208 .09635 L
.0621 .32835 L
.06213 .29828 L
.06215 .47872 L
.06217 .42287 L
.06219 .23383 L
.06221 .22524 L
.06224 .12642 L
.06226 .31117 L
.06228 .31546 L
.0623 .39709 L
.06233 .36272 L
.06235 .19946 L
.06237 .24672 L
.06239 .22094 L
.06242 .31976 L
.06244 .35413 L
.06246 .34983 L
.06248 .2682 L
.0625 .25961 L
.06253 .31976 L
.06255 .32405 L
.06257 .37131 L
.06259 .31546 L
.06262 .23813 L
.06264 .21235 L
.06266 .22953 L
.06268 .29828 L
.06271 .30687 L
.06273 .32835 L
.06275 .28539 L
.06277 .28539 L
.0628 .24242 L
.06282 .2682 L
.06284 .21235 L
.06286 .21235 L
Mistroke
.06288 .49591 L
.06291 .45295 L
.06293 .42717 L
.06295 .44006 L
.06297 .1522 L
.063 .12642 L
.06302 .05768 L
.06304 .22524 L
.06306 .31546 L
.06309 .34124 L
.06311 .51739 L
.06313 .31117 L
.06315 .32835 L
.06317 .28109 L
.0632 .18657 L
.06322 .37131 L
.06324 .27679 L
.06326 .33265 L
.06329 .29828 L
.06331 .28968 L
.06333 .31976 L
.06335 .21664 L
.06338 .28109 L
.0634 .25102 L
.06342 .25531 L
.06344 .32405 L
.06347 .33265 L
.06349 .32405 L
.06351 .29828 L
.06353 .34554 L
.06355 .34983 L
.06358 .33694 L
.0636 .34983 L
.06362 .23813 L
.06364 .21664 L
.06367 .19946 L
.06369 .25102 L
.06371 .34124 L
.06373 .36272 L
.06376 .35843 L
.06378 .25961 L
.0638 .19516 L
.06382 .13931 L
.06384 .37991 L
.06387 .46154 L
.06389 .45295 L
.06391 .45295 L
.06393 .17368 L
.06396 .16938 L
.06398 .08346 L
Mistroke
.064 .26391 L
.06402 .34554 L
.06405 .32835 L
.06407 .44006 L
.06409 .22953 L
.06411 .26391 L
.06413 .22524 L
.06416 .31546 L
.06418 .52169 L
.0642 .35843 L
.06422 .3928 L
.06425 .13931 L
.06427 .13072 L
.06429 .22094 L
.06431 .2682 L
.06434 .49591 L
.06436 .37131 L
.06438 .32835 L
.0644 .18227 L
.06443 .12212 L
.06445 .25961 L
.06447 .32405 L
.06449 .5045 L
.06451 .45295 L
.06454 .32835 L
.06456 .22953 L
.06458 .13501 L
.0646 .24242 L
.06463 .28539 L
.06465 .34124 L
.06467 .31546 L
.06469 .24242 L
.06472 .2682 L
.06474 .27679 L
.06476 .33265 L
.06478 .26391 L
.0648 .29398 L
.06483 .45295 L
.06485 .30687 L
.06487 .3842 L
.06489 .31976 L
.06492 .22094 L
.06494 .23383 L
.06496 .1565 L
.06498 .32835 L
.06501 .25102 L
.06503 .31976 L
.06505 .36272 L
.06507 .22094 L
.0651 .21664 L
Mistroke
.06512 .26391 L
.06514 .26391 L
.06516 .49591 L
.06518 .3885 L
.06521 .46154 L
.06523 .21664 L
.06525 .09205 L
.06527 .16509 L
.0653 .17368 L
.06532 .47013 L
.06534 .36702 L
.06536 .41857 L
.06539 .28109 L
.06541 .10064 L
.06543 .27679 L
.06545 .19946 L
.06547 .47013 L
.0655 .47443 L
.06552 .33694 L
.06554 .31117 L
.06556 .11783 L
.06559 .26391 L
.06561 .24242 L
.06563 .35843 L
.06565 .36272 L
.06568 .22524 L
.0657 .25102 L
.06572 .21664 L
.06574 .31546 L
.06576 .33265 L
.06579 .34124 L
.06581 .37991 L
.06583 .30687 L
.06585 .28539 L
.06588 .30257 L
.0659 .25961 L
.06592 .32405 L
.06594 .23383 L
.06597 .25102 L
.06599 .25531 L
.06601 .23383 L
.06603 .33265 L
.06606 .30257 L
.06608 .28539 L
.0661 .20376 L
.06612 .42717 L
.06614 .3842 L
.06617 .37561 L
.06619 .40998 L
.06621 .13501 L
Mistroke
.06623 .21235 L
.06626 .10064 L
.06628 .30257 L
.0663 .36702 L
.06632 .34983 L
.06635 .44435 L
.06637 .20805 L
.06639 .24242 L
.06641 .21664 L
.06643 .27679 L
.06646 .48732 L
.06648 .32405 L
.0665 .37991 L
.06652 .18657 L
.06655 .17798 L
.06657 .2682 L
.06659 .2682 L
.06661 .43576 L
.06664 .32835 L
.06666 .27679 L
.06668 .20376 L
.0667 .20376 L
.06673 .22524 L
.06675 .36272 L
.06677 .51739 L
.06679 .39709 L
.06681 .37991 L
.06684 .20376 L
.06686 .14361 L
.06688 .17798 L
.0669 .22953 L
.06693 .36272 L
.06695 .32835 L
.06697 .34124 L
.06699 .28109 L
.06702 .20805 L
.06704 .22094 L
.06706 .46154 L
.06708 .45724 L
.0671 .37991 L
.06713 .33694 L
.06715 .06627 L
.06717 .14361 L
.06719 .16079 L
.06722 .33694 L
.06724 .45724 L
.06726 .37991 L
.06728 .39709 L
.06731 .18657 L
.06733 .19946 L
Mistroke
.06735 .23383 L
.06737 .2682 L
.06739 .47443 L
.06742 .32835 L
.06744 .35843 L
.06746 .24242 L
.06748 .20376 L
.06751 .20376 L
.06753 .30687 L
.06755 .2682 L
.06757 .3842 L
.0676 .29398 L
.06762 .24242 L
.06764 .23383 L
.06766 .22524 L
.06769 .24672 L
.06771 .32405 L
.06773 .5088 L
.06775 .40139 L
.06777 .3842 L
.0678 .2682 L
.06782 .14361 L
.06784 .19516 L
.06786 .17368 L
.06789 .32405 L
.06791 .31117 L
.06793 .32835 L
.06795 .34983 L
.06798 .2682 L
.068 .23383 L
.06802 .27679 L
.06804 .51739 L
.06806 .35843 L
.06809 .41428 L
.06811 .23813 L
.06813 .09635 L
.06815 .21664 L
.06818 .1522 L
.0682 .42717 L
.06822 .37991 L
.06824 .3885 L
.06827 .36272 L
.06829 .17368 L
.06831 .25531 L
.06833 .18227 L
.06836 .43576 L
.06838 .41428 L
.0684 .35413 L
.06842 .35413 L
.06844 .11783 L
Mistroke
.06847 .25531 L
.06849 .19946 L
.06851 .34983 L
.06853 .3842 L
.06856 .2682 L
.06858 .28968 L
.0686 .17368 L
.06862 .24242 L
.06865 .25102 L
.06867 .49591 L
.06869 .46583 L
.06871 .35413 L
.06873 .33265 L
.06876 .07057 L
.06878 .20805 L
.0688 .18227 L
.06882 .34124 L
.06885 .40998 L
.06887 .28539 L
.06889 .32835 L
.06891 .19946 L
.06894 .18657 L
.06896 .25531 L
.06898 .5088 L
.069 .42717 L
.06902 .41428 L
.06905 .28968 L
.06907 .05768 L
.06909 .18657 L
.06911 .1565 L
.06914 .36702 L
.06916 .42287 L
.06918 .33265 L
.0692 .33694 L
.06923 .17368 L
.06925 .25531 L
.06927 .31117 L
.06929 .47443 L
.06932 .43146 L
.06934 .30257 L
.06936 .22524 L
.06938 .07057 L
.0694 .22953 L
.06943 .30257 L
.06945 .45295 L
.06947 .44435 L
.06949 .28968 L
.06952 .20376 L
.06954 .11783 L
.06956 .19946 L
Mistroke
.06958 .34124 L
.06961 .5088 L
.06963 .43576 L
.06965 .35413 L
.06967 .19946 L
.06969 .11353 L
.06972 .21664 L
.06974 .28109 L
.06976 .39709 L
.06978 .34554 L
.06981 .27679 L
.06983 .21664 L
.06985 .20376 L
.06987 .20376 L
.0699 .2682 L
.06992 .26391 L
.06994 .47013 L
.06996 .42287 L
.06999 .34124 L
.07001 .33694 L
.07003 .1522 L
.07005 .23383 L
.07007 .19516 L
.0701 .25961 L
.07012 .34554 L
.07014 .26391 L
.07016 .33694 L
.07019 .28539 L
.07021 .23813 L
.07023 .28109 L
.07025 .44435 L
.07028 .40569 L
.0703 .37991 L
.07032 .32405 L
.07034 .12212 L
.07036 .18657 L
.07039 .16509 L
.07041 .32405 L
.07043 .40998 L
.07045 .34983 L
.07048 .34124 L
.0705 .18657 L
.07052 .17368 L
.07054 .31117 L
.07057 .47443 L
.07059 .43146 L
.07061 .40569 L
.07063 .19087 L
.07065 .09635 L
.07068 .13931 L
Mistroke
.0707 .22094 L
.07072 .45295 L
.07074 .45295 L
.07077 .43146 L
.07079 .27679 L
.07081 .16079 L
.07083 .19516 L
.07086 .19516 L
.07088 .33265 L
.0709 .3842 L
.07092 .40998 L
.07095 .33265 L
.07097 .2725 L
.07099 .28968 L
.07101 .2682 L
.07103 .34124 L
.07106 .27679 L
.07108 .22094 L
.0711 .17798 L
.07112 .19516 L
.07115 .28539 L
.07117 .34983 L
.07119 .40998 L
.07121 .28109 L
.07124 .29828 L
.07126 .37131 L
.07128 .28968 L
.0713 .43576 L
.07132 .34124 L
.07135 .22524 L
.07137 .16509 L
.07139 .09205 L
.07141 .24242 L
.07144 .30687 L
.07146 .3842 L
.07148 .43576 L
.0715 .30257 L
.07153 .33265 L
.07155 .37561 L
.07157 .32405 L
.07159 .35843 L
.07162 .17798 L
.07164 .16079 L
.07166 .17798 L
.07168 .23383 L
.0717 .43146 L
.07173 .44006 L
.07175 .42287 L
.07177 .29398 L
.07179 .1522 L
Mistroke
.07182 .18657 L
.07184 .23813 L
.07186 .3928 L
.07188 .40998 L
.07191 .34554 L
.07193 .28968 L
.07195 .20805 L
.07197 .2682 L
.07199 .31546 L
.07202 .34554 L
.07204 .32405 L
.07206 .22524 L
.07208 .20376 L
.07211 .19516 L
.07213 .24242 L
.07215 .28968 L
.07217 .5045 L
.0722 .45295 L
.07222 .40139 L
.07224 .40139 L
.07226 .35413 L
.07228 .12642 L
.07231 .16079 L
.07233 .11783 L
.07235 .23813 L
.07237 .34554 L
.0724 .36272 L
.07242 .41857 L
.07244 .31546 L
.07246 .17798 L
.07249 .29828 L
.07251 .44435 L
.07253 .35843 L
.07255 .44435 L
.07258 .18227 L
.0726 .12212 L
.07262 .14361 L
.07264 .18227 L
.07266 .42717 L
.07269 .46154 L
.07271 .45724 L
.07273 .31117 L
.07275 .16079 L
.07278 .1479 L
.0728 .25531 L
.07282 .46154 L
.07284 .40569 L
.07287 .37131 L
.07289 .21664 L
.07291 .11353 L
Mistroke
.07293 .24242 L
.07295 .29398 L
.07298 .45724 L
.073 .44006 L
.07302 .27679 L
.07304 .17368 L
.07307 .10924 L
.07309 .25961 L
.07311 .40569 L
.07313 .50021 L
.07316 .42287 L
.07318 .28968 L
.0732 .1479 L
.07322 .10064 L
.07325 .24242 L
.07327 .31117 L
.07329 .42287 L
.07331 .35843 L
.07333 .22953 L
.07336 .16938 L
.07338 .20376 L
.0734 .44006 L
.07342 .48302 L
.07345 .50021 L
.07347 .34124 L
.07349 .12212 L
.07351 .07057 L
.07354 .09635 L
.07356 .25531 L
.07358 .3885 L
.0736 .44006 L
.07362 .3928 L
.07365 .25531 L
.07367 .32835 L
.07369 .27679 L
.07371 .41428 L
.07374 .3885 L
.07376 .19087 L
.07378 .17798 L
.0738 .07057 L
.07383 .22953 L
.07385 .31976 L
.07387 .43146 L
.07389 .52169 L
.07391 .33265 L
.07394 .29398 L
.07396 .22524 L
.07398 .18227 L
.074 .28539 L
.07403 .24242 L
Mistroke
.07405 .28968 L
.07407 .28968 L
.07409 .28109 L
.07412 .36272 L
.07414 .37561 L
.07416 .37131 L
.07418 .32405 L
.07421 .20376 L
.07423 .22094 L
.07425 .23813 L
.07427 .26391 L
.07429 .37561 L
.07432 .32835 L
.07434 .35843 L
.07436 .31976 L
.07438 .26391 L
.07441 .31976 L
.07443 .24242 L
.07445 .28109 L
.07447 .24242 L
.0745 .21235 L
.07452 .25531 L
.07454 .23813 L
.07456 .41857 L
.07458 .41857 L
.07461 .41857 L
.07463 .39709 L
.07465 .41428 L
.07467 .22953 L
.0747 .21664 L
.07472 .1522 L
.07474 .18227 L
.07476 .28968 L
.07479 .29398 L
.07481 .36702 L
.07483 .33694 L
.07485 .25102 L
.07487 .31976 L
.0749 .42287 L
.07492 .37561 L
.07494 .40569 L
.07496 .23813 L
.07499 .13931 L
.07501 .1565 L
.07503 .17368 L
.07505 .35843 L
.07508 .44006 L
.0751 .40569 L
.07512 .33694 L
.07514 .18227 L
Mistroke
.07517 .20376 L
.07519 .31976 L
.07521 .37561 L
.07523 .43576 L
.07525 .28968 L
.07528 .21235 L
.0753 .14361 L
.07532 .20805 L
.07534 .33265 L
.07537 .40998 L
.07539 .43146 L
.07541 .29398 L
.07543 .20805 L
.07546 .14361 L
.07548 .2725 L
.0755 .3928 L
.07552 .40998 L
.07554 .41857 L
.07557 .26391 L
.07559 .19516 L
.07561 .19087 L
.07563 .23813 L
.07566 .34554 L
.07568 .35843 L
.0757 .29828 L
.07572 .25961 L
.07575 .20376 L
.07577 .17798 L
.07579 .31546 L
.07581 .49161 L
.07584 .40569 L
.07586 .45724 L
.07588 .2725 L
.0759 .13072 L
.07592 .18227 L
.07595 .11783 L
.07597 .31546 L
.07599 .35413 L
.07601 .35413 L
.07604 .37131 L
.07606 .20376 L
.07608 .28109 L
.0761 .41428 L
.07613 .37991 L
.07615 .46583 L
.07617 .29398 L
.07619 .14361 L
.07621 .13072 L
.07624 .13072 L
.07626 .28539 L
Mistroke
.07628 .41857 L
.0763 .44006 L
.07633 .37561 L
.07635 .25961 L
.07637 .20805 L
.07639 .2725 L
.07642 .36272 L
.07644 .40139 L
.07646 .31117 L
.07648 .23383 L
.0765 .13931 L
.07653 .20376 L
.07655 .30687 L
.07657 .39709 L
.07659 .46154 L
.07662 .32405 L
.07664 .20805 L
.07666 .22953 L
.07668 .21664 L
.07671 .34124 L
.07673 .41857 L
.07675 .31546 L
.07677 .31546 L
.0768 .18227 L
.07682 .21664 L
.07684 .28968 L
.07686 .33265 L
.07688 .3928 L
.07691 .28968 L
.07693 .18657 L
.07695 .23383 L
.07697 .23383 L
.077 .31117 L
.07702 .36272 L
.07704 .49161 L
.07706 .36702 L
.07709 .25531 L
.07711 .16938 L
.07713 .11783 L
.07715 .20805 L
.07717 .32835 L
.0772 .36272 L
.07722 .3842 L
.07724 .29828 L
.07726 .22094 L
.07729 .34983 L
.07731 .37991 L
.07733 .42287 L
.07735 .3885 L
.07738 .20376 L
Mistroke
.0774 .13931 L
.07742 .14361 L
.07744 .18227 L
.07747 .39709 L
.07749 .43146 L
.07751 .40139 L
.07753 .34554 L
.07755 .20805 L
.07758 .2682 L
.0776 .30257 L
.07762 .35843 L
.07764 .32405 L
.07767 .24242 L
.07769 .18657 L
.07771 .20376 L
.07773 .27679 L
.07776 .37991 L
.07778 .44006 L
.0778 .34983 L
.07782 .22094 L
.07784 .23383 L
.07787 .22953 L
.07789 .28968 L
.07791 .42717 L
.07793 .31546 L
.07796 .31117 L
.07798 .21664 L
.078 .19087 L
.07802 .28539 L
.07805 .31117 L
.07807 .37131 L
.07809 .32405 L
.07811 .20805 L
.07813 .19087 L
.07816 .31976 L
.07818 .34124 L
.0782 .45724 L
.07822 .43146 L
.07825 .2682 L
.07827 .22094 L
.07829 .12212 L
.07831 .1522 L
.07834 .31117 L
.07836 .31976 L
.07838 .37991 L
.0784 .32835 L
.07843 .25102 L
.07845 .34554 L
.07847 .34124 L
.07849 .44006 L
Mistroke
.07851 .37991 L
.07854 .23383 L
.07856 .16509 L
.07858 .13501 L
.0786 .19087 L
.07863 .34983 L
.07865 .42287 L
.07867 .40139 L
.07869 .33265 L
.07872 .20376 L
.07874 .2682 L
.07876 .28968 L
.07878 .3842 L
.0788 .37131 L
.07883 .25102 L
.07885 .20376 L
.07887 .16938 L
.07889 .22953 L
.07892 .36272 L
.07894 .41428 L
.07896 .37991 L
.07898 .24672 L
.07901 .22524 L
.07903 .25531 L
.07905 .2682 L
.07907 .43576 L
.0791 .33694 L
.07912 .30257 L
.07914 .22953 L
.07916 .16079 L
.07918 .25531 L
.07921 .30687 L
.07923 .36272 L
.07925 .33265 L
.07927 .21664 L
.0793 .33265 L
.07932 .33265 L
.07934 .28539 L
.07936 .37131 L
.07939 .46583 L
.07941 .28109 L
.07943 .25531 L
.07945 .1479 L
.07947 .13931 L
.0795 .25531 L
.07952 .34983 L
.07954 .3928 L
.07956 .3928 L
.07959 .28539 L
.07961 .28109 L
Mistroke
.07963 .31546 L
.07965 .34124 L
.07968 .3842 L
.0797 .29398 L
.07972 .19946 L
.07974 .19516 L
.07976 .19946 L
.07979 .30257 L
.07981 .43146 L
.07983 .3885 L
.07985 .37131 L
.07988 .24242 L
.0799 .19087 L
.07992 .29828 L
.07994 .28539 L
.07997 .40569 L
.07999 .33265 L
.08001 .24242 L
.08003 .22953 L
.08006 .19087 L
.08008 .28968 L
.0801 .37991 L
.08012 .36702 L
.08014 .33265 L
.08017 .19946 L
.08019 .1479 L
.08021 .29398 L
.08023 .31546 L
.08026 .45724 L
.08028 .44435 L
.0803 .29828 L
.08032 .23813 L
.08035 .13501 L
.08037 .16079 L
.08039 .28539 L
.08041 .30687 L
.08043 .34983 L
.08046 .2725 L
.08048 .24242 L
.0805 .37991 L
.08052 .31976 L
.08055 .50021 L
.08057 .40569 L
.08059 .25102 L
.08061 .18227 L
.08064 .07916 L
.08066 .17798 L
.08068 .29828 L
.0807 .36272 L
.08073 .41857 L
Mistroke
.08075 .34554 L
.08077 .29398 L
.08079 .32835 L
.08081 .33265 L
.08084 .40569 L
.08086 .31976 L
.08088 .22094 L
.0809 .16938 L
.08093 .16938 L
.08095 .24242 L
.08097 .3928 L
.08099 .44865 L
.08102 .41857 L
.08104 .31976 L
.08106 .23383 L
.08108 .23813 L
.0811 .24242 L
.08113 .33265 L
.08115 .30687 L
.08117 .28539 L
.08119 .28109 L
.08122 .24242 L
.08124 .31546 L
.08126 .33694 L
.08128 .33265 L
.08131 .28109 L
.08133 .21664 L
.08135 .29828 L
.08137 .26391 L
.08139 .37131 L
.08142 .37561 L
.08144 .2682 L
.08146 .28539 L
.08148 .19946 L
.08151 .23813 L
.08153 .30257 L
.08155 .28968 L
.08157 .31546 L
.0816 .27679 L
.08162 .18657 L
.08164 .32405 L
.08166 .35843 L
.08169 .35843 L
.08171 .3885 L
.08173 .45295 L
.08175 .2725 L
.08177 .22953 L
.0818 .18227 L
.08182 .13931 L
.08184 .28968 L
Mistroke
.08186 .30257 L
.08189 .32405 L
.08191 .35843 L
.08193 .25102 L
.08195 .32835 L
.08198 .35413 L
.082 .37561 L
.08202 .40569 L
.08204 .26391 L
.08206 .20376 L
.08209 .17798 L
.08211 .19946 L
.08213 .31976 L
.08215 .3885 L
.08218 .37561 L
.0822 .34124 L
.08222 .23383 L
.08224 .31976 L
.08227 .30687 L
.08229 .35413 L
.08231 .41857 L
.08233 .23813 L
.08236 .24672 L
.08238 .17798 L
.0824 .21235 L
.08242 .34983 L
.08244 .35843 L
.08247 .37561 L
.08249 .2725 L
.08251 .1479 L
.08253 .32405 L
.08256 .28109 L
.08258 .42287 L
.0826 .45295 L
.08262 .25961 L
.08265 .24242 L
.08267 .12642 L
.08269 .16509 L
.08271 .30687 L
.08273 .31546 L
.08276 .37131 L
.08278 .27679 L
.0828 .23813 L
.08282 .33694 L
.08285 .31546 L
.08287 .48302 L
.08289 .37561 L
.08291 .23813 L
.08294 .18227 L
.08296 .09205 L
Mistroke
.08298 .20376 L
.083 .30687 L
.08302 .36702 L
.08305 .41428 L
.08307 .28968 L
.08309 .31117 L
.08311 .31117 L
.08314 .32835 L
.08316 .42717 L
.08318 .25961 L
.0832 .21664 L
.08323 .16938 L
.08325 .1522 L
.08327 .30687 L
.08329 .37131 L
.08332 .44435 L
.08334 .37131 L
.08336 .28109 L
.08338 .33265 L
.0834 .22953 L
.08343 .36702 L
.08345 .32405 L
.08347 .24242 L
.08349 .26391 L
.08352 .17798 L
.08354 .2725 L
.08356 .35413 L
.08358 .35843 L
.08361 .40139 L
.08363 .23383 L
.08365 .30257 L
.08367 .29398 L
.08369 .28968 L
.08372 .42717 L
.08374 .2682 L
.08376 .26391 L
.08378 .19946 L
.08381 .16079 L
.08383 .29828 L
.08385 .30687 L
.08387 .36272 L
.0839 .34124 L
.08392 .25102 L
.08394 .34983 L
.08396 .28539 L
.08399 .39709 L
.08401 .36272 L
.08403 .23383 L
.08405 .23383 L
.08407 .22094 L
Mistroke
.0841 .13072 L
.08412 .20805 L
.08414 .31976 L
.08416 .34554 L
.08419 .42287 L
.08421 .31546 L
.08423 .24242 L
.08425 .32835 L
.08428 .25531 L
.0843 .37561 L
.08432 .34124 L
.08434 .22094 L
.08436 .24242 L
.08439 .16079 L
.08441 .24672 L
.08443 .34983 L
.08445 .35843 L
.08448 .39709 L
.0845 .24242 L
.08452 .25102 L
.08454 .34124 L
.08457 .2682 L
.08459 .47443 L
.08461 .31546 L
.08463 .25531 L
.08465 .22094 L
.08468 .12642 L
.0847 .29398 L
.08472 .33265 L
.08474 .37131 L
.08477 .40139 L
.08479 .20376 L
.08481 .30687 L
.08483 .28109 L
.08486 .34554 L
.08488 .49591 L
.0849 .31117 L
.08492 .28109 L
.08495 .1479 L
.08497 .11353 L
.08499 .25531 L
.08501 .29828 L
.08503 .40139 L
.08506 .3842 L
.08508 .26391 L
.0851 .32405 L
.08512 .2725 L
.08515 .37991 L
.08517 .3928 L
.08519 .2682 L
Mistroke
.08521 .22094 L
.08524 .12642 L
.08526 .17798 L
.08528 .2682 L
.0853 .35413 L
.08532 .43576 L
.08535 .34124 L
.08537 .28109 L
.08539 .29828 L
.08541 .24242 L
.08544 .35843 L
.08546 .31546 L
.08548 .24672 L
.0855 .22953 L
.08553 .16079 L
.08555 .24672 L
.08557 .30687 L
.08559 .34983 L
.08562 .3842 L
.08564 .2725 L
.08566 .35843 L
.08568 .27679 L
.0857 .33694 L
.08573 .3842 L
.08575 .24672 L
.08577 .2725 L
.08579 .16079 L
.08582 .20376 L
.08584 .30257 L
.08586 .29828 L
.08588 .3928 L
.08591 .34554 L
.08593 .24672 L
.08595 .36272 L
.08597 .29398 L
.08599 .41428 L
.08602 .40998 L
.08604 .28539 L
.08606 .23813 L
.08608 .13501 L
.08611 .18227 L
.08613 .28109 L
.08615 .32835 L
.08617 .40569 L
.0862 .34124 L
.08622 .24672 L
.08624 .33265 L
.08626 .29398 L
.08628 .3928 L
.08631 .42717 L
Mistroke
.08633 .25961 L
.08635 .24672 L
.08637 .12212 L
.0864 .17798 L
.08642 .17798 L
.08644 .28539 L
.08646 .32835 L
.08649 .41857 L
.08651 .30257 L
.08653 .24672 L
.08655 .32405 L
.08658 .24242 L
.0866 .43146 L
.08662 .37561 L
.08664 .2725 L
.08666 .23383 L
.08669 .09205 L
.08671 .20805 L
.08673 .25961 L
.08675 .33694 L
.08678 .42717 L
.0868 .26391 L
.08682 .29398 L
.08684 .28968 L
.08687 .24672 L
.08689 .47013 L
.08691 .34983 L
.08693 .31546 L
.08695 .21235 L
.08698 .10064 L
.087 .22524 L
.08702 .24242 L
.08704 .36702 L
.08707 .43576 L
.08709 .30257 L
.08711 .30687 L
.08713 .27679 L
.08716 .28539 L
.08718 .42717 L
.0872 .37561 L
.08722 .32835 L
.08725 .25961 L
.08727 .1565 L
.08729 .21235 L
.08731 .25102 L
.08733 .33694 L
.08736 .3928 L
.08738 .30257 L
.0874 .29398 L
.08742 .30687 L
Mistroke
.08745 .28109 L
.08747 .42287 L
.08749 .3842 L
.08751 .33265 L
.08754 .25961 L
.08756 .1522 L
.08758 .20376 L
.0876 .23383 L
.08762 .31117 L
.08765 .35413 L
.08767 .24242 L
.08769 .29398 L
.08771 .31976 L
.08774 .30687 L
.08776 .47872 L
.08778 .37991 L
.0878 .32405 L
.08783 .20805 L
.08785 .10064 L
.08787 .18227 L
.08789 .22094 L
.08791 .33694 L
.08794 .3842 L
.08796 .28109 L
.08798 .25531 L
.088 .26391 L
.08803 .28968 L
.08805 .44435 L
.08807 .44435 L
.08809 .34554 L
.08812 .2682 L
.08814 .13501 L
.08816 .1565 L
.08818 .22953 L
.08821 .31546 L
.08823 .40139 L
.08825 .33265 L
.08827 .25961 L
.08829 .30257 L
.08832 .24672 L
.08834 .40569 L
.08836 .44006 L
.08838 .36702 L
.08841 .33694 L
.08843 .18227 L
.08845 .19516 L
.08847 .22524 L
.0885 .2725 L
.08852 .35843 L
.08854 .28968 L
Mistroke
.08856 .2682 L
.08858 .31976 L
.08861 .23813 L
.08863 .41428 L
.08865 .43576 L
.08867 .3842 L
.0887 .35413 L
.08872 .18657 L
.08874 .18657 L
.08876 .18227 L
.08879 .18227 L
.08881 .24242 L
.08883 .34124 L
.08885 .28109 L
.08888 .27679 L
.0889 .31546 L
.08892 .24242 L
.08894 .3885 L
.08896 .45724 L
.08899 .3885 L
.08901 .37561 L
.08903 .20376 L
.08905 .16938 L
.08908 .16938 L
.0891 .20376 L
.08912 .31117 L
.08914 .28968 L
.08917 .2682 L
.08919 .28109 L
.08921 .2682 L
.08923 .33694 L
.08925 .43576 L
.08928 .3928 L
.0893 .36702 L
.08932 .2682 L
.08934 .20376 L
.08937 .22524 L
.08939 .22524 L
.08941 .28968 L
.08943 .28968 L
.08946 .22094 L
.08948 .24672 L
.0895 .28109 L
.08952 .31117 L
.08954 .46154 L
.08957 .44435 L
.08959 .40569 L
.08961 .31117 L
.08963 .20805 L
.08966 .20805 L
Mistroke
.08968 .19516 L
.0897 .2682 L
.08972 .29828 L
.08975 .23383 L
.08977 .23813 L
.08979 .29828 L
.08981 .2682 L
.08984 .44006 L
.08986 .49591 L
.08988 .43146 L
.0899 .37561 L
.08992 .19946 L
.08995 .16509 L
.08997 .1479 L
.08999 .21235 L
.09001 .31976 L
.09004 .29828 L
.09006 .30257 L
.09008 .25531 L
.0901 .23813 L
.09013 .31546 L
.09015 .41428 L
.09017 .46583 L
.09019 .44435 L
.09021 .36272 L
.09024 .22953 L
.09026 .16938 L
.09028 .18227 L
.0903 .21664 L
.09033 .25531 L
.09035 .28109 L
.09037 .23813 L
.09039 .21664 L
.09042 .28968 L
.09044 .31546 L
.09046 .42717 L
.09048 .47872 L
.0905 .42287 L
.09053 .34983 L
.09055 .19946 L
.09057 .16938 L
.09059 .13931 L
.09062 .18227 L
.09064 .25961 L
.09066 .24672 L
.09068 .24242 L
.09071 .31117 L
.09073 .31546 L
.09075 .36272 L
.09077 .50021 L
Mistroke
.0908 .44006 L
.09082 .44435 L
.09084 .31976 L
.09086 .18657 L
.09088 .16079 L
.09091 .12642 L
.09093 .21235 L
.09095 .23813 L
.09097 .2725 L
.091 .34124 L
.09102 .33694 L
.09104 .34124 L
.09106 .41857 L
.09109 .40569 L
.09111 .43146 L
.09113 .3928 L
.09115 .3928 L
.09117 .2682 L
.0912 .22094 L
.09122 .1522 L
.09124 .18227 L
.09126 .20805 L
.09129 .25531 L
.09131 .32835 L
.09133 .28539 L
.09135 .36272 L
.09138 .3842 L
.0914 .34554 L
.09142 .40139 L
.09144 .36272 L
.09147 .31117 L
.09149 .2682 L
.09151 .22953 L
.09153 .22953 L
.09155 .22524 L
.09158 .25531 L
.0916 .26391 L
.09162 .20805 L
.09164 .29828 L
.09167 .32835 L
.09169 .32835 L
.09171 .43576 L
.09173 .3885 L
.09176 .33265 L
.09178 .27679 L
.0918 .19516 L
.09182 .19516 L
.09184 .20376 L
.09187 .27679 L
.09189 .28539 L
Mistroke
.09191 .2725 L
.09193 .25102 L
.09196 .26391 L
.09198 .31117 L
.092 .34554 L
.09202 .44006 L
.09205 .42717 L
.09207 .3928 L
.09209 .29828 L
.09211 .20376 L
.09213 .16509 L
.09216 .19946 L
.09218 .25531 L
.0922 .30257 L
.09222 .33265 L
.09225 .29828 L
.09227 .25531 L
.09229 .29398 L
.09231 .29398 L
.09234 .3842 L
.09236 .45724 L
.09238 .42287 L
.0924 .35843 L
.09243 .26391 L
.09245 .19516 L
.09247 .17368 L
.09249 .22094 L
.09251 .26391 L
.09254 .29398 L
.09256 .28539 L
.09258 .29398 L
.0926 .31117 L
.09263 .28539 L
.09265 .36272 L
.09267 .40139 L
.09269 .3928 L
.09272 .37131 L
.09274 .30257 L
.09276 .22094 L
.09278 .20376 L
.0928 .22094 L
.09283 .22094 L
.09285 .25102 L
.09287 .26391 L
.09289 .30257 L
.09292 .31546 L
.09294 .30687 L
.09296 .35413 L
.09298 .36272 L
.09301 .35413 L
Mistroke
.09303 .35843 L
.09305 .28968 L
.09307 .23813 L
.0931 .22953 L
.09312 .21664 L
.09314 .22953 L
.09316 .25102 L
.09318 .25961 L
.09321 .25961 L
.09323 .31117 L
.09325 .30687 L
.09327 .34554 L
.0933 .3842 L
.09332 .36702 L
.09334 .35843 L
.09336 .32405 L
.09339 .28539 L
.09341 .26391 L
.09343 .25961 L
.09345 .2682 L
.09347 .26391 L
.0935 .22524 L
.09352 .22524 L
.09354 .22953 L
.09356 .28968 L
.09359 .30257 L
.09361 .35843 L
.09363 .40998 L
.09365 .37991 L
.09368 .35843 L
.0937 .32835 L
.09372 .25531 L
.09374 .24672 L
.09376 .25531 L
.09379 .26391 L
.09381 .26391 L
.09383 .24242 L
.09385 .21664 L
.09388 .25961 L
.0939 .28968 L
.09392 .33694 L
.09394 .40569 L
.09397 .40139 L
.09399 .39709 L
.09401 .35413 L
.09403 .2725 L
.09406 .23383 L
.09408 .20805 L
.0941 .22094 L
.09412 .25961 L
Mistroke
.09414 .25102 L
.09417 .25961 L
.09419 .25102 L
.09421 .2725 L
.09423 .31976 L
.09426 .34983 L
.09428 .39709 L
.0943 .3842 L
.09432 .33694 L
.09435 .29828 L
.09437 .22953 L
.09439 .21664 L
.09441 .24242 L
.09443 .25961 L
.09446 .30257 L
.09448 .28109 L
.0945 .25961 L
.09452 .27679 L
.09455 .27679 L
.09457 .31976 L
.09459 .36702 L
.09461 .37131 L
.09464 .36702 L
.09466 .32835 L
.09468 .26391 L
.0947 .24242 L
.09473 .23813 L
.09475 .24242 L
.09477 .2725 L
.09479 .28109 L
.09481 .2682 L
.09484 .31546 L
.09486 .31117 L
.09488 .32405 L
.0949 .37561 L
.09493 .35843 L
.09495 .35843 L
.09497 .33265 L
.09499 .2682 L
.09502 .25102 L
.09504 .22953 L
.09506 .24242 L
.09508 .27679 L
.0951 .27679 L
.09513 .30257 L
.09515 .28109 L
.09517 .26391 L
.09519 .30687 L
.09522 .31976 L
.09524 .34983 L
Mistroke
.09526 .37131 L
.09528 .34554 L
.09531 .32835 L
.09533 .28539 L
.09535 .25961 L
.09537 .24672 L
.09539 .24242 L
.09542 .2682 L
.09544 .2725 L
.09546 .28109 L
.09548 .28109 L
.09551 .28109 L
.09553 .30687 L
.09555 .31976 L
.09557 .34124 L
.0956 .34983 L
.09562 .33265 L
.09564 .30687 L
.09566 .2682 L
.09569 .24672 L
.09571 .24242 L
.09573 .24242 L
.09575 .2682 L
.09577 .2682 L
.0958 .25961 L
.09582 .28539 L
.09584 .30687 L
.09586 .32835 L
.09589 .32835 L
.09591 .35413 L
.09593 .36272 L
.09595 .34983 L
.09598 .31976 L
.096 .30257 L
.09602 .27679 L
.09604 .2682 L
.09606 .2725 L
.09609 .27679 L
.09611 .28109 L
.09613 .28968 L
.09615 .28539 L
.09618 .27679 L
.0962 .2725 L
.09622 .29828 L
.09624 .31976 L
.09627 .34124 L
.09629 .35413 L
.09631 .34983 L
.09633 .32835 L
.09636 .30687 L
Mistroke
.09638 .2725 L
.0964 .25961 L
.09642 .26391 L
.09644 .27679 L
.09647 .28539 L
.09649 .29398 L
.09651 .2725 L
.09653 .2725 L
.09656 .28968 L
.09658 .30687 L
.0966 .34983 L
.09662 .36702 L
.09665 .35413 L
.09667 .32835 L
.09669 .27679 L
.09671 .25102 L
.09673 .24242 L
.09676 .25961 L
.09678 .2725 L
.0968 .2682 L
.09682 .26391 L
.09685 .24242 L
.09687 .28539 L
.09689 .31546 L
.09691 .32835 L
.09694 .35843 L
.09696 .34554 L
.09698 .34554 L
.097 .33694 L
.09702 .30257 L
.09705 .28968 L
.09707 .25531 L
.09709 .24242 L
.09711 .23813 L
.09714 .24672 L
.09716 .28539 L
.09718 .29398 L
.0972 .29398 L
.09723 .29398 L
.09725 .28539 L
.09727 .31117 L
.09729 .32835 L
.09732 .35413 L
.09734 .36702 L
.09736 .34124 L
.09738 .31546 L
.0974 .2682 L
.09743 .25961 L
.09745 .2682 L
.09747 .2725 L
Mistroke
.09749 .29828 L
.09752 .29828 L
.09754 .28109 L
.09756 .27679 L
.09758 .28539 L
.09761 .31117 L
.09763 .33265 L
.09765 .34554 L
.09767 .34124 L
.09769 .32405 L
.09772 .30687 L
.09774 .28539 L
.09776 .2725 L
.09778 .2682 L
.09781 .25961 L
.09783 .25961 L
.09785 .2725 L
.09787 .27679 L
.0979 .28539 L
.09792 .30687 L
.09794 .30687 L
.09796 .30687 L
.09799 .31976 L
.09801 .33694 L
.09803 .34124 L
.09805 .31976 L
.09807 .29828 L
.0981 .2682 L
.09812 .25102 L
.09814 .24672 L
.09816 .25102 L
.09819 .27679 L
.09821 .28109 L
.09823 .28109 L
.09825 .27679 L
.09828 .2682 L
.0983 .26391 L
.09832 .28539 L
.09834 .29828 L
.09836 .31546 L
.09839 .34124 L
.09841 .34124 L
.09843 .34124 L
.09845 .31117 L
.09848 .28539 L
.0985 .2682 L
.09852 .25102 L
.09854 .26391 L
.09857 .28968 L
.09859 .30257 L
Mistroke
.09861 .31117 L
.09863 .28968 L
.09865 .2725 L
.09868 .2725 L
.0987 .28968 L
.09872 .31546 L
.09874 .33265 L
.09877 .35413 L
.09879 .34983 L
.09881 .31546 L
.09883 .28539 L
.09886 .25531 L
.09888 .25102 L
.0989 .2682 L
.09892 .29398 L
.09895 .30687 L
.09897 .29398 L
.09899 .28539 L
.09901 .28968 L
.09903 .29398 L
.09906 .30257 L
.09908 .30257 L
.0991 .31546 L
.09912 .33694 L
.09915 .32835 L
.09917 .30687 L
.09919 .28539 L
.09921 .25961 L
.09924 .25531 L
.09926 .2725 L
.09928 .30687 L
.0993 .31546 L
.09932 .30257 L
.09935 .28109 L
.09937 .25102 L
.09939 .25102 L
.09941 .2682 L
.09944 .28539 L
.09946 .30687 L
.09948 .31117 L
.0995 .31546 L
.09953 .31117 L
.09955 .30257 L
.09957 .29828 L
.09959 .28109 L
.09962 .2682 L
.09964 .2682 L
.09966 .28109 L
.09968 .29828 L
.0997 .30687 L
Mistroke
.09973 .29828 L
.09975 .28539 L
.09977 .26391 L
.09979 .26391 L
.09982 .28968 L
.09984 .30687 L
.09986 .32405 L
.09988 .32835 L
.09991 .31546 L
.09993 .29398 L
.09995 .28109 L
.09997 .28539 L
.09999 .29398 L
.10002 .31117 L
.10004 .31117 L
.10006 .30257 L
.10008 .29828 L
.10011 .29828 L
.10013 .29398 L
.10015 .30687 L
.10017 .31546 L
.1002 .29398 L
.10022 .28109 L
.10024 .30257 L
.10026 .31117 L
.10028 .30687 L
.10031 .30257 L
.10033 .29828 L
.10035 .29398 L
.10037 .29398 L
.1004 .31117 L
.10042 .31546 L
.10044 .31546 L
.10046 .30687 L
.10049 .28109 L
.10051 .28109 L
.10053 .28968 L
.10055 .28539 L
.10058 .28539 L
.1006 .28539 L
.10062 .28539 L
.10064 .28109 L
.10066 .28109 L
.10069 .29828 L
.10071 .31117 L
.10073 .30257 L
.10075 .29398 L
.10078 .28968 L
.1008 .28109 L
.10082 .29828 L
Mistroke
.10084 .31117 L
.10087 .30257 L
.10089 .29828 L
.10091 .29398 L
.10093 .28109 L
.10095 .27679 L
.10098 .28539 L
.101 .28539 L
.10102 .28968 L
.10104 .29398 L
.10107 .29828 L
.10109 .30257 L
.10111 .31117 L
.10113 .30687 L
.10116 .29828 L
.10118 .29398 L
.1012 .28968 L
.10122 .28968 L
.10125 .29828 L
.10127 .30687 L
.10129 .31117 L
.10131 .31117 L
.10133 .30257 L
.10136 .28968 L
.10138 .29828 L
.1014 .31117 L
.10142 .30257 L
.10145 .30257 L
.10147 .31546 L
.10149 .30257 L
.10151 .29828 L
.10154 .30257 L
.10156 .30257 L
.10158 .29828 L
.1016 .29828 L
.10162 .29398 L
.10165 .29828 L
.10167 .31117 L
.10169 .31117 L
.10171 .29828 L
.10174 .28539 L
.10176 .28109 L
.10178 .28539 L
.1018 .28968 L
.10183 .29398 L
.10185 .30257 L
.10187 .29828 L
.10189 .28539 L
.10191 .28109 L
.10194 .29398 L
Mistroke
.10196 .30687 L
.10198 .31976 L
.102 .31546 L
.10203 .30257 L
.10205 .29828 L
.10207 .29398 L
.10209 .29398 L
.10212 .29398 L
.10214 .29398 L
.10216 .28539 L
.10218 .2682 L
.10221 .26391 L
.10223 .25961 L
.10225 .28109 L
.10227 .30257 L
.10229 .29398 L
.10232 .28539 L
.10234 .29828 L
.10236 .29398 L
.10238 .27679 L
.10241 .28968 L
.10243 .30257 L
.10245 .30687 L
.10247 .31546 L
.1025 .32405 L
.10252 .31976 L
.10254 .31546 L
.10256 .31117 L
.10258 .29398 L
.10261 .28968 L
.10263 .28968 L
.10265 .28539 L
.10267 .28109 L
.1027 .29398 L
.10272 .29828 L
.10274 .28968 L
.10276 .28539 L
.10279 .28968 L
.10281 .28109 L
.10283 .27679 L
.10285 .28539 L
.10288 .29398 L
.1029 .28968 L
.10292 .28968 L
.10294 .29828 L
.10296 .29828 L
.10299 .29828 L
.10301 .31117 L
.10303 .32405 L
.10305 .31976 L
Mistroke
.10308 .31976 L
.1031 .31976 L
.10312 .30257 L
.10314 .29398 L
.10317 .29828 L
.10319 .29398 L
.10321 .28109 L
.10323 .28109 L
.10325 .27679 L
.10328 .2725 L
.1033 .27679 L
.10332 .2725 L
.10334 .28539 L
.10337 .28109 L
.10339 .25961 L
.10341 .26391 L
.10343 .28539 L
.10346 .28539 L
.10348 .28109 L
.1035 .29398 L
.10352 .29828 L
.10354 .30257 L
.10357 .31976 L
.10359 .32835 L
.10361 .32835 L
.10363 .32835 L
.10366 .31117 L
.10368 .28968 L
.1037 .29828 L
.10372 .30257 L
.10375 .28968 L
.10377 .29398 L
.10379 .30687 L
.10381 .29398 L
.10384 .28109 L
.10386 .28539 L
.10388 .28109 L
.1039 .28539 L
.10392 .30257 L
.10395 .28539 L
.10397 .2682 L
.10399 .28109 L
.10401 .28539 L
.10404 .27679 L
.10406 .28968 L
.10408 .30687 L
.1041 .30257 L
.10413 .30687 L
.10415 .32835 L
.10417 .32405 L
Mistroke
.10419 .31976 L
.10421 .33265 L
.10424 .30687 L
.10426 .28539 L
.10428 .30257 L
.1043 .29398 L
.10433 .27679 L
.10435 .28968 L
.10437 .28539 L
.10439 .2725 L
.10442 .28109 L
.10444 .28968 L
.10446 .28109 L
.10448 .28968 L
.10451 .29398 L
.10453 .25961 L
.10455 .25961 L
.10457 .28968 L
.10459 .28968 L
.10462 .28109 L
.10464 .29828 L
.10466 .30257 L
.10468 .28968 L
.10471 .31117 L
.10473 .32835 L
.10475 .31546 L
.10477 .32835 L
.1048 .32835 L
.10482 .28968 L
.10484 .29828 L
.10486 .31546 L
.10488 .28968 L
.10491 .28539 L
.10493 .29828 L
.10495 .28539 L
.10497 .2725 L
.105 .28539 L
.10502 .27679 L
.10504 .2725 L
.10506 .30257 L
.10509 .28968 L
.10511 .2682 L
.10513 .29398 L
.10515 .30257 L
.10517 .2725 L
.1052 .28109 L
.10522 .30687 L
.10524 .30257 L
.10526 .30687 L
.10529 .33265 L
Mistroke
.10531 .31976 L
.10533 .31976 L
.10535 .31117 L
.10538 .32405 L
.1054 .30687 L
.10542 .29398 L
.10544 .31546 L
.10547 .30687 L
.10549 .28109 L
.10551 .29398 L
.10553 .29828 L
.10555 .27679 L
.10558 .28539 L
.1056 .28968 L
.10562 .26391 L
.10564 .2682 L
.10567 .29398 L
.10569 .27679 L
.10571 .2682 L
.10573 .29398 L
.10576 .29398 L
.10578 .2725 L
.1058 .28968 L
.10582 .31117 L
.10584 .29828 L
.10587 .31117 L
.10589 .32835 L
.10591 .30687 L
.10593 .30687 L
.10596 .32405 L
.10598 .30687 L
.106 .29828 L
.10602 .31976 L
.10605 .30687 L
.10607 .28109 L
.10609 .29828 L
.10611 .30257 L
.10614 .28539 L
.10616 .29398 L
.10618 .29398 L
.1062 .26391 L
.10622 .2725 L
.10625 .30257 L
.10627 .27679 L
.10629 .2725 L
.10631 .30257 L
.10634 .29398 L
.10636 .2725 L
.10638 .29398 L
.1064 .31117 L
Mistroke
.10643 .30257 L
.10645 .31976 L
.10647 .33694 L
.10649 .31117 L
.10651 .31117 L
.10654 .32835 L
.10656 .30687 L
.10658 .29398 L
.1066 .31546 L
.10663 .30257 L
.10665 .27679 L
.10667 .29398 L
.10669 .29398 L
.10672 .28109 L
.10674 .28539 L
.10676 .28109 L
.10678 .25961 L
.1068 .2725 L
.10683 .30257 L
.10685 .28109 L
.10687 .26391 L
.10689 .29398 L
.10692 .28968 L
.10694 .2725 L
.10696 .28968 L
.10698 .31117 L
.10701 .29828 L
.10703 .30687 L
.10705 .32405 L
.10707 .31117 L
.1071 .31117 L
.10712 .32835 L
.10714 .31117 L
.10716 .29398 L
.10718 .30687 L
.10721 .30257 L
.10723 .28539 L
.10725 .29828 L
.10727 .30257 L
.1073 .28539 L
.10732 .28968 L
.10734 .28539 L
.10736 .2682 L
.10739 .2725 L
.10741 .29828 L
.10743 .29828 L
.10745 .2725 L
.10747 .28968 L
.1075 .29828 L
.10752 .28539 L
Mistroke
.10754 .28968 L
.10756 .31117 L
.10759 .30687 L
.10761 .30687 L
.10763 .32835 L
.10765 .32405 L
.10768 .31117 L
.1077 .31117 L
.10772 .32405 L
.10774 .31976 L
.10776 .29398 L
.10779 .29828 L
.10781 .31117 L
.10783 .28968 L
.10785 .28539 L
.10788 .29398 L
.1079 .28109 L
.10792 .28109 L
.10794 .28539 L
.10797 .27679 L
.10799 .2682 L
.10801 .28539 L
.10803 .29398 L
.10806 .2725 L
.10808 .2725 L
.1081 .29828 L
.10812 .28968 L
.10814 .28109 L
.10817 .28968 L
.10819 .29828 L
.10821 .29398 L
.10823 .31546 L
.10826 .32835 L
.10828 .31117 L
.1083 .31117 L
.10832 .31976 L
.10835 .29828 L
.10837 .28968 L
.10839 .31117 L
.10841 .29828 L
.10843 .28109 L
.10846 .28539 L
.10848 .28539 L
.1085 .27679 L
.10852 .28109 L
.10855 .28109 L
.10857 .2682 L
.10859 .2725 L
.10861 .29398 L
.10864 .28968 L
Mistroke
.10866 .2725 L
.10868 .29398 L
.1087 .30257 L
.10873 .28539 L
.10875 .28968 L
.10877 .30687 L
.10879 .30257 L
.10881 .30687 L
.10884 .32835 L
.10886 .31976 L
.10888 .31117 L
.1089 .31976 L
.10893 .31117 L
.10895 .29398 L
.10897 .29828 L
.10899 .31117 L
.10902 .28968 L
.10904 .28539 L
.10906 .28968 L
.10908 .28109 L
.1091 .28109 L
.10913 .27679 L
.10915 .2725 L
.10917 .26391 L
.10919 .2725 L
.10922 .29398 L
.10924 .28109 L
.10926 .2725 L
.10928 .29398 L
.10931 .29398 L
.10933 .27679 L
.10935 .28968 L
.10937 .30687 L
.10939 .30257 L
.10942 .31546 L
.10944 .32405 L
.10946 .31117 L
.10948 .30687 L
.10951 .31546 L
.10953 .30687 L
.10955 .29398 L
.10957 .30687 L
.1096 .29828 L
.10962 .27679 L
.10964 .28539 L
.10966 .29398 L
.10969 .28109 L
.10971 .28539 L
.10973 .28109 L
.10975 .2725 L
Mistroke
.10977 .26391 L
.1098 .28968 L
.10982 .30257 L
.10984 .28109 L
.10986 .28539 L
.10989 .29828 L
.10991 .28968 L
.10993 .28539 L
.10995 .30687 L
.10998 .31976 L
.11 .31117 L
.11002 .32835 L
.11004 .32835 L
.11006 .32835 L
.11009 .31117 L
.11011 .32405 L
.11013 .32835 L
.11015 .30687 L
.11018 .30257 L
.1102 .31546 L
.11022 .29828 L
.11024 .28109 L
.11027 .28968 L
.11029 .28968 L
.11031 .28109 L
.11033 .28109 L
.11036 .28109 L
.11038 .2682 L
.1104 .2682 L
.11042 .29828 L
.11044 .29398 L
.11047 .2725 L
.11049 .28968 L
.11051 .29828 L
.11053 .28539 L
.11056 .28539 L
.11058 .30687 L
.1106 .30257 L
.11062 .30257 L
.11065 .32835 L
.11067 .32405 L
.11069 .31117 L
.11071 .31976 L
.11073 .31546 L
.11076 .29398 L
.11078 .30257 L
.1108 .31117 L
.11082 .28968 L
.11085 .28109 L
.11087 .28968 L
Mistroke
.11089 .28109 L
.11091 .27679 L
.11094 .28109 L
.11096 .27679 L
.11098 .26391 L
.111 .2682 L
.11102 .29398 L
.11105 .28539 L
.11107 .2725 L
.11109 .29398 L
.11111 .30257 L
.11114 .28968 L
.11116 .28968 L
.11118 .30687 L
.1112 .31117 L
.11123 .31546 L
.11125 .33265 L
.11127 .32835 L
.11129 .31546 L
.11132 .32405 L
.11134 .31546 L
.11136 .29398 L
.11138 .30687 L
.1114 .31546 L
.11143 .28968 L
.11145 .28539 L
.11147 .29398 L
.11149 .28539 L
.11152 .28109 L
.11154 .28109 L
.11156 .27679 L
.11158 .26391 L
.11161 .2725 L
.11163 .29828 L
.11165 .28109 L
.11167 .2725 L
.11169 .29398 L
.11172 .29398 L
.11174 .27679 L
.11176 .28968 L
.11178 .30687 L
.11181 .30257 L
.11183 .31117 L
.11185 .33265 L
.11187 .31976 L
.1119 .31117 L
.11192 .32405 L
.11194 .31546 L
.11196 .29398 L
.11199 .31117 L
Mistroke
.11201 .30687 L
.11203 .28109 L
.11205 .28539 L
.11207 .29398 L
.1121 .28539 L
.11212 .27679 L
.11214 .28109 L
.11216 .2725 L
.11219 .25961 L
.11221 .27679 L
.11223 .29828 L
.11225 .28539 L
.11228 .27679 L
.1123 .29398 L
.11232 .29398 L
.11234 .28539 L
.11236 .29398 L
.11239 .31117 L
.11241 .31546 L
.11243 .31546 L
.11245 .31976 L
.11248 .33694 L
.1125 .32405 L
.11252 .31976 L
.11254 .32835 L
.11257 .31976 L
.11259 .30687 L
.11261 .31546 L
.11263 .31117 L
.11265 .28968 L
.11268 .28539 L
.1127 .29398 L
.11272 .28539 L
.11274 .28539 L
.11277 .28109 L
.11279 .2725 L
.11281 .25531 L
.11283 .2725 L
.11286 .29398 L
.11288 .28539 L
.1129 .2725 L
.11292 .29398 L
.11295 .28968 L
.11297 .27679 L
.11299 .28539 L
.11301 .30687 L
.11303 .30687 L
.11306 .31546 L
.11308 .33265 L
.1131 .31546 L
Mistroke
.11312 .30687 L
.11315 .31546 L
.11317 .31117 L
.11319 .29828 L
.11321 .30687 L
.11324 .30687 L
.11326 .28539 L
.11328 .28109 L
.1133 .28968 L
.11332 .28539 L
.11335 .28109 L
.11337 .28109 L
.11339 .2725 L
.11341 .25531 L
.11344 .26391 L
.11346 .28539 L
.11348 .28968 L
.1135 .27679 L
.11353 .28968 L
.11355 .29398 L
.11357 .28539 L
.11359 .28539 L
.11362 .30687 L
.11364 .31976 L
.11366 .31976 L
.11368 .32835 L
.1137 .32835 L
.11373 .31546 L
.11375 .32405 L
.11377 .32405 L
.11379 .30257 L
.11382 .30687 L
.11384 .31117 L
.11386 .29398 L
.11388 .28539 L
.11391 .29398 L
.11393 .29398 L
.11395 .28539 L
.11397 .27679 L
.11399 .2725 L
.11402 .26391 L
.11404 .25961 L
.11406 .28539 L
.11408 .28968 L
.11411 .27679 L
.11413 .28539 L
.11415 .29398 L
.11417 .28109 L
.1142 .27679 L
.11422 .29828 L
Mistroke
.11424 .31117 L
.11426 .31117 L
.11428 .32405 L
.11431 .32405 L
.11433 .30687 L
.11435 .31546 L
.11437 .31976 L
.1144 .30257 L
.11442 .29828 L
.11444 .31117 L
.11446 .28968 L
.11449 .28109 L
.11451 .29398 L
.11453 .28968 L
.11455 .2725 L
.11458 .27679 L
.1146 .27679 L
.11462 .25531 L
.11464 .25961 L
.11466 .28968 L
.11469 .28539 L
.11471 .27679 L
.11473 .28968 L
.11475 .28968 L
.11478 .29828 L
.1148 .29828 L
.11482 .29398 L
.11484 .29398 L
.11487 .31976 L
.11489 .32405 L
.11491 .32835 L
.11493 .34124 L
.11495 .32405 L
.11498 .33694 L
.115 .32835 L
.11502 .30257 L
.11504 .31117 L
.11507 .29398 L
.11509 .27679 L
.11511 .28109 L
.11513 .26391 L
.11516 .27679 L
.11518 .27679 L
.1152 .25961 L
.11522 .27679 L
.11525 .25961 L
.11527 .25531 L
.11529 .31546 L
.11531 .32405 L
.11533 .32835 L
Mistroke
.11536 .35413 L
.11538 .31546 L
.1154 .29828 L
.11542 .29398 L
.11545 .26391 L
.11547 .28968 L
.11549 .30257 L
.11551 .31117 L
.11554 .31976 L
.11556 .28968 L
.11558 .29828 L
.1156 .29398 L
.11562 .27679 L
.11565 .31546 L
.11567 .29828 L
.11569 .2682 L
.11571 .26391 L
.11574 .22953 L
.11576 .23383 L
.11578 .26391 L
.1158 .2725 L
.11583 .29398 L
.11585 .28539 L
.11587 .2682 L
.11589 .31976 L
.11591 .34554 L
.11594 .33694 L
.11596 .37131 L
.11598 .34983 L
.116 .29828 L
.11603 .29398 L
.11605 .26391 L
.11607 .2682 L
.11609 .30257 L
.11612 .31546 L
.11614 .32405 L
.11616 .30257 L
.11618 .30687 L
.11621 .31117 L
.11623 .28539 L
.11625 .32405 L
.11627 .31546 L
.11629 .27679 L
.11632 .27679 L
.11634 .25961 L
.11636 .25102 L
.11638 .2725 L
.11641 .28539 L
.11643 .27679 L
.11645 .26391 L
Mistroke
.11647 .24672 L
.1165 .32835 L
.11652 .37991 L
.11654 .34983 L
.11656 .3928 L
.11658 .34983 L
.11661 .24672 L
.11663 .2682 L
.11665 .23813 L
.11667 .26391 L
.1167 .32835 L
.11672 .32835 L
.11674 .31976 L
.11676 .26391 L
.11679 .27679 L
.11681 .30257 L
.11683 .27679 L
.11685 .34983 L
.11688 .32405 L
.1169 .23383 L
.11692 .23813 L
.11694 .22094 L
.11696 .22953 L
.11699 .29398 L
.11701 .31546 L
.11703 .30257 L
.11705 .25961 L
.11708 .21664 L
.1171 .29828 L
.11712 .3842 L
.11714 .3842 L
.11717 .36702 L
.11719 .40569 L
.11721 .37131 L
.11723 .22524 L
.11725 .23813 L
.11728 .23383 L
.1173 .25531 L
.11732 .34124 L
.11734 .35843 L
.11737 .34983 L
.11739 .2682 L
.11741 .25961 L
.11743 .31117 L
.11746 .27679 L
.11748 .36272 L
.1175 .36272 L
.11752 .26391 L
.11754 .25961 L
.11757 .22524 L
Mistroke
.11759 .24672 L
.11761 .28968 L
.11763 .31546 L
.11766 .31546 L
.11768 .25102 L
.1177 .21664 L
.11772 .26391 L
.11775 .39709 L
.11777 .42287 L
.11779 .3885 L
.11781 .40569 L
.11784 .22524 L
.11786 .16938 L
.11788 .23813 L
.1179 .24242 L
.11792 .34983 L
.11795 .37131 L
.11797 .33694 L
.11799 .26391 L
.11801 .20376 L
.11804 .31117 L
.11806 .30687 L
.11808 .34124 L
.1181 .3842 L
.11813 .22953 L
.11815 .19946 L
.11817 .20376 L
.11819 .22524 L
.11821 .31546 L
.11824 .32835 L
.11826 .32835 L
.11828 .24672 L
.1183 .17368 L
.11833 .22094 L
.11835 .36702 L
.11837 .48732 L
.11839 .41857 L
.11842 .37561 L
.11844 .2682 L
.11846 .10494 L
.11848 .20376 L
.11851 .29828 L
.11853 .36702 L
.11855 .41428 L
.11857 .33265 L
.11859 .25102 L
.11862 .18227 L
.11864 .2682 L
.11866 .40569 L
.11868 .37561 L
Mistroke
.11871 .3928 L
.11873 .28968 L
.11875 .1565 L
.11877 .20376 L
.1188 .25531 L
.11882 .35413 L
.11884 .37131 L
.11886 .30687 L
.11888 .25102 L
.11891 .1565 L
.11893 .17798 L
.11895 .32835 L
.11897 .51739 L
.119 .49591 L
.11902 .34124 L
.11904 .28968 L
.11906 .13072 L
.11909 .10924 L
.11911 .32405 L
.11913 .3885 L
.11915 .3928 L
.11917 .32835 L
.1192 .22524 L
.11922 .18657 L
.11924 .21664 L
.11926 .40139 L
.11929 .44006 L
.11931 .32405 L
.11933 .29828 L
.11935 .16509 L
.11938 .13501 L
.1194 .25531 L
.11942 .33694 L
.11944 .37561 L
.11947 .31117 L
.11949 .22524 L
.11951 .22524 L
.11953 .18227 L
.11955 .16509 L
.11958 .28539 L
.1196 .47443 L
.11962 .51739 L
.11964 .37561 L
.11967 .23383 L
.11969 .18657 L
.11971 .13931 L
.11973 .25531 L
.11976 .41857 L
.11978 .39709 L
.1198 .30257 L
Mistroke
.11982 .24672 L
.11984 .22524 L
.11987 .25531 L
.11989 .37561 L
.11991 .45295 L
.11993 .34983 L
.11996 .25102 L
.11998 .22524 L
.12 .21235 L
.12002 .2725 L
.12005 .35843 L
.12007 .3842 L
.12009 .29398 L
.12011 .21664 L
.12014 .21664 L
.12016 .22094 L
.12018 .28539 L
.1202 .35413 L
.12022 .45295 L
.12025 .47443 L
.12027 .27679 L
.12029 .22524 L
.12031 .25961 L
.12034 .17368 L
.12036 .28539 L
.12038 .37561 L
.1204 .31117 L
.12043 .2682 L
.12045 .2725 L
.12047 .30257 L
.12049 .29398 L
.12051 .36702 L
.12054 .3885 L
.12056 .25102 L
.12058 .22524 L
.1206 .25102 L
.12063 .22094 L
.12065 .2725 L
.12067 .31546 L
.12069 .31546 L
.12072 .26391 L
.12074 .24242 L
.12076 .25961 L
.12078 .24672 L
.1208 .28109 L
.12083 .31546 L
.12085 .42717 L
.12087 .46583 L
.12089 .28539 L
.12092 .23813 L
Mistroke
.12094 .25531 L
.12096 .16509 L
.12098 .2682 L
.12101 .3842 L
.12103 .34554 L
.12105 .30257 L
.12107 .29828 L
.1211 .30257 L
.12112 .29398 L
.12114 .35843 L
.12116 .3928 L
.12118 .26391 L
.12121 .22953 L
.12123 .28539 L
.12125 .2725 L
.12127 .29828 L
.1213 .34983 L
.12132 .33265 L
.12134 .25102 L
.12136 .22953 L
.12139 .2682 L
.12141 .2682 L
.12143 .28968 L
.12145 .31976 L
.12147 .3842 L
.1215 .47872 L
.12152 .34554 L
.12154 .22094 L
.12156 .2682 L
.12159 .17798 L
.12161 .20805 L
.12163 .37131 L
.12165 .35413 L
.12168 .31546 L
.1217 .29828 L
.12172 .30257 L
.12174 .2725 L
.12177 .28968 L
.12179 .37561 L
.12181 .28539 L
.12183 .20805 L
.12185 .28109 L
.12188 .28109 L
.1219 .24672 L
.12192 .25102 L
.12194 .31546 L
.12197 .30687 L
.12199 .2725 L
.12201 .25102 L
.12203 .2725 L
Mistroke
.12206 .26391 L
.12208 .2682 L
.1221 .28968 L
.12212 .33694 L
.12214 .47872 L
.12217 .41428 L
.12219 .20805 L
.12221 .24242 L
.12223 .23813 L
.12226 .17798 L
.12228 .34124 L
.1223 .41857 L
.12232 .31546 L
.12235 .28109 L
.12237 .31976 L
.12239 .30687 L
.12241 .28968 L
.12243 .37561 L
.12246 .32835 L
.12248 .19516 L
.1225 .2682 L
.12252 .33265 L
.12255 .28968 L
.12257 .32835 L
.12259 .34554 L
.12261 .25531 L
.12264 .21235 L
.12266 .2725 L
.12268 .28968 L
.1227 .28109 L
.12273 .32835 L
.12275 .31546 L
.12277 .37561 L
.12279 .48302 L
.12281 .30687 L
.12284 .18227 L
.12286 .25102 L
.12288 .17798 L
.1229 .22524 L
.12293 .3842 L
.12295 .37991 L
.12297 .31546 L
.12299 .27679 L
.12302 .29398 L
.12304 .25961 L
.12306 .28109 L
.12308 .35413 L
.1231 .2725 L
.12313 .21664 L
.12315 .30687 L
Mistroke
.12317 .28109 L
.12319 .25102 L
.12322 .30257 L
.12324 .31117 L
.12326 .25961 L
.12328 .23383 L
.12331 .25961 L
.12333 .2725 L
.12335 .28109 L
.12337 .30687 L
.12339 .31976 L
.12342 .47013 L
.12344 .44435 L
.12346 .18227 L
.12348 .18657 L
.12351 .25961 L
.12353 .16938 L
.12355 .31546 L
.12357 .44865 L
.1236 .34983 L
.12362 .2682 L
.12364 .30257 L
.12366 .31117 L
.12369 .26391 L
.12371 .33694 L
.12373 .34124 L
.12375 .20376 L
.12377 .26391 L
.1238 .37131 L
.12382 .29828 L
.12384 .28109 L
.12386 .32405 L
.12389 .25961 L
.12391 .19946 L
.12393 .2725 L
.12395 .31976 L
.12398 .28968 L
.124 .31976 L
.12402 .33694 L
.12404 .29398 L
.12406 .43146 L
.12409 .42717 L
.12411 .16509 L
.12413 .16509 L
.12415 .2682 L
.12418 .19946 L
.1242 .31546 L
.12422 .44435 L
.12424 .44435 L
.12427 .36272 L
Mistroke
.12429 .23813 L
.12431 .25102 L
.12433 .29828 L
.12436 .25531 L
.12438 .31117 L
.1244 .34124 L
.12442 .22953 L
.12444 .26391 L
.12447 .34983 L
.12449 .27679 L
.12451 .25102 L
.12453 .28968 L
.12456 .2725 L
.12458 .22953 L
.1246 .26391 L
.12462 .31976 L
.12465 .28968 L
.12467 .29828 L
.12469 .29398 L
.12471 .30257 L
.12473 .49161 L
.12476 .40139 L
.12478 .11783 L
.1248 .19946 L
.12482 .28109 L
.12485 .19516 L
.12487 .37561 L
.12489 .47443 L
.12491 .31546 L
.12494 .21664 L
.12496 .30257 L
.12498 .31117 L
.125 .25961 L
.12502 .36702 L
.12505 .33265 L
.12507 .19087 L
.12509 .29828 L
.12511 .39709 L
.12514 .28539 L
.12516 .2725 L
.12518 .31117 L
.1252 .24672 L
.12523 .21664 L
.12525 .30687 L
.12527 .33694 L
.12529 .28539 L
.12532 .30687 L
.12534 .29398 L
.12536 .24672 L
.12538 .47443 L
Mistroke
.1254 .45295 L
.12543 .13931 L
.12545 .16938 L
.12547 .28539 L
.12549 .17798 L
.12552 .32835 L
.12554 .47013 L
.12556 .35843 L
.12558 .19946 L
.12561 .25531 L
.12563 .31976 L
.12565 .22524 L
.12567 .33694 L
.12569 .3885 L
.12572 .20805 L
.12574 .23383 L
.12576 .3928 L
.12578 .28109 L
.12581 .23813 L
.12583 .30257 L
.12585 .29828 L
.12587 .21664 L
.1259 .28968 L
.12592 .33694 L
.12594 .27679 L
.12596 .27679 L
.12599 .35413 L
.12601 .25531 L
.12603 .29398 L
.12605 .49591 L
.12607 .36702 L
.1261 .10064 L
.12612 .23383 L
.12614 .33694 L
.12616 .22094 L
.12619 .35413 L
.12621 .46583 L
.12623 .28968 L
.12625 .18657 L
.12628 .33694 L
.1263 .33265 L
.12632 .24672 L
.12634 .35843 L
.12636 .34554 L
.12639 .19516 L
.12641 .30257 L
.12643 .41857 L
.12645 .28539 L
.12648 .24242 L
.1265 .28539 L
Mistroke
.12652 .23813 L
.12654 .22953 L
.12657 .33265 L
.12659 .33694 L
.12661 .33694 L
.12663 .28968 L
.12665 .29828 L
.12668 .29398 L
.1267 .22524 L
.12672 .39709 L
.12674 .51739 L
.12677 .22953 L
.12679 .09205 L
.12681 .29398 L
.12683 .25102 L
.12686 .25102 L
.12688 .44865 L
.1269 .40569 L
.12692 .19087 L
.12695 .21664 L
.12697 .34983 L
.12699 .25531 L
.12701 .2725 L
.12703 .39709 L
.12706 .26391 L
.12708 .19516 L
.1271 .3928 L
.12712 .37991 L
.12715 .22953 L
.12717 .24672 L
.12719 .2725 L
.12721 .21235 L
.12724 .25961 L
.12726 .36272 L
.12728 .33265 L
.1273 .2725 L
.12732 .32835 L
.12735 .28968 L
.12737 .21664 L
.12739 .41857 L
.12741 .47872 L
.12744 .19946 L
.12746 .13501 L
.12748 .34554 L
.1275 .28539 L
.12753 .25961 L
.12755 .43576 L
.12757 .3885 L
.12759 .17798 L
.12762 .24242 L
Mistroke
.12764 .37131 L
.12766 .26391 L
.12768 .28109 L
.1277 .41857 L
.12773 .30687 L
.12775 .21664 L
.12777 .35413 L
.12779 .32835 L
.12782 .19946 L
.12784 .24672 L
.12786 .29828 L
.12788 .26391 L
.12791 .30687 L
.12793 .36702 L
.12795 .30687 L
.12797 .25531 L
.12799 .29398 L
.12802 .25961 L
.12804 .20376 L
.12806 .40139 L
.12808 .51309 L
.12811 .25102 L
.12813 .10924 L
.12815 .31117 L
.12817 .2682 L
.1282 .19516 L
.12822 .40139 L
.12824 .40569 L
.12826 .18657 L
.12828 .24672 L
.12831 .3885 L
.12833 .2682 L
.12835 .24672 L
.12837 .3885 L
.1284 .2725 L
.12842 .16938 L
.12844 .34983 L
.12846 .41428 L
.12849 .25961 L
.12851 .24672 L
.12853 .26391 L
.12855 .21664 L
.12858 .24672 L
.1286 .35413 L
.12862 .32835 L
.12864 .28539 L
.12866 .31546 L
.12869 .30687 L
.12871 .20805 L
.12873 .36272 L
Mistroke
.12875 .52598 L
.12878 .2682 L
.1288 .08346 L
.12882 .31117 L
.12884 .32835 L
.12887 .20805 L
.12889 .40139 L
.12891 .43576 L
.12893 .19516 L
.12895 .20376 L
.12898 .20376 L
.129 .3842 L
.12902 .28968 L
.12904 .22953 L
.12907 .40139 L
.12909 .33265 L
.12911 .18657 L
.12913 .32405 L
.12916 .39709 L
.12918 .23813 L
.1292 .23383 L
.12922 .28539 L
.12925 .22953 L
.12927 .25531 L
.12929 .35843 L
.12931 .32835 L
.12933 .25961 L
.12936 .28968 L
.12938 .28968 L
.1294 .21235 L
.12942 .25531 L
.12945 .47443 L
.12947 .43576 L
.12949 .14361 L
.12951 .16079 L
.12954 .34554 L
.12956 .21664 L
.12958 .25961 L
.1296 .45295 L
.12962 .32405 L
.12965 .16509 L
.12967 .31117 L
.12969 .35843 L
.12971 .21664 L
.12974 .29828 L
.12976 .37991 L
.12978 .22953 L
.1298 .24672 L
.12983 .41857 L
.12985 .33694 L
Mistroke
.12987 .21235 L
.12989 .24242 L
.12991 .25531 L
.12994 .23813 L
.12996 .33265 L
.12998 .37561 L
.13 .31117 L
.13003 .26391 L
.13005 .28539 L
.13007 .28109 L
.13009 .22094 L
.13012 .41428 L
.13014 .5088 L
.13016 .22094 L
.13018 .10494 L
.13021 .34983 L
.13023 .29398 L
.13025 .21235 L
.13027 .41428 L
.13029 .3885 L
.13032 .17368 L
.13034 .27679 L
.13036 .39709 L
.13038 .25531 L
.13041 .24672 L
.13043 .3842 L
.13045 .27679 L
.13047 .21235 L
.1305 .37131 L
.13052 .39709 L
.13054 .24242 L
.13056 .23383 L
.13058 .26391 L
.13061 .22524 L
.13063 .25961 L
.13065 .36272 L
.13067 .32405 L
.1307 .2682 L
.13072 .28968 L
.13074 .29398 L
.13076 .21235 L
.13079 .27679 L
.13081 .49161 L
.13083 .3842 L
.13085 .10494 L
.13088 .23383 L
.1309 .36272 L
.13092 .18657 L
.13094 .30687 L
.13096 .44865 L
Mistroke
.13099 .25102 L
.13101 .19516 L
.13103 .37561 L
.13105 .33265 L
.13108 .22094 L
.1311 .34124 L
.13112 .35843 L
.13114 .23813 L
.13117 .29828 L
.13119 .3928 L
.13121 .28968 L
.13123 .23813 L
.13125 .29398 L
.13128 .28968 L
.1313 .25961 L
.13132 .30257 L
.13134 .30257 L
.13137 .33265 L
.13139 .29828 L
.13141 .29828 L
.13143 .33265 L
.13146 .26391 L
.13148 .19516 L
.1315 .39709 L
.13152 .51739 L
.13154 .25961 L
.13157 .10494 L
.13159 .32835 L
.13161 .29828 L
.13163 .18657 L
.13166 .39709 L
.13168 .42717 L
.1317 .19516 L
.13172 .25102 L
.13175 .40569 L
.13177 .2682 L
.13179 .22524 L
.13181 .35413 L
.13184 .31117 L
.13186 .24672 L
.13188 .33265 L
.1319 .36702 L
.13192 .27679 L
.13195 .25102 L
.13197 .25531 L
.13199 .22953 L
.13201 .25102 L
.13204 .31976 L
.13206 .31546 L
.13208 .30257 L
Mistroke
.1321 .28109 L
.13213 .2725 L
.13215 .21235 L
.13217 .29828 L
.13219 .54317 L
.13221 .34983 L
.13224 .07916 L
.13226 .27679 L
.13228 .29828 L
.1323 .17368 L
.13233 .40569 L
.13235 .44435 L
.13237 .24672 L
.13239 .24672 L
.13242 .3885 L
.13244 .27679 L
.13246 .22953 L
.13248 .36702 L
.13251 .29828 L
.13253 .22094 L
.13255 .35843 L
.13257 .42717 L
.13259 .31117 L
.13262 .25102 L
.13264 .23813 L
.13266 .24242 L
.13268 .24242 L
.13271 .31546 L
.13273 .34124 L
.13275 .32835 L
.13277 .31117 L
.1328 .30257 L
.13282 .24672 L
.13284 .19946 L
.13286 .32835 L
.13288 .51739 L
.13291 .30257 L
.13293 .12212 L
.13295 .32405 L
.13297 .28539 L
.133 .17368 L
.13302 .41428 L
.13304 .40569 L
.13306 .19087 L
.13309 .25961 L
.13311 .37991 L
.13313 .26391 L
.13315 .24242 L
.13317 .37561 L
.1332 .28539 L
Mistroke
.13322 .22524 L
.13324 .34124 L
.13326 .36272 L
.13329 .26391 L
.13331 .2725 L
.13333 .26391 L
.13335 .24242 L
.13338 .26391 L
.1334 .29398 L
.13342 .29828 L
.13344 .28539 L
.13347 .30687 L
.13349 .30687 L
.13351 .22524 L
.13353 .23383 L
.13355 .51739 L
.13358 .43576 L
.1336 .08775 L
.13362 .25961 L
.13364 .33265 L
.13367 .1479 L
.13369 .37131 L
.13371 .37131 L
.13373 .47443 L
.13376 .28968 L
.13378 .22094 L
.1338 .3928 L
.13382 .29398 L
.13384 .18657 L
.13387 .31976 L
.13389 .33265 L
.13391 .25961 L
.13393 .36702 L
.13396 .39709 L
.13398 .26391 L
.134 .21235 L
.13402 .23383 L
.13405 .30257 L
.13407 .28968 L
.13409 .30257 L
.13411 .31117 L
.13414 .31117 L
.13416 .30257 L
.13418 .31546 L
.1342 .28539 L
.13422 .24242 L
.13425 .19516 L
.13427 .30257 L
.13429 .48732 L
.13431 .3842 L
Mistroke
.13434 .17368 L
.13436 .26391 L
.13438 .25531 L
.1344 .17368 L
.13443 .34983 L
.13445 .39709 L
.13447 .2682 L
.13449 .28109 L
.13451 .37991 L
.13454 .28968 L
.13456 .21664 L
.13458 .28968 L
.1346 .29828 L
.13463 .24242 L
.13465 .35413 L
.13467 .37561 L
.13469 .25531 L
.13472 .22094 L
.13474 .26391 L
.13476 .25531 L
.13478 .28109 L
.1348 .34124 L
.13483 .34554 L
.13485 .31546 L
.13487 .29828 L
.13489 .28539 L
.13492 .23383 L
.13494 .22094 L
.13496 .43146 L
.13498 .49591 L
.13501 .19946 L
.13503 .19087 L
.13505 .35413 L
.13507 .19516 L
.1351 .26391 L
.13512 .43146 L
.13514 .31546 L
.13516 .22524 L
.13518 .35413 L
.13521 .35843 L
.13523 .22524 L
.13525 .29828 L
.13527 .35843 L
.1353 .21235 L
.13532 .2725 L
.13534 .3842 L
.13536 .2725 L
.13539 .23813 L
.13541 .29828 L
.13543 .28968 L
Mistroke
.13545 .2682 L
.13547 .29828 L
.1355 .28968 L
.13552 .27679 L
.13554 .31546 L
.13556 .31546 L
.13559 .28109 L
.13561 .22953 L
.13563 .23813 L
.13565 .44865 L
.13568 .43576 L
.1357 .1565 L
.13572 .19946 L
.13574 .34124 L
.13577 .17798 L
.13579 .28109 L
.13581 .44006 L
.13583 .28539 L
.13585 .22953 L
.13588 .37561 L
.1359 .32405 L
.13592 .20376 L
.13594 .30257 L
.13597 .30687 L
.13599 .22094 L
.13601 .31976 L
.13603 .43146 L
.13606 .43146 L
.13608 .31976 L
.1361 .23383 L
.13612 .24672 L
.13614 .25531 L
.13617 .25961 L
.13619 .31976 L
.13621 .32835 L
.13623 .31976 L
.13626 .31546 L
.13628 .30687 L
.1363 .25102 L
.13632 .19946 L
.13635 .39709 L
.13637 .51309 L
.13639 .20376 L
.13641 .12642 L
.13643 .36272 L
.13646 .24242 L
.13648 .22953 L
.1365 .44865 L
.13652 .35413 L
.13655 .19087 L
Mistroke
.13657 .31976 L
.13659 .37131 L
.13661 .20805 L
.13664 .2682 L
.13666 .34554 L
.13668 .25961 L
.1367 .29828 L
.13673 .3885 L
.13675 .34983 L
.13677 .2725 L
.13679 .23383 L
.13681 .22953 L
.13684 .24672 L
.13686 .27679 L
.13688 .32405 L
.1369 .34124 L
.13693 .32835 L
.13695 .30687 L
.13697 .26391 L
.13699 .20376 L
.13702 .18657 L
.13704 .3885 L
.13706 .53887 L
.13708 .22953 L
.1371 .1479 L
.13713 .34554 L
.13715 .20376 L
.13717 .24672 L
.13719 .44006 L
.13722 .33265 L
.13724 .21664 L
.13726 .31976 L
.13728 .37561 L
.13731 .24672 L
.13733 .28968 L
.13735 .33694 L
.13737 .24242 L
.1374 .31117 L
.13742 .3842 L
.13744 .30687 L
.13746 .30257 L
.13748 .2725 L
.13751 .2725 L
.13753 .29398 L
.13755 .29398 L
.13757 .28109 L
.1376 .30687 L
.13762 .32405 L
.13764 .31117 L
.13766 .30257 L
Mistroke
.13769 .2725 L
.13771 .23813 L
.13773 .24242 L
.13775 .26391 L
.13777 .47443 L
.1378 .45724 L
.13782 .13072 L
.13784 .19087 L
.13786 .34124 L
.13789 .18657 L
.13791 .31117 L
.13793 .44865 L
.13795 .28968 L
.13798 .22524 L
.138 .37991 L
.13802 .32835 L
.13804 .18227 L
.13806 .29398 L
.13809 .31117 L
.13811 .24242 L
.13813 .33694 L
.13815 .37991 L
.13818 .30687 L
.1382 .26391 L
.13822 .24242 L
.13824 .25531 L
.13827 .2682 L
.13829 .28109 L
.13831 .31546 L
.13833 .33694 L
.13836 .31546 L
.13838 .29828 L
.1384 .2725 L
.13842 .2725 L
.13844 .24242 L
.13847 .23813 L
.13849 .2682 L
.13851 .45724 L
.13853 .45724 L
.13856 .16509 L
.13858 .19087 L
.1386 .35843 L
.13862 .22524 L
.13865 .29828 L
.13867 .42717 L
.13869 .29828 L
.13871 .22524 L
.13873 .37131 L
.13876 .34983 L
.13878 .22094 L
Mistroke
.1388 .29398 L
.13882 .31546 L
.13885 .26391 L
.13887 .32405 L
.13889 .36272 L
.13891 .31117 L
.13894 .28109 L
.13896 .25961 L
.13898 .26391 L
.139 .2725 L
.13903 .28539 L
.13905 .29828 L
.13907 .31546 L
.13909 .31976 L
.13911 .30257 L
.13914 .25961 L
.13916 .24672 L
.13918 .22953 L
.1392 .28968 L
.13923 .51309 L
.13925 .36702 L
.13927 .09205 L
.13929 .2682 L
.13932 .33694 L
.13934 .18227 L
.13936 .34983 L
.13938 .39709 L
.1394 .23383 L
.13943 .24672 L
.13945 .40139 L
.13947 .29398 L
.13949 .20376 L
.13952 .31546 L
.13954 .28539 L
.13956 .25961 L
.13958 .34983 L
.13961 .30257 L
.13963 .29398 L
.13965 .31976 L
.13967 .27679 L
.13969 .2682 L
.13972 .27679 L
.13974 .24672 L
.13976 .28109 L
.13978 .34124 L
.13981 .33265 L
.13983 .31117 L
.13985 .30687 L
.13987 .25102 L
.1399 .24242 L
Mistroke
.13992 .25961 L
.13994 .40998 L
.13996 .47872 L
.13999 .22094 L
.14001 .1522 L
.14003 .37561 L
.14005 .2725 L
.14007 .21664 L
.1401 .40139 L
.14012 .33694 L
.14014 .21235 L
.14016 .35413 L
.14019 .37991 L
.14021 .20376 L
.14023 .23813 L
.14025 .33694 L
.14028 .27679 L
.1403 .31976 L
.14032 .34554 L
.14034 .27679 L
.14036 .29398 L
.14039 .28968 L
.14041 .23813 L
.14043 .2725 L
.14045 .28539 L
.14048 .2725 L
.1405 .29828 L
.14052 .31546 L
.14054 .29398 L
.14057 .29398 L
.14059 .25961 L
.14061 .23813 L
.14063 .21664 L
.14065 .37991 L
.14068 .52598 L
.1407 .22094 L
.14072 .11353 L
.14074 .37561 L
.14077 .24242 L
.14079 .24242 L
.14081 .18657 L
.14083 .41428 L
.14086 .33694 L
.14088 .22094 L
.1409 .35413 L
.14092 .37991 L
.14095 .19946 L
.14097 .24242 L
.14099 .33694 L
.14101 .25531 L
Mistroke
.14103 .32405 L
.14106 .36272 L
.14108 .28109 L
.1411 .31976 L
.14112 .31546 L
.14115 .26391 L
.14117 .29398 L
.14119 .28539 L
.14121 .24672 L
.14124 .31117 L
.14126 .34983 L
.14128 .30687 L
.1413 .32405 L
.14132 .29828 L
.14135 .25102 L
.14137 .23813 L
.14139 .31546 L
.14141 .5045 L
.14144 .32835 L
.14146 .09635 L
.14148 .32405 L
.1415 .34124 L
.14153 .17798 L
.14155 .36272 L
.14157 .37131 L
.14159 .22094 L
.14162 .29398 L
.14164 .40569 L
.14166 .25102 L
.14168 .20805 L
.1417 .33694 L
.14173 .27679 L
.14175 .28539 L
.14177 .37991 L
.14179 .27679 L
.14182 .2682 L
.14184 .31117 L
.14186 .24672 L
.14188 .26391 L
.14191 .30687 L
.14193 .2682 L
.14195 .28968 L
.14197 .33694 L
.14199 .29828 L
.14202 .27679 L
.14204 .29398 L
.14206 .25531 L
.14208 .28109 L
.14211 .2682 L
.14213 .25961 L
Mistroke
.14215 .48302 L
.14217 .3885 L
.1422 .09635 L
.14222 .28539 L
.14224 .36702 L
.14226 .16938 L
.14228 .32405 L
.14231 .3928 L
.14233 .25531 L
.14235 .28968 L
.14237 .41857 L
.1424 .30687 L
.14242 .21664 L
.14244 .32405 L
.14246 .28968 L
.14249 .2682 L
.14251 .35843 L
.14253 .30257 L
.14255 .31117 L
.14258 .33694 L
.1426 .25102 L
.14262 .24672 L
.14264 .30257 L
.14266 .28968 L
.14269 .30687 L
.14271 .33265 L
.14273 .28109 L
.14275 .29398 L
.14278 .31117 L
.1428 .25961 L
.14282 .25102 L
.14284 .25102 L
.14287 .43576 L
.14289 .44006 L
.14291 .13072 L
.14293 .24242 L
.14295 .36272 L
.14298 .18227 L
.143 .29828 L
.14302 .37991 L
.14304 .2682 L
.14307 .25102 L
.14309 .37561 L
.14311 .33265 L
.14313 .21664 L
.14316 .21664 L
.14318 .30257 L
.1432 .28539 L
.14322 .24242 L
.14325 .33694 L
Mistroke
.14327 .28968 L
.14329 .28539 L
.14331 .32835 L
.14333 .28968 L
.14336 .25531 L
.14338 .25961 L
.1434 .25102 L
.14342 .29398 L
.14345 .34983 L
.14347 .28968 L
.14349 .29398 L
.14351 .33265 L
.14354 .25102 L
.14356 .25102 L
.14358 .23813 L
.1436 .3885 L
.14362 .50021 L
.14365 .19087 L
.14367 .21664 L
.14369 .3928 L
.14371 .19516 L
.14374 .2682 L
.14376 .3885 L
.14378 .30257 L
.1438 .26391 L
.14383 .3885 L
.14385 .36272 L
.14387 .22094 L
.14389 .29398 L
.14391 .31976 L
.14394 .25531 L
.14396 .32405 L
.14398 .30687 L
.144 .28968 L
.14403 .31976 L
.14405 .30257 L
.14407 .25531 L
.14409 .2682 L
.14412 .25961 L
.14414 .25531 L
.14416 .35843 L
.14418 .32835 L
.14421 .27679 L
.14423 .30257 L
.14425 .25531 L
.14427 .24672 L
.14429 .23383 L
.14432 .40139 L
.14434 .47872 L
.14436 .1522 L
Mistroke
.14438 .20376 L
.14441 .40569 L
.14443 .19516 L
.14445 .22953 L
.14447 .37131 L
.1445 .2725 L
.14452 .25102 L
.14454 .3928 L
.14456 .34983 L
.14458 .20376 L
.14461 .29398 L
.14463 .31976 L
.14465 .24672 L
.14467 .31546 L
.1447 .30687 L
.14472 .2725 L
.14474 .29828 L
.14476 .28968 L
.14479 .26391 L
.14481 .30257 L
.14483 .30687 L
.14485 .28109 L
.14488 .32835 L
.1449 .29398 L
.14492 .28539 L
.14494 .32405 L
.14496 .2725 L
.14499 .28109 L
.14501 .25961 L
.14503 .30257 L
.14505 .52169 L
.14508 .34554 L
.1451 .10494 L
.14512 .34554 L
.14514 .33265 L
.14517 .1522 L
.14519 .34124 L
.14521 .34983 L
.14523 .24672 L
.14525 .34554 L
.14528 .41428 L
.1453 .26391 L
.14532 .22953 L
.14534 .33265 L
.14537 .25961 L
.14539 .26391 L
.14541 .32835 L
.14543 .26391 L
.14546 .30257 L
.14548 .33694 L
Mistroke
.1455 .28109 L
.14552 .28109 L
.14554 .26391 L
.14557 .2682 L
.14559 .21664 L
.14561 .29398 L
.14563 .34983 L
.14566 .27679 L
.14568 .30257 L
.1457 .29828 L
.14572 .23383 L
.14575 .22094 L
.14577 .41857 L
.14579 .49161 L
.14581 .12642 L
.14584 .19946 L
.14586 .43576 L
.14588 .18657 L
.1459 .23813 L
.14592 .37131 L
.14595 .2682 L
.14597 .28109 L
.14599 .37991 L
.14601 .33694 L
.14604 .22524 L
.14606 .29398 L
.14608 .31546 L
.1461 .27679 L
.14613 .30687 L
.14615 .28539 L
.14617 .31546 L
.14619 .32835 L
.14621 .29398 L
.14624 .28968 L
.14626 .28968 L
.14628 .23813 L
.1463 .25961 L
.14633 .34124 L
.14635 .31117 L
.14637 .31976 L
.14639 .32405 L
.14642 .25102 L
.14644 .22953 L
.14646 .44006 L
.14648 .49161 L
.14651 .10494 L
.14653 .20376 L
.14655 .44435 L
.14657 .19087 L
.14659 .25961 L
Mistroke
.14662 .35843 L
.14664 .26391 L
.14666 .28539 L
.14668 .37561 L
.14671 .34124 L
.14673 .22524 L
.14675 .28109 L
.14677 .29828 L
.1468 .2725 L
.14682 .31976 L
.14684 .28539 L
.14686 .28539 L
.14688 .31117 L
.14691 .28539 L
.14693 .2682 L
.14695 .2725 L
.14697 .23813 L
.147 .2725 L
.14702 .33694 L
.14704 .27679 L
.14706 .31546 L
.14709 .31117 L
.14711 .24242 L
.14713 .24672 L
.14715 .25961 L
.14717 .47872 L
.1472 .36702 L
.14722 .09635 L
.14724 .35413 L
.14726 .34554 L
.14729 .18227 L
.14731 .31976 L
.14733 .30257 L
.14735 .2682 L
.14738 .31546 L
.1474 .3885 L
.14742 .30257 L
.14744 .2682 L
.14747 .32835 L
.14749 .29828 L
.14751 .28968 L
.14753 .31546 L
.14755 .28109 L
.14758 .28109 L
.1476 .32405 L
.14762 .31117 L
.14764 .28109 L
.14767 .29398 L
.14769 .23813 L
.14771 .30257 L
Mistroke
.14773 .32405 L
.14776 .31976 L
.14778 .31976 L
.1478 .25961 L
.14782 .23383 L
.14784 .2725 L
.14787 .51739 L
.14789 .51739 L
.14791 .33694 L
.14793 .08346 L
.14796 .3928 L
.14798 .33694 L
.148 .16079 L
.14802 .31117 L
.14805 .30687 L
.14807 .25531 L
.14809 .31976 L
.14811 .3842 L
.14814 .25531 L
.14816 .2725 L
.14818 .34983 L
.1482 .28968 L
.14822 .27679 L
.14825 .2682 L
.14827 .28109 L
.14829 .28968 L
.14831 .28968 L
.14834 .28109 L
.14836 .30687 L
.14838 .28109 L
.1484 .22524 L
.14843 .31117 L
.14845 .30687 L
.14847 .28109 L
.14849 .28968 L
.14851 .26391 L
.14854 .23383 L
.14856 .41857 L
.14858 .48302 L
.1486 .12212 L
.14863 .26391 L
.14865 .43576 L
.14867 .18227 L
.14869 .25531 L
.14872 .31976 L
.14874 .26391 L
.14876 .31546 L
.14878 .3928 L
.1488 .30687 L
.14883 .28539 L
Mistroke
.14885 .34983 L
.14887 .29828 L
.14889 .31117 L
.14892 .28109 L
.14894 .25531 L
.14896 .30687 L
.14898 .30687 L
.14901 .28539 L
.14903 .28539 L
.14905 .32835 L
.14907 .25102 L
.1491 .2725 L
.14912 .33694 L
.14914 .29398 L
.14916 .28539 L
.14918 .28539 L
.14921 .23383 L
.14923 .31546 L
.14925 .5088 L
.14927 .23813 L
.1493 .14361 L
.14932 .44006 L
.14934 .28109 L
.14936 .19087 L
.14939 .31117 L
.14941 .26391 L
.14943 .2682 L
.14945 .35843 L
.14947 .31976 L
.1495 .25531 L
.14952 .33265 L
.14954 .33265 L
.14956 .29398 L
.14959 .29828 L
.14961 .25531 L
.14963 .25961 L
.14965 .29828 L
.14968 .27679 L
.1497 .23813 L
.14972 .32835 L
.14974 .27679 L
.14977 .26391 L
.14979 .32835 L
.14981 .29398 L
.14983 .29398 L
.14985 .29398 L
.14988 .23813 L
.1499 .30257 L
.14992 .5045 L
.14994 .25531 L
Mistroke
.14997 .13501 L
.14999 .45724 L
.15001 .29398 L
.15003 .18657 L
.15006 .34983 L
.15008 .27679 L
.1501 .26391 L
.15012 .36272 L
.15014 .32835 L
.15017 .2725 L
.15019 .33694 L
.15021 .34983 L
.15023 .29828 L
.15026 .29828 L
.15028 .28968 L
.1503 .28968 L
.15032 .28109 L
.15035 .29398 L
.15037 .29398 L
.15039 .24672 L
.15041 .31976 L
.15043 .29398 L
.15046 .25961 L
.15048 .30687 L
.1505 .2725 L
.15052 .28539 L
.15055 .28968 L
.15057 .22094 L
.15059 .3885 L
.15061 .48302 L
.15064 .1479 L
.15066 .25531 L
.15068 .45295 L
.1507 .19946 L
.15073 .22094 L
.15075 .30257 L
.15077 .25531 L
.15079 .27679 L
.15081 .33694 L
.15084 .30257 L
.15086 .27679 L
.15088 .34983 L
.1509 .34124 L
.15093 .27679 L
.15095 .29828 L
.15097 .2725 L
.15099 .25102 L
.15102 .30687 L
.15104 .26391 L
.15106 .24242 L
Mistroke
.15108 .32835 L
.1511 .25531 L
.15113 .28539 L
.15115 .31976 L
.15117 .29398 L
.15119 .30257 L
.15122 .29828 L
.15124 .24672 L
.15126 .30257 L
.15128 .49591 L
.15131 .25961 L
.15133 .1479 L
.15135 .45724 L
.15137 .31976 L
.1514 .17798 L
.15142 .31546 L
.15144 .29828 L
.15146 .2725 L
.15148 .33265 L
.15151 .32405 L
.15153 .2682 L
.15155 .32835 L
.15157 .35843 L
.1516 .30257 L
.15162 .28539 L
.15164 .30257 L
.15166 .28968 L
.15169 .28539 L
.15171 .2682 L
.15173 .24672 L
.15175 .31117 L
.15177 .2725 L
.1518 .25531 L
.15182 .31546 L
.15184 .28109 L
.15186 .2682 L
.15189 .29828 L
.15191 .24242 L
.15193 .41857 L
.15195 .44006 L
.15198 .11353 L
.152 .31117 L
.15202 .43146 L
.15204 .18227 L
.15206 .22953 L
.15209 .28968 L
.15211 .25531 L
.15213 .27679 L
.15215 .32405 L
.15218 .27679 L
Mistroke
.1522 .28968 L
.15222 .37131 L
.15224 .33694 L
.15227 .28109 L
.15229 .29398 L
.15231 .30257 L
.15233 .25531 L
.15236 .28968 L
.15238 .25102 L
.1524 .26391 L
.15242 .31546 L
.15244 .26391 L
.15247 .29398 L
.15249 .31117 L
.15251 .28539 L
.15253 .31117 L
.15256 .30257 L
.15258 .29398 L
.1526 .47013 L
.15262 .47013 L
.15265 .31976 L
.15267 .1479 L
.15269 .43146 L
.15271 .33265 L
.15273 .17368 L
.15276 .29828 L
.15278 .30257 L
.1528 .26391 L
.15282 .30257 L
.15285 .31117 L
.15287 .27679 L
.15289 .33694 L
.15291 .36702 L
.15294 .31976 L
.15296 .30257 L
.15298 .29398 L
.153 .28109 L
.15303 .2725 L
.15305 .28539 L
.15307 .23813 L
.15309 .28968 L
.15311 .27679 L
.15314 .24672 L
.15316 .29398 L
.15318 .28968 L
.1532 .2725 L
.15323 .30687 L
.15325 .26391 L
.15327 .40569 L
.15329 .41428 L
Mistroke
.15332 .12212 L
.15334 .34124 L
.15336 .43146 L
.15338 .16938 L
.1534 .22953 L
.15343 .28968 L
.15345 .25531 L
.15347 .2725 L
.15349 .29828 L
.15352 .2682 L
.15354 .31546 L
.15356 .34554 L
.15358 .32405 L
.15361 .32405 L
.15363 .31117 L
.15365 .31546 L
.15367 .27679 L
.15369 .27679 L
.15372 .24242 L
.15374 .27679 L
.15376 .30257 L
.15378 .25961 L
.15381 .28539 L
.15383 .31117 L
.15385 .27679 L
.15387 .28968 L
.1539 .29828 L
.15392 .40139 L
.15394 .45724 L
.15396 .17368 L
.15399 .30257 L
.15401 .46154 L
.15403 .20805 L
.15405 .22094 L
.15407 .30687 L
.1541 .2682 L
.15412 .2725 L
.15414 .27679 L
.15416 .26391 L
.15419 .31546 L
.15421 .34983 L
.15423 .33694 L
.15425 .32835 L
.15428 .33265 L
.1543 .33265 L
.15432 .25961 L
.15434 .2725 L
.15436 .2725 L
.15439 .25102 L
.15441 .26391 L
Mistroke
.15443 .23813 L
.15445 .26391 L
.15448 .29398 L
.1545 .25102 L
.15452 .26391 L
.15454 .29398 L
.15457 .31546 L
.15459 .48732 L
.15461 .25961 L
.15463 .18657 L
.15466 .47872 L
.15468 .29398 L
.1547 .1479 L
.15472 .28109 L
.15474 .28109 L
.15477 .25102 L
.15479 .25961 L
.15481 .23813 L
.15483 .30257 L
.15486 .34554 L
.15488 .33694 L
.1549 .34124 L
.15492 .32405 L
.15495 .37561 L
.15497 .37561 L
.15499 .31117 L
.15501 .25531 L
.15503 .28968 L
.15506 .28539 L
.15508 .28109 L
.1551 .24242 L
.15512 .25531 L
.15515 .30257 L
.15517 .28109 L
.15519 .24672 L
.15521 .28109 L
.15524 .35843 L
.15526 .50021 L
.15528 .25961 L
.1553 .21664 L
.15532 .5088 L
.15535 .32835 L
.15537 .16938 L
.15539 .29398 L
.15541 .28968 L
.15544 .25531 L
.15546 .24672 L
.15548 .21664 L
.1555 .30257 L
.15553 .34124 L
Mistroke
.15555 .31976 L
.15557 .32835 L
.15559 .32405 L
.15562 .3928 L
.15564 .31546 L
.15566 .24242 L
.15568 .30257 L
.1557 .28539 L
.15573 .25102 L
.15575 .22524 L
.15577 .24242 L
.15579 .28109 L
.15582 .2682 L
.15584 .20805 L
.15586 .25102 L
.15588 .31546 L
.15591 .47872 L
.15593 .28968 L
.15595 .19087 L
.15597 .50021 L
.15599 .36702 L
.15602 .16509 L
.15604 .28109 L
.15606 .30687 L
.15608 .26391 L
.15611 .23813 L
.15613 .19946 L
.15615 .28539 L
.15617 .33694 L
.1562 .28968 L
.15622 .31117 L
.15624 .35413 L
.15626 .41428 L
.15628 .32405 L
.15631 .26391 L
.15633 .34124 L
.15635 .31117 L
.15637 .2682 L
.1564 .25102 L
.15642 .26391 L
.15644 .29828 L
.15646 .25531 L
.15649 .21235 L
.15651 .26391 L
.15653 .32405 L
.15655 .47443 L
.15658 .25531 L
.1566 .22094 L
.15662 .51739 L
.15664 .37131 L
Mistroke
.15666 .19946 L
.15669 .31976 L
.15671 .33694 L
.15673 .2682 L
.15675 .22524 L
.15678 .18657 L
.1568 .29398 L
.15682 .31976 L
.15684 .23813 L
.15687 .29398 L
.15689 .33694 L
.15691 .36702 L
.15693 .29398 L
.15695 .28109 L
.15698 .34983 L
.157 .30257 L
.15702 .25102 L
.15704 .24242 L
.15707 .2725 L
.15709 .28968 L
.15711 .23383 L
.15713 .19946 L
.15716 .24672 L
.15718 .3928 L
.1572 .33265 L
.15722 .16938 L
.15725 .39709 L
.15727 .45724 L
.15729 .25531 L
.15731 .27679 L
.15733 .27679 L
.15736 .35413 L
.15738 .31546 L
.1574 .28109 L
.15742 .21235 L
.15745 .25102 L
.15747 .31546 L
.15749 .25531 L
.15751 .24672 L
.15754 .31546 L
.15756 .35843 L
.15758 .32405 L
.1576 .2682 L
.15762 .33694 L
.15765 .34124 L
.15767 .29828 L
.15769 .27679 L
.15771 .29398 L
.15774 .30687 L
.15776 .2682 L
Mistroke
.15778 .20376 L
.1578 .34983 L
.15783 .35843 L
.15785 .18227 L
.15787 .34554 L
.15789 .41428 L
.15791 .2682 L
.15794 .29398 L
.15796 .35843 L
.15798 .31117 L
.158 .31117 L
.15803 .27679 L
.15805 .24672 L
.15807 .30257 L
.15809 .25961 L
.15812 .24242 L
.15814 .28968 L
.15816 .30687 L
.15818 .28539 L
.15821 .25961 L
.15823 .28539 L
.15825 .30687 L
.15827 .31117 L
.15829 .2725 L
.15832 .27679 L
.15834 .28968 L
.15836 .2725 L
.15838 .23383 L
.15841 .37131 L
.15843 .31976 L
.15845 .17798 L
.15847 .37991 L
.1585 .34983 L
.15852 .21664 L
.15854 .32405 L
.15856 .35843 L
.15858 .29398 L
.15861 .30257 L
.15863 .25961 L
.15865 .27679 L
.15867 .31976 L
.1587 .25961 L
.15872 .27679 L
.15874 .31117 L
.15876 .31117 L
.15879 .30257 L
.15881 .28109 L
.15883 .30687 L
.15885 .32405 L
.15888 .31546 L
Mistroke
.1589 .26391 L
.15892 .29398 L
.15894 .31117 L
.15896 .28968 L
.15899 .23813 L
.15901 .28539 L
.15903 .42287 L
.15905 .23813 L
.15908 .22524 L
.1591 .42717 L
.15912 .32835 L
.15914 .25531 L
.15917 .34124 L
.15919 .34124 L
.15921 .31546 L
.15923 .28539 L
.15925 .24242 L
.15928 .32405 L
.1593 .29828 L
.15932 .23383 L
.15934 .2682 L
.15937 .29828 L
.15939 .29828 L
.15941 .2725 L
.15943 .27679 L
.15946 .31546 L
.15948 .30687 L
.1595 .25961 L
.15952 .25531 L
.15954 .29828 L
.15957 .29828 L
.15959 .25961 L
.15961 .24672 L
.15963 .3842 L
.15966 .27679 L
.15968 .19516 L
.1597 .19516 L
.15972 .40139 L
.15975 .34124 L
.15977 .23383 L
.15979 .32835 L
.15981 .33265 L
.15984 .28539 L
.15986 .30687 L
.15988 .26391 L
.1599 .29828 L
.15992 .31976 L
.15995 .24672 L
.15997 .2682 L
.15999 .31546 L
Mistroke
.16001 .30687 L
.16004 .28539 L
.16006 .28968 L
.16008 .31117 L
.1601 .31976 L
.16013 .28968 L
.16015 .27679 L
.16017 .30687 L
.16019 .30257 L
.16021 .2682 L
.16024 .25102 L
.16026 .36702 L
.16028 .34983 L
.1603 .19516 L
.16033 .35413 L
.16035 .39709 L
.16037 .25961 L
.16039 .30257 L
.16042 .36272 L
.16044 .31976 L
.16046 .30687 L
.16048 .26391 L
.16051 .28968 L
.16053 .32835 L
.16055 .24672 L
.16057 .25961 L
.16059 .30687 L
.16062 .28968 L
.16064 .2725 L
.16066 .2725 L
.16068 .29828 L
.16071 .31117 L
.16073 .27679 L
.16075 .2725 L
.16077 .29398 L
.1608 .28539 L
.16082 .2682 L
.16084 .24242 L
.16086 .31546 L
.16088 .36702 L
.16091 .18227 L
.16093 .30687 L
.16095 .40998 L
.16097 .23813 L
.161 .27679 L
.16102 .37561 L
.16104 .31117 L
.16106 .28968 L
.16109 .28109 L
.16111 .29398 L
Mistroke
.16113 .33265 L
.16115 .24672 L
.16117 .25102 L
.1612 .31976 L
.16122 .29398 L
.16124 .25531 L
.16126 .28539 L
.16129 .31976 L
.16131 .30687 L
.16133 .27679 L
.16135 .30257 L
.16138 .30687 L
.1614 .28968 L
.16142 .28539 L
.16144 .2725 L
.16147 .30687 L
.16149 .37991 L
.16151 .21235 L
.16153 .28109 L
.16155 .43146 L
.16158 .2682 L
.1616 .24672 L
.16162 .37991 L
.16164 .34124 L
.16167 .28539 L
.16169 .28968 L
.16171 .31117 L
.16173 .34554 L
.16176 .24672 L
.16178 .25102 L
.1618 .31976 L
.16182 .28539 L
.16184 .24672 L
.16187 .28109 L
.16189 .29828 L
.16191 .28968 L
.16193 .25961 L
.16196 .28968 L
.16198 .29828 L
.162 .2725 L
.16202 .27679 L
.16205 .28109 L
.16207 .28109 L
.16209 .27679 L
.16211 .37561 L
.16214 .23383 L
.16216 .23813 L
.16218 .42717 L
.1622 .2682 L
.16222 .22524 L
Mistroke
.16225 .37131 L
.16227 .33694 L
.16229 .26391 L
.16231 .28968 L
.16234 .31976 L
.16236 .33265 L
.16238 .24242 L
.1624 .2682 L
.16243 .34124 L
.16245 .28539 L
.16247 .24242 L
.16249 .29398 L
.16251 .31117 L
.16254 .27679 L
.16256 .25961 L
.16258 .31546 L
.1626 .30687 L
.16263 .26391 L
.16265 .29398 L
.16267 .30687 L
.16269 .2725 L
.16272 .37561 L
.16274 .2725 L
.16276 .23813 L
.16278 .43576 L
.1628 .28968 L
.16283 .22524 L
.16285 .37991 L
.16287 .36702 L
.16289 .25531 L
.16292 .29398 L
.16294 .34124 L
.16296 .32835 L
.16298 .24242 L
.16301 .2682 L
.16303 .34554 L
.16305 .28109 L
.16307 .23813 L
.1631 .30257 L
.16312 .30687 L
.16314 .25961 L
.16316 .26391 L
.16318 .31117 L
.16321 .28109 L
.16323 .24242 L
.16325 .28539 L
.16327 .29398 L
.1633 .24672 L
.16332 .34554 L
.16334 .30687 L
Mistroke
.16336 .19516 L
.16339 .40139 L
.16341 .32835 L
.16343 .21235 L
.16345 .34983 L
.16347 .36702 L
.1635 .25531 L
.16352 .28968 L
.16354 .32835 L
.16356 .31546 L
.16359 .25961 L
.16361 .2682 L
.16363 .33265 L
.16365 .28109 L
.16368 .24242 L
.1637 .29828 L
.16372 .31117 L
.16374 .26391 L
.16377 .27679 L
.16379 .31976 L
.16381 .29398 L
.16383 .25102 L
.16385 .31117 L
.16388 .30687 L
.1639 .25102 L
.16392 .31117 L
.16394 .37561 L
.16397 .19946 L
.16399 .31976 L
.16401 .40998 L
.16403 .23813 L
.16406 .29828 L
.16408 .3928 L
.1641 .31546 L
.16412 .2682 L
.16414 .32835 L
.16417 .34983 L
.16419 .28968 L
.16421 .25102 L
.16423 .32835 L
.16426 .31117 L
.16428 .23813 L
.1643 .27679 L
.16432 .32835 L
.16435 .26391 L
.16437 .25531 L
.16439 .30687 L
.16441 .30257 L
.16443 .30257 L
.16446 .24242 L
Mistroke
.16448 .28968 L
.1645 .30687 L
.16452 .25531 L
.16455 .25102 L
.16457 .35843 L
.16459 .28109 L
.16461 .19516 L
.16464 .39709 L
.16466 .31117 L
.16468 .21235 L
.1647 .34983 L
.16473 .35413 L
.16475 .2682 L
.16477 .28539 L
.16479 .34124 L
.16481 .31976 L
.16484 .25102 L
.16486 .28109 L
.16488 .33694 L
.1649 .2725 L
.16493 .25102 L
.16495 .30687 L
.16497 .30687 L
.16499 .23813 L
.16502 .28109 L
.16504 .33265 L
.16506 .27679 L
.16508 .25531 L
.1651 .33265 L
.16513 .29398 L
.16515 .25961 L
.16517 .28968 L
.16519 .36702 L
.16522 .28109 L
.16524 .22524 L
.16526 .40139 L
.16528 .30687 L
.16531 .23383 L
.16533 .35843 L
.16535 .35843 L
.16537 .27679 L
.1654 .28109 L
.16542 .35413 L
.16544 .31976 L
.16546 .25102 L
.16548 .30687 L
.16551 .35413 L
.16553 .25531 L
.16555 .25961 L
.16557 .33265 L
Mistroke
.1656 .29828 L
.16562 .22953 L
.16564 .30257 L
.16566 .32835 L
.16569 .24242 L
.16571 .25961 L
.16573 .33265 L
.16575 .2725 L
.16577 .24672 L
.1658 .29828 L
.16582 .30687 L
.16584 .30687 L
.16586 .23383 L
.16589 .31117 L
.16591 .35843 L
.16593 .22524 L
.16595 .29398 L
.16598 .34983 L
.166 .29828 L
.16602 .24242 L
.16604 .32835 L
.16606 .33694 L
.16609 .25531 L
.16611 .2682 L
.16613 .35413 L
.16615 .28968 L
.16618 .23813 L
.1662 .33265 L
.16622 .31546 L
.16624 .23813 L
.16627 .28968 L
.16629 .33694 L
.16631 .25961 L
.16633 .2682 L
.16636 .32835 L
.16638 .30257 L
.1664 .25961 L
.16642 .31117 L
.16644 .31117 L
.16647 .28109 L
.16649 .32405 L
.16651 .29828 L
.16653 .27679 L
.16656 .34554 L
.16658 .27679 L
.1666 .29398 L
.16662 .32835 L
.16665 .30687 L
.16667 .27679 L
.16669 .31546 L
Mistroke
.16671 .31976 L
.16673 .28109 L
.16676 .29398 L
.16678 .32405 L
.1668 .32405 L
.16682 .29828 L
.16685 .2725 L
.16687 .32835 L
.16689 .29828 L
.16691 .28109 L
.16694 .28968 L
.16696 .30257 L
.16698 .27679 L
.167 .28539 L
.16703 .29398 L
.16705 .29828 L
.16707 .27679 L
.16709 .29828 L
.16711 .28968 L
.16714 .28109 L
.16716 .28109 L
.16718 .32835 L
.1672 .26391 L
.16723 .25961 L
.16725 .34983 L
.16727 .25961 L
.16729 .26391 L
.16732 .32835 L
.16734 .30257 L
.16736 .24672 L
.16738 .29398 L
.1674 .32405 L
.16743 .27679 L
.16745 .27679 L
.16747 .33265 L
.16749 .30687 L
.16752 .26391 L
.16754 .31976 L
.16756 .32835 L
.16758 .27679 L
.16761 .29398 L
.16763 .34124 L
.16765 .28109 L
.16767 .2725 L
.16769 .32835 L
.16772 .31546 L
.16774 .2725 L
.16776 .31546 L
.16778 .32835 L
.16781 .2725 L
Mistroke
.16783 .28539 L
.16785 .31546 L
.16787 .31546 L
.1679 .26391 L
.16792 .29828 L
.16794 .33265 L
.16796 .25102 L
.16799 .28109 L
.16801 .33265 L
.16803 .28968 L
.16805 .25961 L
.16807 .32405 L
.1681 .31546 L
.16812 .26391 L
.16814 .29398 L
.16816 .33694 L
.16819 .29398 L
.16821 .26391 L
.16823 .32835 L
.16825 .31546 L
.16828 .26391 L
.1683 .29828 L
.16832 .34124 L
.16834 .25531 L
.16836 .2725 L
.16839 .34124 L
.16841 .28968 L
.16843 .26391 L
.16845 .31546 L
.16848 .29398 L
.1685 .25961 L
.16852 .28968 L
.16854 .30687 L
.16857 .2682 L
.16859 .28968 L
.16861 .28539 L
.16863 .2682 L
.16866 .29398 L
.16868 .2725 L
.1687 .29828 L
.16872 .29828 L
.16874 .28968 L
.16877 .28539 L
.16879 .30257 L
.16881 .29828 L
.16883 .29828 L
.16886 .31117 L
.16888 .31546 L
.1689 .29828 L
.16892 .29828 L
Mistroke
.16895 .31117 L
.16897 .30257 L
.16899 .31117 L
.16901 .31117 L
.16903 .30687 L
.16906 .29398 L
.16908 .30257 L
.1691 .30687 L
.16912 .31117 L
.16915 .28968 L
.16917 .28968 L
.16919 .30257 L
.16921 .30687 L
.16924 .28109 L
.16926 .29398 L
.16928 .29828 L
.1693 .28109 L
.16932 .28539 L
.16935 .29828 L
.16937 .2725 L
.16939 .28539 L
.16941 .30687 L
.16944 .28109 L
.16946 .28109 L
.16948 .30257 L
.1695 .28968 L
.16953 .27679 L
.16955 .30687 L
.16957 .30687 L
.16959 .28109 L
.16962 .28968 L
.16964 .31117 L
.16966 .29398 L
.16968 .28968 L
.1697 .30687 L
.16973 .30257 L
.16975 .28539 L
.16977 .28539 L
.16979 .30687 L
.16982 .28968 L
.16984 .28539 L
.16986 .30257 L
.16988 .29398 L
.16991 .28539 L
.16993 .29398 L
.16995 .29828 L
.16997 .29398 L
.16999 .28968 L
.17002 .30257 L
.17004 .28968 L
Mistroke
.17006 .28539 L
.17008 .30257 L
.17011 .29828 L
.17013 .28539 L
.17015 .30257 L
.17017 .30687 L
.1702 .28539 L
.17022 .30257 L
.17024 .31117 L
.17026 .29398 L
.17029 .29398 L
.17031 .31546 L
.17033 .30257 L
.17035 .29398 L
.17037 .31117 L
.1704 .30687 L
.17042 .28968 L
.17044 .30257 L
.17046 .31117 L
.17049 .29828 L
.17051 .29398 L
.17053 .30687 L
.17055 .29828 L
.17058 .28539 L
.1706 .30257 L
.17062 .31546 L
.17064 .29398 L
.17066 .29828 L
.17069 .30257 L
.17071 .28968 L
.17073 .29398 L
.17075 .30257 L
.17078 .29828 L
.1708 .28539 L
.17082 .28968 L
.17084 .28968 L
.17087 .28539 L
.17089 .28968 L
.17091 .29828 L
.17093 .28539 L
.17095 .27679 L
.17098 .28539 L
.171 .28968 L
.17102 .28968 L
.17104 .29828 L
.17107 .29828 L
.17109 .28109 L
.17111 .27679 L
.17113 .29398 L
.17116 .29828 L
Mistroke
.17118 .29828 L
.1712 .29828 L
.17122 .29828 L
.17125 .28539 L
.17127 .28968 L
.17129 .31117 L
.17131 .31117 L
.17133 .30257 L
.17136 .30687 L
.17138 .29828 L
.1714 .29828 L
.17142 .30257 L
.17145 .31117 L
.17147 .31117 L
.17149 .30257 L
.17151 .29828 L
.17154 .29828 L
.17156 .29398 L
.17158 .28968 L
.1716 .30257 L
.17162 .30687 L
.17165 .28968 L
.17167 .28968 L
.17169 .28539 L
.17171 .28539 L
.17174 .29398 L
.17176 .29828 L
.17178 .29828 L
.1718 .28539 L
.17183 .28539 L
.17185 .29398 L
.17187 .29828 L
.17189 .30257 L
.17191 .30257 L
.17194 .29398 L
.17196 .28968 L
.17198 .29398 L
.172 .30257 L
.17203 .30257 L
.17205 .29828 L
.17207 .29398 L
.17209 .28968 L
.17212 .29398 L
.17214 .30257 L
.17216 .30257 L
.17218 .29398 L
.17221 .28968 L
.17223 .28968 L
.17225 .28968 L
.17227 .29398 L
Mistroke
.17229 .29828 L
.17232 .28539 L
.17234 .27679 L
.17236 .28109 L
.17238 .28539 L
.17241 .28968 L
.17243 .28968 L
.17245 .29398 L
.17247 .28539 L
.1725 .28109 L
.17252 .28968 L
.17254 .29828 L
.17256 .29828 L
.17258 .29828 L
.17261 .29828 L
.17263 .29398 L
.17265 .29398 L
.17267 .30257 L
.1727 .30687 L
.17272 .30257 L
.17274 .30257 L
.17276 .30257 L
.17279 .29828 L
.17281 .30257 L
.17283 .30687 L
.17285 .30687 L
.17288 .29828 L
.1729 .29828 L
.17292 .29828 L
.17294 .29828 L
.17296 .30257 L
.17299 .30257 L
.17301 .29398 L
.17303 .29398 L
.17305 .29398 L
.17308 .29398 L
.1731 .29398 L
.17312 .29828 L
.17314 .29398 L
.17317 .28539 L
.17319 .28968 L
.17321 .29398 L
.17323 .29398 L
.17325 .28968 L
.17328 .28539 L
.1733 .28539 L
.17332 .28968 L
.17334 .28968 L
.17337 .29398 L
.17339 .28968 L
Mistroke
.17341 .28109 L
.17343 .28539 L
.17346 .29398 L
.17348 .29398 L
.1735 .29398 L
.17352 .28968 L
.17354 .28539 L
.17357 .28539 L
.17359 .28968 L
.17361 .29828 L
.17363 .29828 L
.17366 .29828 L
.17368 .29398 L
.1737 .29398 L
.17372 .29828 L
.17375 .30257 L
.17377 .30687 L
.17379 .30257 L
.17381 .29828 L
.17384 .29828 L
.17386 .30257 L
.17388 .30257 L
.1739 .30257 L
.17392 .30687 L
.17395 .30257 L
.17397 .29828 L
.17399 .29398 L
.17401 .29398 L
.17404 .29828 L
.17406 .29828 L
.17408 .29828 L
.1741 .29828 L
.17413 .28968 L
.17415 .28968 L
.17417 .29398 L
.17419 .30257 L
.17421 .30257 L
.17424 .28968 L
.17426 .29398 L
.17428 .29398 L
.1743 .29398 L
.17433 .30257 L
.17435 .30687 L
.17437 .29828 L
.17439 .28968 L
.17442 .29398 L
.17444 .29828 L
.17446 .30257 L
.17448 .30257 L
.17451 .29828 L
Mistroke
.17453 .29398 L
.17455 .28968 L
.17457 .29828 L
.17459 .30257 L
.17462 .30257 L
.17464 .29398 L
.17466 .28968 L
.17468 .28109 L
.17471 .28968 L
.17473 .29398 L
.17475 .28968 L
.17477 .28539 L
.1748 .28109 L
.17482 .28109 L
.17484 .28539 L
.17486 .28968 L
.17488 .29398 L
.17491 .29398 L
.17493 .28968 L
.17495 .28968 L
.17497 .29398 L
.175 .29828 L
.17502 .30257 L
.17504 .30257 L
.17506 .30257 L
.17509 .29828 L
.17511 .30257 L
.17513 .30687 L
.17515 .30687 L
.17517 .30687 L
.1752 .30687 L
.17522 .30687 L
.17524 .30687 L
.17526 .30257 L
.17529 .30687 L
.17531 .30687 L
.17533 .30687 L
.17535 .29828 L
.17538 .29398 L
.1754 .30257 L
.17542 .30257 L
.17544 .29828 L
.17547 .29828 L
.17549 .29398 L
.17551 .28968 L
.17553 .28968 L
.17555 .29828 L
.17558 .30257 L
.1756 .29398 L
.17562 .28539 L
Mistroke
.17564 .28539 L
.17567 .28539 L
.17569 .28968 L
.17571 .29828 L
.17573 .29828 L
.17576 .28968 L
.17578 .28539 L
.1758 .28539 L
.17582 .29398 L
.17584 .29828 L
.17587 .29828 L
.17589 .29398 L
.17591 .28539 L
.17593 .28539 L
.17596 .29398 L
.17598 .29828 L
.176 .29828 L
.17602 .29828 L
.17605 .28968 L
.17607 .28539 L
.17609 .28968 L
.17611 .30257 L
.17614 .30687 L
.17616 .30257 L
.17618 .29828 L
.1762 .29398 L
.17622 .29398 L
.17625 .29398 L
.17627 .29828 L
.17629 .30687 L
.17631 .30687 L
.17634 .30257 L
.17636 .29828 L
.17638 .29828 L
.1764 .29398 L
.17643 .29828 L
.17645 .30687 L
.17647 .30257 L
.17649 .29828 L
.17651 .29828 L
.17654 .29398 L
.17656 .29398 L
.17658 .29828 L
.1766 .30257 L
.17663 .29828 L
.17665 .29398 L
.17667 .29398 L
.17669 .29398 L
.17672 .29398 L
.17674 .30257 L
Mistroke
.17676 .30257 L
.17678 .29828 L
.1768 .29398 L
.17683 .29398 L
.17685 .29398 L
.17687 .30257 L
.17689 .30257 L
.17692 .29828 L
.17694 .29398 L
.17696 .28968 L
.17698 .29398 L
.17701 .29828 L
.17703 .29828 L
.17705 .29398 L
.17707 .28968 L
.1771 .28539 L
.17712 .28539 L
.17714 .28968 L
.17716 .29398 L
.17718 .28968 L
.17721 .28109 L
.17723 .28109 L
.17725 .28109 L
.17727 .28539 L
.1773 .28968 L
.17732 .29398 L
.17734 .28539 L
.17736 .28109 L
.17739 .28539 L
.17741 .28539 L
.17743 .29398 L
.17745 .29828 L
.17747 .29828 L
.1775 .29398 L
.17752 .29398 L
.17754 .29398 L
.17756 .30257 L
.17759 .30687 L
.17761 .31117 L
.17763 .30687 L
.17765 .29828 L
.17768 .30257 L
.1777 .30257 L
.17772 .30257 L
.17774 .30687 L
.17777 .30687 L
.17779 .30257 L
.17781 .29828 L
.17783 .29398 L
.17785 .29828 L
Mistroke
.17788 .29828 L
.1779 .30257 L
.17792 .29828 L
.17794 .29398 L
.17797 .28968 L
.17799 .28968 L
.17801 .28968 L
.17803 .29398 L
.17806 .29398 L
.17808 .29398 L
.1781 .28539 L
.17812 .28539 L
.17814 .28539 L
.17817 .29398 L
.17819 .29398 L
.17821 .28968 L
.17823 .28968 L
.17826 .28539 L
.17828 .28539 L
.1783 .28968 L
.17832 .29398 L
.17835 .29398 L
.17837 .28968 L
.17839 .28539 L
.17841 .28539 L
.17843 .28968 L
.17846 .29828 L
.17848 .29828 L
.1785 .29398 L
.17852 .28968 L
.17855 .28968 L
.17857 .28968 L
.17859 .29828 L
.17861 .29828 L
.17864 .30257 L
.17866 .30257 L
.17868 .29828 L
.1787 .29398 L
.17873 .29398 L
.17875 .29398 L
.17877 .29828 L
.17879 .30687 L
.17881 .30687 L
.17884 .29828 L
.17886 .29828 L
.17888 .29398 L
.1789 .29828 L
.17893 .30257 L
.17895 .30257 L
.17897 .30257 L
Mistroke
.17899 .29828 L
.17902 .29398 L
.17904 .28968 L
.17906 .29398 L
.17908 .30257 L
.1791 .30257 L
.17913 .29828 L
.17915 .29398 L
.17917 .28968 L
.17919 .28968 L
.17922 .29828 L
.17924 .30687 L
.17926 .30687 L
.17928 .29828 L
.17931 .29398 L
.17933 .29398 L
.17935 .29828 L
.17937 .30687 L
.1794 .30687 L
.17942 .30257 L
.17944 .28968 L
.17946 .28968 L
.17948 .29398 L
.17951 .30257 L
.17953 .29828 L
.17955 .29398 L
.17957 .28539 L
.1796 .28539 L
.17962 .28968 L
.17964 .29398 L
.17966 .29398 L
.17969 .28968 L
.17971 .28539 L
.17973 .28109 L
.17975 .28539 L
.17977 .28968 L
.1798 .29398 L
.17982 .29398 L
.17984 .28968 L
.17986 .28968 L
.17989 .28968 L
.17991 .29398 L
.17993 .29828 L
.17995 .29828 L
.17998 .29828 L
.18 .29828 L
.18002 .30257 L
.18004 .30257 L
.18006 .30687 L
.18009 .30687 L
Mistroke
.18011 .30257 L
.18013 .30257 L
.18015 .31117 L
.18018 .31117 L
.1802 .30687 L
.18022 .30687 L
.18024 .30257 L
.18027 .30257 L
.18029 .30687 L
.18031 .30687 L
.18033 .30687 L
.18036 .30257 L
.18038 .29398 L
.1804 .29398 L
.18042 .29398 L
.18044 .29828 L
.18047 .29828 L
.18049 .29828 L
.18051 .28968 L
.18053 .28968 L
.18056 .28968 L
.18058 .29398 L
.1806 .29828 L
.18062 .29398 L
.18065 .28968 L
.18067 .28539 L
.18069 .28539 L
.18071 .28968 L
.18073 .29398 L
.18076 .29398 L
.18078 .28968 L
.1808 .28539 L
.18082 .28539 L
.18085 .28968 L
.18087 .29398 L
.18089 .29828 L
.18091 .29398 L
.18094 .28968 L
.18096 .28968 L
.18098 .28968 L
.181 .28968 L
.18103 .29398 L
.18105 .29828 L
.18107 .29828 L
.18109 .29398 L
.18111 .28968 L
.18114 .29398 L
.18116 .29398 L
.18118 .30257 L
.1812 .30257 L
Mistroke
.18123 .30257 L
.18125 .29828 L
.18127 .29398 L
.18129 .29398 L
.18132 .30257 L
.18134 .30257 L
.18136 .30257 L
.18138 .30257 L
.1814 .29828 L
.18143 .29398 L
.18145 .29828 L
.18147 .29828 L
.18149 .29828 L
.18152 .29828 L
.18154 .29398 L
.18156 .29398 L
.18158 .29398 L
.18161 .29398 L
.18163 .29398 L
.18165 .29398 L
.18167 .29398 L
.18169 .29828 L
.18172 .29398 L
.18174 .29828 L
.18176 .29398 L
.18178 .29828 L
.18181 .29398 L
.18183 .29828 L
.18185 .29828 L
.18187 .29828 L
.1819 .29398 L
.18192 .29398 L
.18194 .29398 L
.18196 .29398 L
.18199 .29398 L
.18201 .29398 L
.18203 .29398 L
.18205 .29398 L
.18207 .28968 L
.1821 .28968 L
.18212 .28968 L
.18214 .28968 L
.18216 .28968 L
.18219 .28968 L
.18221 .28968 L
.18223 .28539 L
.18225 .28539 L
.18228 .28539 L
.1823 .28968 L
.18232 .28968 L
Mistroke
.18234 .28968 L
.18236 .28968 L
.18239 .28968 L
.18241 .28968 L
.18243 .29398 L
.18245 .29398 L
.18248 .29828 L
.1825 .29828 L
.18252 .29828 L
.18254 .29828 L
.18257 .29828 L
.18259 .30257 L
.18261 .30257 L
.18263 .30257 L
.18266 .30257 L
.18268 .30257 L
.1827 .30257 L
.18272 .30257 L
.18274 .30257 L
.18277 .30257 L
.18279 .30257 L
.18281 .30257 L
.18283 .30257 L
.18286 .29828 L
.18288 .29828 L
.1829 .29828 L
.18292 .29828 L
.18295 .29828 L
.18297 .29828 L
.18299 .29828 L
.18301 .29398 L
.18303 .29828 L
.18306 .29828 L
.18308 .29398 L
.1831 .29398 L
.18312 .29398 L
.18315 .28968 L
.18317 .28968 L
.18319 .28968 L
.18321 .28968 L
.18324 .28968 L
.18326 .28968 L
.18328 .28968 L
.1833 .28968 L
.18332 .28968 L
.18335 .28968 L
.18337 .28968 L
.18339 .28968 L
.18341 .28968 L
.18344 .28968 L
Mistroke
.18346 .28968 L
.18348 .28968 L
.1835 .28968 L
.18353 .29398 L
.18355 .29398 L
.18357 .28968 L
.18359 .28968 L
.18362 .29398 L
.18364 .29398 L
.18366 .29828 L
.18368 .29828 L
.1837 .29828 L
.18373 .29828 L
.18375 .29828 L
.18377 .30257 L
.18379 .30257 L
.18382 .30687 L
.18384 .30257 L
.18386 .30257 L
.18388 .29828 L
.18391 .30257 L
.18393 .30257 L
.18395 .30257 L
.18397 .30257 L
.18399 .29828 L
.18402 .29828 L
.18404 .29828 L
.18406 .29828 L
.18408 .29828 L
.18411 .29828 L
.18413 .29398 L
.18415 .29398 L
.18417 .29398 L
.1842 .29398 L
.18422 .29828 L
.18424 .29398 L
.18426 .29398 L
.18429 .29398 L
.18431 .29398 L
.18433 .29398 L
.18435 .29828 L
.18437 .29828 L
.1844 .29398 L
.18442 .28968 L
.18444 .28968 L
.18446 .29398 L
.18449 .29398 L
.18451 .29398 L
.18453 .29398 L
.18455 .28968 L
Mistroke
.18458 .28968 L
.1846 .28968 L
.18462 .29398 L
.18464 .29398 L
.18466 .28968 L
.18469 .28968 L
.18471 .28968 L
.18473 .28968 L
.18475 .28968 L
.18478 .29398 L
.1848 .28968 L
.18482 .28968 L
.18484 .28968 L
.18487 .29398 L
.18489 .29398 L
.18491 .29398 L
.18493 .29398 L
.18495 .29398 L
.18498 .29828 L
.185 .29828 L
.18502 .30257 L
.18504 .29828 L
.18507 .29828 L
.18509 .29828 L
.18511 .30257 L
.18513 .30257 L
.18516 .30257 L
.18518 .29828 L
.1852 .29828 L
.18522 .29828 L
.18525 .30257 L
.18527 .29828 L
.18529 .29828 L
.18531 .29828 L
.18533 .29398 L
.18536 .29398 L
.18538 .29828 L
.1854 .29828 L
.18542 .29828 L
.18545 .29828 L
.18547 .29398 L
.18549 .29398 L
.18551 .29398 L
.18554 .29398 L
.18556 .29828 L
.18558 .29828 L
.1856 .29398 L
.18562 .29398 L
.18565 .29398 L
.18567 .29398 L
Mistroke
.18569 .29398 L
.18571 .29398 L
.18574 .29828 L
.18576 .29398 L
.18578 .28968 L
.1858 .28968 L
.18583 .28968 L
.18585 .28968 L
.18587 .29398 L
.18589 .29398 L
.18592 .28968 L
.18594 .28968 L
.18596 .28968 L
.18598 .28968 L
.186 .29398 L
.18603 .29398 L
.18605 .28968 L
.18607 .28968 L
.18609 .28968 L
.18612 .29398 L
.18614 .29398 L
.18616 .29398 L
.18618 .29828 L
.18621 .29398 L
.18623 .29398 L
.18625 .29828 L
.18627 .30257 L
.18629 .30257 L
.18632 .30257 L
.18634 .30257 L
.18636 .29828 L
.18638 .30257 L
.18641 .30257 L
.18643 .30257 L
.18645 .30257 L
.18647 .30257 L
.1865 .29828 L
.18652 .29828 L
.18654 .29828 L
.18656 .29828 L
.18658 .29828 L
.18661 .29828 L
.18663 .29828 L
.18665 .29828 L
.18667 .29828 L
.1867 .29398 L
.18672 .29398 L
.18674 .29828 L
.18676 .29398 L
.18679 .29828 L
Mistroke
.18681 .29398 L
.18683 .29398 L
.18685 .29398 L
.18688 .29398 L
.1869 .29398 L
.18692 .29398 L
.18694 .29398 L
.18696 .29398 L
.18699 .28968 L
.18701 .29398 L
.18703 .28968 L
.18705 .29398 L
.18708 .29398 L
.1871 .28968 L
.18712 .28968 L
.18714 .28968 L
.18717 .28968 L
.18719 .28968 L
.18721 .29398 L
.18723 .28968 L
.18725 .28539 L
.18728 .28539 L
.1873 .28539 L
.18732 .28968 L
.18734 .29398 L
.18737 .29398 L
.18739 .29398 L
.18741 .29398 L
.18743 .29398 L
.18746 .29398 L
.18748 .29828 L
.1875 .29828 L
.18752 .29828 L
.18755 .29828 L
.18757 .29828 L
.18759 .30257 L
.18761 .30257 L
.18763 .30257 L
.18766 .29828 L
.18768 .29828 L
.1877 .30257 L
.18772 .30257 L
.18775 .30257 L
.18777 .29828 L
.18779 .29828 L
.18781 .29828 L
.18784 .29828 L
.18786 .29828 L
.18788 .29828 L
.1879 .29828 L
Mistroke
.18792 .29828 L
.18795 .29398 L
.18797 .29398 L
.18799 .29398 L
.18801 .29828 L
.18804 .29828 L
.18806 .29398 L
.18808 .29398 L
.1881 .29398 L
.18813 .29398 L
.18815 .29398 L
.18817 .28968 L
.18819 .29398 L
.18821 .29828 L
.18824 .29828 L
.18826 .29398 L
.18828 .28968 L
.1883 .28968 L
.18833 .29398 L
.18835 .29398 L
.18837 .29828 L
.18839 .29398 L
.18842 .28968 L
.18844 .28539 L
.18846 .28968 L
.18848 .29828 L
.18851 .29828 L
.18853 .29398 L
.18855 .28968 L
.18857 .28968 L
.18859 .28968 L
.18862 .29828 L
.18864 .29828 L
.18866 .30257 L
.18868 .29828 L
.18871 .29398 L
.18873 .29398 L
.18875 .29828 L
.18877 .30257 L
.1888 .30687 L
.18882 .30257 L
.18884 .30257 L
.18886 .29828 L
.18888 .29828 L
.18891 .30257 L
.18893 .30687 L
.18895 .30257 L
.18897 .30257 L
.189 .30257 L
.18902 .29828 L
Mistroke
.18904 .30257 L
.18906 .30257 L
.18909 .30257 L
.18911 .29828 L
.18913 .29398 L
.18915 .29398 L
.18917 .29828 L
.1892 .30257 L
.18922 .30257 L
.18924 .29828 L
.18926 .29398 L
.18929 .29398 L
.18931 .29828 L
.18933 .30257 L
.18935 .30257 L
.18938 .29828 L
.1894 .28968 L
.18942 .29398 L
.18944 .29398 L
.18947 .30257 L
.18949 .30257 L
.18951 .29398 L
.18953 .28539 L
.18955 .28968 L
.18958 .29828 L
.1896 .30257 L
.18962 .29828 L
.18964 .28968 L
.18967 .28109 L
.18969 .28539 L
.18971 .29398 L
.18973 .30257 L
.18976 .29828 L
.18978 .28968 L
.1898 .28109 L
.18982 .28968 L
.18984 .29398 L
.18987 .30257 L
.18989 .30257 L
.18991 .29828 L
.18993 .28968 L
.18996 .28968 L
.18998 .29828 L
.19 .30687 L
.19002 .30687 L
.19005 .30257 L
.19007 .29398 L
.19009 .29398 L
.19011 .29828 L
.19014 .30687 L
Mistroke
.19016 .30687 L
.19018 .30257 L
.1902 .29828 L
.19022 .29398 L
.19025 .29398 L
.19027 .30257 L
.19029 .30687 L
.19031 .30257 L
.19034 .29398 L
.19036 .28968 L
.19038 .29398 L
.1904 .29828 L
.19043 .30257 L
.19045 .30257 L
.19047 .30257 L
.19049 .29398 L
.19051 .28539 L
.19054 .28968 L
.19056 .29828 L
.19058 .30257 L
.1906 .29828 L
.19063 .28968 L
.19065 .28109 L
.19067 .28539 L
.19069 .29828 L
.19072 .30257 L
.19074 .29828 L
.19076 .28109 L
.19078 .27679 L
.1908 .28539 L
.19083 .29828 L
.19085 .30257 L
.19087 .29398 L
.19089 .28109 L
.19092 .27679 L
.19094 .28109 L
.19096 .29398 L
.19098 .30257 L
.19101 .29398 L
.19103 .28109 L
.19105 .27679 L
.19107 .28109 L
.1911 .29398 L
.19112 .30257 L
.19114 .29828 L
.19116 .28968 L
.19118 .28539 L
.19121 .28968 L
.19123 .29398 L
.19125 .30257 L
Mistroke
.19127 .30257 L
.1913 .29398 L
.19132 .29398 L
.19134 .29398 L
.19136 .29828 L
.19139 .30257 L
.19141 .30257 L
.19143 .29828 L
.19145 .29398 L
.19147 .29398 L
.1915 .29828 L
.19152 .29828 L
.19154 .29828 L
.19156 .29398 L
.19159 .28968 L
.19161 .28968 L
.19163 .29398 L
.19165 .30257 L
.19168 .29828 L
.1917 .29398 L
.19172 .28968 L
.19174 .28968 L
.19177 .29828 L
.19179 .30257 L
.19181 .29828 L
.19183 .28968 L
.19185 .28539 L
.19188 .28968 L
.1919 .29398 L
.19192 .29828 L
.19194 .29828 L
.19197 .28539 L
.19199 .28109 L
.19201 .28539 L
.19203 .29398 L
.19206 .30257 L
.19208 .29398 L
.1921 .28109 L
.19212 .27679 L
.19214 .28539 L
.19217 .29828 L
.19219 .29828 L
.19221 .29398 L
.19223 .28109 L
.19226 .27679 L
.19228 .28109 L
.1923 .29398 L
.19232 .30257 L
.19235 .29828 L
.19237 .28539 L
Mistroke
.19239 .28109 L
.19241 .28539 L
.19243 .29828 L
.19246 .30687 L
.19248 .30687 L
.1925 .29828 L
.19252 .28968 L
.19255 .29398 L
.19257 .29828 L
.19259 .30687 L
.19261 .30687 L
.19264 .29828 L
.19266 .29398 L
.19268 .28968 L
.1927 .29828 L
.19273 .30687 L
.19275 .30687 L
.19277 .29828 L
.19279 .29828 L
.19281 .28968 L
.19284 .28968 L
.19286 .29398 L
.19288 .30257 L
.1929 .30687 L
.19293 .29828 L
.19295 .28968 L
.19297 .28968 L
.19299 .29828 L
.19302 .30687 L
.19304 .30687 L
.19306 .29828 L
.19308 .28968 L
.1931 .28968 L
.19313 .29828 L
.19315 .30687 L
.19317 .30257 L
.19319 .28968 L
.19322 .28539 L
.19324 .28539 L
.19326 .29828 L
.19328 .30257 L
.19331 .29828 L
.19333 .28968 L
.19335 .28109 L
.19337 .28968 L
.1934 .29828 L
.19342 .29828 L
.19344 .29398 L
.19346 .28539 L
.19348 .28109 L
Mistroke
.19351 .28968 L
.19353 .29828 L
.19355 .29828 L
.19357 .29398 L
.1936 .28968 L
.19362 .28539 L
.19364 .29398 L
.19366 .30257 L
.19369 .30257 L
.19371 .30257 L
.19373 .29398 L
.19375 .29398 L
.19377 .29828 L
.1938 .30257 L
.19382 .30687 L
.19384 .30687 L
.19386 .30257 L
.19389 .29828 L
.19391 .30257 L
.19393 .30257 L
.19395 .30687 L
.19398 .30257 L
.194 .29828 L
.19402 .29398 L
.19404 .29828 L
.19406 .30257 L
.19409 .30257 L
.19411 .29828 L
.19413 .29398 L
.19415 .29398 L
.19418 .29828 L
.1942 .30687 L
.19422 .30687 L
.19424 .30257 L
.19427 .29398 L
.19429 .28968 L
.19431 .29828 L
.19433 .30687 L
.19436 .31117 L
.19438 .30257 L
.1944 .28539 L
.19442 .28109 L
.19444 .29398 L
.19447 .30687 L
.19449 .30687 L
.19451 .29828 L
.19453 .28109 L
.19456 .27679 L
.19458 .28968 L
.1946 .30257 L
Mistroke
.19462 .30687 L
.19465 .29398 L
.19467 .27679 L
.19469 .27679 L
.19471 .28539 L
.19473 .30257 L
.19476 .30687 L
.19478 .29398 L
.1948 .28109 L
.19482 .27679 L
.19485 .28539 L
.19487 .30257 L
.19489 .30687 L
.19491 .30687 L
.19494 .29398 L
.19496 .28968 L
.19498 .29398 L
.195 .30257 L
.19503 .31117 L
.19505 .31117 L
.19507 .30257 L
.19509 .29828 L
.19511 .29398 L
.19514 .30257 L
.19516 .30257 L
.19518 .30687 L
.1952 .31117 L
.19523 .30687 L
.19525 .29398 L
.19527 .28968 L
.19529 .29398 L
.19532 .30687 L
.19534 .30687 L
.19536 .31546 L
.19538 .28539 L
.1954 .28539 L
.19543 .31117 L
.19545 .28109 L
.19547 .28968 L
.19549 .33694 L
.19552 .28968 L
.19554 .25531 L
.19556 .33265 L
.19558 .28539 L
.19561 .2682 L
.19563 .32835 L
.19565 .29828 L
.19567 .26391 L
.19569 .30687 L
.19572 .28968 L
Mistroke
.19574 .28109 L
.19576 .31976 L
.19578 .27679 L
.19581 .29828 L
.19583 .29398 L
.19585 .25961 L
.19587 .31117 L
.1959 .28968 L
.19592 .27679 L
.19594 .30687 L
.19596 .27679 L
.19599 .28109 L
.19601 .30257 L
.19603 .2725 L
.19605 .28539 L
.19607 .31976 L
.1961 .27679 L
.19612 .28109 L
.19614 .30687 L
.19616 .28539 L
.19619 .29828 L
.19621 .30257 L
.19623 .30687 L
.19625 .30257 L
.19628 .28968 L
.1963 .29828 L
.19632 .29398 L
.19634 .30687 L
.19636 .31546 L
.19639 .29398 L
.19641 .28968 L
.19643 .30687 L
.19645 .29828 L
.19648 .29398 L
.1965 .31117 L
.19652 .29398 L
.19654 .29398 L
.19657 .30257 L
.19659 .30257 L
.19661 .28539 L
.19663 .31117 L
.19666 .31546 L
.19668 .27679 L
.1967 .29398 L
.19672 .30257 L
.19674 .28968 L
.19677 .31117 L
.19679 .29828 L
.19681 .28539 L
.19683 .30687 L
Mistroke
.19686 .29398 L
.19688 .27679 L
.1969 .30687 L
.19692 .29398 L
.19695 .28539 L
.19697 .30257 L
.19699 .28539 L
.19701 .29398 L
.19703 .29828 L
.19706 .28539 L
.19708 .29398 L
.1971 .29828 L
.19712 .28968 L
.19715 .27679 L
.19717 .29398 L
.19719 .30257 L
.19721 .29398 L
.19724 .29398 L
.19726 .28539 L
.19728 .28539 L
.1973 .29398 L
.19732 .28968 L
.19735 .29398 L
.19737 .29828 L
.19739 .29398 L
.19741 .28968 L
.19744 .28539 L
.19746 .29828 L
.19748 .29398 L
.1975 .30257 L
.19753 .30257 L
.19755 .30687 L
.19757 .2725 L
.19759 .30687 L
.19762 .33265 L
.19764 .2682 L
.19766 .30257 L
.19768 .32405 L
.1977 .28109 L
.19773 .29398 L
.19775 .29828 L
.19777 .30687 L
.19779 .29828 L
.19782 .29828 L
.19784 .33265 L
.19786 .27679 L
.19788 .28109 L
.19791 .31117 L
.19793 .28539 L
.19795 .30257 L
Mistroke
.19797 .28968 L
.19799 .31976 L
.19802 .28968 L
.19804 .26391 L
.19806 .31546 L
.19808 .28109 L
.19811 .29398 L
.19813 .29828 L
.19815 .2725 L
.19817 .29828 L
.1982 .28109 L
.19822 .28968 L
.19824 .31117 L
.19826 .28539 L
.19829 .29398 L
.19831 .29828 L
.19833 .28109 L
.19835 .28539 L
.19837 .29828 L
.1984 .27679 L
.19842 .31976 L
.19844 .30257 L
.19846 .26391 L
.19849 .30687 L
.19851 .29398 L
.19853 .28539 L
.19855 .28109 L
.19858 .30687 L
.1986 .30257 L
.19862 .2725 L
.19864 .30687 L
.19866 .29828 L
.19869 .28539 L
.19871 .30687 L
.19873 .29828 L
.19875 .28968 L
.19878 .29828 L
.1988 .28539 L
.19882 .28539 L
.19884 .30687 L
.19887 .28968 L
.19889 .29398 L
.19891 .29828 L
.19893 .28109 L
.19895 .28968 L
.19898 .29398 L
.199 .29398 L
.19902 .30257 L
.19904 .28539 L
.19907 .29828 L
Mistroke
.19909 .30257 L
.19911 .28539 L
.19913 .29828 L
.19916 .31546 L
.19918 .30687 L
.1992 .30257 L
.19922 .30687 L
.19925 .31117 L
.19927 .30687 L
.19929 .31117 L
.19931 .31546 L
.19933 .28539 L
.19936 .29398 L
.19938 .28539 L
.1994 .2725 L
.19942 .30257 L
.19945 .28968 L
.19947 .2682 L
.19949 .27679 L
.19951 .2725 L
.19954 .2725 L
.19956 .30687 L
.19958 .25961 L
.1996 .28109 L
.19962 .31546 L
.19965 .26391 L
.19967 .29828 L
.19969 .28109 L
.19971 .31117 L
.19974 .33265 L
.19976 .27679 L
.19978 .29398 L
.1998 .34554 L
.19983 .30687 L
.19985 .30687 L
.19987 .32405 L
.19989 .32405 L
.19992 .31117 L
.19994 .32835 L
.19996 .2682 L
.19998 .28968 L
.2 .31117 L
.20003 .25531 L
.20005 .29828 L
.20007 .26391 L
.20009 .2725 L
.20012 .31546 L
.20014 .22094 L
.20016 .31976 L
.20018 .32835 L
Mistroke
.20021 .19946 L
.20023 .33694 L
.20025 .31117 L
.20027 .28968 L
.20029 .31117 L
.20032 .28109 L
.20034 .3842 L
.20036 .31117 L
.20038 .2725 L
.20041 .37131 L
.20043 .33694 L
.20045 .30257 L
.20047 .32405 L
.2005 .34124 L
.20052 .34983 L
.20054 .27679 L
.20056 .27679 L
.20058 .32835 L
.20061 .25531 L
.20063 .24672 L
.20065 .28109 L
.20067 .25102 L
.2007 .24672 L
.20072 .22094 L
.20074 .25531 L
.20076 .35843 L
.20079 .21235 L
.20081 .21664 L
.20083 .36702 L
.20085 .31117 L
.20088 .27679 L
.2009 .24672 L
.20092 .40569 L
.20094 .3885 L
.20096 .25531 L
.20099 .33265 L
.20101 .3842 L
.20103 .36272 L
.20105 .29828 L
.20108 .31546 L
.2011 .36702 L
.20112 .30257 L
.20114 .25102 L
.20117 .25961 L
.20119 .29398 L
.20121 .24672 L
.20123 .22094 L
.20125 .24672 L
.20128 .23813 L
.2013 .23813 L
Mistroke
.20132 .19946 L
.20134 .33265 L
.20137 .32405 L
.20139 .1565 L
.20141 .33265 L
.20143 .40139 L
.20146 .32405 L
.20148 .22953 L
.2015 .40139 L
.20152 .47013 L
.20155 .29828 L
.20157 .29828 L
.20159 .39709 L
.20161 .41857 L
.20163 .29828 L
.20166 .28968 L
.20168 .32405 L
.2017 .34983 L
.20172 .22953 L
.20175 .17798 L
.20177 .28109 L
.20179 .28968 L
.20181 .16079 L
.20184 .20376 L
.20186 .25102 L
.20188 .22524 L
.2019 .1479 L
.20192 .35413 L
.20195 .35413 L
.20197 .12212 L
.20199 .34554 L
.20201 .47013 L
.20204 .33694 L
.20206 .20376 L
.20208 .45724 L
.2021 .48732 L
.20213 .28968 L
.20215 .27679 L
.20217 .41428 L
.20219 .40998 L
.20221 .24242 L
.20224 .22953 L
.20226 .22953 L
.20228 .32835 L
.2023 .29398 L
.20233 .1522 L
.20235 .18227 L
.20237 .25531 L
.20239 .26391 L
.20242 .1565 L
Mistroke
.20244 .19946 L
.20246 .23813 L
.20248 .19516 L
.20251 .29828 L
.20253 .44435 L
.20255 .17368 L
.20257 .28109 L
.20259 .52169 L
.20262 .43576 L
.20264 .20376 L
.20266 .35413 L
.20268 .56895 L
.20271 .34554 L
.20273 .19946 L
.20275 .34554 L
.20277 .47013 L
.2028 .23383 L
.20282 .14361 L
.20284 .29828 L
.20286 .34124 L
.20288 .1565 L
.20291 .1565 L
.20293 .24242 L
.20295 .31546 L
.20297 .17798 L
.203 .18227 L
.20302 .23383 L
.20304 .26391 L
.20306 .40998 L
.20309 .37991 L
.20311 .1565 L
.20313 .37131 L
.20315 .54747 L
.20318 .34554 L
.2032 .16938 L
.20322 .42287 L
.20324 .52598 L
.20326 .22953 L
.20329 .13931 L
.20331 .40569 L
.20333 .40998 L
.20335 .1479 L
.20338 .13931 L
.2034 .34554 L
.20342 .29828 L
.20344 .1479 L
.20347 .18657 L
.20349 .2725 L
.20351 .30687 L
.20353 .19516 L
Mistroke
.20355 .21664 L
.20358 .22094 L
.2036 .41428 L
.20362 .47872 L
.20364 .16509 L
.20367 .23813 L
.20369 .55606 L
.20371 .44006 L
.20373 .1522 L
.20376 .28968 L
.20378 .52169 L
.2038 .33694 L
.20382 .11783 L
.20384 .26391 L
.20387 .43146 L
.20389 .29398 L
.20391 .13931 L
.20393 .2725 L
.20396 .34983 L
.20398 .26391 L
.204 .21235 L
.20402 .24242 L
.20405 .32835 L
.20407 .28539 L
.20409 .25102 L
.20411 .21664 L
.20414 .31117 L
.20416 .52598 L
.20418 .29828 L
.2042 .13931 L
.20422 .44865 L
.20425 .49591 L
.20427 .23813 L
.20429 .19516 L
.20431 .42287 L
.20434 .40998 L
.20436 .20805 L
.20438 .17368 L
.2044 .31546 L
.20443 .37131 L
.20445 .25961 L
.20447 .21235 L
.20449 .28968 L
.20451 .32405 L
.20454 .28539 L
.20456 .21235 L
.20458 .2725 L
.2046 .31546 L
.20463 .31546 L
.20465 .28109 L
Mistroke
.20467 .21664 L
.20469 .19516 L
.20472 .43146 L
.20474 .46583 L
.20476 .12642 L
.20478 .25961 L
.2048 .52169 L
.20483 .35843 L
.20485 .16938 L
.20487 .28968 L
.20489 .42287 L
.20492 .30687 L
.20494 .19087 L
.20496 .24242 L
.20498 .30257 L
.20501 .33694 L
.20503 .28109 L
.20505 .24672 L
.20507 .28539 L
.2051 .34554 L
.20512 .29398 L
.20514 .22094 L
.20516 .2682 L
.20518 .33694 L
.20521 .29398 L
.20523 .20376 L
.20525 .22094 L
.20527 .45724 L
.2053 .44865 L
.20532 .12642 L
.20534 .31976 L
.20536 .52169 L
.20539 .33265 L
.20541 .19516 L
.20543 .29828 L
.20545 .40139 L
.20547 .30687 L
.2055 .20805 L
.20552 .25102 L
.20554 .2725 L
.20556 .32835 L
.20559 .32835 L
.20561 .25961 L
.20563 .2682 L
.20565 .36272 L
.20568 .31117 L
.2057 .19946 L
.20572 .25102 L
.20574 .34124 L
.20577 .28968 L
Mistroke
.20579 .21664 L
.20581 .20805 L
.20583 .37991 L
.20585 .47872 L
.20588 .17368 L
.2059 .25102 L
.20592 .50021 L
.20594 .36272 L
.20597 .20376 L
.20599 .25531 L
.20601 .35413 L
.20603 .33265 L
.20606 .21664 L
.20608 .23383 L
.2061 .23383 L
.20612 .30687 L
.20614 .37131 L
.20617 .28109 L
.20619 .24242 L
.20621 .34983 L
.20623 .34124 L
.20626 .22094 L
.20628 .21664 L
.2063 .30687 L
.20632 .31976 L
.20635 .22524 L
.20637 .17368 L
.20639 .28968 L
.20641 .54317 L
.20643 .29398 L
.20646 .16079 L
.20648 .46583 L
.2065 .44006 L
.20652 .2682 L
.20655 .24242 L
.20657 .31976 L
.20659 .33694 L
.20661 .24672 L
.20664 .23383 L
.20666 .22953 L
.20668 .28968 L
.2067 .40998 L
.20673 .34554 L
.20675 .25961 L
.20677 .28539 L
.20679 .33694 L
.20681 .2682 L
.20684 .21664 L
.20686 .25102 L
.20688 .31117 L
Mistroke
.2069 .23813 L
.20693 .22953 L
.20695 .22094 L
.20697 .3842 L
.20699 .3842 L
.20702 .52598 L
.20704 .19087 L
.20706 .22094 L
.20708 .51309 L
.2071 .37131 L
.20713 .21664 L
.20715 .22953 L
.20717 .29398 L
.20719 .28109 L
.20722 .22524 L
.20724 .26391 L
.20726 .25961 L
.20728 .33265 L
.20731 .3928 L
.20733 .30257 L
.20735 .28539 L
.20737 .33265 L
.2074 .26391 L
.20742 .20376 L
.20744 .21664 L
.20746 .25531 L
.20748 .28109 L
.20751 .23383 L
.20753 .22524 L
.20755 .22524 L
.20757 .44865 L
.2076 .52169 L
.20762 .1479 L
.20764 .29828 L
.20766 .53028 L
.20769 .29828 L
.20771 .17798 L
.20773 .21664 L
.20775 .30687 L
.20777 .2682 L
.2078 .25961 L
.20782 .31117 L
.20784 .28109 L
.20786 .40139 L
.20789 .41428 L
.20791 .32405 L
.20793 .25102 L
.20795 .23813 L
.20798 .24672 L
.208 .22953 L
Mistroke
.20802 .23813 L
.20804 .29398 L
.20806 .31976 L
.20809 .25102 L
.20811 .19946 L
.20813 .2682 L
.20815 .53887 L
.20818 .44006 L
.2082 .08346 L
.20822 .36702 L
.20824 .45724 L
.20827 .18657 L
.20829 .17798 L
.20831 .25961 L
.20833 .31117 L
.20836 .25961 L
.20838 .32835 L
.2084 .33265 L
.20842 .31117 L
.20844 .43576 L
.20847 .34554 L
.20849 .23383 L
.20851 .21664 L
.20853 .21235 L
.20856 .25102 L
.20858 .25531 L
.2086 .27679 L
.20862 .30687 L
.20865 .28109 L
.20867 .24242 L
.20869 .23383 L
.20871 .40569 L
.20873 .57324 L
.20876 .21235 L
.20878 .12212 L
.2088 .44435 L
.20882 .31546 L
.20885 .18227 L
.20887 .21235 L
.20889 .31976 L
.20891 .32835 L
.20894 .29398 L
.20896 .40998 L
.20898 .34554 L
.209 .34124 L
.20903 .35843 L
.20905 .22524 L
.20907 .24242 L
.20909 .21235 L
.20911 .23813 L
Mistroke
.20914 .30687 L
.20916 .31976 L
.20918 .32405 L
.2092 .31546 L
.20923 .28968 L
.20925 .2682 L
.20927 .28968 L
.20929 .48732 L
.20932 .41428 L
.20934 .08346 L
.20936 .08346 L
.20938 .27679 L
.2094 .39709 L
.20943 .22524 L
.20945 .22953 L
.20947 .28539 L
.20949 .36702 L
.20952 .31117 L
.20954 .34554 L
.20956 .3885 L
.20958 .27679 L
.20961 .29398 L
.20963 .23813 L
.20965 .22524 L
.20967 .27679 L
.20969 .23813 L
.20972 .28968 L
.20974 .33265 L
.20976 .33265 L
.20978 .31546 L
.20981 .2725 L
.20983 .25102 L
.20985 .25102 L
.20987 .40998 L
.2099 .43576 L
.20992 .1522 L
.20994 .21664 L
.20996 .36702 L
.20999 .25961 L
.21001 .28109 L
.21003 .28968 L
.21005 .32405 L
.21007 .31976 L
.2101 .29828 L
.21012 .37991 L
.21014 .28968 L
.21016 .25102 L
.21019 .30257 L
.21021 .25531 L
.21023 .26391 L
Mistroke
.21025 .25961 L
.21028 .28539 L
.2103 .32835 L
.21032 .33265 L
.21034 .32405 L
.21036 .27679 L
.21039 .24242 L
.21041 .2725 L
.21043 .37131 L
.21045 .45724 L
.21048 .2682 L
.2105 .16509 L
.21052 .33694 L
.21054 .29828 L
.21057 .2682 L
.21059 .30257 L
.21061 .28968 L
.21063 .31117 L
.21066 .30687 L
.21068 .34983 L
.2107 .32835 L
.21072 .2682 L
.21074 .28109 L
.21077 .25961 L
.21079 .28109 L
.21081 .2682 L
.21083 .23383 L
.21086 .30257 L
.21088 .34124 L
.2109 .31546 L
.21092 .28109 L
.21095 .26391 L
.21097 .2725 L
.21099 .30687 L
.21101 .41857 L
.21103 .36272 L
.21106 .1522 L
.21108 .25102 L
.2111 .34554 L
.21112 .25531 L
.21115 .27679 L
.21117 .29398 L
.21119 .29398 L
.21121 .30257 L
.21124 .33265 L
.21126 .37131 L
.21128 .29828 L
.2113 .22524 L
.21132 .25102 L
.21135 .2682 L
Mistroke
.21137 .27679 L
.21139 .2682 L
.21141 .29828 L
.21144 .33265 L
.21146 .32405 L
.21148 .30687 L
.2115 .28109 L
.21153 .24672 L
.21155 .30257 L
.21157 .44435 L
.21159 .35843 L
.21162 .16079 L
.21164 .2682 L
.21166 .34124 L
.21168 .25531 L
.2117 .25531 L
.21173 .29398 L
.21175 .31117 L
.21177 .31117 L
.21179 .29828 L
.21182 .33694 L
.21184 .37991 L
.21186 .27679 L
.21188 .19516 L
.21191 .2682 L
.21193 .31976 L
.21195 .2725 L
.21197 .25531 L
.21199 .32405 L
.21202 .32405 L
.21204 .29828 L
.21206 .31117 L
.21208 .2725 L
.21211 .21664 L
.21213 .28109 L
.21215 .42287 L
.21217 .39709 L
.2122 .21235 L
.21222 .23383 L
.21224 .34554 L
.21226 .25531 L
.21229 .25531 L
.21231 .30687 L
.21233 .29398 L
.21235 .28109 L
.21237 .31546 L
.2124 .37991 L
.21242 .31976 L
.21244 .20805 L
.21246 .2725 L
Mistroke
.21249 .31117 L
.21251 .24242 L
.21253 .22094 L
.21255 .29398 L
.21258 .32835 L
.2126 .32405 L
.21262 .33265 L
.21264 .30257 L
.21266 .23383 L
.21269 .28539 L
.21271 .43146 L
.21273 .3842 L
.21275 .18657 L
.21278 .22953 L
.2128 .32835 L
.21282 .2682 L
.21284 .30257 L
.21287 .34554 L
.21289 .31546 L
.21291 .28968 L
.21293 .31976 L
.21295 .35413 L
.21298 .26391 L
.213 .19516 L
.21302 .31546 L
.21304 .33694 L
.21307 .25961 L
.21309 .26391 L
.21311 .30687 L
.21313 .29398 L
.21316 .29398 L
.21318 .31976 L
.2132 .30257 L
.21322 .21664 L
.21325 .28539 L
.21327 .45295 L
.21329 .37991 L
.21331 .18227 L
.21333 .22953 L
.21336 .33694 L
.21338 .2725 L
.2134 .27679 L
.21342 .33265 L
.21345 .30687 L
.21347 .30687 L
.21349 .34554 L
.21351 .27679 L
.21354 .20376 L
.21356 .29398 L
.21358 .32835 L
Mistroke
.2136 .24672 L
.21362 .25961 L
.21365 .31546 L
.21367 .29398 L
.21369 .28539 L
.21371 .31546 L
.21374 .31976 L
.21376 .25961 L
.21378 .24242 L
.2138 .28968 L
.21383 .35413 L
.21385 .34124 L
.21387 .34124 L
.21389 .32835 L
.21392 .22094 L
.21394 .22953 L
.21396 .30257 L
.21398 .29398 L
.214 .31546 L
.21403 .3928 L
.21405 .37131 L
.21407 .37131 L
.21409 .2682 L
.21412 .21235 L
.21414 .24672 L
.21416 .25961 L
.21418 .2725 L
.21421 .32405 L
.21423 .33694 L
.21425 .30687 L
.21427 .30257 L
.21429 .25961 L
.21432 .25961 L
.21434 .25961 L
.21436 .25961 L
.21438 .37561 L
.21441 .47013 L
.21443 .2725 L
.21445 .1522 L
.21447 .28109 L
.2145 .34983 L
.21452 .27679 L
.21454 .29398 L
.21456 .29398 L
.21458 .2682 L
.21461 .29398 L
.21463 .35413 L
.21465 .30257 L
.21467 .25102 L
.2147 .25102 L
Mistroke
.21472 .26391 L
.21474 .22953 L
.21476 .37561 L
.21479 .49161 L
.21481 .33265 L
.21483 .1565 L
.21485 .19946 L
.21488 .24242 L
.2149 .23813 L
.21492 .32405 L
.21494 .37131 L
.21496 .30687 L
.21499 .24242 L
.21501 .2725 L
.21503 .25102 L
.21505 .3928 L
.21508 .49591 L
.2151 .19516 L
.21512 .08346 L
.21514 .28968 L
.21517 .3842 L
.21519 .33265 L
.21521 .37131 L
.21523 .32835 L
.21525 .2725 L
.21528 .28109 L
.2153 .30687 L
.21532 .22094 L
.21534 .22094 L
.21537 .29828 L
.21539 .35843 L
.21541 .34554 L
.21543 .32835 L
.21546 .31546 L
.21548 .26391 L
.2155 .27679 L
.21552 .32405 L
.21555 .32405 L
.21557 .25531 L
.21559 .22953 L
.21561 .31546 L
.21563 .36702 L
.21566 .32835 L
.21568 .28109 L
.2157 .24242 L
.21572 .25531 L
.21575 .31546 L
.21577 .34124 L
.21579 .31117 L
.21581 .27679 L
Mistroke
.21584 .2682 L
.21586 .2682 L
.21588 .25102 L
.2159 .26391 L
.21592 .3928 L
.21595 .44435 L
.21597 .28968 L
.21599 .23813 L
.21601 .2682 L
.21604 .20805 L
.21606 .19946 L
.21608 .32405 L
.2161 .36272 L
.21613 .31976 L
.21615 .31546 L
.21617 .29828 L
.21619 .20376 L
.21621 .20376 L
.21624 .3842 L
.21626 .45724 L
.21628 .25102 L
.2163 .18227 L
.21633 .32835 L
.21635 .36702 L
.21637 .28968 L
.21639 .32405 L
.21642 .28968 L
.21644 .21235 L
.21646 .24672 L
.21648 .33265 L
.21651 .32835 L
.21653 .29828 L
.21655 .31546 L
.21657 .29828 L
.21659 .28109 L
.21662 .28968 L
.21664 .32405 L
.21666 .32405 L
.21668 .3842 L
.21671 .34554 L
.21673 .2725 L
.21675 .24242 L
.21677 .23813 L
.2168 .25102 L
.21682 .31546 L
.21684 .37561 L
.21686 .34554 L
.21688 .30257 L
.21691 .27679 L
.21693 .2682 L
Mistroke
.21695 .25102 L
.21697 .26391 L
.217 .28539 L
.21702 .36702 L
.21704 .45295 L
.21706 .34983 L
.21709 .20805 L
.21711 .16509 L
.21713 .21664 L
.21715 .28968 L
.21718 .36272 L
.2172 .37131 L
.21722 .32405 L
.21724 .2725 L
.21726 .28109 L
.21729 .2725 L
.21731 .22953 L
.21733 .22094 L
.21735 .29828 L
.21738 .47443 L
.2174 .3885 L
.21742 .25961 L
.21744 .24242 L
.21747 .22953 L
.21749 .18227 L
.21751 .29398 L
.21753 .36272 L
.21755 .34124 L
.21758 .29398 L
.2176 .30687 L
.21762 .31117 L
.21764 .24672 L
.21767 .24672 L
.21769 .25102 L
.21771 .29828 L
.21773 .3928 L
.21776 .43576 L
.21778 .37131 L
.2178 .22524 L
.21782 .1479 L
.21784 .21235 L
.21787 .31117 L
.21789 .37131 L
.21791 .39709 L
.21793 .35413 L
.21796 .2725 L
.21798 .24672 L
.218 .25531 L
.21802 .23813 L
.21805 .2725 L
Mistroke
.21807 .34554 L
.21809 .3928 L
.21811 .37991 L
.21814 .32405 L
.21816 .24672 L
.21818 .19087 L
.2182 .20805 L
.21822 .29398 L
.21825 .36272 L
.21827 .36272 L
.21829 .33265 L
.21831 .29828 L
.21834 .2725 L
.21836 .25102 L
.21838 .25531 L
.2184 .2682 L
.21843 .27679 L
.21845 .28109 L
.21847 .37131 L
.21849 .45295 L
.21851 .32835 L
.21854 .18227 L
.21856 .17798 L
.21858 .22953 L
.2186 .2725 L
.21863 .34124 L
.21865 .37131 L
.21867 .31976 L
.21869 .27679 L
.21872 .25102 L
.21874 .2725 L
.21876 .22953 L
.21878 .21235 L
.21881 .31117 L
.21883 .45724 L
.21885 .39709 L
.21887 .28109 L
.21889 .26391 L
.21892 .18227 L
.21894 .17798 L
.21896 .30257 L
.21898 .40998 L
.21901 .36702 L
.21903 .36702 L
.21905 .31546 L
.21907 .2682 L
.2191 .25961 L
.21912 .25102 L
.21914 .25961 L
.21916 .28539 L
Mistroke
.21918 .32835 L
.21921 .3928 L
.21923 .40139 L
.21925 .31117 L
.21927 .19087 L
.2193 .1565 L
.21932 .24672 L
.21934 .33694 L
.21936 .37561 L
.21939 .3928 L
.21941 .33694 L
.21943 .24242 L
.21945 .21235 L
.21947 .24242 L
.2195 .26391 L
.21952 .29398 L
.21954 .33694 L
.21956 .40569 L
.21959 .40569 L
.21961 .29828 L
.21963 .16509 L
.21965 .1479 L
.21968 .23813 L
.2197 .34983 L
.21972 .3928 L
.21974 .35413 L
.21977 .28968 L
.21979 .23383 L
.21981 .24242 L
.21983 .2682 L
.21985 .26391 L
.21988 .25102 L
.2199 .28968 L
.21992 .45724 L
.21994 .40998 L
.21997 .27679 L
.21999 .19087 L
.22001 .14361 L
.22003 .21235 L
.22006 .31117 L
.22008 .43576 L
.2201 .37991 L
.22012 .32405 L
.22014 .23813 L
.22017 .18227 L
.22019 .24672 L
.22021 .2725 L
.22023 .34983 L
.22026 .41428 L
.22028 .39709 L
Mistroke
.2203 .29828 L
.22032 .23813 L
.22035 .24242 L
.22037 .19516 L
.22039 .2725 L
.22041 .36272 L
.22044 .37561 L
.22046 .31546 L
.22048 .29398 L
.2205 .30257 L
.22052 .24242 L
.22055 .25102 L
.22057 .28109 L
.22059 .28109 L
.22061 .30257 L
.22064 .37561 L
.22066 .44435 L
.22068 .33265 L
.2207 .16509 L
.22073 .14361 L
.22075 .23383 L
.22077 .33265 L
.22079 .37561 L
.22081 .40998 L
.22084 .36272 L
.22086 .25531 L
.22088 .22094 L
.2209 .22524 L
.22093 .23383 L
.22095 .28539 L
.22097 .37561 L
.22099 .43146 L
.22102 .3928 L
.22104 .27679 L
.22106 .1522 L
.22108 .1479 L
.2211 .25961 L
.22113 .37991 L
.22115 .40139 L
.22117 .34554 L
.22119 .2682 L
.22122 .23813 L
.22124 .22094 L
.22126 .28109 L
.22128 .29828 L
.22131 .25961 L
.22133 .31976 L
.22135 .45295 L
.22137 .3928 L
.2214 .3928 L
Mistroke
.22142 .21664 L
.22144 .22953 L
.22146 .22524 L
.22148 .22953 L
.22151 .28968 L
.22153 .42717 L
.22155 .36702 L
.22157 .27679 L
.2216 .30687 L
.22162 .22953 L
.22164 .22524 L
.22166 .28539 L
.22169 .31546 L
.22171 .37131 L
.22173 .43576 L
.22175 .40998 L
.22177 .19946 L
.2218 .11353 L
.22182 .19087 L
.22184 .33265 L
.22186 .40998 L
.22189 .40139 L
.22191 .34983 L
.22193 .2725 L
.22195 .20376 L
.22198 .19946 L
.222 .26391 L
.22202 .33265 L
.22204 .34983 L
.22206 .34554 L
.22209 .34554 L
.22211 .37131 L
.22213 .28968 L
.22215 .18227 L
.22218 .17798 L
.2222 .28109 L
.22222 .36272 L
.22224 .36702 L
.22227 .35843 L
.22229 .29398 L
.22231 .24242 L
.22233 .22524 L
.22236 .24672 L
.22238 .27679 L
.2224 .30257 L
.22242 .31546 L
.22244 .35413 L
.22247 .46154 L
.22249 .31117 L
.22251 .10924 L
Mistroke
.22253 .13501 L
.22256 .27679 L
.22258 .3885 L
.2226 .37561 L
.22262 .37991 L
.22265 .2682 L
.22267 .19516 L
.22269 .24672 L
.22271 .28968 L
.22273 .32405 L
.22276 .31117 L
.22278 .30687 L
.2228 .28539 L
.22282 .31117 L
.22285 .44865 L
.22287 .37131 L
.22289 .16938 L
.22291 .13501 L
.22294 .2725 L
.22296 .36272 L
.22298 .35843 L
.223 .3842 L
.22303 .30257 L
.22305 .22953 L
.22307 .23383 L
.22309 .25531 L
.22311 .28539 L
.22314 .28539 L
.22316 .32405 L
.22318 .39709 L
.2232 .42287 L
.22323 .33694 L
.22325 .16079 L
.22327 .10924 L
.22329 .24242 L
.22332 .40139 L
.22334 .43576 L
.22336 .35413 L
.22338 .28968 L
.2234 .24242 L
.22343 .19087 L
.22345 .22094 L
.22347 .31117 L
.22349 .34554 L
.22352 .34124 L
.22354 .35413 L
.22356 .37561 L
.22358 .28968 L
.22361 .17368 L
.22363 .17798 L
Mistroke
.22365 .2725 L
.22367 .37131 L
.22369 .3885 L
.22372 .35413 L
.22374 .27679 L
.22376 .27679 L
.22378 .18657 L
.22381 .21235 L
.22383 .28109 L
.22385 .34124 L
.22387 .34983 L
.2239 .30257 L
.22392 .25531 L
.22394 .30687 L
.22396 .3928 L
.22399 .29398 L
.22401 .21664 L
.22403 .24672 L
.22405 .29828 L
.22407 .31976 L
.2241 .33265 L
.22412 .34554 L
.22414 .26391 L
.22416 .25531 L
.22419 .28968 L
.22421 .29398 L
.22423 .31546 L
.22425 .28109 L
.22428 .25961 L
.2243 .2682 L
.22432 .43576 L
.22434 .46154 L
.22436 .18227 L
.22439 .14361 L
.22441 .21235 L
.22443 .35843 L
.22445 .36702 L
.22448 .35413 L
.2245 .37131 L
.22452 .19087 L
.22454 .20805 L
.22457 .26391 L
.22459 .28539 L
.22461 .34124 L
.22463 .30257 L
.22466 .34124 L
.22468 .37991 L
.2247 .3928 L
.22472 .26391 L
.22474 .09635 L
Mistroke
.22477 .17368 L
.22479 .35413 L
.22481 .44006 L
.22483 .3885 L
.22486 .31117 L
.22488 .20805 L
.2249 .16079 L
.22492 .24242 L
.22495 .32835 L
.22497 .35413 L
.22499 .31976 L
.22501 .30687 L
.22503 .35413 L
.22506 .32405 L
.22508 .21664 L
.2251 .17798 L
.22512 .24672 L
.22515 .34983 L
.22517 .3842 L
.22519 .35843 L
.22521 .29398 L
.22524 .21664 L
.22526 .22094 L
.22528 .28968 L
.2253 .34554 L
.22532 .34983 L
.22535 .30257 L
.22537 .25102 L
.22539 .25102 L
.22541 .3842 L
.22544 .44006 L
.22546 .28109 L
.22548 .17798 L
.2255 .17798 L
.22553 .28539 L
.22555 .35413 L
.22557 .37561 L
.22559 .36702 L
.22562 .25102 L
.22564 .22953 L
.22566 .25961 L
.22568 .25531 L
.2257 .29828 L
.22573 .29398 L
.22575 .31976 L
.22577 .37131 L
.22579 .43146 L
.22582 .33265 L
.22584 .1522 L
.22586 .11353 L
Mistroke
.22588 .26391 L
.22591 .41428 L
.22593 .39709 L
.22595 .33265 L
.22597 .2682 L
.22599 .22524 L
.22602 .23383 L
.22604 .25961 L
.22606 .30687 L
.22608 .31976 L
.22611 .32405 L
.22613 .32405 L
.22615 .37131 L
.22617 .39709 L
.2262 .24672 L
.22622 .12212 L
.22624 .17368 L
.22626 .31976 L
.22629 .44865 L
.22631 .40998 L
.22633 .31976 L
.22635 .20805 L
.22637 .1479 L
.2264 .25102 L
.22642 .33694 L
.22644 .36272 L
.22646 .34554 L
.22649 .28968 L
.22651 .30687 L
.22653 .34554 L
.22655 .31976 L
.22658 .22094 L
.2266 .19946 L
.22662 .29398 L
.22664 .37991 L
.22666 .36702 L
.22669 .32405 L
.22671 .25961 L
.22673 .22094 L
.22675 .25961 L
.22678 .31546 L
.2268 .34124 L
.22682 .32835 L
.22684 .28539 L
.22687 .26391 L
.22689 .25102 L
.22691 .25531 L
.22693 .40998 L
.22695 .44435 L
.22698 .23813 L
Mistroke
.227 .1479 L
.22702 .22524 L
.22704 .36272 L
.22707 .31546 L
.22709 .31117 L
.22711 .3842 L
.22713 .2682 L
.22716 .23383 L
.22718 .23383 L
.2272 .2725 L
.22722 .30687 L
.22725 .28109 L
.22727 .32405 L
.22729 .36272 L
.22731 .41857 L
.22733 .31546 L
.22736 .1565 L
.22738 .13501 L
.2274 .27679 L
.22742 .40569 L
.22745 .3885 L
.22747 .28109 L
.22749 .23383 L
.22751 .25961 L
.22754 .26391 L
.22756 .25961 L
.22758 .32405 L
.2276 .31546 L
.22762 .28539 L
.22765 .40139 L
.22767 .37991 L
.22769 .22094 L
.22771 .14361 L
.22774 .22094 L
.22776 .37131 L
.22778 .40569 L
.2278 .37991 L
.22783 .33694 L
.22785 .21235 L
.22787 .16938 L
.22789 .25961 L
.22792 .35843 L
.22794 .36702 L
.22796 .31546 L
.22798 .31546 L
.228 .33694 L
.22803 .31976 L
.22805 .25961 L
.22807 .21235 L
.22809 .22953 L
Mistroke
.22812 .31117 L
.22814 .37991 L
.22816 .34983 L
.22818 .28109 L
.22821 .25961 L
.22823 .25102 L
.22825 .26391 L
.22827 .31546 L
.22829 .32405 L
.22832 .28539 L
.22834 .25102 L
.22836 .31117 L
.22838 .43576 L
.22841 .34554 L
.22843 .21664 L
.22845 .19087 L
.22847 .18657 L
.2285 .18657 L
.22852 .32405 L
.22854 .40998 L
.22856 .34983 L
.22858 .28109 L
.22861 .24242 L
.22863 .23383 L
.22865 .25531 L
.22867 .28539 L
.2287 .29398 L
.22872 .27679 L
.22874 .3842 L
.22876 .44865 L
.22879 .31117 L
.22881 .19946 L
.22883 .11353 L
.22885 .20805 L
.22888 .40139 L
.2289 .41428 L
.22892 .35413 L
.22894 .2725 L
.22896 .21235 L
.22899 .23383 L
.22901 .27679 L
.22903 .32405 L
.22905 .31546 L
.22908 .30687 L
.2291 .33694 L
.22912 .3885 L
.22914 .35843 L
.22917 .19087 L
.22919 .16509 L
.22921 .26391 L
Mistroke
.22923 .36272 L
.22925 .42287 L
.22928 .37131 L
.2293 .27679 L
.22932 .21235 L
.22934 .20805 L
.22937 .27679 L
.22939 .31546 L
.22941 .31976 L
.22943 .3842 L
.22946 .46154 L
.22948 .26391 L
.2295 .13501 L
.22952 .17798 L
.22955 .23813 L
.22957 .40998 L
.22959 .40569 L
.22961 .33694 L
.22963 .30687 L
.22966 .17798 L
.22968 .21235 L
.2297 .31976 L
.22972 .31117 L
.22975 .32835 L
.22977 .33265 L
.22979 .30687 L
.22981 .29398 L
.22984 .29828 L
.22986 .29828 L
.22988 .25961 L
.2299 .2682 L
.22992 .29828 L
.22995 .32835 L
.22997 .30257 L
.22999 .2682 L
.23001 .28539 L
.23004 .2682 L
.23006 .28539 L
.23008 .28539 L
.2301 .29398 L
.23013 .34124 L
.23015 .26391 L
.23017 .23383 L
.23019 .39709 L
.23021 .43146 L
.23024 .2682 L
.23026 .16509 L
.23028 .21235 L
.2303 .32405 L
.23033 .34983 L
Mistroke
.23035 .39709 L
.23037 .35413 L
.23039 .22094 L
.23042 .20805 L
.23044 .24242 L
.23046 .31546 L
.23048 .37991 L
.23051 .36272 L
.23053 .31546 L
.23055 .32835 L
.23057 .30687 L
.23059 .21664 L
.23062 .22524 L
.23064 .28539 L
.23066 .35843 L
.23068 .36272 L
.23071 .33265 L
.23073 .31117 L
.23075 .23383 L
.23077 .20805 L
.2308 .28109 L
.23082 .32405 L
.23084 .32405 L
.23086 .32405 L
.23088 .29398 L
.23091 .31546 L
.23093 .42717 L
.23095 .32405 L
.23097 .1479 L
.231 .19946 L
.23102 .27679 L
.23104 .36272 L
.23106 .3842 L
.23109 .30257 L
.23111 .26391 L
.23113 .21235 L
.23115 .24242 L
.23118 .32835 L
.2312 .32405 L
.23122 .32835 L
.23124 .30257 L
.23126 .22094 L
.23129 .19516 L
.23131 .37561 L
.23133 .5045 L
.23135 .25531 L
.23138 .16509 L
.2314 .20805 L
.23142 .25531 L
.23144 .3928 L
Mistroke
.23147 .34554 L
.23149 .31546 L
.23151 .29828 L
.23153 .19516 L
.23155 .24672 L
.23158 .32405 L
.2316 .30687 L
.23162 .29828 L
.23164 .28539 L
.23167 .43576 L
.23169 .44435 L
.23171 .20376 L
.23173 .1522 L
.23176 .16938 L
.23178 .29828 L
.2318 .46583 L
.23182 .41428 L
.23184 .30257 L
.23187 .24242 L
.23189 .22524 L
.23191 .24242 L
.23193 .27679 L
.23196 .33694 L
.23198 .35413 L
.232 .32405 L
.23202 .30687 L
.23205 .31976 L
.23207 .28968 L
.23209 .23813 L
.23211 .24672 L
.23214 .29828 L
.23216 .34554 L
.23218 .33265 L
.2322 .31546 L
.23222 .28968 L
.23225 .23383 L
.23227 .24242 L
.23229 .31117 L
.23231 .31546 L
.23234 .31117 L
.23236 .28968 L
.23238 .29398 L
.2324 .35843 L
.23243 .29828 L
.23245 .24242 L
.23247 .2725 L
.23249 .2725 L
.23251 .2682 L
.23254 .31117 L
.23256 .33265 L
Mistroke
.23258 .30257 L
.2326 .2682 L
.23263 .27679 L
.23265 .2725 L
.23267 .28109 L
.23269 .30257 L
.23272 .2725 L
.23274 .27679 L
.23276 .27679 L
.23278 .34983 L
.23281 .47443 L
.23283 .24672 L
.23285 .1522 L
.23287 .26391 L
.23289 .25102 L
.23292 .36702 L
.23294 .3928 L
.23296 .31546 L
.23298 .2725 L
.23301 .19946 L
.23303 .25961 L
.23305 .32835 L
.23307 .31976 L
.2331 .32405 L
.23312 .30257 L
.23314 .28109 L
.23316 .31117 L
.23318 .40569 L
.23321 .40569 L
.23323 .30687 L
.23325 .17368 L
.23327 .21235 L
.2333 .33265 L
.23332 .3842 L
.23334 .34554 L
.23336 .28109 L
.23339 .23813 L
.23341 .19946 L
.23343 .2682 L
.23345 .36702 L
.23347 .35413 L
.2335 .28109 L
.23352 .30687 L
.23354 .35413 L
.23356 .24672 L
.23359 .20376 L
.23361 .25961 L
.23363 .30257 L
.23365 .34554 L
.23368 .34554 L
Mistroke
.2337 .32835 L
.23372 .27679 L
.23374 .18227 L
.23377 .22953 L
.23379 .31976 L
.23381 .32835 L
.23383 .31546 L
.23385 .27679 L
.23388 .29828 L
.2339 .40569 L
.23392 .30687 L
.23394 .14361 L
.23397 .19946 L
.23399 .28539 L
.23401 .3885 L
.23403 .3928 L
.23406 .28968 L
.23408 .2725 L
.2341 .21664 L
.23412 .21664 L
.23414 .34124 L
.23417 .34554 L
.23419 .31117 L
.23421 .30687 L
.23423 .23813 L
.23426 .2682 L
.23428 .41428 L
.2343 .3928 L
.23432 .2682 L
.23435 .22953 L
.23437 .22094 L
.23439 .28109 L
.23441 .36272 L
.23444 .34124 L
.23446 .32405 L
.23448 .26391 L
.2345 .20805 L
.23452 .2725 L
.23455 .31976 L
.23457 .31546 L
.23459 .33694 L
.23461 .29828 L
.23464 .28968 L
.23466 .39709 L
.23468 .32405 L
.2347 .16938 L
.23473 .19946 L
.23475 .31546 L
.23477 .37131 L
.23479 .35843 L
Mistroke
.23481 .30257 L
.23484 .25531 L
.23486 .25961 L
.23488 .2682 L
.2349 .29828 L
.23493 .31976 L
.23495 .29398 L
.23497 .28109 L
.23499 .29398 L
.23502 .33265 L
.23504 .34554 L
.23506 .31546 L
.23508 .23383 L
.2351 .19516 L
.23513 .28109 L
.23515 .32835 L
.23517 .33694 L
.23519 .34983 L
.23522 .28968 L
.23524 .23383 L
.23526 .23813 L
.23528 .31117 L
.23531 .34554 L
.23533 .30257 L
.23535 .2682 L
.23537 .28968 L
.2354 .37991 L
.23542 .36702 L
.23544 .23383 L
.23546 .23813 L
.23548 .30257 L
.23551 .29828 L
.23553 .34554 L
.23555 .34124 L
.23557 .34124 L
.2356 .25531 L
.23562 .2682 L
.23564 .32835 L
.23566 .31117 L
.23569 .28539 L
.23571 .2725 L
.23573 .24672 L
.23575 .25961 L
.23577 .31546 L
.2358 .47443 L
.23582 .42717 L
.23584 .18227 L
.23586 .16079 L
.23589 .20376 L
.23591 .31546 L
Mistroke
.23593 .42287 L
.23595 .37991 L
.23598 .29828 L
.236 .20805 L
.23602 .21664 L
.23604 .30257 L
.23607 .31976 L
.23609 .34983 L
.23611 .33694 L
.23613 .26391 L
.23615 .19946 L
.23618 .31117 L
.2362 .44865 L
.23622 .31546 L
.23624 .16938 L
.23627 .23383 L
.23629 .31117 L
.23631 .31546 L
.23633 .32835 L
.23636 .33265 L
.23638 .2725 L
.2364 .23813 L
.23642 .28539 L
.23644 .28539 L
.23647 .25961 L
.23649 .32405 L
.23651 .44006 L
.23653 .33694 L
.23656 .17798 L
.23658 .24672 L
.2366 .2682 L
.23662 .2682 L
.23665 .37991 L
.23667 .37991 L
.23669 .28109 L
.23671 .24242 L
.23673 .26391 L
.23676 .28968 L
.23678 .31117 L
.2368 .33265 L
.23682 .32405 L
.23685 .2682 L
.23687 .28968 L
.23689 .42717 L
.23691 .34983 L
.23694 .13501 L
.23696 .22524 L
.23698 .33694 L
.237 .33265 L
.23703 .36272 L
Mistroke
.23705 .31117 L
.23707 .22524 L
.23709 .28109 L
.23711 .30257 L
.23714 .25961 L
.23716 .28539 L
.23718 .31546 L
.2372 .2682 L
.23723 .22094 L
.23725 .42287 L
.23727 .49161 L
.23729 .19946 L
.23732 .1522 L
.23734 .21664 L
.23736 .25531 L
.23738 .37131 L
.2374 .37561 L
.23743 .31117 L
.23745 .26391 L
.23747 .22524 L
.23749 .28539 L
.23752 .29398 L
.23754 .2682 L
.23756 .28968 L
.23758 .28109 L
.23761 .2725 L
.23763 .3928 L
.23765 .45724 L
.23767 .19516 L
.23769 .07486 L
.23772 .2725 L
.23774 .37561 L
.23776 .36272 L
.23778 .37991 L
.23781 .31546 L
.23783 .20805 L
.23785 .21664 L
.23787 .29828 L
.2379 .30687 L
.23792 .28109 L
.23794 .28109 L
.23796 .34983 L
.23799 .49161 L
.23801 .34124 L
.23803 .11353 L
.23805 .16938 L
.23807 .27679 L
.2381 .35843 L
.23812 .41857 L
.23814 .37991 L
Mistroke
.23816 .25961 L
.23819 .18657 L
.23821 .26391 L
.23823 .32835 L
.23825 .30257 L
.23828 .32405 L
.2383 .33694 L
.23832 .25961 L
.23834 .2682 L
.23836 .35413 L
.23839 .37561 L
.23841 .24672 L
.23843 .22524 L
.23845 .33265 L
.23848 .28109 L
.2385 .29828 L
.23852 .31546 L
.23854 .25531 L
.23857 .30257 L
.23859 .31117 L
.23861 .2682 L
.23863 .26391 L
.23866 .25531 L
.23868 .28109 L
.2387 .29828 L
.23872 .34554 L
.23874 .47443 L
.23877 .30257 L
.23879 .09635 L
.23881 .1522 L
.23883 .28539 L
.23886 .40139 L
.23888 .41857 L
.2389 .32835 L
.23892 .19946 L
.23895 .17798 L
.23897 .29828 L
.23899 .33694 L
.23901 .33694 L
.23903 .31546 L
.23906 .25531 L
.23908 .25102 L
.2391 .30257 L
.23912 .37991 L
.23915 .3842 L
.23917 .2725 L
.23919 .21235 L
.23921 .25531 L
.23924 .31117 L
.23926 .34554 L
Mistroke
.23928 .34554 L
.2393 .31976 L
.23932 .26391 L
.23935 .25102 L
.23937 .28539 L
.23939 .28109 L
.23941 .28109 L
.23944 .41857 L
.23946 .42287 L
.23948 .16938 L
.2395 .19087 L
.23953 .31546 L
.23955 .28109 L
.23957 .30257 L
.23959 .3842 L
.23962 .33265 L
.23964 .23383 L
.23966 .22524 L
.23968 .2682 L
.2397 .29398 L
.23973 .34983 L
.23975 .33694 L
.23977 .24672 L
.23979 .21664 L
.23982 .25102 L
.23984 .43146 L
.23986 .42717 L
.23988 .20376 L
.23991 .21235 L
.23993 .21664 L
.23995 .24672 L
.23997 .39709 L
.23999 .37131 L
.24002 .25531 L
.24004 .21664 L
.24006 .24242 L
.24008 .27679 L
.24011 .28968 L
.24013 .31546 L
.24015 .32835 L
.24017 .24672 L
.2402 .31117 L
.24022 .46154 L
.24024 .28109 L
.24026 .11353 L
.24029 .20376 L
.24031 .20376 L
.24033 .35843 L
.24035 .3928 L
.24037 .33265 L
Mistroke
.2404 .28539 L
.24042 .28539 L
.24044 .2682 L
.24046 .28109 L
.24049 .31546 L
.24051 .28539 L
.24053 .28539 L
.24055 .3885 L
.24058 .3842 L
.2406 .25531 L
.24062 .19946 L
.24064 .25102 L
.24066 .31117 L
.24069 .36702 L
.24071 .3885 L
.24073 .32405 L
.24075 .22953 L
.24078 .20376 L
.2408 .25961 L
.24082 .32405 L
.24084 .34983 L
.24087 .32405 L
.24089 .31117 L
.24091 .3842 L
.24093 .34124 L
.24095 .16079 L
.24098 .17798 L
.241 .30687 L
.24102 .34554 L
.24104 .35413 L
.24107 .33694 L
.24109 .28109 L
.24111 .24242 L
.24113 .24672 L
.24116 .2725 L
.24118 .28968 L
.2412 .30687 L
.24122 .29398 L
.24125 .27679 L
.24127 .37991 L
.24129 .37561 L
.24131 .18227 L
.24133 .22094 L
.24136 .29398 L
.24138 .29828 L
.2414 .35413 L
.24142 .30257 L
.24145 .22094 L
.24147 .2682 L
.24149 .30257 L
Mistroke
.24151 .29828 L
.24154 .27679 L
.24156 .2725 L
.24158 .31976 L
.2416 .31546 L
.24162 .40998 L
.24165 .42287 L
.24167 .18657 L
.24169 .13501 L
.24171 .25102 L
.24174 .3842 L
.24176 .42717 L
.24178 .34554 L
.2418 .25961 L
.24183 .19087 L
.24185 .22953 L
.24187 .33265 L
.24189 .37131 L
.24192 .35413 L
.24194 .25961 L
.24196 .34554 L
.24198 .36272 L
.242 .19946 L
.24203 .23383 L
.24205 .31117 L
.24207 .31546 L
.24209 .36272 L
.24212 .35413 L
.24214 .28968 L
.24216 .22524 L
.24218 .23383 L
.24221 .31546 L
.24223 .31546 L
.24225 .29398 L
.24227 .28539 L
.24229 .31546 L
.24232 .3885 L
.24234 .29828 L
.24236 .19946 L
.24238 .2725 L
.24241 .27679 L
.24243 .28539 L
.24245 .35843 L
.24247 .29828 L
.2425 .22953 L
.24252 .26391 L
.24254 .29828 L
.24256 .31117 L
.24258 .32405 L
.24261 .28109 L
Mistroke
.24263 .23383 L
.24265 .2682 L
.24267 .2682 L
.2427 .29398 L
.24272 .36702 L
.24274 .41428 L
.24276 .23383 L
.24279 .19946 L
.24281 .29398 L
.24283 .26391 L
.24285 .34124 L
.24288 .37991 L
.2429 .2725 L
.24292 .25102 L
.24294 .28109 L
.24296 .28109 L
.24299 .29398 L
.24301 .29828 L
.24303 .30257 L
.24305 .28968 L
.24308 .3885 L
.2431 .48732 L
.24312 .24672 L
.24314 .08775 L
.24317 .20805 L
.24319 .37131 L
.24321 .43146 L
.24323 .37131 L
.24325 .2682 L
.24328 .21235 L
.2433 .22524 L
.24332 .2725 L
.24334 .33694 L
.24337 .39709 L
.24339 .29828 L
.24341 .34983 L
.24343 .3885 L
.24346 .18227 L
.24348 .17368 L
.2435 .28539 L
.24352 .34124 L
.24355 .37561 L
.24357 .3928 L
.24359 .30257 L
.24361 .16509 L
.24363 .18227 L
.24366 .31546 L
.24368 .34983 L
.2437 .34983 L
.24372 .31546 L
Mistroke
.24375 .22953 L
.24377 .29398 L
.24379 .40139 L
.24381 .25961 L
.24384 .18657 L
.24386 .29828 L
.24388 .31546 L
.2439 .34124 L
.24392 .34554 L
.24395 .20805 L
.24397 .19946 L
.24399 .32835 L
.24401 .33265 L
.24404 .29828 L
.24406 .32835 L
.24408 .29828 L
.2441 .24242 L
.24413 .24242 L
.24415 .29398 L
.24417 .41857 L
.24419 .41857 L
.24421 .24242 L
.24424 .22094 L
.24426 .22953 L
.24428 .25102 L
.2443 .36702 L
.24433 .37561 L
.24435 .29828 L
.24437 .28539 L
.24439 .2725 L
.24442 .23383 L
.24444 .24672 L
.24446 .29398 L
.24448 .32405 L
.24451 .35413 L
.24453 .47443 L
.24455 .36702 L
.24457 .10494 L
.24459 .10494 L
.24462 .28109 L
.24464 .43576 L
.24466 .44006 L
.24468 .30257 L
.24471 .19516 L
.24473 .17798 L
.24475 .23383 L
.24477 .30257 L
.2448 .36272 L
.24482 .35843 L
.24484 .46583 L
Mistroke
.24486 .33265 L
.24488 .07057 L
.24491 .13931 L
.24493 .25961 L
.24495 .36272 L
.24497 .47013 L
.245 .44435 L
.24502 .24672 L
.24504 .24672 L
.24506 .07916 L
.24509 .1565 L
.24511 .33265 L
.24513 .39709 L
.24515 .37991 L
.24518 .31546 L
.2452 .22953 L
.24522 .23383 L
.24524 .26391 L
.24526 .30257 L
.24529 .35843 L
.24531 .31546 L
.24533 .28109 L
.24535 .28539 L
.24538 .24672 L
.2454 .22953 L
.24542 .31546 L
.24544 .37561 L
.24547 .33265 L
.24549 .2725 L
.24551 .23383 L
.24553 .24672 L
.24555 .29828 L
.24558 .33265 L
.2456 .37561 L
.24562 .37131 L
.24564 .25961 L
.24567 .23383 L
.24569 .2725 L
.24571 .22953 L
.24573 .31117 L
.24576 .39709 L
.24578 .31976 L
.2458 .25531 L
.24582 .26391 L
.24584 .2682 L
.24587 .28539 L
.24589 .27679 L
.24591 .27679 L
.24593 .29398 L
.24596 .40139 L
Mistroke
.24598 .44865 L
.246 .25961 L
.24602 .16509 L
.24605 .14361 L
.24607 .2682 L
.24609 .44006 L
.24611 .42287 L
.24614 .28109 L
.24616 .19946 L
.24618 .21235 L
.2462 .22524 L
.24622 .27679 L
.24625 .37561 L
.24627 .3842 L
.24629 .43576 L
.24631 .33694 L
.24634 .12212 L
.24636 .12212 L
.24638 .25102 L
.2464 .40569 L
.24643 .46154 L
.24645 .3928 L
.24647 .24672 L
.24649 .13931 L
.24651 .17798 L
.24654 .28968 L
.24656 .37131 L
.24658 .37561 L
.2466 .33265 L
.24663 .37131 L
.24665 .29398 L
.24667 .1565 L
.24669 .20805 L
.24672 .32405 L
.24674 .37561 L
.24676 .39709 L
.24678 .34124 L
.24681 .24672 L
.24683 .19946 L
.24685 .25102 L
.24687 .31117 L
.24689 .32835 L
.24692 .31117 L
.24694 .31546 L
.24696 .45295 L
.24698 .36272 L
.24701 .10924 L
.24703 .16509 L
.24705 .30687 L
.24707 .35843 L
Mistroke
.2471 .41857 L
.24712 .37561 L
.24714 .21664 L
.24716 .18657 L
.24718 .28109 L
.24721 .30257 L
.24723 .30687 L
.24725 .32405 L
.24727 .28539 L
.2473 .29398 L
.24732 .37561 L
.24734 .33265 L
.24736 .22524 L
.24739 .24672 L
.24741 .24672 L
.24743 .2725 L
.24745 .30687 L
.24747 .37131 L
.2475 .29828 L
.24752 .21235 L
.24754 .2682 L
.24756 .30687 L
.24759 .29828 L
.24761 .28539 L
.24763 .26391 L
.24765 .28968 L
.24768 .36702 L
.2477 .43146 L
.24772 .29398 L
.24774 .1479 L
.24777 .17798 L
.24779 .29828 L
.24781 .40569 L
.24783 .3842 L
.24785 .27679 L
.24788 .22524 L
.2479 .23383 L
.24792 .24242 L
.24794 .30257 L
.24797 .36702 L
.24799 .36702 L
.24801 .42717 L
.24803 .26391 L
.24806 .13072 L
.24808 .20805 L
.2481 .29828 L
.24812 .37561 L
.24814 .43576 L
.24817 .39709 L
.24819 .23813 L
Mistroke
.24821 .14361 L
.24823 .22094 L
.24826 .31976 L
.24828 .36272 L
.2483 .36702 L
.24832 .29828 L
.24835 .25961 L
.24837 .33265 L
.24839 .31117 L
.24841 .22953 L
.24844 .2682 L
.24846 .32835 L
.24848 .33694 L
.2485 .34124 L
.24852 .25961 L
.24855 .18657 L
.24857 .28539 L
.24859 .35843 L
.24861 .31546 L
.24864 .29828 L
.24866 .28109 L
.24868 .24242 L
.2487 .23813 L
.24873 .32405 L
.24875 .43146 L
.24877 .33694 L
.24879 .22953 L
.24881 .24242 L
.24884 .21235 L
.24886 .28109 L
.24888 .37991 L
.2489 .32835 L
.24893 .27679 L
.24895 .26391 L
.24897 .25531 L
.24899 .28109 L
.24902 .2682 L
.24904 .23813 L
.24906 .31976 L
.24908 .5088 L
.2491 .36702 L
.24913 .17368 L
.24915 .19516 L
.24917 .16938 L
.24919 .30257 L
.24922 .45724 L
.24924 .3928 L
.24926 .26391 L
.24928 .20376 L
.24931 .20805 L
Mistroke
.24933 .24242 L
.24935 .33265 L
.24937 .39709 L
.2494 .42717 L
.24942 .44435 L
.24944 .21235 L
.24946 .08775 L
.24948 .18657 L
.24951 .31976 L
.24953 .44006 L
.24955 .45724 L
.24957 .35413 L
.2496 .20805 L
.24962 .13072 L
.24964 .21235 L
.24966 .33265 L
.24969 .39709 L
.24971 .37561 L
.24973 .34554 L
.24975 .33694 L
.24977 .33694 L
.2498 .21235 L
.24982 .1522 L
.24984 .2725 L
.24986 .35843 L
.24989 .39709 L
.24991 .3842 L
.24993 .26391 L
.24995 .17368 L
.24998 .20805 L
.25 .29398 L
.25002 .34554 L
.25004 .33265 L
.25007 .28109 L
.25009 .31117 L
.25011 .3842 L
.25013 .2682 L
.25015 .19087 L
.25018 .2682 L
.2502 .26391 L
.25022 .31546 L
.25024 .37991 L
.25027 .30257 L
.25029 .25961 L
.25031 .2725 L
.25033 .2682 L
.25036 .2725 L
.25038 .29398 L
.2504 .28539 L
.25042 .26391 L
Mistroke
.25044 .40998 L
.25047 .42717 L
.25049 .19946 L
.25051 .21664 L
.25053 .2682 L
.25056 .25531 L
.25058 .3842 L
.2506 .37561 L
.25062 .23813 L
.25065 .22953 L
.25067 .28968 L
.25069 .29828 L
.25071 .2682 L
.25073 .30257 L
.25076 .32405 L
.25078 .42717 L
.2508 .44006 L
.25082 .20376 L
.25085 .09635 L
.25087 .22094 L
.25089 .3842 L
.25091 .45295 L
.25094 .34983 L
.25096 .20805 L
.25098 .18657 L
.251 .23813 L
.25103 .28109 L
.25105 .37131 L
.25107 .37991 L
.25109 .44006 L
.25111 .32835 L
.25114 .09635 L
.25116 .1479 L
.25118 .2682 L
.2512 .37131 L
.25123 .44865 L
.25125 .41428 L
.25127 .28109 L
.25129 .14361 L
.25132 .16509 L
.25134 .2682 L
.25136 .34124 L
.25138 .3928 L
.2514 .33694 L
.25143 .29828 L
.25145 .37131 L
.25147 .23383 L
.25149 .11783 L
.25152 .25961 L
.25154 .37131 L
Mistroke
.25156 .40998 L
.25158 .37991 L
.25161 .21664 L
.25163 .13501 L
.25165 .25531 L
.25167 .35843 L
.2517 .33694 L
.25172 .32405 L
.25174 .28968 L
.25176 .22094 L
.25178 .29398 L
.25181 .41857 L
.25183 .34124 L
.25185 .24242 L
.25187 .22094 L
.2519 .24672 L
.25192 .34554 L
.25194 .36702 L
.25196 .28968 L
.25199 .25102 L
.25201 .29398 L
.25203 .31976 L
.25205 .25102 L
.25207 .25531 L
.2521 .25961 L
.25212 .25961 L
.25214 .39709 L
.25216 .49591 L
.25219 .21664 L
.25221 .20376 L
.25223 .26391 L
.25225 .21235 L
.25228 .35413 L
.2523 .41857 L
.25232 .29828 L
.25234 .21664 L
.25236 .24242 L
.25239 .27679 L
.25241 .25531 L
.25243 .31546 L
.25245 .36702 L
.25248 .43576 L
.2525 .3842 L
.25252 .1522 L
.25254 .12642 L
.25257 .25102 L
.25259 .37131 L
.25261 .42287 L
.25263 .36272 L
.25266 .24242 L
Mistroke
.25268 .18227 L
.2527 .22094 L
.25272 .28539 L
.25274 .33694 L
.25277 .36702 L
.25279 .44006 L
.25281 .34554 L
.25283 .12212 L
.25286 .1479 L
.25288 .26391 L
.2529 .34983 L
.25292 .43576 L
.25295 .42287 L
.25297 .29398 L
.25299 .16079 L
.25301 .1565 L
.25303 .25102 L
.25306 .34554 L
.25308 .35843 L
.2531 .3885 L
.25312 .47013 L
.25315 .28968 L
.25317 .08346 L
.25319 .17798 L
.25321 .30257 L
.25324 .3928 L
.25326 .45724 L
.25328 .34554 L
.2533 .20805 L
.25333 .19087 L
.25335 .24242 L
.25337 .30687 L
.25339 .34983 L
.25341 .33265 L
.25344 .29828 L
.25346 .40998 L
.25348 .32405 L
.2535 .19946 L
.25353 .23813 L
.25355 .19946 L
.25357 .34124 L
.25359 .45724 L
.25362 .31117 L
.25364 .20805 L
.25366 .22094 L
.25368 .25961 L
.2537 .28968 L
.25373 .28539 L
.25375 .32405 L
.25377 .47443 L
Mistroke
.25379 .37561 L
.25382 .18657 L
.25384 .1565 L
.25386 .18657 L
.25388 .33694 L
.25391 .46583 L
.25393 .3885 L
.25395 .23813 L
.25397 .17368 L
.25399 .19087 L
.25402 .24242 L
.25404 .34124 L
.25406 .39709 L
.25408 .47872 L
.25411 .3842 L
.25413 .11783 L
.25415 .12642 L
.25417 .22094 L
.2542 .35413 L
.25422 .46154 L
.25424 .40998 L
.25426 .25961 L
.25429 .17368 L
.25431 .21664 L
.25433 .2725 L
.25435 .33694 L
.25437 .37131 L
.2544 .31546 L
.25442 .37131 L
.25444 .37131 L
.25446 .19087 L
.25449 .19087 L
.25451 .19087 L
.25453 .27679 L
.25455 .34124 L
.25458 .41428 L
.2546 .37131 L
.25462 .25102 L
.25464 .21235 L
.25466 .24672 L
.25469 .2725 L
.25471 .29398 L
.25473 .30687 L
.25475 .41857 L
.25478 .46154 L
.2548 .20805 L
.25482 .12642 L
.25484 .22524 L
.25487 .2682 L
.25489 .3885 L
Mistroke
.25491 .42287 L
.25493 .31976 L
.25495 .24242 L
.25498 .20376 L
.255 .22953 L
.25502 .29828 L
.25504 .32835 L
.25507 .29398 L
.25509 .37131 L
.25511 .43576 L
.25513 .23813 L
.25516 .18227 L
.25518 .22953 L
.2552 .23813 L
.25522 .40998 L
.25525 .40998 L
.25527 .25102 L
.25529 .21235 L
.25531 .23813 L
.25533 .2725 L
.25536 .29828 L
.25538 .29398 L
.2554 .34124 L
.25542 .46583 L
.25545 .32405 L
.25547 .19516 L
.25549 .16938 L
.25551 .19516 L
.25554 .3842 L
.25556 .47013 L
.25558 .34983 L
.2556 .21664 L
.25562 .17368 L
.25565 .21235 L
.25567 .2725 L
.25569 .35843 L
.25571 .44865 L
.25574 .48302 L
.25576 .22524 L
.25578 .09205 L
.2558 .19516 L
.25583 .28539 L
.25585 .40139 L
.25587 .46154 L
.25589 .3885 L
.25592 .24242 L
.25594 .14361 L
.25596 .17368 L
.25598 .2725 L
.256 .39709 L
Mistroke
.25603 .39709 L
.25605 .32835 L
.25607 .34124 L
.25609 .26391 L
.25612 .16079 L
.25614 .24672 L
.25616 .32405 L
.25618 .36272 L
.25621 .40569 L
.25623 .28968 L
.25625 .16509 L
.25627 .22953 L
.25629 .30257 L
.25632 .29828 L
.25634 .31117 L
.25636 .25961 L
.25638 .35413 L
.25641 .46154 L
.25643 .22953 L
.25645 .16079 L
.25647 .20805 L
.2565 .23813 L
.25652 .40139 L
.25654 .40998 L
.25656 .29398 L
.25658 .22953 L
.25661 .22524 L
.25663 .25961 L
.25665 .28539 L
.25667 .30687 L
.2567 .2682 L
.25672 .40569 L
.25674 .43146 L
.25676 .18657 L
.25679 .23383 L
.25681 .21664 L
.25683 .23813 L
.25685 .23813 L
.25688 .44006 L
.2569 .3842 L
.25692 .25531 L
.25694 .23383 L
.25696 .23813 L
.25699 .28109 L
.25701 .29398 L
.25703 .30687 L
.25705 .39709 L
.25708 .43146 L
.2571 .2725 L
.25712 .19516 L
Mistroke
.25714 .17368 L
.25717 .24672 L
.25719 .42287 L
.25721 .42717 L
.25723 .29828 L
.25725 .20805 L
.25728 .19087 L
.2573 .22524 L
.25732 .29828 L
.25734 .36702 L
.25737 .47013 L
.25739 .42717 L
.25741 .13072 L
.25743 .10924 L
.25746 .22524 L
.25748 .31976 L
.2575 .43146 L
.25752 .43146 L
.25755 .34554 L
.25757 .19087 L
.25759 .13931 L
.25761 .22524 L
.25763 .31117 L
.25766 .3842 L
.25768 .34983 L
.2577 .37131 L
.25772 .36702 L
.25775 .16509 L
.25777 .1565 L
.25779 .27679 L
.25781 .34124 L
.25784 .42287 L
.25786 .36272 L
.25788 .22094 L
.2579 .21235 L
.25792 .25961 L
.25795 .28109 L
.25797 .30687 L
.25799 .30257 L
.25801 .29828 L
.25804 .45295 L
.25806 .35843 L
.25808 .17368 L
.2581 .21664 L
.25813 .19087 L
.25815 .32405 L
.25817 .46154 L
.25819 .34554 L
.25821 .24672 L
.25824 .25531 L
Mistroke
.25826 .29828 L
.25828 .25961 L
.2583 .2725 L
.25833 .29398 L
.25835 .3928 L
.25837 .48302 L
.25839 .22094 L
.25842 .21235 L
.25844 .23813 L
.25846 .20376 L
.25848 .42717 L
.25851 .41428 L
.25853 .2725 L
.25855 .23383 L
.25857 .23383 L
.25859 .25961 L
.25862 .27679 L
.25864 .33265 L
.25866 .41428 L
.25868 .41428 L
.25871 .25531 L
.25873 .18227 L
.25875 .18657 L
.25877 .25531 L
.2588 .41428 L
.25882 .42717 L
.25884 .29828 L
.25886 .20376 L
.25888 .20376 L
.25891 .22524 L
.25893 .30687 L
.25895 .37131 L
.25897 .44865 L
.259 .43146 L
.25902 .13931 L
.25904 .12642 L
.25906 .22524 L
.25909 .29398 L
.25911 .44006 L
.25913 .46154 L
.25915 .34124 L
.25918 .16509 L
.2592 .1522 L
.25922 .1522 L
.25924 .25531 L
.25926 .31117 L
.25929 .37991 L
.25931 .34983 L
.25933 .35843 L
.25935 .3842 L
Mistroke
.25938 .18227 L
.2594 .1565 L
.25942 .28539 L
.25944 .34983 L
.25947 .43146 L
.25949 .37991 L
.25951 .20376 L
.25953 .19946 L
.25955 .26391 L
.25958 .29398 L
.2596 .35413 L
.25962 .31976 L
.25964 .24242 L
.25967 .43576 L
.25969 .42717 L
.25971 .17368 L
.25973 .18227 L
.25976 .19516 L
.25978 .31546 L
.2598 .45295 L
.25982 .34554 L
.25984 .23383 L
.25987 .25102 L
.25989 .2725 L
.25991 .24672 L
.25993 .25531 L
.25996 .37131 L
.25998 .47013 L
.26 .2682 L
.26002 .18657 L
.26005 .30687 L
.26007 .19087 L
.26009 .27679 L
.26011 .41857 L
.26014 .33265 L
.26016 .30687 L
.26018 .24672 L
.2602 .19087 L
.26022 .21664 L
.26025 .29398 L
.26027 .37991 L
.26029 .47872 L
.26031 .35843 L
.26034 .13931 L
.26036 .13501 L
.26038 .22953 L
.2604 .3885 L
.26043 .42717 L
.26045 .33694 L
.26047 .25531 L
Mistroke
.26049 .21235 L
.26051 .20805 L
.26054 .23383 L
.26056 .29828 L
.26058 .45724 L
.2606 .49591 L
.26063 .20376 L
.26065 .12642 L
.26067 .19946 L
.26069 .23813 L
.26072 .40139 L
.26074 .46154 L
.26076 .40139 L
.26078 .26391 L
.26081 .1565 L
.26083 .19087 L
.26085 .26391 L
.26087 .35843 L
.26089 .36272 L
.26092 .3928 L
.26094 .42717 L
.26096 .21664 L
.26098 .12642 L
.26101 .22953 L
.26103 .30687 L
.26105 .41857 L
.26107 .40998 L
.2611 .25961 L
.26112 .22094 L
.26114 .24242 L
.26116 .24672 L
.26118 .30257 L
.26121 .29828 L
.26123 .31117 L
.26125 .44006 L
.26127 .33694 L
.2613 .22524 L
.26132 .21664 L
.26134 .1479 L
.26136 .31546 L
.26139 .43146 L
.26141 .34124 L
.26143 .26391 L
.26145 .23383 L
.26147 .22953 L
.2615 .25961 L
.26152 .25961 L
.26154 .3928 L
.26156 .48732 L
.26159 .48732 L
Mistroke
.26161 .19946 L
.26163 .21235 L
.26165 .25102 L
.26168 .18657 L
.2617 .37131 L
.26172 .3928 L
.26174 .31976 L
.26177 .29398 L
.26179 .22524 L
.26181 .20376 L
.26183 .24672 L
.26185 .33265 L
.26188 .40998 L
.2619 .45724 L
.26192 .2682 L
.26194 .1565 L
.26197 .20805 L
.26199 .2725 L
.26201 .3842 L
.26203 .3842 L
.26206 .32405 L
.26208 .2682 L
.2621 .22524 L
.26212 .25961 L
.26214 .29828 L
.26217 .31117 L
.26219 .30257 L
.26221 .41857 L
.26223 .40998 L
.26226 .19087 L
.26228 .16509 L
.2623 .23813 L
.26232 .30257 L
.26235 .40569 L
.26237 .40139 L
.26239 .31117 L
.26241 .23383 L
.26244 .20376 L
.26246 .22524 L
.26248 .25531 L
.2625 .40139 L
.26252 .46154 L
.26255 .25961 L
.26257 .23383 L
.26259 .28968 L
.26261 .20376 L
.26264 .24242 L
.26266 .34983 L
.26268 .35843 L
.2627 .33694 L
Mistroke
.26273 .28539 L
.26275 .21664 L
.26277 .22094 L
.26279 .25102 L
.26281 .32405 L
.26284 .5088 L
.26286 .31546 L
.26288 .19946 L
.2629 .27679 L
.26293 .17368 L
.26295 .29398 L
.26297 .3928 L
.26299 .30257 L
.26302 .31117 L
.26304 .29398 L
.26306 .23813 L
.26308 .24242 L
.2631 .24672 L
.26313 .44006 L
.26315 .46583 L
.26317 .19946 L
.26319 .24242 L
.26322 .23813 L
.26324 .25102 L
.26326 .3928 L
.26328 .34554 L
.26331 .29828 L
.26333 .33265 L
.26335 .2682 L
.26337 .23383 L
.2634 .28109 L
.26342 .28968 L
.26344 .37561 L
.26346 .44865 L
.26348 .28109 L
.26351 .21664 L
.26353 .21664 L
.26355 .26391 L
.26357 .34983 L
.2636 .32835 L
.26362 .32405 L
.26364 .34554 L
.26366 .28539 L
.26369 .24242 L
.26371 .22094 L
.26373 .22524 L
.26375 .41428 L
.26377 .45295 L
.2638 .24242 L
.26382 .21235 L
Mistroke
.26384 .25531 L
.26386 .25531 L
.26389 .31117 L
.26391 .33265 L
.26393 .33265 L
.26395 .33265 L
.26398 .32835 L
.264 .25531 L
.26402 .22094 L
.26404 .22094 L
.26407 .24672 L
.26409 .41857 L
.26411 .44865 L
.26413 .24672 L
.26415 .23383 L
.26418 .23383 L
.2642 .20805 L
.26422 .32405 L
.26424 .34124 L
.26427 .31976 L
.26429 .33265 L
.26431 .27679 L
.26433 .22094 L
.26436 .25102 L
.26438 .24242 L
.2644 .35843 L
.26442 .5045 L
.26444 .2725 L
.26447 .24242 L
.26449 .25961 L
.26451 .18657 L
.26453 .34124 L
.26456 .36702 L
.26458 .29828 L
.2646 .31976 L
.26462 .28539 L
.26465 .24242 L
.26467 .25102 L
.26469 .29828 L
.26471 .47443 L
.26473 .34554 L
.26476 .16509 L
.26478 .28539 L
.2648 .26391 L
.26482 .29398 L
.26485 .37131 L
.26487 .28539 L
.26489 .28968 L
.26491 .29398 L
.26494 .22953 L
Mistroke
.26496 .25531 L
.26498 .30257 L
.265 .32405 L
.26503 .46583 L
.26505 .32405 L
.26507 .12642 L
.26509 .22094 L
.26511 .27679 L
.26514 .33265 L
.26516 .35413 L
.26518 .30687 L
.2652 .31546 L
.26523 .2725 L
.26525 .24242 L
.26527 .23813 L
.26529 .25961 L
.26532 .30687 L
.26534 .3842 L
.26536 .41428 L
.26538 .23383 L
.2654 .18227 L
.26543 .2725 L
.26545 .28539 L
.26547 .32835 L
.26549 .33265 L
.26552 .29398 L
.26554 .29828 L
.26556 .2682 L
.26558 .25531 L
.26561 .24672 L
.26563 .26391 L
.26565 .45724 L
.26567 .43146 L
.2657 .21664 L
.26572 .22953 L
.26574 .23383 L
.26576 .25961 L
.26578 .35413 L
.26581 .34983 L
.26583 .32405 L
.26585 .30687 L
.26587 .2725 L
.2659 .25102 L
.26592 .22953 L
.26594 .25102 L
.26596 .50021 L
.26599 .42717 L
.26601 .18227 L
.26603 .22953 L
.26605 .20805 L
Mistroke
.26607 .29398 L
.2661 .37991 L
.26612 .30257 L
.26614 .32405 L
.26616 .32835 L
.26619 .22953 L
.26621 .21235 L
.26623 .25961 L
.26625 .37561 L
.26628 .49161 L
.2663 .26391 L
.26632 .26391 L
.26634 .1565 L
.26636 .25531 L
.26639 .27679 L
.26641 .34983 L
.26643 .31546 L
.26645 .28968 L
.26648 .33265 L
.2665 .26391 L
.26652 .19946 L
.26654 .24672 L
.26657 .31546 L
.26659 .37991 L
.26661 .45295 L
.26663 .25102 L
.26666 .13501 L
.26668 .24672 L
.2667 .28539 L
.26672 .33265 L
.26674 .37131 L
.26677 .34124 L
.26679 .29398 L
.26681 .25102 L
.26683 .21664 L
.26686 .23383 L
.26688 .2682 L
.2669 .43576 L
.26692 .48732 L
.26695 .19946 L
.26697 .19516 L
.26699 .28968 L
.26701 .26391 L
.26703 .33694 L
.26706 .31546 L
.26708 .31976 L
.2671 .35413 L
.26712 .25961 L
.26715 .22953 L
.26717 .25531 L
Mistroke
.26719 .24242 L
.26721 .46154 L
.26724 .45724 L
.26726 .19516 L
.26728 .22953 L
.2673 .22094 L
.26733 .2725 L
.26735 .36702 L
.26737 .29398 L
.26739 .32405 L
.26741 .34554 L
.26744 .23813 L
.26746 .22953 L
.26748 .23383 L
.2675 .36702 L
.26753 .47443 L
.26755 .23813 L
.26757 .22524 L
.26759 .28109 L
.26762 .23383 L
.26764 .33265 L
.26766 .31117 L
.26768 .2682 L
.2677 .34554 L
.26773 .27679 L
.26775 .22524 L
.26777 .2682 L
.26779 .28968 L
.26782 .37991 L
.26784 .3842 L
.26786 .24242 L
.26788 .23813 L
.26791 .23813 L
.26793 .25961 L
.26795 .31976 L
.26797 .33265 L
.26799 .33694 L
.26802 .31117 L
.26804 .26391 L
.26806 .22953 L
.26808 .22524 L
.26811 .28109 L
.26813 .45295 L
.26815 .37991 L
.26817 .21664 L
.2682 .2725 L
.26822 .28539 L
.26824 .28109 L
.26826 .28968 L
.26829 .28539 L
Mistroke
.26831 .35843 L
.26833 .35843 L
.26835 .2725 L
.26837 .23813 L
.2684 .22524 L
.26842 .28109 L
.26844 .44435 L
.26846 .36272 L
.26849 .22524 L
.26851 .30257 L
.26853 .25531 L
.26855 .26391 L
.26858 .29398 L
.2686 .2682 L
.26862 .32835 L
.26864 .33265 L
.26866 .2725 L
.26869 .2725 L
.26871 .28109 L
.26873 .21664 L
.26875 .27679 L
.26878 .49161 L
.2688 .27679 L
.26882 .19946 L
.26884 .31976 L
.26887 .22524 L
.26889 .30687 L
.26891 .32835 L
.26893 .22953 L
.26896 .31117 L
.26898 .29828 L
.269 .23383 L
.26902 .28539 L
.26904 .28968 L
.26907 .40139 L
.26909 .37991 L
.26911 .17798 L
.26913 .24672 L
.26916 .28109 L
.26918 .27679 L
.2692 .33694 L
.26922 .28539 L
.26925 .29828 L
.26927 .31976 L
.26929 .25102 L
.26931 .25531 L
.26933 .2725 L
.26936 .31976 L
.26938 .44865 L
.2694 .32835 L
Mistroke
.26942 .21664 L
.26945 .2682 L
.26947 .25102 L
.26949 .29828 L
.26951 .35413 L
.26954 .34554 L
.26956 .34554 L
.26958 .31546 L
.2696 .25531 L
.26962 .23813 L
.26965 .23813 L
.26967 .29398 L
.26969 .45724 L
.26971 .36702 L
.26974 .23383 L
.26976 .29828 L
.26978 .28109 L
.2698 .25961 L
.26983 .26391 L
.26985 .28539 L
.26987 .35843 L
.26989 .33694 L
.26992 .25961 L
.26994 .2725 L
.26996 .24242 L
.26998 .26391 L
.27 .48302 L
.27003 .32405 L
.27005 .19516 L
.27007 .32405 L
.27009 .24672 L
.27012 .29398 L
.27014 .29828 L
.27016 .23813 L
.27018 .32835 L
.27021 .31546 L
.27023 .25961 L
.27025 .28968 L
.27027 .23813 L
.27029 .37561 L
.27032 .45295 L
.27034 .16938 L
.27036 .26391 L
.27038 .30257 L
.27041 .23383 L
.27043 .36272 L
.27045 .29398 L
.27047 .2682 L
.2705 .33694 L
.27052 .25102 L
Mistroke
.27054 .24242 L
.27056 .29398 L
.27058 .31117 L
.27061 .43146 L
.27063 .40139 L
.27065 .20376 L
.27067 .24242 L
.2707 .29398 L
.27072 .30687 L
.27074 .30257 L
.27076 .28539 L
.27079 .34554 L
.27081 .34124 L
.27083 .2682 L
.27085 .29828 L
.27088 .28109 L
.2709 .30257 L
.27092 .42717 L
.27094 .25102 L
.27096 .23383 L
.27099 .33265 L
.27101 .27679 L
.27103 .27679 L
.27105 .30687 L
.27108 .30687 L
.2711 .28968 L
.27112 .34983 L
.27114 .31976 L
.27117 .23383 L
.27119 .24672 L
.27121 .2682 L
.27123 .32405 L
.27125 .43146 L
.27128 .28539 L
.2713 .24242 L
.27132 .33265 L
.27134 .26391 L
.27137 .25531 L
.27139 .25531 L
.27141 .28539 L
.27143 .33265 L
.27146 .29398 L
.27148 .2682 L
.2715 .28539 L
.27152 .22094 L
.27155 .35843 L
.27157 .45724 L
.27159 .16079 L
.27161 .25531 L
.27163 .33694 L
Mistroke
.27166 .23383 L
.27168 .31546 L
.2717 .27679 L
.27172 .26391 L
.27175 .33265 L
.27177 .24672 L
.27179 .25961 L
.27181 .27679 L
.27184 .30687 L
.27186 .50021 L
.27188 .27679 L
.2719 .17798 L
.27192 .31976 L
.27195 .24672 L
.27197 .29828 L
.27199 .31546 L
.27201 .29398 L
.27204 .37131 L
.27206 .29398 L
.27208 .23383 L
.2721 .2682 L
.27213 .25531 L
.27215 .34124 L
.27217 .47443 L
.27219 .25102 L
.27221 .19946 L
.27224 .33265 L
.27226 .28539 L
.27228 .25531 L
.2723 .2682 L
.27233 .34554 L
.27235 .36702 L
.27237 .28968 L
.27239 .22524 L
.27242 .24672 L
.27244 .26391 L
.27246 .3885 L
.27248 .43576 L
.27251 .16079 L
.27253 .25531 L
.27255 .37991 L
.27257 .27679 L
.27259 .26391 L
.27262 .25102 L
.27264 .31546 L
.27266 .33265 L
.27268 .23383 L
.27271 .24672 L
.27273 .2725 L
.27275 .24242 L
Mistroke
.27277 .47872 L
.2728 .3885 L
.27282 .10494 L
.27284 .29828 L
.27286 .29398 L
.27288 .24672 L
.27291 .31117 L
.27293 .25961 L
.27295 .33694 L
.27297 .34124 L
.273 .20805 L
.27302 .2682 L
.27304 .25102 L
.27306 .24672 L
.27309 .52598 L
.27311 .31117 L
.27313 .1479 L
.27315 .36272 L
.27318 .2725 L
.2732 .2725 L
.27322 .28109 L
.27324 .2725 L
.27326 .37991 L
.27329 .29828 L
.27331 .22953 L
.27333 .31976 L
.27335 .31117 L
.27338 .34983 L
.2734 .34983 L
.27342 .40139 L
.27344 .20805 L
.27347 .26391 L
.27349 .32835 L
.27351 .25102 L
.27353 .29398 L
.27355 .28968 L
.27358 .31546 L
.2736 .34983 L
.27362 .28968 L
.27364 .25531 L
.27367 .25961 L
.27369 .28968 L
.27371 .42287 L
.27373 .30257 L
.27376 .20376 L
.27378 .32405 L
.2738 .30687 L
.27382 .2725 L
.27384 .2725 L
.27387 .28109 L
Mistroke
.27389 .34983 L
.27391 .31546 L
.27393 .24242 L
.27396 .25531 L
.27398 .24242 L
.274 .31117 L
.27402 .45724 L
.27405 .24242 L
.27407 .21664 L
.27409 .37991 L
.27411 .27679 L
.27414 .25961 L
.27416 .23813 L
.27418 .2682 L
.2742 .35413 L
.27422 .28109 L
.27425 .24242 L
.27427 .31546 L
.27429 .22953 L
.27431 .32835 L
.27434 .5045 L
.27436 .19946 L
.27438 .24242 L
.2744 .34554 L
.27443 .25102 L
.27445 .28539 L
.27447 .24672 L
.27449 .29828 L
.27451 .37561 L
.27454 .27679 L
.27456 .2682 L
.27458 .28968 L
.2746 .34983 L
.27463 .44006 L
.27465 .23383 L
.27467 .21664 L
.27469 .35843 L
.27472 .27679 L
.27474 .26391 L
.27476 .29828 L
.27478 .30257 L
.27481 .35843 L
.27483 .28109 L
.27485 .23813 L
.27487 .28968 L
.27489 .31117 L
.27492 .40569 L
.27494 .29828 L
.27496 .21664 L
.27498 .33694 L
Mistroke
.27501 .30257 L
.27503 .23383 L
.27505 .28109 L
.27507 .33265 L
.2751 .33694 L
.27512 .31117 L
.27514 .26391 L
.27516 .2725 L
.27518 .2682 L
.27521 .2682 L
.27523 .3885 L
.27525 .31546 L
.27527 .21235 L
.2753 .33265 L
.27532 .32835 L
.27534 .2682 L
.27536 .25961 L
.27539 .2682 L
.27541 .31546 L
.27543 .29398 L
.27545 .24672 L
.27547 .28968 L
.2755 .28539 L
.27552 .2725 L
.27554 .41857 L
.27556 .32835 L
.27559 .21235 L
.27561 .36272 L
.27563 .28968 L
.27565 .23383 L
.27568 .27679 L
.2757 .2682 L
.27572 .30257 L
.27574 .29828 L
.27577 .29828 L
.27579 .28109 L
.27581 .32405 L
.27583 .25102 L
.27585 .39709 L
.27588 .43576 L
.2759 .17368 L
.27592 .31546 L
.27594 .32405 L
.27597 .21235 L
.27599 .30257 L
.27601 .26391 L
.27603 .30687 L
.27606 .36272 L
.27608 .22524 L
.2761 .29398 L
Mistroke
.27612 .29398 L
.27614 .35843 L
.27617 .44435 L
.27619 .16938 L
.27621 .22953 L
.27623 .3885 L
.27626 .25961 L
.27628 .24672 L
.2763 .2725 L
.27632 .31546 L
.27635 .36272 L
.27637 .2682 L
.27639 .28109 L
.27641 .31117 L
.27644 .25531 L
.27646 .29828 L
.27648 .37131 L
.2765 .26391 L
.27652 .24242 L
.27655 .33265 L
.27657 .29398 L
.27659 .2682 L
.27661 .29398 L
.27664 .2725 L
.27666 .31546 L
.27668 .29828 L
.2767 .23813 L
.27673 .26391 L
.27675 .25961 L
.27677 .39709 L
.27679 .36702 L
.27681 .19946 L
.27684 .32835 L
.27686 .34983 L
.27688 .24672 L
.2769 .25531 L
.27693 .24672 L
.27695 .30257 L
.27697 .32405 L
.27699 .22953 L
.27702 .29398 L
.27704 .28539 L
.27706 .31976 L
.27708 .47872 L
.2771 .26391 L
.27713 .22953 L
.27715 .3885 L
.27717 .24242 L
.27719 .22953 L
.27722 .28109 L
Mistroke
.27724 .25531 L
.27726 .34554 L
.27728 .2682 L
.27731 .25102 L
.27733 .32835 L
.27735 .31546 L
.27737 .44435 L
.2774 .30687 L
.27742 .17798 L
.27744 .34554 L
.27746 .29828 L
.27748 .20805 L
.27751 .2725 L
.27753 .28539 L
.27755 .33265 L
.27757 .30687 L
.2776 .24242 L
.27762 .32835 L
.27764 .30687 L
.27766 .35843 L
.27769 .35413 L
.27771 .18657 L
.27773 .28109 L
.27775 .33265 L
.27777 .22953 L
.2778 .2682 L
.27782 .31546 L
.27784 .30687 L
.27786 .33694 L
.27789 .2682 L
.27791 .25961 L
.27793 .28109 L
.27795 .31117 L
.27798 .3885 L
.278 .23383 L
.27802 .22524 L
.27804 .3842 L
.27807 .28968 L
.27809 .25102 L
.27811 .29398 L
.27813 .29398 L
.27815 .28539 L
.27818 .33694 L
.2782 .2725 L
.27822 .22953 L
.27824 .30687 L
.27827 .25531 L
.27829 .30687 L
.27831 .45724 L
.27833 .2682 L
Mistroke
.27836 .24242 L
.27838 .41428 L
.2784 .29828 L
.27842 .24672 L
.27844 .2725 L
.27847 .24672 L
.27849 .32405 L
.27851 .25961 L
.27853 .22953 L
.27856 .31976 L
.27858 .26391 L
.2786 .37561 L
.27862 .45295 L
.27865 .22524 L
.27867 .28968 L
.27869 .39709 L
.27871 .24242 L
.27873 .22953 L
.27876 .25102 L
.27878 .28109 L
.2788 .32405 L
.27882 .22094 L
.27885 .2725 L
.27887 .34554 L
.27889 .31117 L
.27891 .40569 L
.27894 .32835 L
.27896 .22524 L
.27898 .35843 L
.279 .30687 L
.27903 .19516 L
.27905 .25531 L
.27907 .28109 L
.27909 .30687 L
.27911 .29828 L
.27914 .23813 L
.27916 .30257 L
.27918 .30687 L
.2792 .34554 L
.27923 .36702 L
.27925 .23813 L
.27927 .30687 L
.27929 .37131 L
.27932 .23383 L
.27934 .23813 L
.27936 .31117 L
.27938 .28539 L
.2794 .29828 L
.27943 .2725 L
.27945 .26391 L
Mistroke
.27947 .2682 L
.27949 .32835 L
.27952 .3842 L
.27954 .28968 L
.27956 .30257 L
.27958 .36272 L
.27961 .30257 L
.27963 .28539 L
.27965 .2725 L
.27967 .2682 L
.2797 .31117 L
.27972 .28539 L
.27974 .2682 L
.27976 .2682 L
.27978 .2725 L
.27981 .34554 L
.27983 .34983 L
.27985 .27679 L
.27987 .31976 L
.2799 .33265 L
.27992 .30687 L
.27994 .30257 L
.27996 .25961 L
.27999 .28109 L
.28001 .31976 L
.28003 .2725 L
.28005 .2682 L
.28007 .29398 L
.2801 .28539 L
.28012 .30687 L
.28014 .31976 L
.28016 .27679 L
.28019 .29828 L
.28021 .32405 L
.28023 .30257 L
.28025 .28968 L
.28028 .27679 L
.2803 .28968 L
.28032 .31117 L
.28034 .27679 L
.28036 .27679 L
.28039 .29828 L
.28041 .27679 L
.28043 .28968 L
.28045 .31546 L
.28048 .28539 L
.2805 .28539 L
.28052 .29398 L
.28054 .31546 L
.28057 .29398 L
Mistroke
.28059 .28109 L
.28061 .29398 L
.28063 .30257 L
.28066 .28968 L
.28068 .28968 L
.2807 .30257 L
.28072 .28968 L
.28074 .28539 L
.28077 .29828 L
.28079 .31117 L
.28081 .32405 L
.28083 .29828 L
.28086 .28968 L
.28088 .31117 L
.2809 .30687 L
.28092 .29398 L
.28095 .28539 L
.28097 .28968 L
.28099 .31117 L
.28101 .29398 L
.28103 .28539 L
.28106 .29828 L
.28108 .29398 L
.2811 .29828 L
.28112 .32405 L
.28115 .29828 L
.28117 .2725 L
.28119 .30687 L
.28121 .31117 L
.28124 .28539 L
.28126 .28109 L
.28128 .28968 L
.2813 .29828 L
.28133 .29828 L
.28135 .28109 L
.28137 .29398 L
.28139 .29828 L
.28141 .28539 L
.28144 .31546 L
.28146 .31117 L
.28148 .25531 L
.2815 .29828 L
.28153 .31117 L
.28155 .28539 L
.28157 .28539 L
.28159 .28539 L
.28162 .28539 L
.28164 .29828 L
.28166 .27679 L
.28168 .29828 L
Mistroke
.2817 .30257 L
.28173 .29398 L
.28175 .29398 L
.28177 .31117 L
.28179 .27679 L
.28182 .27679 L
.28184 .30687 L
.28186 .30687 L
.28188 .28109 L
.28191 .28109 L
.28193 .28968 L
.28195 .29828 L
.28197 .29828 L
.28199 .29828 L
.28202 .30687 L
.28204 .30257 L
.28206 .29828 L
.28208 .30687 L
.28211 .30257 L
.28213 .28539 L
.28215 .31117 L
.28217 .30257 L
.2822 .28539 L
.28222 .28968 L
.28224 .30257 L
.28226 .29828 L
.28229 .30687 L
.28231 .30257 L
.28233 .29828 L
.28235 .28968 L
.28237 .28109 L
.2824 .30257 L
.28242 .32835 L
.28244 .27679 L
.28246 .28109 L
.28249 .30687 L
.28251 .30257 L
.28253 .28109 L
.28255 .28968 L
.28258 .29398 L
.2826 .30257 L
.28262 .28968 L
.28264 .28539 L
.28266 .28968 L
.28269 .2725 L
.28271 .28539 L
.28273 .33694 L
.28275 .28109 L
.28278 .25961 L
.2828 .31546 L
Mistroke
.28282 .31117 L
.28284 .28968 L
.28287 .28968 L
.28289 .28539 L
.28291 .27679 L
.28293 .28968 L
.28296 .29398 L
.28298 .28109 L
.283 .29828 L
.28302 .27679 L
.28304 .28109 L
.28307 .32835 L
.28309 .28109 L
.28311 .2682 L
.28313 .32835 L
.28316 .31546 L
.28318 .28968 L
.2832 .28539 L
.28322 .28539 L
.28325 .29398 L
.28327 .30257 L
.28329 .29398 L
.28331 .30257 L
.28333 .28968 L
.28336 .28539 L
.28338 .31976 L
.2834 .31117 L
.28342 .28968 L
.28345 .31546 L
.28347 .31117 L
.28349 .30257 L
.28351 .28968 L
.28354 .28539 L
.28356 .29828 L
.28358 .30687 L
.2836 .28539 L
.28362 .29398 L
.28365 .28109 L
.28367 .28539 L
.28369 .31976 L
.28371 .30687 L
.28374 .28539 L
.28376 .30257 L
.28378 .30257 L
.2838 .29398 L
.28383 .28968 L
.28385 .28968 L
.28387 .30257 L
.28389 .29398 L
.28392 .28109 L
Mistroke
.28394 .28968 L
.28396 .28539 L
.28398 .28539 L
.284 .28968 L
.28403 .31976 L
.28405 .29398 L
.28407 .2725 L
.28409 .29828 L
.28412 .30257 L
.28414 .29828 L
.28416 .28109 L
.28418 .28109 L
.28421 .28968 L
.28423 .29828 L
.28425 .28968 L
.28427 .29828 L
.28429 .28539 L
.28432 .28109 L
.28434 .30687 L
.28436 .31976 L
.28438 .26391 L
.28441 .28968 L
.28443 .30687 L
.28445 .29828 L
.28447 .29398 L
.2845 .28968 L
.28452 .28968 L
.28454 .30257 L
.28456 .29828 L
.28459 .30257 L
.28461 .29398 L
.28463 .28968 L
.28465 .29828 L
.28467 .32835 L
.2847 .29828 L
.28472 .28109 L
.28474 .31546 L
.28476 .30257 L
.28479 .30687 L
.28481 .30257 L
.28483 .28968 L
.28485 .29398 L
.28488 .29828 L
.2849 .29398 L
.28492 .30257 L
.28494 .29398 L
.28496 .29828 L
.28499 .29828 L
.28501 .31117 L
.28503 .28968 L
Mistroke
.28505 .28968 L
.28508 .30687 L
.2851 .29828 L
.28512 .29828 L
.28514 .28539 L
.28517 .28109 L
.28519 .28539 L
.28521 .29828 L
.28523 .29828 L
.28525 .29828 L
.28528 .29828 L
.2853 .28968 L
.28532 .28539 L
.28534 .28968 L
.28537 .30687 L
.28539 .29828 L
.28541 .28968 L
.28543 .28968 L
.28546 .29398 L
.28548 .29398 L
.2855 .28968 L
.28552 .28968 L
.28555 .29398 L
.28557 .29398 L
.28559 .29398 L
.28561 .29398 L
.28563 .28968 L
.28566 .29398 L
.28568 .29828 L
.2857 .30687 L
.28572 .30257 L
.28575 .28109 L
.28577 .29398 L
.28579 .30687 L
.28581 .31117 L
.28584 .29398 L
.28586 .29398 L
.28588 .29828 L
.2859 .30687 L
.28592 .30257 L
.28595 .30257 L
.28597 .30257 L
.28599 .29828 L
.28601 .29398 L
.28604 .30257 L
.28606 .32405 L
.28608 .28968 L
.2861 .28968 L
.28613 .30687 L
.28615 .30257 L
Mistroke
.28617 .28968 L
.28619 .29398 L
.28622 .29828 L
.28624 .29828 L
.28626 .28968 L
.28628 .29398 L
.2863 .29398 L
.28633 .28968 L
.28635 .29398 L
.28637 .30257 L
.28639 .30687 L
.28642 .2725 L
.28644 .29828 L
.28646 .29828 L
.28648 .29828 L
.28651 .29398 L
.28653 .29398 L
.28655 .28539 L
.28657 .28968 L
.28659 .28968 L
.28662 .29828 L
.28664 .29398 L
.28666 .28968 L
.28668 .28968 L
.28671 .29828 L
.28673 .31117 L
.28675 .27679 L
.28677 .29398 L
.2868 .30687 L
.28682 .29828 L
.28684 .29398 L
.28686 .28968 L
.28688 .28539 L
.28691 .29828 L
.28693 .29398 L
.28695 .29828 L
.28697 .30257 L
.287 .28968 L
.28702 .29398 L
.28704 .29828 L
.28706 .31546 L
.28709 .28968 L
.28711 .29398 L
.28713 .31117 L
.28715 .30257 L
.28718 .30257 L
.2872 .29398 L
.28722 .29398 L
.28724 .29828 L
.28726 .30687 L
Mistroke
.28729 .30257 L
.28731 .29828 L
.28733 .28968 L
.28735 .29828 L
.28738 .29828 L
.2874 .30257 L
.28742 .31117 L
.28744 .28968 L
.28747 .28968 L
.28749 .29398 L
.28751 .30257 L
.28753 .29398 L
.28755 .29398 L
.28758 .28968 L
.2876 .28968 L
.28762 .28968 L
.28764 .28968 L
.28767 .29398 L
.28769 .29398 L
.28771 .28968 L
.28773 .29828 L
.28776 .29398 L
.28778 .29828 L
.2878 .29398 L
.28782 .28968 L
.28784 .29398 L
.28787 .28968 L
.28789 .29398 L
.28791 .28968 L
.28793 .28539 L
.28796 .28968 L
.28798 .29398 L
.288 .29398 L
.28802 .28968 L
.28805 .29398 L
.28807 .29828 L
.28809 .29398 L
.28811 .28539 L
.28814 .30257 L
.28816 .29398 L
.28818 .28109 L
.2882 .29398 L
.28822 .29828 L
.28825 .30257 L
.28827 .29398 L
.28829 .28539 L
.28831 .29398 L
.28834 .30257 L
.28836 .29828 L
.28838 .30257 L
Mistroke
.2884 .29828 L
.28843 .29828 L
.28845 .29398 L
.28847 .29828 L
.28849 .31117 L
.28851 .28968 L
.28854 .30257 L
.28856 .30257 L
.28858 .30257 L
.2886 .29828 L
.28863 .28968 L
.28865 .29398 L
.28867 .30257 L
.28869 .28968 L
.28872 .29398 L
.28874 .29828 L
.28876 .29398 L
.28878 .29828 L
.28881 .28968 L
.28883 .29828 L
.28885 .30257 L
.28887 .28109 L
.28889 .28968 L
.28892 .29398 L
.28894 .29828 L
.28896 .29828 L
.28898 .28109 L
.28901 .28539 L
.28903 .29398 L
.28905 .28968 L
.28907 .29398 L
.2891 .29398 L
.28912 .29398 L
.28914 .29398 L
.28916 .28539 L
.28918 .28968 L
.28921 .30257 L
.28923 .28968 L
.28925 .28539 L
.28927 .29398 L
.2893 .29828 L
.28932 .29828 L
.28934 .28109 L
.28936 .28539 L
.28939 .29828 L
.28941 .28968 L
.28943 .28968 L
.28945 .29398 L
.28947 .28968 L
.2895 .29828 L
Mistroke
.28952 .28968 L
.28954 .29398 L
.28956 .30687 L
.28959 .30257 L
.28961 .29398 L
.28963 .29398 L
.28965 .30257 L
.28968 .31117 L
.2897 .29398 L
.28972 .28968 L
.28974 .30687 L
.28977 .29828 L
.28979 .29828 L
.28981 .30257 L
.28983 .30257 L
.28985 .30257 L
.28988 .29398 L
.2899 .29398 L
.28992 .29828 L
.28994 .29828 L
.28997 .31117 L
.28999 .29398 L
.29001 .28968 L
.29003 .29398 L
.29006 .30687 L
.29008 .30687 L
.2901 .28109 L
.29012 .29398 L
.29014 .30257 L
.29017 .28539 L
.29019 .28968 L
.29021 .29828 L
.29023 .29398 L
.29026 .29828 L
.29028 .28968 L
.2903 .28968 L
.29032 .29828 L
.29035 .29828 L
.29037 .29398 L
.29039 .29828 L
.29041 .29828 L
.29044 .31117 L
.29046 .28109 L
.29048 .27679 L
.2905 .29828 L
.29052 .29398 L
.29055 .28968 L
.29057 .28968 L
.29059 .28968 L
.29061 .29398 L
Mistroke
.29064 .28968 L
.29066 .28968 L
.29068 .28968 L
.2907 .30257 L
.29073 .30257 L
.29075 .28539 L
.29077 .29398 L
.29079 .31546 L
.29081 .31546 L
.29084 .28539 L
.29086 .28968 L
.29088 .30257 L
.2909 .29398 L
.29093 .29398 L
.29095 .29398 L
.29097 .30257 L
.29099 .29828 L
.29102 .29398 L
.29104 .29398 L
.29106 .29398 L
.29108 .32405 L
.2911 .29398 L
.29113 .29398 L
.29115 .31117 L
.29117 .32405 L
.29119 .31117 L
.29122 .28109 L
.29124 .30257 L
.29126 .30257 L
.29128 .29398 L
.29131 .29398 L
.29133 .28968 L
.29135 .29398 L
.29137 .29828 L
.2914 .28968 L
.29142 .28109 L
.29144 .28968 L
.29146 .31976 L
.29148 .28968 L
.29151 .28109 L
.29153 .30687 L
.29155 .31976 L
.29157 .30687 L
.2916 .28539 L
.29162 .28968 L
.29164 .28968 L
.29166 .28109 L
.29169 .28968 L
.29171 .28539 L
.29173 .28968 L
Mistroke
.29175 .29828 L
.29177 .27679 L
.2918 .27679 L
.29182 .28968 L
.29184 .31546 L
.29186 .29398 L
.29189 .28539 L
.29191 .31117 L
.29193 .31546 L
.29195 .31546 L
.29198 .28968 L
.292 .30257 L
.29202 .28968 L
.29204 .28109 L
.29207 .28539 L
.29209 .28109 L
.29211 .29828 L
.29213 .29828 L
.29215 .28109 L
.29218 .28539 L
.2922 .28539 L
.29222 .31117 L
.29224 .30687 L
.29227 .29828 L
.29229 .31117 L
.29231 .31117 L
.29233 .31546 L
.29236 .32405 L
.29238 .29828 L
.2924 .30687 L
.29242 .30687 L
.29244 .29398 L
.29247 .28539 L
.29249 .2725 L
.29251 .28968 L
.29253 .29398 L
.29256 .29398 L
.29258 .28968 L
.2926 .28109 L
.29262 .28968 L
.29265 .30687 L
.29267 .30687 L
.29269 .30257 L
.29271 .31117 L
.29273 .32405 L
.29276 .31976 L
.29278 .28968 L
.2928 .29398 L
.29282 .28968 L
.29285 .28968 L
Mistroke
.29287 .28109 L
.29289 .2682 L
.29291 .27679 L
.29294 .28539 L
.29296 .28539 L
.29298 .27679 L
.293 .28109 L
.29303 .28109 L
.29305 .29828 L
.29307 .31546 L
.29309 .29398 L
.29311 .30257 L
.29314 .32835 L
.29316 .33265 L
.29318 .29828 L
.2932 .28539 L
.29323 .29828 L
.29325 .28539 L
.29327 .28109 L
.29329 .2725 L
.29332 .27679 L
.29334 .28109 L
.29336 .28968 L
.29338 .27679 L
.2934 .2725 L
.29343 .29398 L
.29345 .30257 L
.29347 .31117 L
.29349 .30257 L
.29352 .30257 L
.29354 .31976 L
.29356 .33265 L
.29358 .31976 L
.29361 .29828 L
.29363 .30257 L
.29365 .29398 L
.29367 .28539 L
.2937 .2682 L
.29372 .27679 L
.29374 .28539 L
.29376 .28539 L
.29378 .28539 L
.29381 .28109 L
.29383 .28539 L
.29385 .29398 L
.29387 .29398 L
.2939 .31546 L
.29392 .31976 L
.29394 .30257 L
.29396 .31546 L
Mistroke
.29399 .33265 L
.29401 .31976 L
.29403 .29398 L
.29405 .29398 L
.29407 .29398 L
.2941 .28539 L
.29412 .26391 L
.29414 .26391 L
.29416 .2725 L
.29419 .27679 L
.29421 .28539 L
.29423 .28109 L
.29425 .28109 L
.29428 .28968 L
.2943 .28539 L
.29432 .29398 L
.29434 .31976 L
.29436 .30687 L
.29439 .30687 L
.29441 .31546 L
.29443 .31976 L
.29445 .30687 L
.29448 .29828 L
.2945 .30257 L
.29452 .29398 L
.29454 .27679 L
.29457 .2682 L
.29459 .27679 L
.29461 .2725 L
.29463 .28539 L
.29466 .28968 L
.29468 .28968 L
.2947 .28539 L
.29472 .28968 L
.29474 .28968 L
.29477 .28539 L
.29479 .29828 L
.29481 .31976 L
.29483 .31976 L
.29486 .30257 L
.29488 .31546 L
.2949 .32405 L
.29492 .31976 L
.29495 .30687 L
.29497 .30687 L
.29499 .29398 L
.29501 .28539 L
.29503 .27679 L
.29506 .2682 L
.29508 .28109 L
Mistroke
.2951 .28968 L
.29512 .29398 L
.29515 .28539 L
.29517 .28968 L
.29519 .29398 L
.29521 .29398 L
.29524 .29828 L
.29526 .30687 L
.29528 .31117 L
.2953 .30687 L
.29533 .30687 L
.29535 .31117 L
.29537 .31546 L
.29539 .30687 L
.29541 .29828 L
.29544 .29828 L
.29546 .28968 L
.29548 .28539 L
.2955 .27679 L
.29553 .27679 L
.29555 .28539 L
.29557 .28109 L
.29559 .28539 L
.29562 .28968 L
.29564 .28968 L
.29566 .29398 L
.29568 .29398 L
.2957 .29398 L
.29573 .29398 L
.29575 .30257 L
.29577 .30687 L
.29579 .30687 L
.29582 .30257 L
.29584 .30687 L
.29586 .31546 L
.29588 .30687 L
.29591 .29828 L
.29593 .30257 L
.29595 .29828 L
.29597 .29398 L
.29599 .28539 L
.29602 .28539 L
.29604 .29398 L
.29606 .28968 L
.29608 .28968 L
.29611 .28968 L
.29613 .29398 L
.29615 .29828 L
.29617 .29398 L
.2962 .29828 L
Mistroke
.29622 .30257 L
.29624 .29828 L
.29626 .29828 L
.29629 .30257 L
.29631 .31117 L
.29633 .31117 L
.29635 .30687 L
.29637 .31546 L
.2964 .31117 L
.29642 .30257 L
.29644 .30257 L
.29646 .30687 L
.29649 .29828 L
.29651 .28968 L
.29653 .28968 L
.29655 .28968 L
.29658 .28539 L
.2966 .29398 L
.29662 .29828 L
.29664 .28968 L
.29666 .28968 L
.29669 .29398 L
.29671 .29398 L
.29673 .29398 L
.29675 .29398 L
.29678 .29828 L
.2968 .29398 L
.29682 .29398 L
.29684 .29828 L
.29687 .29828 L
.29689 .29828 L
.29691 .29828 L
.29693 .30257 L
.29696 .29828 L
.29698 .29828 L
.297 .30257 L
.29702 .30687 L
.29704 .30687 L
.29707 .29828 L
.29709 .28968 L
.29711 .28968 L
.29713 .28539 L
.29716 .29398 L
.29718 .28968 L
.2972 .28968 L
.29722 .29398 L
.29725 .28968 L
.29727 .28539 L
.29729 .28968 L
.29731 .28968 L
Mistroke
.29733 .28968 L
.29736 .28968 L
.29738 .29398 L
.2974 .29398 L
.29742 .29828 L
.29745 .30257 L
.29747 .30257 L
.29749 .30257 L
.29751 .30257 L
.29754 .30687 L
.29756 .29828 L
.29758 .29828 L
.2976 .30257 L
.29762 .29828 L
.29765 .29398 L
.29767 .29398 L
.29769 .29398 L
.29771 .28539 L
.29774 .28968 L
.29776 .28968 L
.29778 .28539 L
.2978 .28968 L
.29783 .28968 L
.29785 .28968 L
.29787 .28968 L
.29789 .29398 L
.29792 .29398 L
.29794 .29398 L
.29796 .29398 L
.29798 .29398 L
.298 .28968 L
.29803 .29398 L
.29805 .29398 L
.29807 .29398 L
.29809 .29398 L
.29812 .29398 L
.29814 .29398 L
.29816 .28968 L
.29818 .29398 L
.29821 .29398 L
.29823 .29398 L
.29825 .29398 L
.29827 .29398 L
.29829 .28968 L
.29832 .28968 L
.29834 .29828 L
.29836 .29828 L
.29838 .29398 L
.29841 .28968 L
.29843 .29398 L
Mistroke
.29845 .29398 L
.29847 .29398 L
.2985 .28968 L
.29852 .29398 L
.29854 .29398 L
.29856 .28968 L
.29859 .29398 L
.29861 .29398 L
.29863 .29398 L
.29865 .29398 L
.29867 .29398 L
.2987 .29398 L
.29872 .29398 L
.29874 .29828 L
.29876 .30257 L
.29879 .30257 L
.29881 .29828 L
.29883 .29828 L
.29885 .30257 L
.29888 .29828 L
.2989 .30257 L
.29892 .30257 L
.29894 .29828 L
.29896 .29398 L
.29899 .29398 L
.29901 .29398 L
.29903 .29398 L
.29905 .29828 L
.29908 .29398 L
.2991 .28968 L
.29912 .28968 L
.29914 .28968 L
.29917 .29828 L
.29919 .30687 L
.29921 .29828 L
.29923 .29398 L
.29925 .29398 L
.29928 .28968 L
.2993 .29398 L
.29932 .29828 L
.29934 .29828 L
.29937 .30257 L
.29939 .29828 L
.29941 .29828 L
.29943 .29398 L
.29946 .29398 L
.29948 .29398 L
.2995 .29828 L
.29952 .29828 L
.29955 .29828 L
Mistroke
.29957 .30257 L
.29959 .29828 L
.29961 .29398 L
.29963 .28968 L
.29966 .29398 L
.29968 .29828 L
.2997 .29828 L
.29972 .29828 L
.29975 .29828 L
.29977 .29828 L
.29979 .29398 L
.29981 .28968 L
.29984 .29828 L
.29986 .30257 L
.29988 .30257 L
.2999 .29828 L
.29992 .29398 L
.29995 .28968 L
.29997 .28968 L
.29999 .29398 L
.30001 .29828 L
.30004 .29828 L
.30006 .29828 L
.30008 .29828 L
.3001 .29398 L
.30013 .28968 L
.30015 .29398 L
.30017 .29828 L
.30019 .29828 L
.30022 .29828 L
.30024 .29828 L
.30026 .29398 L
.30028 .29398 L
.3003 .29398 L
.30033 .29398 L
.30035 .29398 L
.30037 .29828 L
.30039 .30257 L
.30042 .29828 L
.30044 .29828 L
.30046 .28968 L
.30048 .28968 L
.30051 .28968 L
.30053 .29398 L
.30055 .29828 L
.30057 .29398 L
.30059 .29828 L
.30062 .29398 L
.30064 .28968 L
.30066 .28968 L
Mistroke
.30068 .29398 L
.30071 .29828 L
.30073 .29828 L
.30075 .29828 L
.30077 .29398 L
.3008 .28968 L
.30082 .28968 L
.30084 .29398 L
.30086 .29828 L
.30088 .29828 L
.30091 .29828 L
.30093 .29398 L
.30095 .28968 L
.30097 .28968 L
.301 .29398 L
.30102 .29828 L
.30104 .30257 L
.30106 .30257 L
.30109 .29398 L
.30111 .29398 L
.30113 .29398 L
.30115 .29828 L
.30118 .29828 L
.3012 .29828 L
.30122 .29828 L
.30124 .29398 L
.30126 .29398 L
.30129 .29398 L
.30131 .29398 L
.30133 .29398 L
.30135 .29828 L
.30138 .29828 L
.3014 .29828 L
.30142 .29828 L
.30144 .29828 L
.30147 .29398 L
.30149 .29398 L
.30151 .29828 L
.30153 .29828 L
.30155 .30257 L
.30158 .30257 L
.3016 .29828 L
.30162 .29398 L
.30164 .28968 L
.30167 .28968 L
.30169 .29828 L
.30171 .29828 L
.30173 .29828 L
.30176 .29398 L
.30178 .29398 L
Mistroke
.3018 .28968 L
.30182 .28968 L
.30185 .28968 L
.30187 .29398 L
.30189 .29828 L
.30191 .29398 L
.30193 .28968 L
.30196 .28968 L
.30198 .28968 L
.302 .29398 L
.30202 .29828 L
.30205 .29828 L
.30207 .29828 L
.30209 .29398 L
.30211 .28968 L
.30214 .29398 L
.30216 .29398 L
.30218 .29828 L
.3022 .29828 L
.30222 .29828 L
.30225 .29398 L
.30227 .29398 L
.30229 .29398 L
.30231 .29828 L
.30234 .29828 L
.30236 .29828 L
.30238 .29828 L
.3024 .29398 L
.30243 .29398 L
.30245 .29398 L
.30247 .29398 L
.30249 .29828 L
.30251 .29828 L
.30254 .29828 L
.30256 .29828 L
.30258 .29828 L
.3026 .29398 L
.30263 .29398 L
.30265 .29398 L
.30267 .29828 L
.30269 .29828 L
.30272 .30257 L
.30274 .29828 L
.30276 .29398 L
.30278 .29398 L
.30281 .28968 L
.30283 .29398 L
.30285 .29828 L
.30287 .30257 L
.30289 .29828 L
Mistroke
.30292 .29398 L
.30294 .28968 L
.30296 .28968 L
.30298 .29398 L
.30301 .29828 L
.30303 .29828 L
.30305 .29828 L
.30307 .29398 L
.3031 .28968 L
.30312 .28968 L
.30314 .29398 L
.30316 .29398 L
.30318 .29828 L
.30321 .29398 L
.30323 .29398 L
.30325 .28968 L
.30327 .28968 L
.3033 .29398 L
.30332 .29828 L
.30334 .29828 L
.30336 .29828 L
.30339 .29398 L
.30341 .29398 L
.30343 .29398 L
.30345 .29398 L
.30347 .29828 L
.3035 .29828 L
.30352 .29828 L
.30354 .29828 L
.30356 .29398 L
.30359 .29398 L
.30361 .29398 L
.30363 .29828 L
.30365 .29828 L
.30368 .29828 L
.3037 .29828 L
.30372 .29398 L
.30374 .28968 L
.30377 .29398 L
.30379 .29398 L
.30381 .30257 L
.30383 .30257 L
.30385 .29828 L
.30388 .29398 L
.3039 .28968 L
.30392 .29398 L
.30394 .29828 L
.30397 .30687 L
.30399 .30687 L
.30401 .30257 L
Mistroke
.30403 .29398 L
.30406 .28968 L
.30408 .29398 L
.3041 .29828 L
.30412 .30257 L
.30414 .30257 L
.30417 .30257 L
.30419 .29828 L
.30421 .28968 L
.30423 .28968 L
.30426 .28968 L
.30428 .29828 L
.3043 .29828 L
.30432 .29398 L
.30435 .29398 L
.30437 .29398 L
.30439 .29398 L
.30441 .29398 L
.30444 .29398 L
.30446 .29398 L
.30448 .29398 L
.3045 .29828 L
.30452 .29398 L
.30455 .29398 L
.30457 .28968 L
.30459 .28968 L
.30461 .29398 L
.30464 .29828 L
.30466 .30257 L
.30468 .29828 L
.3047 .28968 L
.30473 .28968 L
.30475 .29398 L
.30477 .29828 L
.30479 .30257 L
.30481 .30257 L
.30484 .29828 L
.30486 .28968 L
.30488 .28968 L
.3049 .29398 L
.30493 .30257 L
.30495 .30257 L
.30497 .30257 L
.30499 .29398 L
.30502 .28968 L
.30504 .28539 L
.30506 .29398 L
.30508 .30257 L
.3051 .30257 L
.30513 .30257 L
Mistroke
.30515 .29828 L
.30517 .28968 L
.30519 .28968 L
.30522 .29398 L
.30524 .30257 L
.30526 .30687 L
.30528 .30687 L
.30531 .29828 L
.30533 .29398 L
.30535 .29398 L
.30537 .29398 L
.3054 .29828 L
.30542 .30257 L
.30544 .30257 L
.30546 .29398 L
.30548 .29398 L
.30551 .28968 L
.30553 .28968 L
.30555 .29398 L
.30557 .29828 L
.3056 .29828 L
.30562 .29828 L
.30564 .28968 L
.30566 .28539 L
.30569 .28539 L
.30571 .29398 L
.30573 .29828 L
.30575 .30257 L
.30577 .29828 L
.3058 .28968 L
.30582 .28539 L
.30584 .28968 L
.30586 .29398 L
.30589 .29828 L
.30591 .29828 L
.30593 .29398 L
.30595 .28968 L
.30598 .28539 L
.306 .28968 L
.30602 .29828 L
.30604 .30257 L
.30607 .29828 L
.30609 .29398 L
.30611 .28968 L
.30613 .28539 L
.30615 .28968 L
.30618 .29828 L
.3062 .30257 L
.30622 .29828 L
.30624 .29398 L
Mistroke
.30627 .28968 L
.30629 .28968 L
.30631 .29398 L
.30633 .29828 L
.30636 .30257 L
.30638 .30257 L
.3064 .29828 L
.30642 .28968 L
.30644 .28968 L
.30647 .29398 L
.30649 .30257 L
.30651 .30257 L
.30653 .30687 L
.30656 .30687 L
.30658 .29828 L
.3066 .29398 L
.30662 .28968 L
.30665 .29398 L
.30667 .30257 L
.30669 .30687 L
.30671 .30257 L
.30673 .29398 L
.30676 .28539 L
.30678 .28539 L
.3068 .28968 L
.30682 .29828 L
.30685 .30257 L
.30687 .29398 L
.30689 .28968 L
.30691 .28109 L
.30694 .28539 L
.30696 .29398 L
.30698 .30257 L
.307 .29828 L
.30703 .28968 L
.30705 .28539 L
.30707 .28539 L
.30709 .28968 L
.30711 .29828 L
.30714 .30257 L
.30716 .29828 L
.30718 .28968 L
.3072 .28539 L
.30723 .28539 L
.30725 .29398 L
.30727 .30257 L
.30729 .29828 L
.30732 .29398 L
.30734 .28968 L
.30736 .28539 L
Mistroke
.30738 .28968 L
.3074 .29828 L
.30743 .30257 L
.30745 .29828 L
.30747 .29398 L
.30749 .28968 L
.30752 .28968 L
.30754 .29398 L
.30756 .29828 L
.30758 .30257 L
.30761 .30257 L
.30763 .29828 L
.30765 .29398 L
.30767 .29398 L
.3077 .29398 L
.30772 .29828 L
.30774 .30257 L
.30776 .30687 L
.30778 .30257 L
.30781 .29828 L
.30783 .29398 L
.30785 .29398 L
.30787 .29828 L
.3079 .30687 L
.30792 .30687 L
.30794 .30257 L
.30796 .29398 L
.30799 .28968 L
.30801 .29398 L
.30803 .29828 L
.30805 .30687 L
.30807 .30257 L
.3081 .29398 L
.30812 .28539 L
.30814 .28539 L
.30816 .29398 L
.30819 .29828 L
.30821 .30257 L
.30823 .29398 L
.30825 .28968 L
.30828 .28539 L
.3083 .28968 L
.30832 .29398 L
.30834 .29828 L
.30836 .29398 L
.30839 .28968 L
.30841 .28539 L
.30843 .28539 L
.30845 .29398 L
.30848 .29828 L
Mistroke
.3085 .29828 L
.30852 .29398 L
.30854 .28539 L
.30857 .28539 L
.30859 .28968 L
.30861 .29828 L
.30863 .30257 L
.30866 .29398 L
.30868 .28968 L
.3087 .28968 L
.30872 .28968 L
.30874 .29828 L
.30877 .30257 L
.30879 .30257 L
.30881 .29398 L
.30883 .28968 L
.30886 .28968 L
.30888 .28968 L
.3089 .29398 L
.30892 .30257 L
.30895 .30257 L
.30897 .30257 L
.30899 .29828 L
.30901 .29828 L
.30903 .29398 L
.30906 .29828 L
.30908 .30257 L
.3091 .30687 L
.30912 .30687 L
.30915 .30257 L
.30917 .29828 L
.30919 .29398 L
.30921 .29828 L
.30924 .30257 L
.30926 .30687 L
.30928 .30257 L
.3093 .29828 L
.30933 .28968 L
.30935 .28968 L
.30937 .29398 L
.30939 .29828 L
.30941 .30257 L
.30944 .29828 L
.30946 .28968 L
.30948 .28539 L
.3095 .28539 L
.30953 .29398 L
.30955 .30257 L
.30957 .29828 L
.30959 .29398 L
Mistroke
.30962 .28539 L
.30964 .28109 L
.30966 .28968 L
.30968 .29828 L
.3097 .30257 L
.30973 .29828 L
.30975 .28968 L
.30977 .28109 L
.30979 .28539 L
.30982 .29398 L
.30984 .30257 L
.30986 .30257 L
.30988 .29398 L
.30991 .28968 L
.30993 .28539 L
.30995 .28968 L
.30997 .29828 L
.30999 .30257 L
.31002 .29828 L
.31004 .29398 L
.31006 .28968 L
.31008 .28968 L
.31011 .29398 L
.31013 .29828 L
.31015 .30257 L
.31017 .29828 L
.3102 .29828 L
.31022 .29398 L
.31024 .29828 L
.31026 .29828 L
.31029 .29828 L
.31031 .30257 L
.31033 .30257 L
.31035 .30257 L
.31037 .29828 L
.3104 .29828 L
.31042 .29828 L
.31044 .29828 L
.31046 .30257 L
.31049 .30257 L
.31051 .29828 L
.31053 .29828 L
.31055 .29398 L
.31058 .29398 L
.3106 .29398 L
.31062 .29398 L
.31064 .29828 L
.31066 .29398 L
.31069 .29398 L
.31071 .28968 L
Mistroke
.31073 .28968 L
.31075 .29398 L
.31078 .29398 L
.3108 .29398 L
.31082 .29398 L
.31084 .28968 L
.31087 .28968 L
.31089 .28968 L
.31091 .29398 L
.31093 .29398 L
.31096 .29828 L
.31098 .29398 L
.311 .28968 L
.31102 .28968 L
.31104 .28968 L
.31107 .29398 L
.31109 .29828 L
.31111 .29828 L
.31113 .29398 L
.31116 .28968 L
.31118 .28968 L
.3112 .29398 L
.31122 .29398 L
.31125 .29828 L
.31127 .30257 L
.31129 .29828 L
.31131 .29398 L
.31133 .28968 L
.31136 .28968 L
.31138 .29828 L
.3114 .29828 L
.31142 .30257 L
.31145 .29828 L
.31147 .29828 L
.31149 .29398 L
.31151 .29828 L
.31154 .29828 L
.31156 .30257 L
.31158 .30687 L
.3116 .30687 L
.31162 .30257 L
.31165 .29828 L
.31167 .29828 L
.31169 .29828 L
.31171 .30257 L
.31174 .30257 L
.31176 .30257 L
.31178 .29828 L
.3118 .29398 L
.31183 .29398 L
Mistroke
.31185 .29398 L
.31187 .29398 L
.31189 .29828 L
.31192 .30257 L
.31194 .29828 L
.31196 .28968 L
.31198 .28968 L
.312 .28968 L
.31203 .29398 L
.31205 .29828 L
.31207 .30257 L
.31209 .29828 L
.31212 .28968 L
.31214 .28539 L
.31216 .28968 L
.31218 .28968 L
.31221 .29828 L
.31223 .29828 L
.31225 .29828 L
.31227 .29398 L
.31229 .28968 L
.31232 .28968 L
.31234 .28968 L
.31236 .29398 L
.31238 .30257 L
.31241 .29828 L
.31243 .29398 L
.31245 .28968 L
.31247 .28968 L
.3125 .29398 L
.31252 .29828 L
.31254 .30257 L
.31256 .30257 L
.31259 .29398 L
.31261 .28968 L
.31263 .28968 L
.31265 .29398 L
.31267 .29828 L
.3127 .30257 L
.31272 .30257 L
.31274 .30257 L
.31276 .29398 L
.31279 .28968 L
.31281 .29398 L
.31283 .29828 L
.31285 .30687 L
.31288 .30687 L
.3129 .30257 L
.31292 .29828 L
.31294 .29398 L
Mistroke
.31296 .29398 L
.31299 .29828 L
.31301 .30257 L
.31303 .30257 L
.31305 .30257 L
.31308 .29398 L
.3131 .28968 L
.31312 .28968 L
.31314 .29398 L
.31317 .29828 L
.31319 .29828 L
.31321 .29828 L
.31323 .29398 L
.31325 .28968 L
.31328 .28539 L
.3133 .28968 L
.31332 .29398 L
.31334 .29828 L
.31337 .29828 L
.31339 .29398 L
.31341 .28968 L
.31343 .28539 L
.31346 .28539 L
.31348 .28968 L
.3135 .29828 L
.31352 .29828 L
.31355 .29828 L
.31357 .28968 L
.31359 .28968 L
.31361 .28539 L
.31363 .28539 L
.31366 .29398 L
.31368 .29828 L
.3137 .29828 L
.31372 .29398 L
.31375 .28968 L
.31377 .28968 L
.31379 .28968 L
.31381 .29398 L
.31384 .29828 L
.31386 .29828 L
.31388 .29828 L
.3139 .29398 L
.31392 .28968 L
.31395 .28968 L
.31397 .29398 L
.31399 .29828 L
.31401 .30257 L
.31404 .30257 L
.31406 .29828 L
Mistroke
.31408 .29398 L
.3141 .29398 L
.31413 .29398 L
.31415 .29828 L
.31417 .30257 L
.31419 .30257 L
.31422 .30257 L
.31424 .29398 L
.31426 .29398 L
.31428 .29398 L
.3143 .29828 L
.31433 .30257 L
.31435 .30257 L
.31437 .29828 L
.31439 .28968 L
.31442 .28968 L
.31444 .28968 L
.31446 .29398 L
.31448 .29398 L
.31451 .29828 L
.31453 .29398 L
.31455 .29398 L
.31457 .28968 L
.31459 .29398 L
.31462 .28968 L
.31464 .29398 L
.31466 .29398 L
.31468 .29398 L
.31471 .29398 L
.31473 .29398 L
.31475 .28968 L
.31477 .28539 L
.3148 .28968 L
.31482 .29398 L
.31484 .29828 L
.31486 .29828 L
.31488 .29398 L
.31491 .28968 L
.31493 .28539 L
.31495 .28968 L
.31497 .29828 L
.315 .30257 L
.31502 .30257 L
.31504 .29398 L
.31506 .28539 L
.31509 .28539 L
.31511 .28968 L
.31513 .29828 L
.31515 .30257 L
.31518 .30257 L
Mistroke
.3152 .29398 L
.31522 .28968 L
.31524 .28968 L
.31526 .29398 L
.31529 .29828 L
.31531 .30257 L
.31533 .29828 L
.31535 .29828 L
.31538 .29828 L
.3154 .29398 L
.31542 .29398 L
.31544 .29828 L
.31547 .29828 L
.31549 .30257 L
.31551 .30257 L
.31553 .30257 L
.31555 .29398 L
.31558 .29398 L
.3156 .29398 L
.31562 .29398 L
.31564 .29398 L
.31567 .29828 L
.31569 .29828 L
.31571 .29398 L
.31573 .28968 L
.31576 .28968 L
.31578 .28968 L
.3158 .29398 L
.31582 .29828 L
.31585 .29828 L
.31587 .29398 L
.31589 .28968 L
.31591 .28968 L
.31593 .28968 L
.31596 .28968 L
.31598 .29398 L
.316 .29398 L
.31602 .29398 L
.31605 .29398 L
.31607 .28968 L
.31609 .28968 L
.31611 .28968 L
.31614 .29398 L
.31616 .29828 L
.31618 .29828 L
.3162 .29828 L
.31622 .29398 L
.31625 .29398 L
.31627 .28968 L
.31629 .29398 L
Mistroke
.31631 .29828 L
.31634 .29828 L
.31636 .29828 L
.31638 .29398 L
.3164 .29398 L
.31643 .28968 L
.31645 .29398 L
.31647 .29828 L
.31649 .30257 L
.31651 .30257 L
.31654 .29828 L
.31656 .29398 L
.31658 .29398 L
.3166 .29398 L
.31663 .29828 L
.31665 .30257 L
.31667 .30257 L
.31669 .30257 L
.31672 .29828 L
.31674 .29398 L
.31676 .29398 L
.31678 .29398 L
.31681 .30257 L
.31683 .30257 L
.31685 .30257 L
.31687 .29828 L
.31689 .29398 L
.31692 .29398 L
.31694 .29398 L
.31696 .29828 L
.31698 .30257 L
.31701 .30257 L
.31703 .29828 L
.31705 .28968 L
.31707 .28968 L
.3171 .28968 L
.31712 .29398 L
.31714 .29828 L
.31716 .30257 L
.31718 .29828 L
.31721 .28968 L
.31723 .28968 L
.31725 .28968 L
.31727 .29398 L
.3173 .29828 L
.31732 .29828 L
.31734 .29828 L
.31736 .29398 L
.31739 .28968 L
.31741 .28968 L
Mistroke
.31743 .29398 L
.31745 .29828 L
.31748 .30257 L
.3175 .29828 L
.31752 .29398 L
.31754 .28968 L
.31756 .28968 L
.31759 .29398 L
.31761 .30257 L
.31763 .30257 L
.31765 .29828 L
.31768 .29398 L
.3177 .28968 L
.31772 .28968 L
.31774 .29398 L
.31777 .29828 L
.31779 .30257 L
.31781 .30257 L
.31783 .29828 L
.31785 .29398 L
.31788 .29398 L
.3179 .29398 L
.31792 .29828 L
.31794 .29828 L
.31797 .29828 L
.31799 .30257 L
.31801 .29828 L
.31803 .29828 L
.31806 .29828 L
.31808 .29398 L
.3181 .29828 L
.31812 .29828 L
.31814 .29828 L
.31817 .29828 L
.31819 .29828 L
.31821 .29398 L
.31823 .29398 L
.31826 .29398 L
.31828 .29398 L
.3183 .29828 L
.31832 .29828 L
.31835 .29828 L
.31837 .29828 L
.31839 .29398 L
.31841 .28968 L
.31844 .28968 L
.31846 .29398 L
.31848 .29398 L
.3185 .29828 L
.31852 .29828 L
Mistroke
.31855 .29398 L
.31857 .28968 L
.31859 .28968 L
.31861 .29398 L
.31864 .29828 L
.31866 .29828 L
.31868 .29398 L
.3187 .29398 L
.31873 .28968 L
.31875 .28968 L
.31877 .29398 L
.31879 .29828 L
.31881 .29828 L
.31884 .29398 L
.31886 .29398 L
.31888 .28968 L
.3189 .29398 L
.31893 .29398 L
.31895 .29828 L
.31897 .29828 L
.31899 .29828 L
.31902 .29398 L
.31904 .28968 L
.31906 .28968 L
.31908 .29398 L
.31911 .29828 L
.31913 .29828 L
.31915 .30257 L
.31917 .29828 L
.31919 .29398 L
.31922 .28968 L
.31924 .29398 L
.31926 .29828 L
.31928 .30257 L
.31931 .30257 L
.31933 .30257 L
.31935 .29828 L
.31937 .29398 L
.3194 .29398 L
.31942 .29828 L
.31944 .29828 L
.31946 .30257 L
.31948 .30257 L
.31951 .29828 L
.31953 .29398 L
.31955 .29398 L
.31957 .29398 L
.3196 .29828 L
.31962 .30257 L
.31964 .29828 L
Mistroke
.31966 .29398 L
.31969 .28968 L
.31971 .28968 L
.31973 .29398 L
.31975 .29828 L
.31977 .29828 L
.3198 .29828 L
.31982 .29398 L
.31984 .28968 L
.31986 .28968 L
.31989 .29398 L
.31991 .29828 L
.31993 .30257 L
.31995 .29828 L
.31998 .29398 L
.32 .28968 L
.32002 .28968 L
.32004 .29398 L
.32007 .29828 L
.32009 .29828 L
.32011 .29828 L
.32013 .29398 L
.32015 .28968 L
.32018 .28968 L
.3202 .29398 L
.32022 .29828 L
.32024 .30257 L
.32027 .29828 L
.32029 .29398 L
.32031 .28968 L
.32033 .28968 L
.32036 .29398 L
.32038 .29828 L
.3204 .30257 L
.32042 .30257 L
.32044 .29398 L
.32047 .29398 L
.32049 .29398 L
.32051 .29398 L
.32053 .29828 L
.32056 .30257 L
.32058 .30257 L
.3206 .29828 L
.32062 .29828 L
.32065 .29398 L
.32067 .29398 L
.32069 .29398 L
.32071 .29828 L
.32073 .29828 L
.32076 .29828 L
Mistroke
.32078 .29828 L
.3208 .29398 L
.32082 .29398 L
.32085 .29398 L
.32087 .29398 L
.32089 .29398 L
.32091 .29828 L
.32094 .29398 L
.32096 .29398 L
.32098 .29398 L
.321 .29398 L
.32103 .29398 L
.32105 .29398 L
.32107 .29398 L
.32109 .29398 L
.32111 .29398 L
.32114 .29398 L
.32116 .29398 L
.32118 .29398 L
.3212 .28968 L
.32123 .28968 L
.32125 .29398 L
.32127 .29828 L
.32129 .29398 L
.32132 .29398 L
.32134 .28968 L
.32136 .28968 L
.32138 .29398 L
.3214 .29828 L
.32143 .29828 L
.32145 .29398 L
.32147 .28968 L
.32149 .28968 L
.32152 .28968 L
.32154 .29398 L
.32156 .29828 L
.32158 .30257 L
.32161 .29398 L
.32163 .28968 L
.32165 .28968 L
.32167 .29398 L
.3217 .29828 L
.32172 .30257 L
.32174 .30257 L
.32176 .29828 L
.32178 .28968 L
.32181 .28968 L
.32183 .29828 L
.32185 .30257 L
.32187 .30257 L
Mistroke
.3219 .29828 L
.32192 .29398 L
.32194 .28968 L
.32196 .28968 L
.32199 .29398 L
.32201 .29828 L
.32203 .29828 L
.32205 .29398 L
.32207 .29398 L
.3221 .28968 L
.32212 .29398 L
.32214 .29398 L
.32216 .29828 L
.32219 .29398 L
.32221 .29398 L
.32223 .28968 L
.32225 .28968 L
.32228 .29398 L
.3223 .29398 L
.32232 .29398 L
.32234 .29398 L
.32236 .29398 L
.32239 .28968 L
.32241 .29398 L
.32243 .29398 L
.32245 .29828 L
.32248 .29398 L
.3225 .29398 L
.32252 .29398 L
.32254 .29398 L
.32257 .29398 L
.32259 .29828 L
.32261 .29828 L
.32263 .29398 L
.32266 .28968 L
.32268 .29398 L
.3227 .29398 L
.32272 .29828 L
.32274 .29828 L
.32277 .29828 L
.32279 .29398 L
.32281 .29398 L
.32283 .29398 L
.32286 .29828 L
.32288 .30257 L
.3229 .30257 L
.32292 .30257 L
.32295 .29828 L
.32297 .29828 L
.32299 .29828 L
Mistroke
.32301 .29828 L
.32303 .30257 L
.32306 .30257 L
.32308 .30257 L
.3231 .30257 L
.32312 .29828 L
.32315 .29828 L
.32317 .29398 L
.32319 .29828 L
.32321 .30257 L
.32324 .30257 L
.32326 .30257 L
.32328 .29828 L
.3233 .29398 L
.32333 .29398 L
.32335 .29398 L
.32337 .29828 L
.32339 .29828 L
.32341 .29828 L
.32344 .29398 L
.32346 .28968 L
.32348 .29398 L
.3235 .29398 L
.32353 .29828 L
.32355 .29828 L
.32357 .29398 L
.32359 .29398 L
.32362 .29398 L
.32364 .29398 L
.32366 .29828 L
.32368 .29828 L
.3237 .29828 L
.32373 .29398 L
.32375 .29398 L
.32377 .29398 L
.32379 .29828 L
.32382 .29828 L
.32384 .29398 L
.32386 .29398 L
.32388 .28968 L
.32391 .29398 L
.32393 .29398 L
.32395 .29828 L
.32397 .29828 L
.32399 .29398 L
.32402 .29398 L
.32404 .29398 L
.32406 .29828 L
.32408 .29828 L
.32411 .29828 L
Mistroke
.32413 .29828 L
.32415 .29398 L
.32417 .29398 L
.3242 .29828 L
.32422 .29828 L
.32424 .30257 L
.32426 .30257 L
.32429 .30257 L
.32431 .29398 L
.32433 .29398 L
.32435 .29398 L
.32437 .29828 L
.3244 .30257 L
.32442 .30257 L
.32444 .29828 L
.32446 .28968 L
.32449 .28968 L
.32451 .28968 L
.32453 .29828 L
.32455 .30257 L
.32458 .29828 L
.3246 .28968 L
.32462 .28539 L
.32464 .28539 L
.32466 .29398 L
.32469 .29828 L
.32471 .29828 L
.32473 .29398 L
.32475 .28539 L
.32478 .28539 L
.3248 .28968 L
.32482 .29398 L
.32484 .29828 L
.32487 .29828 L
.32489 .28968 L
.32491 .28539 L
.32493 .28539 L
.32496 .29398 L
.32498 .29398 L
.325 .29398 L
.32502 .29398 L
.32504 .28968 L
.32507 .28968 L
.32509 .28968 L
.32511 .29398 L
.32513 .29398 L
.32516 .29398 L
.32518 .29398 L
.3252 .29398 L
.32522 .29398 L
Mistroke
.32525 .29398 L
.32527 .29828 L
.32529 .29828 L
.32531 .29828 L
.32533 .29828 L
.32536 .29828 L
.32538 .29828 L
.3254 .30257 L
.32542 .30257 L
.32545 .29828 L
.32547 .29828 L
.32549 .29828 L
.32551 .30257 L
.32554 .30257 L
.32556 .29828 L
.32558 .29828 L
.3256 .29828 L
.32562 .29828 L
.32565 .30257 L
.32567 .29828 L
.32569 .29828 L
.32571 .29398 L
.32574 .29398 L
.32576 .29398 L
.32578 .29828 L
.3258 .29828 L
.32583 .29398 L
.32585 .29398 L
.32587 .29398 L
.32589 .29398 L
.32592 .29398 L
.32594 .29398 L
.32596 .29398 L
.32598 .29398 L
.326 .29398 L
.32603 .29398 L
.32605 .29828 L
.32607 .29398 L
.32609 .29398 L
.32612 .29398 L
.32614 .29398 L
.32616 .29398 L
.32618 .29398 L
.32621 .29828 L
.32623 .29398 L
.32625 .29398 L
.32627 .28968 L
.32629 .28968 L
.32632 .29398 L
.32634 .29828 L
Mistroke
.32636 .29828 L
.32638 .29398 L
.32641 .29398 L
.32643 .28968 L
.32645 .29398 L
.32647 .29828 L
.3265 .29828 L
.32652 .30257 L
.32654 .29828 L
.32656 .29398 L
.32659 .29398 L
.32661 .29828 L
.32663 .29828 L
.32665 .30257 L
.32667 .30257 L
.3267 .30257 L
.32672 .29828 L
.32674 .29828 L
.32676 .29828 L
.32679 .29828 L
.32681 .29828 L
.32683 .29828 L
.32685 .29828 L
.32688 .29398 L
.3269 .29398 L
.32692 .29398 L
.32694 .29398 L
.32696 .29398 L
.32699 .29398 L
.32701 .29398 L
.32703 .28968 L
.32705 .28968 L
.32708 .28968 L
.3271 .28968 L
.32712 .29398 L
.32714 .29398 L
.32717 .29398 L
.32719 .28968 L
.32721 .28968 L
.32723 .28968 L
.32725 .29398 L
.32728 .29398 L
.3273 .29398 L
.32732 .28968 L
.32734 .28968 L
.32737 .28968 L
.32739 .28968 L
.32741 .28968 L
.32743 .29398 L
.32746 .28968 L
Mistroke
.32748 .28968 L
.3275 .28539 L
.32752 .28968 L
.32755 .29398 L
.32757 .29398 L
.32759 .29398 L
.32761 .28968 L
.32763 .28968 L
.32766 .28968 L
.32768 .28968 L
.3277 .29398 L
.32772 .29398 L
.32775 .29398 L
.32777 .29398 L
.32779 .29828 L
.32781 .29828 L
.32784 .29398 L
.32786 .29398 L
.32788 .29828 L
.3279 .29398 L
.32792 .29828 L
.32795 .29828 L
.32797 .30257 L
.32799 .29828 L
.32801 .29828 L
.32804 .29828 L
.32806 .29398 L
.32808 .29828 L
.3281 .29828 L
.32813 .29828 L
.32815 .29828 L
.32817 .29398 L
.32819 .29398 L
.32822 .29398 L
.32824 .29828 L
.32826 .29828 L
.32828 .29398 L
.3283 .29398 L
.32833 .28968 L
.32835 .29398 L
.32837 .29398 L
.32839 .29398 L
.32842 .29828 L
.32844 .29398 L
.32846 .29398 L
.32848 .29398 L
.32851 .29398 L
.32853 .29398 L
.32855 .29828 L
.32857 .29828 L
Mistroke
.32859 .29828 L
.32862 .29398 L
.32864 .29398 L
.32866 .28968 L
.32868 .29398 L
.32871 .29398 L
.32873 .29828 L
.32875 .29828 L
.32877 .29398 L
.3288 .28968 L
.32882 .28968 L
.32884 .29398 L
.32886 .29828 L
.32888 .30257 L
.32891 .29828 L
.32893 .29398 L
.32895 .28968 L
.32897 .29398 L
.329 .29828 L
.32902 .30257 L
.32904 .30257 L
.32906 .30257 L
.32909 .29828 L
.32911 .29398 L
.32913 .29398 L
.32915 .30257 L
.32918 .30687 L
.3292 .30687 L
.32922 .30687 L
.32924 .30257 L
.32926 .29828 L
.32929 .29828 L
.32931 .30257 L
.32933 .30257 L
.32935 .30257 L
.32938 .30257 L
.3294 .29828 L
.32942 .29398 L
.32944 .29398 L
.32947 .29398 L
.32949 .29828 L
.32951 .29828 L
.32953 .29828 L
.32955 .29398 L
.32958 .29398 L
.3296 .28968 L
.32962 .29398 L
.32964 .29828 L
.32967 .29828 L
.32969 .29828 L
Mistroke
.32971 .29398 L
.32973 .29398 L
.32976 .29398 L
.32978 .29398 L
.3298 .29398 L
.32982 .29828 L
.32985 .29828 L
.32987 .29828 L
.32989 .29398 L
.32991 .28968 L
.32993 .28968 L
.32996 .29398 L
.32998 .29828 L
.33 .29828 L
.33002 .29828 L
.33005 .29398 L
.33007 .28968 L
.33009 .28968 L
.33011 .29398 L
.33014 .29398 L
.33016 .29828 L
.33018 .29828 L
.3302 .29828 L
.33022 .29398 L
.33025 .28968 L
.33027 .28539 L
.33029 .29398 L
.33031 .29828 L
.33034 .30257 L
.33036 .30257 L
.33038 .29828 L
.3304 .29398 L
.33043 .29398 L
.33045 .29398 L
.33047 .29828 L
.33049 .30257 L
.33051 .30257 L
.33054 .30257 L
.33056 .29828 L
.33058 .29398 L
.3306 .29398 L
.33063 .29398 L
.33065 .29828 L
.33067 .29828 L
.33069 .29828 L
.33072 .29828 L
.33074 .29398 L
.33076 .28968 L
.33078 .28968 L
.33081 .28968 L
Mistroke
.33083 .29398 L
.33085 .29398 L
.33087 .29398 L
.33089 .29398 L
.33092 .28968 L
.33094 .28539 L
.33096 .28968 L
.33098 .28968 L
.33101 .29398 L
.33103 .29828 L
.33105 .29828 L
.33107 .29398 L
.3311 .28968 L
.33112 .28539 L
.33114 .28968 L
.33116 .29398 L
.33118 .29828 L
.33121 .29828 L
.33123 .29398 L
.33125 .28968 L
.33127 .28539 L
.3313 .28968 L
.33132 .29398 L
.33134 .29828 L
.33136 .29828 L
.33139 .29398 L
.33141 .28968 L
.33143 .28968 L
.33145 .28968 L
.33148 .29398 L
.3315 .29828 L
.33152 .29828 L
.33154 .29828 L
.33156 .29398 L
.33159 .29398 L
.33161 .29398 L
.33163 .29398 L
.33165 .29828 L
.33168 .30257 L
.3317 .30257 L
.33172 .30257 L
.33174 .29828 L
.33177 .29828 L
.33179 .29398 L
.33181 .29828 L
.33183 .30257 L
.33185 .30257 L
.33188 .30687 L
.3319 .29828 L
.33192 .29398 L
Mistroke
.33194 .29398 L
.33197 .29398 L
.33199 .29828 L
.33201 .29828 L
.33203 .29828 L
.33206 .29828 L
.33208 .29398 L
.3321 .29398 L
.33212 .28968 L
.33214 .29398 L
.33217 .29828 L
.33219 .29828 L
.33221 .29828 L
.33223 .29398 L
.33226 .29398 L
.33228 .29398 L
.3323 .29398 L
.33232 .29398 L
.33235 .29828 L
.33237 .29828 L
.33239 .29828 L
.33241 .29398 L
.33244 .29398 L
.33246 .28968 L
.33248 .29398 L
.3325 .29398 L
.33252 .29828 L
.33255 .30257 L
.33257 .30257 L
.33259 .29828 L
.33261 .29398 L
.33264 .29398 L
.33266 .29398 L
.33268 .29828 L
.3327 .29828 L
.33273 .30257 L
.33275 .29828 L
.33277 .29398 L
.33279 .28968 L
.33281 .28968 L
.33284 .29398 L
.33286 .29828 L
.33288 .30257 L
.3329 .30257 L
.33293 .30257 L
.33295 .29828 L
.33297 .29398 L
.33299 .29398 L
.33302 .30257 L
.33304 .30257 L
Mistroke
.33306 .30687 L
.33308 .30257 L
.33311 .29828 L
.33313 .29828 L
.33315 .29828 L
.33317 .29828 L
.33319 .29828 L
.33322 .29828 L
.33324 .29828 L
.33326 .29828 L
.33328 .29828 L
.33331 .29398 L
.33333 .29398 L
.33335 .28968 L
.33337 .29398 L
.3334 .29828 L
.33342 .29828 L
.33344 .29828 L
.33346 .29398 L
.33348 .28968 L
.33351 .28539 L
.33353 .28968 L
.33355 .29828 L
.33357 .30257 L
.3336 .29828 L
.33362 .29398 L
.33364 .28539 L
.33366 .28539 L
.33369 .28968 L
.33371 .29828 L
.33373 .30257 L
.33375 .30257 L
.33377 .29398 L
.3338 .28539 L
.33382 .28539 L
.33384 .28968 L
.33386 .29828 L
.33389 .30257 L
.33391 .29828 L
.33393 .28968 L
.33395 .28968 L
.33398 .28968 L
.334 .29398 L
.33402 .29398 L
.33404 .29828 L
.33407 .29828 L
.33409 .29828 L
.33411 .29398 L
.33413 .29398 L
.33415 .29398 L
Mistroke
.33418 .29398 L
.3342 .29828 L
.33422 .29828 L
.33424 .30257 L
.33427 .30257 L
.33429 .29828 L
.33431 .29398 L
.33433 .28968 L
.33436 .29398 L
.33438 .29828 L
.3344 .30257 L
.33442 .30257 L
.33444 .29828 L
.33447 .28968 L
.33449 .28968 L
.33451 .28968 L
.33453 .29828 L
.33456 .29828 L
.33458 .29828 L
.3346 .29398 L
.33462 .28968 L
.33465 .28968 L
.33467 .28968 L
.33469 .28968 L
.33471 .29398 L
.33474 .29398 L
.33476 .28968 L
.33478 .28968 L
.3348 .28539 L
.33482 .28539 L
.33485 .28968 L
.33487 .28968 L
.33489 .29398 L
.33491 .29398 L
.33494 .29398 L
.33496 .28539 L
.33498 .28539 L
.335 .28539 L
.33503 .28968 L
.33505 .29398 L
.33507 .29828 L
.33509 .29398 L
.33511 .28968 L
.33514 .28539 L
.33516 .28968 L
.33518 .29398 L
.3352 .29828 L
.33523 .29828 L
.33525 .29398 L
.33527 .28968 L
Mistroke
.33529 .28539 L
.33532 .28968 L
.33534 .29828 L
.33536 .29828 L
.33538 .29828 L
.3354 .29828 L
.33543 .29398 L
.33545 .29398 L
.33547 .29398 L
.33549 .29828 L
.33552 .30257 L
.33554 .30257 L
.33556 .30257 L
.33558 .30257 L
.33561 .29828 L
.33563 .29398 L
.33565 .29398 L
.33567 .29828 L
.3357 .30257 L
.33572 .30257 L
.33574 .29828 L
.33576 .29398 L
.33578 .28968 L
.33581 .28968 L
.33583 .29398 L
.33585 .29828 L
.33587 .29828 L
.3359 .29398 L
.33592 .28968 L
.33594 .28539 L
.33596 .28968 L
.33599 .29398 L
.33601 .30257 L
.33603 .29828 L
.33605 .29398 L
.33607 .28968 L
.3361 .28968 L
.33612 .28968 L
.33614 .29828 L
.33616 .29828 L
.33619 .29828 L
.33621 .29398 L
.33623 .28968 L
.33625 .28968 L
.33628 .29398 L
.3363 .29828 L
.33632 .29828 L
.33634 .29828 L
.33636 .29398 L
.33639 .28968 L
Mistroke
.33641 .29398 L
.33643 .29398 L
.33645 .29828 L
.33648 .29828 L
.3365 .29828 L
.33652 .29828 L
.33654 .29398 L
.33657 .29398 L
.33659 .29398 L
.33661 .29828 L
.33663 .29828 L
.33666 .30257 L
.33668 .30257 L
.3367 .29828 L
.33672 .29398 L
.33674 .29398 L
.33677 .29828 L
.33679 .30257 L
.33681 .30687 L
.33683 .30687 L
.33686 .30257 L
.33688 .29828 L
.3369 .28968 L
.33692 .29398 L
.33695 .29828 L
.33697 .30257 L
.33699 .30257 L
.33701 .29828 L
.33703 .29398 L
.33706 .28539 L
.33708 .28968 L
.3371 .29828 L
.33712 .30257 L
.33715 .29828 L
.33717 .29398 L
.33719 .28539 L
.33721 .28539 L
.33724 .28539 L
.33726 .28968 L
.33728 .29828 L
.3373 .29828 L
.33733 .29398 L
.33735 .28968 L
.33737 .28539 L
.33739 .28539 L
.33741 .29398 L
.33744 .29828 L
.33746 .29828 L
.33748 .29398 L
.3375 .28968 L
Mistroke
.33753 .28968 L
.33755 .28968 L
.33757 .29398 L
.33759 .29828 L
.33762 .30257 L
.33764 .29828 L
.33766 .29398 L
.33768 .28968 L
.3377 .29398 L
.33773 .29828 L
.33775 .30257 L
.33777 .30257 L
.33779 .29828 L
.33782 .29398 L
.33784 .28968 L
.33786 .29398 L
.33788 .29828 L
.33791 .30687 L
.33793 .30687 L
.33795 .30257 L
.33797 .29828 L
.33799 .29398 L
.33802 .29828 L
.33804 .30257 L
.33806 .30687 L
.33808 .31117 L
.33811 .30687 L
.33813 .29828 L
.33815 .29398 L
.33817 .29398 L
.3382 .30257 L
.33822 .30687 L
.33824 .30687 L
.33826 .30257 L
.33829 .29398 L
.33831 .28968 L
.33833 .28968 L
.33835 .29398 L
.33837 .29828 L
.3384 .30257 L
.33842 .29398 L
.33844 .28968 L
.33846 .28968 L
.33849 .28968 L
.33851 .29398 L
.33853 .29828 L
.33855 .29828 L
.33858 .29828 L
.3386 .29398 L
.33862 .28968 L
Mistroke
.33864 .28968 L
.33866 .29398 L
.33869 .29828 L
.33871 .29828 L
.33873 .29828 L
.33875 .29398 L
.33878 .29398 L
.3388 .28968 L
.33882 .29398 L
.33884 .29828 L
.33887 .29828 L
.33889 .29828 L
.33891 .29398 L
.33893 .29398 L
.33896 .29398 L
.33898 .29828 L
.339 .29828 L
.33902 .29828 L
.33904 .29828 L
.33907 .29828 L
.33909 .29828 L
.33911 .29828 L
.33913 .30257 L
.33916 .30257 L
.33918 .30257 L
.3392 .30257 L
.33922 .29828 L
.33925 .29828 L
.33927 .30257 L
.33929 .30257 L
.33931 .30257 L
.33933 .30257 L
.33936 .30257 L
.33938 .30257 L
.3394 .30257 L
.33942 .29828 L
.33945 .29828 L
.33947 .29828 L
.33949 .29828 L
.33951 .29828 L
.33954 .29828 L
.33956 .29398 L
.33958 .29398 L
.3396 .29398 L
.33962 .29398 L
.33965 .29398 L
.33967 .29398 L
.33969 .29398 L
.33971 .29398 L
.33974 .29398 L
Mistroke
.33976 .29398 L
.33978 .28968 L
.3398 .29398 L
.33983 .29398 L
.33985 .29398 L
.33987 .28968 L
.33989 .28968 L
.33992 .28968 L
.33994 .29398 L
.33996 .29398 L
.33998 .29398 L
.34 .29398 L
.34003 .28968 L
.34005 .28968 L
.34007 .29398 L
.34009 .29398 L
.34012 .29828 L
.34014 .29398 L
.34016 .28968 L
.34018 .28968 L
.34021 .28968 L
.34023 .29398 L
.34025 .29828 L
.34027 .29828 L
.34029 .29828 L
.34032 .29398 L
.34034 .29398 L
.34036 .29398 L
.34038 .29828 L
.34041 .30257 L
.34043 .30257 L
.34045 .29828 L
.34047 .29828 L
.3405 .29828 L
.34052 .29828 L
.34054 .30257 L
.34056 .30257 L
.34059 .30257 L
.34061 .29828 L
.34063 .29828 L
.34065 .29398 L
.34067 .29398 L
.3407 .29828 L
.34072 .29828 L
.34074 .29828 L
.34076 .29398 L
.34079 .29398 L
.34081 .28968 L
.34083 .28968 L
.34085 .29398 L
Mistroke
.34088 .29398 L
.3409 .28968 L
.34092 .28968 L
.34094 .28968 L
.34096 .28968 L
.34099 .28968 L
.34101 .28968 L
.34103 .29398 L
.34105 .29398 L
.34108 .28968 L
.3411 .28539 L
.34112 .28539 L
.34114 .28539 L
.34117 .28968 L
.34119 .28968 L
.34121 .28968 L
.34123 .28968 L
.34125 .28539 L
.34128 .28539 L
.3413 .28968 L
.34132 .28968 L
.34134 .28968 L
.34137 .28968 L
.34139 .28968 L
.34141 .28968 L
.34143 .28968 L
.34146 .28968 L
.34148 .28968 L
.3415 .29398 L
.34152 .29398 L
.34155 .29398 L
.34157 .29398 L
.34159 .29398 L
.34161 .29398 L
.34163 .29828 L
.34166 .29828 L
.34168 .29828 L
.3417 .29828 L
.34172 .29828 L
.34175 .29828 L
.34177 .29828 L
.34179 .29828 L
.34181 .29828 L
.34184 .29828 L
.34186 .29828 L
.34188 .29828 L
.3419 .29828 L
.34192 .29398 L
.34195 .29398 L
.34197 .29398 L
Mistroke
.34199 .29398 L
.34201 .28968 L
.34204 .29398 L
.34206 .29398 L
.34208 .28968 L
.3421 .28968 L
.34213 .28968 L
.34215 .28968 L
.34217 .28968 L
.34219 .28968 L
.34222 .28968 L
.34224 .28968 L
.34226 .28968 L
.34228 .28968 L
.3423 .28968 L
.34233 .28968 L
.34235 .28968 L
.34237 .28968 L
.34239 .28968 L
.34242 .28968 L
.34244 .29398 L
.34246 .28968 L
.34248 .28968 L
.34251 .28968 L
.34253 .28968 L
.34255 .29398 L
.34257 .29398 L
.34259 .28968 L
.34262 .28968 L
.34264 .28539 L
.34266 .28968 L
.34268 .29398 L
.34271 .29828 L
.34273 .29828 L
.34275 .29828 L
.34277 .29398 L
.3428 .28968 L
.34282 .29398 L
.34284 .29828 L
.34286 .30257 L
.34288 .30687 L
.34291 .30257 L
.34293 .29828 L
.34295 .29828 L
.34297 .29828 L
.343 .30257 L
.34302 .30687 L
.34304 .30687 L
.34306 .30687 L
.34309 .30257 L
Mistroke
.34311 .29828 L
.34313 .29398 L
.34315 .29828 L
.34318 .30257 L
.3432 .30257 L
.34322 .30687 L
.34324 .29828 L
.34326 .29398 L
.34329 .28968 L
.34331 .29398 L
.34333 .29828 L
.34335 .30257 L
.34338 .30257 L
.3434 .29828 L
.34342 .28968 L
.34344 .28968 L
.34347 .29398 L
.34349 .29828 L
.34351 .30257 L
.34353 .29828 L
.34355 .29398 L
.34358 .28968 L
.3436 .28968 L
.34362 .29398 L
.34364 .29828 L
.34367 .29828 L
.34369 .29828 L
.34371 .29398 L
.34373 .29398 L
.34376 .29398 L
.34378 .29398 L
.3438 .29828 L
.34382 .29828 L
.34385 .29828 L
.34387 .29828 L
.34389 .29398 L
.34391 .29398 L
.34393 .29398 L
.34396 .29828 L
.34398 .30257 L
.344 .30257 L
.34402 .30257 L
.34405 .30257 L
.34407 .29828 L
.34409 .30257 L
.34411 .30257 L
.34414 .30687 L
.34416 .30687 L
.34418 .30687 L
.3442 .30687 L
Mistroke
.34422 .30687 L
.34425 .30257 L
.34427 .30257 L
.34429 .30687 L
.34431 .30687 L
.34434 .30687 L
.34436 .30687 L
.34438 .30687 L
.3444 .30257 L
.34443 .30257 L
.34445 .30257 L
.34447 .29828 L
.34449 .29828 L
.34451 .30257 L
.34454 .30257 L
.34456 .29828 L
.34458 .29828 L
.3446 .29828 L
.34463 .29828 L
.34465 .29398 L
.34467 .29398 L
.34469 .29828 L
.34472 .29828 L
.34474 .29828 L
.34476 .29828 L
.34478 .29398 L
.34481 .28968 L
.34483 .29398 L
.34485 .29398 L
.34487 .29828 L
.34489 .29828 L
.34492 .29398 L
.34494 .28968 L
.34496 .28968 L
.34498 .29398 L
.34501 .29398 L
.34503 .29398 L
.34505 .29398 L
.34507 .29398 L
.3451 .28968 L
.34512 .28968 L
.34514 .29398 L
.34516 .29398 L
.34518 .29828 L
.34521 .29398 L
.34523 .29398 L
.34525 .29398 L
.34527 .29398 L
.3453 .29398 L
.34532 .29828 L
Mistroke
.34534 .29828 L
.34536 .29828 L
.34539 .29828 L
.34541 .29828 L
.34543 .29828 L
.34545 .29828 L
.34548 .29828 L
.3455 .30257 L
.34552 .30257 L
.34554 .30257 L
.34556 .30257 L
.34559 .29828 L
.34561 .29398 L
.34563 .29398 L
.34565 .29828 L
.34568 .29828 L
.3457 .29828 L
.34572 .29828 L
.34574 .29398 L
.34577 .28968 L
.34579 .28968 L
.34581 .28968 L
.34583 .29828 L
.34585 .29828 L
.34588 .29828 L
.3459 .29398 L
.34592 .28968 L
.34594 .28968 L
.34597 .28968 L
.34599 .29398 L
.34601 .29828 L
.34603 .29398 L
.34606 .28968 L
.34608 .28539 L
.3461 .28539 L
.34612 .28539 L
.34614 .29398 L
.34617 .29828 L
.34619 .29398 L
.34621 .28968 L
.34623 .28539 L
.34626 .28539 L
.34628 .28968 L
.3463 .29398 L
.34632 .29828 L
.34635 .29828 L
.34637 .29398 L
.34639 .28539 L
.34641 .28539 L
.34644 .28968 L
Mistroke
.34646 .29398 L
.34648 .29828 L
.3465 .29828 L
.34652 .29398 L
.34655 .28968 L
.34657 .28968 L
.34659 .29398 L
.34661 .29398 L
.34664 .30257 L
.34666 .30257 L
.34668 .30257 L
.3467 .29828 L
.34673 .29398 L
.34675 .29398 L
.34677 .29398 L
.34679 .29828 L
.34681 .29828 L
.34684 .29828 L
.34686 .29828 L
.34688 .29828 L
.3469 .29398 L
.34693 .29398 L
.34695 .29398 L
.34697 .29398 L
.34699 .29398 L
.34702 .29828 L
.34704 .29828 L
.34706 .29398 L
.34708 .29398 L
.34711 .28968 L
.34713 .28968 L
.34715 .29398 L
.34717 .29398 L
.34719 .29398 L
.34722 .29398 L
.34724 .28968 L
.34726 .28968 L
.34728 .28968 L
.34731 .28968 L
.34733 .29398 L
.34735 .29398 L
.34737 .29398 L
.3474 .28968 L
.34742 .28968 L
.34744 .28968 L
.34746 .29398 L
.34748 .29398 L
.34751 .29398 L
.34753 .29398 L
.34755 .28968 L
Mistroke
.34757 .28968 L
.3476 .28968 L
.34762 .29398 L
.34764 .29398 L
.34766 .29398 L
.34769 .29398 L
.34771 .29398 L
.34773 .29398 L
.34775 .28968 L
.34777 .29398 L
.3478 .29398 L
.34782 .29828 L
.34784 .29828 L
.34786 .29828 L
.34789 .29828 L
.34791 .29398 L
.34793 .29398 L
.34795 .29828 L
.34798 .30257 L
.348 .30257 L
.34802 .30257 L
.34804 .30257 L
.34807 .29828 L
.34809 .29828 L
.34811 .29828 L
.34813 .30257 L
.34815 .30257 L
.34818 .29828 L
.3482 .29828 L
.34822 .29828 L
.34824 .29828 L
.34827 .29828 L
.34829 .29828 L
.34831 .29828 L
.34833 .29398 L
.34836 .29398 L
.34838 .29828 L
.3484 .29828 L
.34842 .29828 L
.34844 .29398 L
.34847 .29398 L
.34849 .29398 L
.34851 .29828 L
.34853 .29828 L
.34856 .29828 L
.34858 .29828 L
.3486 .29398 L
.34862 .28968 L
.34865 .29398 L
.34867 .29828 L
Mistroke
.34869 .29828 L
.34871 .29828 L
.34874 .29828 L
.34876 .29398 L
.34878 .28968 L
.3488 .29398 L
.34882 .29828 L
.34885 .29828 L
.34887 .29828 L
.34889 .29398 L
.34891 .29398 L
.34894 .29398 L
.34896 .29398 L
.34898 .29828 L
.349 .29828 L
.34903 .29828 L
.34905 .29828 L
.34907 .29828 L
.34909 .29828 L
.34911 .29828 L
.34914 .29828 L
.34916 .29828 L
.34918 .29828 L
.3492 .30257 L
.34923 .30257 L
.34925 .30257 L
.34927 .30257 L
.34929 .29828 L
.34932 .29828 L
.34934 .29828 L
.34936 .30257 L
.34938 .30257 L
.3494 .30257 L
.34943 .30257 L
.34945 .29828 L
.34947 .29398 L
.34949 .29398 L
.34952 .29398 L
.34954 .29828 L
.34956 .29828 L
.34958 .29828 L
.34961 .29398 L
.34963 .28968 L
.34965 .28539 L
.34967 .28968 L
.3497 .29398 L
.34972 .29828 L
.34974 .29828 L
.34976 .29398 L
.34978 .28968 L
Mistroke
.34981 .28539 L
.34983 .28968 L
.34985 .29398 L
.34987 .29828 L
.3499 .29828 L
.34992 .29398 L
.34994 .28539 L
.34996 .28539 L
.34999 .28968 L
.35001 .29398 L
.35003 .29398 L
.35005 .29398 L
.35007 .29398 L
.3501 .28968 L
.35012 .28968 L
.35014 .28968 L
.35016 .28968 L
.35019 .29398 L
.35021 .29398 L
.35023 .29398 L
.35025 .29398 L
.35028 .29398 L
.3503 .28968 L
.35032 .28968 L
.35034 .29398 L
.35037 .29398 L
.35039 .29828 L
.35041 .29828 L
.35043 .29398 L
.35045 .29398 L
.35048 .28968 L
.3505 .29398 L
.35052 .29828 L
.35054 .30257 L
.35057 .30687 L
.35059 .30257 L
.35061 .29828 L
.35063 .28968 L
.35066 .29398 L
.35068 .29398 L
.3507 .29828 L
.35072 .29828 L
.35074 .29828 L
.35077 .29398 L
.35079 .28968 L
.35081 .28539 L
.35083 .28968 L
.35086 .28968 L
.35088 .29398 L
.3509 .29398 L
Mistroke
.35092 .29398 L
.35095 .28968 L
.35097 .28539 L
.35099 .28968 L
.35101 .28968 L
.35103 .29398 L
.35106 .29398 L
.35108 .29398 L
.3511 .28968 L
.35112 .28539 L
.35115 .28539 L
.35117 .28968 L
.35119 .28968 L
.35121 .29398 L
.35124 .29398 L
.35126 .28968 L
.35128 .28539 L
.3513 .28539 L
.35133 .28539 L
.35135 .29398 L
.35137 .29828 L
.35139 .29398 L
.35141 .29398 L
.35144 .28968 L
.35146 .28968 L
.35148 .28968 L
.3515 .28968 L
.35153 .29398 L
.35155 .29828 L
.35157 .29828 L
.35159 .29398 L
.35162 .29398 L
.35164 .28968 L
.35166 .29398 L
.35168 .29828 L
.3517 .30257 L
.35173 .30257 L
.35175 .29828 L
.35177 .29828 L
.35179 .29828 L
.35182 .29828 L
.35184 .29828 L
.35186 .29828 L
.35188 .30257 L
.35191 .30257 L
.35193 .29828 L
.35195 .29828 L
.35197 .29828 L
.352 .29828 L
.35202 .29828 L
Mistroke
.35204 .29828 L
.35206 .29828 L
.35208 .29828 L
.35211 .29398 L
.35213 .29398 L
.35215 .29398 L
.35217 .29398 L
.3522 .29828 L
.35222 .29828 L
.35224 .29828 L
.35226 .29398 L
.35229 .29398 L
.35231 .29398 L
.35233 .29398 L
.35235 .29398 L
.35237 .29828 L
.3524 .29828 L
.35242 .29398 L
.35244 .29398 L
.35246 .29398 L
.35249 .29398 L
.35251 .29828 L
.35253 .29828 L
.35255 .29828 L
.35258 .29398 L
.3526 .29398 L
.35262 .29398 L
.35264 .29398 L
.35266 .29828 L
.35269 .30257 L
.35271 .29828 L
.35273 .29398 L
.35275 .29398 L
.35278 .29398 L
.3528 .29828 L
.35282 .30257 L
.35284 .30257 L
.35287 .30257 L
.35289 .29828 L
.35291 .29828 L
.35293 .29828 L
.35296 .30257 L
.35298 .30687 L
.353 .30687 L
.35302 .30257 L
.35304 .30257 L
.35307 .29828 L
.35309 .30257 L
.35311 .30687 L
.35313 .30687 L
Mistroke
.35316 .30257 L
.35318 .30257 L
.3532 .29828 L
.35322 .29828 L
.35325 .29828 L
.35327 .29828 L
.35329 .29828 L
.35331 .29828 L
.35333 .29398 L
.35336 .29398 L
.35338 .29398 L
.3534 .29398 L
.35342 .29398 L
.35345 .29398 L
.35347 .29398 L
.35349 .29398 L
.35351 .29398 L
.35354 .28968 L
.35356 .28968 L
.35358 .29398 L
.3536 .29398 L
.35362 .29828 L
.35365 .29398 L
.35367 .29398 L
.35369 .28968 L
.35371 .28968 L
.35374 .28968 L
.35376 .29398 L
.35378 .29398 L
.3538 .29828 L
.35383 .29398 L
.35385 .28968 L
.35387 .28968 L
.35389 .28539 L
.35392 .29398 L
.35394 .29828 L
.35396 .29828 L
.35398 .29828 L
.354 .28968 L
.35403 .28539 L
.35405 .28968 L
.35407 .29398 L
.35409 .29828 L
.35412 .30257 L
.35414 .29828 L
.35416 .29398 L
.35418 .29398 L
.35421 .29398 L
.35423 .29828 L
.35425 .30257 L
Mistroke
.35427 .30687 L
.35429 .30257 L
.35432 .29828 L
.35434 .29398 L
.35436 .29398 L
.35438 .29828 L
.35441 .30257 L
.35443 .30257 L
.35445 .30257 L
.35447 .29828 L
.3545 .28968 L
.35452 .28968 L
.35454 .29398 L
.35456 .29828 L
.35459 .29828 L
.35461 .29828 L
.35463 .28968 L
.35465 .28539 L
.35467 .28539 L
.3547 .28968 L
.35472 .29398 L
.35474 .29828 L
.35476 .29398 L
.35479 .28968 L
.35481 .28539 L
.35483 .28539 L
.35485 .28968 L
.35488 .29398 L
.3549 .29398 L
.35492 .29398 L
.35494 .28968 L
.35496 .28539 L
.35499 .28539 L
.35501 .28968 L
.35503 .29398 L
.35505 .29828 L
.35508 .29398 L
.3551 .28968 L
.35512 .28539 L
.35514 .28539 L
.35517 .28968 L
.35519 .29398 L
.35521 .29828 L
.35523 .29398 L
.35525 .28968 L
.35528 .28968 L
.3553 .28968 L
.35532 .29398 L
.35534 .30257 L
.35537 .30257 L
Mistroke
.35539 .29828 L
.35541 .29828 L
.35543 .29398 L
.35546 .29398 L
.35548 .30257 L
.3555 .30257 L
.35552 .30687 L
.35555 .30257 L
.35557 .30257 L
.35559 .29828 L
.35561 .29828 L
.35563 .29828 L
.35566 .30257 L
.35568 .30257 L
.3557 .30257 L
.35572 .29398 L
.35575 .29398 L
.35577 .29398 L
.35579 .29398 L
.35581 .29828 L
.35584 .29828 L
.35586 .29398 L
.35588 .29398 L
.3559 .28968 L
.35592 .28968 L
.35595 .28968 L
.35597 .29398 L
.35599 .29398 L
.35601 .29828 L
.35604 .29398 L
.35606 .28968 L
.35608 .28968 L
.3561 .28968 L
.35613 .29398 L
.35615 .29398 L
.35617 .29828 L
.35619 .29398 L
.35622 .29398 L
.35624 .28968 L
.35626 .28968 L
.35628 .29398 L
.3563 .29828 L
.35633 .29828 L
.35635 .29398 L
.35637 .28968 L
.35639 .28968 L
.35642 .28968 L
.35644 .29828 L
.35646 .29828 L
.35648 .29828 L
Mistroke
.35651 .29398 L
.35653 .28968 L
.35655 .29398 L
.35657 .29828 L
.35659 .30257 L
.35662 .30687 L
.35664 .30257 L
.35666 .30257 L
.35668 .29828 L
.35671 .30257 L
.35673 .30257 L
.35675 .30687 L
.35677 .31117 L
.3568 .30687 L
.35682 .30257 L
.35684 .30257 L
.35686 .30257 L
.35688 .30257 L
.35691 .30257 L
.35693 .30257 L
.35695 .30257 L
.35697 .30257 L
.357 .29828 L
.35702 .29398 L
.35704 .29828 L
.35706 .29828 L
.35709 .29828 L
.35711 .29828 L
.35713 .29828 L
.35715 .29398 L
.35718 .28968 L
.3572 .29398 L
.35722 .29828 L
.35724 .29828 L
.35726 .29828 L
.35729 .29398 L
.35731 .28968 L
.35733 .28968 L
.35735 .28968 L
.35738 .29828 L
.3574 .29828 L
.35742 .29828 L
.35744 .28968 L
.35747 .28539 L
.35749 .28539 L
.35751 .28968 L
.35753 .29398 L
.35755 .29828 L
.35758 .29398 L
.3576 .28968 L
Mistroke
.35762 .28539 L
.35764 .28539 L
.35767 .28968 L
.35769 .29828 L
.35771 .29828 L
.35773 .29398 L
.35776 .28968 L
.35778 .28968 L
.3578 .28968 L
.35782 .29828 L
.35785 .30257 L
.35787 .30257 L
.35789 .30257 L
.35791 .29828 L
.35793 .29828 L
.35796 .29828 L
.35798 .30257 L
.358 .30257 L
.35802 .30687 L
.35805 .30257 L
.35807 .30257 L
.35809 .29828 L
.35811 .29828 L
.35814 .29828 L
.35816 .29828 L
.35818 .30257 L
.3582 .29828 L
.35822 .29828 L
.35825 .29398 L
.35827 .29398 L
.35829 .28968 L
.35831 .29398 L
.35834 .29398 L
.35836 .29398 L
.35838 .29398 L
.3584 .28968 L
.35843 .28968 L
.35845 .28539 L
.35847 .28968 L
.35849 .28968 L
.35851 .28968 L
.35854 .29398 L
.35856 .28968 L
.35858 .28968 L
.3586 .28539 L
.35863 .28539 L
.35865 .28539 L
.35867 .28539 L
.35869 .28968 L
.35872 .28968 L
Mistroke
.35874 .28968 L
.35876 .28539 L
.35878 .28539 L
.35881 .28539 L
.35883 .28968 L
.35885 .28968 L
.35887 .28968 L
.35889 .28968 L
.35892 .28539 L
.35894 .28539 L
.35896 .28968 L
.35898 .28968 L
.35901 .28968 L
.35903 .29398 L
.35905 .29398 L
.35907 .29398 L
.3591 .29398 L
.35912 .29398 L
.35914 .29828 L
.35916 .29828 L
.35918 .29828 L
.35921 .30257 L
.35923 .30257 L
.35925 .29828 L
.35927 .29828 L
.3593 .29828 L
.35932 .29828 L
.35934 .29828 L
.35936 .30257 L
.35939 .30257 L
.35941 .29828 L
.35943 .29398 L
.35945 .29398 L
.35948 .29398 L
.3595 .29398 L
.35952 .29828 L
.35954 .29828 L
.35956 .29398 L
.35959 .29398 L
.35961 .28968 L
.35963 .28968 L
.35965 .29398 L
.35968 .29398 L
.3597 .29398 L
.35972 .29398 L
.35974 .28968 L
.35977 .28968 L
.35979 .28968 L
.35981 .28968 L
.35983 .29398 L
Mistroke
.35985 .29398 L
.35988 .29398 L
.3599 .28968 L
.35992 .28968 L
.35994 .28968 L
.35997 .28968 L
.35999 .29398 L
.36001 .29398 L
.36003 .29398 L
.36006 .29398 L
.36008 .28968 L
.3601 .28968 L
.36012 .29398 L
.36014 .29398 L
.36017 .29828 L
.36019 .29828 L
.36021 .29398 L
.36023 .29398 L
.36026 .29398 L
.36028 .29828 L
.3603 .29828 L
.36032 .30257 L
.36035 .30257 L
.36037 .30257 L
.36039 .29828 L
.36041 .29828 L
.36044 .30257 L
.36046 .30687 L
.36048 .30687 L
.3605 .30687 L
.36052 .30687 L
.36055 .30257 L
.36057 .30257 L
.36059 .30257 L
.36061 .30257 L
.36064 .30257 L
.36066 .30257 L
.36068 .30257 L
.3607 .29828 L
.36073 .29828 L
.36075 .30257 L
.36077 .29828 L
.36079 .29828 L
.36081 .29828 L
.36084 .29828 L
.36086 .29828 L
.36088 .29828 L
.3609 .29828 L
.36093 .29828 L
.36095 .29398 L
Mistroke
.36097 .29398 L
.36099 .29398 L
.36102 .29398 L
.36104 .29828 L
.36106 .29828 L
.36108 .29828 L
.36111 .29398 L
.36113 .28968 L
.36115 .28968 L
.36117 .28968 L
.36119 .29398 L
.36122 .29398 L
.36124 .29398 L
.36126 .28968 L
.36128 .28968 L
.36131 .28968 L
.36133 .29398 L
.36135 .29398 L
.36137 .29398 L
.3614 .28968 L
.36142 .28968 L
.36144 .28968 L
.36146 .29398 L
.36148 .29398 L
.36151 .29828 L
.36153 .29828 L
.36155 .29828 L
.36157 .29828 L
.3616 .29828 L
.36162 .29828 L
.36164 .29828 L
.36166 .30257 L
.36169 .30257 L
.36171 .30257 L
.36173 .30257 L
.36175 .30257 L
.36177 .30257 L
.3618 .29828 L
.36182 .30257 L
.36184 .29828 L
.36186 .30257 L
.36189 .30257 L
.36191 .30257 L
.36193 .29828 L
.36195 .29828 L
.36198 .29398 L
.362 .29398 L
.36202 .29828 L
.36204 .29398 L
.36207 .29398 L
Mistroke
.36209 .29398 L
.36211 .29398 L
.36213 .29398 L
.36215 .29398 L
.36218 .29398 L
.3622 .28968 L
.36222 .28968 L
.36224 .28968 L
.36227 .28968 L
.36229 .28968 L
.36231 .28968 L
.36233 .28968 L
.36236 .28968 L
.36238 .28968 L
.3624 .29398 L
.36242 .28968 L
.36244 .28968 L
.36247 .28968 L
.36249 .28539 L
.36251 .28968 L
.36253 .28968 L
.36256 .28968 L
.36258 .28968 L
.3626 .28968 L
.36262 .28968 L
.36265 .28968 L
.36267 .28968 L
.36269 .28968 L
.36271 .29398 L
.36274 .29398 L
.36276 .29828 L
.36278 .29828 L
.3628 .29398 L
.36282 .29828 L
.36285 .29828 L
.36287 .29828 L
.36289 .30257 L
.36291 .30257 L
.36294 .30257 L
.36296 .29828 L
.36298 .29828 L
.363 .29828 L
.36303 .30257 L
.36305 .30257 L
.36307 .30257 L
.36309 .30257 L
.36311 .29828 L
.36314 .29828 L
.36316 .29828 L
.36318 .29398 L
Mistroke
.3632 .29398 L
.36323 .29828 L
.36325 .29828 L
.36327 .29828 L
.36329 .30257 L
.36332 .29828 L
.36334 .29398 L
.36336 .28968 L
.36338 .28968 L
.3634 .29398 L
.36343 .29828 L
.36345 .29828 L
.36347 .29398 L
.36349 .29398 L
.36352 .28539 L
.36354 .28539 L
.36356 .29398 L
.36358 .29398 L
.36361 .29828 L
.36363 .29398 L
.36365 .28968 L
.36367 .28539 L
.3637 .28539 L
.36372 .28968 L
.36374 .29398 L
.36376 .29398 L
.36378 .29398 L
.36381 .28968 L
.36383 .28968 L
.36385 .28968 L
.36387 .29398 L
.3639 .29398 L
.36392 .29398 L
.36394 .29398 L
.36396 .29398 L
.36399 .29398 L
.36401 .29828 L
.36403 .29828 L
.36405 .29828 L
.36407 .29828 L
.3641 .29828 L
.36412 .29828 L
.36414 .29828 L
.36416 .30257 L
.36419 .30257 L
.36421 .30257 L
.36423 .29828 L
.36425 .30257 L
.36428 .30257 L
.3643 .30257 L
Mistroke
.36432 .30257 L
.36434 .30257 L
.36437 .29828 L
.36439 .29828 L
.36441 .29828 L
.36443 .29828 L
.36445 .29828 L
.36448 .29828 L
.3645 .29828 L
.36452 .29828 L
.36454 .29398 L
.36457 .29398 L
.36459 .29398 L
.36461 .29398 L
.36463 .29398 L
.36466 .29398 L
.36468 .29828 L
.3647 .29828 L
.36472 .29398 L
.36474 .28968 L
.36477 .28968 L
.36479 .29398 L
.36481 .29398 L
.36483 .29398 L
.36486 .28968 L
.36488 .29398 L
.3649 .28539 L
.36492 .28539 L
.36495 .29398 L
.36497 .29398 L
.36499 .29398 L
.36501 .29398 L
.36503 .28968 L
.36506 .28539 L
.36508 .28968 L
.3651 .28968 L
.36512 .29398 L
.36515 .29828 L
.36517 .29828 L
.36519 .29398 L
.36521 .28968 L
.36524 .28968 L
.36526 .29828 L
.36528 .30257 L
.3653 .30257 L
.36533 .30257 L
.36535 .30257 L
.36537 .29398 L
.36539 .29398 L
.36541 .29828 L
Mistroke
.36544 .30257 L
.36546 .30257 L
.36548 .30257 L
.3655 .30257 L
.36553 .29828 L
.36555 .29828 L
.36557 .29828 L
.36559 .29828 L
.36562 .30257 L
.36564 .30257 L
.36566 .30257 L
.36568 .30257 L
.3657 .29828 L
.36573 .30257 L
.36575 .29828 L
.36577 .30257 L
.36579 .29828 L
.36582 .28968 L
.36584 .28968 L
.36586 .29398 L
.36588 .28968 L
.36591 .28539 L
.36593 .28968 L
.36595 .28539 L
.36597 .29398 L
.366 .29828 L
.36602 .28968 L
.36604 .28539 L
.36606 .28539 L
.36608 .28539 L
.36611 .28968 L
.36613 .30257 L
.36615 .30257 L
.36617 .29398 L
.3662 .29398 L
.36622 .28968 L
.36624 .28968 L
.36626 .28968 L
.36629 .28968 L
.36631 .28539 L
.36633 .28539 L
.36635 .28539 L
.36637 .28109 L
.3664 .28109 L
.36642 .28539 L
.36644 .28968 L
.36646 .29828 L
.36649 .28968 L
.36651 .28968 L
.36653 .28968 L
Mistroke
.36655 .28968 L
.36658 .29828 L
.3666 .30257 L
.36662 .31117 L
.36664 .31546 L
.36666 .31117 L
.36669 .30687 L
.36671 .30687 L
.36673 .30257 L
.36675 .29398 L
.36678 .28968 L
.3668 .29398 L
.36682 .29398 L
.36684 .29828 L
.36687 .29398 L
.36689 .28539 L
.36691 .29398 L
.36693 .30687 L
.36696 .29398 L
.36698 .28968 L
.367 .29828 L
.36702 .29398 L
.36704 .29398 L
.36707 .31117 L
.36709 .31546 L
.36711 .30687 L
.36713 .32405 L
.36716 .31976 L
.36718 .29828 L
.3672 .29398 L
.36722 .28109 L
.36725 .2682 L
.36727 .28109 L
.36729 .28109 L
.36731 .2725 L
.36733 .2725 L
.36736 .27679 L
.36738 .2682 L
.3674 .31117 L
.36742 .29828 L
.36745 .28109 L
.36747 .28539 L
.36749 .29398 L
.36751 .30687 L
.36754 .31546 L
.36756 .32835 L
.36758 .28968 L
.3676 .31546 L
.36763 .33694 L
.36765 .31546 L
Mistroke
.36767 .28968 L
.36769 .2725 L
.36771 .25102 L
.36774 .25961 L
.36776 .28539 L
.36778 .26391 L
.3678 .25531 L
.36783 .2682 L
.36785 .25961 L
.36787 .31546 L
.36789 .33694 L
.36792 .30687 L
.36794 .30257 L
.36796 .30257 L
.36798 .31117 L
.368 .34124 L
.36803 .34554 L
.36805 .36272 L
.36807 .30687 L
.36809 .31117 L
.36812 .35843 L
.36814 .33694 L
.36816 .28968 L
.36818 .25531 L
.36821 .23383 L
.36823 .23813 L
.36825 .28109 L
.36827 .25531 L
.36829 .22953 L
.36832 .23813 L
.36834 .25102 L
.36836 .34554 L
.36838 .36702 L
.36841 .31546 L
.36843 .31117 L
.36845 .32405 L
.36847 .36272 L
.3685 .36702 L
.36852 .35843 L
.36854 .26391 L
.36856 .29828 L
.36859 .34983 L
.36861 .31117 L
.36863 .25961 L
.36865 .22094 L
.36867 .19946 L
.3687 .22524 L
.36872 .2682 L
.36874 .22094 L
.36876 .19946 L
Mistroke
.36879 .20805 L
.36881 .28539 L
.36883 .42717 L
.36885 .36702 L
.36888 .32835 L
.3689 .31546 L
.36892 .36272 L
.36894 .3885 L
.36896 .3928 L
.36899 .30257 L
.36901 .23383 L
.36903 .33265 L
.36905 .32835 L
.36908 .28539 L
.3691 .22524 L
.36912 .20376 L
.36914 .20805 L
.36917 .26391 L
.36919 .25531 L
.36921 .20376 L
.36923 .20805 L
.36925 .25531 L
.36928 .44865 L
.3693 .44006 L
.36932 .35413 L
.36934 .34554 L
.36937 .35413 L
.36939 .40139 L
.36941 .40998 L
.36943 .32405 L
.36946 .17798 L
.36948 .29828 L
.3695 .33694 L
.36952 .29398 L
.36955 .23813 L
.36957 .19946 L
.36959 .19087 L
.36961 .26391 L
.36963 .2725 L
.36966 .19516 L
.36968 .19946 L
.3697 .23383 L
.36972 .44435 L
.36975 .47013 L
.36977 .34983 L
.36979 .34124 L
.36981 .33694 L
.36984 .3842 L
.36986 .3928 L
.36988 .31546 L
Mistroke
.3699 .13501 L
.36992 .2725 L
.36995 .33265 L
.36997 .28539 L
.36999 .22524 L
.37001 .19946 L
.37004 .18657 L
.37006 .26391 L
.37008 .28539 L
.3701 .18227 L
.37013 .19516 L
.37015 .24242 L
.37017 .45724 L
.37019 .48302 L
.37022 .34554 L
.37024 .33265 L
.37026 .34124 L
.37028 .3928 L
.3703 .37991 L
.37033 .37991 L
.37035 .28968 L
.37037 .12642 L
.37039 .28968 L
.37042 .34124 L
.37044 .29398 L
.37046 .22524 L
.37048 .20805 L
.37051 .22524 L
.37053 .30687 L
.37055 .28968 L
.37057 .17798 L
.37059 .21235 L
.37062 .27679 L
.37064 .49591 L
.37066 .46583 L
.37068 .31546 L
.37071 .32405 L
.37073 .35843 L
.37075 .3928 L
.37077 .35843 L
.3708 .22953 L
.37082 .12212 L
.37084 .33265 L
.37086 .34983 L
.37088 .26391 L
.37091 .20376 L
.37093 .22524 L
.37095 .23813 L
.37097 .31976 L
.371 .25102 L
Mistroke
.37102 .16079 L
.37104 .19946 L
.37106 .30687 L
.37109 .53028 L
.37111 .40998 L
.37113 .28109 L
.37115 .31546 L
.37118 .37991 L
.3712 .37561 L
.37122 .33265 L
.37124 .1565 L
.37126 .1565 L
.37129 .37131 L
.37131 .31546 L
.37133 .22094 L
.37135 .19516 L
.37138 .23813 L
.3714 .2725 L
.37142 .34124 L
.37144 .21664 L
.37147 .16079 L
.37149 .21235 L
.37151 .37131 L
.37153 .56036 L
.37155 .34554 L
.37158 .2725 L
.3716 .35413 L
.37162 .40139 L
.37164 .36272 L
.37167 .29398 L
.37169 .11783 L
.37171 .25531 L
.37173 .41857 L
.37176 .29398 L
.37178 .19516 L
.3718 .21664 L
.37182 .25961 L
.37185 .31117 L
.37187 .32835 L
.37189 .18227 L
.37191 .19516 L
.37193 .25531 L
.37196 .41428 L
.37198 .53028 L
.372 .28968 L
.37202 .28539 L
.37205 .3885 L
.37207 .39709 L
.37209 .31976 L
.37211 .24242 L
Mistroke
.37214 .12642 L
.37216 .31976 L
.37218 .3885 L
.3722 .23813 L
.37222 .18227 L
.37225 .25531 L
.37227 .28109 L
.37229 .30687 L
.37231 .28109 L
.37234 .17368 L
.37236 .19946 L
.37238 .28539 L
.3724 .53028 L
.37243 .41428 L
.37245 .22094 L
.37247 .35413 L
.37249 .40139 L
.37251 .34983 L
.37254 .29828 L
.37256 .16938 L
.37258 .17368 L
.3726 .40569 L
.37263 .33265 L
.37265 .17798 L
.37267 .22094 L
.37269 .22094 L
.37272 .28109 L
.37274 .2682 L
.37276 .31546 L
.37278 .22524 L
.37281 .19946 L
.37283 .27679 L
.37285 .31117 L
.37287 .53028 L
.37289 .37561 L
.37292 .23813 L
.37294 .3842 L
.37296 .41857 L
.37298 .31117 L
.37301 .2725 L
.37303 .18657 L
.37305 .23383 L
.37307 .40139 L
.3731 .29398 L
.37312 .19516 L
.37314 .28109 L
.37316 .31976 L
.37318 .26391 L
.37321 .29398 L
.37323 .21235 L
Mistroke
.37325 .20376 L
.37327 .24242 L
.3733 .40998 L
.37332 .51309 L
.37334 .25102 L
.37336 .31117 L
.37339 .41428 L
.37341 .35413 L
.37343 .29398 L
.37345 .25102 L
.37348 .16079 L
.3735 .32405 L
.37352 .3842 L
.37354 .20376 L
.37356 .19946 L
.37359 .30257 L
.37361 .25531 L
.37363 .26391 L
.37365 .28539 L
.37368 .21235 L
.3737 .25961 L
.37372 .26391 L
.37374 .37561 L
.37377 .52598 L
.37379 .25102 L
.37381 .28109 L
.37383 .39709 L
.37385 .32835 L
.37388 .25531 L
.3739 .25531 L
.37392 .17368 L
.37394 .29828 L
.37397 .37131 L
.37399 .25531 L
.37401 .24242 L
.37403 .34554 L
.37406 .29828 L
.37408 .25961 L
.3741 .28109 L
.37412 .19087 L
.37414 .21664 L
.37417 .26391 L
.37419 .48732 L
.37421 .42287 L
.37423 .22953 L
.37426 .3842 L
.37428 .40139 L
.3743 .32835 L
.37432 .29828 L
.37435 .22524 L
Mistroke
.37437 .20376 L
.37439 .3885 L
.37441 .31976 L
.37444 .17368 L
.37446 .23383 L
.37448 .32835 L
.3745 .2682 L
.37452 .25961 L
.37455 .24242 L
.37457 .22953 L
.37459 .28109 L
.37461 .28539 L
.37464 .49591 L
.37466 .41428 L
.37468 .21235 L
.3747 .3842 L
.37473 .37131 L
.37475 .25102 L
.37477 .25102 L
.37479 .21235 L
.37481 .21664 L
.37484 .37131 L
.37486 .28539 L
.37488 .22094 L
.3749 .31976 L
.37493 .34554 L
.37495 .22953 L
.37497 .28109 L
.37499 .23813 L
.37502 .19087 L
.37504 .23383 L
.37506 .23383 L
.37508 .29398 L
.37511 .50021 L
.37513 .34983 L
.37515 .25531 L
.37517 .3928 L
.37519 .37561 L
.37522 .29398 L
.37524 .26391 L
.37526 .22524 L
.37528 .28109 L
.37531 .37131 L
.37533 .25102 L
.37535 .19946 L
.37537 .29398 L
.3754 .30257 L
.37542 .24672 L
.37544 .30257 L
.37546 .26391 L
Mistroke
.37548 .22524 L
.37551 .26391 L
.37553 .37561 L
.37555 .54317 L
.37557 .2725 L
.3756 .25531 L
.37562 .43146 L
.37564 .32405 L
.37566 .24242 L
.37569 .24672 L
.37571 .19946 L
.37573 .34124 L
.37575 .37131 L
.37577 .22094 L
.3758 .24672 L
.37582 .35413 L
.37584 .29398 L
.37586 .24242 L
.37589 .28109 L
.37591 .21235 L
.37593 .26391 L
.37595 .25102 L
.37598 .34983 L
.376 .51309 L
.37602 .25961 L
.37604 .29398 L
.37607 .40998 L
.37609 .31546 L
.37611 .24242 L
.37613 .26391 L
.37615 .22094 L
.37618 .32405 L
.3762 .33265 L
.37622 .21664 L
.37624 .22524 L
.37627 .31546 L
.37629 .28109 L
.37631 .26391 L
.37633 .29398 L
.37636 .21664 L
.37638 .2682 L
.3764 .2682 L
.37642 .43146 L
.37644 .48302 L
.37647 .17798 L
.37649 .34124 L
.37651 .43146 L
.37653 .26391 L
.37656 .23813 L
.37658 .25531 L
Mistroke
.3766 .22953 L
.37662 .3842 L
.37665 .33265 L
.37667 .20805 L
.37669 .29398 L
.37671 .37131 L
.37674 .24242 L
.37676 .23813 L
.37678 .28968 L
.3768 .22953 L
.37682 .28109 L
.37685 .24242 L
.37687 .43576 L
.37689 .46583 L
.37691 .20805 L
.37694 .35413 L
.37696 .41428 L
.37698 .28539 L
.377 .25961 L
.37703 .25961 L
.37705 .22094 L
.37707 .37561 L
.37709 .31117 L
.37711 .19516 L
.37714 .2682 L
.37716 .34554 L
.37718 .25961 L
.3772 .26391 L
.37723 .2682 L
.37725 .22524 L
.37727 .28539 L
.37729 .25961 L
.37732 .47443 L
.37734 .40569 L
.37736 .1565 L
.37738 .39709 L
.3774 .3928 L
.37743 .3928 L
.37745 .20805 L
.37747 .25102 L
.37749 .25961 L
.37752 .24672 L
.37754 .40139 L
.37756 .27679 L
.37758 .19516 L
.37761 .32835 L
.37763 .35843 L
.37765 .19946 L
.37767 .25531 L
.3777 .29398 L
Mistroke
.37772 .23813 L
.37774 .26391 L
.37776 .23383 L
.37778 .47872 L
.37781 .41857 L
.37783 .19516 L
.37785 .37561 L
.37787 .40569 L
.3779 .26391 L
.37792 .25961 L
.37794 .25102 L
.37796 .26391 L
.37799 .37991 L
.37801 .26391 L
.37803 .21664 L
.37805 .30257 L
.37807 .33694 L
.3781 .26391 L
.37812 .27679 L
.37814 .25961 L
.37816 .25961 L
.37819 .28968 L
.37821 .29398 L
.37823 .51309 L
.37825 .32405 L
.37828 .19516 L
.3783 .42717 L
.37832 .34554 L
.37834 .19946 L
.37837 .2725 L
.37839 .2725 L
.37841 .28968 L
.37843 .37131 L
.37845 .22953 L
.37848 .22524 L
.3785 .34124 L
.37852 .30257 L
.37854 .21664 L
.37857 .28109 L
.37859 .25961 L
.37861 .24672 L
.37863 .24242 L
.37866 .27679 L
.37868 .53458 L
.3787 .29828 L
.37872 .20376 L
.37874 .42717 L
.37877 .34124 L
.37879 .21664 L
.37881 .2725 L
Mistroke
.37883 .23813 L
.37886 .31546 L
.37888 .35413 L
.3789 .19946 L
.37892 .23813 L
.37895 .33265 L
.37897 .29828 L
.37899 .24242 L
.37901 .28968 L
.37903 .26391 L
.37906 .2682 L
.37908 .24672 L
.3791 .36702 L
.37912 .5088 L
.37915 .18227 L
.37917 .28968 L
.37919 .46154 L
.37921 .25531 L
.37924 .22094 L
.37926 .29828 L
.37928 .24242 L
.3793 .34983 L
.37933 .33694 L
.37935 .20376 L
.37937 .29828 L
.37939 .35843 L
.37941 .23813 L
.37944 .23383 L
.37946 .30257 L
.37948 .24242 L
.3795 .23383 L
.37953 .24672 L
.37955 .48732 L
.37957 .41428 L
.37959 .17798 L
.37962 .37561 L
.37964 .40998 L
.37966 .25102 L
.37968 .25102 L
.3797 .25531 L
.37973 .28109 L
.37975 .34124 L
.37977 .22953 L
.37979 .22953 L
.37982 .20805 L
.37984 .30257 L
.37986 .32405 L
.37988 .26391 L
.37991 .25531 L
.37993 .27679 L
Mistroke
.37995 .27679 L
.37997 .23383 L
.38 .32405 L
.38002 .52169 L
.38004 .25531 L
.38006 .21664 L
.38008 .44006 L
.38011 .29828 L
.38013 .19516 L
.38015 .28968 L
.38017 .26391 L
.3802 .30687 L
.38022 .33265 L
.38024 .22524 L
.38026 .2682 L
.38029 .33265 L
.38031 .2725 L
.38033 .23813 L
.38035 .29398 L
.38037 .28109 L
.3804 .25102 L
.38042 .23383 L
.38044 .3842 L
.38046 .51309 L
.38049 .20805 L
.38051 .2725 L
.38053 .44865 L
.38055 .30257 L
.38058 .22524 L
.3806 .28539 L
.38062 .26391 L
.38064 .32835 L
.38066 .28968 L
.38069 .20805 L
.38071 .28109 L
.38073 .33694 L
.38075 .28539 L
.38078 .25531 L
.3808 .27679 L
.38082 .29398 L
.38084 .23383 L
.38087 .2725 L
.38089 .52598 L
.38091 .34124 L
.38093 .16079 L
.38096 .43146 L
.38098 .36272 L
.381 .18657 L
.38102 .28109 L
.38104 .28539 L
Mistroke
.38107 .29398 L
.38109 .33265 L
.38111 .22524 L
.38113 .25102 L
.38116 .32405 L
.38118 .29398 L
.3812 .24672 L
.38122 .28968 L
.38125 .28539 L
.38127 .26391 L
.38129 .22094 L
.38131 .32835 L
.38133 .53458 L
.38136 .24672 L
.38138 .21664 L
.3814 .46154 L
.38142 .31976 L
.38145 .20376 L
.38147 .29398 L
.38149 .2725 L
.38151 .32835 L
.38154 .30257 L
.38156 .21235 L
.38158 .28109 L
.3816 .32835 L
.38163 .28109 L
.38165 .26391 L
.38167 .28109 L
.38169 .29828 L
.38171 .2725 L
.38174 .23383 L
.38176 .46154 L
.38178 .43576 L
.3818 .1522 L
.38183 .37561 L
.38185 .43146 L
.38187 .22094 L
.38189 .25961 L
.38192 .30687 L
.38194 .2725 L
.38196 .34124 L
.38198 .25961 L
.382 .25531 L
.38203 .32835 L
.38205 .30257 L
.38207 .25102 L
.38209 .28109 L
.38212 .28539 L
.38214 .2725 L
.38216 .2725 L
Mistroke
.38218 .23383 L
.38221 .29398 L
.38223 .51739 L
.38225 .31546 L
.38227 .17798 L
.38229 .42717 L
.38232 .36702 L
.38234 .21235 L
.38236 .27679 L
.38238 .28968 L
.38241 .31117 L
.38243 .29398 L
.38245 .20805 L
.38247 .26391 L
.3825 .32405 L
.38252 .29398 L
.38254 .26391 L
.38256 .27679 L
.38259 .28968 L
.38261 .2682 L
.38263 .21664 L
.38265 .40139 L
.38267 .48732 L
.3827 .18227 L
.38272 .28968 L
.38274 .45295 L
.38276 .24672 L
.38279 .20376 L
.38281 .30687 L
.38283 .28109 L
.38285 .32405 L
.38288 .2725 L
.3829 .23813 L
.38292 .29398 L
.38294 .30257 L
.38296 .2682 L
.38299 .2682 L
.38301 .28968 L
.38303 .29398 L
.38305 .24672 L
.38308 .22953 L
.3831 .46583 L
.38312 .42287 L
.38314 .13931 L
.38317 .37561 L
.38319 .44865 L
.38321 .21235 L
.38323 .24672 L
.38326 .30687 L
.38328 .28109 L
Mistroke
.3833 .32835 L
.38332 .24242 L
.38334 .24242 L
.38337 .32405 L
.38339 .29398 L
.38341 .23383 L
.38343 .26391 L
.38346 .29398 L
.38348 .28109 L
.3835 .21664 L
.38352 .35413 L
.38355 .5045 L
.38357 .23813 L
.38359 .23383 L
.38361 .45724 L
.38363 .31117 L
.38366 .19516 L
.38368 .30257 L
.3837 .2725 L
.38372 .28968 L
.38375 .2725 L
.38377 .22524 L
.38379 .2682 L
.38381 .31976 L
.38384 .28109 L
.38386 .25531 L
.38388 .28539 L
.3839 .28539 L
.38392 .25531 L
.38395 .24242 L
.38397 .43146 L
.38399 .43576 L
.38401 .1522 L
.38404 .32835 L
.38406 .44435 L
.38408 .20805 L
.3841 .22524 L
.38413 .33265 L
.38415 .27679 L
.38417 .31976 L
.38419 .25961 L
.38422 .22524 L
.38424 .30687 L
.38426 .31546 L
.38428 .24672 L
.3843 .2682 L
.38433 .29828 L
.38435 .27679 L
.38437 .22094 L
.38439 .30257 L
Mistroke
.38442 .5088 L
.38444 .30687 L
.38446 .20376 L
.38448 .45295 L
.38451 .45295 L
.38453 .36702 L
.38455 .17368 L
.38457 .29828 L
.38459 .29398 L
.38462 .28109 L
.38464 .30687 L
.38466 .22524 L
.38468 .25531 L
.38471 .32405 L
.38473 .2682 L
.38475 .24242 L
.38477 .30257 L
.3848 .28968 L
.38482 .2682 L
.38484 .22094 L
.38486 .40139 L
.38489 .47872 L
.38491 .16938 L
.38493 .28968 L
.38495 .48732 L
.38497 .25102 L
.385 .18657 L
.38502 .34124 L
.38504 .25961 L
.38506 .31117 L
.38509 .28109 L
.38511 .21664 L
.38513 .30687 L
.38515 .31546 L
.38518 .22953 L
.3852 .2682 L
.38522 .29828 L
.38524 .28968 L
.38526 .25531 L
.38529 .22953 L
.38531 .47013 L
.38533 .40569 L
.38535 .13501 L
.38538 .3842 L
.3854 .45295 L
.38542 .19946 L
.38544 .25531 L
.38547 .32405 L
.38549 .26391 L
.38551 .33694 L
Mistroke
.38553 .24242 L
.38555 .24242 L
.38558 .34124 L
.3856 .29828 L
.38562 .22953 L
.38564 .28539 L
.38567 .30257 L
.38569 .28109 L
.38571 .22953 L
.38573 .33265 L
.38576 .52169 L
.38578 .25961 L
.3858 .20376 L
.38582 .47872 L
.38585 .34983 L
.38587 .18227 L
.38589 .32835 L
.38591 .28968 L
.38593 .28539 L
.38596 .29398 L
.38598 .20805 L
.386 .28968 L
.38602 .33694 L
.38605 .25102 L
.38607 .25102 L
.38609 .30257 L
.38611 .28968 L
.38614 .25102 L
.38616 .23813 L
.38618 .43576 L
.3862 .45724 L
.38622 .16509 L
.38625 .31117 L
.38627 .46583 L
.38629 .24672 L
.38631 .22094 L
.38634 .33694 L
.38636 .27679 L
.38638 .31117 L
.3864 .25102 L
.38643 .22094 L
.38645 .31976 L
.38647 .30687 L
.38649 .24242 L
.38651 .28539 L
.38654 .31117 L
.38656 .2725 L
.38658 .23383 L
.3866 .2682 L
.38663 .50021 L
Mistroke
.38665 .37131 L
.38667 .14361 L
.38669 .42287 L
.38672 .43576 L
.38674 .17798 L
.38676 .2725 L
.38678 .34554 L
.38681 .28109 L
.38683 .33694 L
.38685 .21664 L
.38687 .21664 L
.38689 .24672 L
.38692 .34983 L
.38694 .2682 L
.38696 .22953 L
.38698 .31117 L
.38701 .31546 L
.38703 .26391 L
.38705 .21235 L
.38707 .33694 L
.3871 .51739 L
.38712 .25102 L
.38714 .21664 L
.38716 .47872 L
.38718 .34554 L
.38721 .18227 L
.38723 .31117 L
.38725 .28968 L
.38727 .30687 L
.3873 .29398 L
.38732 .19087 L
.38734 .28968 L
.38736 .32835 L
.38739 .22953 L
.38741 .24672 L
.38743 .31117 L
.38745 .29398 L
.38748 .24242 L
.3875 .22094 L
.38752 .41857 L
.38754 .46154 L
.38756 .16079 L
.38759 .31117 L
.38761 .48732 L
.38763 .24672 L
.38765 .20805 L
.38768 .32405 L
.3877 .2682 L
.38772 .32835 L
.38774 .24242 L
Mistroke
.38777 .20376 L
.38779 .33694 L
.38781 .29828 L
.38783 .21235 L
.38785 .2725 L
.38788 .32405 L
.3879 .28968 L
.38792 .24242 L
.38794 .23813 L
.38797 .46154 L
.38799 .42287 L
.38801 .13072 L
.38803 .36272 L
.38806 .47872 L
.38808 .21664 L
.3881 .23813 L
.38812 .32405 L
.38814 .28109 L
.38817 .34554 L
.38819 .20805 L
.38821 .22524 L
.38823 .37561 L
.38826 .28109 L
.38828 .19516 L
.3883 .28539 L
.38832 .32405 L
.38835 .26391 L
.38837 .22094 L
.38839 .26391 L
.38841 .50021 L
.38844 .34983 L
.38846 .13931 L
.38848 .41428 L
.3885 .44435 L
.38852 .20376 L
.38855 .25961 L
.38857 .31117 L
.38859 .30257 L
.38861 .31117 L
.38864 .16938 L
.38866 .25102 L
.38868 .36272 L
.3887 .24242 L
.38873 .20376 L
.38875 .29398 L
.38877 .31976 L
.38879 .25102 L
.38881 .22524 L
.38884 .26391 L
.38886 .5045 L
Mistroke
.38888 .34983 L
.3889 .11783 L
.38893 .42717 L
.38895 .44865 L
.38897 .16938 L
.38899 .26391 L
.38902 .32405 L
.38904 .31117 L
.38906 .32835 L
.38908 .16079 L
.38911 .26391 L
.38913 .39709 L
.38915 .24242 L
.38917 .19946 L
.38919 .32405 L
.38922 .32405 L
.38924 .32405 L
.38926 .24242 L
.38928 .19087 L
.38931 .33265 L
.38933 .51739 L
.38935 .22953 L
.38937 .21235 L
.3894 .48732 L
.38942 .37131 L
.38944 .20376 L
.38946 .30257 L
.38948 .30687 L
.38951 .35413 L
.38953 .27679 L
.38955 .16509 L
.38957 .31976 L
.3896 .34124 L
.38962 .19087 L
.38964 .23383 L
.38966 .33265 L
.38969 .30257 L
.38971 .23813 L
.38973 .22524 L
.38975 .31976 L
.38977 .52169 L
.3898 .25531 L
.38982 .16509 L
.38984 .48732 L
.38986 .40998 L
.38989 .1565 L
.38991 .28109 L
.38993 .33265 L
.38995 .32405 L
.38998 .2682 L
Mistroke
.39 .1522 L
.39002 .32405 L
.39004 .37131 L
.39007 .18657 L
.39009 .20376 L
.39011 .34983 L
.39013 .32835 L
.39015 .22524 L
.39018 .22524 L
.3902 .32835 L
.39022 .52169 L
.39024 .25961 L
.39027 .16079 L
.39029 .48732 L
.39031 .42287 L
.39033 .16938 L
.39036 .28109 L
.39038 .34983 L
.3904 .33694 L
.39042 .27679 L
.39044 .1522 L
.39047 .33694 L
.39049 .37991 L
.39051 .19087 L
.39053 .21664 L
.39056 .35413 L
.39058 .31546 L
.3906 .20805 L
.39062 .20376 L
.39065 .40569 L
.39067 .48302 L
.39069 .17368 L
.39071 .26391 L
.39074 .5045 L
.39076 .34554 L
.39078 .19946 L
.3908 .31546 L
.39082 .34554 L
.39085 .34124 L
.39087 .23383 L
.39089 .18227 L
.39091 .35413 L
.39094 .31976 L
.39096 .16509 L
.39098 .23383 L
.391 .34983 L
.39103 .28109 L
.39105 .20376 L
.39107 .23383 L
.39109 .33694 L
Mistroke
.39111 .5045 L
.39114 .21664 L
.39116 .18657 L
.39118 .5088 L
.3912 .40569 L
.39123 .16079 L
.39125 .29398 L
.39127 .37131 L
.39129 .31976 L
.39132 .22953 L
.39134 .16938 L
.39136 .35413 L
.39138 .33694 L
.3914 .16079 L
.39143 .23813 L
.39145 .36272 L
.39147 .28539 L
.39149 .19516 L
.39152 .22524 L
.39154 .40139 L
.39156 .47443 L
.39158 .16938 L
.39161 .16938 L
.39163 .2682 L
.39165 .52169 L
.39167 .34124 L
.3917 .18227 L
.39172 .33265 L
.39174 .36272 L
.39176 .31976 L
.39178 .21235 L
.39181 .20805 L
.39183 .37561 L
.39185 .28539 L
.39187 .16079 L
.3919 .2682 L
.39192 .35413 L
.39194 .2725 L
.39196 .20376 L
.39199 .24672 L
.39201 .34983 L
.39203 .48302 L
.39205 .21235 L
.39207 .22953 L
.3921 .51739 L
.39212 .37561 L
.39214 .17798 L
.39216 .31117 L
.39219 .3842 L
.39221 .31117 L
Mistroke
.39223 .21664 L
.39225 .20376 L
.39228 .36702 L
.3923 .28539 L
.39232 .1479 L
.39234 .25961 L
.39237 .34983 L
.39239 .25531 L
.39241 .19516 L
.39243 .23813 L
.39245 .36272 L
.39248 .46154 L
.3925 .16938 L
.39252 .25961 L
.39254 .52598 L
.39257 .34983 L
.39259 .18657 L
.39261 .34554 L
.39263 .3928 L
.39266 .30257 L
.39268 .21664 L
.3927 .22524 L
.39272 .3885 L
.39274 .27679 L
.39277 .1522 L
.39279 .28539 L
.39281 .34554 L
.39283 .24242 L
.39286 .19946 L
.39288 .28109 L
.3929 .30257 L
.39292 .43576 L
.39295 .29828 L
.39297 .17368 L
.39299 .47013 L
.39301 .44435 L
.39303 .20376 L
.39306 .26391 L
.39308 .43146 L
.3931 .31546 L
.39312 .22524 L
.39315 .21235 L
.39317 .34554 L
.39319 .32835 L
.39321 .16509 L
.39324 .22953 L
.39326 .35843 L
.39328 .27679 L
.3933 .17368 L
.39333 .25102 L
Mistroke
.39335 .31546 L
.39337 .42717 L
.39339 .2682 L
.39341 .17368 L
.39344 .47443 L
.39346 .42717 L
.39348 .20805 L
.3935 .2682 L
.39353 .44006 L
.39355 .31976 L
.39357 .21664 L
.39359 .22953 L
.39362 .34124 L
.39364 .30687 L
.39366 .16509 L
.39368 .24672 L
.3937 .33694 L
.39373 .25961 L
.39375 .18657 L
.39377 .2682 L
.39379 .29398 L
.39382 .31117 L
.39384 .40998 L
.39386 .22094 L
.39388 .31976 L
.39391 .48732 L
.39393 .32405 L
.39395 .20805 L
.39397 .20805 L
.394 .40998 L
.39402 .39709 L
.39404 .23383 L
.39406 .26391 L
.39408 .28539 L
.39411 .31546 L
.39413 .24242 L
.39415 .19946 L
.39417 .30257 L
.3942 .31117 L
.39422 .19946 L
.39424 .22953 L
.39426 .30257 L
.39429 .24672 L
.39431 .3928 L
.39433 .30687 L
.39435 .20376 L
.39437 .45295 L
.3944 .40569 L
.39442 .22094 L
.39444 .30687 L
Mistroke
.39446 .45295 L
.39449 .2682 L
.39451 .25531 L
.39453 .30257 L
.39455 .30257 L
.39458 .28109 L
.3946 .20805 L
.39462 .25531 L
.39464 .31976 L
.39466 .23813 L
.39469 .19946 L
.39471 .28968 L
.39473 .25102 L
.39475 .24242 L
.39478 .41857 L
.3948 .25531 L
.39482 .24242 L
.39484 .45724 L
.39487 .35413 L
.39489 .22094 L
.39491 .36702 L
.39493 .40569 L
.39496 .24672 L
.39498 .29398 L
.395 .30257 L
.39502 .29828 L
.39504 .28539 L
.39507 .22524 L
.39509 .28539 L
.39511 .31546 L
.39513 .22524 L
.39516 .24242 L
.39518 .28968 L
.3952 .23383 L
.39522 .2682 L
.39525 .41428 L
.39527 .25102 L
.39529 .24672 L
.39531 .44865 L
.39533 .35843 L
.39536 .22094 L
.39538 .36702 L
.3954 .40569 L
.39542 .25102 L
.39545 .29828 L
.39547 .32405 L
.39549 .29828 L
.39551 .2682 L
.39554 .24242 L
.39556 .29398 L
Mistroke
.39558 .29398 L
.3956 .22953 L
.39563 .24672 L
.39565 .28109 L
.39567 .23813 L
.39569 .24242 L
.39571 .37991 L
.39574 .31117 L
.39576 .19946 L
.39578 .40569 L
.3958 .3928 L
.39583 .22953 L
.39585 .32405 L
.39587 .42287 L
.39589 .28109 L
.39592 .28968 L
.39594 .34554 L
.39596 .28968 L
.39598 .28109 L
.396 .2725 L
.39603 .2725 L
.39605 .28968 L
.39607 .24242 L
.39609 .23383 L
.39612 .27679 L
.39614 .25531 L
.39616 .22524 L
.39618 .30257 L
.39621 .3928 L
.39623 .20376 L
.39625 .2725 L
.39627 .46154 L
.39629 .28968 L
.39632 .25531 L
.39634 .25531 L
.39636 .40569 L
.39638 .3842 L
.39641 .26391 L
.39643 .34554 L
.39645 .33694 L
.39647 .31117 L
.3965 .29398 L
.39652 .26391 L
.39654 .29398 L
.39656 .28539 L
.39659 .22953 L
.39661 .26391 L
.39663 .2725 L
.39665 .22953 L
.39667 .24242 L
Mistroke
.3967 .29828 L
.39672 .35843 L
.39674 .18657 L
.39676 .31117 L
.39679 .42717 L
.39681 .25961 L
.39683 .2682 L
.39685 .41428 L
.39688 .37991 L
.3969 .23813 L
.39692 .37131 L
.39694 .36272 L
.39696 .27679 L
.39699 .2725 L
.39701 .32405 L
.39703 .28539 L
.39705 .25102 L
.39708 .24672 L
.3971 .28109 L
.39712 .25531 L
.39714 .22524 L
.39717 .26391 L
.39719 .2682 L
.39721 .33265 L
.39723 .22953 L
.39726 .2682 L
.39728 .40569 L
.3973 .28109 L
.39732 .2682 L
.39734 .37131 L
.39737 .40139 L
.39739 .26391 L
.39741 .35413 L
.39743 .36702 L
.39746 .28968 L
.39748 .28539 L
.3975 .32835 L
.39752 .27679 L
.39755 .26391 L
.39757 .28539 L
.39759 .2682 L
.39761 .25102 L
.39763 .24242 L
.39766 .2725 L
.39768 .25531 L
.3977 .31976 L
.39772 .28109 L
.39775 .22524 L
.39777 .3842 L
.39779 .32835 L
Mistroke
.39781 .25531 L
.39784 .34554 L
.39786 .41857 L
.39788 .2725 L
.3979 .31117 L
.39792 .3885 L
.39795 .29398 L
.39797 .2682 L
.39799 .32405 L
.39801 .28968 L
.39804 .25102 L
.39806 .28109 L
.39808 .24672 L
.3981 .24672 L
.39813 .25102 L
.39815 .25531 L
.39817 .25102 L
.39819 .2682 L
.39822 .33265 L
.39824 .22953 L
.39826 .28968 L
.39828 .37991 L
.3983 .28109 L
.39833 .27679 L
.39835 .3928 L
.39837 .35413 L
.39839 .26391 L
.39842 .36272 L
.39844 .34554 L
.39846 .25961 L
.39848 .29828 L
.39851 .32405 L
.39853 .24242 L
.39855 .25961 L
.39857 .28539 L
.39859 .25102 L
.39862 .22953 L
.39864 .2725 L
.39866 .28109 L
.39868 .25102 L
.39871 .25102 L
.39873 .28968 L
.39875 .33265 L
.39877 .24242 L
.3988 .31117 L
.39882 .37561 L
.39884 .2682 L
.39886 .31117 L
.39889 .39709 L
.39891 .31546 L
Mistroke
.39893 .2725 L
.39895 .3842 L
.39897 .31976 L
.399 .24242 L
.39902 .32835 L
.39904 .32405 L
.39906 .22524 L
.39909 .26391 L
.39911 .28968 L
.39913 .24672 L
.39915 .25961 L
.39918 .28539 L
.3992 .27679 L
.39922 .25961 L
.39924 .27679 L
.39926 .32835 L
.39929 .25531 L
.39931 .2725 L
.39933 .3928 L
.39935 .2725 L
.39938 .26391 L
.3994 .37131 L
.39942 .34554 L
.39944 .23383 L
.39947 .33694 L
.39949 .37561 L
.39951 .24672 L
.39953 .28109 L
.39955 .35413 L
.39958 .25102 L
.3996 .23813 L
.39962 .30687 L
.39964 .26391 L
.39967 .25531 L
.39969 .30687 L
.39971 .29828 L
.39973 .24242 L
.39976 .28968 L
.39978 .30687 L
.3998 .29828 L
.39982 .26391 L
.39985 .30687 L
.39987 .36272 L
.39989 .25961 L
.39991 .28539 L
.39993 .35843 L
.39996 .30687 L
.39998 .25102 L
.4 .35843 L
.40002 .34124 L
Mistroke
.40005 .25531 L
.40007 .30257 L
.40009 .34554 L
.40011 .25102 L
.40014 .2725 L
.40016 .33265 L
.40018 .28109 L
.4002 .2725 L
.40022 .30687 L
.40025 .29828 L
.40027 .2725 L
.40029 .28539 L
.40031 .28968 L
.40034 .30257 L
.40036 .2725 L
.40038 .2725 L
.4004 .32405 L
.40043 .27679 L
.40045 .2682 L
.40047 .32405 L
.40049 .31976 L
.40052 .26391 L
.40054 .30257 L
.40056 .33694 L
.40058 .29398 L
.4006 .28109 L
.40063 .33694 L
.40065 .31546 L
.40067 .25531 L
.40069 .29828 L
.40072 .30257 L
.40074 .28539 L
.40076 .28539 L
.40078 .30257 L
.40081 .29398 L
.40083 .26391 L
.40085 .28968 L
.40087 .28539 L
.40089 .27679 L
.40092 .30257 L
.40094 .2725 L
.40096 .29828 L
.40098 .30687 L
.40101 .2682 L
.40103 .29398 L
.40105 .32405 L
.40107 .32405 L
.4011 .28968 L
.40112 .29828 L
.40114 .33265 L
Mistroke
.40116 .31117 L
.40118 .28968 L
.40121 .31976 L
.40123 .32405 L
.40125 .28109 L
.40127 .29398 L
.4013 .31546 L
.40132 .30257 L
.40134 .29398 L
.40136 .29828 L
.40139 .29828 L
.40141 .28539 L
.40143 .28968 L
.40145 .30257 L
.40148 .27679 L
.4015 .28968 L
.40152 .30257 L
.40154 .2682 L
.40156 .30687 L
.40159 .31117 L
.40161 .2725 L
.40163 .29398 L
.40165 .32405 L
.40168 .27679 L
.4017 .28109 L
.40172 .33265 L
.40174 .29398 L
.40177 .28968 L
.40179 .31976 L
.40181 .30257 L
.40183 .2725 L
.40185 .30257 L
.40188 .29828 L
.4019 .31117 L
.40192 .30257 L
.40194 .28539 L
.40197 .31117 L
.40199 .30257 L
.40201 .2725 L
.40203 .30257 L
.40206 .29828 L
.40208 .28968 L
.4021 .29828 L
.40212 .27679 L
.40214 .27679 L
.40217 .30257 L
.40219 .28968 L
.40221 .2725 L
.40223 .30687 L
.40226 .29828 L
Mistroke
.40228 .2725 L
.4023 .30257 L
.40232 .31546 L
.40235 .28968 L
.40237 .31546 L
.40239 .32835 L
.40241 .29398 L
.40244 .29828 L
.40246 .32405 L
.40248 .31546 L
.4025 .30687 L
.40252 .31546 L
.40255 .31546 L
.40257 .29828 L
.40259 .28968 L
.40261 .29398 L
.40264 .28968 L
.40266 .28109 L
.40268 .30257 L
.4027 .28109 L
.40273 .28109 L
.40275 .2725 L
.40277 .28109 L
.40279 .28539 L
.40281 .28539 L
.40284 .28968 L
.40286 .30257 L
.40288 .29398 L
.4029 .28539 L
.40293 .29828 L
.40295 .31546 L
.40297 .30687 L
.40299 .31117 L
.40302 .31117 L
.40304 .29398 L
.40306 .29398 L
.40308 .29828 L
.40311 .30687 L
.40313 .28968 L
.40315 .28968 L
.40317 .31546 L
.40319 .26391 L
.40322 .2725 L
.40324 .31976 L
.40326 .26391 L
.40328 .24672 L
.40331 .31546 L
.40333 .29398 L
.40335 .25531 L
.40337 .29398 L
Mistroke
.4034 .29398 L
.40342 .29398 L
.40344 .27679 L
.40346 .29828 L
.40348 .29398 L
.40351 .28968 L
.40353 .30257 L
.40355 .30687 L
.40357 .28968 L
.4036 .30257 L
.40362 .30687 L
.40364 .29398 L
.40366 .30257 L
.40369 .30687 L
.40371 .29828 L
.40373 .29398 L
.40375 .30687 L
.40377 .29398 L
.4038 .28968 L
.40382 .31546 L
.40384 .28968 L
.40386 .28968 L
.40389 .30257 L
.40391 .28968 L
.40393 .30257 L
.40395 .28539 L
.40398 .28109 L
.404 .30257 L
.40402 .28109 L
.40404 .2725 L
.40407 .28968 L
.40409 .29398 L
.40411 .28109 L
.40413 .27679 L
.40415 .29398 L
.40418 .29398 L
.4042 .28539 L
.40422 .29398 L
.40424 .29828 L
.40427 .29398 L
.40429 .28968 L
.40431 .29828 L
.40433 .30257 L
.40436 .29828 L
.40438 .28968 L
.4044 .30257 L
.40442 .30257 L
.40444 .29398 L
.40447 .29398 L
.40449 .30257 L
Mistroke
.40451 .30687 L
.40453 .27679 L
.40456 .28539 L
.40458 .31546 L
.4046 .27679 L
.40462 .28109 L
.40465 .30687 L
.40467 .2725 L
.40469 .27679 L
.40471 .29828 L
.40474 .27679 L
.40476 .28968 L
.40478 .30257 L
.4048 .28968 L
.40482 .28539 L
.40485 .30257 L
.40487 .29828 L
.40489 .29828 L
.40491 .30257 L
.40494 .30687 L
.40496 .29828 L
.40498 .29398 L
.405 .30687 L
.40503 .30257 L
.40505 .29828 L
.40507 .30687 L
.40509 .30257 L
.40511 .29398 L
.40514 .29828 L
.40516 .29828 L
.40518 .29398 L
.4052 .30257 L
.40523 .30257 L
.40525 .28968 L
.40527 .29398 L
.40529 .29398 L
.40532 .28539 L
.40534 .29398 L
.40536 .29398 L
.40538 .29398 L
.4054 .28539 L
.40543 .28968 L
.40545 .28968 L
.40547 .28539 L
.40549 .29398 L
.40552 .29398 L
.40554 .29398 L
.40556 .28968 L
.40558 .29398 L
.40561 .28968 L
Mistroke
.40563 .29398 L
.40565 .30257 L
.40567 .30257 L
.4057 .29828 L
.40572 .29828 L
.40574 .29828 L
.40576 .29398 L
.40578 .29398 L
.40581 .30257 L
.40583 .30687 L
.40585 .30257 L
.40587 .29828 L
.4059 .30257 L
.40592 .29828 L
.40594 .29398 L
.40596 .30257 L
.40599 .30257 L
.40601 .29828 L
.40603 .30257 L
.40605 .29828 L
.40607 .28968 L
.4061 .29398 L
.40612 .30257 L
.40614 .30257 L
.40616 .29828 L
.40619 .30257 L
.40621 .30257 L
.40623 .29398 L
.40625 .29828 L
.40628 .30257 L
.4063 .29828 L
.40632 .29828 L
.40634 .30257 L
.40637 .29828 L
.40639 .29828 L
.40641 .29398 L
.40643 .30257 L
.40645 .30257 L
.40648 .30687 L
.4065 .30257 L
.40652 .30257 L
.40654 .30257 L
.40657 .29828 L
.40659 .30257 L
.40661 .30257 L
.40663 .30687 L
.40666 .30257 L
.40668 .30257 L
.4067 .29828 L
.40672 .29398 L
Mistroke
.40674 .29828 L
.40677 .29828 L
.40679 .29828 L
.40681 .29398 L
.40683 .28968 L
.40686 .28539 L
.40688 .28539 L
.4069 .28968 L
.40692 .29828 L
.40695 .28968 L
.40697 .28539 L
.40699 .28539 L
.40701 .28539 L
.40703 .28539 L
.40706 .29398 L
.40708 .29828 L
.4071 .29398 L
.40712 .29398 L
.40715 .28968 L
.40717 .29398 L
.40719 .29828 L
.40721 .30257 L
.40724 .30687 L
.40726 .30687 L
.40728 .30257 L
.4073 .30257 L
.40733 .30257 L
.40735 .29828 L
.40737 .30687 L
.40739 .30687 L
.40741 .30257 L
.40744 .30257 L
.40746 .30257 L
.40748 .29398 L
.4075 .29398 L
.40753 .29828 L
.40755 .29398 L
.40757 .29398 L
.40759 .29398 L
.40762 .29398 L
.40764 .28539 L
.40766 .28539 L
.40768 .28968 L
.4077 .28968 L
.40773 .28968 L
.40775 .28968 L
.40777 .28968 L
.40779 .28539 L
.40782 .28968 L
.40784 .28968 L
Mistroke
.40786 .28968 L
.40788 .28968 L
.40791 .29398 L
.40793 .28968 L
.40795 .29398 L
.40797 .29398 L
.408 .29398 L
.40802 .29398 L
.40804 .29828 L
.40806 .29828 L
.40808 .29398 L
.40811 .29828 L
.40813 .29828 L
.40815 .29828 L
.40817 .29828 L
.4082 .29828 L
.40822 .29398 L
.40824 .29398 L
.40826 .29398 L
.40829 .29398 L
.40831 .28968 L
.40833 .29398 L
.40835 .29398 L
.40837 .28539 L
.4084 .28968 L
.40842 .28539 L
.40844 .28968 L
.40846 .29398 L
.40849 .28968 L
.40851 .29398 L
.40853 .29398 L
.40855 .28968 L
.40858 .29398 L
.4086 .29828 L
.40862 .29828 L
.40864 .29828 L
.40866 .29828 L
.40869 .30257 L
.40871 .29828 L
.40873 .29828 L
.40875 .29828 L
.40878 .29828 L
.4088 .30257 L
.40882 .29828 L
.40884 .29828 L
.40887 .30257 L
.40889 .29828 L
.40891 .29828 L
.40893 .29828 L
.40896 .29828 L
Mistroke
.40898 .29828 L
.409 .29828 L
.40902 .29828 L
.40904 .29398 L
.40907 .29398 L
.40909 .28968 L
.40911 .28968 L
.40913 .29398 L
.40916 .29398 L
.40918 .28968 L
.4092 .28539 L
.40922 .28539 L
.40925 .28539 L
.40927 .28539 L
.40929 .28968 L
.40931 .29398 L
.40933 .28968 L
.40936 .28968 L
.40938 .28968 L
.4094 .28539 L
.40942 .28968 L
.40945 .29398 L
.40947 .28968 L
.40949 .29398 L
.40951 .28968 L
.40954 .28539 L
.40956 .28968 L
.40958 .29398 L
.4096 .28968 L
.40963 .29828 L
.40965 .29828 L
.40967 .29398 L
.40969 .29828 L
.40971 .29828 L
.40974 .29398 L
.40976 .30257 L
.40978 .30687 L
.4098 .30257 L
.40983 .30257 L
.40985 .30257 L
.40987 .30257 L
.40989 .30257 L
.40992 .30257 L
.40994 .30257 L
.40996 .30687 L
.40998 .29828 L
.41 .30257 L
.41003 .29828 L
.41005 .29398 L
.41007 .29398 L
Mistroke
.41009 .29398 L
.41012 .29398 L
.41014 .29398 L
.41016 .29398 L
.41018 .28968 L
.41021 .28968 L
.41023 .28968 L
.41025 .28968 L
.41027 .28968 L
.41029 .29398 L
.41032 .29398 L
.41034 .28968 L
.41036 .28539 L
.41038 .28968 L
.41041 .28968 L
.41043 .28968 L
.41045 .29398 L
.41047 .29828 L
.4105 .29398 L
.41052 .29398 L
.41054 .29398 L
.41056 .29398 L
.41059 .29398 L
.41061 .29398 L
.41063 .29828 L
.41065 .29828 L
.41067 .29398 L
.4107 .29398 L
.41072 .29398 L
.41074 .29398 L
.41076 .29828 L
.41079 .29828 L
.41081 .29828 L
.41083 .29398 L
.41085 .29398 L
.41088 .29398 L
.4109 .29398 L
.41092 .29828 L
.41094 .29398 L
.41096 .29828 L
.41099 .29828 L
.41101 .29398 L
.41103 .29398 L
.41105 .29398 L
.41108 .29828 L
.4111 .29828 L
.41112 .29828 L
.41114 .29828 L
.41117 .29828 L
.41119 .29828 L
Mistroke
.41121 .29828 L
.41123 .29828 L
.41126 .29828 L
.41128 .29828 L
.4113 .29828 L
.41132 .29828 L
.41134 .29828 L
.41137 .29828 L
.41139 .29828 L
.41141 .29398 L
.41143 .29828 L
.41146 .29828 L
.41148 .29828 L
.4115 .29398 L
.41152 .29398 L
.41155 .29828 L
.41157 .29398 L
.41159 .29398 L
.41161 .29398 L
.41163 .29398 L
.41166 .28968 L
.41168 .28968 L
.4117 .29398 L
.41172 .29398 L
.41175 .29398 L
.41177 .29398 L
.41179 .29398 L
.41181 .29398 L
.41184 .28968 L
.41186 .29398 L
.41188 .29398 L
.4119 .29828 L
.41192 .29398 L
.41195 .29398 L
.41197 .29398 L
.41199 .29398 L
.41201 .29828 L
.41204 .29828 L
.41206 .29828 L
.41208 .29828 L
.4121 .29398 L
.41213 .28968 L
.41215 .29398 L
.41217 .30257 L
.41219 .29828 L
.41222 .29828 L
.41224 .29828 L
.41226 .29828 L
.41228 .29828 L
.4123 .29828 L
Mistroke
.41233 .30257 L
.41235 .30687 L
.41237 .30687 L
.41239 .30257 L
.41242 .29828 L
.41244 .30257 L
.41246 .29828 L
.41248 .30257 L
.41251 .30687 L
.41253 .30257 L
.41255 .30257 L
.41257 .29828 L
.41259 .29398 L
.41262 .29828 L
.41264 .29828 L
.41266 .29398 L
.41268 .29828 L
.41271 .29398 L
.41273 .28968 L
.41275 .28968 L
.41277 .28968 L
.4128 .28968 L
.41282 .29398 L
.41284 .29398 L
.41286 .29398 L
.41289 .29398 L
.41291 .29398 L
.41293 .29398 L
.41295 .28968 L
.41297 .28968 L
.413 .29398 L
.41302 .29828 L
.41304 .29398 L
.41306 .29398 L
.41309 .29398 L
.41311 .29398 L
.41313 .28968 L
.41315 .29828 L
.41318 .29828 L
.4132 .29398 L
.41322 .29398 L
.41324 .29398 L
.41326 .29398 L
.41329 .29398 L
.41331 .29828 L
.41333 .29828 L
.41335 .29828 L
.41338 .29398 L
.4134 .29398 L
.41342 .29398 L
Mistroke
.41344 .29828 L
.41347 .29828 L
.41349 .29828 L
.41351 .29828 L
.41353 .29828 L
.41355 .29828 L
.41358 .29828 L
.4136 .29398 L
.41362 .29828 L
.41364 .29828 L
.41367 .29828 L
.41369 .29828 L
.41371 .29828 L
.41373 .29828 L
.41376 .29828 L
.41378 .29398 L
.4138 .29828 L
.41382 .29828 L
.41385 .29828 L
.41387 .29828 L
.41389 .29398 L
.41391 .29398 L
.41393 .28968 L
.41396 .29398 L
.41398 .29398 L
.414 .29398 L
.41402 .29398 L
.41405 .28968 L
.41407 .28968 L
.41409 .28539 L
.41411 .28968 L
.41414 .28968 L
.41416 .29398 L
.41418 .29398 L
.4142 .28968 L
.41422 .28968 L
.41425 .28968 L
.41427 .28968 L
.41429 .29398 L
.41431 .29398 L
.41434 .29398 L
.41436 .29398 L
.41438 .28968 L
.4144 .28968 L
.41443 .28968 L
.41445 .29398 L
.41447 .29398 L
.41449 .29398 L
.41452 .29398 L
.41454 .29398 L
Mistroke
.41456 .29398 L
.41458 .29398 L
.4146 .29398 L
.41463 .29398 L
.41465 .29398 L
.41467 .29398 L
.41469 .29398 L
.41472 .29398 L
.41474 .29398 L
.41476 .29828 L
.41478 .29828 L
.41481 .29828 L
.41483 .29398 L
.41485 .29398 L
.41487 .29828 L
.41489 .29828 L
.41492 .29828 L
.41494 .29828 L
.41496 .29828 L
.41498 .29828 L
.41501 .29398 L
.41503 .29828 L
.41505 .29828 L
.41507 .29828 L
.4151 .29828 L
.41512 .29398 L
.41514 .29398 L
.41516 .28968 L
.41518 .28968 L
.41521 .29398 L
.41523 .29398 L
.41525 .29398 L
.41527 .29398 L
.4153 .28968 L
.41532 .28539 L
.41534 .28539 L
.41536 .28968 L
.41539 .29398 L
.41541 .29398 L
.41543 .28968 L
.41545 .28539 L
.41548 .28539 L
.4155 .28968 L
.41552 .29398 L
.41554 .29828 L
.41556 .29398 L
.41559 .28968 L
.41561 .28968 L
.41563 .28968 L
.41565 .29398 L
Mistroke
.41568 .29828 L
.4157 .29828 L
.41572 .29398 L
.41574 .28968 L
.41577 .28968 L
.41579 .29398 L
.41581 .29828 L
.41583 .29828 L
.41585 .29398 L
.41588 .28968 L
.4159 .28968 L
.41592 .29398 L
.41594 .29398 L
.41597 .29828 L
.41599 .29828 L
.41601 .29398 L
.41603 .29398 L
.41606 .29398 L
.41608 .29398 L
.4161 .29828 L
.41612 .29828 L
.41615 .29828 L
.41617 .29398 L
.41619 .29828 L
.41621 .29828 L
.41623 .29828 L
.41626 .30257 L
.41628 .30257 L
.4163 .29828 L
.41632 .29398 L
.41635 .29398 L
.41637 .29398 L
.41639 .29828 L
.41641 .29828 L
.41644 .29828 L
.41646 .29398 L
.41648 .28968 L
.4165 .29398 L
.41652 .29398 L
.41655 .29398 L
.41657 .29828 L
.41659 .29398 L
.41661 .28968 L
.41664 .28968 L
.41666 .28968 L
.41668 .29398 L
.4167 .29828 L
.41673 .29828 L
.41675 .29398 L
.41677 .28968 L
Mistroke
.41679 .28968 L
.41681 .29398 L
.41684 .29828 L
.41686 .29828 L
.41688 .29828 L
.4169 .28968 L
.41693 .28968 L
.41695 .29398 L
.41697 .29828 L
.41699 .30257 L
.41702 .30257 L
.41704 .29398 L
.41706 .28968 L
.41708 .29398 L
.41711 .29828 L
.41713 .30257 L
.41715 .30687 L
.41717 .30257 L
.41719 .29828 L
.41722 .29398 L
.41724 .29828 L
.41726 .30257 L
.41728 .30687 L
.41731 .30687 L
.41733 .30687 L
.41735 .29828 L
.41737 .29828 L
.4174 .29828 L
.41742 .30257 L
.41744 .30687 L
.41746 .30687 L
.41748 .30257 L
.41751 .29828 L
.41753 .29828 L
.41755 .29828 L
.41757 .29828 L
.4176 .30257 L
.41762 .30257 L
.41764 .30257 L
.41766 .29828 L
.41769 .29398 L
.41771 .29398 L
.41773 .29398 L
.41775 .29398 L
.41778 .29398 L
.4178 .29828 L
.41782 .29828 L
.41784 .29398 L
.41786 .28968 L
.41789 .28968 L
Mistroke
.41791 .29398 L
.41793 .29398 L
.41795 .29398 L
.41798 .29828 L
.418 .29398 L
.41802 .29398 L
.41804 .29398 L
.41807 .29398 L
.41809 .29398 L
.41811 .29398 L
.41813 .29398 L
.41815 .29398 L
.41818 .29398 L
.4182 .29398 L
.41822 .29398 L
.41824 .29398 L
.41827 .29398 L
.41829 .29398 L
.41831 .29398 L
.41833 .29398 L
.41836 .29398 L
.41838 .29398 L
.4184 .29398 L
.41842 .29828 L
.41844 .29828 L
.41847 .30257 L
.41849 .29828 L
.41851 .29828 L
.41853 .29828 L
.41856 .29828 L
.41858 .29828 L
.4186 .30257 L
.41862 .30257 L
.41865 .30257 L
.41867 .29828 L
.41869 .30257 L
.41871 .29828 L
.41874 .29828 L
.41876 .29828 L
.41878 .30257 L
.4188 .29828 L
.41882 .29828 L
.41885 .29398 L
.41887 .29398 L
.41889 .29398 L
.41891 .29398 L
.41894 .29398 L
.41896 .29398 L
.41898 .28968 L
.419 .28968 L
Mistroke
.41903 .28968 L
.41905 .29398 L
.41907 .29398 L
.41909 .29398 L
.41911 .28968 L
.41914 .28968 L
.41916 .28968 L
.41918 .28968 L
.4192 .29398 L
.41923 .29398 L
.41925 .29398 L
.41927 .28968 L
.41929 .28968 L
.41932 .28968 L
.41934 .29398 L
.41936 .29398 L
.41938 .29398 L
.4194 .28968 L
.41943 .28539 L
.41945 .28968 L
.41947 .28968 L
.41949 .29398 L
.41952 .29828 L
.41954 .29398 L
.41956 .28968 L
.41958 .28539 L
.41961 .28968 L
.41963 .29398 L
.41965 .29828 L
.41967 .29828 L
.4197 .29828 L
.41972 .29398 L
.41974 .29398 L
.41976 .29828 L
.41978 .30257 L
.41981 .30687 L
.41983 .30687 L
.41985 .30257 L
.41987 .29828 L
.4199 .29398 L
.41992 .29398 L
.41994 .30257 L
.41996 .30687 L
.41999 .30687 L
.42001 .30257 L
.42003 .29828 L
.42005 .28968 L
.42007 .28539 L
.4201 .28968 L
.42012 .29398 L
Mistroke
.42014 .29828 L
.42016 .29828 L
.42019 .28968 L
.42021 .28539 L
.42023 .28539 L
.42025 .28968 L
.42028 .29398 L
.4203 .29398 L
.42032 .29398 L
.42034 .28968 L
.42037 .28968 L
.42039 .28968 L
.42041 .29398 L
.42043 .29398 L
.42045 .29398 L
.42048 .29398 L
.4205 .28968 L
.42052 .28968 L
.42054 .28968 L
.42057 .28968 L
.42059 .28968 L
.42061 .29398 L
.42063 .28968 L
.42066 .29398 L
.42068 .28968 L
.4207 .28968 L
.42072 .29398 L
.42074 .29398 L
.42077 .28968 L
.42079 .29398 L
.42081 .29398 L
.42083 .29398 L
.42086 .29398 L
.42088 .29828 L
.4209 .29828 L
.42092 .29828 L
.42095 .29828 L
.42097 .30257 L
.42099 .30257 L
.42101 .30687 L
.42103 .30687 L
.42106 .30257 L
.42108 .30257 L
.4211 .30257 L
.42112 .30257 L
.42115 .30257 L
.42117 .30257 L
.42119 .30257 L
.42121 .30257 L
.42124 .29828 L
Mistroke
.42126 .29828 L
.42128 .29398 L
.4213 .29828 L
.42133 .29828 L
.42135 .29828 L
.42137 .29828 L
.42139 .29398 L
.42141 .28968 L
.42144 .28968 L
.42146 .29398 L
.42148 .29398 L
.4215 .29828 L
.42153 .29398 L
.42155 .28968 L
.42157 .28968 L
.42159 .29398 L
.42162 .29398 L
.42164 .29398 L
.42166 .29828 L
.42168 .28968 L
.4217 .28968 L
.42173 .28968 L
.42175 .28968 L
.42177 .29398 L
.42179 .29398 L
.42182 .29398 L
.42184 .28968 L
.42186 .28968 L
.42188 .28539 L
.42191 .29398 L
.42193 .29828 L
.42195 .28539 L
.42197 .29828 L
.422 .29398 L
.42202 .28109 L
.42204 .31117 L
.42206 .28109 L
.42208 .29828 L
.42211 .31117 L
.42213 .28539 L
.42215 .30687 L
.42217 .30257 L
.4222 .28968 L
.42222 .30687 L
.42224 .30687 L
.42226 .29398 L
.42229 .31117 L
.42231 .31546 L
.42233 .31546 L
.42235 .28968 L
Mistroke
.42237 .30257 L
.4224 .31117 L
.42242 .28968 L
.42244 .30687 L
.42246 .30687 L
.42249 .29398 L
.42251 .30687 L
.42253 .29398 L
.42255 .28968 L
.42258 .30257 L
.4226 .29828 L
.42262 .28968 L
.42264 .30687 L
.42266 .29828 L
.42269 .28968 L
.42271 .28968 L
.42273 .29828 L
.42275 .28539 L
.42278 .30687 L
.4228 .28539 L
.42282 .29828 L
.42284 .31117 L
.42287 .25961 L
.42289 .32405 L
.42291 .28109 L
.42293 .2725 L
.42296 .33694 L
.42298 .26391 L
.423 .28109 L
.42302 .31976 L
.42304 .2725 L
.42307 .28539 L
.42309 .32405 L
.42311 .29398 L
.42313 .26391 L
.42316 .30257 L
.42318 .28968 L
.4232 .2682 L
.42322 .31117 L
.42325 .29828 L
.42327 .28109 L
.42329 .30257 L
.42331 .28539 L
.42333 .29398 L
.42336 .30257 L
.42338 .28539 L
.4234 .30687 L
.42342 .30257 L
.42345 .29828 L
.42347 .30257 L
Mistroke
.42349 .28109 L
.42351 .33694 L
.42354 .30257 L
.42356 .25961 L
.42358 .33265 L
.4236 .31546 L
.42363 .28539 L
.42365 .31117 L
.42367 .31976 L
.42369 .2682 L
.42371 .29398 L
.42374 .31117 L
.42376 .28539 L
.42378 .31976 L
.4238 .30687 L
.42383 .26391 L
.42385 .29828 L
.42387 .29828 L
.42389 .27679 L
.42392 .31117 L
.42394 .30257 L
.42396 .28968 L
.42398 .28968 L
.424 .28539 L
.42403 .28539 L
.42405 .29828 L
.42407 .29828 L
.42409 .29828 L
.42412 .28109 L
.42414 .29398 L
.42416 .29828 L
.42418 .29398 L
.42421 .27679 L
.42423 .29398 L
.42425 .30687 L
.42427 .27679 L
.42429 .28109 L
.42432 .28968 L
.42434 .27679 L
.42436 .29828 L
.42438 .30257 L
.42441 .26391 L
.42443 .29398 L
.42445 .29828 L
.42447 .2725 L
.4245 .28968 L
.42452 .29828 L
.42454 .29398 L
.42456 .29398 L
.42459 .29398 L
Mistroke
.42461 .29828 L
.42463 .30257 L
.42465 .28539 L
.42467 .28968 L
.4247 .28968 L
.42472 .32835 L
.42474 .29398 L
.42476 .29828 L
.42479 .29398 L
.42481 .30687 L
.42483 .31976 L
.42485 .30257 L
.42488 .28109 L
.4249 .29398 L
.42492 .34124 L
.42494 .28539 L
.42496 .27679 L
.42499 .30687 L
.42501 .28968 L
.42503 .30257 L
.42505 .30687 L
.42508 .28968 L
.4251 .28968 L
.42512 .29398 L
.42514 .27679 L
.42517 .28539 L
.42519 .32835 L
.42521 .27679 L
.42523 .30687 L
.42526 .30687 L
.42528 .2682 L
.4253 .29398 L
.42532 .28109 L
.42534 .28109 L
.42537 .31117 L
.42539 .28109 L
.42541 .2725 L
.42543 .31117 L
.42546 .27679 L
.42548 .29398 L
.4255 .30257 L
.42552 .2725 L
.42555 .31117 L
.42557 .28968 L
.42559 .29398 L
.42561 .31117 L
.42563 .2725 L
.42566 .30257 L
.42568 .30257 L
.4257 .2682 L
Mistroke
.42572 .29398 L
.42575 .29398 L
.42577 .28968 L
.42579 .29398 L
.42581 .29398 L
.42584 .28968 L
.42586 .30257 L
.42588 .28539 L
.4259 .30687 L
.42592 .31546 L
.42595 .27679 L
.42597 .30687 L
.42599 .31117 L
.42601 .28109 L
.42604 .32405 L
.42606 .29828 L
.42608 .28968 L
.4261 .33265 L
.42613 .27679 L
.42615 .30687 L
.42617 .31117 L
.42619 .28109 L
.42622 .30687 L
.42624 .30687 L
.42626 .31546 L
.42628 .29398 L
.4263 .28539 L
.42633 .28968 L
.42635 .29398 L
.42637 .30257 L
.42639 .28109 L
.42642 .30257 L
.42644 .28968 L
.42646 .28539 L
.42648 .31546 L
.42651 .2682 L
.42653 .28968 L
.42655 .30257 L
.42657 .2725 L
.42659 .29828 L
.42662 .28968 L
.42664 .28968 L
.42666 .30687 L
.42668 .28968 L
.42671 .30257 L
.42673 .27679 L
.42675 .28539 L
.42677 .29828 L
.4268 .2725 L
.42682 .28968 L
Mistroke
.42684 .28539 L
.42686 .28968 L
.42689 .30687 L
.42691 .2682 L
.42693 .29828 L
.42695 .29398 L
.42697 .2682 L
.427 .30687 L
.42702 .29828 L
.42704 .28109 L
.42706 .28109 L
.42709 .29828 L
.42711 .33694 L
.42713 .27679 L
.42715 .28109 L
.42718 .31976 L
.4272 .27679 L
.42722 .32405 L
.42724 .32405 L
.42726 .2682 L
.42729 .30257 L
.42731 .31117 L
.42733 .31117 L
.42735 .29828 L
.42738 .31976 L
.4274 .28968 L
.42742 .32835 L
.42744 .29828 L
.42747 .28109 L
.42749 .30687 L
.42751 .29398 L
.42753 .30687 L
.42755 .28968 L
.42758 .31546 L
.4276 .29398 L
.42762 .28968 L
.42764 .30257 L
.42767 .28109 L
.42769 .30687 L
.42771 .28539 L
.42773 .28539 L
.42776 .30687 L
.42778 .28539 L
.4278 .30257 L
.42782 .29828 L
.42785 .27679 L
.42787 .29828 L
.42789 .28539 L
.42791 .29398 L
.42793 .29828 L
Mistroke
.42796 .28539 L
.42798 .29398 L
.428 .30257 L
.42802 .29398 L
.42805 .28539 L
.42807 .28539 L
.42809 .28968 L
.42811 .31546 L
.42814 .29398 L
.42816 .26391 L
.42818 .30687 L
.4282 .28539 L
.42822 .2682 L
.42825 .33694 L
.42827 .29398 L
.42829 .28539 L
.42831 .31546 L
.42834 .28109 L
.42836 .28968 L
.42838 .28539 L
.4284 .28968 L
.42843 .31546 L
.42845 .32835 L
.42847 .31117 L
.42849 .30257 L
.42852 .30257 L
.42854 .29398 L
.42856 .28539 L
.42858 .30687 L
.4286 .29828 L
.42863 .30687 L
.42865 .31546 L
.42867 .28968 L
.42869 .28968 L
.42872 .31976 L
.42874 .29398 L
.42876 .28968 L
.42878 .32835 L
.42881 .28968 L
.42883 .29828 L
.42885 .30687 L
.42887 .29828 L
.42889 .30257 L
.42892 .29398 L
.42894 .29828 L
.42896 .27679 L
.42898 .31546 L
.42901 .27679 L
.42903 .28109 L
.42905 .32835 L
Mistroke
.42907 .2682 L
.4291 .29828 L
.42912 .29828 L
.42914 .28539 L
.42916 .28968 L
.42918 .31117 L
.42921 .30257 L
.42923 .28539 L
.42925 .28968 L
.42927 .27679 L
.4293 .29828 L
.42932 .29828 L
.42934 .28968 L
.42936 .30687 L
.42939 .27679 L
.42941 .28539 L
.42943 .28539 L
.42945 .31117 L
.42948 .28539 L
.4295 .28539 L
.42952 .29398 L
.42954 .31117 L
.42956 .28539 L
.42959 .28968 L
.42961 .31546 L
.42963 .28109 L
.42965 .30687 L
.42968 .30687 L
.4297 .28539 L
.42972 .30687 L
.42974 .29398 L
.42977 .28968 L
.42979 .32405 L
.42981 .30257 L
.42983 .28968 L
.42985 .32405 L
.42988 .30257 L
.4299 .29398 L
.42992 .30257 L
.42994 .29398 L
.42997 .30687 L
.42999 .31117 L
.43001 .29398 L
.43003 .28539 L
.43006 .29828 L
.43008 .28539 L
.4301 .30687 L
.43012 .29828 L
.43015 .30257 L
.43017 .28109 L
Mistroke
.43019 .28539 L
.43021 .30257 L
.43023 .28539 L
.43026 .28968 L
.43028 .29828 L
.4303 .30257 L
.43032 .26391 L
.43035 .29398 L
.43037 .30687 L
.43039 .2725 L
.43041 .31117 L
.43044 .29828 L
.43046 .28109 L
.43048 .2725 L
.4305 .27679 L
.43052 .32405 L
.43055 .25961 L
.43057 .29828 L
.43059 .28968 L
.43061 .25531 L
.43064 .29828 L
.43066 .28109 L
.43068 .28539 L
.4307 .27679 L
.43073 .32835 L
.43075 .2725 L
.43077 .28539 L
.43079 .30687 L
.43081 .28539 L
.43084 .30257 L
.43086 .31117 L
.43088 .29398 L
.4309 .28968 L
.43093 .28539 L
.43095 .30687 L
.43097 .32405 L
.43099 .27679 L
.43102 .31117 L
.43104 .32405 L
.43106 .2682 L
.43108 .30257 L
.43111 .29398 L
.43113 .31117 L
.43115 .31117 L
.43117 .29828 L
.43119 .30257 L
.43122 .30257 L
.43124 .28968 L
.43126 .28109 L
.43128 .30687 L
Mistroke
.43131 .31546 L
.43133 .28968 L
.43135 .28968 L
.43137 .30257 L
.4314 .27679 L
.43142 .28968 L
.43144 .30687 L
.43146 .28539 L
.43148 .29828 L
.43151 .29828 L
.43153 .29398 L
.43155 .28968 L
.43157 .28968 L
.4316 .30257 L
.43162 .28539 L
.43164 .28109 L
.43166 .29398 L
.43169 .29398 L
.43171 .29828 L
.43173 .29398 L
.43175 .29828 L
.43178 .28539 L
.4318 .28539 L
.43182 .28539 L
.43184 .28539 L
.43186 .28968 L
.43189 .30257 L
.43191 .28109 L
.43193 .29828 L
.43195 .28109 L
.43198 .2725 L
.432 .30687 L
.43202 .28968 L
.43204 .28109 L
.43207 .29828 L
.43209 .30257 L
.43211 .29398 L
.43213 .29828 L
.43215 .30257 L
.43218 .30257 L
.4322 .30257 L
.43222 .2725 L
.43224 .31117 L
.43227 .32405 L
.43229 .2682 L
.43231 .31546 L
.43233 .34124 L
.43236 .2725 L
.43238 .34124 L
.4324 .31546 L
Mistroke
.43242 .28968 L
.43244 .31117 L
.43247 .28109 L
.43249 .31546 L
.43251 .2725 L
.43253 .28968 L
.43256 .28968 L
.43258 .28109 L
.4326 .29398 L
.43262 .2725 L
.43265 .28539 L
.43267 .28109 L
.43269 .30257 L
.43271 .28109 L
.43274 .29828 L
.43276 .30257 L
.43278 .30257 L
.4328 .28968 L
.43282 .28968 L
.43285 .31976 L
.43287 .27679 L
.43289 .30257 L
.43291 .31546 L
.43294 .2725 L
.43296 .28109 L
.43298 .32405 L
.433 .28539 L
.43303 .26391 L
.43305 .31976 L
.43307 .29828 L
.43309 .25102 L
.43311 .29398 L
.43314 .31546 L
.43316 .28109 L
.43318 .28968 L
.4332 .29828 L
.43323 .28539 L
.43325 .28968 L
.43327 .29398 L
.43329 .28539 L
.43332 .31546 L
.43334 .31117 L
.43336 .2682 L
.43338 .30687 L
.43341 .31976 L
.43343 .27679 L
.43345 .30687 L
.43347 .31976 L
.43349 .29398 L
.43352 .29828 L
Mistroke
.43354 .28968 L
.43356 .31546 L
.43358 .30257 L
.43361 .28968 L
.43363 .31546 L
.43365 .29398 L
.43367 .29828 L
.4337 .28968 L
.43372 .29398 L
.43374 .31117 L
.43376 .28539 L
.43378 .30257 L
.43381 .30687 L
.43383 .2682 L
.43385 .32405 L
.43387 .29398 L
.4339 .27679 L
.43392 .31117 L
.43394 .28968 L
.43396 .28968 L
.43399 .29398 L
.43401 .29828 L
.43403 .29398 L
.43405 .27679 L
.43407 .29398 L
.4341 .29398 L
.43412 .28109 L
.43414 .29828 L
.43416 .29828 L
.43419 .28968 L
.43421 .28539 L
.43423 .27679 L
.43425 .29398 L
.43428 .28539 L
.4343 .28539 L
.43432 .30687 L
.43434 .28539 L
.43437 .28539 L
.43439 .29398 L
.43441 .29828 L
.43443 .28539 L
.43445 .28968 L
.43448 .31117 L
.4345 .28109 L
.43452 .27679 L
.43454 .31546 L
.43457 .29828 L
.43459 .28968 L
.43461 .31117 L
.43463 .30687 L
Mistroke
.43466 .30257 L
.43468 .30257 L
.4347 .30257 L
.43472 .30257 L
.43474 .30687 L
.43477 .30687 L
.43479 .29398 L
.43481 .31976 L
.43483 .29828 L
.43486 .28968 L
.43488 .32835 L
.4349 .30257 L
.43492 .28109 L
.43495 .29828 L
.43497 .32405 L
.43499 .28539 L
.43501 .28968 L
.43503 .30257 L
.43506 .29828 L
.43508 .28968 L
.4351 .28968 L
.43512 .29398 L
.43515 .28968 L
.43517 .31546 L
.43519 .2725 L
.43521 .30257 L
.43524 .29828 L
.43526 .28539 L
.43528 .29828 L
.4353 .29398 L
.43533 .31117 L
.43535 .2725 L
.43537 .27679 L
.43539 .32405 L
.43541 .27679 L
.43544 .26391 L
.43546 .32405 L
.43548 .29828 L
.4355 .2682 L
.43553 .28968 L
.43555 .31117 L
.43557 .28539 L
.43559 .28539 L
.43562 .30257 L
.43564 .28968 L
.43566 .2725 L
.43568 .30257 L
.4357 .29398 L
.43573 .28109 L
.43575 .30257 L
Mistroke
.43577 .29828 L
.43579 .28968 L
.43582 .29828 L
.43584 .28539 L
.43586 .29398 L
.43588 .31546 L
.43591 .31117 L
.43593 .27679 L
.43595 .30687 L
.43597 .32835 L
.436 .27679 L
.43602 .29828 L
.43604 .32835 L
.43606 .29398 L
.43608 .28539 L
.43611 .30257 L
.43613 .30687 L
.43615 .28968 L
.43617 .30257 L
.4362 .31117 L
.43622 .28968 L
.43624 .30257 L
.43626 .29828 L
.43629 .28968 L
.43631 .30687 L
.43633 .30687 L
.43635 .28539 L
.43637 .29398 L
.4364 .30257 L
.43642 .28539 L
.43644 .29828 L
.43646 .29398 L
.43649 .27679 L
.43651 .28968 L
.43653 .28968 L
.43655 .29398 L
.43658 .2725 L
.4366 .2682 L
.43662 .30687 L
.43664 .28539 L
.43666 .25961 L
.43669 .29828 L
.43671 .26391 L
.43673 .28539 L
.43675 .29828 L
.43678 .2682 L
.4368 .2725 L
.43682 .29398 L
.43684 .30257 L
.43687 .28109 L
Mistroke
.43689 .29398 L
.43691 .31976 L
.43693 .32405 L
.43696 .30257 L
.43698 .31117 L
.437 .33694 L
.43702 .31976 L
.43704 .31117 L
.43707 .29828 L
.43709 .31976 L
.43711 .30257 L
.43713 .2725 L
.43716 .29828 L
.43718 .29828 L
.4372 .28539 L
.43722 .2725 L
.43725 .28968 L
.43727 .28109 L
.43729 .26391 L
.43731 .2725 L
.43733 .27679 L
.43736 .28968 L
.43738 .28109 L
.4374 .28109 L
.43742 .29398 L
.43745 .29828 L
.43747 .29398 L
.43749 .30257 L
.43751 .31976 L
.43754 .30687 L
.43756 .31117 L
.43758 .33265 L
.4376 .32835 L
.43763 .33265 L
.43765 .34983 L
.43767 .32835 L
.43769 .30687 L
.43771 .31976 L
.43774 .30257 L
.43776 .27679 L
.43778 .28539 L
.4378 .28539 L
.43783 .25961 L
.43785 .24672 L
.43787 .26391 L
.43789 .26391 L
.43792 .24672 L
.43794 .25102 L
.43796 .26391 L
.43798 .25961 L
Mistroke
.438 .25102 L
.43803 .26391 L
.43805 .29828 L
.43807 .31117 L
.43809 .2682 L
.43812 .29398 L
.43814 .35413 L
.43816 .31117 L
.43818 .29398 L
.43821 .36702 L
.43823 .35843 L
.43825 .31546 L
.43827 .33265 L
.43829 .37561 L
.43832 .34124 L
.43834 .30687 L
.43836 .32405 L
.43838 .32405 L
.43841 .2725 L
.43843 .25961 L
.43845 .28539 L
.43847 .28109 L
.4385 .25102 L
.43852 .25102 L
.43854 .27679 L
.43856 .25531 L
.43859 .23813 L
.43861 .26391 L
.43863 .28109 L
.43865 .26391 L
.43867 .2725 L
.4387 .31546 L
.43872 .30257 L
.43874 .29398 L
.43876 .34124 L
.43879 .34124 L
.43881 .31976 L
.43883 .35413 L
.43885 .36272 L
.43888 .31976 L
.4389 .31976 L
.43892 .33265 L
.43894 .37991 L
.43896 .33265 L
.43899 .28968 L
.43901 .32405 L
.43903 .30687 L
.43905 .23813 L
.43908 .24672 L
.4391 .28109 L
Mistroke
.43912 .24672 L
.43914 .22094 L
.43917 .24242 L
.43919 .25102 L
.43921 .23383 L
.43923 .23383 L
.43926 .25102 L
.43928 .24672 L
.4393 .26391 L
.43932 .29828 L
.43934 .28539 L
.43937 .28968 L
.43939 .34124 L
.43941 .34983 L
.43943 .30687 L
.43946 .34983 L
.43948 .40569 L
.4395 .33694 L
.43952 .31546 L
.43955 .3928 L
.43957 .37561 L
.43959 .30257 L
.43961 .31117 L
.43963 .33694 L
.43966 .28968 L
.43968 .23813 L
.4397 .25961 L
.43972 .27679 L
.43975 .24242 L
.43977 .22094 L
.43979 .25102 L
.43981 .26391 L
.43984 .22524 L
.43986 .22953 L
.43988 .26391 L
.4399 .25961 L
.43992 .28968 L
.43995 .31546 L
.43997 .29398 L
.43999 .31546 L
.44001 .36702 L
.44004 .34983 L
.44006 .32835 L
.44008 .3842 L
.4401 .3842 L
.44013 .32405 L
.44015 .34554 L
.44017 .37131 L
.44019 .32835 L
.44022 .28968 L
Mistroke
.44024 .29828 L
.44026 .28968 L
.44028 .24242 L
.4403 .22953 L
.44033 .23383 L
.44035 .23813 L
.44037 .22524 L
.44039 .21664 L
.44042 .24242 L
.44044 .23813 L
.44046 .21664 L
.44048 .24672 L
.44051 .25102 L
.44053 .2725 L
.44055 .33265 L
.44057 .28539 L
.44059 .29398 L
.44062 .3842 L
.44064 .37561 L
.44066 .32405 L
.44068 .36702 L
.44071 .41428 L
.44073 .35413 L
.44075 .31976 L
.44077 .37561 L
.4408 .37131 L
.44082 .28968 L
.44084 .28968 L
.44086 .31117 L
.44089 .25961 L
.44091 .22094 L
.44093 .23813 L
.44095 .24672 L
.44097 .23813 L
.441 .22524 L
.44102 .23813 L
.44104 .24672 L
.44106 .23813 L
.44109 .23813 L
.44111 .25102 L
.44113 .32405 L
.44115 .34554 L
.44118 .24672 L
.4412 .32835 L
.44122 .42717 L
.44124 .42717 L
.44126 .36272 L
.44129 .30687 L
.44131 .39709 L
.44133 .42287 L
Mistroke
.44135 .32405 L
.44138 .31117 L
.4414 .3928 L
.44142 .34554 L
.44144 .25531 L
.44147 .2725 L
.44149 .29398 L
.44151 .23383 L
.44153 .19516 L
.44155 .22094 L
.44158 .23813 L
.4416 .21664 L
.44162 .19516 L
.44164 .23383 L
.44167 .24672 L
.44169 .22953 L
.44171 .23383 L
.44173 .26391 L
.44176 .34983 L
.44178 .30257 L
.4418 .25531 L
.44182 .3842 L
.44185 .41428 L
.44187 .33265 L
.44189 .33694 L
.44191 .43576 L
.44193 .3928 L
.44196 .29828 L
.44198 .35843 L
.442 .39709 L
.44202 .30257 L
.44205 .25961 L
.44207 .30257 L
.44209 .28109 L
.44211 .20805 L
.44214 .21235 L
.44216 .24242 L
.44218 .24242 L
.4422 .21664 L
.44222 .22094 L
.44225 .25102 L
.44227 .24672 L
.44229 .23383 L
.44231 .25102 L
.44234 .34124 L
.44236 .33694 L
.44238 .26391 L
.4424 .35843 L
.44243 .42287 L
.44245 .35843 L
Mistroke
.44247 .33265 L
.44249 .42717 L
.44252 .40998 L
.44254 .30257 L
.44256 .35843 L
.44258 .3928 L
.4426 .29828 L
.44263 .28539 L
.44265 .29398 L
.44267 .2682 L
.44269 .22953 L
.44272 .20805 L
.44274 .21664 L
.44276 .22094 L
.44278 .22094 L
.44281 .20376 L
.44283 .22524 L
.44285 .24672 L
.44287 .23383 L
.44289 .22953 L
.44292 .2725 L
.44294 .35413 L
.44296 .28968 L
.44298 .28968 L
.44301 .40569 L
.44303 .39709 L
.44305 .33265 L
.44307 .37991 L
.4431 .41428 L
.44312 .35843 L
.44314 .33694 L
.44316 .37561 L
.44318 .33694 L
.44321 .30687 L
.44323 .29828 L
.44325 .26391 L
.44327 .25961 L
.4433 .24242 L
.44332 .21235 L
.44334 .22094 L
.44336 .23813 L
.44339 .22524 L
.44341 .21664 L
.44343 .24242 L
.44345 .25102 L
.44348 .25102 L
.4435 .22953 L
.44352 .36702 L
.44354 .35843 L
.44356 .22953 L
Mistroke
.44359 .37991 L
.44361 .37991 L
.44363 .44435 L
.44365 .34124 L
.44368 .33694 L
.4437 .44006 L
.44372 .40569 L
.44374 .30687 L
.44377 .34554 L
.44379 .3842 L
.44381 .30257 L
.44383 .28968 L
.44385 .2682 L
.44388 .25531 L
.4439 .24242 L
.44392 .20376 L
.44394 .19087 L
.44397 .23813 L
.44399 .23383 L
.44401 .19087 L
.44403 .21235 L
.44406 .25102 L
.44408 .25102 L
.4441 .21235 L
.44412 .32405 L
.44415 .3842 L
.44417 .24242 L
.44419 .32835 L
.44421 .43146 L
.44423 .36702 L
.44426 .31546 L
.44428 .40998 L
.4443 .40998 L
.44432 .30687 L
.44435 .33694 L
.44437 .36272 L
.44439 .29398 L
.44441 .29828 L
.44444 .26391 L
.44446 .24242 L
.44448 .25531 L
.4445 .22524 L
.44452 .18657 L
.44455 .23383 L
.44457 .25102 L
.44459 .21235 L
.44461 .20805 L
.44464 .25531 L
.44466 .26391 L
.44468 .22953 L
Mistroke
.4447 .33265 L
.44473 .37131 L
.44475 .25961 L
.44477 .34983 L
.44479 .44435 L
.44481 .35413 L
.44484 .31546 L
.44486 .43576 L
.44488 .40139 L
.4449 .29398 L
.44493 .34124 L
.44495 .37561 L
.44497 .28539 L
.44499 .28539 L
.44502 .28539 L
.44504 .24242 L
.44506 .24242 L
.44508 .23383 L
.44511 .18657 L
.44513 .22953 L
.44515 .25102 L
.44517 .21664 L
.44519 .20376 L
.44522 .24672 L
.44524 .26391 L
.44526 .22524 L
.44528 .34124 L
.44531 .37131 L
.44533 .23813 L
.44535 .34554 L
.44537 .44006 L
.4454 .34983 L
.44542 .29398 L
.44544 .43146 L
.44546 .41857 L
.44548 .26391 L
.44551 .32405 L
.44553 .3842 L
.44555 .2682 L
.44557 .2725 L
.4456 .28109 L
.44562 .24672 L
.44564 .24672 L
.44566 .23813 L
.44569 .19087 L
.44571 .23383 L
.44573 .26391 L
.44575 .23383 L
.44578 .21235 L
.4458 .25102 L
Mistroke
.44582 .27679 L
.44584 .24672 L
.44586 .36702 L
.44589 .34124 L
.44591 .26391 L
.44593 .39709 L
.44595 .43146 L
.44598 .43146 L
.446 .33265 L
.44602 .30687 L
.44604 .44435 L
.44607 .40139 L
.44609 .25961 L
.44611 .32835 L
.44613 .37991 L
.44615 .28109 L
.44618 .26391 L
.4462 .27679 L
.44622 .25531 L
.44624 .25961 L
.44627 .24242 L
.44629 .19087 L
.44631 .24672 L
.44633 .27679 L
.44636 .22953 L
.44638 .19946 L
.4464 .26391 L
.44642 .26391 L
.44644 .2682 L
.44647 .3842 L
.44649 .28968 L
.44651 .2725 L
.44653 .41857 L
.44656 .40139 L
.44658 .28539 L
.4466 .31976 L
.44662 .45295 L
.44665 .36272 L
.44667 .23813 L
.44669 .33265 L
.44671 .35843 L
.44674 .2682 L
.44676 .25961 L
.44678 .25961 L
.4468 .25531 L
.44682 .26391 L
.44685 .22094 L
.44687 .18657 L
.44689 .25961 L
.44691 .28539 L
Mistroke
.44694 .22524 L
.44696 .20376 L
.44698 .2725 L
.447 .2682 L
.44703 .27679 L
.44705 .39709 L
.44707 .28968 L
.44709 .28539 L
.44711 .43576 L
.44714 .40569 L
.44716 .28109 L
.44718 .34124 L
.4472 .45724 L
.44723 .35843 L
.44725 .23813 L
.44727 .34124 L
.44729 .35843 L
.44732 .2682 L
.44734 .2682 L
.44736 .26391 L
.44738 .25961 L
.44741 .27679 L
.44743 .22953 L
.44745 .19516 L
.44747 .2682 L
.44749 .28968 L
.44752 .22953 L
.44754 .21235 L
.44756 .2725 L
.44758 .26391 L
.44761 .28968 L
.44763 .40569 L
.44765 .25102 L
.44767 .28539 L
.4477 .44865 L
.44772 .3842 L
.44774 .24672 L
.44776 .34124 L
.44778 .44865 L
.44781 .32835 L
.44783 .23383 L
.44785 .32835 L
.44787 .34124 L
.4479 .2682 L
.44792 .24672 L
.44794 .25102 L
.44796 .25961 L
.44799 .2725 L
.44801 .22094 L
.44803 .19516 L
Mistroke
.44805 .2682 L
.44807 .29398 L
.4481 .22094 L
.44812 .20805 L
.44814 .27679 L
.44816 .26391 L
.44819 .31117 L
.44821 .40569 L
.44823 .24672 L
.44825 .29398 L
.44828 .46154 L
.4483 .3885 L
.44832 .24672 L
.44834 .24672 L
.44837 .35413 L
.44839 .46583 L
.44841 .32405 L
.44843 .24242 L
.44845 .34124 L
.44848 .34124 L
.4485 .2725 L
.44852 .26391 L
.44854 .25531 L
.44857 .2725 L
.44859 .28968 L
.44861 .22953 L
.44863 .20376 L
.44866 .28539 L
.44868 .30257 L
.4487 .24242 L
.44872 .22094 L
.44874 .28109 L
.44877 .2682 L
.44879 .27679 L
.44881 .42287 L
.44883 .27679 L
.44886 .24242 L
.44888 .45295 L
.4489 .40998 L
.44892 .24242 L
.44895 .30687 L
.44897 .46154 L
.44899 .35413 L
.44901 .25531 L
.44904 .29398 L
.44906 .32405 L
.44908 .28968 L
.4491 .2682 L
.44912 .21664 L
.44915 .25961 L
Mistroke
.44917 .29398 L
.44919 .24672 L
.44921 .17368 L
.44924 .25961 L
.44926 .30257 L
.44928 .26391 L
.4493 .21664 L
.44933 .25531 L
.44935 .2682 L
.44937 .25102 L
.44939 .41428 L
.44941 .33694 L
.44944 .17798 L
.44946 .42287 L
.44948 .46154 L
.4495 .26391 L
.44953 .24242 L
.44955 .45295 L
.44957 .39709 L
.44959 .26391 L
.44962 .30687 L
.44964 .32405 L
.44966 .28539 L
.44968 .30257 L
.4497 .22953 L
.44973 .24672 L
.44975 .30687 L
.44977 .29828 L
.44979 .18227 L
.44982 .24242 L
.44984 .31546 L
.44986 .29398 L
.44988 .23383 L
.44991 .24242 L
.44993 .28539 L
.44995 .25102 L
.44997 .31117 L
.45 .44435 L
.45002 .19087 L
.45004 .28968 L
.45006 .48732 L
.45008 .34554 L
.45011 .21664 L
.45013 .37131 L
.45015 .43576 L
.45017 .29398 L
.4502 .27679 L
.45022 .33265 L
.45024 .25531 L
.45026 .30257 L
Mistroke
.45029 .2682 L
.45031 .20376 L
.45033 .25531 L
.45035 .31976 L
.45037 .22094 L
.4504 .19516 L
.45042 .28968 L
.45044 .30257 L
.45046 .24672 L
.45049 .23813 L
.45051 .25531 L
.45053 .27679 L
.45055 .22953 L
.45058 .40139 L
.4506 .34983 L
.45062 .1565 L
.45064 .40569 L
.45067 .44435 L
.45069 .28109 L
.45071 .28109 L
.45073 .26391 L
.45075 .40998 L
.45078 .3842 L
.4508 .29398 L
.45082 .31976 L
.45084 .30687 L
.45087 .25102 L
.45089 .33265 L
.45091 .24672 L
.45093 .21235 L
.45096 .28539 L
.45098 .32835 L
.451 .21235 L
.45102 .23813 L
.45104 .30257 L
.45107 .30257 L
.45109 .26391 L
.45111 .25531 L
.45113 .24672 L
.45116 .29398 L
.45118 .25102 L
.4512 .42287 L
.45122 .30257 L
.45125 .19087 L
.45127 .43146 L
.45129 .41428 L
.45131 .2725 L
.45133 .29828 L
.45136 .40569 L
.45138 .36702 L
Mistroke
.4514 .29828 L
.45142 .31117 L
.45145 .2682 L
.45147 .26391 L
.45149 .32405 L
.45151 .22094 L
.45154 .21235 L
.45156 .28109 L
.45158 .30687 L
.4516 .21235 L
.45163 .24672 L
.45165 .29398 L
.45167 .29828 L
.45169 .2725 L
.45171 .24672 L
.45174 .23383 L
.45176 .28539 L
.45178 .25961 L
.4518 .43146 L
.45183 .25961 L
.45185 .20805 L
.45187 .44006 L
.45189 .40569 L
.45192 .2682 L
.45194 .30257 L
.45196 .40569 L
.45198 .37561 L
.452 .31117 L
.45203 .31546 L
.45205 .25961 L
.45207 .28968 L
.45209 .32405 L
.45212 .22524 L
.45214 .22094 L
.45216 .30687 L
.45218 .31117 L
.45221 .22524 L
.45223 .26391 L
.45225 .29398 L
.45227 .31546 L
.45229 .28968 L
.45232 .24672 L
.45234 .24672 L
.45236 .30257 L
.45238 .23813 L
.45241 .41857 L
.45243 .30257 L
.45245 .19087 L
.45247 .42717 L
.4525 .41857 L
Mistroke
.45252 .28968 L
.45254 .30687 L
.45256 .3842 L
.45259 .36702 L
.45261 .31546 L
.45263 .31117 L
.45265 .24672 L
.45267 .26391 L
.4527 .32405 L
.45272 .22094 L
.45274 .20376 L
.45276 .28539 L
.45279 .30687 L
.45281 .24242 L
.45283 .25961 L
.45285 .26391 L
.45288 .30687 L
.4529 .29398 L
.45292 .23383 L
.45294 .22953 L
.45296 .31546 L
.45299 .20805 L
.45301 .37131 L
.45303 .37131 L
.45305 .1565 L
.45308 .1565 L
.4531 .37991 L
.45312 .44006 L
.45314 .31546 L
.45317 .29398 L
.45319 .36702 L
.45321 .36702 L
.45323 .32405 L
.45326 .32405 L
.45328 .26391 L
.4533 .23813 L
.45332 .33265 L
.45334 .24242 L
.45337 .22094 L
.45339 .27679 L
.45341 .31546 L
.45343 .26391 L
.45346 .28109 L
.45348 .26391 L
.4535 .30687 L
.45352 .30687 L
.45355 .25961 L
.45357 .22524 L
.45359 .30257 L
.45361 .21664 L
Mistroke
.45363 .33694 L
.45366 .41857 L
.45368 .17368 L
.4537 .32835 L
.45372 .45295 L
.45375 .33694 L
.45377 .29398 L
.45379 .35843 L
.45381 .36272 L
.45384 .33265 L
.45386 .32835 L
.45388 .25961 L
.4539 .20376 L
.45392 .31546 L
.45395 .26391 L
.45397 .22094 L
.45399 .25102 L
.45401 .29398 L
.45404 .2725 L
.45406 .28968 L
.45408 .25961 L
.4541 .27679 L
.45413 .31546 L
.45415 .27679 L
.45417 .22524 L
.45419 .2682 L
.45422 .22524 L
.45424 .25961 L
.45426 .45724 L
.45428 .22524 L
.4543 .24242 L
.45433 .44435 L
.45435 .37131 L
.45437 .30687 L
.45439 .35413 L
.45442 .34983 L
.45444 .33694 L
.45446 .36272 L
.45448 .31117 L
.45451 .19516 L
.45453 .28539 L
.45455 .30257 L
.45457 .23813 L
.45459 .25531 L
.45462 .28109 L
.45464 .28539 L
.45466 .30257 L
.45468 .28539 L
.45471 .25961 L
.45473 .31546 L
Mistroke
.45475 .29828 L
.45477 .24242 L
.4548 .25531 L
.45482 .25961 L
.45484 .19946 L
.45486 .42287 L
.45489 .34983 L
.45491 .18227 L
.45493 .3885 L
.45495 .40569 L
.45497 .32835 L
.455 .35413 L
.45502 .34554 L
.45504 .31546 L
.45506 .35843 L
.45509 .34124 L
.45511 .21664 L
.45513 .22524 L
.45515 .29398 L
.45518 .23813 L
.4552 .25961 L
.45522 .26391 L
.45524 .26391 L
.45526 .28109 L
.45529 .31117 L
.45531 .25531 L
.45533 .29398 L
.45535 .29828 L
.45538 .24672 L
.4554 .24242 L
.45542 .28109 L
.45544 .28109 L
.45547 .19516 L
.45549 .29398 L
.45551 .44865 L
.45553 .20805 L
.45555 .28968 L
.45558 .43146 L
.4556 .34554 L
.45562 .35413 L
.45564 .37991 L
.45567 .31546 L
.45569 .32835 L
.45571 .35843 L
.45573 .28539 L
.45576 .20376 L
.45578 .28109 L
.4558 .25961 L
.45582 .26391 L
.45585 .28539 L
Mistroke
.45587 .2682 L
.45589 .2725 L
.45591 .31117 L
.45593 .29398 L
.45596 .29398 L
.45598 .30257 L
.456 .25531 L
.45602 .24672 L
.45605 .2725 L
.45607 .25102 L
.45609 .20376 L
.45611 .42287 L
.45614 .32405 L
.45616 .21235 L
.45618 .41428 L
.4562 .35843 L
.45622 .33694 L
.45625 .40139 L
.45627 .32835 L
.45629 .29828 L
.45631 .34554 L
.45634 .31117 L
.45636 .22094 L
.45638 .23813 L
.4564 .25961 L
.45643 .22524 L
.45645 .28539 L
.45647 .27679 L
.45649 .2725 L
.45652 .2725 L
.45654 .29828 L
.45656 .28539 L
.45658 .30257 L
.4566 .2682 L
.45663 .24242 L
.45665 .24242 L
.45667 .26391 L
.45669 .19087 L
.45672 .34983 L
.45674 .3885 L
.45676 .20376 L
.45678 .37131 L
.45681 .3928 L
.45683 .32835 L
.45685 .39709 L
.45687 .36272 L
.45689 .28968 L
.45692 .34124 L
.45694 .33694 L
.45696 .25961 L
Mistroke
.45698 .22524 L
.45701 .26391 L
.45703 .22953 L
.45705 .27679 L
.45707 .28539 L
.4571 .28968 L
.45712 .28109 L
.45714 .30687 L
.45716 .28968 L
.45718 .30257 L
.45721 .29398 L
.45723 .25102 L
.45725 .23813 L
.45727 .2725 L
.4573 .23383 L
.45732 .21235 L
.45734 .43576 L
.45736 .28109 L
.45739 .24242 L
.45741 .43146 L
.45743 .33265 L
.45745 .36272 L
.45748 .41428 L
.4575 .29398 L
.45752 .29398 L
.45754 .33694 L
.45756 .28539 L
.45759 .22094 L
.45761 .24242 L
.45763 .22524 L
.45765 .22953 L
.45768 .28968 L
.4577 .28539 L
.45772 .28968 L
.45774 .28109 L
.45777 .28968 L
.45779 .28968 L
.45781 .28968 L
.45783 .30687 L
.45785 .26391 L
.45788 .23383 L
.4579 .24672 L
.45792 .2725 L
.45794 .18227 L
.45797 .36702 L
.45799 .37991 L
.45801 .19516 L
.45803 .40569 L
.45806 .3842 L
.45808 .32835 L
Mistroke
.4581 .42717 L
.45812 .35413 L
.45815 .27679 L
.45817 .34124 L
.45819 .31546 L
.45821 .25102 L
.45823 .24672 L
.45826 .24242 L
.45828 .21664 L
.4583 .29828 L
.45832 .29398 L
.45835 .31546 L
.45837 .29398 L
.45839 .28539 L
.45841 .29398 L
.45844 .31117 L
.45846 .28539 L
.45848 .25531 L
.4585 .23813 L
.45852 .25531 L
.45855 .20376 L
.45857 .27679 L
.45859 .44865 L
.45861 .22953 L
.45864 .31546 L
.45866 .42717 L
.45868 .31546 L
.4587 .40998 L
.45873 .40569 L
.45875 .25961 L
.45877 .31546 L
.45879 .32835 L
.45881 .25102 L
.45884 .24672 L
.45886 .23383 L
.45888 .18227 L
.4589 .27679 L
.45893 .30257 L
.45895 .30257 L
.45897 .32405 L
.45899 .25961 L
.45902 .27679 L
.45904 .31976 L
.45906 .31117 L
.45908 .25961 L
.45911 .24672 L
.45913 .22524 L
.45915 .24242 L
.45917 .21235 L
.45919 .41857 L
Mistroke
.45922 .34124 L
.45924 .21664 L
.45926 .43576 L
.45928 .34554 L
.45931 .35843 L
.45933 .45724 L
.45935 .30687 L
.45937 .2682 L
.4594 .35413 L
.45942 .26391 L
.45944 .25102 L
.45946 .26391 L
.45948 .19946 L
.45951 .23383 L
.45953 .32835 L
.45955 .28539 L
.45957 .35413 L
.4596 .29398 L
.45962 .2682 L
.45964 .30687 L
.45966 .31546 L
.45969 .27679 L
.45971 .2682 L
.45973 .22524 L
.45975 .22953 L
.45978 .19087 L
.4598 .3842 L
.45982 .39709 L
.45984 .22094 L
.45986 .40569 L
.45989 .34983 L
.45991 .32835 L
.45993 .47013 L
.45995 .34124 L
.45998 .25102 L
.46 .34124 L
.46002 .25961 L
.46004 .24242 L
.46007 .27679 L
.46009 .19946 L
.46011 .19087 L
.46013 .32405 L
.46015 .32405 L
.46018 .28539 L
.4602 .36272 L
.46022 .31976 L
.46024 .22953 L
.46027 .28109 L
.46029 .31546 L
.46031 .29828 L
Mistroke
.46033 .28539 L
.46036 .21664 L
.46038 .22094 L
.4604 .19087 L
.46042 .29828 L
.46044 .46154 L
.46047 .25102 L
.46049 .34124 L
.46051 .39709 L
.46053 .29828 L
.46056 .44435 L
.46058 .41857 L
.4606 .25102 L
.46062 .31976 L
.46065 .28968 L
.46067 .23383 L
.46069 .28968 L
.46071 .24242 L
.46074 .17368 L
.46076 .29828 L
.46078 .31117 L
.4608 .35413 L
.46082 .36272 L
.46085 .24242 L
.46087 .25102 L
.46089 .30257 L
.46091 .30687 L
.46094 .30687 L
.46096 .25102 L
.46098 .20805 L
.461 .17368 L
.46103 .25102 L
.46105 .47013 L
.46107 .29828 L
.46109 .30687 L
.46111 .40569 L
.46114 .28109 L
.46116 .40569 L
.46118 .46154 L
.4612 .25531 L
.46123 .29828 L
.46125 .28109 L
.46127 .20805 L
.46129 .28968 L
.46132 .2725 L
.46134 .16079 L
.46136 .26391 L
.46138 .31546 L
.46141 .33265 L
.46143 .37561 L
Mistroke
.46145 .25531 L
.46147 .22094 L
.46149 .28109 L
.46152 .29398 L
.46154 .31546 L
.46156 .26391 L
.46158 .20376 L
.46161 .1522 L
.46163 .28968 L
.46165 .47013 L
.46167 .28109 L
.4617 .36272 L
.46172 .36272 L
.46174 .25102 L
.46176 .43146 L
.46178 .44006 L
.46181 .25531 L
.46183 .32835 L
.46185 .23383 L
.46187 .19087 L
.4619 .32835 L
.46192 .25531 L
.46194 .19087 L
.46196 .30257 L
.46199 .28968 L
.46201 .35413 L
.46203 .36702 L
.46205 .24242 L
.46207 .24672 L
.4621 .2725 L
.46212 .2682 L
.46214 .33694 L
.46216 .2682 L
.46219 .19516 L
.46221 .1479 L
.46223 .32405 L
.46225 .43146 L
.46228 .29828 L
.4623 .41428 L
.46232 .31976 L
.46234 .25961 L
.46237 .45295 L
.46239 .3842 L
.46241 .28539 L
.46243 .34983 L
.46245 .17368 L
.46248 .20376 L
.4625 .31546 L
.46252 .31546 L
.46254 .22953 L
Mistroke
.46257 .24672 L
.46259 .33265 L
.46261 .2725 L
.46263 .34124 L
.46266 .31976 L
.46268 .23813 L
.4627 .2682 L
.46272 .2725 L
.46274 .30687 L
.46277 .30687 L
.46279 .26391 L
.46281 .16079 L
.46283 .19946 L
.46286 .43576 L
.46288 .31546 L
.4629 .35413 L
.46292 .42287 L
.46295 .22094 L
.46297 .34554 L
.46299 .46154 L
.46301 .26391 L
.46304 .35413 L
.46306 .30257 L
.46308 .12642 L
.4631 .28539 L
.46312 .28539 L
.46315 .20376 L
.46317 .34124 L
.46319 .31546 L
.46321 .28109 L
.46324 .35843 L
.46326 .24672 L
.46328 .24242 L
.4633 .29828 L
.46333 .25102 L
.46335 .29828 L
.46337 .29398 L
.46339 .22094 L
.46341 .1479 L
.46344 .32835 L
.46346 .41428 L
.46348 .28968 L
.4635 .44006 L
.46353 .32835 L
.46355 .24672 L
.46357 .42717 L
.46359 .36272 L
.46362 .2725 L
.46364 .37131 L
.46366 .18227 L
Mistroke
.46368 .19946 L
.4637 .30687 L
.46373 .22953 L
.46375 .2682 L
.46377 .37991 L
.46379 .2725 L
.46382 .31117 L
.46384 .29398 L
.46386 .21235 L
.46388 .27679 L
.46391 .29398 L
.46393 .26391 L
.46395 .31117 L
.46397 .25531 L
.464 .14361 L
.46402 .28968 L
.46404 .43146 L
.46406 .28539 L
.46408 .41857 L
.46411 .35843 L
.46413 .22524 L
.46415 .40139 L
.46417 .37561 L
.4642 .2682 L
.46422 .37991 L
.46424 .20805 L
.46426 .18657 L
.46429 .30257 L
.46431 .24672 L
.46433 .26391 L
.46435 .3842 L
.46437 .29398 L
.4644 .28968 L
.46442 .30257 L
.46444 .21664 L
.46446 .24672 L
.46449 .29828 L
.46451 .26391 L
.46453 .31546 L
.46455 .27679 L
.46458 .13501 L
.4646 .33265 L
.46462 .42717 L
.46464 .28968 L
.46467 .43576 L
.46469 .34554 L
.46471 .22094 L
.46473 .40139 L
.46475 .35413 L
.46478 .2725 L
Mistroke
.4648 .37131 L
.46482 .19516 L
.46484 .21664 L
.46487 .30257 L
.46489 .25102 L
.46491 .31546 L
.46493 .37561 L
.46496 .27679 L
.46498 .28968 L
.465 .25961 L
.46502 .22094 L
.46504 .2725 L
.46507 .28539 L
.46509 .27679 L
.46511 .27679 L
.46513 .32405 L
.46516 .22953 L
.46518 .1479 L
.4652 .39709 L
.46522 .37991 L
.46525 .32405 L
.46527 .44865 L
.46529 .27679 L
.46531 .24672 L
.46533 .40139 L
.46536 .29828 L
.46538 .32835 L
.4654 .32835 L
.46542 .16079 L
.46545 .26391 L
.46547 .2725 L
.46549 .2682 L
.46551 .37991 L
.46554 .35413 L
.46556 .25961 L
.46558 .27679 L
.4656 .19946 L
.46563 .23383 L
.46565 .29398 L
.46567 .27679 L
.46569 .30257 L
.46571 .31117 L
.46574 .17368 L
.46576 .25961 L
.46578 .46154 L
.4658 .33265 L
.46583 .39709 L
.46585 .39709 L
.46587 .22094 L
.46589 .30257 L
Mistroke
.46592 .37991 L
.46594 .26391 L
.46596 .34983 L
.46598 .25961 L
.466 .19087 L
.46603 .28109 L
.46605 .29828 L
.46607 .31976 L
.46609 .40569 L
.46612 .30687 L
.46614 .22953 L
.46616 .24242 L
.46618 .20376 L
.46621 .26391 L
.46623 .31117 L
.46625 .28109 L
.46627 .28968 L
.4663 .25531 L
.46632 .16938 L
.46634 .40998 L
.46636 .41428 L
.46638 .34124 L
.46641 .43576 L
.46643 .27679 L
.46645 .22953 L
.46647 .37131 L
.4665 .28539 L
.46652 .30687 L
.46654 .30687 L
.46656 .18227 L
.46659 .25531 L
.46661 .28968 L
.46663 .33265 L
.46665 .3928 L
.46667 .34983 L
.4667 .22524 L
.46672 .21235 L
.46674 .19516 L
.46676 .23383 L
.46679 .28968 L
.46681 .29828 L
.46683 .28539 L
.46685 .24242 L
.46688 .18657 L
.4669 .41428 L
.46692 .41857 L
.46694 .3842 L
.46696 .43146 L
.46699 .25961 L
.46701 .24672 L
Mistroke
.46703 .34124 L
.46705 .27679 L
.46708 .32835 L
.4671 .28109 L
.46712 .17798 L
.46714 .27679 L
.46717 .2682 L
.46719 .36702 L
.46721 .41857 L
.46723 .33265 L
.46726 .24242 L
.46728 .20805 L
.4673 .17798 L
.46732 .26391 L
.46734 .28968 L
.46737 .28539 L
.46739 .28539 L
.46741 .23383 L
.46743 .18227 L
.46746 .41428 L
.46748 .41428 L
.4675 .44006 L
.46752 .37991 L
.46755 .44865 L
.46757 .25961 L
.46759 .22094 L
.46761 .34983 L
.46763 .2682 L
.46766 .31117 L
.46768 .30687 L
.4677 .1565 L
.46772 .25531 L
.46775 .28539 L
.46777 .37131 L
.46779 .42287 L
.46781 .34554 L
.46784 .21664 L
.46786 .16938 L
.46788 .17368 L
.4679 .25102 L
.46792 .31117 L
.46795 .31117 L
.46797 .2725 L
.46799 .16938 L
.46801 .22953 L
.46804 .47013 L
.46806 .40139 L
.46808 .47013 L
.4681 .39709 L
.46813 .19087 L
Mistroke
.46815 .25961 L
.46817 .30257 L
.46819 .25102 L
.46822 .3885 L
.46824 .23383 L
.46826 .19516 L
.46828 .2682 L
.4683 .27679 L
.46833 .42717 L
.46835 .41857 L
.46837 .29398 L
.46839 .22524 L
.46842 .16079 L
.46844 .19946 L
.46846 .31117 L
.46848 .31117 L
.46851 .32405 L
.46853 .25531 L
.46855 .10494 L
.46857 .34983 L
.46859 .44435 L
.46862 .3842 L
.46864 .53028 L
.46866 .29828 L
.46868 .18657 L
.46871 .30687 L
.46873 .24242 L
.46875 .29828 L
.46877 .39709 L
.4688 .17798 L
.46882 .25102 L
.46884 .24242 L
.46886 .31976 L
.46889 .44006 L
.46891 .37131 L
.46893 .2725 L
.46895 .19516 L
.46897 .13072 L
.469 .24242 L
.46902 .30257 L
.46904 .30687 L
.46906 .34124 L
.46909 .14361 L
.46911 .24672 L
.46913 .43576 L
.46915 .34554 L
.46918 .5045 L
.4692 .40998 L
.46922 .21235 L
.46924 .25531 L
Mistroke
.46926 .25102 L
.46929 .22524 L
.46931 .3885 L
.46933 .25102 L
.46935 .23813 L
.46938 .27679 L
.4694 .27679 L
.46942 .3842 L
.46944 .37991 L
.46947 .28109 L
.46949 .24672 L
.46951 .17798 L
.46953 .22094 L
.46955 .31546 L
.46958 .30257 L
.4696 .33265 L
.46962 .23813 L
.46964 .16509 L
.46967 .41857 L
.46969 .35843 L
.46971 .42717 L
.46973 .47872 L
.46976 .25961 L
.46978 .24672 L
.4698 .28109 L
.46982 .22524 L
.46985 .22524 L
.46987 .34983 L
.46989 .30687 L
.46991 .21664 L
.46993 .27679 L
.46996 .2725 L
.46998 .35413 L
.47 .37561 L
.47002 .31546 L
.47005 .24242 L
.47007 .19087 L
.47009 .19946 L
.47011 .28968 L
.47014 .29398 L
.47016 .31976 L
.47018 .23813 L
.4702 .25961 L
.47022 .3885 L
.47025 .34983 L
.47027 .45295 L
.47029 .39709 L
.47031 .28968 L
.47034 .26391 L
.47036 .23383 L
Mistroke
.47038 .25102 L
.4704 .29828 L
.47043 .25961 L
.47045 .28539 L
.47047 .25961 L
.47049 .31117 L
.47052 .34554 L
.47054 .30257 L
.47056 .28109 L
.47058 .25102 L
.4706 .21235 L
.47063 .26391 L
.47065 .30257 L
.47067 .28109 L
.47069 .30687 L
.47072 .20376 L
.47074 .28109 L
.47076 .40569 L
.47078 .35413 L
.47081 .45724 L
.47083 .37561 L
.47085 .2682 L
.47087 .28109 L
.47089 .22953 L
.47092 .2725 L
.47094 .31976 L
.47096 .25102 L
.47098 .30257 L
.47101 .2682 L
.47103 .29828 L
.47105 .35843 L
.47107 .28968 L
.4711 .27679 L
.47112 .24672 L
.47114 .19087 L
.47116 .25961 L
.47118 .27679 L
.47121 .29398 L
.47123 .2725 L
.47125 .27679 L
.47127 .39709 L
.4713 .32405 L
.47132 .43576 L
.47134 .3842 L
.47136 .30257 L
.47139 .31546 L
.47141 .22953 L
.47143 .22094 L
.47145 .29828 L
.47148 .21664 L
Mistroke
.4715 .31546 L
.47152 .31976 L
.47154 .29398 L
.47156 .35843 L
.47159 .25531 L
.47161 .24242 L
.47163 .25531 L
.47165 .22094 L
.47168 .28109 L
.4717 .30257 L
.47172 .26391 L
.47174 .28968 L
.47177 .20376 L
.47179 .31546 L
.47181 .40569 L
.47183 .36702 L
.47185 .45724 L
.47188 .33694 L
.4719 .26391 L
.47192 .28109 L
.47194 .21664 L
.47197 .28109 L
.47199 .31546 L
.47201 .24672 L
.47203 .33694 L
.47206 .2725 L
.47208 .30257 L
.4721 .33265 L
.47212 .25102 L
.47215 .25961 L
.47217 .25102 L
.47219 .22094 L
.47221 .22094 L
.47223 .28539 L
.47226 .28109 L
.47228 .27679 L
.4723 .25961 L
.47232 .33694 L
.47235 .40998 L
.47237 .34983 L
.47239 .44435 L
.47241 .33265 L
.47244 .28109 L
.47246 .28968 L
.47248 .22094 L
.4725 .25961 L
.47252 .27679 L
.47255 .23383 L
.47257 .34124 L
.47259 .28539 L
Mistroke
.47261 .33265 L
.47264 .34124 L
.47266 .22953 L
.47268 .25961 L
.4727 .25102 L
.47273 .22953 L
.47275 .28539 L
.47277 .26391 L
.47279 .25531 L
.47281 .23383 L
.47284 .33265 L
.47286 .41428 L
.47288 .36702 L
.4729 .45295 L
.47293 .32835 L
.47295 .28539 L
.47297 .2682 L
.47299 .22953 L
.47302 .25531 L
.47304 .2725 L
.47306 .24242 L
.47308 .33265 L
.47311 .28539 L
.47313 .32835 L
.47315 .31976 L
.47317 .23383 L
.47319 .25102 L
.47322 .24242 L
.47324 .25531 L
.47326 .29828 L
.47328 .28109 L
.47331 .2682 L
.47333 .22953 L
.47335 .36702 L
.47337 .41428 L
.4734 .37991 L
.47342 .44865 L
.47344 .30687 L
.47346 .26391 L
.47348 .26391 L
.47351 .22953 L
.47353 .28539 L
.47355 .2725 L
.47357 .26391 L
.4736 .33265 L
.47362 .27679 L
.47364 .33265 L
.47366 .30687 L
.47369 .22524 L
.47371 .2682 L
Mistroke
.47373 .24242 L
.47375 .25961 L
.47378 .28539 L
.4738 .28109 L
.47382 .24672 L
.47384 .23383 L
.47386 .40998 L
.47389 .3842 L
.47391 .41857 L
.47393 .42287 L
.47395 .28968 L
.47398 .2725 L
.474 .23813 L
.47402 .23383 L
.47404 .29828 L
.47407 .25961 L
.47409 .30257 L
.47411 .30257 L
.47413 .25531 L
.47415 .30687 L
.47418 .25102 L
.4742 .24672 L
.47422 .2682 L
.47424 .26391 L
.47427 .28968 L
.47429 .2725 L
.47431 .28109 L
.47433 .23813 L
.47436 .31976 L
.47438 .43576 L
.4744 .37561 L
.47442 .43146 L
.47444 .33694 L
.47447 .2682 L
.47449 .25961 L
.47451 .23813 L
.47453 .28109 L
.47456 .30687 L
.47458 .30687 L
.4746 .2725 L
.47462 .33694 L
.47465 .28539 L
.47467 .25961 L
.47469 .28968 L
.47471 .23383 L
.47474 .25531 L
.47476 .27679 L
.47478 .27679 L
.4748 .28109 L
.47482 .2682 L
Mistroke
.47485 .25531 L
.47487 .26391 L
.47489 .43146 L
.47491 .40139 L
.47494 .41857 L
.47496 .39709 L
.47498 .2725 L
.475 .27679 L
.47503 .23813 L
.47505 .25102 L
.47507 .31117 L
.47509 .28109 L
.47511 .31117 L
.47514 .32405 L
.47516 .25531 L
.47518 .27679 L
.4752 .23383 L
.47523 .22953 L
.47525 .25531 L
.47527 .27679 L
.47529 .29828 L
.47532 .25102 L
.47534 .2725 L
.47536 .24672 L
.47538 .39709 L
.47541 .43576 L
.47543 .40139 L
.47545 .42717 L
.47547 .2682 L
.47549 .25531 L
.47552 .23813 L
.47554 .22094 L
.47556 .30687 L
.47558 .31546 L
.47561 .29398 L
.47563 .34983 L
.47565 .25961 L
.47567 .25961 L
.4757 .23813 L
.47572 .22953 L
.47574 .2725 L
.47576 .28539 L
.47578 .29398 L
.47581 .26391 L
.47583 .24242 L
.47585 .23383 L
.47587 .40139 L
.4759 .44865 L
.47592 .41428 L
.47594 .44865 L
Mistroke
.47596 .25102 L
.47599 .24242 L
.47601 .23383 L
.47603 .21235 L
.47605 .32835 L
.47607 .33265 L
.4761 .30687 L
.47612 .34554 L
.47614 .24242 L
.47616 .24672 L
.47619 .23383 L
.47621 .22524 L
.47623 .28968 L
.47625 .28109 L
.47628 .28539 L
.4763 .25961 L
.47632 .22953 L
.47634 .22524 L
.47637 .3885 L
.47639 .47013 L
.47641 .41428 L
.47643 .44865 L
.47645 .25531 L
.47648 .21664 L
.4765 .24242 L
.47652 .21664 L
.47654 .33694 L
.47657 .35843 L
.47659 .28539 L
.47661 .33265 L
.47663 .22953 L
.47666 .22094 L
.47668 .25531 L
.4767 .22953 L
.47672 .28968 L
.47674 .28539 L
.47677 .26391 L
.47679 .25531 L
.47681 .23383 L
.47683 .23383 L
.47686 .44435 L
.47688 .45724 L
.4769 .41857 L
.47692 .44006 L
.47695 .44006 L
.47697 .21235 L
.47699 .22524 L
.47701 .24242 L
.47704 .21664 L
.47706 .37991 L
Mistroke
.47708 .34124 L
.4771 .29398 L
.47712 .33265 L
.47715 .20376 L
.47717 .25531 L
.47719 .2725 L
.47721 .23813 L
.47724 .30687 L
.47726 .2725 L
.47728 .25531 L
.4773 .25102 L
.47733 .22953 L
.47735 .25102 L
.47737 .46583 L
.47739 .43146 L
.47741 .43146 L
.47744 .43146 L
.47746 .18657 L
.47748 .25531 L
.4775 .22094 L
.47753 .21235 L
.47755 .39709 L
.47757 .32405 L
.47759 .31117 L
.47762 .34554 L
.47764 .18227 L
.47766 .24672 L
.47768 .23813 L
.4777 .22094 L
.47773 .30687 L
.47775 .2682 L
.47777 .24242 L
.47779 .24672 L
.47782 .18227 L
.47784 .35413 L
.47786 .49591 L
.47788 .41428 L
.47791 .49591 L
.47793 .29398 L
.47795 .17368 L
.47797 .23383 L
.478 .16509 L
.47802 .31117 L
.47804 .40139 L
.47806 .28539 L
.47808 .37131 L
.47811 .24242 L
.47813 .19946 L
.47815 .2725 L
.47817 .22953 L
Mistroke
.4782 .29398 L
.47822 .30257 L
.47824 .23813 L
.47826 .24242 L
.47829 .21235 L
.47831 .24242 L
.47833 .48302 L
.47835 .44435 L
.47837 .44435 L
.4784 .41857 L
.47842 .17798 L
.47844 .22094 L
.47846 .21235 L
.47849 .22524 L
.47851 .41857 L
.47853 .34124 L
.47855 .33265 L
.47858 .33265 L
.4786 .18227 L
.47862 .24672 L
.47864 .25102 L
.47867 .25531 L
.47869 .31976 L
.47871 .26391 L
.47873 .22953 L
.47875 .23813 L
.47878 .19087 L
.4788 .3885 L
.47882 .5045 L
.47884 .40569 L
.47887 .48732 L
.47889 .24672 L
.47891 .16938 L
.47893 .23813 L
.47896 .16079 L
.47898 .35413 L
.479 .40998 L
.47902 .28968 L
.47904 .37561 L
.47907 .20805 L
.47909 .18657 L
.47911 .28109 L
.47913 .24242 L
.47916 .32835 L
.47918 .31117 L
.4792 .21235 L
.47922 .23383 L
.47925 .16938 L
.47927 .29398 L
.47929 .52169 L
Mistroke
.47931 .52169 L
.47933 .43146 L
.47936 .48302 L
.47938 .33265 L
.4794 .13501 L
.47942 .20376 L
.47945 .18657 L
.47947 .27679 L
.47949 .45724 L
.47951 .31546 L
.47954 .35413 L
.47956 .27679 L
.47958 .16079 L
.4796 .28539 L
.47963 .2725 L
.47965 .28968 L
.47967 .33694 L
.47969 .22524 L
.47971 .21664 L
.47974 .19087 L
.47976 .22953 L
.47978 .50021 L
.4798 .46154 L
.47983 .47872 L
.47985 .40569 L
.47987 .17368 L
.47989 .19087 L
.47992 .19946 L
.47994 .22953 L
.47996 .42717 L
.47998 .34983 L
.48 .32835 L
.48003 .31117 L
.48005 .16509 L
.48007 .25102 L
.48009 .27679 L
.48012 .28539 L
.48014 .35843 L
.48016 .2682 L
.48018 .21235 L
.48021 .21664 L
.48023 .17798 L
.48025 .44435 L
.48027 .47872 L
.4803 .44865 L
.48032 .45295 L
.48034 .19087 L
.48036 .1565 L
.48038 .19946 L
.48041 .20805 L
Mistroke
.48043 .40998 L
.48045 .3885 L
.48047 .30687 L
.4805 .33265 L
.48052 .16079 L
.48054 .21664 L
.48056 .30257 L
.48059 .28539 L
.48061 .35413 L
.48063 .29828 L
.48065 .20376 L
.48067 .21235 L
.4807 .1522 L
.48072 .35413 L
.48074 .5088 L
.48076 .43576 L
.48079 .48302 L
.48081 .26391 L
.48083 .1522 L
.48085 .20805 L
.48088 .19946 L
.4809 .36272 L
.48092 .43576 L
.48094 .30687 L
.48096 .34124 L
.48099 .19087 L
.48101 .17368 L
.48103 .2682 L
.48105 .27679 L
.48108 .35413 L
.4811 .33265 L
.48112 .23383 L
.48114 .22953 L
.48117 .16079 L
.48119 .32835 L
.48121 .51309 L
.48123 .43576 L
.48126 .49161 L
.48128 .27679 L
.4813 .13501 L
.48132 .18227 L
.48134 .17798 L
.48137 .34124 L
.48139 .45295 L
.48141 .31546 L
.48143 .34554 L
.48146 .20805 L
.48148 .1522 L
.4815 .28109 L
.48152 .28539 L
Mistroke
.48155 .34554 L
.48157 .34554 L
.48159 .21235 L
.48161 .20376 L
.48163 .1565 L
.48166 .1565 L
.48168 .2725 L
.4817 .51739 L
.48172 .44435 L
.48175 .49161 L
.48177 .31117 L
.48179 .14361 L
.48181 .16938 L
.48184 .18657 L
.48186 .31117 L
.48188 .45724 L
.4819 .32405 L
.48193 .32405 L
.48195 .22953 L
.48197 .14361 L
.48199 .25961 L
.48201 .28109 L
.48204 .33694 L
.48206 .35413 L
.48208 .22953 L
.4821 .22094 L
.48213 .16938 L
.48215 .30257 L
.48217 .5088 L
.48219 .45295 L
.48222 .50021 L
.48224 .29398 L
.48226 .16509 L
.48228 .16509 L
.4823 .17798 L
.48233 .32835 L
.48235 .44435 L
.48237 .33694 L
.48239 .34124 L
.48242 .22524 L
.48244 .16938 L
.48246 .25961 L
.48248 .28539 L
.48251 .34554 L
.48253 .33694 L
.48255 .23813 L
.48257 .21664 L
.48259 .17798 L
.48262 .2725 L
.48264 .49591 L
Mistroke
.48266 .44006 L
.48268 .47013 L
.48271 .31976 L
.48273 .16079 L
.48275 .16938 L
.48277 .19087 L
.4828 .29828 L
.48282 .44865 L
.48284 .34983 L
.48286 .31546 L
.48289 .24242 L
.48291 .1522 L
.48293 .23813 L
.48295 .2725 L
.48297 .32835 L
.483 .34124 L
.48302 .23813 L
.48304 .22953 L
.48306 .17368 L
.48309 .30687 L
.48311 .48732 L
.48313 .44435 L
.48315 .49591 L
.48318 .27679 L
.4832 .17368 L
.48322 .1522 L
.48324 .16938 L
.48326 .33265 L
.48329 .44435 L
.48331 .35413 L
.48333 .33694 L
.48335 .21664 L
.48338 .16509 L
.4834 .25961 L
.48342 .28109 L
.48344 .37131 L
.48347 .35413 L
.48349 .23813 L
.48351 .22524 L
.48353 .1522 L
.48356 .31976 L
.48358 .49161 L
.4836 .45724 L
.48362 .49161 L
.48364 .2725 L
.48367 .1522 L
.48369 .1479 L
.48371 .18227 L
.48373 .34983 L
.48376 .47013 L
Mistroke
.48378 .35413 L
.4838 .33265 L
.48382 .20376 L
.48385 .1479 L
.48387 .25102 L
.48389 .2682 L
.48391 .34983 L
.48393 .34124 L
.48396 .22524 L
.48398 .19946 L
.484 .16509 L
.48402 .16509 L
.48405 .3842 L
.48407 .45724 L
.48409 .49161 L
.48411 .47013 L
.48414 .22953 L
.48416 .17368 L
.48418 .11353 L
.4842 .18657 L
.48422 .35843 L
.48425 .43576 L
.48427 .36272 L
.48429 .32405 L
.48431 .16938 L
.48434 .16509 L
.48436 .24672 L
.48438 .28539 L
.4844 .3928 L
.48443 .34983 L
.48445 .23813 L
.48447 .19946 L
.48449 .1479 L
.48452 .37561 L
.48454 .46154 L
.48456 .47443 L
.48458 .47013 L
.4846 .22953 L
.48463 .13931 L
.48465 .1479 L
.48467 .19087 L
.48469 .3842 L
.48472 .47872 L
.48474 .35843 L
.48476 .33265 L
.48478 .16079 L
.48481 .1565 L
.48483 .25531 L
.48485 .28539 L
.48487 .3842 L
Mistroke
.48489 .33265 L
.48492 .22953 L
.48494 .17798 L
.48496 .21235 L
.48498 .42717 L
.48501 .43576 L
.48503 .53887 L
.48505 .3928 L
.48507 .22953 L
.4851 .16079 L
.48512 .11353 L
.48514 .24672 L
.48516 .3885 L
.48518 .40998 L
.48521 .35843 L
.48523 .27679 L
.48525 .13931 L
.48527 .21664 L
.4853 .25961 L
.48532 .33265 L
.48534 .40998 L
.48536 .28968 L
.48539 .22524 L
.48541 .1565 L
.48543 .25531 L
.48545 .44435 L
.48548 .44435 L
.4855 .51739 L
.48552 .32835 L
.48554 .18227 L
.48556 .12642 L
.48559 .14361 L
.48561 .28109 L
.48563 .45295 L
.48565 .40139 L
.48568 .35843 L
.4857 .23383 L
.48572 .13072 L
.48574 .23383 L
.48577 .25531 L
.48579 .34554 L
.48581 .37131 L
.48583 .25531 L
.48585 .19946 L
.48588 .16079 L
.4859 .35843 L
.48592 .42717 L
.48594 .49591 L
.48597 .49161 L
.48599 .2725 L
Mistroke
.48601 .20376 L
.48603 .10924 L
.48606 .17798 L
.48608 .35413 L
.4861 .41857 L
.48612 .3842 L
.48615 .33265 L
.48617 .16509 L
.48619 .17798 L
.48621 .24242 L
.48623 .28968 L
.48626 .40139 L
.48628 .34124 L
.4863 .25961 L
.48632 .17798 L
.48635 .21235 L
.48637 .39709 L
.48639 .39709 L
.48641 .40569 L
.48644 .52598 L
.48646 .3842 L
.48648 .23383 L
.4865 .1522 L
.48652 .11353 L
.48655 .23813 L
.48657 .40569 L
.48659 .41857 L
.48661 .3842 L
.48664 .28539 L
.48666 .13501 L
.48668 .21235 L
.4867 .23813 L
.48673 .32405 L
.48675 .3928 L
.48677 .28109 L
.48679 .23383 L
.48681 .14361 L
.48684 .30257 L
.48686 .3928 L
.48688 .44865 L
.4869 .51309 L
.48693 .30687 L
.48695 .22953 L
.48697 .11353 L
.48699 .1522 L
.48702 .29828 L
.48704 .42287 L
.48706 .3885 L
.48708 .35843 L
.48711 .20805 L
Mistroke
.48713 .16079 L
.48715 .22524 L
.48717 .25102 L
.48719 .37131 L
.48722 .34983 L
.48724 .28539 L
.48726 .20376 L
.48728 .19946 L
.48731 .3885 L
.48733 .37561 L
.48735 .52169 L
.48737 .41428 L
.4874 .2725 L
.48742 .19946 L
.48744 .10924 L
.48746 .21235 L
.48748 .36272 L
.48751 .40569 L
.48753 .37991 L
.48755 .31546 L
.48757 .16938 L
.4876 .21664 L
.48762 .23813 L
.48764 .29828 L
.48766 .3885 L
.48769 .28968 L
.48771 .24672 L
.48773 .16079 L
.48775 .29828 L
.48778 .37561 L
.4878 .44006 L
.48782 .50021 L
.48784 .31976 L
.48786 .25102 L
.48789 .12642 L
.48791 .1522 L
.48793 .28539 L
.48795 .40139 L
.48798 .37561 L
.488 .37131 L
.48802 .21664 L
.48804 .16938 L
.48807 .23813 L
.48809 .22953 L
.48811 .36272 L
.48813 .34554 L
.48815 .27679 L
.48818 .20376 L
.4882 .19946 L
.48822 .36272 L
Mistroke
.48824 .36272 L
.48827 .5088 L
.48829 .40569 L
.48831 .28968 L
.48833 .20805 L
.48836 .11783 L
.48838 .19087 L
.4884 .34983 L
.48842 .3842 L
.48844 .37991 L
.48847 .33694 L
.48849 .16938 L
.48851 .23383 L
.48853 .22524 L
.48856 .27679 L
.48858 .3842 L
.4886 .30257 L
.48862 .25961 L
.48865 .19946 L
.48867 .31976 L
.48869 .34983 L
.48871 .46154 L
.48874 .47013 L
.48876 .47013 L
.48878 .32405 L
.4888 .28109 L
.48882 .13072 L
.48885 .16509 L
.48887 .26391 L
.48889 .36702 L
.48891 .36702 L
.48894 .37991 L
.48896 .22524 L
.48898 .21235 L
.489 .24242 L
.48903 .23383 L
.48905 .35843 L
.48907 .31976 L
.48909 .28968 L
.48911 .20805 L
.48914 .24242 L
.48916 .34983 L
.48918 .37131 L
.4892 .5045 L
.48923 .37131 L
.48925 .31546 L
.48927 .18227 L
.48929 .1479 L
.48932 .19946 L
.48934 .34554 L
Mistroke
.48936 .36702 L
.48938 .3842 L
.48941 .30687 L
.48943 .16938 L
.48945 .23383 L
.48947 .20376 L
.48949 .30257 L
.48952 .34124 L
.48954 .30257 L
.48956 .24242 L
.48958 .19946 L
.48961 .33265 L
.48963 .31976 L
.48965 .48302 L
.48967 .44006 L
.4897 .34124 L
.48972 .25961 L
.48974 .14361 L
.48976 .18227 L
.48978 .27679 L
.48981 .37131 L
.48983 .35413 L
.48985 .37131 L
.48987 .20376 L
.4899 .23383 L
.48992 .23383 L
.48994 .26391 L
.48996 .36702 L
.48999 .31117 L
.49001 .29398 L
.49003 .19087 L
.49005 .30257 L
.49007 .32835 L
.4901 .40569 L
.49012 .49591 L
.49014 .34554 L
.49016 .31546 L
.49019 .16079 L
.49021 .16509 L
.49023 .22094 L
.49025 .35843 L
.49028 .34124 L
.4903 .3842 L
.49032 .26391 L
.49034 .20805 L
.49037 .25961 L
.49039 .22094 L
.49041 .33694 L
.49043 .31117 L
.49045 .29398 L
Mistroke
.49048 .19087 L
.4905 .28539 L
.49052 .32405 L
.49054 .35413 L
.49057 .51739 L
.49059 .34983 L
.49061 .35413 L
.49063 .22094 L
.49066 .14361 L
.49068 .20805 L
.4907 .31976 L
.49072 .31117 L
.49074 .37991 L
.49077 .28968 L
.49079 .19087 L
.49081 .27679 L
.49083 .20376 L
.49086 .31976 L
.49088 .33265 L
.4909 .28968 L
.49092 .25102 L
.49095 .22524 L
.49097 .35413 L
.49099 .32405 L
.49101 .5045 L
.49104 .40569 L
.49106 .36272 L
.49108 .26391 L
.4911 .16938 L
.49112 .16938 L
.49115 .19516 L
.49117 .28109 L
.49119 .35413 L
.49121 .34124 L
.49124 .36272 L
.49126 .19946 L
.49128 .2725 L
.4913 .22524 L
.49133 .28968 L
.49135 .33694 L
.49137 .29398 L
.49139 .27679 L
.49141 .19946 L
.49144 .33694 L
.49146 .30687 L
.49148 .45295 L
.4915 .44006 L
.49153 .35413 L
.49155 .31117 L
.49157 .17798 L
Mistroke
.49159 .19946 L
.49162 .24242 L
.49164 .34554 L
.49166 .31546 L
.49168 .37561 L
.4917 .22094 L
.49173 .24242 L
.49175 .24242 L
.49177 .24672 L
.49179 .33694 L
.49182 .28968 L
.49184 .29398 L
.49186 .19516 L
.49188 .30257 L
.49191 .30257 L
.49193 .3928 L
.49195 .47443 L
.49197 .35413 L
.492 .34983 L
.49202 .19946 L
.49204 .19087 L
.49206 .19946 L
.49208 .32835 L
.49211 .30257 L
.49213 .37561 L
.49215 .28109 L
.49217 .21664 L
.4922 .25961 L
.49222 .22094 L
.49224 .32405 L
.49226 .30257 L
.49229 .30257 L
.49231 .23383 L
.49233 .26391 L
.49235 .33694 L
.49237 .32835 L
.4924 .49591 L
.49242 .3885 L
.49244 .3842 L
.49246 .25961 L
.49249 .21235 L
.49251 .19087 L
.49253 .29828 L
.49255 .31117 L
.49258 .33694 L
.4926 .32835 L
.49262 .20376 L
.49264 .26391 L
.49267 .21235 L
.49269 .29398 L
Mistroke
.49271 .30687 L
.49273 .30687 L
.49275 .23813 L
.49278 .24672 L
.4928 .32835 L
.49282 .29398 L
.49284 .47443 L
.49287 .39709 L
.49289 .37991 L
.49291 .30257 L
.49293 .21664 L
.49296 .19087 L
.49298 .2725 L
.493 .29398 L
.49302 .31117 L
.49304 .34554 L
.49307 .20376 L
.49309 .25961 L
.49311 .21235 L
.49313 .2682 L
.49316 .31546 L
.49318 .30257 L
.4932 .26391 L
.49322 .21235 L
.49325 .29398 L
.49327 .28109 L
.49329 .41428 L
.49331 .43576 L
.49333 .3842 L
.49336 .34554 L
.49338 .23383 L
.4934 .21664 L
.49342 .23383 L
.49345 .32835 L
.49347 .29398 L
.49349 .29398 L
.49351 .37561 L
.49354 .24242 L
.49356 .25531 L
.49358 .23383 L
.4936 .25961 L
.49363 .31546 L
.49365 .31117 L
.49367 .28968 L
.49369 .22094 L
.49371 .28539 L
.49374 .28109 L
.49376 .36272 L
.49378 .44006 L
.4938 .3885 L
Mistroke
.49383 .37561 L
.49385 .2682 L
.49387 .24242 L
.49389 .21664 L
.49392 .31117 L
.49394 .28539 L
.49396 .34554 L
.49398 .27679 L
.494 .23813 L
.49403 .24672 L
.49405 .24242 L
.49407 .29828 L
.49409 .30257 L
.49412 .29828 L
.49414 .24242 L
.49416 .24242 L
.49418 .27679 L
.49421 .29828 L
.49423 .39709 L
.49425 .3885 L
.49427 .37131 L
.4943 .31117 L
.49432 .25531 L
.49434 .23383 L
.49436 .2682 L
.49438 .31546 L
.49441 .30257 L
.49443 .32405 L
.49445 .22953 L
.49447 .26391 L
.4945 .24242 L
.49452 .28968 L
.49454 .29828 L
.49456 .30687 L
.49459 .26391 L
.49461 .24242 L
.49463 .25531 L
.49465 .28539 L
.49467 .32835 L
.4947 .3842 L
.49472 .35843 L
.49474 .34983 L
.49476 .28539 L
.49479 .28109 L
.49481 .25102 L
.49483 .32835 L
.49485 .31546 L
.49488 .34554 L
.4949 .29828 L
.49492 .26391 L
Mistroke
.49494 .28539 L
.49496 .28968 L
.49499 .31117 L
.49501 .30257 L
.49503 .30257 L
.49505 .25102 L
.49508 .2682 L
.4951 .25961 L
.49512 .30257 L
.49514 .30257 L
.49517 .33265 L
.49519 .31117 L
.49521 .31117 L
.49523 .27679 L
.49526 .28968 L
.49528 .2682 L
.4953 .31546 L
.49532 .31117 L
.49534 .33265 L
.49537 .30257 L
.49539 .29398 L
.49541 .29398 L
.49543 .31117 L
.49546 .30257 L
.49548 .29828 L
.4955 .29828 L
.49552 .26391 L
.49555 .28109 L
.49557 .2682 L
.49559 .29398 L
.49561 .28539 L
.49563 .28968 L
.49566 .27679 L
.49568 .28539 L
.4957 .27679 L
.49572 .27679 L
.49575 .28539 L
.49577 .28109 L
.49579 .31546 L
.49581 .31976 L
.49584 .32835 L
.49586 .32835 L
.49588 .31976 L
.4959 .31546 L
.49593 .30687 L
.49595 .31117 L
.49597 .31117 L
.49599 .30257 L
.49601 .30687 L
.49604 .29398 L
Mistroke
.49606 .30257 L
.49608 .29398 L
.4961 .28968 L
.49613 .28968 L
.49615 .28109 L
.49617 .28109 L
.49619 .28109 L
.49622 .28539 L
.49624 .28109 L
.49626 .29828 L
.49628 .29828 L
.4963 .31117 L
.49633 .32835 L
.49635 .31976 L
.49637 .31976 L
.49639 .30687 L
.49642 .31117 L
.49644 .30257 L
.49646 .31117 L
.49648 .30257 L
.49651 .30257 L
.49653 .28968 L
.49655 .28968 L
.49657 .28539 L
.49659 .28539 L
.49662 .28109 L
.49664 .27679 L
.49666 .27679 L
.49668 .2682 L
.49671 .2725 L
.49673 .28109 L
.49675 .29398 L
.49677 .30257 L
.4968 .30257 L
.49682 .29828 L
.49684 .29398 L
.49686 .29828 L
.49689 .29828 L
.49691 .31117 L
.49693 .30687 L
.49695 .30687 L
.49697 .29828 L
.497 .29398 L
.49702 .28968 L
.49704 .28968 L
.49706 .28968 L
.49709 .28968 L
.49711 .28539 L
.49713 .28109 L
.49715 .28539 L
Mistroke
.49718 .28539 L
.4972 .29398 L
.49722 .29828 L
.49724 .29828 L
.49726 .30257 L
.49729 .29828 L
.49731 .29828 L
.49733 .30257 L
.49735 .30257 L
.49738 .30257 L
.4974 .30687 L
.49742 .30687 L
.49744 .30687 L
.49747 .30687 L
.49749 .30257 L
.49751 .30257 L
.49753 .29398 L
.49756 .28968 L
.49758 .28539 L
.4976 .28968 L
.49762 .29828 L
.49764 .29828 L
.49767 .30687 L
.49769 .29828 L
.49771 .29828 L
.49773 .29398 L
.49776 .28968 L
.49778 .29398 L
.4978 .29398 L
.49782 .28968 L
.49785 .28968 L
.49787 .28539 L
.49789 .28539 L
.49791 .29398 L
.49793 .28539 L
.49796 .29828 L
.49798 .29398 L
.498 .28539 L
.49802 .28539 L
.49805 .28539 L
.49807 .28968 L
.49809 .29828 L
.49811 .30687 L
.49814 .30257 L
.49816 .29828 L
.49818 .29398 L
.4982 .29398 L
.49822 .29398 L
.49825 .29398 L
.49827 .30257 L
Mistroke
.49829 .29828 L
.49831 .28968 L
.49834 .28539 L
.49836 .28109 L
.49838 .28539 L
.4984 .28539 L
.49843 .28968 L
.49845 .29398 L
.49847 .28968 L
.49849 .28968 L
.49852 .28539 L
.49854 .28968 L
.49856 .29828 L
.49858 .30687 L
.4986 .31117 L
.49863 .31546 L
.49865 .30687 L
.49867 .30257 L
.49869 .30257 L
.49872 .30257 L
.49874 .31117 L
.49876 .30257 L
.49878 .30257 L
.49881 .29398 L
.49883 .29398 L
.49885 .28968 L
.49887 .28968 L
.49889 .28968 L
.49892 .28968 L
.49894 .28968 L
.49896 .28539 L
.49898 .28539 L
.49901 .28539 L
.49903 .28968 L
.49905 .29398 L
.49907 .29828 L
.4991 .29828 L
.49912 .29828 L
.49914 .29398 L
.49916 .28968 L
.49919 .29398 L
.49921 .29828 L
.49923 .29828 L
.49925 .29828 L
.49927 .29398 L
.4993 .28968 L
.49932 .28539 L
.49934 .29398 L
.49936 .28968 L
.49939 .29398 L
Mistroke
.49941 .28968 L
.49943 .28968 L
.49945 .28539 L
.49948 .28968 L
.4995 .28968 L
.49952 .29828 L
.49954 .29828 L
.49956 .30257 L
.49959 .29828 L
.49961 .28968 L
.49963 .28968 L
.49965 .28968 L
.49968 .29828 L
.4997 .30257 L
.49972 .29828 L
.49974 .29828 L
.49977 .28968 L
.49979 .28968 L
.49981 .28968 L
.49983 .29828 L
.49985 .30257 L
.49988 .30257 L
.4999 .29828 L
.49992 .29828 L
.49994 .29828 L
.49997 .29828 L
.49999 .30687 L
.50001 .30687 L
.50003 .31117 L
.50006 .30687 L
.50008 .29828 L
.5001 .29398 L
.50012 .29398 L
.50015 .29398 L
.50017 .29828 L
.50019 .30257 L
.50021 .29828 L
.50023 .29398 L
.50026 .28539 L
.50028 .28539 L
.5003 .28539 L
.50032 .29398 L
.50035 .29828 L
.50037 .29828 L
.50039 .29828 L
.50041 .29398 L
.50044 .29398 L
.50046 .29398 L
.50048 .30257 L
.5005 .30687 L
Mistroke
.50052 .30257 L
.50055 .29398 L
.50057 .29398 L
.50059 .29398 L
.50061 .28539 L
.50064 .28968 L
.50066 .29398 L
.50068 .29828 L
.5007 .29398 L
.50073 .29398 L
.50075 .28968 L
.50077 .28109 L
.50079 .28539 L
.50081 .28968 L
.50084 .29828 L
.50086 .30257 L
.50088 .30257 L
.5009 .29828 L
.50093 .29398 L
.50095 .29828 L
.50097 .29828 L
.50099 .30687 L
.50102 .30687 L
.50104 .30687 L
.50106 .29828 L
.50108 .29398 L
.50111 .28968 L
.50113 .29398 L
.50115 .29398 L
.50117 .30257 L
.50119 .29828 L
.50122 .29398 L
.50124 .28968 L
.50126 .28539 L
.50128 .28968 L
.50131 .29398 L
.50133 .29828 L
.50135 .30257 L
.50137 .30687 L
.5014 .30257 L
.50142 .29828 L
.50144 .29828 L
.50146 .29398 L
.50148 .30257 L
.50151 .30257 L
.50153 .30687 L
.50155 .30257 L
.50157 .29398 L
.5016 .28968 L
.50162 .28539 L
Mistroke
.50164 .28968 L
.50166 .29828 L
.50169 .29828 L
.50171 .29398 L
.50173 .28968 L
.50175 .28539 L
.50178 .28539 L
.5018 .28968 L
.50182 .29828 L
.50184 .30687 L
.50186 .30257 L
.50189 .29828 L
.50191 .28968 L
.50193 .28968 L
.50195 .29398 L
.50198 .29828 L
.502 .30257 L
.50202 .29828 L
.50204 .29398 L
.50207 .28968 L
.50209 .28539 L
.50211 .28968 L
.50213 .29398 L
.50215 .30257 L
.50218 .29828 L
.5022 .29828 L
.50222 .29398 L
.50224 .28968 L
.50227 .28968 L
.50229 .29828 L
.50231 .29828 L
.50233 .30687 L
.50236 .30257 L
.50238 .29828 L
.5024 .29398 L
.50242 .28968 L
.50244 .29398 L
.50247 .29398 L
.50249 .29828 L
.50251 .29828 L
.50253 .29828 L
.50256 .28968 L
.50258 .28968 L
.5026 .28539 L
.50262 .28968 L
.50265 .29828 L
.50267 .29828 L
.50269 .30257 L
.50271 .29828 L
.50274 .29398 L
Mistroke
.50276 .29398 L
.50278 .29398 L
.5028 .29828 L
.50282 .30257 L
.50285 .30687 L
.50287 .29828 L
.50289 .29398 L
.50291 .28539 L
.50294 .28539 L
.50296 .28968 L
.50298 .28968 L
.503 .29398 L
.50303 .29828 L
.50305 .29398 L
.50307 .28968 L
.50309 .28539 L
.50311 .28539 L
.50314 .28968 L
.50316 .29828 L
.50318 .29828 L
.5032 .29828 L
.50323 .29398 L
.50325 .29398 L
.50327 .29398 L
.50329 .28968 L
.50332 .29828 L
.50334 .29828 L
.50336 .29828 L
.50338 .29828 L
.50341 .29398 L
.50343 .28968 L
.50345 .29398 L
.50347 .29828 L
.50349 .29828 L
.50352 .29828 L
.50354 .29828 L
.50356 .29398 L
.50358 .29398 L
.50361 .28968 L
.50363 .29398 L
.50365 .29828 L
.50367 .30257 L
.5037 .30257 L
.50372 .29828 L
.50374 .28968 L
.50376 .28968 L
.50378 .28968 L
.50381 .29398 L
.50383 .29828 L
.50385 .29828 L
Mistroke
.50387 .29828 L
.5039 .29398 L
.50392 .28968 L
.50394 .28968 L
.50396 .29398 L
.50399 .29398 L
.50401 .29828 L
.50403 .29828 L
.50405 .30257 L
.50407 .29398 L
.5041 .29398 L
.50412 .29398 L
.50414 .29398 L
.50416 .30257 L
.50419 .30257 L
.50421 .30257 L
.50423 .29828 L
.50425 .29398 L
.50428 .28968 L
.5043 .28968 L
.50432 .29398 L
.50434 .29828 L
.50437 .30257 L
.50439 .29398 L
.50441 .28968 L
.50443 .28539 L
.50445 .28968 L
.50448 .29398 L
.5045 .29828 L
.50452 .29828 L
.50454 .29828 L
.50457 .29398 L
.50459 .28968 L
.50461 .29398 L
.50463 .29828 L
.50466 .30257 L
.50468 .30257 L
.5047 .29828 L
.50472 .29398 L
.50474 .28968 L
.50477 .28968 L
.50479 .29398 L
.50481 .29828 L
.50483 .29828 L
.50486 .29828 L
.50488 .29398 L
.5049 .28968 L
.50492 .28968 L
.50495 .29398 L
.50497 .29828 L
Mistroke
.50499 .29828 L
.50501 .29828 L
.50504 .29828 L
.50506 .29398 L
.50508 .28968 L
.5051 .28968 L
.50512 .29398 L
.50515 .29828 L
.50517 .29828 L
.50519 .29828 L
.50521 .29828 L
.50524 .29398 L
.50526 .28968 L
.50528 .29398 L
.5053 .29398 L
.50533 .29398 L
.50535 .30257 L
.50537 .30257 L
.50539 .29828 L
.50541 .29828 L
.50544 .29398 L
.50546 .29398 L
.50548 .29398 L
.5055 .29828 L
.50553 .30257 L
.50555 .30257 L
.50557 .30257 L
.50559 .29398 L
.50562 .28968 L
.50564 .28968 L
.50566 .29398 L
.50568 .29828 L
.5057 .30257 L
.50573 .29828 L
.50575 .29398 L
.50577 .28968 L
.50579 .28539 L
.50582 .29398 L
.50584 .29828 L
.50586 .30257 L
.50588 .30257 L
.50591 .29398 L
.50593 .29398 L
.50595 .28968 L
.50597 .29398 L
.506 .30257 L
.50602 .30257 L
.50604 .30257 L
.50606 .29828 L
.50608 .28968 L
Mistroke
.50611 .28539 L
.50613 .28968 L
.50615 .29828 L
.50617 .30257 L
.5062 .30257 L
.50622 .29398 L
.50624 .28539 L
.50626 .28109 L
.50629 .28968 L
.50631 .29398 L
.50633 .30257 L
.50635 .30257 L
.50637 .29398 L
.5064 .28968 L
.50642 .28539 L
.50644 .28968 L
.50646 .29828 L
.50649 .30257 L
.50651 .30257 L
.50653 .29828 L
.50655 .28968 L
.50658 .28968 L
.5066 .28968 L
.50662 .29828 L
.50664 .30257 L
.50667 .30257 L
.50669 .29828 L
.50671 .29398 L
.50673 .28968 L
.50675 .29398 L
.50678 .29398 L
.5068 .29828 L
.50682 .29828 L
.50684 .29828 L
.50687 .29828 L
.50689 .29398 L
.50691 .29398 L
.50693 .29398 L
.50696 .29398 L
.50698 .29398 L
.507 .29398 L
.50702 .29398 L
.50704 .29398 L
.50707 .29398 L
.50709 .28968 L
.50711 .28968 L
.50713 .29398 L
.50716 .29828 L
.50718 .29828 L
.5072 .29828 L
Mistroke
.50722 .29398 L
.50725 .28968 L
.50727 .28968 L
.50729 .29398 L
.50731 .30257 L
.50733 .30257 L
.50736 .29828 L
.50738 .28968 L
.5074 .28539 L
.50742 .28968 L
.50745 .29828 L
.50747 .30257 L
.50749 .29828 L
.50751 .29398 L
.50754 .28109 L
.50756 .28539 L
.50758 .28968 L
.5076 .30257 L
.50763 .29828 L
.50765 .29398 L
.50767 .29398 L
.50769 .30257 L
.50771 .28109 L
.50774 .28109 L
.50776 .29398 L
.50778 .30257 L
.5078 .30687 L
.50783 .30257 L
.50785 .29828 L
.50787 .29828 L
.50789 .28968 L
.50792 .28968 L
.50794 .30257 L
.50796 .30257 L
.50798 .30257 L
.508 .29828 L
.50803 .29828 L
.50805 .29398 L
.50807 .29398 L
.50809 .29828 L
.50812 .29398 L
.50814 .29828 L
.50816 .29828 L
.50818 .29398 L
.50821 .29398 L
.50823 .28968 L
.50825 .29398 L
.50827 .29398 L
.5083 .29828 L
.50832 .29828 L
Mistroke
.50834 .29828 L
.50836 .29398 L
.50838 .28968 L
.50841 .28968 L
.50843 .29828 L
.50845 .30257 L
.50847 .30257 L
.5085 .29828 L
.50852 .28968 L
.50854 .28539 L
.50856 .28968 L
.50859 .29828 L
.50861 .30687 L
.50863 .30257 L
.50865 .29398 L
.50867 .28539 L
.5087 .28109 L
.50872 .28539 L
.50874 .29828 L
.50876 .30687 L
.50879 .30257 L
.50881 .29398 L
.50883 .28109 L
.50885 .28109 L
.50888 .28968 L
.5089 .30257 L
.50892 .30687 L
.50894 .30257 L
.50896 .28968 L
.50899 .28109 L
.50901 .28539 L
.50903 .29828 L
.50905 .30687 L
.50908 .30687 L
.5091 .30257 L
.50912 .28968 L
.50914 .28539 L
.50917 .28968 L
.50919 .29828 L
.50921 .30687 L
.50923 .30687 L
.50926 .29828 L
.50928 .28968 L
.5093 .28968 L
.50932 .29398 L
.50934 .29828 L
.50937 .30257 L
.50939 .30257 L
.50941 .29398 L
.50943 .28968 L
Mistroke
.50946 .28968 L
.50948 .29398 L
.5095 .29828 L
.50952 .30257 L
.50955 .29828 L
.50957 .28968 L
.50959 .28968 L
.50961 .28968 L
.50963 .29828 L
.50966 .30257 L
.50968 .29828 L
.5097 .29828 L
.50972 .28968 L
.50975 .28968 L
.50977 .29398 L
.50979 .29828 L
.50981 .29828 L
.50984 .29828 L
.50986 .28968 L
.50988 .28968 L
.5099 .29398 L
.50993 .29828 L
.50995 .29828 L
.50997 .29828 L
.50999 .28968 L
.51001 .28539 L
.51004 .28539 L
.51006 .28968 L
.51008 .29398 L
.5101 .29828 L
.51013 .30257 L
.51015 .29398 L
.51017 .28968 L
.51019 .28968 L
.51022 .29398 L
.51024 .29828 L
.51026 .30257 L
.51028 .30257 L
.5103 .29828 L
.51033 .29398 L
.51035 .29398 L
.51037 .29398 L
.51039 .30257 L
.51042 .30257 L
.51044 .29828 L
.51046 .29828 L
.51048 .29398 L
.51051 .29828 L
.51053 .29828 L
.51055 .30257 L
Mistroke
.51057 .30257 L
.51059 .29828 L
.51062 .29398 L
.51064 .29398 L
.51066 .29828 L
.51068 .29828 L
.51071 .30257 L
.51073 .29828 L
.51075 .29398 L
.51077 .28968 L
.5108 .29398 L
.51082 .29828 L
.51084 .29828 L
.51086 .29828 L
.51089 .29828 L
.51091 .29398 L
.51093 .29398 L
.51095 .29828 L
.51097 .29828 L
.511 .29828 L
.51102 .29398 L
.51104 .28968 L
.51106 .29398 L
.51109 .29828 L
.51111 .29828 L
.51113 .29828 L
.51115 .29398 L
.51118 .28968 L
.5112 .28968 L
.51122 .29398 L
.51124 .29828 L
.51126 .29828 L
.51129 .29398 L
.51131 .28539 L
.51133 .28539 L
.51135 .28968 L
.51138 .29828 L
.5114 .30257 L
.51142 .29828 L
.51144 .29398 L
.51147 .28539 L
.51149 .28968 L
.51151 .29398 L
.51153 .30257 L
.51156 .30687 L
.51158 .30257 L
.5116 .29398 L
.51162 .28968 L
.51164 .29398 L
.51167 .29828 L
Mistroke
.51169 .30257 L
.51171 .30687 L
.51173 .30257 L
.51176 .29398 L
.51178 .28968 L
.5118 .29398 L
.51182 .29828 L
.51185 .30687 L
.51187 .30257 L
.51189 .29828 L
.51191 .29398 L
.51193 .28968 L
.51196 .28968 L
.51198 .29398 L
.512 .30257 L
.51202 .30257 L
.51205 .29828 L
.51207 .28968 L
.51209 .28539 L
.51211 .28968 L
.51214 .29828 L
.51216 .30687 L
.51218 .30257 L
.5122 .29828 L
.51222 .28968 L
.51225 .28539 L
.51227 .28968 L
.51229 .30257 L
.51231 .30257 L
.51234 .30257 L
.51236 .29398 L
.51238 .28539 L
.5124 .28539 L
.51243 .28539 L
.51245 .29398 L
.51247 .29828 L
.51249 .30257 L
.51252 .29828 L
.51254 .28968 L
.51256 .28109 L
.51258 .28539 L
.5126 .29398 L
.51263 .30257 L
.51265 .29828 L
.51267 .29398 L
.51269 .28968 L
.51272 .28539 L
.51274 .28968 L
.51276 .29828 L
.51278 .30257 L
Mistroke
.51281 .30257 L
.51283 .29398 L
.51285 .28968 L
.51287 .29398 L
.51289 .29398 L
.51292 .30257 L
.51294 .30257 L
.51296 .30257 L
.51298 .29398 L
.51301 .29398 L
.51303 .29398 L
.51305 .29828 L
.51307 .30257 L
.5131 .30257 L
.51312 .29828 L
.51314 .29398 L
.51316 .28968 L
.51319 .29398 L
.51321 .29398 L
.51323 .29828 L
.51325 .29828 L
.51327 .29398 L
.5133 .28968 L
.51332 .28968 L
.51334 .29398 L
.51336 .29828 L
.51339 .30257 L
.51341 .29828 L
.51343 .29398 L
.51345 .28968 L
.51348 .28968 L
.5135 .28968 L
.51352 .29828 L
.51354 .30257 L
.51356 .29828 L
.51359 .28968 L
.51361 .28539 L
.51363 .28539 L
.51365 .29398 L
.51368 .30257 L
.5137 .29828 L
.51372 .29398 L
.51374 .28539 L
.51377 .28109 L
.51379 .28539 L
.51381 .29398 L
.51383 .29828 L
.51385 .29828 L
.51388 .29398 L
.5139 .28539 L
Mistroke
.51392 .28539 L
.51394 .28539 L
.51397 .29398 L
.51399 .29828 L
.51401 .30257 L
.51403 .29828 L
.51406 .28968 L
.51408 .28968 L
.5141 .28968 L
.51412 .29828 L
.51415 .30257 L
.51417 .30257 L
.51419 .30257 L
.51421 .29828 L
.51423 .29398 L
.51426 .29398 L
.51428 .29828 L
.5143 .29828 L
.51432 .30687 L
.51435 .30257 L
.51437 .29828 L
.51439 .29398 L
.51441 .28968 L
.51444 .28968 L
.51446 .29828 L
.51448 .30257 L
.5145 .30257 L
.51452 .29398 L
.51455 .28968 L
.51457 .28539 L
.51459 .28968 L
.51461 .29828 L
.51464 .30257 L
.51466 .30257 L
.51468 .29828 L
.5147 .28968 L
.51473 .28539 L
.51475 .29398 L
.51477 .29398 L
.51479 .29828 L
.51482 .30257 L
.51484 .29828 L
.51486 .28968 L
.51488 .28539 L
.5149 .28968 L
.51493 .29398 L
.51495 .29828 L
.51497 .29828 L
.51499 .29398 L
.51502 .28539 L
Mistroke
.51504 .28539 L
.51506 .28968 L
.51508 .29828 L
.51511 .30257 L
.51513 .29828 L
.51515 .29398 L
.51517 .28539 L
.51519 .28539 L
.51522 .29398 L
.51524 .30257 L
.51526 .30257 L
.51528 .29828 L
.51531 .29398 L
.51533 .28539 L
.51535 .28968 L
.51537 .29828 L
.5154 .30257 L
.51542 .30687 L
.51544 .30687 L
.51546 .29828 L
.51548 .28968 L
.51551 .28968 L
.51553 .29828 L
.51555 .30687 L
.51557 .30687 L
.5156 .30687 L
.51562 .29828 L
.51564 .28968 L
.51566 .28968 L
.51569 .29398 L
.51571 .30257 L
.51573 .30687 L
.51575 .30257 L
.51578 .29398 L
.5158 .28968 L
.51582 .28968 L
.51584 .29398 L
.51586 .29828 L
.51589 .30687 L
.51591 .30257 L
.51593 .29828 L
.51595 .28968 L
.51598 .28968 L
.516 .29398 L
.51602 .29828 L
.51604 .30257 L
.51607 .30257 L
.51609 .29398 L
.51611 .28968 L
.51613 .28539 L
Mistroke
.51615 .28968 L
.51618 .29398 L
.5162 .29828 L
.51622 .29828 L
.51624 .29398 L
.51627 .28968 L
.51629 .28539 L
.51631 .28968 L
.51633 .29828 L
.51636 .30257 L
.51638 .30257 L
.5164 .29828 L
.51642 .28968 L
.51644 .28539 L
.51647 .28968 L
.51649 .29398 L
.51651 .29828 L
.51653 .30257 L
.51656 .29828 L
.51658 .29398 L
.5166 .28968 L
.51662 .28968 L
.51665 .29398 L
.51667 .30257 L
.51669 .30257 L
.51671 .30257 L
.51674 .29828 L
.51676 .29398 L
.51678 .29398 L
.5168 .29398 L
.51682 .29828 L
.51685 .30257 L
.51687 .30257 L
.51689 .29828 L
.51691 .29828 L
.51694 .29398 L
.51696 .29398 L
.51698 .29398 L
.517 .29828 L
.51703 .30257 L
.51705 .29828 L
.51707 .29828 L
.51709 .29398 L
.51711 .28968 L
.51714 .28968 L
.51716 .29398 L
.51718 .29398 L
.5172 .29828 L
.51723 .29828 L
.51725 .29828 L
Mistroke
.51727 .29398 L
.51729 .28968 L
.51732 .28968 L
.51734 .29398 L
.51736 .29398 L
.51738 .29828 L
.51741 .29398 L
.51743 .29398 L
.51745 .28968 L
.51747 .28968 L
.51749 .28968 L
.51752 .29398 L
.51754 .29828 L
.51756 .29828 L
.51758 .29398 L
.51761 .29398 L
.51763 .28968 L
.51765 .28968 L
.51767 .29398 L
.5177 .29828 L
.51772 .29828 L
.51774 .29828 L
.51776 .29398 L
.51778 .28968 L
.51781 .28968 L
.51783 .29398 L
.51785 .29828 L
.51787 .30257 L
.5179 .30257 L
.51792 .29828 L
.51794 .29398 L
.51796 .28968 L
.51799 .29398 L
.51801 .29828 L
.51803 .30687 L
.51805 .30687 L
.51807 .30257 L
.5181 .29828 L
.51812 .29398 L
.51814 .29398 L
.51816 .29828 L
.51819 .30257 L
.51821 .30257 L
.51823 .30257 L
.51825 .29398 L
.51828 .29398 L
.5183 .29398 L
.51832 .29398 L
.51834 .29828 L
.51837 .30257 L
Mistroke
.51839 .29828 L
.51841 .29398 L
.51843 .29398 L
.51845 .28968 L
.51848 .29398 L
.5185 .29828 L
.51852 .29828 L
.51854 .29828 L
.51857 .29398 L
.51859 .29398 L
.51861 .28968 L
.51863 .29398 L
.51866 .29398 L
.51868 .29398 L
.5187 .29398 L
.51872 .29398 L
.51874 .29398 L
.51877 .28968 L
.51879 .28968 L
.51881 .29398 L
.51883 .29398 L
.51886 .29398 L
.51888 .29398 L
.5189 .29398 L
.51892 .29398 L
.51895 .29398 L
.51897 .28968 L
.51899 .28968 L
.51901 .29398 L
.51904 .29398 L
.51906 .29828 L
.51908 .29828 L
.5191 .29398 L
.51912 .28968 L
.51915 .29398 L
.51917 .29398 L
.51919 .29828 L
.51921 .30257 L
.51924 .30257 L
.51926 .29828 L
.51928 .29398 L
.5193 .29398 L
.51933 .29828 L
.51935 .30257 L
.51937 .30687 L
.51939 .30687 L
.51941 .29828 L
.51944 .29398 L
.51946 .29398 L
.51948 .29398 L
Mistroke
.5195 .29398 L
.51953 .29828 L
.51955 .30257 L
.51957 .30257 L
.51959 .29828 L
.51962 .29398 L
.51964 .29398 L
.51966 .29398 L
.51968 .29828 L
.5197 .29828 L
.51973 .29828 L
.51975 .29398 L
.51977 .29398 L
.51979 .29398 L
.51982 .29398 L
.51984 .29398 L
.51986 .29398 L
.51988 .29398 L
.51991 .29398 L
.51993 .29398 L
.51995 .29398 L
.51997 .29398 L
.52 .29398 L
.52002 .29398 L
.52004 .29398 L
.52006 .29398 L
.52008 .29398 L
.52011 .29398 L
.52013 .29398 L
.52015 .29398 L
.52017 .28968 L
.5202 .29398 L
.52022 .29398 L
.52024 .29398 L
.52026 .29828 L
.52029 .29398 L
.52031 .28968 L
.52033 .28968 L
.52035 .28968 L
.52037 .29398 L
.5204 .29828 L
.52042 .30257 L
.52044 .29828 L
.52046 .29398 L
.52049 .29398 L
.52051 .29398 L
.52053 .29828 L
.52055 .30257 L
.52058 .30257 L
.5206 .30257 L
Mistroke
.52062 .29828 L
.52064 .29398 L
.52067 .29398 L
.52069 .29828 L
.52071 .29828 L
.52073 .30257 L
.52075 .30257 L
.52078 .29828 L
.5208 .29828 L
.52082 .29398 L
.52084 .29398 L
.52087 .29398 L
.52089 .29828 L
.52091 .29828 L
.52093 .29828 L
.52096 .29398 L
.52098 .29398 L
.521 .28968 L
.52102 .29398 L
.52104 .29398 L
.52107 .29398 L
.52109 .29398 L
.52111 .29398 L
.52113 .29398 L
.52116 .28968 L
.52118 .28968 L
.5212 .29398 L
.52122 .29398 L
.52125 .29828 L
.52127 .29398 L
.52129 .29398 L
.52131 .28968 L
.52133 .28968 L
.52136 .29398 L
.52138 .29398 L
.5214 .29828 L
.52142 .29398 L
.52145 .29398 L
.52147 .28968 L
.52149 .28968 L
.52151 .29398 L
.52154 .29828 L
.52156 .29828 L
.52158 .29828 L
.5216 .29398 L
.52163 .28968 L
.52165 .28968 L
.52167 .28968 L
.52169 .29828 L
.52171 .30257 L
Mistroke
.52174 .30257 L
.52176 .29828 L
.52178 .29398 L
.5218 .28968 L
.52183 .29398 L
.52185 .29398 L
.52187 .30257 L
.52189 .30687 L
.52192 .30687 L
.52194 .30257 L
.52196 .29398 L
.52198 .28968 L
.522 .29398 L
.52203 .30257 L
.52205 .30687 L
.52207 .30687 L
.52209 .29828 L
.52212 .29398 L
.52214 .28968 L
.52216 .28968 L
.52218 .29828 L
.52221 .30257 L
.52223 .30687 L
.52225 .29398 L
.52227 .28968 L
.5223 .28539 L
.52232 .28968 L
.52234 .29398 L
.52236 .30257 L
.52238 .30257 L
.52241 .29398 L
.52243 .28539 L
.52245 .28539 L
.52247 .28539 L
.5225 .29398 L
.52252 .30257 L
.52254 .30257 L
.52256 .29398 L
.52259 .28539 L
.52261 .28109 L
.52263 .28968 L
.52265 .29398 L
.52267 .30257 L
.5227 .30257 L
.52272 .29398 L
.52274 .28539 L
.52276 .28109 L
.52279 .28968 L
.52281 .29828 L
.52283 .30257 L
Mistroke
.52285 .30257 L
.52288 .29828 L
.5229 .28968 L
.52292 .28539 L
.52294 .28968 L
.52296 .29828 L
.52299 .30257 L
.52301 .30257 L
.52303 .29828 L
.52305 .29398 L
.52308 .29398 L
.5231 .29398 L
.52312 .29828 L
.52314 .30257 L
.52317 .30257 L
.52319 .30257 L
.52321 .30257 L
.52323 .29828 L
.52326 .29828 L
.52328 .29828 L
.5233 .29828 L
.52332 .30257 L
.52334 .30257 L
.52337 .30257 L
.52339 .29828 L
.52341 .29398 L
.52343 .29398 L
.52346 .29398 L
.52348 .29828 L
.5235 .29828 L
.52352 .29828 L
.52355 .29398 L
.52357 .28968 L
.52359 .28968 L
.52361 .29398 L
.52363 .29828 L
.52366 .29828 L
.52368 .29398 L
.5237 .28968 L
.52372 .28539 L
.52375 .28968 L
.52377 .29398 L
.52379 .29828 L
.52381 .29398 L
.52384 .28968 L
.52386 .28539 L
.52388 .28539 L
.5239 .29398 L
.52393 .29828 L
.52395 .30257 L
Mistroke
.52397 .29398 L
.52399 .28968 L
.52401 .28539 L
.52404 .28539 L
.52406 .29398 L
.52408 .30257 L
.5241 .30257 L
.52413 .29828 L
.52415 .29398 L
.52417 .28968 L
.52419 .28968 L
.52422 .28968 L
.52424 .29828 L
.52426 .30257 L
.52428 .30687 L
.5243 .30257 L
.52433 .29398 L
.52435 .28968 L
.52437 .28968 L
.52439 .29828 L
.52442 .30687 L
.52444 .31117 L
.52446 .30687 L
.52448 .29828 L
.52451 .28968 L
.52453 .29398 L
.52455 .30257 L
.52457 .30687 L
.52459 .31546 L
.52462 .30257 L
.52464 .30257 L
.52466 .28539 L
.52468 .2725 L
.52471 .30687 L
.52473 .28968 L
.52475 .28968 L
.52477 .31546 L
.5248 .28968 L
.52482 .2682 L
.52484 .28968 L
.52486 .31546 L
.52489 .28539 L
.52491 .2725 L
.52493 .32405 L
.52495 .30257 L
.52497 .2682 L
.525 .29828 L
.52502 .29828 L
.52504 .31546 L
.52506 .29398 L
Mistroke
.52509 .28968 L
.52511 .31546 L
.52513 .27679 L
.52515 .28109 L
.52518 .30257 L
.5252 .28968 L
.52522 .32405 L
.52524 .29398 L
.52526 .25961 L
.52529 .31976 L
.52531 .28109 L
.52533 .2682 L
.52535 .31976 L
.52538 .29398 L
.5254 .29398 L
.52542 .29828 L
.52544 .28968 L
.52547 .30257 L
.52549 .28968 L
.52551 .29398 L
.52553 .29828 L
.52556 .28968 L
.52558 .29398 L
.5256 .30687 L
.52562 .30257 L
.52564 .29828 L
.52567 .30257 L
.52569 .28968 L
.52571 .30257 L
.52573 .29828 L
.52576 .29398 L
.52578 .30257 L
.5258 .30257 L
.52582 .28968 L
.52585 .29828 L
.52587 .30687 L
.52589 .28968 L
.52591 .29828 L
.52593 .30687 L
.52596 .28109 L
.52598 .30257 L
.526 .29398 L
.52602 .2725 L
.52605 .31546 L
.52607 .28968 L
.52609 .27679 L
.52611 .31976 L
.52614 .28968 L
.52616 .2682 L
.52618 .31546 L
Mistroke
.5262 .29828 L
.52622 .26391 L
.52625 .33265 L
.52627 .29398 L
.52629 .25961 L
.52631 .32405 L
.52634 .2682 L
.52636 .26391 L
.52638 .32405 L
.5264 .2725 L
.52643 .30257 L
.52645 .31117 L
.52647 .25961 L
.52649 .30257 L
.52652 .28968 L
.52654 .28968 L
.52656 .29828 L
.52658 .29828 L
.5266 .28968 L
.52663 .28968 L
.52665 .28539 L
.52667 .29398 L
.52669 .29828 L
.52672 .29828 L
.52674 .30257 L
.52676 .28539 L
.52678 .29828 L
.52681 .29398 L
.52683 .28968 L
.52685 .31546 L
.52687 .29398 L
.52689 .30257 L
.52692 .31546 L
.52694 .28968 L
.52696 .29828 L
.52698 .29398 L
.52701 .30257 L
.52703 .29398 L
.52705 .29398 L
.52707 .31117 L
.5271 .29828 L
.52712 .31546 L
.52714 .31546 L
.52716 .2725 L
.52719 .30257 L
.52721 .29828 L
.52723 .28109 L
.52725 .30687 L
.52727 .29398 L
.5273 .30257 L
Mistroke
.52732 .29828 L
.52734 .29828 L
.52736 .28968 L
.52739 .28109 L
.52741 .31546 L
.52743 .28109 L
.52745 .28968 L
.52748 .31117 L
.5275 .27679 L
.52752 .30257 L
.52754 .28539 L
.52756 .29828 L
.52759 .31546 L
.52761 .2682 L
.52763 .31117 L
.52765 .29398 L
.52768 .2682 L
.5277 .30257 L
.52772 .32405 L
.52774 .28539 L
.52777 .28109 L
.52779 .31976 L
.52781 .2725 L
.52783 .2725 L
.52785 .28968 L
.52788 .28539 L
.5279 .31546 L
.52792 .29828 L
.52794 .28968 L
.52797 .30257 L
.52799 .2682 L
.52801 .28539 L
.52803 .30257 L
.52806 .28539 L
.52808 .31546 L
.5281 .31117 L
.52812 .28968 L
.52815 .31117 L
.52817 .29398 L
.52819 .28109 L
.52821 .30687 L
.52823 .30687 L
.52826 .29398 L
.52828 .30257 L
.5283 .30257 L
.52832 .29398 L
.52835 .30257 L
.52837 .30687 L
.52839 .28968 L
.52841 .31546 L
Mistroke
.52844 .31117 L
.52846 .2682 L
.52848 .30687 L
.5285 .31546 L
.52852 .27679 L
.52855 .30687 L
.52857 .31546 L
.52859 .29398 L
.52861 .28109 L
.52864 .29398 L
.52866 .30687 L
.52868 .28109 L
.5287 .30257 L
.52873 .30687 L
.52875 .30257 L
.52877 .28968 L
.52879 .28539 L
.52882 .30687 L
.52884 .28539 L
.52886 .30257 L
.52888 .29398 L
.5289 .28539 L
.52893 .32405 L
.52895 .32405 L
.52897 .2682 L
.52899 .27679 L
.52902 .31546 L
.52904 .28109 L
.52906 .27679 L
.52908 .30687 L
.52911 .29828 L
.52913 .29398 L
.52915 .29828 L
.52917 .28968 L
.52919 .30687 L
.52922 .30687 L
.52924 .28539 L
.52926 .29828 L
.52928 .30687 L
.52931 .28968 L
.52933 .30687 L
.52935 .29398 L
.52937 .29398 L
.5294 .31976 L
.52942 .25102 L
.52944 .30257 L
.52946 .31976 L
.52948 .2725 L
.52951 .29828 L
.52953 .32835 L
Mistroke
.52955 .30257 L
.52957 .27679 L
.5296 .33265 L
.52962 .31976 L
.52964 .24672 L
.52966 .31117 L
.52969 .30257 L
.52971 .2725 L
.52973 .31976 L
.52975 .28968 L
.52978 .28968 L
.5298 .31117 L
.52982 .29398 L
.52984 .2725 L
.52986 .30687 L
.52989 .29828 L
.52991 .27679 L
.52993 .30687 L
.52995 .29398 L
.52998 .29398 L
.53 .29828 L
.53002 .27679 L
.53004 .30687 L
.53007 .29398 L
.53009 .27679 L
.53011 .30687 L
.53013 .29828 L
.53015 .28968 L
.53018 .28968 L
.5302 .29828 L
.53022 .31976 L
.53024 .28109 L
.53027 .28109 L
.53029 .31976 L
.53031 .29828 L
.53033 .27679 L
.53036 .29398 L
.53038 .28968 L
.5304 .30257 L
.53042 .28109 L
.53045 .29398 L
.53047 .30687 L
.53049 .2682 L
.53051 .29398 L
.53053 .29398 L
.53056 .29398 L
.53058 .31117 L
.5306 .28968 L
.53062 .30257 L
.53065 .30257 L
Mistroke
.53067 .29398 L
.53069 .29828 L
.53071 .28968 L
.53074 .30687 L
.53076 .31117 L
.53078 .28539 L
.5308 .30687 L
.53082 .28539 L
.53085 .29398 L
.53087 .31546 L
.53089 .28968 L
.53091 .30257 L
.53094 .30257 L
.53096 .29398 L
.53098 .29828 L
.531 .29398 L
.53103 .28539 L
.53105 .29828 L
.53107 .30257 L
.53109 .28109 L
.53111 .29828 L
.53114 .29828 L
.53116 .29398 L
.53118 .28539 L
.5312 .28968 L
.53123 .29828 L
.53125 .29398 L
.53127 .28539 L
.53129 .29828 L
.53132 .29828 L
.53134 .28539 L
.53136 .27679 L
.53138 .31117 L
.53141 .29828 L
.53143 .29828 L
.53145 .29398 L
.53147 .28968 L
.53149 .30257 L
.53152 .27679 L
.53154 .29398 L
.53156 .29828 L
.53158 .27679 L
.53161 .29828 L
.53163 .29828 L
.53165 .28109 L
.53167 .28539 L
.5317 .29828 L
.53172 .29398 L
.53174 .28968 L
.53176 .28968 L
Mistroke
.53178 .29828 L
.53181 .29828 L
.53183 .28968 L
.53185 .28968 L
.53187 .29828 L
.5319 .31117 L
.53192 .28539 L
.53194 .28968 L
.53196 .31546 L
.53199 .29398 L
.53201 .28968 L
.53203 .30257 L
.53205 .30257 L
.53208 .28539 L
.5321 .31117 L
.53212 .31546 L
.53214 .28968 L
.53216 .30687 L
.53219 .29398 L
.53221 .29828 L
.53223 .29398 L
.53225 .30257 L
.53228 .30687 L
.5323 .2725 L
.53232 .30257 L
.53234 .28539 L
.53237 .28109 L
.53239 .31117 L
.53241 .28109 L
.53243 .27679 L
.53245 .30257 L
.53248 .28539 L
.5325 .2725 L
.53252 .30257 L
.53254 .31117 L
.53257 .29398 L
.53259 .30257 L
.53261 .31546 L
.53263 .29398 L
.53266 .29828 L
.53268 .32405 L
.5327 .30257 L
.53272 .29828 L
.53274 .30687 L
.53277 .29398 L
.53279 .27679 L
.53281 .2725 L
.53283 .28539 L
.53286 .27679 L
.53288 .28109 L
Mistroke
.5329 .27679 L
.53292 .28109 L
.53295 .26391 L
.53297 .24672 L
.53299 .28109 L
.53301 .28968 L
.53304 .31117 L
.53306 .29828 L
.53308 .30257 L
.5331 .34983 L
.53312 .35413 L
.53315 .33265 L
.53317 .33265 L
.53319 .34983 L
.53321 .32405 L
.53324 .28109 L
.53326 .27679 L
.53328 .29828 L
.5333 .28968 L
.53333 .25531 L
.53335 .27679 L
.53337 .28109 L
.53339 .25531 L
.53341 .24672 L
.53344 .25102 L
.53346 .2682 L
.53348 .25961 L
.5335 .29398 L
.53353 .31117 L
.53355 .30687 L
.53357 .33694 L
.53359 .32405 L
.53362 .33265 L
.53364 .3885 L
.53366 .34554 L
.53368 .34554 L
.5337 .32405 L
.53373 .37561 L
.53375 .30687 L
.53377 .25961 L
.53379 .30687 L
.53382 .29398 L
.53384 .24672 L
.53386 .26391 L
.53388 .2725 L
.53391 .24242 L
.53393 .23383 L
.53395 .24242 L
.53397 .25961 L
.534 .25531 L
Mistroke
.53402 .24672 L
.53404 .28539 L
.53406 .30687 L
.53408 .31976 L
.53411 .33265 L
.53413 .32405 L
.53415 .35843 L
.53417 .3885 L
.5342 .37991 L
.53422 .34124 L
.53424 .33694 L
.53426 .34554 L
.53429 .29398 L
.53431 .25102 L
.53433 .27679 L
.53435 .28109 L
.53437 .24242 L
.5344 .22953 L
.53442 .26391 L
.53444 .24672 L
.53446 .21664 L
.53449 .24672 L
.53451 .25531 L
.53453 .24242 L
.53455 .29828 L
.53458 .31546 L
.5346 .30687 L
.53462 .36272 L
.53464 .34554 L
.53467 .34983 L
.53469 .41857 L
.53471 .3842 L
.53473 .31976 L
.53475 .37561 L
.53478 .32405 L
.5348 .23813 L
.53482 .28968 L
.53484 .27679 L
.53487 .22953 L
.53489 .25961 L
.53491 .24672 L
.53493 .22953 L
.53496 .23383 L
.53498 .22524 L
.535 .23813 L
.53502 .23813 L
.53504 .28109 L
.53507 .30687 L
.53509 .31546 L
.53511 .35413 L
Mistroke
.53513 .32835 L
.53516 .36272 L
.53518 .46583 L
.5352 .37561 L
.53522 .29398 L
.53525 .41428 L
.53527 .32835 L
.53529 .18657 L
.53531 .28539 L
.53533 .29828 L
.53536 .22953 L
.53538 .23813 L
.5354 .23383 L
.53542 .23383 L
.53545 .22094 L
.53547 .20376 L
.53549 .25102 L
.53551 .2682 L
.53554 .2725 L
.53556 .28968 L
.53558 .32405 L
.5356 .37561 L
.53563 .35843 L
.53565 .35843 L
.53567 .44865 L
.53569 .40139 L
.53571 .29828 L
.53574 .34554 L
.53576 .32405 L
.53578 .24242 L
.5358 .2682 L
.53583 .2682 L
.53585 .25531 L
.53587 .25102 L
.53589 .21664 L
.53592 .22953 L
.53594 .24242 L
.53596 .21235 L
.53598 .23813 L
.536 .28109 L
.53603 .27679 L
.53605 .27679 L
.53607 .30257 L
.53609 .33694 L
.53612 .37991 L
.53614 .35843 L
.53616 .3842 L
.53618 .47013 L
.53621 .37131 L
.53623 .2725 L
Mistroke
.53625 .37131 L
.53627 .31117 L
.5363 .19087 L
.53632 .26391 L
.53634 .28539 L
.53636 .24242 L
.53638 .22094 L
.53641 .20805 L
.53643 .23813 L
.53645 .23813 L
.53647 .19087 L
.5365 .23383 L
.53652 .29398 L
.53654 .29398 L
.53656 .30257 L
.53659 .37991 L
.53661 .3842 L
.53663 .39709 L
.53665 .45724 L
.53667 .3842 L
.5367 .30687 L
.53672 .34983 L
.53674 .29398 L
.53676 .20376 L
.53679 .25961 L
.53681 .27679 L
.53683 .23813 L
.53685 .23383 L
.53688 .22953 L
.5369 .22524 L
.53692 .22524 L
.53694 .20376 L
.53696 .22953 L
.53699 .2725 L
.53701 .30257 L
.53703 .33694 L
.53705 .36702 L
.53708 .3842 L
.5371 .44435 L
.53712 .45724 L
.53714 .34983 L
.53717 .30687 L
.53719 .36272 L
.53721 .26391 L
.53723 .17798 L
.53726 .27679 L
.53728 .29828 L
.5373 .23813 L
.53732 .23383 L
.53734 .24672 L
Mistroke
.53737 .25531 L
.53739 .22094 L
.53741 .20376 L
.53743 .25102 L
.53746 .28968 L
.53748 .32405 L
.5375 .33265 L
.53752 .34124 L
.53755 .40139 L
.53757 .48302 L
.53759 .40569 L
.53761 .28539 L
.53763 .34983 L
.53766 .35413 L
.53768 .16938 L
.5377 .18227 L
.53772 .31976 L
.53775 .27679 L
.53777 .21664 L
.53779 .24242 L
.53781 .2682 L
.53784 .24242 L
.53786 .19516 L
.53788 .22094 L
.5379 .28539 L
.53793 .31117 L
.53795 .34124 L
.53797 .35843 L
.53799 .35413 L
.53801 .45724 L
.53804 .47872 L
.53806 .29828 L
.53808 .28539 L
.5381 .36272 L
.53813 .21235 L
.53815 .14361 L
.53817 .2682 L
.53819 .29828 L
.53822 .25531 L
.53824 .22953 L
.53826 .25531 L
.53828 .2682 L
.5383 .22953 L
.53833 .22953 L
.53835 .28109 L
.53837 .32405 L
.53839 .32405 L
.53842 .35413 L
.53844 .34554 L
.53846 .34554 L
Mistroke
.53848 .45295 L
.53851 .47872 L
.53853 .30687 L
.53855 .25531 L
.53857 .34983 L
.53859 .23813 L
.53862 .13931 L
.53864 .25531 L
.53866 .31117 L
.53868 .25531 L
.53871 .23813 L
.53873 .25102 L
.53875 .27679 L
.53877 .2682 L
.5388 .23813 L
.53882 .30687 L
.53884 .37991 L
.53886 .34124 L
.53889 .31976 L
.53891 .40139 L
.53893 .47872 L
.53895 .37991 L
.53897 .25531 L
.539 .2725 L
.53902 .2725 L
.53904 .17798 L
.53906 .16938 L
.53909 .26391 L
.53911 .29828 L
.53913 .25961 L
.53915 .23813 L
.53918 .25531 L
.5392 .28109 L
.53922 .28539 L
.53924 .32835 L
.53926 .36702 L
.53929 .35413 L
.53931 .37131 L
.53933 .41428 L
.53935 .45295 L
.53938 .35843 L
.5394 .21235 L
.53942 .25961 L
.53944 .26391 L
.53947 .13072 L
.53949 .17368 L
.53951 .2725 L
.53953 .26391 L
.53956 .24242 L
.53958 .24242 L
Mistroke
.5396 .28968 L
.53962 .31546 L
.53964 .33265 L
.53967 .36702 L
.53969 .36272 L
.53971 .36272 L
.53973 .42287 L
.53976 .44006 L
.53978 .36272 L
.5398 .25102 L
.53982 .2682 L
.53985 .28539 L
.53987 .16079 L
.53989 .1479 L
.53991 .26391 L
.53993 .28109 L
.53996 .22094 L
.53998 .20805 L
.54 .27679 L
.54002 .31976 L
.54005 .29828 L
.54007 .34983 L
.54009 .44006 L
.54011 .41857 L
.54014 .41428 L
.54016 .47013 L
.54018 .34124 L
.5402 .17798 L
.54022 .25102 L
.54025 .23813 L
.54027 .12642 L
.54029 .19516 L
.54031 .25531 L
.54034 .25531 L
.54036 .25102 L
.54038 .24242 L
.5404 .27679 L
.54043 .33265 L
.54045 .35413 L
.54047 .34124 L
.54049 .36272 L
.54052 .39709 L
.54054 .41857 L
.54056 .43146 L
.54058 .31546 L
.5406 .19516 L
.54063 .26391 L
.54065 .23813 L
.54067 .12212 L
.54069 .19516 L
Mistroke
.54072 .27679 L
.54074 .25102 L
.54076 .25102 L
.54078 .21664 L
.54081 .23383 L
.54083 .29398 L
.54085 .36702 L
.54087 .40569 L
.54089 .3885 L
.54092 .37131 L
.54094 .44435 L
.54096 .47013 L
.54098 .28109 L
.54101 .1565 L
.54103 .27679 L
.54105 .25102 L
.54107 .12212 L
.5411 .17368 L
.54112 .25961 L
.54114 .2725 L
.54116 .24242 L
.54119 .25531 L
.54121 .37561 L
.54123 .45724 L
.54125 .3928 L
.54127 .32405 L
.5413 .3842 L
.54132 .44865 L
.54134 .33694 L
.54136 .17798 L
.54139 .21664 L
.54141 .28968 L
.54143 .20376 L
.54145 .1565 L
.54148 .21664 L
.5415 .27679 L
.54152 .24672 L
.54154 .23383 L
.54156 .32405 L
.54159 .42717 L
.54161 .40569 L
.54163 .37131 L
.54165 .40569 L
.54168 .41857 L
.5417 .35413 L
.54172 .24672 L
.54174 .19516 L
.54177 .21664 L
.54179 .17368 L
.54181 .1479 L
Mistroke
.54183 .19516 L
.54185 .22524 L
.54188 .25102 L
.5419 .28109 L
.54192 .31546 L
.54194 .40998 L
.54197 .47013 L
.54199 .36272 L
.54201 .33265 L
.54203 .44006 L
.54206 .42717 L
.54208 .28109 L
.5421 .18227 L
.54212 .19516 L
.54215 .24242 L
.54217 .18227 L
.54219 .13931 L
.54221 .21235 L
.54223 .26391 L
.54226 .23383 L
.54228 .24672 L
.5423 .34554 L
.54232 .47013 L
.54235 .46583 L
.54237 .41428 L
.54239 .42717 L
.54241 .42717 L
.54244 .33694 L
.54246 .22094 L
.54248 .18657 L
.5425 .21235 L
.54252 .19516 L
.54255 .16079 L
.54257 .18227 L
.54259 .24672 L
.54261 .27679 L
.54264 .25961 L
.54266 .28968 L
.54268 .40139 L
.5427 .48732 L
.54273 .40139 L
.54275 .33265 L
.54277 .43576 L
.54279 .47872 L
.54282 .2725 L
.54284 .12212 L
.54286 .24242 L
.54288 .28109 L
.5429 .12212 L
.54293 .11783 L
Mistroke
.54295 .25102 L
.54297 .29828 L
.54299 .23813 L
.54302 .22953 L
.54304 .37991 L
.54306 .52598 L
.54308 .44435 L
.54311 .30257 L
.54313 .30257 L
.54315 .3842 L
.54317 .47443 L
.54319 .29398 L
.54322 .10494 L
.54324 .18227 L
.54326 .30687 L
.54328 .21664 L
.54331 .13931 L
.54333 .22953 L
.54335 .33694 L
.54337 .29398 L
.5434 .17368 L
.54342 .28539 L
.54344 .52598 L
.54346 .46583 L
.54348 .24242 L
.54351 .36272 L
.54353 .52169 L
.54355 .36702 L
.54357 .1522 L
.5436 .16509 L
.54362 .28109 L
.54364 .22524 L
.54366 .10924 L
.54369 .18227 L
.54371 .29828 L
.54373 .31546 L
.54375 .2725 L
.54378 .37131 L
.5438 .53887 L
.54382 .43576 L
.54384 .27679 L
.54386 .41428 L
.54389 .43576 L
.54391 .24242 L
.54393 .18227 L
.54395 .19946 L
.54398 .24672 L
.544 .24242 L
.54402 .17368 L
.54404 .22524 L
Mistroke
.54407 .29398 L
.54409 .25531 L
.54411 .25102 L
.54413 .34983 L
.54415 .48302 L
.54418 .46154 L
.5442 .37991 L
.54422 .42287 L
.54424 .40569 L
.54427 .22953 L
.54429 .13931 L
.54431 .17368 L
.54433 .20805 L
.54436 .19516 L
.54438 .17798 L
.5444 .22953 L
.54442 .28968 L
.54445 .30687 L
.54447 .28539 L
.54449 .32405 L
.54451 .5045 L
.54453 .47013 L
.54456 .25961 L
.54458 .37561 L
.5446 .47443 L
.54462 .23813 L
.54465 .11783 L
.54467 .19087 L
.54469 .23813 L
.54471 .22094 L
.54474 .16079 L
.54476 .17798 L
.54478 .28539 L
.5448 .32405 L
.54482 .28539 L
.54485 .37131 L
.54487 .53458 L
.54489 .44865 L
.54491 .34983 L
.54494 .43576 L
.54496 .35843 L
.54498 .17798 L
.545 .16079 L
.54503 .16509 L
.54505 .18657 L
.54507 .20376 L
.54509 .20376 L
.54511 .26391 L
.54514 .33694 L
.54516 .33265 L
Mistroke
.54518 .2725 L
.5452 .40998 L
.54523 .56036 L
.54525 .3842 L
.54527 .28109 L
.54529 .44435 L
.54532 .35843 L
.54534 .1479 L
.54536 .13501 L
.54538 .18657 L
.54541 .21664 L
.54543 .19946 L
.54545 .17368 L
.54547 .23383 L
.54549 .23383 L
.54552 .31546 L
.54554 .31976 L
.54556 .34983 L
.54558 .48732 L
.54561 .47872 L
.54563 .33694 L
.54565 .37561 L
.54567 .3928 L
.5457 .24242 L
.54572 .16938 L
.54574 .16509 L
.54576 .19087 L
.54578 .21235 L
.54581 .20376 L
.54583 .24672 L
.54585 .2682 L
.54587 .25531 L
.5459 .28539 L
.54592 .37991 L
.54594 .5045 L
.54596 .41857 L
.54599 .33265 L
.54601 .45295 L
.54603 .37991 L
.54605 .1565 L
.54608 .16509 L
.5461 .21664 L
.54612 .18657 L
.54614 .17798 L
.54616 .22953 L
.54619 .28968 L
.54621 .32835 L
.54623 .31117 L
.54625 .21664 L
.54628 .34124 L
Mistroke
.5463 .58613 L
.54632 .40569 L
.54634 .18657 L
.54637 .43146 L
.54639 .49591 L
.54641 .19946 L
.54643 .07916 L
.54645 .18227 L
.54648 .25531 L
.5465 .20805 L
.54652 .16079 L
.54654 .23383 L
.54657 .36272 L
.54659 .35843 L
.54661 .25102 L
.54663 .34983 L
.54666 .54747 L
.54668 .41857 L
.5467 .2682 L
.54672 .39709 L
.54674 .40569 L
.54677 .20376 L
.54679 .12642 L
.54681 .18227 L
.54683 .24242 L
.54686 .22953 L
.54688 .19946 L
.5469 .23383 L
.54692 .31546 L
.54695 .33694 L
.54697 .24242 L
.54699 .29398 L
.54701 .56036 L
.54704 .46154 L
.54706 .23383 L
.54708 .39709 L
.5471 .44865 L
.54712 .19946 L
.54715 .11783 L
.54717 .16079 L
.54719 .22524 L
.54721 .23383 L
.54724 .18227 L
.54726 .23383 L
.54728 .35413 L
.5473 .34554 L
.54733 .21235 L
.54735 .33265 L
.54737 .60332 L
.54739 .39709 L
Mistroke
.54741 .17368 L
.54744 .45295 L
.54746 .46154 L
.54748 .1522 L
.5475 .1522 L
.54753 .23383 L
.54755 .23813 L
.54757 .22524 L
.54759 .19516 L
.54762 .25102 L
.54764 .35413 L
.54766 .31117 L
.54768 .28109 L
.54771 .49161 L
.54773 .51739 L
.54775 .2682 L
.54777 .33265 L
.54779 .47872 L
.54782 .2725 L
.54784 .13501 L
.54786 .13501 L
.54788 .16938 L
.54791 .21664 L
.54793 .25102 L
.54795 .22953 L
.54797 .21664 L
.548 .28539 L
.54802 .33265 L
.54804 .28539 L
.54806 .32405 L
.54808 .50021 L
.54811 .45295 L
.54813 .30257 L
.54815 .39709 L
.54817 .40139 L
.5482 .17368 L
.54822 .1479 L
.54824 .20805 L
.54826 .18657 L
.54829 .20805 L
.54831 .2682 L
.54833 .28968 L
.54835 .31976 L
.54837 .31117 L
.5484 .22953 L
.54842 .31976 L
.54844 .56895 L
.54846 .3842 L
.54849 .16938 L
.54851 .44006 L
Mistroke
.54853 .47443 L
.54855 .16509 L
.54858 .10924 L
.5486 .19516 L
.54862 .25102 L
.54864 .23383 L
.54867 .17798 L
.54869 .26391 L
.54871 .40139 L
.54873 .37561 L
.54875 .25531 L
.54878 .25961 L
.5488 .51739 L
.54882 .5088 L
.54884 .20805 L
.54887 .26391 L
.54889 .48732 L
.54891 .32405 L
.54893 .12212 L
.54896 .1522 L
.54898 .25531 L
.549 .2725 L
.54902 .21664 L
.54904 .21664 L
.54907 .31546 L
.54909 .37131 L
.54911 .29828 L
.54913 .22094 L
.54916 .48302 L
.54918 .52598 L
.5492 .19516 L
.54922 .31546 L
.54925 .52169 L
.54927 .28539 L
.54929 .12642 L
.54931 .17368 L
.54933 .22953 L
.54936 .28109 L
.54938 .21235 L
.5494 .18227 L
.54942 .31117 L
.54945 .3842 L
.54947 .28968 L
.54949 .20376 L
.54951 .47013 L
.54954 .55176 L
.54956 .21235 L
.54958 .29828 L
.5496 .52169 L
.54963 .24242 L
Mistroke
.54965 .10494 L
.54967 .21664 L
.54969 .22094 L
.54971 .24242 L
.54974 .25102 L
.54976 .21235 L
.54978 .30687 L
.5498 .36702 L
.54983 .24672 L
.54985 .30687 L
.54987 .56895 L
.54989 .40998 L
.54992 .18227 L
.54994 .43146 L
.54996 .44435 L
.54998 .16079 L
.55 .13072 L
.55003 .20376 L
.55005 .24672 L
.55007 .28539 L
.55009 .22094 L
.55012 .20805 L
.55014 .33694 L
.55016 .31976 L
.55018 .33265 L
.55021 .54747 L
.55023 .54747 L
.55025 .41857 L
.55027 .25531 L
.5503 .44865 L
.55032 .39709 L
.55034 .09635 L
.55036 .17368 L
.55038 .2682 L
.55041 .19087 L
.55043 .23383 L
.55045 .25961 L
.55047 .28539 L
.5505 .35413 L
.55052 .30687 L
.55054 .22524 L
.55056 .41857 L
.55059 .56895 L
.55061 .25961 L
.55063 .19946 L
.55065 .48302 L
.55067 .33694 L
.5507 .10924 L
.55072 .18227 L
.55074 .21235 L
Mistroke
.55076 .24672 L
.55079 .2682 L
.55081 .22953 L
.55083 .28968 L
.55085 .40569 L
.55088 .36272 L
.5509 .19087 L
.55092 .32835 L
.55094 .54317 L
.55096 .30257 L
.55099 .16938 L
.55101 .41428 L
.55103 .39709 L
.55105 .19087 L
.55108 .17368 L
.5511 .20805 L
.55112 .25961 L
.55114 .2682 L
.55117 .21664 L
.55119 .25531 L
.55121 .36272 L
.55123 .33265 L
.55126 .18657 L
.55128 .37131 L
.5513 .58613 L
.55132 .26391 L
.55134 .19516 L
.55137 .52598 L
.55139 .36702 L
.55141 .08775 L
.55143 .18227 L
.55146 .21664 L
.55148 .23383 L
.5515 .2682 L
.55152 .22524 L
.55155 .31117 L
.55157 .40569 L
.55159 .37131 L
.55161 .27679 L
.55163 .25531 L
.55166 .47443 L
.55168 .49161 L
.5517 .16509 L
.55172 .21235 L
.55175 .44865 L
.55177 .28109 L
.55179 .16938 L
.55181 .21235 L
.55184 .20805 L
.55186 .31546 L
Mistroke
.55188 .32405 L
.5519 .19516 L
.55193 .2682 L
.55195 .36272 L
.55197 .28968 L
.55199 .13072 L
.55201 .3885 L
.55204 .58184 L
.55206 .18657 L
.55208 .21235 L
.5521 .57754 L
.55213 .34554 L
.55215 .07916 L
.55217 .18227 L
.55219 .21664 L
.55222 .22094 L
.55224 .25961 L
.55226 .18657 L
.55228 .28539 L
.5523 .40569 L
.55233 .30257 L
.55235 .23383 L
.55237 .47443 L
.55239 .53458 L
.55242 .24242 L
.55244 .31976 L
.55246 .45295 L
.55248 .13931 L
.55251 .13501 L
.55253 .28968 L
.55255 .17798 L
.55257 .21235 L
.55259 .21235 L
.55262 .32835 L
.55264 .28109 L
.55266 .30257 L
.55268 .3885 L
.55271 .30687 L
.55273 .41428 L
.55275 .52169 L
.55277 .24242 L
.5528 .18657 L
.55282 .43146 L
.55284 .30257 L
.55286 .11353 L
.55289 .22953 L
.55291 .24242 L
.55293 .25961 L
.55295 .32835 L
.55297 .2725 L
Mistroke
.553 .25531 L
.55302 .30687 L
.55304 .29828 L
.55306 .31976 L
.55309 .47872 L
.55311 .36272 L
.55313 .23813 L
.55315 .41857 L
.55318 .40569 L
.5532 .14361 L
.55322 .14361 L
.55324 .25531 L
.55326 .23813 L
.55329 .25531 L
.55331 .27679 L
.55333 .28539 L
.55335 .34554 L
.55338 .34983 L
.5534 .19516 L
.55342 .31546 L
.55344 .56895 L
.55347 .34124 L
.55349 .13072 L
.55351 .43146 L
.55353 .41428 L
.55356 .12212 L
.55358 .18657 L
.5536 .20805 L
.55362 .18227 L
.55364 .32835 L
.55367 .31117 L
.55369 .24242 L
.55371 .37991 L
.55373 .44006 L
.55376 .28539 L
.55378 .16938 L
.5538 .37561 L
.55382 .51309 L
.55385 .21235 L
.55387 .20376 L
.55389 .44435 L
.55391 .34554 L
.55393 .23383 L
.55396 .22094 L
.55398 .1565 L
.554 .2682 L
.55402 .37561 L
.55405 .24242 L
.55407 .23813 L
.55409 .37561 L
Mistroke
.55411 .36272 L
.55414 .20805 L
.55416 .1479 L
.55418 .45295 L
.5542 .55176 L
.55422 .16509 L
.55425 .24242 L
.55427 .54317 L
.55429 .34554 L
.55431 .13072 L
.55434 .16079 L
.55436 .18227 L
.55438 .2682 L
.5544 .29398 L
.55443 .17368 L
.55445 .29828 L
.55447 .43146 L
.55449 .33694 L
.55452 .22524 L
.55454 .44865 L
.55456 .53458 L
.55458 .22524 L
.5546 .25102 L
.55463 .42287 L
.55465 .18227 L
.55467 .13501 L
.55469 .28109 L
.55472 .21235 L
.55474 .24672 L
.55476 .36272 L
.55478 .29828 L
.55481 .27679 L
.55483 .35843 L
.55485 .29828 L
.55487 .36702 L
.55489 .50021 L
.55492 .24672 L
.55494 .1479 L
.55496 .1479 L
.55498 .40139 L
.55501 .39709 L
.55503 .1522 L
.55505 .20805 L
.55507 .2725 L
.5551 .23383 L
.55512 .30687 L
.55514 .25961 L
.55516 .20376 L
.55519 .31546 L
.55521 .31546 L
Mistroke
.55523 .24242 L
.55525 .5045 L
.55527 .46154 L
.5553 .20376 L
.55532 .3842 L
.55534 .5045 L
.55536 .19946 L
.55539 .07486 L
.55541 .21664 L
.55543 .19946 L
.55545 .24672 L
.55548 .28109 L
.5555 .2725 L
.55552 .34983 L
.55554 .44006 L
.55556 .32405 L
.55559 .21235 L
.55561 .44006 L
.55563 .50021 L
.55565 .19516 L
.55568 .22094 L
.5557 .40998 L
.55572 .22094 L
.55574 .16938 L
.55577 .29398 L
.55579 .22524 L
.55581 .25531 L
.55583 .36702 L
.55585 .29398 L
.55588 .26391 L
.5559 .34124 L
.55592 .30687 L
.55594 .22953 L
.55597 .43576 L
.55599 .43576 L
.55601 .16509 L
.55603 .28539 L
.55606 .48732 L
.55608 .31117 L
.5561 .1522 L
.55612 .20376 L
.55615 .20805 L
.55617 .25531 L
.55619 .28968 L
.55621 .22094 L
.55623 .2682 L
.55626 .3842 L
.55628 .29828 L
.5563 .1565 L
.55632 .42287 L
Mistroke
.55635 .57324 L
.55637 .24672 L
.55639 .23813 L
.55641 .48302 L
.55644 .27679 L
.55646 .09205 L
.55648 .22094 L
.5565 .19946 L
.55652 .22953 L
.55655 .34983 L
.55657 .29828 L
.55659 .28968 L
.55661 .40139 L
.55664 .34554 L
.55666 .20805 L
.55668 .47013 L
.5567 .47872 L
.55673 .1565 L
.55675 .22524 L
.55677 .43576 L
.55679 .23383 L
.55682 .1522 L
.55684 .29828 L
.55686 .22524 L
.55688 .25102 L
.5569 .34124 L
.55693 .28109 L
.55695 .26391 L
.55697 .34554 L
.55699 .31117 L
.55702 .24672 L
.55704 .43576 L
.55706 .42287 L
.55708 .17798 L
.55711 .29398 L
.55713 .50021 L
.55715 .28109 L
.55717 .09635 L
.55719 .19516 L
.55722 .23383 L
.55724 .22953 L
.55726 .30257 L
.55728 .28109 L
.55731 .28109 L
.55733 .28539 L
.55735 .3928 L
.55737 .35413 L
.5574 .17798 L
.55742 .3928 L
.55744 .53887 L
Mistroke
.55746 .22524 L
.55748 .19946 L
.55751 .44435 L
.55753 .29828 L
.55755 .12212 L
.55757 .25102 L
.5576 .22953 L
.55762 .21664 L
.55764 .34124 L
.55766 .2725 L
.55769 .23383 L
.55771 .35843 L
.55773 .33265 L
.55775 .20805 L
.55778 .49591 L
.5578 .50021 L
.55782 .16938 L
.55784 .27679 L
.55786 .49591 L
.55789 .21664 L
.55791 .06198 L
.55793 .27679 L
.55795 .24242 L
.55798 .24242 L
.558 .33694 L
.55802 .29828 L
.55804 .29828 L
.55807 .40998 L
.55809 .30687 L
.55811 .25531 L
.55813 .47872 L
.55815 .3928 L
.55818 .17798 L
.5582 .31546 L
.55822 .37561 L
.55824 .16938 L
.55827 .21235 L
.55829 .31546 L
.55831 .20805 L
.55833 .25531 L
.55836 .35843 L
.55838 .30257 L
.5584 .25102 L
.55842 .2725 L
.55845 .30687 L
.55847 .46154 L
.55849 .39709 L
.55851 .19946 L
.55853 .30257 L
.55856 .45724 L
Mistroke
.55858 .31117 L
.5586 .11783 L
.55862 .18227 L
.55865 .23813 L
.55867 .27679 L
.55869 .26391 L
.55871 .24242 L
.55874 .2682 L
.55876 .36702 L
.55878 .30257 L
.5588 .25102 L
.55882 .49591 L
.55885 .47443 L
.55887 .22094 L
.55889 .28539 L
.55891 .41428 L
.55894 .17368 L
.55896 .10494 L
.55898 .2682 L
.559 .23813 L
.55903 .25961 L
.55905 .37131 L
.55907 .32835 L
.55909 .2725 L
.55911 .37561 L
.55914 .35843 L
.55916 .20376 L
.55918 .29398 L
.5592 .51309 L
.55923 .29828 L
.55925 .1522 L
.55927 .40569 L
.55929 .39709 L
.55932 .20805 L
.55934 .20376 L
.55936 .23813 L
.55938 .18657 L
.55941 .33265 L
.55943 .33265 L
.55945 .24242 L
.55947 .31117 L
.55949 .40139 L
.55952 .22094 L
.55954 .10064 L
.55956 .45295 L
.55958 .54317 L
.55961 .16509 L
.55963 .2682 L
.55965 .52169 L
.55967 .52169 L
Mistroke
.5597 .33265 L
.55972 .13072 L
.55974 .19516 L
.55976 .13931 L
.55978 .23813 L
.55981 .3885 L
.55983 .22524 L
.55985 .23813 L
.55987 .40998 L
.5599 .37991 L
.55992 .16509 L
.55994 .42287 L
.55996 .55606 L
.55999 .22094 L
.56001 .19516 L
.56003 .44865 L
.56005 .2725 L
.56008 .08775 L
.5601 .2725 L
.56012 .24672 L
.56014 .21235 L
.56016 .36702 L
.56019 .29398 L
.56021 .23813 L
.56023 .36702 L
.56025 .37561 L
.56028 .33265 L
.5603 .47013 L
.56032 .34554 L
.56034 .18227 L
.56037 .31546 L
.56039 .40569 L
.56041 .1565 L
.56043 .16938 L
.56045 .31976 L
.56048 .27679 L
.5605 .25531 L
.56052 .31546 L
.56054 .27679 L
.56057 .24242 L
.56059 .29828 L
.56061 .45295 L
.56063 .47872 L
.56066 .25961 L
.56068 .28539 L
.5607 .39709 L
.56072 .35413 L
.56074 .16079 L
.56077 .1479 L
.56079 .22094 L
Mistroke
.56081 .26391 L
.56083 .30687 L
.56086 .28539 L
.56088 .28539 L
.5609 .32835 L
.56092 .33694 L
.56095 .29828 L
.56097 .42287 L
.56099 .43146 L
.56101 .26391 L
.56104 .25961 L
.56106 .37131 L
.56108 .26391 L
.5611 .12642 L
.56112 .23813 L
.56115 .26391 L
.56117 .26391 L
.56119 .32835 L
.56121 .32405 L
.56124 .28539 L
.56126 .30257 L
.56128 .30257 L
.5613 .24242 L
.56133 .40998 L
.56135 .44006 L
.56137 .21664 L
.56139 .26391 L
.56141 .45724 L
.56144 .30687 L
.56146 .11783 L
.56148 .21235 L
.5615 .24242 L
.56153 .23383 L
.56155 .29398 L
.56157 .29828 L
.56159 .28968 L
.56162 .37131 L
.56164 .37131 L
.56166 .19516 L
.56168 .24672 L
.56171 .52169 L
.56173 .40139 L
.56175 .1565 L
.56177 .33694 L
.56179 .43146 L
.56182 .25102 L
.56184 .17368 L
.56186 .21235 L
.56188 .16509 L
.56191 .31976 L
Mistroke
.56193 .35843 L
.56195 .23813 L
.56197 .2682 L
.562 .40998 L
.56202 .2725 L
.56204 .2725 L
.56206 .12642 L
.56208 .45724 L
.56211 .52598 L
.56213 .17798 L
.56215 .25961 L
.56217 .49591 L
.5622 .28968 L
.56222 .12642 L
.56224 .25961 L
.56226 .17368 L
.56229 .19516 L
.56231 .35843 L
.56233 .26391 L
.56235 .22094 L
.56237 .36702 L
.5624 .35413 L
.56242 .22953 L
.56244 .48302 L
.56246 .45724 L
.56249 .22524 L
.56251 .26391 L
.56253 .40569 L
.56255 .22094 L
.56258 .1479 L
.5626 .28968 L
.56262 .21664 L
.56264 .22953 L
.56267 .34124 L
.56269 .30257 L
.56271 .24672 L
.56273 .34983 L
.56275 .32835 L
.56278 .34983 L
.5628 .43576 L
.56282 .32405 L
.56284 .22524 L
.56287 .32835 L
.56289 .40569 L
.56291 .20805 L
.56293 .16079 L
.56296 .24242 L
.56298 .2682 L
.563 .27679 L
.56302 .2725 L
Mistroke
.56304 .22524 L
.56307 .24672 L
.56309 .2682 L
.56311 .3885 L
.56313 .53458 L
.56316 .33694 L
.56318 .2725 L
.5632 .40998 L
.56322 .41428 L
.56325 .17368 L
.56327 .11783 L
.56329 .22094 L
.56331 .22094 L
.56334 .29828 L
.56336 .2682 L
.56338 .25961 L
.5634 .31976 L
.56342 .42287 L
.56345 .31117 L
.56347 .28968 L
.56349 .41857 L
.56351 .41428 L
.56354 .25102 L
.56356 .25102 L
.56358 .33694 L
.5636 .25102 L
.56363 .24672 L
.56365 .27679 L
.56367 .22094 L
.56369 .25961 L
.56371 .34124 L
.56374 .28109 L
.56376 .23813 L
.56378 .28539 L
.5638 .28968 L
.56383 .3928 L
.56385 .44006 L
.56387 .26391 L
.56389 .25961 L
.56392 .41857 L
.56394 .36272 L
.56396 .16938 L
.56398 .19516 L
.564 .23813 L
.56403 .24672 L
.56405 .28539 L
.56407 .27679 L
.56409 .25102 L
.56412 .30257 L
.56414 .31976 L
Mistroke
.56416 .18657 L
.56418 .3842 L
.56421 .52598 L
.56423 .2725 L
.56425 .25961 L
.56427 .46583 L
.5643 .3885 L
.56432 .16079 L
.56434 .21664 L
.56436 .23383 L
.56438 .18657 L
.56441 .18657 L
.56443 .33265 L
.56445 .30257 L
.56447 .23813 L
.5645 .32405 L
.56452 .3885 L
.56454 .21664 L
.56456 .23813 L
.56459 .48302 L
.56461 .43146 L
.56463 .22524 L
.56465 .34124 L
.56467 .40998 L
.5647 .2682 L
.56472 .21664 L
.56474 .23383 L
.56476 .16938 L
.56479 .2725 L
.56481 .34554 L
.56483 .22953 L
.56485 .22953 L
.56488 .34124 L
.5649 .2682 L
.56492 .28539 L
.56494 .51739 L
.56497 .35413 L
.56499 .20376 L
.56501 .34983 L
.56503 .44435 L
.56505 .23813 L
.56508 .18227 L
.5651 .2725 L
.56512 .20376 L
.56514 .25531 L
.56517 .27679 L
.56519 .22094 L
.56521 .22094 L
.56523 .32835 L
.56526 .36702 L
Mistroke
.56528 .44006 L
.5653 .36272 L
.56532 .31117 L
.56534 .34983 L
.56537 .36702 L
.56539 .28539 L
.56541 .17798 L
.56543 .25961 L
.56546 .24242 L
.56548 .25102 L
.5655 .25531 L
.56552 .28968 L
.56555 .27679 L
.56557 .29828 L
.56559 .32405 L
.56561 .30257 L
.56563 .36702 L
.56566 .3885 L
.56568 .31976 L
.5657 .30687 L
.56572 .3842 L
.56575 .31117 L
.56577 .21664 L
.56579 .25961 L
.56581 .26391 L
.56584 .23813 L
.56586 .26391 L
.56588 .28109 L
.5659 .25961 L
.56593 .2682 L
.56595 .26391 L
.56597 .25102 L
.56599 .44865 L
.56601 .41428 L
.56604 .25531 L
.56606 .31117 L
.56608 .42287 L
.5661 .34983 L
.56613 .19946 L
.56615 .23383 L
.56617 .20805 L
.56619 .25531 L
.56622 .28109 L
.56624 .22094 L
.56626 .22094 L
.56628 .29828 L
.5663 .28109 L
.56633 .29828 L
.56635 .43576 L
.56637 .39709 L
Mistroke
.56639 .30687 L
.56642 .34554 L
.56644 .41428 L
.56646 .28109 L
.56648 .20376 L
.56651 .25531 L
.56653 .20805 L
.56655 .24672 L
.56657 .28968 L
.56659 .2725 L
.56662 .23383 L
.56664 .31546 L
.56666 .32835 L
.56668 .28968 L
.56671 .37991 L
.56673 .36702 L
.56675 .28968 L
.56677 .28968 L
.5668 .31117 L
.56682 .37991 L
.56684 .29828 L
.56686 .24672 L
.56689 .30257 L
.56691 .26391 L
.56693 .24242 L
.56695 .27679 L
.56697 .2725 L
.567 .21664 L
.56702 .25961 L
.56704 .28109 L
.56706 .28539 L
.56709 .40998 L
.56711 .37131 L
.56713 .29828 L
.56715 .32405 L
.56718 .40569 L
.5672 .32405 L
.56722 .23383 L
.56724 .24672 L
.56726 .21235 L
.56729 .25531 L
.56731 .28539 L
.56733 .24672 L
.56735 .19946 L
.56738 .25961 L
.5674 .27679 L
.56742 .26391 L
.56744 .42287 L
.56747 .39709 L
.56749 .28539 L
Mistroke
.56751 .34554 L
.56753 .45724 L
.56756 .34124 L
.56758 .18657 L
.5676 .24242 L
.56762 .22953 L
.56764 .23813 L
.56767 .29828 L
.56769 .2682 L
.56771 .22094 L
.56773 .28968 L
.56776 .36272 L
.56778 .25102 L
.5678 .25531 L
.56782 .3885 L
.56785 .36702 L
.56787 .27679 L
.56789 .34983 L
.56791 .35843 L
.56793 .2682 L
.56796 .28109 L
.56798 .32405 L
.568 .22524 L
.56802 .22524 L
.56805 .31546 L
.56807 .25961 L
.56809 .23383 L
.56811 .29398 L
.56814 .2682 L
.56816 .2725 L
.56818 .37561 L
.5682 .34124 L
.56822 .2725 L
.56825 .31976 L
.56827 .39709 L
.56829 .33694 L
.56831 .25102 L
.56834 .26391 L
.56836 .24672 L
.56838 .29828 L
.5684 .29398 L
.56843 .24672 L
.56845 .22524 L
.56847 .25961 L
.56849 .28968 L
.56852 .31976 L
.56854 .34983 L
.56856 .31117 L
.56858 .29828 L
.5686 .34124 L
Mistroke
.56863 .3842 L
.56865 .31117 L
.56867 .25961 L
.56869 .2725 L
.56872 .2725 L
.56874 .28968 L
.56876 .28109 L
.56878 .27679 L
.56881 .25531 L
.56883 .30257 L
.56885 .32405 L
.56887 .2725 L
.56889 .2725 L
.56892 .33265 L
.56894 .31976 L
.56896 .30257 L
.56898 .32405 L
.56901 .33694 L
.56903 .30257 L
.56905 .2725 L
.56907 .31546 L
.5691 .28539 L
.56912 .29398 L
.56914 .29398 L
.56916 .29828 L
.56919 .2725 L
.56921 .26391 L
.56923 .27679 L
.56925 .2725 L
.56927 .25961 L
.5693 .32405 L
.56932 .31117 L
.56934 .2725 L
.56936 .30687 L
.56939 .34983 L
.56941 .34983 L
.56943 .30257 L
.56945 .29398 L
.56948 .2725 L
.5695 .28109 L
.56952 .30257 L
.56954 .28539 L
.56956 .2725 L
.56959 .26391 L
.56961 .27679 L
.56963 .26391 L
.56965 .29828 L
.56968 .34124 L
.5697 .29828 L
.56972 .30257 L
Mistroke
.56974 .31976 L
.56977 .35843 L
.56979 .31546 L
.56981 .29398 L
.56983 .29828 L
.56985 .28109 L
.56988 .30687 L
.5699 .30257 L
.56992 .28109 L
.56994 .26391 L
.56997 .28539 L
.56999 .30687 L
.57001 .2725 L
.57003 .29398 L
.57006 .32405 L
.57008 .28968 L
.5701 .30257 L
.57012 .32835 L
.57015 .34554 L
.57017 .29828 L
.57019 .29828 L
.57021 .30687 L
.57023 .28968 L
.57026 .30687 L
.57028 .30257 L
.5703 .2725 L
.57032 .25961 L
.57035 .27679 L
.57037 .2725 L
.57039 .28968 L
.57041 .32405 L
.57044 .28539 L
.57046 .2682 L
.57048 .29828 L
.5705 .34124 L
.57052 .32835 L
.57055 .31546 L
.57057 .29828 L
.57059 .2725 L
.57061 .29398 L
.57064 .29828 L
.57066 .2682 L
.57068 .25102 L
.5707 .2682 L
.57073 .2725 L
.57075 .27679 L
.57077 .31976 L
.57079 .30687 L
.57082 .2725 L
.57084 .30687 L
Mistroke
.57086 .36272 L
.57088 .35843 L
.5709 .30687 L
.57093 .29398 L
.57095 .28109 L
.57097 .30687 L
.57099 .33265 L
.57102 .29398 L
.57104 .25102 L
.57106 .26391 L
.57108 .29828 L
.57111 .30257 L
.57113 .2725 L
.57115 .30687 L
.57117 .30257 L
.57119 .28109 L
.57122 .30687 L
.57124 .33265 L
.57126 .33265 L
.57128 .28968 L
.57131 .30687 L
.57133 .30257 L
.57135 .30257 L
.57137 .31117 L
.5714 .27679 L
.57142 .2682 L
.57144 .2725 L
.57146 .28539 L
.57148 .2682 L
.57151 .2682 L
.57153 .28968 L
.57155 .31546 L
.57157 .2682 L
.5716 .27679 L
.57162 .31546 L
.57164 .34983 L
.57166 .31546 L
.57169 .29828 L
.57171 .27679 L
.57173 .27679 L
.57175 .29828 L
.57178 .28109 L
.5718 .24242 L
.57182 .25102 L
.57184 .27679 L
.57186 .2682 L
.57189 .2725 L
.57191 .31117 L
.57193 .29828 L
.57195 .28109 L
Mistroke
.57198 .31546 L
.572 .35413 L
.57202 .33694 L
.57204 .30257 L
.57207 .29398 L
.57209 .28968 L
.57211 .31117 L
.57213 .31976 L
.57215 .28109 L
.57218 .25531 L
.5722 .28109 L
.57222 .30687 L
.57224 .28539 L
.57227 .28109 L
.57229 .31546 L
.57231 .28539 L
.57233 .28109 L
.57236 .31546 L
.57238 .34124 L
.5724 .31546 L
.57242 .29398 L
.57245 .30687 L
.57247 .29398 L
.57249 .30687 L
.57251 .30687 L
.57253 .2725 L
.57256 .2725 L
.57258 .28539 L
.5726 .28109 L
.57262 .2725 L
.57265 .30687 L
.57267 .29398 L
.57269 .2682 L
.57271 .29828 L
.57274 .34124 L
.57276 .33694 L
.57278 .29828 L
.5728 .28968 L
.57282 .27679 L
.57285 .29398 L
.57287 .30257 L
.57289 .25961 L
.57291 .24242 L
.57294 .26391 L
.57296 .2725 L
.57298 .25961 L
.573 .28968 L
.57303 .31546 L
.57305 .2682 L
.57307 .28539 L
Mistroke
.57309 .32835 L
.57311 .35843 L
.57314 .31976 L
.57316 .29828 L
.57318 .28968 L
.5732 .28539 L
.57323 .32405 L
.57325 .30687 L
.57327 .26391 L
.57329 .2682 L
.57332 .28539 L
.57334 .30687 L
.57336 .28109 L
.57338 .29398 L
.57341 .31546 L
.57343 .27679 L
.57345 .30687 L
.57347 .31976 L
.57349 .33694 L
.57352 .30687 L
.57354 .29398 L
.57356 .31546 L
.57358 .29828 L
.57361 .31546 L
.57363 .29828 L
.57365 .26391 L
.57367 .28539 L
.5737 .28539 L
.57372 .28539 L
.57374 .2682 L
.57376 .30257 L
.57378 .30257 L
.57381 .2682 L
.57383 .30687 L
.57385 .33694 L
.57387 .33694 L
.5739 .33265 L
.57392 .29828 L
.57394 .29398 L
.57396 .28968 L
.57399 .28968 L
.57401 .30687 L
.57403 .2682 L
.57405 .24242 L
.57408 .26391 L
.5741 .2725 L
.57412 .27679 L
.57414 .29398 L
.57416 .30687 L
.57419 .2682 L
Mistroke
.57421 .27679 L
.57423 .32835 L
.57425 .36272 L
.57428 .32405 L
.5743 .29398 L
.57432 .28968 L
.57434 .28968 L
.57437 .31976 L
.57439 .30257 L
.57441 .26391 L
.57443 .25961 L
.57445 .28968 L
.57448 .30257 L
.5745 .27679 L
.57452 .29398 L
.57454 .30687 L
.57457 .28539 L
.57459 .30687 L
.57461 .32835 L
.57463 .33694 L
.57466 .29828 L
.57468 .30687 L
.5747 .31976 L
.57472 .30687 L
.57474 .31976 L
.57477 .29828 L
.57479 .2682 L
.57481 .28539 L
.57483 .28968 L
.57486 .28539 L
.57488 .27679 L
.5749 .31117 L
.57492 .28539 L
.57495 .2682 L
.57497 .31546 L
.57499 .34124 L
.57501 .32835 L
.57504 .29828 L
.57506 .28968 L
.57508 .28109 L
.5751 .30257 L
.57512 .30687 L
.57515 .25961 L
.57517 .25531 L
.57519 .28109 L
.57521 .2725 L
.57524 .25961 L
.57526 .28539 L
.57528 .31976 L
.5753 .2725 L
Mistroke
.57533 .28539 L
.57535 .31976 L
.57537 .34124 L
.57539 .33265 L
.57541 .30687 L
.57544 .29828 L
.57546 .29398 L
.57548 .32405 L
.5755 .29828 L
.57553 .25531 L
.57555 .2725 L
.57557 .28539 L
.57559 .29828 L
.57562 .28109 L
.57564 .2682 L
.57566 .31117 L
.57568 .28109 L
.57571 .28968 L
.57573 .31546 L
.57575 .32835 L
.57577 .32835 L
.57579 .29828 L
.57582 .31546 L
.57584 .29398 L
.57586 .31117 L
.57588 .32405 L
.57591 .27679 L
.57593 .28539 L
.57595 .28539 L
.57597 .28539 L
.576 .27679 L
.57602 .2682 L
.57604 .32405 L
.57606 .2725 L
.57608 .28109 L
.57611 .32405 L
.57613 .32835 L
.57615 .33265 L
.57617 .29828 L
.5762 .29828 L
.57622 .29828 L
.57624 .28109 L
.57626 .30257 L
.57629 .30257 L
.57631 .24242 L
.57633 .25961 L
.57635 .27679 L
.57637 .2682 L
.5764 .28539 L
.57642 .29398 L
Mistroke
.57644 .29398 L
.57646 .2682 L
.57649 .29828 L
.57651 .34983 L
.57653 .34124 L
.57655 .31117 L
.57658 .28539 L
.5766 .28539 L
.57662 .32405 L
.57664 .32405 L
.57667 .28109 L
.57669 .24672 L
.57671 .25961 L
.57673 .28109 L
.57675 .28539 L
.57678 .30687 L
.5768 .30257 L
.57682 .2682 L
.57684 .28109 L
.57687 .31546 L
.57689 .32835 L
.57691 .31546 L
.57693 .29398 L
.57696 .29828 L
.57698 .30257 L
.577 .32405 L
.57702 .30257 L
.57704 .2682 L
.57707 .28109 L
.57709 .28968 L
.57711 .28968 L
.57713 .28539 L
.57716 .30257 L
.57718 .27679 L
.5772 .2682 L
.57722 .31546 L
.57725 .34983 L
.57727 .33694 L
.57729 .29828 L
.57731 .28539 L
.57734 .28968 L
.57736 .31546 L
.57738 .31546 L
.5774 .2725 L
.57742 .25531 L
.57745 .2725 L
.57747 .28109 L
.57749 .2682 L
.57751 .26391 L
.57754 .31976 L
Mistroke
.57756 .27679 L
.57758 .26391 L
.5776 .33694 L
.57763 .34124 L
.57765 .33265 L
.57767 .29828 L
.57769 .31117 L
.57771 .30687 L
.57774 .30687 L
.57776 .31546 L
.57778 .25531 L
.5778 .25961 L
.57783 .29398 L
.57785 .27679 L
.57787 .2682 L
.57789 .21664 L
.57792 .30257 L
.57794 .36702 L
.57796 .25531 L
.57798 .31117 L
.578 .35413 L
.57803 .34983 L
.57805 .34983 L
.57807 .30687 L
.57809 .28539 L
.57812 .24672 L
.57814 .34983 L
.57816 .29398 L
.57818 .20376 L
.57821 .29398 L
.57823 .25961 L
.57825 .26391 L
.57827 .24242 L
.5783 .22524 L
.57832 .3885 L
.57834 .31546 L
.57836 .29828 L
.57838 .34983 L
.57841 .37131 L
.57843 .40139 L
.57845 .28109 L
.57847 .28968 L
.5785 .25961 L
.57852 .27679 L
.57854 .28968 L
.57856 .16938 L
.57859 .16938 L
.57861 .24242 L
.57863 .25961 L
.57865 .25102 L
Mistroke
.57867 .33694 L
.5787 .32405 L
.57872 .29828 L
.57874 .29398 L
.57876 .41428 L
.57879 .42287 L
.57881 .29828 L
.57883 .30687 L
.57885 .28539 L
.57888 .28539 L
.5789 .29398 L
.57892 .19946 L
.57894 .19946 L
.57897 .25102 L
.57899 .25961 L
.57901 .28539 L
.57903 .34124 L
.57905 .28539 L
.57908 .29828 L
.5791 .40569 L
.57912 .37131 L
.57914 .25531 L
.57917 .29398 L
.57919 .34124 L
.57921 .2725 L
.57923 .30687 L
.57926 .28968 L
.57928 .22953 L
.5793 .28539 L
.57932 .28968 L
.57934 .21235 L
.57937 .21664 L
.57939 .33694 L
.57941 .34983 L
.57943 .27679 L
.57946 .31976 L
.57948 .34124 L
.5795 .36272 L
.57952 .36272 L
.57955 .28109 L
.57957 .24242 L
.57959 .28968 L
.57961 .30687 L
.57963 .22094 L
.57966 .22094 L
.57968 .28968 L
.5797 .2725 L
.57972 .22953 L
.57975 .21664 L
.57977 .22953 L
Mistroke
.57979 .39709 L
.57981 .39709 L
.57984 .22953 L
.57986 .37991 L
.57988 .47872 L
.5799 .3928 L
.57993 .25961 L
.57995 .27679 L
.57997 .30257 L
.57999 .27679 L
.58001 .29398 L
.58004 .14361 L
.58006 .24242 L
.58008 .34983 L
.5801 .25531 L
.58013 .22953 L
.58015 .22524 L
.58017 .2725 L
.58019 .35843 L
.58022 .46154 L
.58024 .22524 L
.58026 .23383 L
.58028 .55176 L
.5803 .44006 L
.58033 .22953 L
.58035 .23813 L
.58037 .36702 L
.58039 .2725 L
.58042 .2682 L
.58044 .17368 L
.58046 .1565 L
.58048 .39709 L
.58051 .30257 L
.58053 .1479 L
.58055 .19087 L
.58057 .30257 L
.5806 .41428 L
.58062 .37561 L
.58064 .24672 L
.58066 .2725 L
.58068 .52169 L
.58071 .45295 L
.58073 .1565 L
.58075 .23383 L
.58077 .40998 L
.5808 .2725 L
.58082 .16079 L
.58084 .16509 L
.58086 .25102 L
.58089 .33694 L
Mistroke
.58091 .23383 L
.58093 .20805 L
.58095 .20805 L
.58097 .37991 L
.581 .3842 L
.58102 .34554 L
.58104 .37561 L
.58106 .40139 L
.58109 .34124 L
.58111 .32835 L
.58113 .28968 L
.58115 .21664 L
.58118 .31117 L
.5812 .26391 L
.58122 .20376 L
.58124 .24672 L
.58126 .25961 L
.58129 .22094 L
.58131 .29398 L
.58133 .42287 L
.58135 .28539 L
.58138 .2725 L
.5814 .45724 L
.58142 .37131 L
.58144 .27679 L
.58147 .33694 L
.58149 .33694 L
.58151 .25531 L
.58153 .31117 L
.58156 .25531 L
.58158 .18227 L
.5816 .31546 L
.58162 .25531 L
.58164 .16509 L
.58167 .24242 L
.58169 .31546 L
.58171 .33694 L
.58173 .28968 L
.58176 .31976 L
.58178 .3885 L
.5818 .43146 L
.58182 .36272 L
.58185 .23383 L
.58187 .30257 L
.58189 .32835 L
.58191 .22953 L
.58193 .19516 L
.58196 .22524 L
.58198 .2682 L
.582 .24672 L
Mistroke
.58202 .20376 L
.58205 .19087 L
.58207 .37131 L
.58209 .45724 L
.58211 .19516 L
.58214 .28968 L
.58216 .53028 L
.58218 .43146 L
.5822 .25102 L
.58222 .2725 L
.58225 .37991 L
.58227 .2725 L
.58229 .22524 L
.58231 .1479 L
.58234 .24672 L
.58236 .36702 L
.58238 .22953 L
.5824 .19516 L
.58243 .28109 L
.58245 .32835 L
.58247 .29828 L
.58249 .36272 L
.58252 .31117 L
.58254 .31546 L
.58256 .5045 L
.58258 .33694 L
.5826 .21664 L
.58263 .35413 L
.58265 .3928 L
.58267 .18657 L
.58269 .21664 L
.58272 .2682 L
.58274 .19946 L
.58276 .28968 L
.58278 .22094 L
.58281 .16938 L
.58283 .2725 L
.58285 .39709 L
.58287 .36702 L
.58289 .17798 L
.58292 .40569 L
.58294 .5045 L
.58296 .32835 L
.58298 .26391 L
.58301 .31117 L
.58303 .34554 L
.58305 .22953 L
.58307 .21664 L
.5831 .16509 L
.58312 .27679 L
Mistroke
.58314 .29828 L
.58316 .13501 L
.58319 .20376 L
.58321 .31976 L
.58323 .44865 L
.58325 .29828 L
.58327 .17368 L
.5833 .46154 L
.58332 .46154 L
.58334 .52598 L
.58336 .33694 L
.58339 .19087 L
.58341 .37561 L
.58343 .40139 L
.58345 .19516 L
.58348 .1479 L
.5835 .21235 L
.58352 .35413 L
.58354 .25961 L
.58356 .13931 L
.58359 .23813 L
.58361 .31976 L
.58363 .31546 L
.58365 .33265 L
.58368 .27679 L
.5837 .32835 L
.58372 .5045 L
.58374 .3885 L
.58377 .21235 L
.58379 .32405 L
.58381 .44006 L
.58383 .23383 L
.58385 .16938 L
.58388 .2725 L
.5839 .23813 L
.58392 .2725 L
.58394 .19946 L
.58397 .18657 L
.58399 .30257 L
.58401 .34554 L
.58403 .35843 L
.58406 .22953 L
.58408 .35843 L
.5841 .50021 L
.58412 .35413 L
.58415 .25961 L
.58417 .31117 L
.58419 .37561 L
.58421 .23383 L
.58423 .19946 L
Mistroke
.58426 .23383 L
.58428 .23383 L
.5843 .29828 L
.58432 .19516 L
.58435 .19946 L
.58437 .28539 L
.58439 .39709 L
.58441 .36702 L
.58444 .17798 L
.58446 .37131 L
.58448 .53458 L
.5845 .35413 L
.58452 .21235 L
.58455 .34554 L
.58457 .41428 L
.58459 .19946 L
.58461 .18657 L
.58464 .22953 L
.58466 .29828 L
.58468 .28539 L
.5847 .1565 L
.58473 .23383 L
.58475 .31976 L
.58477 .25961 L
.58479 .30687 L
.58482 .3842 L
.58484 .2725 L
.58486 .37561 L
.58488 .51309 L
.5849 .31117 L
.58493 .25102 L
.58495 .41428 L
.58497 .33265 L
.58499 .1479 L
.58502 .24672 L
.58504 .22953 L
.58506 .22524 L
.58508 .28968 L
.58511 .19946 L
.58513 .24672 L
.58515 .29398 L
.58517 .2725 L
.58519 .41857 L
.58522 .33694 L
.58524 .2725 L
.58526 .47872 L
.58528 .45295 L
.58531 .23813 L
.58533 .28968 L
.58535 .44006 L
Mistroke
.58537 .22524 L
.5854 .17798 L
.58542 .28539 L
.58544 .18657 L
.58546 .28109 L
.58548 .25961 L
.58551 .20805 L
.58553 .28109 L
.58555 .28968 L
.58557 .30687 L
.5856 .35843 L
.58562 .33265 L
.58564 .34554 L
.58566 .47013 L
.58569 .47013 L
.58571 .3842 L
.58573 .22953 L
.58575 .34124 L
.58578 .34983 L
.5858 .19087 L
.58582 .22524 L
.58584 .24672 L
.58586 .20805 L
.58589 .24242 L
.58591 .22953 L
.58593 .19946 L
.58595 .33694 L
.58598 .43576 L
.586 .25961 L
.58602 .25531 L
.58604 .51739 L
.58607 .43146 L
.58609 .23383 L
.58611 .32405 L
.58613 .39709 L
.58615 .25102 L
.58618 .18227 L
.5862 .25102 L
.58622 .24672 L
.58624 .27679 L
.58627 .19946 L
.58629 .18657 L
.58631 .28968 L
.58633 .37561 L
.58636 .35843 L
.58638 .23813 L
.5864 .40139 L
.58642 .5045 L
.58645 .29398 L
.58647 .25102 L
Mistroke
.58649 .3842 L
.58651 .37561 L
.58653 .19946 L
.58656 .23813 L
.58658 .28109 L
.5866 .25961 L
.58662 .25531 L
.58665 .20805 L
.58667 .26391 L
.58669 .28109 L
.58671 .28109 L
.58674 .32835 L
.58676 .31546 L
.58678 .33694 L
.5868 .41428 L
.58682 .41857 L
.58685 .31117 L
.58687 .30687 L
.58689 .34554 L
.58691 .25102 L
.58694 .20805 L
.58696 .25531 L
.58698 .24242 L
.587 .25102 L
.58703 .24672 L
.58705 .26391 L
.58707 .29398 L
.58709 .2682 L
.58711 .24672 L
.58714 .26391 L
.58716 .44865 L
.58718 .34554 L
.5872 .18227 L
.58723 .47443 L
.58725 .47443 L
.58727 .22094 L
.58729 .26391 L
.58732 .42287 L
.58734 .25961 L
.58736 .16079 L
.58738 .24242 L
.58741 .20805 L
.58743 .32835 L
.58745 .23383 L
.58747 .18227 L
.58749 .33265 L
.58752 .28968 L
.58754 .13931 L
.58756 .32405 L
.58758 .53028 L
Mistroke
.58761 .1479 L
.58763 .28109 L
.58765 .57754 L
.58767 .2725 L
.5877 .24242 L
.58772 .43576 L
.58774 .32405 L
.58776 .16509 L
.58778 .31546 L
.58781 .17368 L
.58783 .24242 L
.58785 .35413 L
.58787 .11783 L
.5879 .30257 L
.58792 .3928 L
.58794 .23813 L
.58796 .22094 L
.58799 .31976 L
.58801 .43146 L
.58803 .34983 L
.58805 .34983 L
.58808 .2682 L
.5881 .36702 L
.58812 .47872 L
.58814 .30687 L
.58816 .16509 L
.58819 .34124 L
.58821 .33694 L
.58823 .16938 L
.58825 .20376 L
.58828 .26391 L
.5883 .30257 L
.58832 .24672 L
.58834 .21664 L
.58837 .28968 L
.58839 .29828 L
.58841 .29828 L
.58843 .3885 L
.58845 .29398 L
.58848 .31976 L
.5885 .45724 L
.58852 .36272 L
.58854 .22094 L
.58857 .32835 L
.58859 .35413 L
.58861 .16509 L
.58863 .21235 L
.58866 .24672 L
.58868 .22094 L
.5887 .25531 L
Mistroke
.58872 .20805 L
.58874 .20805 L
.58877 .37131 L
.58879 .42717 L
.58881 .19946 L
.58883 .30687 L
.58886 .54747 L
.58888 .36702 L
.5889 .20376 L
.58892 .34983 L
.58895 .40998 L
.58897 .22524 L
.58899 .18227 L
.58901 .25102 L
.58904 .29828 L
.58906 .24242 L
.58908 .16079 L
.5891 .2682 L
.58912 .33694 L
.58915 .26391 L
.58917 .30257 L
.58919 .37991 L
.58921 .33265 L
.58924 .37991 L
.58926 .40998 L
.58928 .30257 L
.5893 .32835 L
.58933 .35843 L
.58935 .25102 L
.58937 .23383 L
.58939 .28539 L
.58941 .23383 L
.58944 .22953 L
.58946 .26391 L
.58948 .24672 L
.5895 .26391 L
.58953 .26391 L
.58955 .27679 L
.58957 .32405 L
.58959 .34124 L
.58962 .35843 L
.58964 .31546 L
.58966 .39709 L
.58968 .40139 L
.58971 .28968 L
.58973 .28539 L
.58975 .32405 L
.58977 .26391 L
.58979 .18227 L
.58982 .25531 L
Mistroke
.58984 .26391 L
.58986 .25102 L
.58988 .2682 L
.58991 .25531 L
.58993 .30257 L
.58995 .2725 L
.58997 .24242 L
.59 .31117 L
.59002 .44006 L
.59004 .28539 L
.59006 .24672 L
.59008 .5088 L
.59011 .37991 L
.59013 .22524 L
.59015 .33265 L
.59017 .37131 L
.5902 .21235 L
.59022 .19946 L
.59024 .24242 L
.59026 .24672 L
.59029 .30257 L
.59031 .20376 L
.59033 .26391 L
.59035 .35413 L
.59037 .23813 L
.5904 .19087 L
.59042 .19087 L
.59044 .40998 L
.59046 .45295 L
.59049 .1565 L
.59051 .35843 L
.59053 .55606 L
.59055 .28539 L
.59058 .23383 L
.5906 .39709 L
.59062 .34554 L
.59064 .18657 L
.59067 .22524 L
.59069 .22094 L
.59071 .30687 L
.59073 .25961 L
.59075 .16938 L
.59078 .34983 L
.5908 .36702 L
.59082 .24242 L
.59084 .25961 L
.59087 .33265 L
.59089 .33694 L
.59091 .40569 L
.59093 .28539 L
Mistroke
.59096 .22094 L
.59098 .50021 L
.591 .3842 L
.59102 .1522 L
.59104 .31546 L
.59107 .43146 L
.59109 .18657 L
.59111 .18227 L
.59113 .31117 L
.59116 .27679 L
.59118 .29398 L
.5912 .21664 L
.59122 .26391 L
.59125 .36272 L
.59127 .25961 L
.59129 .16509 L
.59131 .28539 L
.59134 .42287 L
.59136 .29828 L
.59138 .21664 L
.5914 .37991 L
.59142 .45295 L
.59145 .28539 L
.59147 .25531 L
.59149 .36702 L
.59151 .34554 L
.59154 .22094 L
.59156 .23383 L
.59158 .27679 L
.5916 .29398 L
.59163 .25531 L
.59165 .22953 L
.59167 .30687 L
.59169 .31117 L
.59171 .22094 L
.59174 .25102 L
.59176 .30257 L
.59178 .32405 L
.5918 .34554 L
.59183 .31546 L
.59185 .34124 L
.59187 .43576 L
.59189 .36272 L
.59192 .27679 L
.59194 .34983 L
.59196 .33694 L
.59198 .21664 L
.592 .24242 L
.59203 .27679 L
.59205 .25102 L
Mistroke
.59207 .25531 L
.59209 .2725 L
.59212 .30257 L
.59214 .31546 L
.59216 .28109 L
.59218 .30257 L
.59221 .33265 L
.59223 .30687 L
.59225 .28109 L
.59227 .32835 L
.5923 .31117 L
.59232 .27679 L
.59234 .32405 L
.59236 .28968 L
.59238 .2682 L
.59241 .30687 L
.59243 .28109 L
.59245 .26391 L
.59247 .30257 L
.5925 .34554 L
.59252 .28109 L
.59254 .28968 L
.59256 .36702 L
.59259 .31117 L
.59261 .24672 L
.59263 .24672 L
.59265 .29828 L
.59267 .24672 L
.5927 .21664 L
.59272 .25102 L
.59274 .28968 L
.59276 .29398 L
.59279 .29398 L
.59281 .25961 L
.59283 .27679 L
.59285 .31117 L
.59288 .41428 L
.5929 .32405 L
.59292 .19946 L
.59294 .41857 L
.59297 .40139 L
.59299 .20376 L
.59301 .28109 L
.59303 .40139 L
.59305 .27679 L
.59308 .22094 L
.5931 .28539 L
.59312 .28539 L
.59314 .30687 L
.59317 .22094 L
Mistroke
.59319 .25102 L
.59321 .34554 L
.59323 .26391 L
.59326 .20805 L
.59328 .27679 L
.5933 .2725 L
.59332 .25531 L
.59334 .47013 L
.59337 .23813 L
.59339 .17798 L
.59341 .54317 L
.59343 .31546 L
.59346 .16509 L
.59348 .37991 L
.5935 .44865 L
.59352 .19087 L
.59355 .29828 L
.59357 .37561 L
.59359 .25531 L
.59361 .36702 L
.59363 .22094 L
.59366 .26391 L
.59368 .33265 L
.5937 .25102 L
.59372 .21664 L
.59375 .26391 L
.59377 .32835 L
.59379 .19946 L
.59381 .25531 L
.59384 .21664 L
.59386 .3885 L
.59388 .42717 L
.5939 .05768 L
.59393 .37991 L
.59395 .52598 L
.59397 .17798 L
.59399 .19946 L
.59401 .47872 L
.59404 .36702 L
.59406 .16079 L
.59408 .32835 L
.5941 .27679 L
.59413 .3885 L
.59415 .31546 L
.59417 .13072 L
.59419 .42287 L
.59422 .34554 L
.59424 .13072 L
.59426 .22094 L
.59428 .37131 L
Mistroke
.5943 .22524 L
.59433 .17798 L
.59435 .30257 L
.59437 .22094 L
.59439 .28109 L
.59442 .47013 L
.59444 .21235 L
.59446 .20376 L
.59448 .54317 L
.59451 .31976 L
.59453 .1522 L
.59455 .40569 L
.59457 .45724 L
.5946 .17798 L
.59462 .27679 L
.59464 .35413 L
.59466 .2682 L
.59468 .39709 L
.59471 .1522 L
.59473 .30687 L
.59475 .44865 L
.59477 .16938 L
.5948 .19516 L
.59482 .36702 L
.59484 .32835 L
.59486 .1522 L
.59489 .29398 L
.59491 .32405 L
.59493 .17368 L
.59495 .37991 L
.59497 .41428 L
.595 .13072 L
.59502 .33265 L
.59504 .49161 L
.59506 .18657 L
.59509 .23813 L
.59511 .46583 L
.59513 .46583 L
.59515 .32405 L
.59518 .16509 L
.5952 .3842 L
.59522 .25531 L
.59524 .33265 L
.59526 .35843 L
.59529 .14361 L
.59531 .41428 L
.59533 .35413 L
.59535 .16079 L
.59538 .25961 L
.5954 .36272 L
Mistroke
.59542 .23383 L
.59544 .17798 L
.59547 .33265 L
.59549 .22524 L
.59551 .22094 L
.59553 .33694 L
.59556 .42717 L
.59558 .18227 L
.5956 .27679 L
.59562 .5088 L
.59564 .24242 L
.59567 .22953 L
.59569 .3928 L
.59571 .3842 L
.59573 .20376 L
.59576 .31546 L
.59578 .29828 L
.5958 .31976 L
.59582 .34554 L
.59585 .18227 L
.59587 .3842 L
.59589 .35413 L
.59591 .19946 L
.59593 .26391 L
.59596 .32405 L
.59598 .25531 L
.596 .21235 L
.59602 .31546 L
.59605 .25531 L
.59607 .23383 L
.59609 .35843 L
.59611 .41428 L
.59614 .1522 L
.59616 .30687 L
.59618 .51309 L
.5962 .21664 L
.59623 .23813 L
.59625 .42287 L
.59627 .35413 L
.59629 .17798 L
.59631 .34124 L
.59634 .29828 L
.59636 .33265 L
.59638 .34124 L
.5964 .17798 L
.59643 .39709 L
.59645 .31976 L
.59647 .19516 L
.59649 .27679 L
.59652 .32835 L
Mistroke
.59654 .25531 L
.59656 .20805 L
.59658 .30687 L
.5966 .23813 L
.59663 .25102 L
.59665 .28539 L
.59667 .45295 L
.59669 .22094 L
.59672 .19516 L
.59674 .53028 L
.59676 .2682 L
.59678 .17798 L
.59681 .3928 L
.59683 .40998 L
.59685 .17798 L
.59687 .30687 L
.59689 .33694 L
.59692 .2725 L
.59694 .37131 L
.59696 .20805 L
.59698 .34554 L
.59701 .37131 L
.59703 .20805 L
.59705 .25102 L
.59707 .32405 L
.5971 .2682 L
.59712 .18657 L
.59714 .31976 L
.59716 .25961 L
.59719 .22953 L
.59721 .27679 L
.59723 .43576 L
.59725 .30257 L
.59727 .13931 L
.5973 .5045 L
.59732 .36272 L
.59734 .18657 L
.59736 .34124 L
.59739 .44006 L
.59741 .24242 L
.59743 .23813 L
.59745 .36272 L
.59748 .28539 L
.5975 .28539 L
.59752 .35413 L
.59754 .22953 L
.59756 .31546 L
.59759 .3885 L
.59761 .20805 L
.59763 .2682 L
Mistroke
.59765 .30687 L
.59768 .29828 L
.5977 .21235 L
.59772 .29398 L
.59774 .28109 L
.59777 .23813 L
.59779 .25961 L
.59781 .29398 L
.59783 .44865 L
.59786 .16509 L
.59788 .26391 L
.5979 .51739 L
.59792 .24242 L
.59794 .19946 L
.59797 .40569 L
.59799 .3885 L
.59801 .18227 L
.59803 .31976 L
.59806 .32405 L
.59808 .31117 L
.5981 .32835 L
.59812 .21235 L
.59815 .3842 L
.59817 .31117 L
.59819 .21664 L
.59821 .2682 L
.59823 .31546 L
.59826 .24672 L
.59828 .20805 L
.5983 .29398 L
.59832 .24242 L
.59835 .23813 L
.59837 .23813 L
.59839 .43576 L
.59841 .27679 L
.59844 .16509 L
.59846 .50021 L
.59848 .33694 L
.5985 .21664 L
.59852 .33265 L
.59855 .44865 L
.59857 .25102 L
.59859 .2725 L
.59861 .33265 L
.59864 .30257 L
.59866 .36272 L
.59868 .19946 L
.5987 .34554 L
.59873 .35843 L
.59875 .22524 L
Mistroke
.59877 .25531 L
.59879 .29828 L
.59882 .28968 L
.59884 .21664 L
.59886 .29398 L
.59888 .2725 L
.5989 .26391 L
.59893 .25102 L
.59895 .23383 L
.59897 .47872 L
.59899 .22094 L
.59902 .17368 L
.59904 .51309 L
.59906 .33694 L
.59908 .14361 L
.59911 .36272 L
.59913 .45295 L
.59915 .19946 L
.59917 .25961 L
.59919 .35413 L
.59922 .31117 L
.59924 .32835 L
.59926 .21235 L
.59928 .35413 L
.59931 .36702 L
.59933 .19516 L
.59935 .25531 L
.59937 .32405 L
.5994 .25961 L
.59942 .19946 L
.59944 .28539 L
.59946 .26391 L
.59948 .25531 L
.59951 .22094 L
.59953 .28539 L
.59955 .47872 L
.59957 .1522 L
.5996 .24242 L
.59962 .53458 L
.59964 .25961 L
.59966 .18227 L
.59969 .43576 L
.59971 .40998 L
.59973 .17798 L
.59975 .31117 L
.59978 .34124 L
.5998 .31976 L
.59982 .30687 L
.59984 .21235 L
.59986 .21235 L
Mistroke
.59989 .3928 L
.59991 .31976 L
.59993 .19516 L
.59995 .28539 L
.59998 .33265 L
.6 .25531 L
.60002 .22094 L
.60004 .31976 L
.60007 .2725 L
.60009 .2682 L
.60011 .22953 L
.60013 .31546 L
.60015 .47013 L
.60018 .13931 L
.6002 .26391 L
.60022 .52598 L
.60024 .24672 L
.60027 .18657 L
.60029 .42287 L
.60031 .40569 L
.60033 .17368 L
.60036 .32405 L
.60038 .34124 L
.6004 .31117 L
.60042 .30687 L
.60045 .22094 L
.60047 .3928 L
.60049 .30687 L
.60051 .19946 L
.60053 .28539 L
.60056 .32835 L
.60058 .22524 L
.6006 .21235 L
.60062 .33265 L
.60065 .25102 L
.60067 .25102 L
.60069 .25531 L
.60071 .25531 L
.60074 .46154 L
.60076 .20805 L
.60078 .16938 L
.6008 .51739 L
.60082 .32835 L
.60085 .14361 L
.60087 .3842 L
.60089 .45295 L
.60091 .19516 L
.60094 .28539 L
.60096 .35843 L
.60098 .31117 L
Mistroke
.601 .32835 L
.60103 .20376 L
.60105 .34983 L
.60107 .36272 L
.60109 .19946 L
.60111 .26391 L
.60114 .34554 L
.60116 .25961 L
.60118 .20376 L
.6012 .32405 L
.60123 .28539 L
.60125 .25102 L
.60127 .2682 L
.60129 .23813 L
.60132 .45295 L
.60134 .28109 L
.60136 .13072 L
.60138 .47872 L
.60141 .40569 L
.60143 .1479 L
.60145 .31546 L
.60147 .48302 L
.60149 .25102 L
.60152 .23383 L
.60154 .36702 L
.60156 .30687 L
.60158 .34554 L
.60161 .20376 L
.60163 .31546 L
.60165 .3885 L
.60167 .21235 L
.6017 .23813 L
.60172 .34554 L
.60174 .28109 L
.60176 .19946 L
.60178 .31117 L
.60181 .30257 L
.60183 .24242 L
.60185 .28109 L
.60187 .20376 L
.6019 .3885 L
.60192 .3928 L
.60194 .09635 L
.60196 .34983 L
.60199 .5088 L
.60201 .1522 L
.60203 .22953 L
.60205 .49591 L
.60208 .31117 L
.6021 .18657 L
Mistroke
.60212 .36272 L
.60214 .32405 L
.60216 .31546 L
.60219 .25102 L
.60221 .24672 L
.60223 .24672 L
.60225 .42717 L
.60228 .25102 L
.6023 .19946 L
.60232 .35413 L
.60234 .30687 L
.60237 .19946 L
.60239 .28109 L
.60241 .33265 L
.60243 .22953 L
.60245 .2725 L
.60248 .22953 L
.6025 .29398 L
.60252 .46154 L
.60254 .1565 L
.60257 .23383 L
.60259 .53887 L
.60261 .24672 L
.60263 .17798 L
.60266 .45295 L
.60268 .42287 L
.6027 .19087 L
.60272 .32405 L
.60274 .35843 L
.60277 .30687 L
.60279 .29828 L
.60281 .21664 L
.60283 .40139 L
.60286 .31117 L
.60288 .18227 L
.6029 .31976 L
.60292 .33694 L
.60295 .22094 L
.60297 .24672 L
.60299 .34554 L
.60301 .25531 L
.60304 .25102 L
.60306 .27679 L
.60308 .23813 L
.6031 .35413 L
.60312 .37561 L
.60315 .13501 L
.60317 .34124 L
.60319 .48302 L
.60321 .16509 L
Mistroke
.60324 .2682 L
.60326 .46583 L
.60328 .32835 L
.6033 .17798 L
.60333 .37561 L
.60335 .32835 L
.60337 .28968 L
.60339 .2682 L
.60341 .25102 L
.60344 .40139 L
.60346 .23813 L
.60348 .22524 L
.6035 .34983 L
.60353 .29398 L
.60355 .20805 L
.60357 .2725 L
.60359 .31976 L
.60362 .23383 L
.60364 .27679 L
.60366 .25102 L
.60368 .25961 L
.60371 .3928 L
.60373 .29828 L
.60375 .1479 L
.60377 .44865 L
.60379 .39709 L
.60382 .16509 L
.60384 .34983 L
.60386 .46583 L
.60388 .26391 L
.60391 .22524 L
.60393 .3928 L
.60395 .29828 L
.60397 .30257 L
.604 .23813 L
.60402 .31546 L
.60404 .37131 L
.60406 .19516 L
.60408 .2725 L
.60411 .34554 L
.60413 .25961 L
.60415 .22953 L
.60417 .31117 L
.6042 .29398 L
.60422 .24672 L
.60424 .27679 L
.60426 .24242 L
.60429 .28539 L
.60431 .3928 L
.60433 .25531 L
Mistroke
.60435 .17368 L
.60437 .49161 L
.6044 .31117 L
.60442 .16509 L
.60444 .3928 L
.60446 .44006 L
.60449 .21235 L
.60451 .26391 L
.60453 .39709 L
.60455 .2682 L
.60458 .29398 L
.6046 .29398 L
.60462 .23813 L
.60464 .34983 L
.60467 .32835 L
.60469 .19087 L
.60471 .30687 L
.60473 .31546 L
.60475 .24242 L
.60478 .22094 L
.6048 .31546 L
.60482 .2682 L
.60484 .23813 L
.60487 .2725 L
.60489 .23813 L
.60491 .29398 L
.60493 .3928 L
.60496 .22953 L
.60498 .19946 L
.605 .51739 L
.60502 .27679 L
.60504 .18657 L
.60507 .44435 L
.60509 .40998 L
.60511 .19087 L
.60513 .31546 L
.60516 .3885 L
.60518 .24672 L
.6052 .30687 L
.60522 .24672 L
.60525 .35843 L
.60527 .30687 L
.60529 .21235 L
.60531 .33265 L
.60534 .32405 L
.60536 .23813 L
.60538 .25102 L
.6054 .34983 L
.60542 .24242 L
.60545 .25961 L
Mistroke
.60547 .28539 L
.60549 .25102 L
.60551 .26391 L
.60554 .36702 L
.60556 .30687 L
.60558 .16079 L
.6056 .47443 L
.60563 .33694 L
.60565 .19516 L
.60567 .3885 L
.60569 .42287 L
.60571 .24242 L
.60574 .27679 L
.60576 .3885 L
.60578 .25102 L
.6058 .31546 L
.60583 .24672 L
.60585 .32835 L
.60587 .31976 L
.60589 .21664 L
.60592 .30257 L
.60594 .31546 L
.60596 .25961 L
.60598 .23813 L
.606 .32405 L
.60603 .25531 L
.60605 .25961 L
.60607 .28109 L
.60609 .25102 L
.60612 .28109 L
.60614 .24672 L
.60616 .41857 L
.60618 .18657 L
.60621 .28109 L
.60623 .47013 L
.60625 .26391 L
.60627 .25531 L
.6063 .40569 L
.60632 .3928 L
.60634 .19087 L
.60636 .36272 L
.60638 .32405 L
.60641 .29828 L
.60643 .28968 L
.60645 .25102 L
.60647 .37991 L
.6065 .2725 L
.60652 .25961 L
.60654 .31546 L
.60656 .32405 L
Mistroke
.60659 .23813 L
.60661 .26391 L
.60663 .33265 L
.60665 .25102 L
.60667 .28539 L
.6067 .25102 L
.60672 .29828 L
.60674 .22524 L
.60676 .35413 L
.60679 .34983 L
.60681 .1479 L
.60683 .45295 L
.60685 .3885 L
.60688 .19516 L
.6069 .34124 L
.60692 .46154 L
.60694 .24672 L
.60697 .24672 L
.60699 .25531 L
.60701 .40998 L
.60703 .25102 L
.60705 .30687 L
.60708 .24242 L
.6071 .32405 L
.60712 .33694 L
.60714 .22094 L
.60717 .29398 L
.60719 .32835 L
.60721 .2682 L
.60723 .20805 L
.60726 .34554 L
.60728 .26391 L
.6073 .23383 L
.60732 .28109 L
.60734 .25531 L
.60737 .26391 L
.60739 .23813 L
.60741 .41428 L
.60743 .20805 L
.60746 .25531 L
.60748 .47872 L
.6075 .25531 L
.60752 .25531 L
.60755 .40139 L
.60757 .3928 L
.60759 .20376 L
.60761 .35413 L
.60763 .32835 L
.60766 .2682 L
.60768 .29828 L
Mistroke
.6077 .24672 L
.60772 .37561 L
.60775 .26391 L
.60777 .25531 L
.60779 .31117 L
.60781 .31976 L
.60784 .22094 L
.60786 .28109 L
.60788 .34983 L
.6079 .22094 L
.60793 .28539 L
.60795 .2682 L
.60797 .28109 L
.60799 .23383 L
.60801 .28109 L
.60804 .44006 L
.60806 .16079 L
.60808 .29398 L
.6081 .47872 L
.60813 .25961 L
.60815 .24242 L
.60817 .43146 L
.60819 .37991 L
.60822 .17368 L
.60824 .36702 L
.60826 .31546 L
.60828 .29398 L
.6083 .2725 L
.60833 .25961 L
.60835 .37561 L
.60837 .23813 L
.60839 .24672 L
.60842 .32835 L
.60844 .31976 L
.60846 .19087 L
.60848 .28968 L
.60851 .32835 L
.60853 .19516 L
.60855 .28968 L
.60857 .26391 L
.6086 .28109 L
.60862 .21235 L
.60864 .27679 L
.60866 .42287 L
.60868 .1565 L
.60871 .29828 L
.60873 .47013 L
.60875 .25961 L
.60877 .22094 L
.6088 .44006 L
Mistroke
.60882 .36272 L
.60884 .17368 L
.60886 .37561 L
.60889 .31117 L
.60891 .28109 L
.60893 .26391 L
.60895 .28109 L
.60897 .36702 L
.609 .24242 L
.60902 .2682 L
.60904 .32835 L
.60906 .31546 L
.60909 .19516 L
.60911 .31546 L
.60913 .33265 L
.60915 .20805 L
.60918 .29398 L
.6092 .27679 L
.60922 .28109 L
.60924 .22524 L
.60926 .27679 L
.60929 .43146 L
.60931 .20805 L
.60933 .20805 L
.60935 .24672 L
.60938 .48302 L
.6094 .30257 L
.60942 .20376 L
.60944 .42717 L
.60947 .40998 L
.60949 .19516 L
.60951 .32835 L
.60953 .34983 L
.60956 .28109 L
.60958 .26391 L
.6096 .2682 L
.60962 .37991 L
.60964 .25102 L
.60967 .23813 L
.60969 .31976 L
.60971 .32405 L
.60973 .19946 L
.60976 .28968 L
.60978 .34124 L
.6098 .20805 L
.60982 .26391 L
.60985 .28539 L
.60987 .2682 L
.60989 .25102 L
.60991 .23813 L
Mistroke
.60993 .3885 L
.60996 .31546 L
.60998 .13931 L
.61 .40998 L
.61002 .42717 L
.61005 .16079 L
.61007 .33265 L
.61009 .47013 L
.61011 .24242 L
.61014 .20805 L
.61016 .41428 L
.61018 .29398 L
.6102 .25531 L
.61023 .26391 L
.61025 .35413 L
.61027 .29828 L
.61029 .21235 L
.61031 .32405 L
.61034 .34554 L
.61036 .23383 L
.61038 .23813 L
.6104 .37561 L
.61043 .24672 L
.61045 .22094 L
.61047 .33265 L
.61049 .28539 L
.61052 .25961 L
.61054 .23813 L
.61056 .31546 L
.61058 .3885 L
.6106 .24242 L
.61063 .20376 L
.61065 .5045 L
.61067 .29828 L
.61069 .17798 L
.61072 .44006 L
.61074 .41857 L
.61076 .16509 L
.61078 .32405 L
.61081 .41428 L
.61083 .24242 L
.61085 .25102 L
.61087 .30257 L
.61089 .37131 L
.61092 .24242 L
.61094 .24672 L
.61096 .34983 L
.61098 .31117 L
.61101 .19516 L
.61103 .28968 L
Mistroke
.61105 .36702 L
.61107 .18657 L
.6111 .2682 L
.61112 .32835 L
.61114 .25102 L
.61116 .22524 L
.61119 .2725 L
.61121 .31976 L
.61123 .36272 L
.61125 .19087 L
.61127 .29828 L
.6113 .48302 L
.61132 .19516 L
.61134 .25531 L
.61136 .47443 L
.61139 .32835 L
.61141 .16079 L
.61143 .40139 L
.61145 .34554 L
.61148 .21235 L
.6115 .27679 L
.61152 .33694 L
.61154 .33265 L
.61156 .19516 L
.61159 .31546 L
.61161 .34554 L
.61163 .25531 L
.61165 .21664 L
.61168 .36702 L
.6117 .36702 L
.61172 .30687 L
.61174 .18657 L
.61177 .33265 L
.61179 .31117 L
.61181 .25961 L
.61183 .22524 L
.61186 .34554 L
.61188 .25102 L
.6119 .34983 L
.61192 .30257 L
.61194 .20376 L
.61197 .47013 L
.61199 .28968 L
.61201 .22524 L
.61203 .40139 L
.61206 .41857 L
.61208 .16509 L
.6121 .33265 L
.61212 .40569 L
.61215 .19946 L
Mistroke
.61217 .29828 L
.61219 .31117 L
.61221 .33694 L
.61223 .22094 L
.61226 .29398 L
.61228 .32835 L
.6123 .28539 L
.61232 .23383 L
.61235 .30687 L
.61237 .34983 L
.61239 .17368 L
.61241 .31117 L
.61244 .32835 L
.61246 .23813 L
.61248 .24242 L
.6125 .32835 L
.61252 .22953 L
.61255 .2725 L
.61257 .40998 L
.61259 .1522 L
.61261 .36272 L
.61264 .41428 L
.61266 .19516 L
.61268 .31117 L
.6127 .44435 L
.61273 .2682 L
.61275 .22524 L
.61277 .43146 L
.61279 .25102 L
.61282 .2682 L
.61284 .28539 L
.61286 .32405 L
.61288 .29398 L
.6129 .25531 L
.61293 .31976 L
.61295 .30687 L
.61297 .2682 L
.61299 .25102 L
.61302 .37131 L
.61304 .24242 L
.61306 .2682 L
.61308 .34554 L
.61311 .25961 L
.61313 .2682 L
.61315 .28109 L
.61317 .31117 L
.61319 .20805 L
.61322 .35843 L
.61324 .35413 L
.61326 .16938 L
Mistroke
.61328 .36702 L
.61331 .41428 L
.61333 .20805 L
.61335 .30257 L
.61337 .45724 L
.6134 .25961 L
.61342 .23813 L
.61344 .40569 L
.61346 .28109 L
.61349 .25961 L
.61351 .28968 L
.61353 .34983 L
.61355 .2725 L
.61357 .24242 L
.6136 .32835 L
.61362 .31117 L
.61364 .24242 L
.61366 .28109 L
.61369 .36702 L
.61371 .21664 L
.61373 .2682 L
.61375 .32835 L
.61378 .25961 L
.6138 .25531 L
.61382 .28539 L
.61384 .29828 L
.61386 .20376 L
.61389 .30257 L
.61391 .37131 L
.61393 .18657 L
.61395 .29828 L
.61398 .43576 L
.614 .22524 L
.61402 .25531 L
.61404 .25531 L
.61407 .44865 L
.61409 .29828 L
.61411 .21664 L
.61413 .40139 L
.61415 .30687 L
.61418 .24672 L
.6142 .29398 L
.61422 .33265 L
.61424 .28539 L
.61427 .25531 L
.61429 .32835 L
.61431 .31117 L
.61433 .2682 L
.61436 .27679 L
.61438 .36272 L
Mistroke
.6144 .25102 L
.61442 .25961 L
.61445 .34554 L
.61447 .26391 L
.61449 .25531 L
.61451 .30257 L
.61453 .29828 L
.61456 .23813 L
.61458 .25961 L
.6146 .31546 L
.61462 .35413 L
.61465 .18227 L
.61467 .31976 L
.61469 .43576 L
.61471 .19946 L
.61474 .28968 L
.61476 .44006 L
.61478 .30257 L
.6148 .20805 L
.61482 .40569 L
.61485 .31546 L
.61487 .23383 L
.61489 .29828 L
.61491 .34983 L
.61494 .28109 L
.61496 .24672 L
.61498 .33265 L
.615 .30257 L
.61503 .25961 L
.61505 .2682 L
.61507 .35843 L
.61509 .25102 L
.61511 .25531 L
.61514 .31976 L
.61516 .2682 L
.61518 .24672 L
.6152 .27679 L
.61523 .30687 L
.61525 .22524 L
.61527 .25531 L
.61529 .28968 L
.61532 .34983 L
.61534 .18657 L
.61536 .29398 L
.61538 .43576 L
.61541 .21235 L
.61543 .28109 L
.61545 .43146 L
.61547 .31976 L
.61549 .20805 L
Mistroke
.61552 .40569 L
.61554 .32835 L
.61556 .24242 L
.61558 .31117 L
.61561 .34983 L
.61563 .28968 L
.61565 .24672 L
.61567 .35413 L
.6157 .30687 L
.61572 .26391 L
.61574 .28539 L
.61576 .36272 L
.61578 .25102 L
.61581 .25961 L
.61583 .34554 L
.61585 .25961 L
.61587 .25102 L
.6159 .29828 L
.61592 .30687 L
.61594 .22524 L
.61596 .28968 L
.61599 .2725 L
.61601 .28109 L
.61603 .33265 L
.61605 .22953 L
.61608 .32835 L
.6161 .37561 L
.61612 .23813 L
.61614 .30257 L
.61616 .42287 L
.61619 .27679 L
.61621 .25531 L
.61623 .40998 L
.61625 .28539 L
.61628 .25531 L
.6163 .32405 L
.61632 .33694 L
.61634 .25531 L
.61637 .28968 L
.61639 .33265 L
.61641 .33265 L
.61643 .28539 L
.61645 .25531 L
.61648 .29828 L
.6165 .33265 L
.61652 .22953 L
.61654 .28109 L
.61657 .31546 L
.61659 .25102 L
.61661 .24672 L
Mistroke
.61663 .30257 L
.61666 .28109 L
.61668 .23813 L
.6167 .28539 L
.61672 .2682 L
.61674 .25102 L
.61677 .32405 L
.61679 .28968 L
.61681 .23813 L
.61683 .3842 L
.61686 .30687 L
.61688 .25102 L
.6169 .3842 L
.61692 .36272 L
.61695 .24672 L
.61697 .35843 L
.61699 .35413 L
.61701 .26391 L
.61704 .31546 L
.61706 .34124 L
.61708 .30257 L
.6171 .27679 L
.61712 .32835 L
.61715 .30257 L
.61717 .28968 L
.61719 .25961 L
.61721 .33694 L
.61724 .28109 L
.61726 .24242 L
.61728 .31117 L
.6173 .29828 L
.61733 .23813 L
.61735 .28109 L
.61737 .31546 L
.61739 .24672 L
.61741 .2682 L
.61744 .28968 L
.61746 .2725 L
.61748 .24242 L
.6175 .31976 L
.61753 .31976 L
.61755 .21664 L
.61757 .34983 L
.61759 .34983 L
.61762 .25102 L
.61764 .32835 L
.61766 .3928 L
.61768 .27679 L
.61771 .28539 L
.61773 .37991 L
Mistroke
.61775 .28968 L
.61777 .27679 L
.61779 .31546 L
.61782 .33694 L
.61784 .25531 L
.61786 .30257 L
.61788 .31546 L
.61791 .27679 L
.61793 .26391 L
.61795 .30687 L
.61797 .29828 L
.618 .24242 L
.61802 .29828 L
.61804 .28968 L
.61806 .25531 L
.61808 .27679 L
.61811 .30257 L
.61813 .2725 L
.61815 .2682 L
.61817 .29398 L
.6182 .27679 L
.61822 .26391 L
.61824 .27679 L
.61826 .33265 L
.61829 .28539 L
.61831 .24672 L
.61833 .37991 L
.61835 .32835 L
.61837 .25531 L
.6184 .36272 L
.61842 .3885 L
.61844 .25531 L
.61846 .31976 L
.61849 .3885 L
.61851 .27679 L
.61853 .28109 L
.61855 .35843 L
.61858 .31976 L
.6186 .25102 L
.61862 .33694 L
.61864 .31546 L
.61867 .2725 L
.61869 .2725 L
.61871 .33265 L
.61873 .2725 L
.61875 .25102 L
.61878 .25102 L
.6188 .31117 L
.61882 .29398 L
.61884 .25102 L
Mistroke
.61887 .28968 L
.61889 .30687 L
.61891 .25102 L
.61893 .27679 L
.61896 .28968 L
.61898 .2725 L
.619 .26391 L
.61902 .28109 L
.61904 .2725 L
.61907 .31976 L
.61909 .25102 L
.61911 .28968 L
.61913 .37991 L
.61916 .2682 L
.61918 .28539 L
.6192 .37991 L
.61922 .30687 L
.61925 .25102 L
.61927 .37131 L
.61929 .32405 L
.61931 .25961 L
.61934 .31546 L
.61936 .34124 L
.61938 .27679 L
.6194 .28968 L
.61942 .34554 L
.61945 .28968 L
.61947 .27679 L
.61949 .29828 L
.61951 .31546 L
.61954 .25531 L
.61956 .28539 L
.61958 .30687 L
.6196 .26391 L
.61963 .2682 L
.61965 .30687 L
.61967 .2682 L
.61969 .2682 L
.61971 .30257 L
.61974 .2725 L
.61976 .2682 L
.61978 .28968 L
.6198 .28109 L
.61983 .25531 L
.61985 .31546 L
.61987 .31546 L
.61989 .24242 L
.61992 .35843 L
.61994 .34124 L
.61996 .25961 L
Mistroke
.61998 .34124 L
.62 .37131 L
.62003 .2682 L
.62005 .30687 L
.62007 .36272 L
.62009 .28109 L
.62012 .29398 L
.62014 .32835 L
.62016 .32405 L
.62018 .25961 L
.62021 .31976 L
.62023 .30257 L
.62025 .28109 L
.62027 .2725 L
.6203 .31117 L
.62032 .27679 L
.62034 .25102 L
.62036 .28968 L
.62038 .28109 L
.62041 .25531 L
.62043 .27679 L
.62045 .28968 L
.62047 .24672 L
.6205 .2725 L
.62052 .28539 L
.62054 .2682 L
.62056 .2682 L
.62059 .28968 L
.62061 .25961 L
.62063 .26391 L
.62065 .28968 L
.62067 .31976 L
.6207 .25102 L
.62072 .31976 L
.62074 .36272 L
.62076 .2725 L
.62079 .29828 L
.62081 .37561 L
.62083 .31117 L
.62085 .28109 L
.62088 .36702 L
.6209 .31976 L
.62092 .27679 L
.62094 .31117 L
.62097 .34983 L
.62099 .28109 L
.62101 .29398 L
.62103 .33694 L
.62105 .29398 L
.62108 .25961 L
Mistroke
.6211 .31546 L
.62112 .30687 L
.62114 .30687 L
.62117 .25961 L
.62119 .29398 L
.62121 .30687 L
.62123 .25531 L
.62126 .26391 L
.62128 .30257 L
.6213 .2725 L
.62132 .27679 L
.62134 .28968 L
.62137 .28539 L
.62139 .25961 L
.62141 .28109 L
.62143 .28968 L
.62146 .2682 L
.62148 .2725 L
.6215 .28109 L
.62152 .31117 L
.62155 .2725 L
.62157 .28109 L
.62159 .36272 L
.62161 .29828 L
.62163 .26391 L
.62166 .34983 L
.62168 .32835 L
.6217 .2682 L
.62172 .33694 L
.62175 .33694 L
.62177 .28109 L
.62179 .30257 L
.62181 .33694 L
.62184 .30687 L
.62186 .28968 L
.62188 .32835 L
.6219 .31546 L
.62193 .27679 L
.62195 .28539 L
.62197 .31976 L
.62199 .27679 L
.62201 .27679 L
.62204 .30687 L
.62206 .28109 L
.62208 .25102 L
.6221 .29828 L
.62213 .28539 L
.62215 .26391 L
.62217 .29828 L
.62219 .28968 L
Mistroke
.62222 .2682 L
.62224 .27679 L
.62226 .29398 L
.62228 .28109 L
.6223 .28109 L
.62233 .29828 L
.62235 .28539 L
.62237 .29828 L
.62239 .31117 L
.62242 .2725 L
.62244 .34983 L
.62246 .33694 L
.62248 .28109 L
.62251 .33265 L
.62253 .34554 L
.62255 .28109 L
.62257 .32405 L
.6226 .35843 L
.62262 .29398 L
.62264 .31117 L
.62266 .33694 L
.62268 .31117 L
.62271 .28539 L
.62273 .33694 L
.62275 .29828 L
.62277 .28109 L
.6228 .28968 L
.62282 .29828 L
.62284 .27679 L
.62286 .28109 L
.62289 .29398 L
.62291 .2725 L
.62293 .26391 L
.62295 .27679 L
.62297 .28109 L
.623 .25961 L
.62302 .28539 L
.62304 .28109 L
.62306 .26391 L
.62309 .2682 L
.62311 .28539 L
.62313 .27679 L
.62315 .27679 L
.62318 .29398 L
.6232 .27679 L
.62322 .27679 L
.62324 .28109 L
.62326 .31976 L
.62329 .30257 L
.62331 .2725 L
Mistroke
.62333 .35843 L
.62335 .31117 L
.62338 .2725 L
.6234 .34983 L
.62342 .34554 L
.62344 .28109 L
.62347 .33694 L
.62349 .34554 L
.62351 .34554 L
.62353 .28968 L
.62356 .30687 L
.62358 .34554 L
.6236 .31117 L
.62362 .29398 L
.62364 .32405 L
.62367 .29398 L
.62369 .28539 L
.62371 .29828 L
.62373 .30257 L
.62376 .28539 L
.62378 .28539 L
.6238 .28109 L
.62382 .2725 L
.62385 .2682 L
.62387 .28968 L
.62389 .28109 L
.62391 .2725 L
.62393 .27679 L
.62396 .28109 L
.62398 .2682 L
.624 .27679 L
.62402 .29398 L
.62405 .27679 L
.62407 .27679 L
.62409 .28109 L
.62411 .27679 L
.62414 .28109 L
.62416 .28968 L
.62418 .28968 L
.6242 .31546 L
.62423 .26391 L
.62425 .29828 L
.62427 .33694 L
.62429 .2725 L
.62431 .30687 L
.62434 .34554 L
.62436 .29398 L
.62438 .28109 L
.6244 .34983 L
.62443 .30687 L
Mistroke
.62445 .29398 L
.62447 .33265 L
.62449 .32405 L
.62452 .2725 L
.62454 .30687 L
.62456 .31117 L
.62458 .28109 L
.6246 .28968 L
.62463 .31117 L
.62465 .27679 L
.62467 .2682 L
.62469 .29828 L
.62472 .28109 L
.62474 .2682 L
.62476 .28539 L
.62478 .28968 L
.62481 .25961 L
.62483 .28109 L
.62485 .28539 L
.62487 .27679 L
.62489 .2682 L
.62492 .29828 L
.62494 .27679 L
.62496 .2725 L
.62498 .29398 L
.62501 .29398 L
.62503 .28109 L
.62505 .29828 L
.62507 .29828 L
.6251 .27679 L
.62512 .30257 L
.62514 .32405 L
.62516 .27679 L
.62519 .30687 L
.62521 .35413 L
.62523 .27679 L
.62525 .30257 L
.62527 .34554 L
.6253 .30257 L
.62532 .29398 L
.62534 .33265 L
.62536 .30687 L
.62539 .28539 L
.62541 .31546 L
.62543 .31976 L
.62545 .28539 L
.62548 .29828 L
.6255 .30687 L
.62552 .27679 L
.62554 .27679 L
Mistroke
.62556 .30257 L
.62559 .28539 L
.62561 .26391 L
.62563 .28968 L
.62565 .27679 L
.62568 .25961 L
.6257 .28109 L
.62572 .28539 L
.62574 .26391 L
.62577 .28539 L
.62579 .27679 L
.62581 .27679 L
.62583 .28109 L
.62586 .29398 L
.62588 .29398 L
.6259 .28539 L
.62592 .28968 L
.62594 .28968 L
.62597 .29398 L
.62599 .28968 L
.62601 .29828 L
.62603 .30257 L
.62606 .29398 L
.62608 .29828 L
.6261 .29398 L
.62612 .30687 L
.62615 .30687 L
.62617 .28539 L
.62619 .33265 L
.62621 .32405 L
.62623 .27679 L
.62626 .33265 L
.62628 .32835 L
.6263 .28968 L
.62632 .32405 L
.62635 .34124 L
.62637 .29398 L
.62639 .30687 L
.62641 .33265 L
.62644 .30687 L
.62646 .29828 L
.62648 .32405 L
.6265 .30687 L
.62652 .28109 L
.62655 .29398 L
.62657 .30257 L
.62659 .28109 L
.62661 .28539 L
.62664 .29828 L
.62666 .27679 L
Mistroke
.62668 .26391 L
.6267 .28539 L
.62673 .27679 L
.62675 .27679 L
.62677 .28539 L
.62679 .28539 L
.62682 .2725 L
.62684 .28109 L
.62686 .28539 L
.62688 .28539 L
.6269 .28539 L
.62693 .28968 L
.62695 .28968 L
.62697 .28109 L
.62699 .29398 L
.62702 .29398 L
.62704 .29398 L
.62706 .29398 L
.62708 .30257 L
.62711 .28539 L
.62713 .30687 L
.62715 .31117 L
.62717 .27679 L
.62719 .33694 L
.62722 .32405 L
.62724 .28109 L
.62726 .32835 L
.62728 .33694 L
.62731 .28968 L
.62733 .31976 L
.62735 .34124 L
.62737 .30687 L
.6274 .30687 L
.62742 .33265 L
.62744 .31117 L
.62746 .29398 L
.62749 .31976 L
.62751 .31546 L
.62753 .28968 L
.62755 .29398 L
.62757 .31117 L
.6276 .28109 L
.62762 .28539 L
.62764 .29828 L
.62766 .28968 L
.62769 .2725 L
.62771 .29398 L
.62773 .28109 L
.62775 .27679 L
.62778 .28968 L
Mistroke
.6278 .28968 L
.62782 .27679 L
.62784 .28539 L
.62786 .28968 L
.62789 .27679 L
.62791 .28539 L
.62793 .28968 L
.62795 .28539 L
.62798 .28109 L
.628 .28968 L
.62802 .28539 L
.62804 .28539 L
.62807 .28968 L
.62809 .28968 L
.62811 .28539 L
.62813 .28539 L
.62815 .28968 L
.62818 .30687 L
.6282 .28109 L
.62822 .28968 L
.62824 .28968 L
.62827 .33694 L
.62829 .28109 L
.62831 .29828 L
.62833 .33265 L
.62836 .31546 L
.62838 .29398 L
.6284 .34124 L
.62842 .31976 L
.62845 .29828 L
.62847 .31976 L
.62849 .32835 L
.62851 .30257 L
.62853 .30687 L
.62856 .31546 L
.62858 .30257 L
.6286 .28968 L
.62862 .29828 L
.62865 .30257 L
.62867 .28539 L
.62869 .28539 L
.62871 .28968 L
.62874 .28109 L
.62876 .2725 L
.62878 .28539 L
.6288 .28109 L
.62882 .28109 L
.62885 .27679 L
.62887 .28539 L
.62889 .27679 L
Mistroke
.62891 .28109 L
.62894 .28109 L
.62896 .28968 L
.62898 .28539 L
.629 .28539 L
.62903 .28968 L
.62905 .28968 L
.62907 .28968 L
.62909 .29398 L
.62912 .29828 L
.62914 .28968 L
.62916 .28968 L
.62918 .29398 L
.6292 .29398 L
.62923 .28968 L
.62925 .29828 L
.62927 .31117 L
.62929 .28968 L
.62932 .28539 L
.62934 .32835 L
.62936 .28968 L
.62938 .29398 L
.62941 .32835 L
.62943 .31117 L
.62945 .28539 L
.62947 .31117 L
.62949 .31976 L
.62952 .29398 L
.62954 .30687 L
.62956 .31976 L
.62958 .30257 L
.62961 .28968 L
.62963 .30687 L
.62965 .30687 L
.62967 .28539 L
.6297 .28968 L
.62972 .30687 L
.62974 .28109 L
.62976 .27679 L
.62978 .29398 L
.62981 .28539 L
.62983 .2725 L
.62985 .29398 L
.62987 .28968 L
.6299 .27679 L
.62992 .28109 L
.62994 .28968 L
.62996 .28539 L
.62999 .28539 L
.63001 .28968 L
Mistroke
.63003 .28968 L
.63005 .28539 L
.63008 .28968 L
.6301 .29398 L
.63012 .28968 L
.63014 .28968 L
.63016 .29828 L
.63019 .29398 L
.63021 .28968 L
.63023 .29828 L
.63025 .29828 L
.63028 .28968 L
.6303 .29828 L
.63032 .30257 L
.63034 .28968 L
.63037 .29828 L
.63039 .31976 L
.63041 .28539 L
.63043 .29828 L
.63045 .33265 L
.63048 .28968 L
.6305 .29398 L
.63052 .32835 L
.63054 .30687 L
.63057 .28968 L
.63059 .31976 L
.63061 .31976 L
.63063 .31546 L
.63066 .29398 L
.63068 .30687 L
.6307 .31546 L
.63072 .29828 L
.63075 .29398 L
.63077 .30257 L
.63079 .29828 L
.63081 .28539 L
.63083 .28539 L
.63086 .29398 L
.63088 .28109 L
.6309 .28109 L
.63092 .28968 L
.63095 .28539 L
.63097 .27679 L
.63099 .28109 L
.63101 .28109 L
.63104 .28109 L
.63106 .28109 L
.63108 .29398 L
.6311 .28539 L
.63112 .28539 L
Mistroke
.63115 .28539 L
.63117 .28968 L
.63119 .28968 L
.63121 .28968 L
.63124 .29398 L
.63126 .29398 L
.63128 .28968 L
.6313 .28968 L
.63133 .29398 L
.63135 .28968 L
.63137 .28968 L
.63139 .30257 L
.63141 .28968 L
.63144 .28968 L
.63146 .29828 L
.63148 .28968 L
.6315 .28968 L
.63153 .30257 L
.63155 .30687 L
.63157 .30257 L
.63159 .28968 L
.63162 .31546 L
.63164 .31117 L
.63166 .28968 L
.63168 .31546 L
.63171 .32405 L
.63173 .30257 L
.63175 .29828 L
.63177 .32405 L
.63179 .30687 L
.63182 .29828 L
.63184 .31546 L
.63186 .31117 L
.63188 .29398 L
.63191 .29828 L
.63193 .30687 L
.63195 .29398 L
.63197 .28109 L
.632 .29398 L
.63202 .29398 L
.63204 .27679 L
.63206 .28109 L
.63208 .28968 L
.63211 .27679 L
.63213 .2725 L
.63215 .28968 L
.63217 .28109 L
.6322 .2725 L
.63222 .28539 L
.63224 .28968 L
Mistroke
.63226 .28109 L
.63229 .28539 L
.63231 .29398 L
.63233 .28539 L
.63235 .28539 L
.63237 .29828 L
.6324 .29398 L
.63242 .28968 L
.63244 .29398 L
.63246 .30257 L
.63249 .28968 L
.63251 .29398 L
.63253 .30257 L
.63255 .29828 L
.63258 .28968 L
.6326 .29828 L
.63262 .29828 L
.63264 .28968 L
.63267 .29828 L
.63269 .30257 L
.63271 .29398 L
.63273 .29398 L
.63275 .31117 L
.63278 .29398 L
.6328 .29828 L
.63282 .32405 L
.63284 .30257 L
.63287 .29828 L
.63289 .31546 L
.63291 .31546 L
.63293 .30257 L
.63296 .30257 L
.63298 .31117 L
.633 .32405 L
.63302 .31117 L
.63304 .30687 L
.63307 .31117 L
.63309 .31117 L
.63311 .29828 L
.63313 .29828 L
.63316 .30687 L
.63318 .29398 L
.6332 .28109 L
.63322 .29398 L
.63325 .28968 L
.63327 .27679 L
.63329 .28539 L
.63331 .28539 L
.63334 .27679 L
.63336 .27679 L
Mistroke
.63338 .28539 L
.6334 .28539 L
.63342 .27679 L
.63345 .28109 L
.63347 .28539 L
.63349 .28109 L
.63351 .28539 L
.63354 .29398 L
.63356 .28968 L
.63358 .28539 L
.6336 .29398 L
.63363 .29398 L
.63365 .28968 L
.63367 .29398 L
.63369 .29828 L
.63371 .29398 L
.63374 .28968 L
.63376 .29398 L
.63378 .29828 L
.6338 .29398 L
.63383 .29828 L
.63385 .29828 L
.63387 .29398 L
.63389 .29398 L
.63392 .29828 L
.63394 .29828 L
.63396 .29398 L
.63398 .29828 L
.634 .29828 L
.63403 .30257 L
.63405 .30257 L
.63407 .29828 L
.63409 .31546 L
.63412 .31117 L
.63414 .30257 L
.63416 .31117 L
.63418 .31546 L
.63421 .30687 L
.63423 .31117 L
.63425 .31546 L
.63427 .31546 L
.6343 .30687 L
.63432 .30687 L
.63434 .31117 L
.63436 .29828 L
.63438 .29828 L
.63441 .30687 L
.63443 .29828 L
.63445 .28539 L
.63447 .29398 L
Mistroke
.6345 .29398 L
.63452 .28109 L
.63454 .28539 L
.63456 .28968 L
.63459 .28109 L
.63461 .28109 L
.63463 .28539 L
.63465 .28539 L
.63467 .28539 L
.6347 .28539 L
.63472 .28539 L
.63474 .28968 L
.63476 .28539 L
.63479 .28539 L
.63481 .28968 L
.63483 .29398 L
.63485 .29398 L
.63488 .29398 L
.6349 .29398 L
.63492 .29398 L
.63494 .29828 L
.63497 .29398 L
.63499 .29828 L
.63501 .29828 L
.63503 .29398 L
.63505 .29398 L
.63508 .29398 L
.6351 .29398 L
.63512 .29828 L
.63514 .29828 L
.63517 .29828 L
.63519 .29828 L
.63521 .29828 L
.63523 .29828 L
.63526 .29398 L
.63528 .29828 L
.6353 .29828 L
.63532 .29828 L
.63534 .29828 L
.63537 .30687 L
.63539 .30257 L
.63541 .29828 L
.63543 .31117 L
.63546 .30687 L
.63548 .30257 L
.6355 .31117 L
.63552 .31546 L
.63555 .30257 L
.63557 .29828 L
.63559 .31117 L
Mistroke
.63561 .30687 L
.63563 .29828 L
.63566 .30687 L
.63568 .31117 L
.6357 .29398 L
.63572 .28968 L
.63575 .29828 L
.63577 .29398 L
.63579 .28539 L
.63581 .29398 L
.63584 .29398 L
.63586 .28109 L
.63588 .28109 L
.6359 .28968 L
.63593 .28539 L
.63595 .28109 L
.63597 .28539 L
.63599 .28539 L
.63601 .27679 L
.63604 .28109 L
.63606 .28539 L
.63608 .28968 L
.6361 .28968 L
.63613 .28968 L
.63615 .28968 L
.63617 .28539 L
.63619 .28968 L
.63622 .29398 L
.63624 .29398 L
.63626 .29398 L
.63628 .29398 L
.6363 .28968 L
.63633 .28968 L
.63635 .28968 L
.63637 .29398 L
.63639 .29398 L
.63642 .29398 L
.63644 .29398 L
.63646 .29398 L
.63648 .29398 L
.63651 .29828 L
.63653 .29828 L
.63655 .29828 L
.63657 .29398 L
.6366 .29398 L
.63662 .29828 L
.63664 .29828 L
.63666 .30257 L
.63668 .30257 L
.63671 .29828 L
Mistroke
.63673 .29398 L
.63675 .30257 L
.63677 .30687 L
.6368 .30257 L
.63682 .31117 L
.63684 .31546 L
.63686 .29828 L
.63689 .29828 L
.63691 .31117 L
.63693 .30687 L
.63695 .29828 L
.63697 .30687 L
.637 .30687 L
.63702 .29398 L
.63704 .28968 L
.63706 .30687 L
.63709 .30257 L
.63711 .28968 L
.63713 .28968 L
.63715 .29398 L
.63718 .28109 L
.6372 .28109 L
.63722 .29398 L
.63724 .28968 L
.63726 .28109 L
.63729 .28109 L
.63731 .28539 L
.63733 .28539 L
.63735 .28539 L
.63738 .28968 L
.6374 .28539 L
.63742 .28109 L
.63744 .28109 L
.63747 .28539 L
.63749 .28968 L
.63751 .28968 L
.63753 .28968 L
.63756 .28968 L
.63758 .28968 L
.6376 .28539 L
.63762 .28968 L
.63764 .29398 L
.63767 .29398 L
.63769 .29398 L
.63771 .28968 L
.63773 .28968 L
.63776 .28968 L
.63778 .28968 L
.6378 .29398 L
.63782 .29828 L
Mistroke
.63785 .29398 L
.63787 .29398 L
.63789 .29398 L
.63791 .29828 L
.63793 .29828 L
.63796 .29828 L
.63798 .30257 L
.638 .29828 L
.63802 .29828 L
.63805 .30257 L
.63807 .30257 L
.63809 .30257 L
.63811 .30257 L
.63814 .29828 L
.63816 .29828 L
.63818 .29828 L
.6382 .30257 L
.63823 .30687 L
.63825 .30257 L
.63827 .29828 L
.63829 .30257 L
.63831 .30687 L
.63834 .30257 L
.63836 .30687 L
.63838 .30687 L
.6384 .30257 L
.63843 .29398 L
.63845 .29828 L
.63847 .30687 L
.63849 .30257 L
.63852 .29398 L
.63854 .29828 L
.63856 .29398 L
.63858 .28539 L
.6386 .29398 L
.63863 .29828 L
.63865 .28968 L
.63867 .28539 L
.63869 .28968 L
.63872 .28968 L
.63874 .28539 L
.63876 .28539 L
.63878 .29398 L
.63881 .28968 L
.63883 .28109 L
.63885 .28968 L
.63887 .29398 L
.63889 .29398 L
.63892 .28968 L
.63894 .29398 L
Mistroke
.63896 .29398 L
.63898 .28968 L
.63901 .29398 L
.63903 .30257 L
.63905 .29828 L
.63907 .28968 L
.6391 .29398 L
.63912 .29828 L
.63914 .29828 L
.63916 .29828 L
.63919 .30257 L
.63921 .29828 L
.63923 .29398 L
.63925 .29398 L
.63927 .29828 L
.6393 .29828 L
.63932 .29828 L
.63934 .30257 L
.63936 .29828 L
.63939 .29398 L
.63941 .29828 L
.63943 .30687 L
.63945 .30687 L
.63948 .30257 L
.6395 .29828 L
.63952 .29828 L
.63954 .29828 L
.63956 .30257 L
.63959 .30687 L
.63961 .30687 L
.63963 .29828 L
.63965 .29398 L
.63968 .29828 L
.6397 .30257 L
.63972 .30257 L
.63974 .30257 L
.63977 .29828 L
.63979 .29398 L
.63981 .29828 L
.63983 .29828 L
.63986 .30257 L
.63988 .30257 L
.6399 .29828 L
.63992 .29398 L
.63994 .28968 L
.63997 .29398 L
.63999 .29828 L
.64001 .30257 L
.64003 .29828 L
.64006 .29828 L
Mistroke
.64008 .29398 L
.6401 .28539 L
.64012 .28539 L
.64015 .29398 L
.64017 .29828 L
.64019 .29398 L
.64021 .28968 L
.64023 .28539 L
.64026 .28968 L
.64028 .28968 L
.6403 .29398 L
.64032 .29398 L
.64035 .29398 L
.64037 .28968 L
.64039 .28539 L
.64041 .28968 L
.64044 .29828 L
.64046 .29398 L
.64048 .29398 L
.6405 .29398 L
.64052 .28968 L
.64055 .28968 L
.64057 .28968 L
.64059 .29398 L
.64061 .29398 L
.64064 .28968 L
.64066 .28968 L
.64068 .28968 L
.6407 .29398 L
.64073 .29398 L
.64075 .29398 L
.64077 .29398 L
.64079 .29398 L
.64082 .29398 L
.64084 .29828 L
.64086 .29828 L
.64088 .29828 L
.6409 .29828 L
.64093 .29398 L
.64095 .29828 L
.64097 .30257 L
.64099 .30257 L
.64102 .29828 L
.64104 .29828 L
.64106 .29398 L
.64108 .29398 L
.64111 .29828 L
.64113 .30257 L
.64115 .29828 L
.64117 .29398 L
Mistroke
.64119 .28968 L
.64122 .29398 L
.64124 .29398 L
.64126 .29398 L
.64128 .29828 L
.64131 .29398 L
.64133 .28968 L
.64135 .28968 L
.64137 .29398 L
.6414 .29828 L
.64142 .29828 L
.64144 .29828 L
.64146 .29398 L
.64149 .29398 L
.64151 .29828 L
.64153 .30257 L
.64155 .30257 L
.64157 .29828 L
.6416 .29828 L
.64162 .29398 L
.64164 .29398 L
.64166 .29398 L
.64169 .29828 L
.64171 .29828 L
.64173 .29398 L
.64175 .28968 L
.64178 .28968 L
.6418 .28968 L
.64182 .28968 L
.64184 .29398 L
.64186 .29398 L
.64189 .28539 L
.64191 .28539 L
.64193 .28539 L
.64195 .28968 L
.64198 .28968 L
.642 .28968 L
.64202 .28968 L
.64204 .28968 L
.64207 .28968 L
.64209 .28968 L
.64211 .29398 L
.64213 .29398 L
.64215 .28968 L
.64218 .28968 L
.6422 .28968 L
.64222 .29398 L
.64224 .29398 L
.64227 .29398 L
.64229 .29398 L
Mistroke
.64231 .29398 L
.64233 .29828 L
.64236 .29828 L
.64238 .29828 L
.6424 .29828 L
.64242 .29828 L
.64245 .29828 L
.64247 .29398 L
.64249 .29828 L
.64251 .30257 L
.64253 .29828 L
.64256 .29828 L
.64258 .29398 L
.6426 .29398 L
.64262 .29398 L
.64265 .29828 L
.64267 .30257 L
.64269 .29828 L
.64271 .29828 L
.64274 .29398 L
.64276 .29828 L
.64278 .29828 L
.6428 .30257 L
.64282 .30257 L
.64285 .30257 L
.64287 .29828 L
.64289 .29828 L
.64291 .29828 L
.64294 .30687 L
.64296 .30687 L
.64298 .30257 L
.643 .29828 L
.64303 .29828 L
.64305 .29828 L
.64307 .29828 L
.64309 .30257 L
.64312 .30257 L
.64314 .29828 L
.64316 .29398 L
.64318 .29398 L
.6432 .29828 L
.64323 .30257 L
.64325 .30257 L
.64327 .29828 L
.64329 .29398 L
.64332 .29398 L
.64334 .29398 L
.64336 .29828 L
.64338 .30257 L
.64341 .29828 L
Mistroke
.64343 .29398 L
.64345 .28968 L
.64347 .29398 L
.64349 .29398 L
.64352 .29828 L
.64354 .29828 L
.64356 .28968 L
.64358 .28539 L
.64361 .28539 L
.64363 .29398 L
.64365 .29828 L
.64367 .29398 L
.6437 .28968 L
.64372 .28539 L
.64374 .28539 L
.64376 .28968 L
.64378 .29828 L
.64381 .29828 L
.64383 .28968 L
.64385 .28539 L
.64387 .28539 L
.6439 .28968 L
.64392 .29398 L
.64394 .30257 L
.64396 .29828 L
.64399 .28968 L
.64401 .28968 L
.64403 .28968 L
.64405 .29828 L
.64408 .30257 L
.6441 .30257 L
.64412 .30257 L
.64414 .29828 L
.64416 .29398 L
.64419 .29828 L
.64421 .30257 L
.64423 .30687 L
.64425 .30687 L
.64428 .30257 L
.6443 .29828 L
.64432 .29828 L
.64434 .30257 L
.64437 .30257 L
.64439 .30257 L
.64441 .30257 L
.64443 .30257 L
.64445 .29828 L
.64448 .29828 L
.6445 .29828 L
.64452 .30257 L
Mistroke
.64454 .30257 L
.64457 .30257 L
.64459 .29828 L
.64461 .29828 L
.64463 .29828 L
.64466 .29398 L
.64468 .29828 L
.6447 .30257 L
.64472 .29828 L
.64475 .29828 L
.64477 .29398 L
.64479 .29398 L
.64481 .29398 L
.64483 .29828 L
.64486 .29828 L
.64488 .29828 L
.6449 .29398 L
.64492 .28968 L
.64495 .28968 L
.64497 .28968 L
.64499 .29828 L
.64501 .29828 L
.64504 .29398 L
.64506 .28968 L
.64508 .28539 L
.6451 .28539 L
.64512 .28968 L
.64515 .29398 L
.64517 .29398 L
.64519 .28539 L
.64521 .28109 L
.64524 .28109 L
.64526 .28539 L
.64528 .28968 L
.6453 .29398 L
.64533 .28968 L
.64535 .28539 L
.64537 .28109 L
.64539 .28539 L
.64541 .28968 L
.64544 .29828 L
.64546 .29828 L
.64548 .29828 L
.6455 .29398 L
.64553 .28968 L
.64555 .28968 L
.64557 .29398 L
.64559 .29828 L
.64562 .30257 L
.64564 .30257 L
Mistroke
.64566 .29398 L
.64568 .29398 L
.64571 .28968 L
.64573 .29398 L
.64575 .30257 L
.64577 .30687 L
.64579 .30257 L
.64582 .29828 L
.64584 .28539 L
.64586 .28539 L
.64588 .29398 L
.64591 .30257 L
.64593 .30257 L
.64595 .29398 L
.64597 .28968 L
.646 .28968 L
.64602 .28968 L
.64604 .30257 L
.64606 .30687 L
.64608 .30257 L
.64611 .29398 L
.64613 .28968 L
.64615 .28968 L
.64617 .29828 L
.6462 .30687 L
.64622 .30257 L
.64624 .29398 L
.64626 .28539 L
.64629 .28539 L
.64631 .28968 L
.64633 .29828 L
.64635 .29828 L
.64638 .29398 L
.6464 .28968 L
.64642 .28539 L
.64644 .28539 L
.64646 .29398 L
.64649 .29828 L
.64651 .29398 L
.64653 .28968 L
.64655 .28539 L
.64658 .28539 L
.6466 .28968 L
.64662 .29398 L
.64664 .29828 L
.64667 .29828 L
.64669 .29398 L
.64671 .28968 L
.64673 .28968 L
.64675 .28968 L
Mistroke
.64678 .29398 L
.6468 .29828 L
.64682 .30257 L
.64684 .29828 L
.64687 .29398 L
.64689 .29398 L
.64691 .29398 L
.64693 .29398 L
.64696 .29828 L
.64698 .30257 L
.647 .30257 L
.64702 .29828 L
.64704 .29398 L
.64707 .29398 L
.64709 .29828 L
.64711 .30257 L
.64713 .30257 L
.64716 .30257 L
.64718 .30257 L
.6472 .29828 L
.64722 .29398 L
.64725 .29398 L
.64727 .29828 L
.64729 .30257 L
.64731 .30687 L
.64734 .30257 L
.64736 .29828 L
.64738 .29398 L
.6474 .29398 L
.64742 .29828 L
.64745 .30257 L
.64747 .30257 L
.64749 .30257 L
.64751 .29828 L
.64754 .29398 L
.64756 .29398 L
.64758 .29828 L
.6476 .29828 L
.64763 .29828 L
.64765 .29828 L
.64767 .29398 L
.64769 .29398 L
.64771 .29398 L
.64774 .29398 L
.64776 .29398 L
.64778 .29398 L
.6478 .29398 L
.64783 .28968 L
.64785 .28968 L
.64787 .28968 L
Mistroke
.64789 .28968 L
.64792 .29398 L
.64794 .29398 L
.64796 .29398 L
.64798 .28968 L
.648 .28968 L
.64803 .29398 L
.64805 .29398 L
.64807 .29398 L
.64809 .29828 L
.64812 .29828 L
.64814 .29828 L
.64816 .29398 L
.64818 .29398 L
.64821 .29398 L
.64823 .29828 L
.64825 .30257 L
.64827 .29828 L
.6483 .29828 L
.64832 .29828 L
.64834 .29828 L
.64836 .29398 L
.64838 .29828 L
.64841 .29828 L
.64843 .30257 L
.64845 .30257 L
.64847 .29828 L
.6485 .29828 L
.64852 .29828 L
.64854 .29828 L
.64856 .30257 L
.64859 .29828 L
.64861 .30257 L
.64863 .30257 L
.64865 .29828 L
.64867 .29828 L
.6487 .29828 L
.64872 .29828 L
.64874 .29828 L
.64876 .30257 L
.64879 .29828 L
.64881 .29828 L
.64883 .29398 L
.64885 .29398 L
.64888 .29398 L
.6489 .29828 L
.64892 .29398 L
.64894 .29398 L
.64897 .29398 L
.64899 .29398 L
Mistroke
.64901 .29398 L
.64903 .29398 L
.64905 .29398 L
.64908 .29398 L
.6491 .29398 L
.64912 .28968 L
.64914 .28968 L
.64917 .28968 L
.64919 .29398 L
.64921 .28968 L
.64923 .29398 L
.64926 .28968 L
.64928 .28968 L
.6493 .28968 L
.64932 .29398 L
.64934 .29398 L
.64937 .29828 L
.64939 .29828 L
.64941 .29398 L
.64943 .29398 L
.64946 .29398 L
.64948 .29398 L
.6495 .29828 L
.64952 .29828 L
.64955 .29828 L
.64957 .30257 L
.64959 .29828 L
.64961 .29398 L
.64963 .29398 L
.64966 .29828 L
.64968 .30257 L
.6497 .30257 L
.64972 .29828 L
.64975 .29828 L
.64977 .29828 L
.64979 .29828 L
.64981 .30257 L
.64984 .29828 L
.64986 .30257 L
.64988 .29828 L
.6499 .29828 L
.64993 .30257 L
.64995 .30257 L
.64997 .30257 L
.64999 .29828 L
.65001 .29828 L
.65004 .29828 L
.65006 .29828 L
.65008 .29828 L
.6501 .29828 L
Mistroke
.65013 .29828 L
.65015 .29398 L
.65017 .29398 L
.65019 .29398 L
.65022 .29828 L
.65024 .29398 L
.65026 .29398 L
.65028 .29398 L
.6503 .28968 L
.65033 .28968 L
.65035 .29398 L
.65037 .29398 L
.65039 .29398 L
.65042 .28968 L
.65044 .28968 L
.65046 .28968 L
.65048 .28968 L
.65051 .29398 L
.65053 .29398 L
.65055 .29398 L
.65057 .28968 L
.6506 .28968 L
.65062 .28968 L
.65064 .28968 L
.65066 .29398 L
.65068 .29828 L
.65071 .29398 L
.65073 .29398 L
.65075 .29398 L
.65077 .29398 L
.6508 .29398 L
.65082 .29828 L
.65084 .30257 L
.65086 .29828 L
.65089 .29828 L
.65091 .29398 L
.65093 .29398 L
.65095 .29828 L
.65097 .29828 L
.651 .29828 L
.65102 .29828 L
.65104 .29828 L
.65106 .29828 L
.65109 .29828 L
.65111 .29828 L
.65113 .29828 L
.65115 .30257 L
.65118 .30257 L
.6512 .29828 L
.65122 .29828 L
Mistroke
.65124 .29828 L
.65126 .29828 L
.65129 .29828 L
.65131 .30257 L
.65133 .29828 L
.65135 .29828 L
.65138 .29828 L
.6514 .29398 L
.65142 .29398 L
.65144 .29398 L
.65147 .29828 L
.65149 .29828 L
.65151 .29828 L
.65153 .29398 L
.65156 .29398 L
.65158 .29398 L
.6516 .29398 L
.65162 .29398 L
.65164 .29398 L
.65167 .29398 L
.65169 .28968 L
.65171 .28968 L
.65173 .28968 L
.65176 .28968 L
.65178 .29398 L
.6518 .28968 L
.65182 .28968 L
.65185 .28968 L
.65187 .28968 L
.65189 .28968 L
.65191 .29398 L
.65193 .29398 L
.65196 .29398 L
.65198 .29398 L
.652 .29398 L
.65202 .29398 L
.65205 .29398 L
.65207 .29828 L
.65209 .29398 L
.65211 .29828 L
.65214 .29828 L
.65216 .29828 L
.65218 .29828 L
.6522 .29828 L
.65223 .29828 L
.65225 .29398 L
.65227 .29828 L
.65229 .29828 L
.65231 .29828 L
.65234 .29828 L
Mistroke
.65236 .29828 L
.65238 .29828 L
.6524 .29398 L
.65243 .29828 L
.65245 .29828 L
.65247 .30257 L
.65249 .30257 L
.65252 .30257 L
.65254 .29398 L
.65256 .29398 L
.65258 .29398 L
.6526 .29828 L
.65263 .29828 L
.65265 .29828 L
.65267 .29828 L
.65269 .29398 L
.65272 .29398 L
.65274 .29398 L
.65276 .29828 L
.65278 .29828 L
.65281 .29828 L
.65283 .29398 L
.65285 .29398 L
.65287 .29398 L
.65289 .29398 L
.65292 .29398 L
.65294 .29398 L
.65296 .29398 L
.65298 .29398 L
.65301 .28968 L
.65303 .29398 L
.65305 .28968 L
.65307 .28968 L
.6531 .28968 L
.65312 .28968 L
.65314 .28968 L
.65316 .29398 L
.65319 .29398 L
.65321 .29398 L
.65323 .29398 L
.65325 .29398 L
.65327 .29398 L
.6533 .29398 L
.65332 .29828 L
.65334 .29828 L
.65336 .29828 L
.65339 .29828 L
.65341 .29398 L
.65343 .29398 L
.65345 .29398 L
Mistroke
.65348 .29828 L
.6535 .29828 L
.65352 .29828 L
.65354 .29398 L
.65356 .28968 L
.65359 .29398 L
.65361 .29398 L
.65363 .29828 L
.65365 .29828 L
.65368 .29828 L
.6537 .29398 L
.65372 .29398 L
.65374 .29398 L
.65377 .29828 L
.65379 .29828 L
.65381 .29828 L
.65383 .29828 L
.65386 .29828 L
.65388 .29398 L
.6539 .29398 L
.65392 .29828 L
.65394 .29828 L
.65397 .29828 L
.65399 .29828 L
.65401 .29398 L
.65403 .29398 L
.65406 .29398 L
.65408 .29398 L
.6541 .29828 L
.65412 .29398 L
.65415 .29398 L
.65417 .28968 L
.65419 .28968 L
.65421 .28968 L
.65423 .28968 L
.65426 .29398 L
.65428 .29398 L
.6543 .29398 L
.65432 .28968 L
.65435 .28968 L
.65437 .29398 L
.65439 .29398 L
.65441 .29398 L
.65444 .29398 L
.65446 .29398 L
.65448 .29398 L
.6545 .29828 L
.65452 .29828 L
.65455 .29828 L
.65457 .29828 L
Mistroke
.65459 .29828 L
.65461 .29398 L
.65464 .29828 L
.65466 .29828 L
.65468 .29828 L
.6547 .29398 L
.65473 .29398 L
.65475 .29398 L
.65477 .29398 L
.65479 .29398 L
.65482 .29398 L
.65484 .29398 L
.65486 .29398 L
.65488 .29398 L
.6549 .29398 L
.65493 .29828 L
.65495 .29828 L
.65497 .29398 L
.65499 .29828 L
.65502 .29828 L
.65504 .29828 L
.65506 .29828 L
.65508 .29828 L
.65511 .29828 L
.65513 .29398 L
.65515 .29828 L
.65517 .29828 L
.65519 .30257 L
.65522 .29828 L
.65524 .29398 L
.65526 .29398 L
.65528 .29398 L
.65531 .29828 L
.65533 .30257 L
.65535 .29828 L
.65537 .29398 L
.6554 .28968 L
.65542 .28968 L
.65544 .29398 L
.65546 .29828 L
.65549 .29828 L
.65551 .29398 L
.65553 .28968 L
.65555 .28968 L
.65557 .29398 L
.6556 .29828 L
.65562 .30257 L
.65564 .30257 L
.65566 .29828 L
.65569 .29398 L
Mistroke
.65571 .29828 L
.65573 .30257 L
.65575 .30257 L
.65578 .30257 L
.6558 .30257 L
.65582 .29828 L
.65584 .29398 L
.65586 .29828 L
.65589 .29828 L
.65591 .29828 L
.65593 .29828 L
.65595 .29398 L
.65598 .29398 L
.656 .28968 L
.65602 .29398 L
.65604 .29398 L
.65607 .29398 L
.65609 .29398 L
.65611 .28968 L
.65613 .28968 L
.65615 .29398 L
.65618 .29398 L
.6562 .29828 L
.65622 .29828 L
.65624 .29398 L
.65627 .28968 L
.65629 .29398 L
.65631 .29398 L
.65633 .29828 L
.65636 .30257 L
.65638 .29828 L
.6564 .29398 L
.65642 .28968 L
.65645 .29398 L
.65647 .29828 L
.65649 .30257 L
.65651 .29828 L
.65653 .29398 L
.65656 .28539 L
.65658 .28539 L
.6566 .28539 L
.65662 .29398 L
.65665 .30257 L
.65667 .29828 L
.65669 .29398 L
.65671 .28968 L
.65674 .28539 L
.65676 .28968 L
.65678 .29828 L
.6568 .30257 L
Mistroke
.65682 .30257 L
.65685 .29828 L
.65687 .29398 L
.65689 .29398 L
.65691 .29828 L
.65694 .30257 L
.65696 .30687 L
.65698 .30257 L
.657 .29828 L
.65703 .29398 L
.65705 .29398 L
.65707 .29828 L
.65709 .30257 L
.65712 .30257 L
.65714 .29828 L
.65716 .29398 L
.65718 .29398 L
.6572 .29398 L
.65723 .29398 L
.65725 .29398 L
.65727 .29398 L
.65729 .29398 L
.65732 .28968 L
.65734 .28968 L
.65736 .28968 L
.65738 .28968 L
.65741 .29398 L
.65743 .29398 L
.65745 .28968 L
.65747 .28968 L
.65749 .28968 L
.65752 .29398 L
.65754 .29828 L
.65756 .29398 L
.65758 .29398 L
.65761 .28968 L
.65763 .29398 L
.65765 .29828 L
.65767 .29828 L
.6577 .29398 L
.65772 .29398 L
.65774 .28968 L
.65776 .29398 L
.65778 .29828 L
.65781 .30257 L
.65783 .29828 L
.65785 .28968 L
.65787 .28968 L
.6579 .28968 L
.65792 .29398 L
Mistroke
.65794 .29828 L
.65796 .29828 L
.65799 .29398 L
.65801 .28968 L
.65803 .28968 L
.65805 .29398 L
.65808 .30257 L
.6581 .30687 L
.65812 .30257 L
.65814 .29828 L
.65816 .29398 L
.65819 .29828 L
.65821 .29828 L
.65823 .30257 L
.65825 .30687 L
.65828 .30257 L
.6583 .29828 L
.65832 .29398 L
.65834 .29398 L
.65837 .29828 L
.65839 .30257 L
.65841 .29828 L
.65843 .29398 L
.65845 .28968 L
.65848 .28539 L
.6585 .28968 L
.65852 .29398 L
.65854 .29828 L
.65857 .29398 L
.65859 .28539 L
.65861 .28109 L
.65863 .28539 L
.65866 .28968 L
.65868 .30257 L
.6587 .29828 L
.65872 .28968 L
.65875 .28109 L
.65877 .28109 L
.65879 .28968 L
.65881 .29828 L
.65883 .30257 L
.65886 .29398 L
.65888 .28539 L
.6589 .28109 L
.65892 .28968 L
.65895 .29828 L
.65897 .29828 L
.65899 .30257 L
.65901 .29828 L
.65904 .28968 L
Mistroke
.65906 .28539 L
.65908 .28539 L
.6591 .29828 L
.65912 .30257 L
.65915 .30257 L
.65917 .29398 L
.65919 .28539 L
.65921 .28539 L
.65924 .29398 L
.65926 .30257 L
.65928 .30687 L
.6593 .30257 L
.65933 .29398 L
.65935 .28968 L
.65937 .29398 L
.65939 .30257 L
.65941 .31117 L
.65944 .31117 L
.65946 .30687 L
.65948 .29828 L
.6595 .29398 L
.65953 .29828 L
.65955 .30257 L
.65957 .30687 L
.65959 .30687 L
.65962 .29828 L
.65964 .28968 L
.65966 .28968 L
.65968 .29398 L
.65971 .29828 L
.65973 .30257 L
.65975 .29398 L
.65977 .28539 L
.65979 .28109 L
.65982 .28968 L
.65984 .29828 L
.65986 .30257 L
.65988 .29828 L
.65991 .28539 L
.65993 .28109 L
.65995 .28539 L
.65997 .29398 L
.66 .30257 L
.66002 .29828 L
.66004 .28539 L
.66006 .27679 L
.66008 .28109 L
.66011 .29398 L
.66013 .30257 L
.66015 .29828 L
Mistroke
.66017 .28968 L
.6602 .28109 L
.66022 .28109 L
.66024 .28968 L
.66026 .29828 L
.66029 .30257 L
.66031 .29828 L
.66033 .28539 L
.66035 .28539 L
.66038 .28968 L
.6604 .29828 L
.66042 .30257 L
.66044 .30257 L
.66046 .29398 L
.66049 .28968 L
.66051 .28968 L
.66053 .29828 L
.66055 .31117 L
.66058 .31117 L
.6606 .30687 L
.66062 .29828 L
.66064 .29398 L
.66067 .29828 L
.66069 .30687 L
.66071 .31117 L
.66073 .31117 L
.66075 .30687 L
.66078 .29398 L
.6608 .29398 L
.66082 .29828 L
.66084 .30257 L
.66087 .30687 L
.66089 .30257 L
.66091 .29398 L
.66093 .28968 L
.66096 .28539 L
.66098 .29398 L
.661 .29828 L
.66102 .29828 L
.66104 .29398 L
.66107 .28968 L
.66109 .28539 L
.66111 .28968 L
.66113 .29828 L
.66116 .29828 L
.66118 .29828 L
.6612 .28968 L
.66122 .28539 L
.66125 .28539 L
.66127 .29398 L
Mistroke
.66129 .29828 L
.66131 .29398 L
.66134 .29398 L
.66136 .28968 L
.66138 .28539 L
.6614 .28539 L
.66142 .28968 L
.66145 .29828 L
.66147 .29828 L
.66149 .28968 L
.66151 .28539 L
.66154 .28539 L
.66156 .29398 L
.66158 .29828 L
.6616 .29828 L
.66163 .29398 L
.66165 .28968 L
.66167 .28968 L
.66169 .29398 L
.66171 .30257 L
.66174 .30687 L
.66176 .30257 L
.66178 .29828 L
.6618 .29398 L
.66183 .29828 L
.66185 .30257 L
.66187 .31117 L
.66189 .31117 L
.66192 .30687 L
.66194 .30257 L
.66196 .29828 L
.66198 .29828 L
.66201 .30257 L
.66203 .30687 L
.66205 .30687 L
.66207 .30257 L
.66209 .29828 L
.66212 .29398 L
.66214 .29398 L
.66216 .29828 L
.66218 .29828 L
.66221 .29828 L
.66223 .29398 L
.66225 .28968 L
.66227 .28539 L
.6623 .28968 L
.66232 .29828 L
.66234 .29828 L
.66236 .29398 L
.66238 .28968 L
Mistroke
.66241 .28539 L
.66243 .28539 L
.66245 .29398 L
.66247 .29828 L
.6625 .29398 L
.66252 .28968 L
.66254 .28539 L
.66256 .28539 L
.66259 .28968 L
.66261 .29398 L
.66263 .29398 L
.66265 .28968 L
.66267 .28109 L
.6627 .28109 L
.66272 .28968 L
.66274 .29398 L
.66276 .29828 L
.66279 .29398 L
.66281 .28968 L
.66283 .28539 L
.66285 .28968 L
.66288 .29398 L
.6629 .29828 L
.66292 .29828 L
.66294 .29828 L
.66297 .29398 L
.66299 .29398 L
.66301 .29828 L
.66303 .30687 L
.66305 .30687 L
.66308 .30687 L
.6631 .30687 L
.66312 .30257 L
.66314 .30257 L
.66317 .30687 L
.66319 .30687 L
.66321 .30687 L
.66323 .30687 L
.66326 .30257 L
.66328 .30257 L
.6633 .29828 L
.66332 .29828 L
.66334 .29828 L
.66337 .29828 L
.66339 .29828 L
.66341 .29828 L
.66343 .29398 L
.66346 .29398 L
.66348 .29398 L
.6635 .29398 L
Mistroke
.66352 .29828 L
.66355 .29398 L
.66357 .29398 L
.66359 .28968 L
.66361 .28968 L
.66364 .28968 L
.66366 .29398 L
.66368 .29398 L
.6637 .29398 L
.66372 .28968 L
.66375 .28539 L
.66377 .28539 L
.66379 .28539 L
.66381 .29398 L
.66384 .29398 L
.66386 .28968 L
.66388 .28539 L
.6639 .28539 L
.66393 .28539 L
.66395 .28968 L
.66397 .28968 L
.66399 .28968 L
.66401 .28968 L
.66404 .28539 L
.66406 .28539 L
.66408 .28968 L
.6641 .29398 L
.66413 .29398 L
.66415 .29398 L
.66417 .29398 L
.66419 .29398 L
.66422 .29398 L
.66424 .29828 L
.66426 .29828 L
.66428 .30257 L
.6643 .30257 L
.66433 .30257 L
.66435 .30687 L
.66437 .30257 L
.66439 .30687 L
.66442 .30257 L
.66444 .30257 L
.66446 .30687 L
.66448 .30687 L
.66451 .30687 L
.66453 .30257 L
.66455 .29828 L
.66457 .29828 L
.6646 .30257 L
.66462 .30257 L
Mistroke
.66464 .30257 L
.66466 .29828 L
.66468 .29398 L
.66471 .29398 L
.66473 .29398 L
.66475 .29398 L
.66477 .29828 L
.6648 .29828 L
.66482 .29398 L
.66484 .28968 L
.66486 .28968 L
.66489 .29398 L
.66491 .29398 L
.66493 .29398 L
.66495 .29398 L
.66497 .28968 L
.665 .28539 L
.66502 .28968 L
.66504 .28968 L
.66506 .29398 L
.66509 .28968 L
.66511 .28968 L
.66513 .28539 L
.66515 .28539 L
.66518 .28539 L
.6652 .28968 L
.66522 .29398 L
.66524 .29398 L
.66526 .28968 L
.66529 .28539 L
.66531 .28539 L
.66533 .28968 L
.66535 .29398 L
.66538 .29828 L
.6654 .29398 L
.66542 .28968 L
.66544 .28968 L
.66547 .29398 L
.66549 .29828 L
.66551 .30257 L
.66553 .30257 L
.66556 .30257 L
.66558 .29828 L
.6656 .29828 L
.66562 .30257 L
.66564 .30687 L
.66567 .30687 L
.66569 .30687 L
.66571 .30687 L
.66573 .30257 L
Mistroke
.66576 .30257 L
.66578 .30257 L
.6658 .30257 L
.66582 .30257 L
.66585 .30257 L
.66587 .30257 L
.66589 .29828 L
.66591 .29828 L
.66593 .29828 L
.66596 .29828 L
.66598 .29828 L
.666 .29828 L
.66602 .29828 L
.66605 .29398 L
.66607 .29398 L
.66609 .29398 L
.66611 .29398 L
.66614 .29398 L
.66616 .29398 L
.66618 .29398 L
.6662 .29398 L
.66623 .29398 L
.66625 .28968 L
.66627 .28968 L
.66629 .28968 L
.66631 .28968 L
.66634 .29398 L
.66636 .29398 L
.66638 .28968 L
.6664 .28968 L
.66643 .28539 L
.66645 .28539 L
.66647 .28968 L
.66649 .28968 L
.66652 .28968 L
.66654 .28968 L
.66656 .28539 L
.66658 .28968 L
.6666 .28968 L
.66663 .29398 L
.66665 .29398 L
.66667 .29398 L
.66669 .29398 L
.66672 .28968 L
.66674 .29398 L
.66676 .29828 L
.66678 .29828 L
.66681 .30257 L
.66683 .30257 L
.66685 .29828 L
Mistroke
.66687 .29828 L
.66689 .30257 L
.66692 .30687 L
.66694 .30687 L
.66696 .30687 L
.66698 .30257 L
.66701 .30257 L
.66703 .30257 L
.66705 .30687 L
.66707 .30687 L
.6671 .30257 L
.66712 .29828 L
.66714 .29828 L
.66716 .29828 L
.66719 .29828 L
.66721 .29828 L
.66723 .29828 L
.66725 .29398 L
.66727 .29398 L
.6673 .28968 L
.66732 .29398 L
.66734 .29398 L
.66736 .29828 L
.66739 .29398 L
.66741 .29398 L
.66743 .28968 L
.66745 .28968 L
.66748 .28968 L
.6675 .29398 L
.66752 .29398 L
.66754 .28968 L
.66756 .28968 L
.66759 .28539 L
.66761 .28968 L
.66763 .28968 L
.66765 .28968 L
.66768 .28968 L
.6677 .28968 L
.66772 .28539 L
.66774 .28539 L
.66777 .28968 L
.66779 .28968 L
.66781 .28968 L
.66783 .28968 L
.66786 .28968 L
.66788 .28968 L
.6679 .28968 L
.66792 .28968 L
.66794 .29398 L
.66797 .29398 L
Mistroke
.66799 .29398 L
.66801 .29398 L
.66803 .29398 L
.66806 .30257 L
.66808 .30257 L
.6681 .30257 L
.66812 .30257 L
.66815 .29828 L
.66817 .30257 L
.66819 .30687 L
.66821 .31117 L
.66823 .30687 L
.66826 .30257 L
.66828 .30257 L
.6683 .30257 L
.66832 .30257 L
.66835 .30687 L
.66837 .30687 L
.66839 .30257 L
.66841 .29828 L
.66844 .29828 L
.66846 .29828 L
.66848 .29828 L
.6685 .29828 L
.66852 .30257 L
.66855 .29828 L
.66857 .29398 L
.66859 .29398 L
.66861 .29398 L
.66864 .29398 L
.66866 .29398 L
.66868 .29398 L
.6687 .29398 L
.66873 .28968 L
.66875 .28968 L
.66877 .28968 L
.66879 .28968 L
.66882 .28968 L
.66884 .28968 L
.66886 .28968 L
.66888 .28968 L
.6689 .28968 L
.66893 .28968 L
.66895 .28968 L
.66897 .28968 L
.66899 .28968 L
.66902 .28968 L
.66904 .28968 L
.66906 .28968 L
.66908 .28968 L
Mistroke
.66911 .28968 L
.66913 .28968 L
.66915 .28968 L
.66917 .28968 L
.66919 .28968 L
.66922 .28968 L
.66924 .28968 L
.66926 .28968 L
.66928 .29398 L
.66931 .29828 L
.66933 .29828 L
.66935 .29828 L
.66937 .29828 L
.6694 .29828 L
.66942 .29828 L
.66944 .30257 L
.66946 .30257 L
.66949 .30687 L
.66951 .30687 L
.66953 .30257 L
.66955 .30257 L
.66957 .30257 L
.6696 .30687 L
.66962 .30687 L
.66964 .30687 L
.66966 .30257 L
.66969 .29828 L
.66971 .29398 L
.66973 .29828 L
.66975 .30257 L
.66978 .30257 L
.6698 .30257 L
.66982 .29398 L
.66984 .28968 L
.66986 .28968 L
.66989 .29398 L
.66991 .29828 L
.66993 .29828 L
.66995 .29398 L
.66998 .28968 L
.67 .28968 L
.67002 .29398 L
.67004 .29398 L
.67007 .29828 L
.67009 .29398 L
.67011 .28968 L
.67013 .28539 L
.67015 .28968 L
.67018 .29398 L
.6702 .29398 L
Mistroke
.67022 .28968 L
.67024 .28539 L
.67027 .28539 L
.67029 .28539 L
.67031 .28968 L
.67033 .28968 L
.67036 .28968 L
.67038 .28539 L
.6704 .28539 L
.67042 .28968 L
.67045 .28968 L
.67047 .29398 L
.67049 .29398 L
.67051 .28968 L
.67053 .28968 L
.67056 .28968 L
.67058 .29398 L
.6706 .29828 L
.67062 .29828 L
.67065 .29828 L
.67067 .29398 L
.67069 .29828 L
.67071 .30257 L
.67074 .30257 L
.67076 .30687 L
.67078 .30687 L
.6708 .30687 L
.67082 .30257 L
.67085 .30257 L
.67087 .30257 L
.67089 .30257 L
.67091 .30687 L
.67094 .31117 L
.67096 .30687 L
.67098 .30257 L
.671 .29828 L
.67103 .29828 L
.67105 .30257 L
.67107 .30687 L
.67109 .30257 L
.67112 .29828 L
.67114 .28968 L
.67116 .28968 L
.67118 .29828 L
.6712 .29828 L
.67123 .29828 L
.67125 .29398 L
.67127 .28968 L
.67129 .28968 L
.67132 .28968 L
Mistroke
.67134 .29828 L
.67136 .29828 L
.67138 .29398 L
.67141 .28539 L
.67143 .28539 L
.67145 .29398 L
.67147 .29828 L
.67149 .29828 L
.67152 .28968 L
.67154 .28539 L
.67156 .28539 L
.67158 .29398 L
.67161 .29828 L
.67163 .29398 L
.67165 .28539 L
.67167 .28109 L
.6717 .28109 L
.67172 .28968 L
.67174 .29828 L
.67176 .29828 L
.67178 .28968 L
.67181 .28539 L
.67183 .28109 L
.67185 .28968 L
.67187 .29828 L
.6719 .30687 L
.67192 .30257 L
.67194 .29398 L
.67196 .28968 L
.67199 .29398 L
.67201 .30257 L
.67203 .31117 L
.67205 .31117 L
.67208 .30687 L
.6721 .29828 L
.67212 .29398 L
.67214 .29828 L
.67216 .30687 L
.67219 .31117 L
.67221 .31117 L
.67223 .30257 L
.67225 .29828 L
.67228 .29828 L
.6723 .30257 L
.67232 .30687 L
.67234 .30687 L
.67237 .30257 L
.67239 .29398 L
.67241 .28968 L
.67243 .29398 L
Mistroke
.67245 .29828 L
.67248 .30257 L
.6725 .29828 L
.67252 .28968 L
.67254 .28539 L
.67257 .28968 L
.67259 .29828 L
.67261 .30257 L
.67263 .29828 L
.67266 .28968 L
.67268 .28539 L
.6727 .28968 L
.67272 .29828 L
.67275 .29828 L
.67277 .29398 L
.67279 .28539 L
.67281 .28109 L
.67283 .28539 L
.67286 .29398 L
.67288 .29828 L
.6729 .29398 L
.67292 .28539 L
.67295 .27679 L
.67297 .28109 L
.67299 .29398 L
.67301 .29828 L
.67304 .29828 L
.67306 .28539 L
.67308 .27679 L
.6731 .28109 L
.67312 .29398 L
.67315 .29398 L
.67317 .30257 L
.67319 .30257 L
.67321 .29398 L
.67324 .28539 L
.67326 .28109 L
.67328 .28968 L
.6733 .30257 L
.67333 .31117 L
.67335 .30687 L
.67337 .29828 L
.67339 .28968 L
.67341 .29398 L
.67344 .30257 L
.67346 .31117 L
.67348 .31117 L
.6735 .30257 L
.67353 .29828 L
.67355 .29398 L
Mistroke
.67357 .29828 L
.67359 .30687 L
.67362 .31117 L
.67364 .30687 L
.67366 .29828 L
.67368 .28968 L
.67371 .28968 L
.67373 .29828 L
.67375 .30257 L
.67377 .30257 L
.67379 .29398 L
.67382 .28539 L
.67384 .28539 L
.67386 .29398 L
.67388 .30257 L
.67391 .29828 L
.67393 .28968 L
.67395 .28539 L
.67397 .28539 L
.674 .29398 L
.67402 .30257 L
.67404 .29828 L
.67406 .28968 L
.67408 .28109 L
.67411 .28109 L
.67413 .29398 L
.67415 .29828 L
.67417 .29398 L
.6742 .28539 L
.67422 .27679 L
.67424 .28109 L
.67426 .29398 L
.67429 .30257 L
.67431 .29828 L
.67433 .28539 L
.67435 .27679 L
.67438 .28109 L
.6744 .29398 L
.67442 .30257 L
.67444 .30257 L
.67446 .28968 L
.67449 .28109 L
.67451 .28109 L
.67453 .28968 L
.67455 .30257 L
.67458 .30687 L
.6746 .30257 L
.67462 .28968 L
.67464 .28539 L
.67467 .28968 L
Mistroke
.67469 .30257 L
.67471 .31117 L
.67473 .31117 L
.67475 .30257 L
.67478 .29398 L
.6748 .28968 L
.67482 .29828 L
.67484 .31117 L
.67487 .31546 L
.67489 .30687 L
.67491 .29398 L
.67493 .28539 L
.67496 .28968 L
.67498 .30257 L
.675 .30687 L
.67502 .30687 L
.67504 .29398 L
.67507 .28109 L
.67509 .28539 L
.67511 .29828 L
.67513 .30687 L
.67516 .30687 L
.67518 .29398 L
.6752 .28109 L
.67522 .28109 L
.67525 .29398 L
.67527 .30687 L
.67529 .30257 L
.67531 .28968 L
.67534 .28109 L
.67536 .28109 L
.67538 .29398 L
.6754 .30257 L
.67542 .30257 L
.67545 .28968 L
.67547 .28109 L
.67549 .28109 L
.67551 .28109 L
.67554 .28968 L
.67556 .30257 L
.67558 .30257 L
.6756 .29398 L
.67563 .28539 L
.67565 .28109 L
.67567 .28968 L
.67569 .30257 L
.67571 .30687 L
.67574 .29828 L
.67576 .28539 L
.67578 .28109 L
Mistroke
.6758 .28539 L
.67583 .30257 L
.67585 .30687 L
.67587 .30687 L
.67589 .30257 L
.67592 .28968 L
.67594 .28968 L
.67596 .30257 L
.67598 .31117 L
.67601 .31546 L
.67603 .31117 L
.67605 .30257 L
.67607 .29828 L
.67609 .29828 L
.67612 .30687 L
.67614 .31546 L
.67616 .31546 L
.67618 .30687 L
.67621 .29828 L
.67623 .29398 L
.67625 .29828 L
.67627 .30687 L
.6763 .31117 L
.67632 .30687 L
.67634 .29828 L
.67636 .29398 L
.67638 .29398 L
.67641 .30257 L
.67643 .30687 L
.67645 .30257 L
.67647 .29398 L
.6765 .28968 L
.67652 .29398 L
.67654 .29828 L
.67656 .30257 L
.67659 .29828 L
.67661 .29398 L
.67663 .28539 L
.67665 .28968 L
.67667 .29398 L
.6767 .29828 L
.67672 .29828 L
.67674 .28968 L
.67676 .28539 L
.67679 .28539 L
.67681 .29398 L
.67683 .29828 L
.67685 .29398 L
.67688 .28968 L
.6769 .28539 L
Mistroke
.67692 .28539 L
.67694 .29398 L
.67697 .29398 L
.67699 .29828 L
.67701 .29398 L
.67703 .28968 L
.67705 .28539 L
.67708 .29398 L
.6771 .29828 L
.67712 .30257 L
.67714 .29828 L
.67717 .29828 L
.67719 .29398 L
.67721 .29398 L
.67723 .29828 L
.67726 .30257 L
.67728 .30257 L
.6773 .30257 L
.67732 .30257 L
.67734 .29828 L
.67737 .29828 L
.67739 .29828 L
.67741 .30257 L
.67743 .30257 L
.67746 .30257 L
.67748 .29828 L
.6775 .29398 L
.67752 .29398 L
.67755 .29828 L
.67757 .30257 L
.67759 .29828 L
.67761 .29828 L
.67764 .29398 L
.67766 .29398 L
.67768 .29398 L
.6777 .29828 L
.67772 .29828 L
.67775 .29398 L
.67777 .28968 L
.67779 .28968 L
.67781 .28968 L
.67784 .29398 L
.67786 .29398 L
.67788 .29398 L
.6779 .29398 L
.67793 .28539 L
.67795 .28539 L
.67797 .28539 L
.67799 .28968 L
.67801 .29398 L
Mistroke
.67804 .29398 L
.67806 .28968 L
.67808 .28109 L
.6781 .28109 L
.67813 .28539 L
.67815 .29398 L
.67817 .29398 L
.67819 .28968 L
.67822 .28539 L
.67824 .28109 L
.67826 .28539 L
.67828 .29398 L
.6783 .29828 L
.67833 .29828 L
.67835 .29398 L
.67837 .28968 L
.67839 .28968 L
.67842 .29398 L
.67844 .30257 L
.67846 .30687 L
.67848 .30257 L
.67851 .29828 L
.67853 .29398 L
.67855 .29398 L
.67857 .29828 L
.6786 .30257 L
.67862 .30687 L
.67864 .30257 L
.67866 .29828 L
.67868 .29398 L
.67871 .29828 L
.67873 .30257 L
.67875 .30257 L
.67877 .30257 L
.6788 .29828 L
.67882 .29398 L
.67884 .29398 L
.67886 .29828 L
.67889 .30257 L
.67891 .30257 L
.67893 .29828 L
.67895 .29398 L
.67897 .29398 L
.679 .29398 L
.67902 .29828 L
.67904 .29828 L
.67906 .29398 L
.67909 .28968 L
.67911 .28968 L
.67913 .28968 L
Mistroke
.67915 .29398 L
.67918 .29398 L
.6792 .29398 L
.67922 .28968 L
.67924 .28539 L
.67927 .28539 L
.67929 .28968 L
.67931 .29398 L
.67933 .28968 L
.67935 .28539 L
.67938 .28109 L
.6794 .28539 L
.67942 .28968 L
.67944 .28968 L
.67947 .29398 L
.67949 .28968 L
.67951 .28539 L
.67953 .28968 L
.67956 .28968 L
.67958 .29828 L
.6796 .29828 L
.67962 .29828 L
.67964 .29398 L
.67967 .29398 L
.67969 .29828 L
.67971 .30257 L
.67973 .29828 L
.67976 .29828 L
.67978 .29828 L
.6798 .29828 L
.67982 .30257 L
.67985 .30257 L
.67987 .30257 L
.67989 .29828 L
.67991 .29828 L
.67993 .29828 L
.67996 .29828 L
.67998 .30257 L
.68 .30257 L
.68002 .29398 L
.68005 .29398 L
.68007 .29828 L
.68009 .29828 L
.68011 .30257 L
.68014 .30257 L
.68016 .29828 L
.68018 .29398 L
.6802 .29398 L
.68023 .29828 L
.68025 .29828 L
Mistroke
.68027 .30257 L
.68029 .30257 L
.68031 .29828 L
.68034 .29398 L
.68036 .28968 L
.68038 .28968 L
.6804 .29398 L
.68043 .29828 L
.68045 .29398 L
.68047 .28968 L
.68049 .28968 L
.68052 .28968 L
.68054 .28968 L
.68056 .28968 L
.68058 .29398 L
.6806 .28968 L
.68063 .28968 L
.68065 .28968 L
.68067 .28968 L
.68069 .28968 L
.68072 .28968 L
.68074 .28968 L
.68076 .29398 L
.68078 .29398 L
.68081 .29398 L
.68083 .29398 L
.68085 .29828 L
.68087 .29828 L
.68089 .29828 L
.68092 .29828 L
.68094 .29828 L
.68096 .30257 L
.68098 .30257 L
.68101 .30257 L
.68103 .30257 L
.68105 .29828 L
.68107 .29828 L
.6811 .29828 L
.68112 .30257 L
.68114 .30257 L
.68116 .30257 L
.68119 .29828 L
.68121 .29398 L
.68123 .29828 L
.68125 .30257 L
.68127 .30257 L
.6813 .30257 L
.68132 .29828 L
.68134 .29828 L
.68136 .29398 L
Mistroke
.68139 .29828 L
.68141 .30257 L
.68143 .30257 L
.68145 .29828 L
.68148 .29828 L
.6815 .29828 L
.68152 .29828 L
.68154 .29828 L
.68156 .29828 L
.68159 .29828 L
.68161 .29398 L
.68163 .29398 L
.68165 .29398 L
.68168 .29828 L
.6817 .29398 L
.68172 .29398 L
.68174 .28968 L
.68177 .28968 L
.68179 .28968 L
.68181 .29398 L
.68183 .29398 L
.68186 .29398 L
.68188 .28968 L
.6819 .28539 L
.68192 .28968 L
.68194 .29398 L
.68197 .29398 L
.68199 .29398 L
.68201 .29398 L
.68203 .29398 L
.68206 .29398 L
.68208 .29828 L
.6821 .30257 L
.68212 .30257 L
.68215 .29828 L
.68217 .29828 L
.68219 .29828 L
.68221 .29828 L
.68223 .30257 L
.68226 .30687 L
.68228 .30257 L
.6823 .29828 L
.68232 .29828 L
.68235 .29828 L
.68237 .29828 L
.68239 .30257 L
.68241 .30257 L
.68244 .29828 L
.68246 .29398 L
.68248 .29398 L
Mistroke
.6825 .29828 L
.68252 .30257 L
.68255 .29828 L
.68257 .29828 L
.68259 .29398 L
.68261 .29398 L
.68264 .29398 L
.68266 .29398 L
.68268 .29828 L
.6827 .30257 L
.68273 .29828 L
.68275 .29398 L
.68277 .29398 L
.68279 .29398 L
.68282 .29828 L
.68284 .29828 L
.68286 .29398 L
.68288 .28968 L
.6829 .28968 L
.68293 .28968 L
.68295 .29398 L
.68297 .29398 L
.68299 .29398 L
.68302 .28968 L
.68304 .28539 L
.68306 .28539 L
.68308 .28968 L
.68311 .28968 L
.68313 .28968 L
.68315 .28968 L
.68317 .28539 L
.68319 .28539 L
.68322 .28539 L
.68324 .28968 L
.68326 .29398 L
.68328 .29398 L
.68331 .28968 L
.68333 .28968 L
.68335 .28968 L
.68337 .29398 L
.6834 .29398 L
.68342 .29828 L
.68344 .29828 L
.68346 .29398 L
.68349 .29398 L
.68351 .29398 L
.68353 .29828 L
.68355 .29828 L
.68357 .29828 L
.6836 .29398 L
Mistroke
.68362 .29398 L
.68364 .29398 L
.68366 .29398 L
.68369 .29398 L
.68371 .29398 L
.68373 .29398 L
.68375 .29398 L
.68378 .29398 L
.6838 .29398 L
.68382 .29398 L
.68384 .29398 L
.68386 .29828 L
.68389 .29398 L
.68391 .29398 L
.68393 .29398 L
.68395 .29398 L
.68398 .29398 L
.684 .29398 L
.68402 .29398 L
.68404 .29398 L
.68407 .29398 L
.68409 .29398 L
.68411 .29398 L
.68413 .29398 L
.68415 .29398 L
.68418 .29398 L
.6842 .29398 L
.68422 .29398 L
.68424 .29398 L
.68427 .29398 L
.68429 .29398 L
.68431 .28968 L
.68433 .28968 L
.68436 .29398 L
.68438 .29398 L
.6844 .28968 L
.68442 .28968 L
.68445 .28968 L
.68447 .28968 L
.68449 .29398 L
.68451 .29398 L
.68453 .29398 L
.68456 .29398 L
.68458 .29398 L
.6846 .29398 L
.68462 .29828 L
.68465 .29828 L
.68467 .30257 L
.68469 .29828 L
.68471 .29398 L
Mistroke
.68474 .29828 L
.68476 .29828 L
.68478 .30257 L
.6848 .30257 L
.68482 .30257 L
.68485 .29828 L
.68487 .29828 L
.68489 .29828 L
.68491 .29828 L
.68494 .30257 L
.68496 .30257 L
.68498 .30257 L
.685 .29828 L
.68503 .29828 L
.68505 .29398 L
.68507 .29828 L
.68509 .29828 L
.68512 .30257 L
.68514 .29828 L
.68516 .29398 L
.68518 .29398 L
.6852 .29828 L
.68523 .30257 L
.68525 .30257 L
.68527 .29828 L
.68529 .29828 L
.68532 .29828 L
.68534 .29828 L
.68536 .30257 L
.68538 .30257 L
.68541 .29828 L
.68543 .29828 L
.68545 .29398 L
.68547 .29398 L
.68549 .29828 L
.68552 .29828 L
.68554 .29828 L
.68556 .29398 L
.68558 .28968 L
.68561 .28968 L
.68563 .29398 L
.68565 .29828 L
.68567 .29828 L
.6857 .29398 L
.68572 .28968 L
.68574 .28968 L
.68576 .28968 L
.68578 .29828 L
.68581 .29828 L
.68583 .29828 L
Mistroke
.68585 .29398 L
.68587 .28968 L
.6859 .28968 L
.68592 .29398 L
.68594 .30257 L
.68596 .30257 L
.68599 .29828 L
.68601 .29398 L
.68603 .29398 L
.68605 .29828 L
.68608 .30257 L
.6861 .30257 L
.68612 .30257 L
.68614 .29828 L
.68616 .29398 L
.68619 .29398 L
.68621 .29828 L
.68623 .30257 L
.68625 .30257 L
.68628 .29828 L
.6863 .29398 L
.68632 .29398 L
.68634 .29398 L
.68637 .29828 L
.68639 .30257 L
.68641 .29828 L
.68643 .29398 L
.68645 .29398 L
.68648 .29828 L
.6865 .30257 L
.68652 .30257 L
.68654 .30257 L
.68657 .29828 L
.68659 .29398 L
.68661 .29398 L
.68663 .29398 L
.68666 .29828 L
.68668 .30257 L
.6867 .29398 L
.68672 .29398 L
.68675 .29398 L
.68677 .29398 L
.68679 .29828 L
.68681 .29828 L
.68683 .29828 L
.68686 .29398 L
.68688 .28968 L
.6869 .28968 L
.68692 .29398 L
.68695 .29398 L
Mistroke
.68697 .29398 L
.68699 .29398 L
.68701 .28968 L
.68704 .28968 L
.68706 .28968 L
.68708 .29398 L
.6871 .29828 L
.68712 .29398 L
.68715 .29398 L
.68717 .28968 L
.68719 .29398 L
.68721 .29398 L
.68724 .29398 L
.68726 .29828 L
.68728 .29398 L
.6873 .29398 L
.68733 .29398 L
.68735 .29398 L
.68737 .29398 L
.68739 .29828 L
.68741 .29828 L
.68744 .29828 L
.68746 .29398 L
.68748 .29398 L
.6875 .29398 L
.68753 .29398 L
.68755 .29828 L
.68757 .29398 L
.68759 .29398 L
.68762 .29398 L
.68764 .29398 L
.68766 .29398 L
.68768 .29398 L
.68771 .29398 L
.68773 .29398 L
.68775 .29398 L
.68777 .29398 L
.68779 .29398 L
.68782 .29398 L
.68784 .29398 L
.68786 .29398 L
.68788 .29398 L
.68791 .29398 L
.68793 .29398 L
.68795 .29828 L
.68797 .29398 L
.688 .29398 L
.68802 .29398 L
.68804 .29398 L
.68806 .29398 L
Mistroke
.68808 .29398 L
.68811 .29398 L
.68813 .29398 L
.68815 .29398 L
.68817 .29398 L
.6882 .29398 L
.68822 .29398 L
.68824 .28968 L
.68826 .28968 L
.68829 .28968 L
.68831 .29398 L
.68833 .28968 L
.68835 .28968 L
.68838 .28968 L
.6884 .28968 L
.68842 .29398 L
.68844 .29398 L
.68846 .29398 L
.68849 .29828 L
.68851 .29398 L
.68853 .29828 L
.68855 .29828 L
.68858 .29828 L
.6886 .29828 L
.68862 .29828 L
.68864 .29828 L
.68867 .29828 L
.68869 .29828 L
.68871 .29828 L
.68873 .29828 L
.68875 .29828 L
.68878 .29828 L
.6888 .29828 L
.68882 .29398 L
.68884 .29398 L
.68887 .28968 L
.68889 .29398 L
.68891 .29398 L
.68893 .29398 L
.68896 .29398 L
.68898 .28968 L
.689 .29398 L
.68902 .29398 L
.68904 .29828 L
.68907 .29828 L
.68909 .29828 L
.68911 .29828 L
.68913 .29398 L
.68916 .29828 L
.68918 .30257 L
Mistroke
.6892 .30257 L
.68922 .29828 L
.68925 .29828 L
.68927 .29828 L
.68929 .29828 L
.68931 .29828 L
.68934 .30257 L
.68936 .29828 L
.68938 .29398 L
.6894 .28968 L
.68942 .28968 L
.68945 .29398 L
.68947 .29398 L
.68949 .29398 L
.68951 .28968 L
.68954 .28539 L
.68956 .28968 L
.68958 .28968 L
.6896 .29828 L
.68963 .29398 L
.68965 .29398 L
.68967 .29398 L
.68969 .29398 L
.68971 .29398 L
.68974 .29828 L
.68976 .30257 L
.68978 .30687 L
.6898 .30687 L
.68983 .30257 L
.68985 .30257 L
.68987 .30257 L
.68989 .30257 L
.68992 .30257 L
.68994 .29828 L
.68996 .29828 L
.68998 .29828 L
.69001 .29398 L
.69003 .29398 L
.69005 .28968 L
.69007 .29398 L
.69009 .28968 L
.69012 .28968 L
.69014 .28968 L
.69016 .28968 L
.69018 .28968 L
.69021 .29398 L
.69023 .28968 L
.69025 .29398 L
.69027 .29828 L
.6903 .29828 L
Mistroke
.69032 .29828 L
.69034 .30257 L
.69036 .30257 L
.69038 .29828 L
.69041 .29828 L
.69043 .29828 L
.69045 .30257 L
.69047 .30257 L
.6905 .30257 L
.69052 .29828 L
.69054 .29398 L
.69056 .28968 L
.69059 .29398 L
.69061 .29398 L
.69063 .29398 L
.69065 .28539 L
.69067 .28109 L
.6907 .28109 L
.69072 .28539 L
.69074 .28968 L
.69076 .29398 L
.69079 .28968 L
.69081 .28539 L
.69083 .29398 L
.69085 .29828 L
.69088 .29828 L
.6909 .30257 L
.69092 .30687 L
.69094 .30257 L
.69097 .30257 L
.69099 .30257 L
.69101 .31117 L
.69103 .30687 L
.69105 .30257 L
.69108 .30687 L
.6911 .30257 L
.69112 .29398 L
.69114 .29828 L
.69117 .29398 L
.69119 .28968 L
.69121 .28539 L
.69123 .28968 L
.69126 .28539 L
.69128 .28539 L
.6913 .28109 L
.69132 .28968 L
.69134 .28968 L
.69137 .28109 L
.69139 .29398 L
.69141 .30257 L
Mistroke
.69143 .29398 L
.69146 .29398 L
.69148 .29828 L
.6915 .30257 L
.69152 .29828 L
.69155 .30257 L
.69157 .31117 L
.69159 .30257 L
.69161 .29398 L
.69164 .30257 L
.69166 .30257 L
.69168 .29398 L
.6917 .29398 L
.69172 .29398 L
.69175 .28109 L
.69177 .27679 L
.69179 .28539 L
.69181 .28539 L
.69184 .28539 L
.69186 .27679 L
.69188 .28539 L
.6919 .28539 L
.69193 .27679 L
.69195 .29398 L
.69197 .30257 L
.69199 .29398 L
.69201 .29398 L
.69204 .30257 L
.69206 .30257 L
.69208 .30687 L
.6921 .29828 L
.69213 .30687 L
.69215 .31546 L
.69217 .30687 L
.69219 .30257 L
.69222 .31117 L
.69224 .30257 L
.69226 .29398 L
.69228 .29828 L
.6923 .30257 L
.69233 .28968 L
.69235 .28109 L
.69237 .28968 L
.69239 .28968 L
.69242 .28109 L
.69244 .28539 L
.69246 .29828 L
.69248 .28539 L
.69251 .28109 L
.69253 .29398 L
Mistroke
.69255 .30257 L
.69257 .29828 L
.6926 .30257 L
.69262 .30687 L
.69264 .30687 L
.69266 .30257 L
.69268 .31117 L
.69271 .31546 L
.69273 .30687 L
.69275 .30687 L
.69277 .30257 L
.6928 .29398 L
.69282 .28968 L
.69284 .29828 L
.69286 .28968 L
.69289 .28109 L
.69291 .28109 L
.69293 .28539 L
.69295 .2725 L
.69297 .27679 L
.693 .29828 L
.69302 .28539 L
.69304 .28109 L
.69306 .29398 L
.69309 .29398 L
.69311 .29828 L
.69313 .30687 L
.69315 .30687 L
.69318 .30687 L
.6932 .30687 L
.69322 .30687 L
.69324 .30687 L
.69327 .31976 L
.69329 .31117 L
.69331 .30257 L
.69333 .29828 L
.69335 .29398 L
.69338 .29398 L
.6934 .28968 L
.69342 .28968 L
.69344 .29398 L
.69347 .29398 L
.69349 .2725 L
.69351 .28539 L
.69353 .30257 L
.69356 .28539 L
.69358 .28968 L
.6936 .30687 L
.69362 .29828 L
.69364 .29828 L
Mistroke
.69367 .31117 L
.69369 .31117 L
.69371 .31546 L
.69373 .31546 L
.69376 .30687 L
.69378 .31546 L
.6938 .31117 L
.69382 .29828 L
.69385 .30257 L
.69387 .29828 L
.69389 .28539 L
.69391 .28539 L
.69393 .27679 L
.69396 .27679 L
.69398 .29398 L
.694 .2682 L
.69402 .2725 L
.69405 .29398 L
.69407 .27679 L
.69409 .27679 L
.69411 .29828 L
.69414 .29398 L
.69416 .28968 L
.69418 .30687 L
.6942 .30257 L
.69423 .31546 L
.69425 .31546 L
.69427 .30257 L
.69429 .31546 L
.69431 .30687 L
.69434 .29398 L
.69436 .29828 L
.69438 .29828 L
.6944 .27679 L
.69443 .27679 L
.69445 .28109 L
.69447 .2725 L
.69449 .28109 L
.69452 .28539 L
.69454 .25961 L
.69456 .29828 L
.69458 .28968 L
.6946 .2682 L
.69463 .29398 L
.69465 .31546 L
.69467 .29828 L
.69469 .30257 L
.69472 .32835 L
.69474 .31546 L
.69476 .31117 L
Mistroke
.69478 .31976 L
.69481 .32835 L
.69483 .31546 L
.69485 .30687 L
.69487 .30687 L
.6949 .29398 L
.69492 .28109 L
.69494 .28539 L
.69496 .28539 L
.69498 .28968 L
.69501 .2725 L
.69503 .25961 L
.69505 .28968 L
.69507 .27679 L
.6951 .2725 L
.69512 .30257 L
.69514 .30257 L
.69516 .28539 L
.69519 .29828 L
.69521 .31117 L
.69523 .30687 L
.69525 .31117 L
.69527 .31546 L
.6953 .31546 L
.69532 .30257 L
.69534 .29398 L
.69536 .28968 L
.69539 .28968 L
.69541 .28109 L
.69543 .27679 L
.69545 .27679 L
.69548 .28968 L
.6955 .25102 L
.69552 .2682 L
.69554 .30257 L
.69556 .2682 L
.69559 .2682 L
.69561 .30257 L
.69563 .29828 L
.69565 .28539 L
.69568 .31117 L
.6957 .31546 L
.69572 .31546 L
.69574 .31117 L
.69577 .31117 L
.69579 .31976 L
.69581 .31117 L
.69583 .29828 L
.69586 .29828 L
.69588 .29398 L
Mistroke
.6959 .28109 L
.69592 .28109 L
.69594 .30687 L
.69597 .28539 L
.69599 .25961 L
.69601 .31117 L
.69603 .29398 L
.69606 .2682 L
.69608 .30687 L
.6961 .32405 L
.69612 .29398 L
.69615 .31117 L
.69617 .31546 L
.69619 .31976 L
.69621 .31976 L
.69623 .30687 L
.69626 .31546 L
.69628 .31976 L
.6963 .28968 L
.69632 .27679 L
.69635 .29828 L
.69637 .27679 L
.69639 .25961 L
.69641 .29828 L
.69644 .28109 L
.69646 .24242 L
.69648 .29398 L
.6965 .29398 L
.69653 .2725 L
.69655 .29398 L
.69657 .31546 L
.69659 .29398 L
.69661 .31546 L
.69664 .31117 L
.69666 .31546 L
.69668 .33265 L
.6967 .30257 L
.69673 .29398 L
.69675 .31546 L
.69677 .29398 L
.69679 .29398 L
.69682 .25961 L
.69684 .28539 L
.69686 .28109 L
.69688 .24672 L
.6969 .28968 L
.69693 .26391 L
.69695 .24672 L
.69697 .30687 L
.69699 .28968 L
Mistroke
.69702 .27679 L
.69704 .31546 L
.69706 .32835 L
.69708 .30687 L
.69711 .34124 L
.69713 .32405 L
.69715 .33265 L
.69717 .34124 L
.69719 .31546 L
.69722 .31546 L
.69724 .32405 L
.69726 .28968 L
.69728 .2725 L
.69731 .29398 L
.69733 .25961 L
.69735 .2725 L
.69737 .30257 L
.6974 .23383 L
.69742 .28109 L
.69744 .30687 L
.69746 .26391 L
.69749 .28539 L
.69751 .34124 L
.69753 .31117 L
.69755 .31546 L
.69757 .33694 L
.6976 .31976 L
.69762 .33694 L
.69764 .31546 L
.69766 .31117 L
.69769 .31117 L
.69771 .30257 L
.69773 .2682 L
.69775 .2725 L
.69778 .2682 L
.6978 .24242 L
.69782 .29828 L
.69784 .23813 L
.69786 .23383 L
.69789 .30687 L
.69791 .2682 L
.69793 .25531 L
.69795 .31546 L
.69798 .33265 L
.698 .30257 L
.69802 .31546 L
.69804 .32405 L
.69807 .33694 L
.69809 .30687 L
.69811 .30257 L
Mistroke
.69813 .31117 L
.69815 .29828 L
.69818 .27679 L
.6982 .2682 L
.69822 .27679 L
.69824 .25961 L
.69827 .29398 L
.69829 .24672 L
.69831 .24242 L
.69833 .32405 L
.69836 .28968 L
.69838 .25961 L
.6984 .32405 L
.69842 .34983 L
.69845 .31976 L
.69847 .31546 L
.69849 .34554 L
.69851 .34554 L
.69853 .32405 L
.69856 .29828 L
.69858 .30257 L
.6986 .31546 L
.69862 .2725 L
.69865 .25102 L
.69867 .2725 L
.69869 .27679 L
.69871 .28968 L
.69874 .22524 L
.69876 .26391 L
.69878 .32835 L
.6988 .27679 L
.69882 .25102 L
.69885 .33265 L
.69887 .35413 L
.69889 .30257 L
.69891 .29828 L
.69894 .34124 L
.69896 .33694 L
.69898 .28968 L
.699 .28539 L
.69903 .29398 L
.69905 .29828 L
.69907 .25102 L
.69909 .23383 L
.69912 .26391 L
.69914 .29398 L
.69916 .29398 L
.69918 .25531 L
.6992 .20805 L
.69923 .30687 L
Mistroke
.69925 .32835 L
.69927 .25102 L
.69929 .2725 L
.69932 .35843 L
.69934 .35413 L
.69936 .28109 L
.69938 .29828 L
.69941 .35843 L
.69943 .32405 L
.69945 .25531 L
.69947 .28968 L
.69949 .31117 L
.69952 .28109 L
.69954 .23383 L
.69956 .25102 L
.69958 .28539 L
.69961 .30687 L
.69963 .22524 L
.69965 .26391 L
.69967 .35413 L
.6997 .31546 L
.69972 .2682 L
.69974 .32835 L
.69976 .3928 L
.69978 .33694 L
.69981 .28968 L
.69983 .32835 L
.69985 .36272 L
.69987 .30257 L
.6999 .24672 L
.69992 .29398 L
.69994 .31546 L
.69996 .24242 L
.69999 .21235 L
.70001 .28109 L
.70003 .32405 L
.70005 .23813 L
.70008 .22953 L
.7001 .33694 L
.70012 .33694 L
.70014 .28539 L
.70016 .29828 L
.70019 .37131 L
.70021 .36702 L
.70023 .29828 L
.70025 .28968 L
.70028 .34554 L
.7003 .31117 L
.70032 .24672 L
.70034 .25102 L
Mistroke
.70037 .29398 L
.70039 .26391 L
.70041 .19946 L
.70043 .24672 L
.70045 .31976 L
.70048 .25961 L
.7005 .22094 L
.70052 .31976 L
.70054 .34554 L
.70057 .30257 L
.70059 .30687 L
.70061 .35413 L
.70063 .36702 L
.70066 .32405 L
.70068 .27679 L
.7007 .32405 L
.70072 .32405 L
.70075 .25531 L
.70077 .22953 L
.70079 .28539 L
.70081 .27679 L
.70083 .20376 L
.70086 .2682 L
.70088 .32835 L
.7009 .25102 L
.70092 .28109 L
.70095 .34124 L
.70097 .34124 L
.70099 .32405 L
.70101 .36702 L
.70104 .36702 L
.70106 .35413 L
.70108 .32835 L
.7011 .29398 L
.70112 .31117 L
.70115 .28539 L
.70117 .26391 L
.70119 .24672 L
.70121 .2682 L
.70124 .22953 L
.70126 .22953 L
.70128 .31117 L
.7013 .2682 L
.70133 .26391 L
.70135 .34124 L
.70137 .35413 L
.70139 .31546 L
.70141 .33265 L
.70144 .39709 L
.70146 .34983 L
Mistroke
.70148 .31976 L
.7015 .30687 L
.70153 .30687 L
.70155 .30257 L
.70157 .2682 L
.70159 .25102 L
.70162 .23383 L
.70164 .24242 L
.70166 .24242 L
.70168 .20805 L
.70171 .28539 L
.70173 .26391 L
.70175 .25102 L
.70177 .31546 L
.70179 .36272 L
.70182 .34124 L
.70184 .31976 L
.70186 .39709 L
.70188 .37561 L
.70191 .31117 L
.70193 .29398 L
.70195 .30257 L
.70197 .28539 L
.702 .24242 L
.70202 .23813 L
.70204 .22953 L
.70206 .24672 L
.70208 .22524 L
.70211 .27679 L
.70213 .26391 L
.70215 .27679 L
.70217 .34124 L
.7022 .35843 L
.70222 .34983 L
.70224 .35413 L
.70226 .41857 L
.70229 .37131 L
.70231 .31976 L
.70233 .31976 L
.70235 .30257 L
.70238 .27679 L
.7024 .25961 L
.70242 .23383 L
.70244 .22524 L
.70246 .25102 L
.70249 .25961 L
.70251 .26391 L
.70253 .25531 L
.70255 .30257 L
.70258 .35843 L
Mistroke
.7026 .34554 L
.70262 .32835 L
.70264 .3885 L
.70267 .40139 L
.70269 .33265 L
.70271 .28109 L
.70273 .29398 L
.70275 .29398 L
.70278 .2682 L
.7028 .22094 L
.70282 .21235 L
.70284 .25961 L
.70287 .25102 L
.70289 .25102 L
.70291 .23813 L
.70293 .29828 L
.70296 .33265 L
.70298 .33265 L
.703 .33694 L
.70302 .37131 L
.70304 .37561 L
.70307 .29398 L
.70309 .30257 L
.70311 .28109 L
.70313 .2682 L
.70316 .27679 L
.70318 .25102 L
.7032 .20376 L
.70322 .24242 L
.70325 .29828 L
.70327 .25102 L
.70329 .24242 L
.70331 .32835 L
.70334 .37561 L
.70336 .32835 L
.70338 .28968 L
.7034 .36272 L
.70342 .35843 L
.70345 .2682 L
.70347 .25961 L
.70349 .32405 L
.70351 .30257 L
.70354 .25102 L
.70356 .25961 L
.70358 .27679 L
.7036 .30687 L
.70363 .30257 L
.70365 .29398 L
.70367 .30687 L
.70369 .36702 L
Mistroke
.70371 .34124 L
.70374 .2682 L
.70376 .31546 L
.70378 .32405 L
.7038 .25102 L
.70383 .25531 L
.70385 .29828 L
.70387 .26391 L
.70389 .26391 L
.70392 .25531 L
.70394 .28539 L
.70396 .29398 L
.70398 .30687 L
.70401 .30687 L
.70403 .34124 L
.70405 .34983 L
.70407 .34124 L
.70409 .28968 L
.70412 .30257 L
.70414 .31546 L
.70416 .24242 L
.70418 .21235 L
.70421 .24672 L
.70423 .25961 L
.70425 .22524 L
.70427 .23383 L
.7043 .2725 L
.70432 .32835 L
.70434 .31976 L
.70436 .29828 L
.70438 .34983 L
.70441 .41428 L
.70443 .34124 L
.70445 .28539 L
.70447 .33265 L
.7045 .2682 L
.70452 .20805 L
.70454 .22524 L
.70456 .23383 L
.70459 .21664 L
.70461 .25102 L
.70463 .24672 L
.70465 .2682 L
.70467 .33265 L
.7047 .34554 L
.70472 .35843 L
.70474 .40998 L
.70476 .40139 L
.70479 .31546 L
.70481 .34983 L
Mistroke
.70483 .31546 L
.70485 .22953 L
.70488 .23813 L
.7049 .25102 L
.70492 .21235 L
.70494 .22094 L
.70497 .24242 L
.70499 .28109 L
.70501 .29828 L
.70503 .31976 L
.70505 .37991 L
.70508 .40998 L
.7051 .3842 L
.70512 .34554 L
.70514 .34983 L
.70517 .29828 L
.70519 .25102 L
.70521 .25102 L
.70523 .24242 L
.70526 .21235 L
.70528 .20805 L
.7053 .22953 L
.70532 .26391 L
.70534 .28539 L
.70537 .30257 L
.70539 .36272 L
.70541 .40139 L
.70543 .37561 L
.70546 .34983 L
.70548 .34554 L
.7055 .28539 L
.70552 .25531 L
.70555 .2682 L
.70557 .24672 L
.70559 .21235 L
.70561 .21235 L
.70564 .22094 L
.70566 .25531 L
.70568 .29828 L
.7057 .31117 L
.70572 .33265 L
.70575 .40139 L
.70577 .37131 L
.70579 .31546 L
.70581 .33694 L
.70584 .28968 L
.70586 .24672 L
.70588 .27679 L
.7059 .26391 L
.70593 .21664 L
Mistroke
.70595 .23813 L
.70597 .2725 L
.70599 .29398 L
.70601 .30687 L
.70604 .32835 L
.70606 .3842 L
.70608 .39709 L
.7061 .36702 L
.70613 .34124 L
.70615 .31117 L
.70617 .2682 L
.70619 .25961 L
.70622 .26391 L
.70624 .23813 L
.70626 .23813 L
.70628 .22524 L
.7063 .23383 L
.70633 .26391 L
.70635 .30257 L
.70637 .32835 L
.70639 .33265 L
.70642 .3885 L
.70644 .41857 L
.70646 .36702 L
.70648 .33265 L
.70651 .30257 L
.70653 .25531 L
.70655 .25531 L
.70657 .25961 L
.7066 .22094 L
.70662 .20805 L
.70664 .22524 L
.70666 .25102 L
.70668 .29828 L
.70671 .31546 L
.70673 .33694 L
.70675 .40139 L
.70677 .40139 L
.7068 .35413 L
.70682 .31976 L
.70684 .27679 L
.70686 .25531 L
.70689 .28109 L
.70691 .25961 L
.70693 .19946 L
.70695 .21235 L
.70697 .24672 L
.707 .26391 L
.70702 .29398 L
.70704 .31117 L
Mistroke
.70706 .35843 L
.70709 .3885 L
.70711 .37131 L
.70713 .34124 L
.70715 .30257 L
.70718 .26391 L
.7072 .28109 L
.70722 .30257 L
.70724 .25961 L
.70727 .23383 L
.70729 .25102 L
.70731 .2725 L
.70733 .29828 L
.70735 .33265 L
.70738 .32835 L
.7074 .36702 L
.70742 .37991 L
.70744 .34983 L
.70747 .31546 L
.70749 .25102 L
.70751 .23383 L
.70753 .28968 L
.70756 .30257 L
.70758 .24242 L
.7076 .23383 L
.70762 .2682 L
.70764 .29398 L
.70767 .31546 L
.70769 .33265 L
.70771 .35843 L
.70773 .3842 L
.70776 .35413 L
.70778 .32405 L
.7078 .2682 L
.70782 .22094 L
.70785 .24672 L
.70787 .29828 L
.70789 .2682 L
.70791 .22524 L
.70793 .23383 L
.70796 .26391 L
.70798 .31976 L
.708 .34983 L
.70802 .33694 L
.70805 .35843 L
.70807 .35413 L
.70809 .32835 L
.70811 .29828 L
.70814 .22953 L
.70816 .21235 L
Mistroke
.70818 .2725 L
.7082 .28109 L
.70823 .24672 L
.70825 .23813 L
.70827 .26391 L
.70829 .30257 L
.70831 .33694 L
.70834 .34554 L
.70836 .36272 L
.70838 .35843 L
.7084 .34124 L
.70843 .31546 L
.70845 .24672 L
.70847 .20376 L
.70849 .26391 L
.70852 .30687 L
.70854 .27679 L
.70856 .25961 L
.70858 .2682 L
.7086 .2682 L
.70863 .28968 L
.70865 .33694 L
.70867 .36272 L
.70869 .35843 L
.70872 .37131 L
.70874 .34124 L
.70876 .30687 L
.70878 .25961 L
.70881 .21235 L
.70883 .21664 L
.70885 .28968 L
.70887 .29828 L
.7089 .2725 L
.70892 .25961 L
.70894 .2725 L
.70896 .31976 L
.70898 .36272 L
.70901 .3842 L
.70903 .37561 L
.70905 .31976 L
.70907 .29398 L
.7091 .25102 L
.70912 .20376 L
.70914 .21235 L
.70916 .2725 L
.70919 .27679 L
.70921 .2682 L
.70923 .2725 L
.70925 .28968 L
.70927 .33265 L
Mistroke
.7093 .34983 L
.70932 .35843 L
.70934 .36272 L
.70936 .32835 L
.70939 .30687 L
.70941 .25531 L
.70943 .20376 L
.70945 .19087 L
.70948 .23813 L
.7095 .2725 L
.70952 .27679 L
.70954 .28109 L
.70956 .29828 L
.70959 .32405 L
.70961 .36702 L
.70963 .3885 L
.70965 .3885 L
.70968 .35843 L
.7097 .29828 L
.70972 .25102 L
.70974 .19946 L
.70977 .19087 L
.70979 .24242 L
.70981 .27679 L
.70983 .27679 L
.70986 .30257 L
.70988 .31546 L
.7099 .32835 L
.70992 .35843 L
.70994 .3842 L
.70997 .3885 L
.70999 .34554 L
.71001 .32405 L
.71003 .26391 L
.71006 .17368 L
.71008 .18227 L
.7101 .22953 L
.71012 .26391 L
.71015 .28109 L
.71017 .27679 L
.71019 .28539 L
.71021 .31976 L
.71023 .3842 L
.71026 .41428 L
.71028 .3928 L
.7103 .3842 L
.71032 .29398 L
.71035 .21235 L
.71037 .18657 L
.71039 .19087 L
Mistroke
.71041 .22094 L
.71044 .26391 L
.71046 .25531 L
.71048 .2682 L
.7105 .31546 L
.71053 .35413 L
.71055 .37991 L
.71057 .3842 L
.71059 .37991 L
.71061 .32405 L
.71064 .32405 L
.71066 .28109 L
.71068 .17368 L
.7107 .17798 L
.71073 .21664 L
.71075 .25102 L
.71077 .25961 L
.71079 .2725 L
.71082 .28109 L
.71084 .32835 L
.71086 .40139 L
.71088 .43146 L
.7109 .39709 L
.71093 .37991 L
.71095 .30257 L
.71097 .30257 L
.71099 .22524 L
.71102 .20376 L
.71104 .20805 L
.71106 .21235 L
.71108 .25531 L
.71111 .27679 L
.71113 .28539 L
.71115 .30687 L
.71117 .35413 L
.71119 .3885 L
.71122 .3885 L
.71124 .37991 L
.71126 .33265 L
.71128 .32835 L
.71131 .28109 L
.71133 .17368 L
.71135 .16509 L
.71137 .22094 L
.7114 .26391 L
.71142 .28109 L
.71144 .29398 L
.71146 .28539 L
.71149 .31117 L
.71151 .40139 L
Mistroke
.71153 .42717 L
.71155 .40569 L
.71157 .35843 L
.7116 .25961 L
.71162 .19946 L
.71164 .19087 L
.71166 .19516 L
.71169 .23383 L
.71171 .2725 L
.71173 .2682 L
.71175 .28968 L
.71178 .31976 L
.7118 .34983 L
.71182 .37561 L
.71184 .40569 L
.71186 .3842 L
.71189 .31546 L
.71191 .29398 L
.71193 .22524 L
.71195 .1565 L
.71198 .18657 L
.712 .25531 L
.71202 .27679 L
.71204 .28968 L
.71207 .30257 L
.71209 .28968 L
.71211 .34124 L
.71213 .43146 L
.71216 .44435 L
.71218 .40998 L
.7122 .32405 L
.71222 .21235 L
.71224 .17798 L
.71227 .19946 L
.71229 .22524 L
.71231 .26391 L
.71233 .26391 L
.71236 .25961 L
.71238 .31546 L
.7124 .35413 L
.71242 .37991 L
.71245 .40139 L
.71247 .40998 L
.71249 .34554 L
.71251 .29398 L
.71253 .28109 L
.71256 .18657 L
.71258 .16079 L
.7126 .21235 L
.71262 .25531 L
Mistroke
.71265 .26391 L
.71267 .28968 L
.71269 .31546 L
.71271 .31976 L
.71274 .3842 L
.71276 .43576 L
.71278 .41857 L
.7128 .36702 L
.71282 .26391 L
.71285 .19087 L
.71287 .17368 L
.71289 .20376 L
.71291 .23383 L
.71294 .25961 L
.71296 .25531 L
.71298 .28539 L
.713 .33694 L
.71303 .37561 L
.71305 .39709 L
.71307 .39709 L
.71309 .37991 L
.71312 .31546 L
.71314 .28968 L
.71316 .22953 L
.71318 .1565 L
.7132 .18227 L
.71323 .22524 L
.71325 .25961 L
.71327 .28109 L
.71329 .31976 L
.71332 .34124 L
.71334 .35843 L
.71336 .41857 L
.71338 .43576 L
.71341 .41428 L
.71343 .31976 L
.71345 .21235 L
.71347 .16938 L
.71349 .16938 L
.71352 .21235 L
.71354 .27679 L
.71356 .27679 L
.71358 .27679 L
.71361 .2682 L
.71363 .32405 L
.71365 .37561 L
.71367 .40139 L
.7137 .41428 L
.71372 .41428 L
.71374 .33694 L
Mistroke
.71376 .26391 L
.71378 .25531 L
.71381 .16938 L
.71383 .1479 L
.71385 .20805 L
.71387 .25531 L
.7139 .27679 L
.71392 .30687 L
.71394 .32835 L
.71396 .33265 L
.71399 .40139 L
.71401 .43576 L
.71403 .42287 L
.71405 .35843 L
.71408 .22953 L
.7141 .1479 L
.71412 .13501 L
.71414 .18657 L
.71416 .24672 L
.71419 .28968 L
.71421 .27679 L
.71423 .28968 L
.71425 .33694 L
.71428 .37991 L
.7143 .41857 L
.71432 .44006 L
.71434 .3885 L
.71437 .28968 L
.71439 .23383 L
.71441 .16509 L
.71443 .13072 L
.71445 .19087 L
.71448 .24672 L
.7145 .27679 L
.71452 .30257 L
.71454 .32835 L
.71457 .34124 L
.71459 .3885 L
.71461 .44865 L
.71463 .44865 L
.71466 .41428 L
.71468 .28968 L
.7147 .16079 L
.71472 .11783 L
.71475 .1479 L
.71477 .22524 L
.71479 .29398 L
.71481 .28968 L
.71483 .28539 L
.71486 .32835 L
Mistroke
.71488 .37561 L
.7149 .41857 L
.71492 .45724 L
.71495 .43146 L
.71497 .31546 L
.71499 .23813 L
.71501 .17798 L
.71504 .11353 L
.71506 .17368 L
.71508 .24672 L
.7151 .25531 L
.71512 .27679 L
.71515 .31117 L
.71517 .33694 L
.71519 .3885 L
.71521 .44006 L
.71524 .45295 L
.71526 .40569 L
.71528 .30257 L
.7153 .19516 L
.71533 .12212 L
.71535 .13501 L
.71537 .20376 L
.71539 .26391 L
.71541 .27679 L
.71544 .28109 L
.71546 .31117 L
.71548 .35843 L
.7155 .40998 L
.71553 .46154 L
.71555 .44435 L
.71557 .32835 L
.71559 .24242 L
.71562 .18227 L
.71564 .13072 L
.71566 .16509 L
.71568 .23383 L
.71571 .25102 L
.71573 .27679 L
.71575 .31117 L
.71577 .33265 L
.71579 .3885 L
.71582 .44435 L
.71584 .46154 L
.71586 .41857 L
.71588 .31546 L
.71591 .21235 L
.71593 .21235 L
.71595 .14361 L
.71597 .13931 L
Mistroke
.716 .19516 L
.71602 .26391 L
.71604 .28539 L
.71606 .28968 L
.71608 .32405 L
.71611 .35843 L
.71613 .40998 L
.71615 .46154 L
.71617 .46583 L
.7162 .36702 L
.71622 .26391 L
.71624 .19087 L
.71626 .12212 L
.71629 .1522 L
.71631 .22524 L
.71633 .25531 L
.71635 .26391 L
.71638 .29828 L
.7164 .32405 L
.71642 .36702 L
.71644 .43146 L
.71646 .46583 L
.71649 .43576 L
.71651 .33265 L
.71653 .22953 L
.71655 .13931 L
.71658 .11783 L
.7166 .17798 L
.71662 .24242 L
.71664 .26391 L
.71667 .2682 L
.71669 .30257 L
.71671 .33694 L
.71673 .3885 L
.71675 .46154 L
.71678 .46583 L
.7168 .37561 L
.71682 .2725 L
.71684 .19946 L
.71687 .12212 L
.71689 .14361 L
.71691 .22094 L
.71693 .25102 L
.71696 .26391 L
.71698 .28968 L
.717 .31117 L
.71702 .35413 L
.71704 .42717 L
.71707 .47013 L
.71709 .44865 L
Mistroke
.71711 .35843 L
.71713 .25531 L
.71716 .1565 L
.71718 .12642 L
.7172 .17798 L
.71722 .24672 L
.71725 .28109 L
.71727 .29398 L
.71729 .31117 L
.71731 .33694 L
.71734 .3885 L
.71736 .45295 L
.71738 .47872 L
.7174 .41428 L
.71742 .30687 L
.71745 .21664 L
.71747 .12642 L
.71749 .13072 L
.71751 .20805 L
.71754 .25531 L
.71756 .2725 L
.71758 .29398 L
.7176 .31117 L
.71763 .33694 L
.71765 .41428 L
.71767 .46583 L
.71769 .45295 L
.71771 .36272 L
.71774 .25961 L
.71776 .1565 L
.71778 .11353 L
.7178 .16509 L
.71783 .22953 L
.71785 .26391 L
.71787 .2725 L
.71789 .29398 L
.71792 .31976 L
.71794 .37131 L
.71796 .44006 L
.71798 .47013 L
.71801 .41428 L
.71803 .30687 L
.71805 .21664 L
.71807 .13072 L
.71809 .13072 L
.71812 .20805 L
.71814 .25102 L
.71816 .2725 L
.71818 .28968 L
.71821 .30687 L
Mistroke
.71823 .32835 L
.71825 .40569 L
.71827 .46154 L
.7183 .46154 L
.71832 .45724 L
.71834 .37561 L
.71836 .28109 L
.71838 .17798 L
.71841 .12212 L
.71843 .16509 L
.71845 .23383 L
.71847 .2725 L
.7185 .29398 L
.71852 .31117 L
.71854 .32835 L
.71856 .36272 L
.71859 .43146 L
.71861 .46583 L
.71863 .43146 L
.71865 .33694 L
.71867 .24672 L
.7187 .1479 L
.71872 .12212 L
.71874 .19087 L
.71876 .25531 L
.71879 .28539 L
.71881 .29828 L
.71883 .31117 L
.71885 .31976 L
.71888 .3885 L
.7189 .45295 L
.71892 .45295 L
.71894 .3885 L
.71897 .28109 L
.71899 .17798 L
.71901 .11353 L
.71903 .1479 L
.71905 .22524 L
.71908 .27679 L
.7191 .28968 L
.71912 .29398 L
.71914 .30687 L
.71917 .34124 L
.71919 .42287 L
.71921 .46154 L
.71923 .43576 L
.71926 .33265 L
.71928 .22953 L
.7193 .13931 L
.71932 .11783 L
Mistroke
.71934 .18657 L
.71937 .25961 L
.71939 .28539 L
.71941 .29398 L
.71943 .29828 L
.71946 .31117 L
.71948 .37561 L
.7195 .44865 L
.71952 .46583 L
.71955 .39709 L
.71957 .28539 L
.71959 .17798 L
.71961 .11783 L
.71964 .1479 L
.71966 .22524 L
.71968 .28539 L
.7197 .30257 L
.71972 .29828 L
.71975 .31117 L
.71977 .34124 L
.71979 .41428 L
.71981 .47013 L
.71984 .45724 L
.71986 .34554 L
.71988 .24242 L
.7199 .1522 L
.71993 .12212 L
.71995 .18657 L
.71997 .25961 L
.71999 .28968 L
.72001 .29828 L
.72004 .30257 L
.72006 .30687 L
.72008 .36272 L
.7201 .44435 L
.72013 .46583 L
.72015 .40998 L
.72017 .30687 L
.72019 .18657 L
.72022 .11353 L
.72024 .13501 L
.72026 .20805 L
.72028 .26391 L
.7203 .30257 L
.72033 .29398 L
.72035 .29828 L
.72037 .31976 L
.72039 .37991 L
.72042 .44006 L
.72044 .46154 L
Mistroke
.72046 .37991 L
.72048 .2682 L
.72051 .16509 L
.72053 .10494 L
.72055 .14361 L
.72057 .23383 L
.7206 .28968 L
.72062 .30687 L
.72064 .30687 L
.72066 .30687 L
.72068 .30257 L
.72071 .33265 L
.72073 .40569 L
.72075 .46154 L
.72077 .43576 L
.7208 .34124 L
.72082 .23383 L
.72084 .12642 L
.72086 .11783 L
.72089 .19087 L
.72091 .26391 L
.72093 .30687 L
.72095 .31976 L
.72097 .31117 L
.721 .30257 L
.72102 .35413 L
.72104 .42717 L
.72106 .47013 L
.72109 .41857 L
.72111 .30687 L
.72113 .18657 L
.72115 .11353 L
.72118 .13931 L
.7212 .22524 L
.72122 .30257 L
.72124 .32835 L
.72127 .31546 L
.72129 .29398 L
.72131 .30687 L
.72133 .3842 L
.72135 .45295 L
.72138 .45295 L
.7214 .37131 L
.72142 .26391 L
.72144 .13931 L
.72147 .10494 L
.72149 .16938 L
.72151 .24242 L
.72153 .30687 L
.72156 .31976 L
Mistroke
.72158 .29828 L
.7216 .28539 L
.72162 .31976 L
.72164 .40569 L
.72167 .45724 L
.72169 .45295 L
.72171 .34983 L
.72173 .19516 L
.72176 .11353 L
.72178 .10924 L
.7218 .18227 L
.72182 .28539 L
.72185 .33694 L
.72187 .31976 L
.72189 .29828 L
.72191 .28539 L
.72193 .34124 L
.72196 .42287 L
.72198 .47443 L
.722 .40998 L
.72202 .29828 L
.72205 .17798 L
.72207 .09635 L
.72209 .13072 L
.72211 .22953 L
.72214 .30257 L
.72216 .34124 L
.72218 .32835 L
.7222 .28968 L
.72223 .28968 L
.72225 .36272 L
.72227 .44435 L
.72229 .47872 L
.72231 .40998 L
.72234 .26391 L
.72236 .13072 L
.72238 .09635 L
.7224 .1565 L
.72243 .26391 L
.72245 .35413 L
.72247 .36272 L
.72249 .32405 L
.72252 .28109 L
.72254 .29398 L
.72256 .37991 L
.72258 .46583 L
.7226 .45724 L
.72263 .36702 L
.72265 .22953 L
.72267 .10494 L
Mistroke
.72269 .10064 L
.72272 .19087 L
.72274 .28109 L
.72276 .34983 L
.72278 .34983 L
.72281 .29398 L
.72283 .25961 L
.72285 .30687 L
.72287 .3928 L
.7229 .46154 L
.72292 .45724 L
.72294 .33265 L
.72296 .16938 L
.72298 .09205 L
.72301 .10494 L
.72303 .10494 L
.72305 .19946 L
.72307 .31976 L
.7231 .37131 L
.72312 .34124 L
.72314 .29828 L
.72316 .25961 L
.72319 .31117 L
.72321 .40998 L
.72323 .47013 L
.72325 .40998 L
.72327 .30687 L
.7233 .16509 L
.72332 .08346 L
.72334 .14361 L
.72336 .23813 L
.72339 .32405 L
.72341 .37991 L
.72343 .34554 L
.72345 .27679 L
.72348 .2682 L
.7235 .33694 L
.72352 .42287 L
.72354 .46583 L
.72356 .41857 L
.72359 .2725 L
.72361 .13501 L
.72363 .10064 L
.72365 .1522 L
.72368 .26391 L
.7237 .37131 L
.72372 .3885 L
.72374 .34124 L
.72377 .28109 L
.72379 .2682 L
Mistroke
.72381 .34554 L
.72383 .43146 L
.72386 .45724 L
.72388 .3842 L
.7239 .25531 L
.72392 .11783 L
.72394 .09205 L
.72397 .17368 L
.72399 .27679 L
.72401 .37561 L
.72403 .37991 L
.72406 .31546 L
.72408 .25961 L
.7241 .2725 L
.72412 .35413 L
.72415 .43576 L
.72417 .45724 L
.72419 .36702 L
.72421 .20805 L
.72423 .10494 L
.72426 .10064 L
.72428 .18227 L
.7243 .31117 L
.72432 .3885 L
.72435 .37131 L
.72437 .31546 L
.72439 .25531 L
.72441 .2725 L
.72444 .36272 L
.72446 .44006 L
.72448 .42717 L
.7245 .34554 L
.72453 .20805 L
.72455 .09635 L
.72457 .12212 L
.72459 .20376 L
.72461 .31117 L
.72464 .3885 L
.72466 .37131 L
.72468 .30687 L
.7247 .25961 L
.72473 .28109 L
.72475 .35843 L
.72477 .44006 L
.72479 .44865 L
.72482 .34124 L
.72484 .19516 L
.72486 .10924 L
.72488 .11783 L
.7249 .21235 L
Mistroke
.72493 .34124 L
.72495 .40139 L
.72497 .3885 L
.72499 .32835 L
.72502 .25961 L
.72504 .2682 L
.72506 .35843 L
.72508 .43576 L
.72511 .42717 L
.72513 .35413 L
.72515 .20805 L
.72517 .09635 L
.72519 .12642 L
.72522 .21235 L
.72524 .31976 L
.72526 .40139 L
.72528 .3885 L
.72531 .31117 L
.72533 .25531 L
.72535 .2682 L
.72537 .33694 L
.7254 .33694 L
.72542 .41857 L
.72544 .43146 L
.72546 .33265 L
.72549 .19946 L
.72551 .11353 L
.72553 .11353 L
.72555 .20805 L
.72557 .33265 L
.7256 .39709 L
.72562 .3842 L
.72564 .31546 L
.72566 .25531 L
.72569 .2682 L
.72571 .33694 L
.72573 .40569 L
.72575 .40998 L
.72578 .33694 L
.7258 .20376 L
.72582 .12642 L
.72584 .13931 L
.72586 .22094 L
.72589 .32405 L
.72591 .3842 L
.72593 .37131 L
.72595 .31976 L
.72598 .27679 L
.726 .27679 L
.72602 .33694 L
Mistroke
.72604 .40569 L
.72607 .41428 L
.72609 .33694 L
.72611 .22094 L
.72613 .13931 L
.72616 .13931 L
.72618 .22094 L
.7262 .32405 L
.72622 .3928 L
.72624 .3928 L
.72627 .34124 L
.72629 .27679 L
.72631 .2682 L
.72633 .32405 L
.72636 .3842 L
.72638 .40139 L
.7264 .35843 L
.72642 .24242 L
.72645 .1479 L
.72647 .14361 L
.72649 .19946 L
.72651 .28968 L
.72653 .37561 L
.72656 .39709 L
.72658 .34554 L
.7266 .28968 L
.72662 .25531 L
.72665 .28109 L
.72667 .35413 L
.72669 .40139 L
.72671 .36702 L
.72674 .2682 L
.72676 .16509 L
.72678 .12642 L
.7268 .17368 L
.72682 .27679 L
.72685 .36702 L
.72687 .40139 L
.72689 .37131 L
.72691 .29398 L
.72694 .25102 L
.72696 .2682 L
.72698 .32835 L
.727 .37991 L
.72703 .37561 L
.72705 .29828 L
.72707 .19087 L
.72709 .14361 L
.72712 .16938 L
.72714 .25102 L
Mistroke
.72716 .34983 L
.72718 .39709 L
.7272 .37561 L
.72723 .31546 L
.72725 .26391 L
.72727 .26391 L
.72729 .32405 L
.72732 .3885 L
.72734 .3885 L
.72736 .31546 L
.72738 .22094 L
.72741 .1522 L
.72743 .16938 L
.72745 .25961 L
.72747 .34554 L
.72749 .40139 L
.72752 .39709 L
.72754 .33265 L
.72756 .2725 L
.72758 .25961 L
.72761 .29828 L
.72763 .35413 L
.72765 .37991 L
.72767 .34983 L
.7277 .24672 L
.72772 .17368 L
.72774 .16938 L
.72776 .16938 L
.72779 .21235 L
.72781 .30257 L
.72783 .37991 L
.72785 .3885 L
.72787 .34983 L
.7279 .28109 L
.72792 .24672 L
.72794 .25961 L
.72796 .33265 L
.72799 .3885 L
.72801 .36272 L
.72803 .28968 L
.72805 .19516 L
.72808 .14361 L
.7281 .18657 L
.72812 .27679 L
.72814 .35843 L
.72816 .40139 L
.72819 .36702 L
.72821 .28539 L
.72823 .22953 L
.72825 .24672 L
Mistroke
.72828 .30687 L
.7283 .36702 L
.72832 .3842 L
.72834 .31976 L
.72837 .21235 L
.72839 .16509 L
.72841 .17798 L
.72843 .25102 L
.72845 .34983 L
.72848 .39709 L
.7285 .37561 L
.72852 .30687 L
.72854 .24242 L
.72857 .24672 L
.72859 .30687 L
.72861 .3928 L
.72863 .40998 L
.72866 .34554 L
.72868 .24672 L
.7287 .16938 L
.72872 .16509 L
.72875 .24242 L
.72877 .32835 L
.72879 .39709 L
.72881 .3885 L
.72883 .32405 L
.72886 .25531 L
.72888 .23383 L
.7289 .28539 L
.72892 .36272 L
.72895 .40139 L
.72897 .37561 L
.72899 .28109 L
.72901 .18227 L
.72904 .16509 L
.72906 .20805 L
.72908 .28968 L
.7291 .36702 L
.72912 .3842 L
.72915 .34124 L
.72917 .2725 L
.72919 .23383 L
.72921 .25531 L
.72924 .32835 L
.72926 .40139 L
.72928 .3885 L
.7293 .31976 L
.72933 .22524 L
.72935 .1565 L
.72937 .17368 L
Mistroke
.72939 .25102 L
.72942 .33694 L
.72944 .37991 L
.72946 .35843 L
.72948 .28539 L
.7295 .22953 L
.72953 .23813 L
.72955 .30257 L
.72957 .37561 L
.72959 .40569 L
.72962 .35843 L
.72964 .25531 L
.72966 .18227 L
.72968 .17798 L
.72971 .22953 L
.72973 .31546 L
.72975 .37561 L
.72977 .37131 L
.72979 .31546 L
.72982 .25531 L
.72984 .24242 L
.72986 .28968 L
.72988 .37561 L
.72991 .41857 L
.72993 .3928 L
.72995 .31117 L
.72997 .22094 L
.73 .17368 L
.73002 .20376 L
.73004 .27679 L
.73006 .34554 L
.73008 .37131 L
.73011 .37131 L
.73013 .34124 L
.73015 .28109 L
.73017 .24242 L
.7302 .26391 L
.73022 .32835 L
.73024 .3885 L
.73026 .40569 L
.73029 .36272 L
.73031 .2682 L
.73033 .19946 L
.73035 .18657 L
.73038 .22094 L
.7304 .29398 L
.73042 .34983 L
.73044 .34554 L
.73046 .30687 L
.73049 .25961 L
Mistroke
.73051 .25102 L
.73053 .28109 L
.73055 .35413 L
.73058 .3928 L
.7306 .37991 L
.73062 .32405 L
.73064 .23813 L
.73067 .17368 L
.73069 .18657 L
.73071 .23813 L
.73073 .29828 L
.73075 .34124 L
.73078 .33265 L
.7308 .28539 L
.73082 .25531 L
.73084 .26391 L
.73087 .30687 L
.73089 .36702 L
.73091 .39709 L
.73093 .37131 L
.73096 .29828 L
.73098 .22524 L
.731 .19087 L
.73102 .20805 L
.73104 .2682 L
.73107 .32835 L
.73109 .34124 L
.73111 .32405 L
.73113 .28968 L
.73116 .2682 L
.73118 .28968 L
.7312 .34554 L
.73122 .39709 L
.73125 .40139 L
.73127 .36272 L
.73129 .2725 L
.73131 .19946 L
.73134 .19087 L
.73136 .22524 L
.73138 .28109 L
.7314 .33694 L
.73142 .33694 L
.73145 .30687 L
.73147 .2725 L
.73149 .2682 L
.73151 .29828 L
.73154 .35843 L
.73156 .39709 L
.73158 .3928 L
.7316 .33265 L
Mistroke
.73163 .25102 L
.73165 .19516 L
.73167 .19087 L
.73169 .22953 L
.73171 .28539 L
.73174 .32405 L
.73176 .32405 L
.73178 .29398 L
.7318 .26391 L
.73183 .2725 L
.73185 .31117 L
.73187 .37131 L
.73189 .3928 L
.73192 .37131 L
.73194 .29828 L
.73196 .21664 L
.73198 .17368 L
.73201 .19516 L
.73203 .24242 L
.73205 .30257 L
.73207 .32835 L
.73209 .31117 L
.73212 .28109 L
.73214 .26391 L
.73216 .28539 L
.73218 .34124 L
.73221 .3842 L
.73223 .39709 L
.73225 .35843 L
.73227 .28539 L
.7323 .22094 L
.73232 .19516 L
.73234 .22094 L
.73236 .26391 L
.73238 .30687 L
.73241 .31976 L
.73243 .30687 L
.73245 .29398 L
.73247 .29398 L
.7325 .28968 L
.73252 .31117 L
.73254 .35843 L
.73256 .3842 L
.73259 .37561 L
.73261 .33265 L
.73263 .26391 L
.73265 .21235 L
.73267 .20805 L
.7327 .22953 L
.73272 .2682 L
Mistroke
.73274 .29828 L
.73276 .31117 L
.73279 .30687 L
.73281 .29828 L
.73283 .29828 L
.73285 .31546 L
.73288 .34124 L
.7329 .36272 L
.73292 .36272 L
.73294 .32835 L
.73297 .27679 L
.73299 .22524 L
.73301 .20376 L
.73303 .21235 L
.73305 .25102 L
.73308 .28968 L
.7331 .31117 L
.73312 .31117 L
.73314 .29398 L
.73317 .28968 L
.73319 .31117 L
.73321 .34554 L
.73323 .36272 L
.73326 .36272 L
.73328 .31976 L
.7333 .25531 L
.73332 .20376 L
.73334 .20376 L
.73337 .22524 L
.73339 .2682 L
.73341 .31117 L
.73343 .32835 L
.73346 .31117 L
.73348 .29398 L
.7335 .28539 L
.73352 .30687 L
.73355 .34124 L
.73357 .37131 L
.73359 .37561 L
.73361 .34554 L
.73364 .28968 L
.73366 .23813 L
.73368 .21235 L
.7337 .22094 L
.73372 .25531 L
.73375 .29398 L
.73377 .31546 L
.73379 .31976 L
.73381 .30257 L
.73384 .29398 L
Mistroke
.73386 .31117 L
.73388 .34554 L
.7339 .36702 L
.73393 .36702 L
.73395 .33694 L
.73397 .28109 L
.73399 .23383 L
.73401 .22524 L
.73404 .23383 L
.73406 .26391 L
.73408 .29828 L
.7341 .31976 L
.73413 .31117 L
.73415 .29398 L
.73417 .28109 L
.73419 .29828 L
.73422 .32835 L
.73424 .36272 L
.73426 .37561 L
.73428 .34554 L
.7343 .29398 L
.73433 .24242 L
.73435 .21235 L
.73437 .22094 L
.73439 .25102 L
.73442 .28539 L
.73444 .29828 L
.73446 .29828 L
.73448 .28539 L
.73451 .28109 L
.73453 .31117 L
.73455 .34983 L
.73457 .36702 L
.7346 .36702 L
.73462 .34124 L
.73464 .28539 L
.73466 .24242 L
.73468 .23383 L
.73471 .24242 L
.73473 .25961 L
.73475 .28539 L
.73477 .30257 L
.7348 .29398 L
.73482 .28968 L
.73484 .28968 L
.73486 .28968 L
.73489 .31117 L
.73491 .34124 L
.73493 .37131 L
.73495 .37561 L
Mistroke
.73497 .35843 L
.735 .31546 L
.73502 .2682 L
.73504 .23383 L
.73506 .22953 L
.73509 .24242 L
.73511 .26391 L
.73513 .28109 L
.73515 .28968 L
.73518 .28968 L
.7352 .29398 L
.73522 .31546 L
.73524 .34983 L
.73527 .36272 L
.73529 .36702 L
.73531 .35413 L
.73533 .31546 L
.73535 .2682 L
.73538 .25102 L
.7354 .23813 L
.73542 .24242 L
.73544 .25531 L
.73547 .2682 L
.73549 .27679 L
.73551 .28539 L
.73553 .29398 L
.73556 .30687 L
.73558 .33265 L
.7356 .34983 L
.73562 .36272 L
.73564 .35843 L
.73567 .33694 L
.73569 .29398 L
.73571 .25102 L
.73573 .22094 L
.73576 .21664 L
.73578 .22953 L
.7358 .25531 L
.73582 .27679 L
.73585 .29398 L
.73587 .29828 L
.73589 .30257 L
.73591 .32835 L
.73593 .34983 L
.73596 .36272 L
.73598 .37131 L
.736 .34983 L
.73602 .30257 L
.73605 .26391 L
.73607 .24242 L
Mistroke
.73609 .22953 L
.73611 .24242 L
.73614 .25961 L
.73616 .27679 L
.73618 .29398 L
.7362 .30257 L
.73623 .30257 L
.73625 .32405 L
.73627 .34554 L
.73629 .36272 L
.73631 .37131 L
.73634 .36272 L
.73636 .32405 L
.73638 .27679 L
.7364 .23383 L
.73643 .21664 L
.73645 .21664 L
.73647 .24242 L
.73649 .2682 L
.73652 .28968 L
.73654 .30257 L
.73656 .30257 L
.73658 .31546 L
.7366 .33694 L
.73663 .35413 L
.73665 .36702 L
.73667 .36702 L
.73669 .33265 L
.73672 .28109 L
.73674 .24672 L
.73676 .22094 L
.73678 .21664 L
.73681 .23383 L
.73683 .25102 L
.73685 .2682 L
.73687 .28539 L
.7369 .29398 L
.73692 .30687 L
.73694 .33265 L
.73696 .35413 L
.73698 .36272 L
.73701 .36272 L
.73703 .34554 L
.73705 .30257 L
.73707 .25961 L
.7371 .22953 L
.73712 .21235 L
.73714 .22094 L
.73716 .23813 L
.73719 .26391 L
Mistroke
.73721 .26391 L
.73723 .28539 L
.73725 .29828 L
.73727 .30687 L
.7373 .33265 L
.73732 .35413 L
.73734 .37131 L
.73736 .37561 L
.73739 .36272 L
.73741 .31976 L
.73743 .27679 L
.73745 .24242 L
.73748 .22094 L
.7375 .22524 L
.73752 .24242 L
.73754 .25531 L
.73756 .27679 L
.73759 .29398 L
.73761 .30257 L
.73763 .31976 L
.73765 .34554 L
.73768 .36702 L
.7377 .37561 L
.73772 .36272 L
.73774 .33265 L
.73777 .28539 L
.73779 .24672 L
.73781 .22524 L
.73783 .22094 L
.73786 .23383 L
.73788 .25102 L
.7379 .2682 L
.73792 .28539 L
.73794 .29828 L
.73797 .31546 L
.73799 .34124 L
.73801 .36272 L
.73803 .37131 L
.73806 .36702 L
.73808 .33694 L
.7381 .29828 L
.73812 .25531 L
.73815 .22953 L
.73817 .21664 L
.73819 .22524 L
.73821 .24672 L
.73823 .2682 L
.73826 .28539 L
.73828 .29828 L
.7383 .31117 L
Mistroke
.73832 .32405 L
.73835 .34554 L
.73837 .36272 L
.73839 .36702 L
.73841 .35413 L
.73844 .31546 L
.73846 .2725 L
.73848 .23813 L
.7385 .22524 L
.73853 .22524 L
.73855 .24242 L
.73857 .26391 L
.73859 .27679 L
.73861 .29398 L
.73864 .31117 L
.73866 .32405 L
.73868 .35413 L
.7387 .37131 L
.73873 .37561 L
.73875 .36272 L
.73877 .33265 L
.73879 .28968 L
.73882 .25531 L
.73884 .23383 L
.73886 .22953 L
.73888 .22953 L
.7389 .24672 L
.73893 .26391 L
.73895 .28109 L
.73897 .30687 L
.73899 .32405 L
.73902 .33694 L
.73904 .34983 L
.73906 .35413 L
.73908 .34983 L
.73911 .34124 L
.73913 .32405 L
.73915 .28968 L
.73917 .25961 L
.73919 .23813 L
.73922 .22524 L
.73924 .22953 L
.73926 .24672 L
.73928 .2682 L
.73931 .29398 L
.73933 .31117 L
.73935 .32835 L
.73937 .34124 L
.7394 .34983 L
.73942 .34983 L
Mistroke
.73944 .34124 L
.73946 .32405 L
.73949 .29398 L
.73951 .26391 L
.73953 .24242 L
.73955 .23813 L
.73957 .23813 L
.7396 .23813 L
.73962 .25102 L
.73964 .2682 L
.73966 .28539 L
.73969 .30257 L
.73971 .31976 L
.73973 .33265 L
.73975 .33694 L
.73978 .34124 L
.7398 .34554 L
.73982 .33694 L
.73984 .31546 L
.73986 .28968 L
.73989 .26391 L
.73991 .23383 L
.73993 .22953 L
.73995 .24242 L
.73998 .26391 L
.74 .28968 L
.74002 .30687 L
.74004 .31546 L
.74007 .31546 L
.74009 .32405 L
.74011 .33694 L
.74013 .34983 L
.74016 .35413 L
.74018 .34983 L
.7402 .31976 L
.74022 .28539 L
.74024 .25102 L
.74027 .22953 L
.74029 .22524 L
.74031 .23813 L
.74033 .25531 L
.74036 .2725 L
.74038 .29398 L
.7404 .31117 L
.74042 .32405 L
.74045 .33694 L
.74047 .34124 L
.74049 .33694 L
.74051 .33694 L
.74053 .32835 L
Mistroke
.74056 .32405 L
.74058 .30687 L
.7406 .28109 L
.74062 .25531 L
.74065 .23813 L
.74067 .23383 L
.74069 .23813 L
.74071 .25531 L
.74074 .2725 L
.74076 .30257 L
.74078 .31976 L
.7408 .33694 L
.74082 .34124 L
.74085 .32835 L
.74087 .30257 L
.74089 .28539 L
.74091 .2725 L
.74094 .26391 L
.74096 .2725 L
.74098 .28968 L
.741 .29828 L
.74103 .30257 L
.74105 .30257 L
.74107 .28968 L
.74109 .28968 L
.74112 .29828 L
.74114 .31117 L
.74116 .31976 L
.74118 .32835 L
.7412 .31546 L
.74123 .28968 L
.74125 .26391 L
.74127 .24242 L
.74129 .23383 L
.74132 .24672 L
.74134 .2682 L
.74136 .28968 L
.74138 .31546 L
.74141 .33694 L
.74143 .34124 L
.74145 .33694 L
.74147 .33694 L
.74149 .31976 L
.74152 .31117 L
.74154 .30687 L
.74156 .30687 L
.74158 .30257 L
.74161 .30257 L
.74163 .28968 L
.74165 .2682 L
Mistroke
.74167 .25531 L
.7417 .24242 L
.74172 .23813 L
.74174 .24242 L
.74176 .25531 L
.74179 .2682 L
.74181 .29828 L
.74183 .32405 L
.74185 .33694 L
.74187 .34983 L
.7419 .34983 L
.74192 .32835 L
.74194 .32835 L
.74196 .31117 L
.74199 .30687 L
.74201 .28968 L
.74203 .28539 L
.74205 .28539 L
.74208 .27679 L
.7421 .27679 L
.74212 .28539 L
.74214 .28968 L
.74216 .28539 L
.74219 .28968 L
.74221 .28968 L
.74223 .28109 L
.74225 .28109 L
.74228 .27679 L
.7423 .2682 L
.74232 .28109 L
.74234 .28539 L
.74237 .29398 L
.74239 .30687 L
.74241 .32405 L
.74243 .31976 L
.74245 .32405 L
.74248 .31976 L
.7425 .31117 L
.74252 .31117 L
.74254 .31546 L
.74257 .31546 L
.74259 .31976 L
.74261 .31976 L
.74263 .30687 L
.74266 .28968 L
.74268 .27679 L
.7427 .26391 L
.74272 .24672 L
.74275 .24672 L
.74277 .25102 L
Mistroke
.74279 .25531 L
.74281 .27679 L
.74283 .29828 L
.74286 .31546 L
.74288 .33694 L
.7429 .34983 L
.74292 .34124 L
.74295 .34124 L
.74297 .33265 L
.74299 .31546 L
.74301 .29828 L
.74304 .29398 L
.74306 .28109 L
.74308 .28539 L
.7431 .29398 L
.74312 .29398 L
.74315 .28968 L
.74317 .28109 L
.74319 .2682 L
.74321 .25961 L
.74324 .2725 L
.74326 .27679 L
.74328 .28109 L
.7433 .28968 L
.74333 .28968 L
.74335 .29828 L
.74337 .31546 L
.74339 .32405 L
.74342 .31976 L
.74344 .31976 L
.74346 .30257 L
.74348 .28968 L
.7435 .28968 L
.74353 .29828 L
.74355 .30257 L
.74357 .31117 L
.74359 .31976 L
.74362 .31546 L
.74364 .30257 L
.74366 .29828 L
.74368 .27679 L
.74371 .26391 L
.74373 .2682 L
.74375 .2682 L
.74377 .2682 L
.74379 .28109 L
.74382 .29398 L
.74384 .29828 L
.74386 .31546 L
.74388 .33265 L
Mistroke
.74391 .32835 L
.74393 .33265 L
.74395 .32835 L
.74397 .31117 L
.744 .29828 L
.74402 .28968 L
.74404 .28109 L
.74406 .28539 L
.74408 .29828 L
.74411 .30257 L
.74413 .29828 L
.74415 .29828 L
.74417 .28109 L
.7442 .2682 L
.74422 .28109 L
.74424 .29398 L
.74426 .28539 L
.74429 .28968 L
.74431 .28968 L
.74433 .29398 L
.74435 .28968 L
.74438 .29828 L
.7444 .30687 L
.74442 .31117 L
.74444 .30257 L
.74446 .30257 L
.74449 .29398 L
.74451 .28968 L
.74453 .28968 L
.74455 .28539 L
.74458 .28109 L
.7446 .29398 L
.74462 .30687 L
.74464 .31117 L
.74467 .31546 L
.74469 .30687 L
.74471 .28109 L
.74473 .26391 L
.74475 .27679 L
.74478 .28539 L
.7448 .28539 L
.74482 .28968 L
.74484 .28539 L
.74487 .28539 L
.74489 .29398 L
.74491 .30687 L
.74493 .31976 L
.74496 .31976 L
.74498 .31546 L
.745 .30257 L
Mistroke
.74502 .28968 L
.74505 .28539 L
.74507 .28539 L
.74509 .28968 L
.74511 .29398 L
.74513 .30257 L
.74516 .30687 L
.74518 .31117 L
.7452 .31117 L
.74522 .30687 L
.74525 .28968 L
.74527 .27679 L
.74529 .28968 L
.74531 .29398 L
.74534 .29828 L
.74536 .29828 L
.74538 .29828 L
.7454 .29398 L
.74542 .28968 L
.74545 .29398 L
.74547 .29828 L
.74549 .29828 L
.74551 .28968 L
.74554 .28109 L
.74556 .27679 L
.74558 .27679 L
.7456 .28539 L
.74563 .29828 L
.74565 .30257 L
.74567 .30257 L
.74569 .30257 L
.74571 .30687 L
.74574 .31117 L
.74576 .30687 L
.74578 .28968 L
.7458 .27679 L
.74583 .28968 L
.74585 .28968 L
.74587 .29398 L
.74589 .29828 L
.74592 .28968 L
.74594 .28109 L
.74596 .28109 L
.74598 .28539 L
.74601 .29398 L
.74603 .30257 L
.74605 .29828 L
.74607 .28968 L
.74609 .28109 L
.74612 .28539 L
Mistroke
.74614 .28968 L
.74616 .30257 L
.74618 .30687 L
.74621 .30257 L
.74623 .30257 L
.74625 .30687 L
.74627 .31117 L
.7463 .31546 L
.74632 .31117 L
.74634 .30257 L
.74636 .30257 L
.74638 .30257 L
.74641 .29828 L
.74643 .29828 L
.74645 .29398 L
.74647 .28109 L
.7465 .27679 L
.74652 .28109 L
.74654 .28539 L
.74656 .29398 L
.74659 .29398 L
.74661 .28539 L
.74663 .28109 L
.74665 .28539 L
.74667 .28539 L
.7467 .29398 L
.74672 .30257 L
.74674 .30257 L
.74676 .30257 L
.74679 .29398 L
.74681 .29828 L
.74683 .30687 L
.74685 .31117 L
.74688 .30257 L
.7469 .29398 L
.74692 .28968 L
.74694 .28968 L
.74697 .29398 L
.74699 .29398 L
.74701 .28968 L
.74703 .28539 L
.74705 .28109 L
.74708 .28539 L
.7471 .29828 L
.74712 .29398 L
.74714 .28968 L
.74717 .28109 L
.74719 .27679 L
.74721 .28109 L
.74723 .28968 L
Mistroke
.74726 .29828 L
.74728 .29828 L
.7473 .29398 L
.74732 .29398 L
.74734 .29398 L
.74737 .30687 L
.74739 .31546 L
.74741 .31546 L
.74743 .31117 L
.74746 .30257 L
.74748 .29828 L
.7475 .30257 L
.74752 .30687 L
.74755 .30687 L
.74757 .30257 L
.74759 .29398 L
.74761 .28539 L
.74764 .28968 L
.74766 .29398 L
.74768 .29398 L
.7477 .28968 L
.74772 .28968 L
.74775 .28968 L
.74777 .29398 L
.74779 .29828 L
.74781 .30257 L
.74784 .29398 L
.74786 .28968 L
.74788 .28968 L
.7479 .29398 L
.74793 .30257 L
.74795 .30257 L
.74797 .30257 L
.74799 .29398 L
.74801 .29398 L
.74804 .29398 L
.74806 .30257 L
.74808 .30257 L
.7481 .29828 L
.74813 .28968 L
.74815 .28539 L
.74817 .28968 L
.74819 .29398 L
.74822 .29398 L
.74824 .28539 L
.74826 .28109 L
.74828 .28109 L
.7483 .28539 L
.74833 .29398 L
.74835 .29398 L
Mistroke
.74837 .28539 L
.74839 .28539 L
.74842 .28109 L
.74844 .28968 L
.74846 .29828 L
.74848 .30257 L
.74851 .30257 L
.74853 .30257 L
.74855 .29828 L
.74857 .30257 L
.7486 .30687 L
.74862 .30687 L
.74864 .30687 L
.74866 .29828 L
.74868 .29398 L
.74871 .29398 L
.74873 .30257 L
.74875 .30257 L
.74877 .30257 L
.7488 .29828 L
.74882 .29398 L
.74884 .29398 L
.74886 .29828 L
.74889 .29828 L
.74891 .30257 L
.74893 .29828 L
.74895 .28968 L
.74897 .28539 L
.749 .28968 L
.74902 .28968 L
.74904 .29828 L
.74906 .29828 L
.74909 .29398 L
.74911 .29398 L
.74913 .29398 L
.74915 .29828 L
.74918 .30257 L
.7492 .30257 L
.74922 .29828 L
.74924 .28968 L
.74927 .28539 L
.74929 .28968 L
.74931 .29398 L
.74933 .29828 L
.74935 .29398 L
.74938 .28968 L
.7494 .28539 L
.74942 .28539 L
.74944 .29398 L
.74947 .29398 L
Mistroke
.74949 .28968 L
.74951 .28539 L
.74953 .28539 L
.74956 .28968 L
.74958 .29398 L
.7496 .29398 L
.74962 .28968 L
.74964 .28539 L
.74967 .28539 L
.74969 .28968 L
.74971 .29828 L
.74973 .29828 L
.74976 .29828 L
.74978 .29828 L
.7498 .29398 L
.74982 .29828 L
.74985 .30257 L
.74987 .30687 L
.74989 .30687 L
.74991 .30687 L
.74993 .30687 L
.74996 .30687 L
.74998 .30257 L
.75 .30687 L
.75002 .30257 L
.75005 .30257 L
.75007 .29828 L
.75009 .29828 L
.75011 .29398 L
.75014 .29398 L
.75016 .29398 L
.75018 .29398 L
.7502 .29398 L
.75023 .29398 L
.75025 .29398 L
.75027 .29828 L
.75029 .29828 L
.75031 .29828 L
.75034 .29828 L
.75036 .29828 L
.75038 .29828 L
.7504 .30257 L
.75043 .29828 L
.75045 .29828 L
.75047 .29398 L
.75049 .28968 L
.75052 .29398 L
.75054 .29828 L
.75056 .29828 L
.75058 .29828 L
Mistroke
.7506 .29398 L
.75063 .28968 L
.75065 .28968 L
.75067 .29398 L
.75069 .29828 L
.75072 .29398 L
.75074 .28968 L
.75076 .28539 L
.75078 .28109 L
.75081 .28539 L
.75083 .28968 L
.75085 .29398 L
.75087 .29398 L
.7509 .28968 L
.75092 .28968 L
.75094 .29398 L
.75096 .30257 L
.75098 .30687 L
.75101 .30687 L
.75103 .30257 L
.75105 .30257 L
.75107 .29828 L
.7511 .30257 L
.75112 .30687 L
.75114 .30687 L
.75116 .30687 L
.75119 .30257 L
.75121 .30257 L
.75123 .30257 L
.75125 .30257 L
.75127 .30257 L
.7513 .30257 L
.75132 .30257 L
.75134 .29828 L
.75136 .29398 L
.75139 .29398 L
.75141 .29398 L
.75143 .29398 L
.75145 .29398 L
.75148 .29398 L
.7515 .29398 L
.75152 .28968 L
.75154 .28968 L
.75156 .29828 L
.75159 .30257 L
.75161 .30257 L
.75163 .30257 L
.75165 .29398 L
.75168 .29398 L
.7517 .29398 L
Mistroke
.75172 .29828 L
.75174 .29828 L
.75177 .29828 L
.75179 .28968 L
.75181 .28539 L
.75183 .28968 L
.75186 .29398 L
.75188 .29398 L
.7519 .29398 L
.75192 .28539 L
.75194 .28109 L
.75197 .28109 L
.75199 .28968 L
.75201 .28968 L
.75203 .29398 L
.75206 .28968 L
.75208 .28539 L
.7521 .28539 L
.75212 .28968 L
.75215 .29828 L
.75217 .29828 L
.75219 .30257 L
.75221 .29828 L
.75223 .29398 L
.75226 .29828 L
.75228 .29828 L
.7523 .30687 L
.75232 .30687 L
.75235 .30687 L
.75237 .30257 L
.75239 .29828 L
.75241 .29828 L
.75244 .30257 L
.75246 .30687 L
.75248 .30687 L
.7525 .30257 L
.75253 .29398 L
.75255 .29398 L
.75257 .29398 L
.75259 .29828 L
.75261 .30257 L
.75264 .30257 L
.75266 .29398 L
.75268 .28968 L
.7527 .28968 L
.75273 .29398 L
.75275 .29828 L
.75277 .29828 L
.75279 .29828 L
.75282 .29398 L
Mistroke
.75284 .28968 L
.75286 .29398 L
.75288 .29828 L
.7529 .30257 L
.75293 .29398 L
.75295 .28968 L
.75297 .28109 L
.75299 .28539 L
.75302 .28968 L
.75304 .29398 L
.75306 .29398 L
.75308 .28968 L
.75311 .28539 L
.75313 .28539 L
.75315 .28968 L
.75317 .29398 L
.75319 .29398 L
.75322 .28968 L
.75324 .28109 L
.75326 .28109 L
.75328 .28968 L
.75331 .29398 L
.75333 .29828 L
.75335 .29398 L
.75337 .28539 L
.7534 .28109 L
.75342 .28539 L
.75344 .29398 L
.75346 .30257 L
.75349 .30257 L
.75351 .29828 L
.75353 .29398 L
.75355 .28968 L
.75357 .29828 L
.7536 .30687 L
.75362 .31546 L
.75364 .31117 L
.75366 .30257 L
.75369 .29828 L
.75371 .29398 L
.75373 .29828 L
.75375 .29828 L
.75378 .30257 L
.7538 .31117 L
.75382 .30687 L
.75384 .29828 L
.75386 .28968 L
.75389 .28539 L
.75391 .29398 L
.75393 .30257 L
Mistroke
.75395 .30257 L
.75398 .29828 L
.754 .28968 L
.75402 .28109 L
.75404 .28539 L
.75407 .29398 L
.75409 .30257 L
.75411 .30257 L
.75413 .29398 L
.75416 .28539 L
.75418 .28539 L
.7542 .29398 L
.75422 .30257 L
.75424 .30257 L
.75427 .29398 L
.75429 .28539 L
.75431 .28109 L
.75433 .28968 L
.75436 .29828 L
.75438 .29828 L
.7544 .29398 L
.75442 .28539 L
.75445 .28109 L
.75447 .28539 L
.75449 .29398 L
.75451 .29828 L
.75453 .29398 L
.75456 .28968 L
.75458 .28539 L
.7546 .28539 L
.75462 .29398 L
.75465 .29828 L
.75467 .29828 L
.75469 .29828 L
.75471 .28968 L
.75474 .28968 L
.75476 .29398 L
.75478 .30257 L
.7548 .30257 L
.75482 .30687 L
.75485 .30687 L
.75487 .30257 L
.75489 .30257 L
.75491 .30257 L
.75494 .30687 L
.75496 .30257 L
.75498 .30257 L
.755 .30257 L
.75503 .30257 L
.75505 .29828 L
Mistroke
.75507 .29828 L
.75509 .29828 L
.75512 .30257 L
.75514 .30257 L
.75516 .29828 L
.75518 .29828 L
.7552 .29828 L
.75523 .29398 L
.75525 .29398 L
.75527 .29828 L
.75529 .29828 L
.75532 .29828 L
.75534 .29398 L
.75536 .28968 L
.75538 .28968 L
.75541 .29398 L
.75543 .29828 L
.75545 .29398 L
.75547 .28968 L
.75549 .28968 L
.75552 .28968 L
.75554 .29398 L
.75556 .29828 L
.75558 .29398 L
.75561 .29398 L
.75563 .28968 L
.75565 .28539 L
.75567 .28968 L
.7557 .29398 L
.75572 .29828 L
.75574 .29398 L
.75576 .28968 L
.75579 .28968 L
.75581 .28968 L
.75583 .29398 L
.75585 .30257 L
.75587 .30257 L
.7559 .29828 L
.75592 .29398 L
.75594 .28968 L
.75596 .29398 L
.75599 .29828 L
.75601 .30257 L
.75603 .29828 L
.75605 .29828 L
.75608 .29398 L
.7561 .29398 L
.75612 .29398 L
.75614 .29828 L
.75616 .30257 L
Mistroke
.75619 .30687 L
.75621 .30687 L
.75623 .30257 L
.75625 .30257 L
.75628 .30257 L
.7563 .30257 L
.75632 .30257 L
.75634 .30257 L
.75637 .30257 L
.75639 .29828 L
.75641 .29828 L
.75643 .29828 L
.75645 .29828 L
.75648 .29828 L
.7565 .29828 L
.75652 .29828 L
.75654 .29828 L
.75657 .29828 L
.75659 .29828 L
.75661 .29398 L
.75663 .29398 L
.75666 .28968 L
.75668 .28968 L
.7567 .28968 L
.75672 .28968 L
.75675 .28968 L
.75677 .28539 L
.75679 .28539 L
.75681 .28539 L
.75683 .28968 L
.75686 .28968 L
.75688 .28968 L
.7569 .28968 L
.75692 .28968 L
.75695 .28968 L
.75697 .29398 L
.75699 .29398 L
.75701 .29398 L
.75704 .29398 L
.75706 .29398 L
.75708 .28968 L
.7571 .28968 L
.75712 .29398 L
.75715 .29828 L
.75717 .29828 L
.75719 .29828 L
.75721 .29828 L
.75724 .29398 L
.75726 .29828 L
.75728 .29828 L
Mistroke
.7573 .30257 L
.75733 .30257 L
.75735 .29828 L
.75737 .29828 L
.75739 .29828 L
.75742 .29828 L
.75744 .29828 L
.75746 .29828 L
.75748 .29828 L
.7575 .29828 L
.75753 .29828 L
.75755 .29828 L
.75757 .29828 L
.75759 .29828 L
.75762 .30257 L
.75764 .30257 L
.75766 .29828 L
.75768 .29828 L
.75771 .29828 L
.75773 .29828 L
.75775 .29828 L
.75777 .29828 L
.75779 .29828 L
.75782 .29398 L
.75784 .29398 L
.75786 .29828 L
.75788 .29398 L
.75791 .29398 L
.75793 .29398 L
.75795 .29398 L
.75797 .29398 L
.758 .29398 L
.75802 .29398 L
.75804 .28968 L
.75806 .28539 L
.75808 .28539 L
.75811 .28539 L
.75813 .28968 L
.75815 .28968 L
.75817 .28968 L
.7582 .28968 L
.75822 .28968 L
.75824 .28968 L
.75826 .28968 L
.75829 .29398 L
.75831 .29398 L
.75833 .29398 L
.75835 .29398 L
.75838 .29398 L
.7584 .29398 L
Mistroke
.75842 .29398 L
.75844 .29828 L
.75846 .29828 L
.75849 .29828 L
.75851 .30257 L
.75853 .29828 L
.75855 .29828 L
.75858 .29828 L
.7586 .30257 L
.75862 .30687 L
.75864 .30687 L
.75867 .30257 L
.75869 .29828 L
.75871 .29828 L
.75873 .29828 L
.75875 .30257 L
.75878 .30257 L
.7588 .29828 L
.75882 .29398 L
.75884 .29398 L
.75887 .29398 L
.75889 .29398 L
.75891 .29398 L
.75893 .29398 L
.75896 .29398 L
.75898 .29398 L
.759 .29398 L
.75902 .29398 L
.75905 .29398 L
.75907 .29828 L
.75909 .29828 L
.75911 .29828 L
.75913 .29398 L
.75916 .29398 L
.75918 .29398 L
.7592 .29398 L
.75922 .29398 L
.75925 .29398 L
.75927 .29398 L
.75929 .28968 L
.75931 .29398 L
.75934 .28968 L
.75936 .28968 L
.75938 .28968 L
.7594 .28968 L
.75942 .28968 L
.75945 .28968 L
.75947 .28968 L
.75949 .28539 L
.75951 .28539 L
Mistroke
.75954 .28968 L
.75956 .28968 L
.75958 .28968 L
.7596 .28968 L
.75963 .28968 L
.75965 .28968 L
.75967 .29398 L
.75969 .29828 L
.75971 .29828 L
.75974 .29828 L
.75976 .29398 L
.75978 .29398 L
.7598 .29828 L
.75983 .30687 L
.75985 .30687 L
.75987 .30257 L
.75989 .29828 L
.75992 .29828 L
.75994 .30257 L
.75996 .30687 L
.75998 .30257 L
.76001 .30257 L
.76003 .29828 L
.76005 .29398 L
.76007 .29828 L
.76009 .30257 L
.76012 .30257 L
.76014 .29828 L
.76016 .29398 L
.76018 .28968 L
.76021 .29398 L
.76023 .29828 L
.76025 .29828 L
.76027 .29828 L
.7603 .29398 L
.76032 .28968 L
.76034 .28968 L
.76036 .29828 L
.76038 .29828 L
.76041 .29828 L
.76043 .29398 L
.76045 .28968 L
.76047 .28968 L
.7605 .29398 L
.76052 .29828 L
.76054 .29828 L
.76056 .29398 L
.76059 .28968 L
.76061 .28539 L
.76063 .28968 L
Mistroke
.76065 .29398 L
.76068 .29828 L
.7607 .29398 L
.76072 .28968 L
.76074 .28539 L
.76076 .28968 L
.76079 .29398 L
.76081 .29828 L
.76083 .29828 L
.76085 .29828 L
.76088 .29398 L
.7609 .28968 L
.76092 .28968 L
.76094 .29398 L
.76097 .29828 L
.76099 .29828 L
.76101 .29828 L
.76103 .29828 L
.76105 .29828 L
.76108 .29828 L
.7611 .30257 L
.76112 .30687 L
.76114 .30257 L
.76117 .30257 L
.76119 .29828 L
.76121 .29828 L
.76123 .30257 L
.76126 .30257 L
.76128 .30257 L
.7613 .29828 L
.76132 .29398 L
.76134 .29398 L
.76137 .29828 L
.76139 .29828 L
.76141 .29828 L
.76143 .29828 L
.76146 .29398 L
.76148 .29398 L
.7615 .29398 L
.76152 .29398 L
.76155 .29398 L
.76157 .29398 L
.76159 .29398 L
.76161 .29398 L
.76164 .29398 L
.76166 .29398 L
.76168 .29398 L
.7617 .29398 L
.76172 .29398 L
.76175 .29398 L
Mistroke
.76177 .28968 L
.76179 .28968 L
.76181 .28968 L
.76184 .28968 L
.76186 .28968 L
.76188 .29398 L
.7619 .28968 L
.76193 .28968 L
.76195 .28968 L
.76197 .28539 L
.76199 .28968 L
.76201 .29398 L
.76204 .29398 L
.76206 .29398 L
.76208 .28968 L
.7621 .28539 L
.76213 .28968 L
.76215 .28968 L
.76217 .29828 L
.76219 .29828 L
.76222 .29398 L
.76224 .29398 L
.76226 .29398 L
.76228 .29398 L
.76231 .29828 L
.76233 .30257 L
.76235 .30257 L
.76237 .29828 L
.76239 .29828 L
.76242 .30257 L
.76244 .30257 L
.76246 .30257 L
.76248 .29828 L
.76251 .29398 L
.76253 .29828 L
.76255 .29828 L
.76257 .29828 L
.7626 .29828 L
.76262 .29398 L
.76264 .29398 L
.76266 .29398 L
.76268 .29398 L
.76271 .29398 L
.76273 .29828 L
.76275 .29398 L
.76277 .28968 L
.7628 .29398 L
.76282 .29398 L
.76284 .29398 L
.76286 .29828 L
Mistroke
.76289 .29828 L
.76291 .29828 L
.76293 .29398 L
.76295 .29398 L
.76297 .29398 L
.763 .29398 L
.76302 .29828 L
.76304 .29398 L
.76306 .29398 L
.76309 .28968 L
.76311 .28539 L
.76313 .28968 L
.76315 .29828 L
.76318 .29828 L
.7632 .29398 L
.76322 .29398 L
.76324 .28968 L
.76327 .28539 L
.76329 .28968 L
.76331 .29828 L
.76333 .29828 L
.76335 .29828 L
.76338 .28968 L
.7634 .28968 L
.76342 .29398 L
.76344 .29828 L
.76347 .30257 L
.76349 .30257 L
.76351 .29828 L
.76353 .29398 L
.76356 .29828 L
.76358 .30257 L
.7636 .30687 L
.76362 .30687 L
.76364 .30257 L
.76367 .30257 L
.76369 .30257 L
.76371 .30257 L
.76373 .30257 L
.76376 .30257 L
.76378 .30257 L
.7638 .29828 L
.76382 .29828 L
.76385 .29828 L
.76387 .29828 L
.76389 .29828 L
.76391 .29828 L
.76393 .29828 L
.76396 .29398 L
.76398 .29398 L
Mistroke
.764 .29828 L
.76402 .29828 L
.76405 .29828 L
.76407 .29398 L
.76409 .28968 L
.76411 .29398 L
.76414 .29828 L
.76416 .30257 L
.76418 .30257 L
.7642 .29398 L
.76423 .28968 L
.76425 .28968 L
.76427 .29828 L
.76429 .30257 L
.76431 .30257 L
.76434 .28968 L
.76436 .28539 L
.76438 .28968 L
.7644 .29828 L
.76443 .30687 L
.76445 .30257 L
.76447 .28968 L
.76449 .28109 L
.76452 .28539 L
.76454 .29828 L
.76456 .30687 L
.76458 .30257 L
.7646 .29398 L
.76463 .28539 L
.76465 .28539 L
.76467 .29828 L
.76469 .30687 L
.76472 .30687 L
.76474 .30257 L
.76476 .28968 L
.76478 .29398 L
.76481 .29828 L
.76483 .30687 L
.76485 .31117 L
.76487 .30687 L
.7649 .29828 L
.76492 .29398 L
.76494 .29828 L
.76496 .30687 L
.76498 .31117 L
.76501 .30687 L
.76503 .29828 L
.76505 .28968 L
.76507 .29398 L
.7651 .29828 L
Mistroke
.76512 .30257 L
.76514 .30257 L
.76516 .29398 L
.76519 .28539 L
.76521 .28968 L
.76523 .29828 L
.76525 .30257 L
.76527 .29828 L
.7653 .28968 L
.76532 .28539 L
.76534 .28968 L
.76536 .29828 L
.76539 .30257 L
.76541 .29398 L
.76543 .28539 L
.76545 .28109 L
.76548 .28539 L
.7655 .29828 L
.76552 .30257 L
.76554 .29398 L
.76556 .28109 L
.76559 .28109 L
.76561 .27679 L
.76563 .28539 L
.76565 .29828 L
.76568 .30257 L
.7657 .29398 L
.76572 .28109 L
.76574 .27679 L
.76577 .28539 L
.76579 .29828 L
.76581 .30257 L
.76583 .29828 L
.76586 .28539 L
.76588 .27679 L
.7659 .28539 L
.76592 .29828 L
.76594 .30257 L
.76597 .30257 L
.76599 .28968 L
.76601 .28539 L
.76603 .28968 L
.76606 .29828 L
.76608 .30687 L
.7661 .30257 L
.76612 .29398 L
.76615 .29398 L
.76617 .29398 L
.76619 .30257 L
.76621 .30257 L
Mistroke
.76623 .30257 L
.76626 .29398 L
.76628 .28968 L
.7663 .29398 L
.76632 .29828 L
.76635 .30257 L
.76637 .29828 L
.76639 .28968 L
.76641 .28539 L
.76644 .28539 L
.76646 .29398 L
.76648 .29828 L
.7665 .29398 L
.76653 .28539 L
.76655 .28109 L
.76657 .28109 L
.76659 .28968 L
.76661 .30257 L
.76664 .29828 L
.76666 .28968 L
.76668 .28109 L
.7667 .28109 L
.76673 .29398 L
.76675 .29828 L
.76677 .29828 L
.76679 .28968 L
.76682 .28109 L
.76684 .28109 L
.76686 .29398 L
.76688 .30257 L
.7669 .29828 L
.76693 .28539 L
.76695 .27679 L
.76697 .28109 L
.76699 .29398 L
.76702 .30257 L
.76704 .29828 L
.76706 .28539 L
.76708 .28109 L
.76711 .28539 L
.76713 .29828 L
.76715 .30687 L
.76717 .30257 L
.76719 .29398 L
.76722 .28539 L
.76724 .28968 L
.76726 .29828 L
.76728 .30687 L
.76731 .31117 L
.76733 .30257 L
Mistroke
.76735 .29398 L
.76737 .29398 L
.7674 .30257 L
.76742 .30687 L
.76744 .31117 L
.76746 .30257 L
.76749 .29398 L
.76751 .29398 L
.76753 .29828 L
.76755 .30257 L
.76757 .30687 L
.7676 .30257 L
.76762 .29398 L
.76764 .28968 L
.76766 .29398 L
.76769 .29828 L
.76771 .30257 L
.76773 .29828 L
.76775 .28968 L
.76778 .28539 L
.7678 .29398 L
.76782 .29828 L
.76784 .29828 L
.76786 .29398 L
.76789 .28968 L
.76791 .28968 L
.76793 .28968 L
.76795 .29398 L
.76798 .30257 L
.768 .29828 L
.76802 .28968 L
.76804 .28539 L
.76807 .28968 L
.76809 .29828 L
.76811 .30257 L
.76813 .29398 L
.76816 .28968 L
.76818 .28539 L
.7682 .28968 L
.76822 .29828 L
.76824 .30257 L
.76827 .29828 L
.76829 .28539 L
.76831 .28539 L
.76833 .28968 L
.76836 .29828 L
.76838 .30257 L
.7684 .29828 L
.76842 .29398 L
.76845 .28968 L
Mistroke
.76847 .29828 L
.76849 .30687 L
.76851 .30687 L
.76853 .30257 L
.76856 .29828 L
.76858 .29828 L
.7686 .30257 L
.76862 .31117 L
.76865 .31117 L
.76867 .30687 L
.76869 .30257 L
.76871 .29828 L
.76874 .29828 L
.76876 .30687 L
.76878 .31117 L
.7688 .30687 L
.76882 .29828 L
.76885 .28968 L
.76887 .29398 L
.76889 .30257 L
.76891 .30687 L
.76894 .30257 L
.76896 .29398 L
.76898 .28539 L
.769 .28539 L
.76903 .29828 L
.76905 .30687 L
.76907 .30257 L
.76909 .29398 L
.76912 .28539 L
.76914 .28539 L
.76916 .29828 L
.76918 .30687 L
.7692 .30257 L
.76923 .28968 L
.76925 .28109 L
.76927 .28539 L
.76929 .29828 L
.76932 .30687 L
.76934 .29828 L
.76936 .28539 L
.76938 .27679 L
.76941 .28539 L
.76943 .29828 L
.76945 .30687 L
.76947 .29828 L
.76949 .28539 L
.76952 .27679 L
.76954 .28539 L
.76956 .29828 L
Mistroke
.76958 .30687 L
.76961 .30257 L
.76963 .28968 L
.76965 .28539 L
.76967 .28539 L
.7697 .29828 L
.76972 .30687 L
.76974 .31117 L
.76976 .30257 L
.76979 .29398 L
.76981 .29398 L
.76983 .29828 L
.76985 .31117 L
.76987 .31117 L
.7699 .30687 L
.76992 .29828 L
.76994 .29398 L
.76996 .29828 L
.76999 .30687 L
.77001 .31117 L
.77003 .30687 L
.77005 .29828 L
.77008 .28968 L
.7701 .29398 L
.77012 .29828 L
.77014 .30257 L
.77016 .30257 L
.77019 .29398 L
.77021 .28539 L
.77023 .28539 L
.77025 .29398 L
.77028 .29828 L
.7703 .29828 L
.77032 .30257 L
.77034 .29398 L
.77037 .28539 L
.77039 .28539 L
.77041 .28968 L
.77043 .29828 L
.77045 .29828 L
.77048 .29398 L
.7705 .28539 L
.77052 .28109 L
.77054 .28539 L
.77057 .29398 L
.77059 .29398 L
.77061 .28968 L
.77063 .28539 L
.77066 .28539 L
.77068 .28539 L
Mistroke
.7707 .28968 L
.77072 .29398 L
.77075 .28968 L
.77077 .28968 L
.77079 .28539 L
.77081 .28539 L
.77083 .28968 L
.77086 .29398 L
.77088 .29828 L
.7709 .29398 L
.77092 .29398 L
.77095 .29398 L
.77097 .29398 L
.77099 .29828 L
.77101 .30257 L
.77104 .30687 L
.77106 .30687 L
.77108 .30257 L
.7711 .29828 L
.77112 .29828 L
.77115 .30257 L
.77117 .30687 L
.77119 .30687 L
.77121 .30687 L
.77124 .29828 L
.77126 .29828 L
.77128 .29828 L
.7713 .30257 L
.77133 .30257 L
.77135 .30257 L
.77137 .29828 L
.77139 .29398 L
.77142 .29398 L
.77144 .29398 L
.77146 .29828 L
.77148 .30257 L
.7715 .29398 L
.77153 .29398 L
.77155 .28968 L
.77157 .29398 L
.77159 .29828 L
.77162 .29828 L
.77164 .29398 L
.77166 .28968 L
.77168 .28968 L
.77171 .29398 L
.77173 .29828 L
.77175 .29828 L
.77177 .28968 L
.77179 .28539 L
Mistroke
.77182 .28539 L
.77184 .28968 L
.77186 .29398 L
.77188 .29398 L
.77191 .28968 L
.77193 .28539 L
.77195 .28539 L
.77197 .28968 L
.772 .29398 L
.77202 .29398 L
.77204 .28968 L
.77206 .28539 L
.77208 .28539 L
.77211 .28968 L
.77213 .29398 L
.77215 .29828 L
.77217 .29828 L
.7722 .29828 L
.77222 .29398 L
.77224 .29398 L
.77226 .29828 L
.77229 .29828 L
.77231 .30257 L
.77233 .30257 L
.77235 .30687 L
.77238 .30257 L
.7724 .29828 L
.77242 .29828 L
.77244 .29828 L
.77246 .30257 L
.77249 .30687 L
.77251 .30687 L
.77253 .29828 L
.77255 .29398 L
.77258 .29398 L
.7726 .29398 L
.77262 .29828 L
.77264 .30257 L
.77267 .30257 L
.77269 .29828 L
.77271 .29398 L
.77273 .28968 L
.77275 .28968 L
.77278 .29828 L
.7728 .29828 L
.77282 .29398 L
.77284 .29398 L
.77287 .28968 L
.77289 .28968 L
.77291 .29398 L
Mistroke
.77293 .29398 L
.77296 .29398 L
.77298 .28968 L
.773 .28968 L
.77302 .28968 L
.77305 .28968 L
.77307 .28968 L
.77309 .28968 L
.77311 .28539 L
.77313 .28539 L
.77316 .28539 L
.77318 .28968 L
.7732 .28968 L
.77322 .29398 L
.77325 .28968 L
.77327 .28539 L
.77329 .28539 L
.77331 .28968 L
.77334 .29398 L
.77336 .29398 L
.77338 .29398 L
.7734 .29398 L
.77342 .29398 L
.77345 .29398 L
.77347 .29828 L
.77349 .29828 L
.77351 .29828 L
.77354 .30257 L
.77356 .30257 L
.77358 .30257 L
.7736 .30257 L
.77363 .30257 L
.77365 .29828 L
.77367 .29828 L
.77369 .30257 L
.77371 .30687 L
.77374 .30257 L
.77376 .29828 L
.77378 .29398 L
.7738 .29398 L
.77383 .29828 L
.77385 .30257 L
.77387 .30257 L
.77389 .29398 L
.77392 .28968 L
.77394 .28968 L
.77396 .29398 L
.77398 .29828 L
.77401 .29828 L
.77403 .29398 L
Mistroke
.77405 .28968 L
.77407 .28968 L
.77409 .29398 L
.77412 .29828 L
.77414 .29828 L
.77416 .29398 L
.77418 .28968 L
.77421 .28968 L
.77423 .28968 L
.77425 .29398 L
.77427 .29828 L
.7743 .29398 L
.77432 .28539 L
.77434 .28539 L
.77436 .28539 L
.77438 .28968 L
.77441 .29398 L
.77443 .29398 L
.77445 .28968 L
.77447 .28539 L
.7745 .28539 L
.77452 .28968 L
.77454 .29398 L
.77456 .29398 L
.77459 .28968 L
.77461 .28968 L
.77463 .28968 L
.77465 .29398 L
.77468 .29828 L
.7747 .29828 L
.77472 .30257 L
.77474 .29828 L
.77476 .29828 L
.77479 .29828 L
.77481 .30257 L
.77483 .30687 L
.77485 .30257 L
.77488 .30257 L
.7749 .30257 L
.77492 .30257 L
.77494 .30257 L
.77497 .30257 L
.77499 .30257 L
.77501 .30257 L
.77503 .30257 L
.77505 .30257 L
.77508 .30257 L
.7751 .30257 L
.77512 .29828 L
.77514 .29828 L
Mistroke
.77517 .29828 L
.77519 .29828 L
.77521 .29828 L
.77523 .29828 L
.77526 .29828 L
.77528 .29828 L
.7753 .29398 L
.77532 .29398 L
.77534 .29398 L
.77537 .29828 L
.77539 .29828 L
.77541 .29828 L
.77543 .29398 L
.77546 .29398 L
.77548 .29398 L
.7755 .29398 L
.77552 .29398 L
.77555 .29398 L
.77557 .29398 L
.77559 .28968 L
.77561 .28968 L
.77564 .28968 L
.77566 .28968 L
.77568 .29398 L
.7757 .29398 L
.77572 .29398 L
.77575 .28968 L
.77577 .28968 L
.77579 .29398 L
.77581 .29398 L
.77584 .29398 L
.77586 .29398 L
.77588 .29398 L
.7759 .29828 L
.77593 .29828 L
.77595 .29828 L
.77597 .29828 L
.77599 .29828 L
.77601 .30257 L
.77604 .30257 L
.77606 .30257 L
.77608 .30257 L
.7761 .30257 L
.77613 .30257 L
.77615 .30687 L
.77617 .30687 L
.77619 .30687 L
.77622 .30257 L
.77624 .30257 L
.77626 .29828 L
Mistroke
.77628 .29828 L
.77631 .30257 L
.77633 .30257 L
.77635 .29828 L
.77637 .29828 L
.77639 .29828 L
.77642 .29828 L
.77644 .29828 L
.77646 .29398 L
.77648 .29398 L
.77651 .29398 L
.77653 .29828 L
.77655 .29828 L
.77657 .29828 L
.7766 .29398 L
.77662 .29398 L
.77664 .29398 L
.77666 .29398 L
.77668 .29398 L
.77671 .29398 L
.77673 .29398 L
.77675 .28968 L
.77677 .28968 L
.7768 .28968 L
.77682 .28968 L
.77684 .28968 L
.77686 .28968 L
.77689 .28968 L
.77691 .28968 L
.77693 .28968 L
.77695 .28968 L
.77697 .28968 L
.777 .28968 L
.77702 .28968 L
.77704 .28968 L
.77706 .28968 L
.77709 .28968 L
.77711 .28968 L
.77713 .29398 L
.77715 .29398 L
.77718 .29398 L
.7772 .29398 L
.77722 .29398 L
.77724 .29828 L
.77727 .29828 L
.77729 .30257 L
.77731 .30257 L
.77733 .30257 L
.77735 .30257 L
.77738 .30257 L
Mistroke
.7774 .30257 L
.77742 .30257 L
.77744 .30257 L
.77747 .29828 L
.77749 .29828 L
.77751 .29828 L
.77753 .29828 L
.77756 .29828 L
.77758 .29828 L
.7776 .29398 L
.77762 .29398 L
.77764 .29398 L
.77767 .29398 L
.77769 .29398 L
.77771 .29828 L
.77773 .29398 L
.77776 .28968 L
.77778 .28968 L
.7778 .29398 L
.77782 .29398 L
.77785 .29398 L
.77787 .29398 L
.77789 .29398 L
.77791 .28968 L
.77794 .28968 L
.77796 .28968 L
.77798 .28968 L
.778 .28968 L
.77802 .28968 L
.77805 .28968 L
.77807 .28539 L
.77809 .28539 L
.77811 .28539 L
.77814 .28968 L
.77816 .28968 L
.77818 .28968 L
.7782 .28539 L
.77823 .28539 L
.77825 .28968 L
.77827 .28968 L
.77829 .28968 L
.77831 .28968 L
.77834 .28539 L
.77836 .28539 L
.77838 .28968 L
.7784 .29398 L
.77843 .29828 L
.77845 .29398 L
.77847 .29398 L
.77849 .29398 L
Mistroke
.77852 .29398 L
.77854 .29828 L
.77856 .30257 L
.77858 .30257 L
.7786 .29828 L
.77863 .29828 L
.77865 .29828 L
.77867 .30257 L
.77869 .30257 L
.77872 .30257 L
.77874 .29828 L
.77876 .29828 L
.77878 .29828 L
.77881 .29828 L
.77883 .30257 L
.77885 .30257 L
.77887 .29828 L
.7789 .29398 L
.77892 .28968 L
.77894 .29398 L
.77896 .29398 L
.77898 .29828 L
.77901 .29828 L
.77903 .29398 L
.77905 .28968 L
.77907 .28968 L
.7791 .29398 L
.77912 .29828 L
.77914 .29828 L
.77916 .29398 L
.77919 .28968 L
.77921 .28968 L
.77923 .29398 L
.77925 .29398 L
.77927 .29398 L
.7793 .29398 L
.77932 .28968 L
.77934 .28968 L
.77936 .29398 L
.77939 .29398 L
.77941 .29398 L
.77943 .28968 L
.77945 .28968 L
.77948 .29398 L
.7795 .29398 L
.77952 .29398 L
.77954 .28968 L
.77956 .28968 L
.77959 .29398 L
.77961 .29398 L
Mistroke
.77963 .29398 L
.77965 .29398 L
.77968 .28968 L
.7797 .29398 L
.77972 .29828 L
.77974 .30257 L
.77977 .30257 L
.77979 .29828 L
.77981 .29828 L
.77983 .29398 L
.77986 .29828 L
.77988 .30257 L
.7799 .30687 L
.77992 .30687 L
.77994 .30257 L
.77997 .30257 L
.77999 .29828 L
.78001 .30257 L
.78003 .30687 L
.78006 .30687 L
.78008 .30257 L
.7801 .29828 L
.78012 .29828 L
.78015 .29828 L
.78017 .30257 L
.78019 .30257 L
.78021 .29828 L
.78023 .29398 L
.78026 .28968 L
.78028 .29398 L
.7803 .30687 L
.78032 .30687 L
.78035 .30257 L
.78037 .28968 L
.78039 .28539 L
.78041 .29398 L
.78044 .30257 L
.78046 .31117 L
.78048 .30257 L
.7805 .28539 L
.78053 .28109 L
.78055 .28968 L
.78057 .30257 L
.78059 .31117 L
.78061 .30257 L
.78064 .28539 L
.78066 .27679 L
.78068 .28968 L
.7807 .30257 L
.78073 .30687 L
Mistroke
.78075 .29828 L
.78077 .28539 L
.78079 .28109 L
.78082 .28968 L
.78084 .30257 L
.78086 .30687 L
.78088 .29828 L
.7809 .28539 L
.78093 .28109 L
.78095 .28968 L
.78097 .30257 L
.78099 .30687 L
.78102 .30257 L
.78104 .28968 L
.78106 .28539 L
.78108 .29398 L
.78111 .30687 L
.78113 .31546 L
.78115 .30687 L
.78117 .29828 L
.78119 .28968 L
.78122 .29398 L
.78124 .30687 L
.78126 .31546 L
.78128 .31117 L
.78131 .29828 L
.78133 .28968 L
.78135 .29398 L
.78137 .30687 L
.7814 .31117 L
.78142 .30687 L
.78144 .29398 L
.78146 .28539 L
.78149 .28968 L
.78151 .30257 L
.78153 .31117 L
.78155 .29828 L
.78157 .28968 L
.7816 .28539 L
.78162 .29398 L
.78164 .30257 L
.78166 .30687 L
.78169 .29398 L
.78171 .28539 L
.78173 .28109 L
.78175 .29398 L
.78178 .30687 L
.7818 .30257 L
.78182 .28968 L
.78184 .28109 L
Mistroke
.78186 .28539 L
.78189 .29398 L
.78191 .30687 L
.78193 .29828 L
.78195 .28539 L
.78198 .27679 L
.782 .28539 L
.78202 .29398 L
.78204 .30257 L
.78207 .29398 L
.78209 .28109 L
.78211 .27679 L
.78213 .27679 L
.78216 .28109 L
.78218 .29398 L
.7822 .30257 L
.78222 .29828 L
.78224 .28539 L
.78227 .27679 L
.78229 .28539 L
.78231 .29828 L
.78233 .30687 L
.78236 .30257 L
.78238 .29398 L
.7824 .28539 L
.78242 .28968 L
.78245 .29828 L
.78247 .30687 L
.78249 .30687 L
.78251 .29828 L
.78253 .28968 L
.78256 .28968 L
.78258 .29828 L
.7826 .30257 L
.78262 .30257 L
.78265 .29398 L
.78267 .28968 L
.78269 .28968 L
.78271 .29398 L
.78274 .30257 L
.78276 .30257 L
.78278 .28968 L
.7828 .28539 L
.78282 .28539 L
.78285 .29828 L
.78287 .30257 L
.78289 .29828 L
.78291 .28968 L
.78294 .28539 L
.78296 .28539 L
Mistroke
.78298 .29828 L
.783 .30257 L
.78303 .29828 L
.78305 .28539 L
.78307 .28109 L
.78309 .28968 L
.78312 .29828 L
.78314 .29828 L
.78316 .28968 L
.78318 .28109 L
.7832 .28109 L
.78323 .28968 L
.78325 .29828 L
.78327 .29828 L
.78329 .28968 L
.78332 .27679 L
.78334 .28109 L
.78336 .28968 L
.78338 .29828 L
.78341 .29398 L
.78343 .28968 L
.78345 .28109 L
.78347 .28109 L
.78349 .29398 L
.78352 .29828 L
.78354 .29828 L
.78356 .29398 L
.78358 .28968 L
.78361 .28968 L
.78363 .29828 L
.78365 .30257 L
.78367 .30687 L
.7837 .29828 L
.78372 .29398 L
.78374 .29398 L
.78376 .29828 L
.78379 .30687 L
.78381 .30687 L
.78383 .30257 L
.78385 .29398 L
.78387 .29398 L
.7839 .29828 L
.78392 .30257 L
.78394 .30257 L
.78396 .29828 L
.78399 .29398 L
.78401 .29398 L
.78403 .29828 L
.78405 .30257 L
.78408 .30257 L
Mistroke
.7841 .29398 L
.78412 .28968 L
.78414 .29398 L
.78416 .29828 L
.78419 .30687 L
.78421 .29828 L
.78423 .29398 L
.78425 .28968 L
.78428 .29398 L
.7843 .30257 L
.78432 .30257 L
.78434 .29398 L
.78437 .28968 L
.78439 .28968 L
.78441 .29398 L
.78443 .30257 L
.78445 .30257 L
.78448 .29398 L
.7845 .29398 L
.78452 .28539 L
.78454 .28539 L
.78457 .29398 L
.78459 .30257 L
.78461 .30257 L
.78463 .29398 L
.78466 .28539 L
.78468 .28539 L
.7847 .29398 L
.78472 .30257 L
.78475 .30257 L
.78477 .29828 L
.78479 .28968 L
.78481 .28539 L
.78483 .29398 L
.78486 .30687 L
.78488 .30687 L
.7849 .30257 L
.78492 .29828 L
.78495 .29398 L
.78497 .29828 L
.78499 .30257 L
.78501 .30687 L
.78504 .30687 L
.78506 .29828 L
.78508 .29828 L
.7851 .29828 L
.78512 .30257 L
.78515 .30257 L
.78517 .30257 L
.78519 .29828 L
Mistroke
.78521 .29398 L
.78524 .29828 L
.78526 .30257 L
.78528 .30257 L
.7853 .30257 L
.78533 .29828 L
.78535 .29398 L
.78537 .29398 L
.78539 .30257 L
.78542 .30257 L
.78544 .29828 L
.78546 .29398 L
.78548 .29398 L
.7855 .29398 L
.78553 .30257 L
.78555 .30257 L
.78557 .29398 L
.78559 .28968 L
.78562 .28968 L
.78564 .29828 L
.78566 .30687 L
.78568 .30257 L
.78571 .29398 L
.78573 .29398 L
.78575 .28539 L
.78577 .28968 L
.78579 .29828 L
.78582 .30257 L
.78584 .28968 L
.78586 .2682 L
.78588 .2725 L
.78591 .27679 L
.78593 .28539 L
.78595 .29398 L
.78597 .28539 L
.786 .28109 L
.78602 .28968 L
.78604 .29398 L
.78606 .29828 L
.78608 .30257 L
.78611 .30687 L
.78613 .30257 L
.78615 .30257 L
.78617 .31546 L
.7862 .32405 L
.78622 .31976 L
.78624 .31117 L
.78626 .30687 L
.78629 .29828 L
.78631 .30687 L
Mistroke
.78633 .31117 L
.78635 .30687 L
.78638 .30257 L
.7864 .28968 L
.78642 .28109 L
.78644 .27679 L
.78646 .28968 L
.78649 .29398 L
.78651 .28539 L
.78653 .27679 L
.78655 .27679 L
.78658 .27679 L
.7866 .28109 L
.78662 .29398 L
.78664 .29398 L
.78667 .28109 L
.78669 .2725 L
.78671 .28539 L
.78673 .29828 L
.78675 .31117 L
.78678 .32835 L
.7868 .30687 L
.78682 .28109 L
.78684 .28109 L
.78687 .28539 L
.78689 .31117 L
.78691 .30687 L
.78693 .30687 L
.78696 .29828 L
.78698 .29828 L
.787 .28968 L
.78702 .29828 L
.78705 .29828 L
.78707 .29398 L
.78709 .29398 L
.78711 .29398 L
.78713 .30257 L
.78716 .30257 L
.78718 .30257 L
.7872 .29828 L
.78722 .28539 L
.78725 .27679 L
.78727 .28109 L
.78729 .28968 L
.78731 .28968 L
.78734 .28539 L
.78736 .28539 L
.78738 .27679 L
.7874 .28109 L
.78742 .29398 L
Mistroke
.78745 .30257 L
.78747 .30257 L
.78749 .28968 L
.78751 .28539 L
.78754 .28539 L
.78756 .28109 L
.78758 .28109 L
.7876 .28968 L
.78763 .28109 L
.78765 .29828 L
.78767 .29398 L
.78769 .2725 L
.78771 .2725 L
.78774 .28968 L
.78776 .30687 L
.78778 .30257 L
.7878 .30687 L
.78783 .32405 L
.78785 .31117 L
.78787 .31117 L
.78789 .33694 L
.78792 .32835 L
.78794 .28968 L
.78796 .28539 L
.78798 .30257 L
.78801 .29398 L
.78803 .27679 L
.78805 .32835 L
.78807 .36272 L
.78809 .28968 L
.78812 .2682 L
.78814 .31976 L
.78816 .32835 L
.78818 .28539 L
.78821 .28109 L
.78823 .29828 L
.78825 .28539 L
.78827 .29828 L
.7883 .31117 L
.78832 .2725 L
.78834 .26391 L
.78836 .30257 L
.78838 .30687 L
.78841 .28109 L
.78843 .29828 L
.78845 .31117 L
.78847 .26391 L
.7885 .26391 L
.78852 .29398 L
.78854 .29828 L
Mistroke
.78856 .28968 L
.78859 .28539 L
.78861 .28968 L
.78863 .28539 L
.78865 .29828 L
.78868 .30257 L
.7887 .31117 L
.78872 .30257 L
.78874 .28109 L
.78876 .28539 L
.78879 .28968 L
.78881 .29398 L
.78883 .28968 L
.78885 .29398 L
.78888 .32405 L
.7889 .2682 L
.78892 .24672 L
.78894 .28968 L
.78897 .29398 L
.78899 .28968 L
.78901 .2725 L
.78903 .31546 L
.78905 .31117 L
.78908 .2682 L
.7891 .31546 L
.78912 .34983 L
.78914 .32405 L
.78917 .27679 L
.78919 .28968 L
.78921 .28968 L
.78923 .28968 L
.78926 .25531 L
.78928 .27679 L
.7893 .30687 L
.78932 .3842 L
.78934 .31117 L
.78937 .2682 L
.78939 .32835 L
.78941 .33265 L
.78943 .32405 L
.78946 .30257 L
.78948 .32835 L
.7895 .28539 L
.78952 .28539 L
.78955 .34554 L
.78957 .2682 L
.78959 .22094 L
.78961 .24672 L
.78964 .30687 L
.78966 .25531 L
Mistroke
.78968 .24242 L
.7897 .34124 L
.78972 .34554 L
.78975 .2682 L
.78977 .24672 L
.78979 .31546 L
.78981 .31546 L
.78984 .28968 L
.78986 .32835 L
.78988 .33694 L
.7899 .28109 L
.78993 .28539 L
.78995 .32835 L
.78997 .2682 L
.78999 .24672 L
.79001 .31117 L
.79004 .31117 L
.79006 .23813 L
.79008 .25102 L
.7901 .3885 L
.79013 .33265 L
.79015 .22953 L
.79017 .27679 L
.79019 .31976 L
.79022 .28968 L
.79024 .26391 L
.79026 .36702 L
.79028 .33265 L
.79031 .23813 L
.79033 .29398 L
.79035 .31976 L
.79037 .27679 L
.79039 .24242 L
.79042 .34554 L
.79044 .26391 L
.79046 .22953 L
.79048 .3842 L
.79051 .34554 L
.79053 .25531 L
.79055 .21664 L
.79057 .34124 L
.7906 .32405 L
.79062 .27679 L
.79064 .35843 L
.79066 .32405 L
.79068 .2682 L
.79071 .25102 L
.79073 .32835 L
.79075 .25531 L
.79077 .21664 L
Mistroke
.7908 .31117 L
.79082 .25961 L
.79084 .32835 L
.79086 .35413 L
.79089 .31117 L
.79091 .2682 L
.79093 .2725 L
.79095 .37131 L
.79097 .34124 L
.791 .33265 L
.79102 .29398 L
.79104 .25531 L
.79106 .23813 L
.79109 .25961 L
.79111 .30687 L
.79113 .23813 L
.79115 .23813 L
.79118 .30687 L
.7912 .34983 L
.79122 .28968 L
.79124 .29398 L
.79127 .37561 L
.79129 .29398 L
.79131 .29398 L
.79133 .35413 L
.79135 .32405 L
.79138 .23813 L
.7914 .2725 L
.79142 .31117 L
.79144 .2725 L
.79147 .35413 L
.79149 .34983 L
.79151 .25531 L
.79153 .19946 L
.79156 .25531 L
.79158 .25531 L
.7916 .22524 L
.79162 .24672 L
.79164 .37561 L
.79167 .3842 L
.79169 .2725 L
.79171 .25961 L
.79173 .39709 L
.79176 .37991 L
.79178 .31976 L
.7918 .31976 L
.79182 .31976 L
.79185 .28539 L
.79187 .2725 L
.79189 .24242 L
Mistroke
.79191 .16938 L
.79194 .20805 L
.79196 .2682 L
.79198 .30687 L
.792 .30687 L
.79202 .31117 L
.79205 .34554 L
.79207 .37561 L
.79209 .37991 L
.79211 .37561 L
.79214 .35413 L
.79216 .25961 L
.79218 .18227 L
.7922 .20805 L
.79223 .26391 L
.79225 .23383 L
.79227 .25102 L
.79229 .31117 L
.79231 .30257 L
.79234 .30257 L
.79236 .37131 L
.79238 .40139 L
.7924 .30687 L
.79243 .30257 L
.79245 .30257 L
.79247 .22094 L
.79249 .24242 L
.79252 .2725 L
.79254 .23813 L
.79256 .25531 L
.79258 .33265 L
.7926 .31976 L
.79263 .33694 L
.79265 .3928 L
.79267 .35843 L
.79269 .30257 L
.79272 .2725 L
.79274 .24242 L
.79276 .22524 L
.79278 .28968 L
.79281 .27679 L
.79283 .21235 L
.79285 .28109 L
.79287 .36272 L
.7929 .33265 L
.79292 .31976 L
.79294 .40569 L
.79296 .3928 L
.79298 .28539 L
.79301 .24672 L
Mistroke
.79303 .22953 L
.79305 .23383 L
.79307 .26391 L
.7931 .24242 L
.79312 .18657 L
.79314 .30257 L
.79316 .45295 L
.79319 .33265 L
.79321 .34124 L
.79323 .43146 L
.79325 .31117 L
.79327 .17368 L
.7933 .27679 L
.79332 .29398 L
.79334 .1565 L
.79336 .24672 L
.79339 .31546 L
.79341 .28109 L
.79343 .31976 L
.79345 .42287 L
.79348 .3842 L
.7935 .29828 L
.79352 .33265 L
.79354 .2682 L
.79357 .09635 L
.79359 .20376 L
.79361 .41428 L
.79363 .31976 L
.79365 .17368 L
.79368 .28539 L
.7937 .35413 L
.79372 .32405 L
.79374 .3842 L
.79377 .3885 L
.79379 .28968 L
.79381 .28109 L
.79383 .29828 L
.79386 .17368 L
.79388 .17368 L
.7939 .29828 L
.79392 .31117 L
.79394 .31117 L
.79397 .28109 L
.79399 .30687 L
.79401 .34983 L
.79403 .37991 L
.79406 .40569 L
.79408 .3885 L
.7941 .26391 L
.79412 .19516 L
Mistroke
.79415 .19516 L
.79417 .16509 L
.79419 .20805 L
.79421 .28539 L
.79423 .28539 L
.79426 .31546 L
.79428 .40139 L
.7943 .46583 L
.79432 .40139 L
.79435 .37561 L
.79437 .3842 L
.79439 .2725 L
.79441 .10064 L
.79444 .09635 L
.79446 .17798 L
.79448 .19946 L
.7945 .23383 L
.79453 .32835 L
.79455 .37991 L
.79457 .3842 L
.79459 .49591 L
.79461 .52169 L
.79464 .37561 L
.79466 .23813 L
.79468 .17798 L
.7947 .10064 L
.79473 .1522 L
.79475 .22094 L
.79477 .1522 L
.79479 .18227 L
.79482 .37991 L
.79484 .47872 L
.79486 .43146 L
.79488 .44006 L
.7949 .47013 L
.79493 .39709 L
.79495 .28539 L
.79497 .14361 L
.79499 .04909 L
.79502 .11353 L
.79504 .22094 L
.79506 .21235 L
.79508 .24672 L
.79511 .40998 L
.79513 .48302 L
.79515 .46583 L
.79517 .51309 L
.7952 .44865 L
.79522 .17798 L
.79524 .12642 L
Mistroke
.79526 .19087 L
.79528 .10924 L
.79531 .10494 L
.79533 .20805 L
.79535 .25102 L
.79537 .36272 L
.7954 .52598 L
.79542 .48302 L
.79544 .42717 L
.79546 .47013 L
.79549 .42717 L
.79551 .18657 L
.79553 .0362 L
.79555 .07916 L
.79557 .13072 L
.7956 .20376 L
.79562 .26391 L
.79564 .31117 L
.79566 .41428 L
.79569 .47872 L
.79571 .51739 L
.79573 .48302 L
.79575 .39709 L
.79578 .23813 L
.7958 .14361 L
.79582 .09635 L
.79584 .08346 L
.79586 .13931 L
.79589 .22524 L
.79591 .29828 L
.79593 .37561 L
.79595 .48732 L
.79598 .52598 L
.796 .44006 L
.79602 .41857 L
.79604 .36272 L
.79607 .1522 L
.79609 .05338 L
.79611 .10924 L
.79613 .13931 L
.79616 .19516 L
.79618 .28539 L
.7962 .34983 L
.79622 .46154 L
.79624 .51739 L
.79627 .49591 L
.79629 .46154 L
.79631 .46154 L
.79633 .34554 L
.79636 .1522 L
Mistroke
.79638 .06627 L
.7964 .10494 L
.79642 .13072 L
.79645 .19516 L
.79647 .29828 L
.79649 .37561 L
.79651 .44006 L
.79653 .5088 L
.79656 .49161 L
.79658 .41428 L
.7966 .34124 L
.79662 .25102 L
.79665 .10494 L
.79667 .07916 L
.79669 .13501 L
.79671 .19946 L
.79674 .2725 L
.79676 .36702 L
.79678 .3842 L
.7968 .46154 L
.79682 .53887 L
.79685 .45295 L
.79687 .32405 L
.79689 .21664 L
.79691 .10924 L
.79694 .08346 L
.79696 .16079 L
.79698 .19946 L
.797 .25961 L
.79703 .36272 L
.79705 .45295 L
.79707 .45724 L
.79709 .46583 L
.79712 .45724 L
.79714 .32835 L
.79716 .17798 L
.79718 .13931 L
.7972 .11353 L
.79723 .11783 L
.79725 .20805 L
.79727 .29828 L
.79729 .35413 L
.79732 .3928 L
.79734 .47872 L
.79736 .5045 L
.79738 .40569 L
.79741 .31117 L
.79743 .20376 L
.79745 .11353 L
.79747 .11783 L
Mistroke
.79749 .16938 L
.79752 .20376 L
.79754 .30257 L
.79756 .40139 L
.79758 .41857 L
.79761 .44865 L
.79763 .51309 L
.79765 .43146 L
.79767 .24242 L
.7977 .1479 L
.79772 .14361 L
.79774 .12642 L
.79776 .16938 L
.79779 .25102 L
.79781 .34124 L
.79783 .40139 L
.79785 .45724 L
.79787 .47443 L
.7979 .42717 L
.79792 .33265 L
.79794 .2682 L
.79796 .17368 L
.79799 .10494 L
.79801 .14361 L
.79803 .21235 L
.79805 .2725 L
.79808 .34124 L
.7981 .41857 L
.79812 .41857 L
.79814 .43146 L
.79816 .46154 L
.79819 .37991 L
.79821 .19087 L
.79823 .09205 L
.79825 .12642 L
.79828 .16509 L
.7983 .21235 L
.79832 .29398 L
.79834 .3928 L
.79837 .44006 L
.79839 .47013 L
.79841 .44435 L
.79843 .35843 L
.79845 .24242 L
.79848 .19087 L
.7985 .12642 L
.79852 .11353 L
.79854 .18227 L
.79857 .26391 L
.79859 .34124 L
Mistroke
.79861 .41857 L
.79863 .44006 L
.79866 .41428 L
.79868 .41428 L
.7987 .44006 L
.79872 .3885 L
.79875 .20805 L
.79877 .09635 L
.79879 .12212 L
.79881 .16509 L
.79883 .22953 L
.79886 .29398 L
.79888 .37131 L
.7989 .43576 L
.79892 .48732 L
.79895 .47013 L
.79897 .36272 L
.79899 .22953 L
.79901 .1522 L
.79904 .1522 L
.79906 .14361 L
.79908 .19087 L
.7991 .25961 L
.79912 .34554 L
.79915 .42287 L
.79917 .45295 L
.79919 .44435 L
.79921 .42717 L
.79924 .32405 L
.79926 .20376 L
.79928 .11783 L
.7993 .10924 L
.79933 .1565 L
.79935 .2725 L
.79937 .30687 L
.79939 .34124 L
.79942 .42717 L
.79944 .47013 L
.79946 .45295 L
.79948 .36702 L
.7995 .24672 L
.79953 .12212 L
.79955 .12212 L
.79957 .16509 L
.79959 .20376 L
.79962 .27679 L
.79964 .33265 L
.79966 .40569 L
.79968 .43146 L
.79971 .42717 L
Mistroke
.79973 .42287 L
.79975 .31546 L
.79977 .16079 L
.79979 .11783 L
.79982 .16079 L
.79984 .16079 L
.79986 .25102 L
.79988 .34124 L
.79991 .35413 L
.79993 .3928 L
.79995 .46154 L
.79997 .48732 L
.8 .33694 L
.80002 .20376 L
.80004 .13501 L
.80006 .13072 L
.80008 .16938 L
.80011 .25961 L
.80013 .31117 L
.80015 .34124 L
.80017 .40569 L
.8002 .47443 L
.80022 .48302 L
.80024 .36702 L
.80026 .19087 L
.80029 .13072 L
.80031 .16509 L
.80033 .18657 L
.80035 .23813 L
.80038 .31976 L
.8004 .37561 L
.80042 .36702 L
.80044 .37991 L
.80046 .40998 L
.80049 .43576 L
.80051 .34124 L
.80053 .16938 L
.80055 .12642 L
.80058 .17368 L
.8006 .22094 L
.80062 .28539 L
.80064 .37131 L
.80067 .37131 L
.80069 .35843 L
.80071 .36702 L
.80073 .36702 L
.80075 .2682 L
.80078 .25961 L
.8008 .2725 L
.80082 .20376 L
Mistroke
.80084 .20805 L
.80087 .31976 L
.80089 .31976 L
.80091 .28109 L
.80093 .33265 L
.80096 .32405 L
.80098 .27679 L
.801 .32835 L
.80102 .32835 L
.80105 .32835 L
.80107 .22953 L
.80109 .2725 L
.80111 .35843 L
.80113 .31117 L
.80116 .23813 L
.80118 .24242 L
.8012 .22094 L
.80122 .23383 L
.80125 .34124 L
.80127 .40569 L
.80129 .40139 L
.80131 .3842 L
.80134 .30257 L
.80136 .22953 L
.80138 .23813 L
.8014 .25961 L
.80142 .22953 L
.80145 .26391 L
.80147 .31117 L
.80149 .31117 L
.80151 .30257 L
.80154 .34983 L
.80156 .36272 L
.80158 .36702 L
.8016 .37991 L
.80163 .30257 L
.80165 .19516 L
.80167 .18227 L
.80169 .23383 L
.80171 .26391 L
.80174 .31117 L
.80176 .36702 L
.80178 .37561 L
.8018 .37131 L
.80183 .29828 L
.80185 .22094 L
.80187 .22953 L
.80189 .28109 L
.80192 .25961 L
.80194 .33694 L
Mistroke
.80196 .37561 L
.80198 .24672 L
.80201 .28109 L
.80203 .34983 L
.80205 .2725 L
.80207 .22524 L
.80209 .30687 L
.80212 .29828 L
.80214 .26391 L
.80216 .30257 L
.80218 .32405 L
.80221 .32835 L
.80223 .37561 L
.80225 .30687 L
.80227 .19516 L
.8023 .16938 L
.80232 .22094 L
.80234 .24672 L
.80236 .33265 L
.80238 .41428 L
.80241 .3928 L
.80243 .3885 L
.80245 .34124 L
.80247 .26391 L
.8025 .16938 L
.80252 .16938 L
.80254 .19946 L
.80256 .26391 L
.80259 .37131 L
.80261 .40139 L
.80263 .37561 L
.80265 .31117 L
.80268 .28968 L
.8027 .42287 L
.80272 .37991 L
.80274 .16079 L
.80276 .10064 L
.80279 .21664 L
.80281 .25961 L
.80283 .31546 L
.80285 .43576 L
.80288 .39709 L
.8029 .32405 L
.80292 .33694 L
.80294 .41857 L
.80297 .25531 L
.80299 .10924 L
.80301 .14361 L
.80303 .25531 L
.80305 .2725 L
Mistroke
.80308 .37561 L
.8031 .40569 L
.80312 .37131 L
.80314 .31546 L
.80317 .25102 L
.80319 .28539 L
.80321 .33265 L
.80323 .27679 L
.80326 .16509 L
.80328 .21235 L
.8033 .31546 L
.80332 .37131 L
.80334 .36702 L
.80337 .37131 L
.80339 .30257 L
.80341 .30257 L
.80343 .25102 L
.80346 .21235 L
.80348 .23813 L
.8035 .25102 L
.80352 .28539 L
.80355 .29398 L
.80357 .25102 L
.80359 .34554 L
.80361 .47013 L
.80364 .37561 L
.80366 .17798 L
.80368 .20376 L
.8037 .25531 L
.80372 .2725 L
.80375 .35843 L
.80377 .34554 L
.80379 .2725 L
.80381 .28968 L
.80384 .34554 L
.80386 .28539 L
.80388 .24242 L
.8039 .2682 L
.80393 .31976 L
.80395 .35413 L
.80397 .31117 L
.80399 .28109 L
.80401 .24672 L
.80404 .31546 L
.80406 .34554 L
.80408 .31546 L
.8041 .27679 L
.80413 .30687 L
.80415 .28109 L
.80417 .28539 L
Mistroke
.80419 .33265 L
.80422 .32405 L
.80424 .28109 L
.80426 .30687 L
.80428 .30257 L
.80431 .16079 L
.80433 .21235 L
.80435 .30687 L
.80437 .42287 L
.80439 .48302 L
.80442 .30257 L
.80444 .22094 L
.80446 .19087 L
.80448 .28539 L
.80451 .2725 L
.80453 .25531 L
.80455 .32835 L
.80457 .31117 L
.8046 .37561 L
.80462 .35843 L
.80464 .29398 L
.80466 .19516 L
.80468 .19516 L
.80471 .28109 L
.80473 .31117 L
.80475 .32835 L
.80477 .30687 L
.8048 .37131 L
.80482 .37131 L
.80484 .27679 L
.80486 .25961 L
.80489 .24672 L
.80491 .24672 L
.80493 .24242 L
.80495 .27679 L
.80497 .30257 L
.805 .33265 L
.80502 .40998 L
.80504 .31976 L
.80506 .29828 L
.80509 .35843 L
.80511 .25961 L
.80513 .17798 L
.80515 .16509 L
.80518 .2682 L
.8052 .30257 L
.80522 .39709 L
.80524 .49161 L
.80527 .34554 L
.80529 .30257 L
Mistroke
.80531 .24242 L
.80533 .24242 L
.80535 .20376 L
.80538 .25102 L
.8054 .31976 L
.80542 .29398 L
.80544 .34983 L
.80547 .34124 L
.80549 .31546 L
.80551 .27679 L
.80553 .28109 L
.80556 .40569 L
.80558 .32405 L
.8056 .1565 L
.80562 .22953 L
.80564 .30257 L
.80567 .31546 L
.80569 .32405 L
.80571 .3842 L
.80573 .31976 L
.80576 .31976 L
.80578 .25531 L
.8058 .26391 L
.80582 .23383 L
.80585 .25102 L
.80587 .30687 L
.80589 .31117 L
.80591 .25961 L
.80594 .34554 L
.80596 .46154 L
.80598 .32835 L
.806 .16509 L
.80602 .20376 L
.80605 .27679 L
.80607 .24672 L
.80609 .34554 L
.80611 .37131 L
.80614 .31546 L
.80616 .30257 L
.80618 .2725 L
.8062 .2682 L
.80623 .2682 L
.80625 .31546 L
.80627 .3885 L
.80629 .2682 L
.80631 .24242 L
.80634 .29828 L
.80636 .32835 L
.80638 .2725 L
.8064 .2725 L
Mistroke
.80643 .32835 L
.80645 .29398 L
.80647 .32835 L
.80649 .28539 L
.80652 .34124 L
.80654 .41428 L
.80656 .29398 L
.80658 .21235 L
.8066 .22094 L
.80663 .24672 L
.80665 .18657 L
.80667 .30687 L
.80669 .44865 L
.80672 .47443 L
.80674 .41428 L
.80676 .26391 L
.80678 .16079 L
.80681 .12642 L
.80683 .22953 L
.80685 .28109 L
.80687 .35843 L
.8069 .40569 L
.80692 .39709 L
.80694 .28968 L
.80696 .22953 L
.80698 .35843 L
.80701 .35413 L
.80703 .18657 L
.80705 .16938 L
.80707 .22953 L
.8071 .33694 L
.80712 .35843 L
.80714 .40998 L
.80716 .37131 L
.80719 .23813 L
.80721 .1522 L
.80723 .23813 L
.80725 .33265 L
.80727 .34983 L
.8073 .29828 L
.80732 .28968 L
.80734 .33694 L
.80736 .30687 L
.80739 .28539 L
.80741 .2682 L
.80743 .24672 L
.80745 .22953 L
.80748 .28109 L
.8075 .33694 L
.80752 .32405 L
Mistroke
.80754 .2725 L
.80757 .36702 L
.80759 .39709 L
.80761 .2682 L
.80763 .22524 L
.80765 .28539 L
.80768 .25531 L
.8077 .23383 L
.80772 .2725 L
.80774 .35843 L
.80777 .35413 L
.80779 .35843 L
.80781 .28968 L
.80783 .24672 L
.80786 .36272 L
.80788 .35413 L
.8079 .19516 L
.80792 .19087 L
.80794 .27679 L
.80797 .30257 L
.80799 .30257 L
.80801 .35843 L
.80803 .35843 L
.80806 .28539 L
.80808 .28539 L
.8081 .32405 L
.80812 .32405 L
.80815 .31976 L
.80817 .24672 L
.80819 .23383 L
.80821 .2725 L
.80823 .29828 L
.80826 .29828 L
.80828 .2725 L
.8083 .29828 L
.80832 .30687 L
.80835 .28539 L
.80837 .28539 L
.80839 .36702 L
.80841 .36272 L
.80844 .25961 L
.80846 .22094 L
.80848 .24242 L
.8085 .28968 L
.80853 .31976 L
.80855 .30257 L
.80857 .25961 L
.80859 .23813 L
.80861 .34124 L
.80864 .32405 L
Mistroke
.80866 .26391 L
.80868 .37561 L
.8087 .37131 L
.80873 .25531 L
.80875 .23383 L
.80877 .22524 L
.80879 .24672 L
.80882 .23383 L
.80884 .25961 L
.80886 .39709 L
.80888 .36702 L
.8089 .40139 L
.80893 .40998 L
.80895 .27679 L
.80897 .19946 L
.80899 .13072 L
.80902 .20376 L
.80904 .31546 L
.80906 .34983 L
.80908 .36272 L
.80911 .33265 L
.80913 .33265 L
.80915 .40139 L
.80917 .37991 L
.8092 .19516 L
.80922 .1479 L
.80924 .18657 L
.80926 .29828 L
.80928 .34124 L
.80931 .39709 L
.80933 .41428 L
.80935 .31117 L
.80937 .17368 L
.8094 .19946 L
.80942 .31117 L
.80944 .32405 L
.80946 .31546 L
.80949 .32405 L
.80951 .35843 L
.80953 .28968 L
.80955 .2725 L
.80957 .2725 L
.8096 .24242 L
.80962 .24672 L
.80964 .24672 L
.80966 .31976 L
.80969 .36272 L
.80971 .31976 L
.80973 .30687 L
.80975 .3885 L
Mistroke
.80978 .37561 L
.8098 .21235 L
.80982 .17798 L
.80984 .20376 L
.80986 .22094 L
.80989 .28109 L
.80991 .34983 L
.80993 .43146 L
.80995 .3885 L
.80998 .28968 L
.81 .27679 L
.81002 .34983 L
.81004 .2682 L
.81007 .12212 L
.81009 .16938 L
.81011 .31117 L
.81013 .41857 L
.81016 .35413 L
.81018 .33694 L
.8102 .39709 L
.81022 .31976 L
.81024 .24672 L
.81027 .19516 L
.81029 .23813 L
.81031 .30687 L
.81033 .32405 L
.81036 .31546 L
.81038 .33265 L
.8104 .3842 L
.81042 .34983 L
.81045 .25531 L
.81047 .20805 L
.81049 .20805 L
.81051 .20805 L
.81053 .2682 L
.81056 .31976 L
.81058 .30257 L
.8106 .40139 L
.81062 .46583 L
.81065 .32405 L
.81067 .22094 L
.81069 .18227 L
.81071 .19087 L
.81074 .21664 L
.81076 .26391 L
.81078 .35413 L
.8108 .39709 L
.81083 .39709 L
.81085 .32835 L
.81087 .40139 L
Mistroke
.81089 .28968 L
.81091 .1522 L
.81094 .14361 L
.81096 .21664 L
.81098 .31117 L
.811 .28109 L
.81103 .36272 L
.81105 .40139 L
.81107 .45724 L
.81109 .41428 L
.81112 .16938 L
.81114 .09205 L
.81116 .14361 L
.81118 .28539 L
.8112 .31546 L
.81123 .3842 L
.81125 .41428 L
.81127 .31976 L
.81129 .23813 L
.81132 .26391 L
.81134 .47013 L
.81136 .22953 L
.81138 .11353 L
.81141 .20376 L
.81143 .31546 L
.81145 .41857 L
.81147 .35843 L
.81149 .39709 L
.81152 .3885 L
.81154 .25531 L
.81156 .13501 L
.81158 .12642 L
.81161 .25961 L
.81163 .40569 L
.81165 .37131 L
.81167 .32405 L
.8117 .47013 L
.81172 .3842 L
.81174 .17368 L
.81176 .22524 L
.81179 .12642 L
.81181 .21664 L
.81183 .2682 L
.81185 .35413 L
.81187 .47872 L
.8119 .3928 L
.81192 .31546 L
.81194 .27679 L
.81196 .29398 L
.81199 .25102 L
Mistroke
.81201 .13072 L
.81203 .1565 L
.81205 .28968 L
.81208 .42287 L
.8121 .42717 L
.81212 .3928 L
.81214 .32405 L
.81216 .25961 L
.81219 .22524 L
.81221 .19516 L
.81223 .19516 L
.81225 .22094 L
.81228 .34554 L
.8123 .40998 L
.81232 .3928 L
.81234 .37561 L
.81237 .2725 L
.81239 .19516 L
.81241 .18227 L
.81243 .23383 L
.81245 .26391 L
.81248 .29398 L
.8125 .33694 L
.81252 .35843 L
.81254 .43576 L
.81257 .40139 L
.81259 .24242 L
.81261 .12642 L
.81263 .18657 L
.81266 .28109 L
.81268 .33265 L
.8127 .34983 L
.81272 .35413 L
.81275 .33265 L
.81277 .29398 L
.81279 .25961 L
.81281 .28109 L
.81283 .43146 L
.81286 .43146 L
.81288 .30257 L
.8129 .18227 L
.81292 .24672 L
.81295 .28109 L
.81297 .27679 L
.81299 .31117 L
.81301 .37131 L
.81304 .35413 L
.81306 .3928 L
.81308 .25102 L
.8131 .28968 L
Mistroke
.81312 .25531 L
.81315 .20805 L
.81317 .28968 L
.81319 .2682 L
.81321 .33265 L
.81324 .29398 L
.81326 .2682 L
.81328 .2682 L
.8133 .5045 L
.81333 .40569 L
.81335 .10924 L
.81337 .16509 L
.81339 .17368 L
.81342 .32835 L
.81344 .35843 L
.81346 .39709 L
.81348 .40569 L
.8135 .35843 L
.81353 .1565 L
.81355 .13931 L
.81357 .26391 L
.81359 .29398 L
.81362 .3928 L
.81364 .35413 L
.81366 .31546 L
.81368 .34124 L
.81371 .2725 L
.81373 .24672 L
.81375 .21664 L
.81377 .20376 L
.81379 .27679 L
.81382 .36272 L
.81384 .33694 L
.81386 .3842 L
.81388 .40139 L
.81391 .29828 L
.81393 .22953 L
.81395 .20376 L
.81397 .21664 L
.814 .24672 L
.81402 .28539 L
.81404 .36272 L
.81406 .42287 L
.81408 .3842 L
.81411 .30257 L
.81413 .32405 L
.81415 .25531 L
.81417 .14361 L
.8142 .21664 L
.81422 .32835 L
Mistroke
.81424 .37131 L
.81426 .40139 L
.81429 .30257 L
.81431 .2725 L
.81433 .31117 L
.81435 .25961 L
.81438 .20805 L
.8144 .22524 L
.81442 .32405 L
.81444 .42717 L
.81446 .36272 L
.81449 .25531 L
.81451 .27679 L
.81453 .23813 L
.81455 .25531 L
.81458 .25961 L
.8146 .2682 L
.81462 .34983 L
.81464 .35413 L
.81467 .29828 L
.81469 .29398 L
.81471 .31546 L
.81473 .32405 L
.81475 .25102 L
.81478 .21235 L
.8148 .24242 L
.81482 .29828 L
.81484 .31117 L
.81487 .29828 L
.81489 .31546 L
.81491 .30687 L
.81493 .25961 L
.81496 .28109 L
.81498 .37561 L
.815 .31546 L
.81502 .22094 L
.81505 .28109 L
.81507 .28539 L
.81509 .30687 L
.81511 .2725 L
.81513 .24242 L
.81516 .29398 L
.81518 .33265 L
.8152 .31976 L
.81522 .31976 L
.81525 .33694 L
.81527 .40998 L
.81529 .2725 L
.81531 .25531 L
.81534 .23383 L
Mistroke
.81536 .24672 L
.81538 .28968 L
.8154 .30687 L
.81542 .28539 L
.81545 .29398 L
.81547 .36272 L
.81549 .43146 L
.81551 .42287 L
.81554 .22094 L
.81556 .12642 L
.81558 .18657 L
.8156 .23813 L
.81563 .34124 L
.81565 .3885 L
.81567 .34983 L
.81569 .32835 L
.81571 .34554 L
.81574 .39709 L
.81576 .23813 L
.81578 .10924 L
.8158 .17798 L
.81583 .28968 L
.81585 .36702 L
.81587 .41428 L
.81589 .42287 L
.81592 .33265 L
.81594 .18657 L
.81596 .10924 L
.81598 .21235 L
.81601 .30257 L
.81603 .35413 L
.81605 .44865 L
.81607 .3928 L
.81609 .21664 L
.81612 .26391 L
.81614 .25531 L
.81616 .21664 L
.81618 .25531 L
.81621 .25961 L
.81623 .30687 L
.81625 .34124 L
.81627 .37991 L
.8163 .29828 L
.81632 .36702 L
.81634 .32405 L
.81636 .20376 L
.81638 .23813 L
.81641 .22524 L
.81643 .26391 L
.81645 .31546 L
Mistroke
.81647 .34124 L
.8165 .37991 L
.81652 .3842 L
.81654 .32405 L
.81656 .30687 L
.81659 .2682 L
.81661 .19087 L
.81663 .22953 L
.81665 .25531 L
.81668 .34983 L
.8167 .39709 L
.81672 .31976 L
.81674 .34983 L
.81676 .32835 L
.81679 .24242 L
.81681 .22094 L
.81683 .20805 L
.81685 .24672 L
.81688 .3885 L
.8169 .43146 L
.81692 .32835 L
.81694 .24672 L
.81697 .23813 L
.81699 .27679 L
.81701 .35413 L
.81703 .30687 L
.81705 .20805 L
.81708 .28109 L
.8171 .2725 L
.81712 .28109 L
.81714 .31117 L
.81717 .25102 L
.81719 .41857 L
.81721 .5045 L
.81723 .20376 L
.81726 .10494 L
.81728 .18227 L
.8173 .26391 L
.81732 .31117 L
.81734 .34124 L
.81737 .34124 L
.81739 .36272 L
.81741 .34554 L
.81743 .42287 L
.81746 .29828 L
.81748 .09635 L
.8175 .16509 L
.81752 .28109 L
.81755 .34554 L
.81757 .32405 L
Mistroke
.81759 .32405 L
.81761 .31546 L
.81764 .39709 L
.81766 .36702 L
.81768 .34554 L
.8177 .31117 L
.81772 .17368 L
.81775 .16509 L
.81777 .25961 L
.81779 .32405 L
.81781 .39709 L
.81784 .37991 L
.81786 .32405 L
.81788 .2725 L
.8179 .30257 L
.81793 .43146 L
.81795 .22094 L
.81797 .14361 L
.81799 .22524 L
.81801 .28539 L
.81804 .3842 L
.81806 .39709 L
.81808 .3885 L
.8181 .37131 L
.81813 .24242 L
.81815 .07916 L
.81817 .19946 L
.81819 .33265 L
.81822 .34124 L
.81824 .3842 L
.81826 .45724 L
.81828 .31546 L
.81831 .23813 L
.81833 .24242 L
.81835 .1522 L
.81837 .2725 L
.81839 .28539 L
.81842 .25102 L
.81844 .36702 L
.81846 .42287 L
.81848 .32405 L
.81851 .32835 L
.81853 .31546 L
.81855 .21235 L
.81857 .17798 L
.8186 .22094 L
.81862 .31546 L
.81864 .34124 L
.81866 .35843 L
.81868 .33265 L
Mistroke
.81871 .34554 L
.81873 .31117 L
.81875 .18227 L
.81877 .22953 L
.8188 .32405 L
.81882 .31546 L
.81884 .30687 L
.81886 .31546 L
.81889 .27679 L
.81891 .30687 L
.81893 .30687 L
.81895 .28539 L
.81897 .32405 L
.819 .29398 L
.81902 .25102 L
.81904 .28968 L
.81906 .35413 L
.81909 .32835 L
.81911 .32405 L
.81913 .28968 L
.81915 .2682 L
.81918 .28109 L
.8192 .30687 L
.81922 .2725 L
.81924 .25961 L
.81927 .30687 L
.81929 .31976 L
.81931 .28968 L
.81933 .25531 L
.81935 .31117 L
.81938 .40998 L
.8194 .34983 L
.81942 .20805 L
.81944 .23813 L
.81947 .25531 L
.81949 .24672 L
.81951 .25531 L
.81953 .29828 L
.81956 .3842 L
.81958 .35413 L
.8196 .29828 L
.81962 .35843 L
.81964 .31546 L
.81967 .20805 L
.81969 .19516 L
.81971 .22953 L
.81973 .27679 L
.81976 .29398 L
.81978 .26391 L
.8198 .35413 L
Mistroke
.81982 .47443 L
.81985 .47443 L
.81987 .20376 L
.81989 .07486 L
.81991 .14361 L
.81994 .24242 L
.81996 .24242 L
.81998 .33694 L
.82 .41428 L
.82002 .42287 L
.82005 .37561 L
.82007 .20376 L
.82009 .1479 L
.82011 .43146 L
.82014 .28539 L
.82016 .1565 L
.82018 .28968 L
.8202 .2682 L
.82023 .37131 L
.82025 .37561 L
.82027 .31976 L
.82029 .35843 L
.82031 .31546 L
.82034 .11353 L
.82036 .16938 L
.82038 .34983 L
.8204 .34554 L
.82043 .37561 L
.82045 .44006 L
.82047 .32405 L
.82049 .18227 L
.82052 .22524 L
.82054 .20805 L
.82056 .2725 L
.82058 .37131 L
.8206 .28968 L
.82063 .30257 L
.82065 .36702 L
.82067 .28109 L
.82069 .25531 L
.82072 .37991 L
.82074 .30687 L
.82076 .20805 L
.82078 .24672 L
.82081 .25961 L
.82083 .28968 L
.82085 .35843 L
.82087 .32405 L
.8209 .29398 L
.82092 .35413 L
Mistroke
.82094 .24242 L
.82096 .19087 L
.82098 .28968 L
.82101 .35413 L
.82103 .35413 L
.82105 .28539 L
.82107 .28539 L
.8211 .2725 L
.82112 .2725 L
.82114 .29828 L
.82116 .25102 L
.82119 .31546 L
.82121 .34554 L
.82123 .28968 L
.82125 .25531 L
.82127 .31117 L
.8213 .37131 L
.82132 .31117 L
.82134 .24672 L
.82136 .2682 L
.82139 .2725 L
.82141 .2682 L
.82143 .30257 L
.82145 .28539 L
.82148 .33694 L
.8215 .33694 L
.82152 .24672 L
.82154 .32405 L
.82157 .41428 L
.82159 .27679 L
.82161 .22953 L
.82163 .29398 L
.82165 .26391 L
.82168 .29828 L
.8217 .28539 L
.82172 .26391 L
.82174 .34983 L
.82177 .35843 L
.82179 .2682 L
.82181 .31976 L
.82183 .36702 L
.82186 .2682 L
.82188 .27679 L
.8219 .25961 L
.82192 .22953 L
.82194 .30257 L
.82197 .22953 L
.82199 .26391 L
.82201 .41428 L
.82203 .48732 L
Mistroke
.82206 .37131 L
.82208 .16079 L
.8221 .13931 L
.82212 .17368 L
.82215 .31546 L
.82217 .35413 L
.82219 .3842 L
.82221 .3842 L
.82223 .31117 L
.82226 .17368 L
.82228 .21664 L
.8223 .40569 L
.82232 .40569 L
.82235 .32405 L
.82237 .25531 L
.82239 .25531 L
.82241 .25531 L
.82244 .37131 L
.82246 .31546 L
.82248 .31546 L
.8225 .32405 L
.82253 .28539 L
.82255 .16938 L
.82257 .19946 L
.82259 .34554 L
.82261 .34983 L
.82264 .32835 L
.82266 .42717 L
.82268 .33694 L
.8227 .17368 L
.82273 .28968 L
.82275 .21235 L
.82277 .25102 L
.82279 .36702 L
.82282 .2682 L
.82284 .31546 L
.82286 .40998 L
.82288 .2725 L
.8229 .21664 L
.82293 .40998 L
.82295 .31117 L
.82297 .25531 L
.82299 .28109 L
.82302 .16509 L
.82304 .2725 L
.82306 .3842 L
.82308 .34554 L
.82311 .31976 L
.82313 .35413 L
.82315 .29398 L
Mistroke
.82317 .29828 L
.8232 .25961 L
.82322 .1479 L
.82324 .25102 L
.82326 .34983 L
.82328 .35843 L
.82331 .36272 L
.82333 .31546 L
.82335 .2725 L
.82337 .28109 L
.8234 .24672 L
.82342 .22094 L
.82344 .24242 L
.82346 .29828 L
.82349 .39709 L
.82351 .43146 L
.82353 .30687 L
.82355 .21664 L
.82357 .25531 L
.8236 .24672 L
.82362 .25102 L
.82364 .35843 L
.82366 .30257 L
.82369 .31976 L
.82371 .29828 L
.82373 .19087 L
.82375 .28968 L
.82378 .2682 L
.8238 .37131 L
.82382 .5045 L
.82384 .25102 L
.82386 .17368 L
.82389 .25102 L
.82391 .24242 L
.82393 .25531 L
.82395 .30257 L
.82398 .31117 L
.824 .37991 L
.82402 .34554 L
.82404 .25102 L
.82407 .41428 L
.82409 .41428 L
.82411 .17368 L
.82413 .1522 L
.82416 .19946 L
.82418 .2725 L
.8242 .29828 L
.82422 .32835 L
.82424 .43576 L
.82427 .51739 L
Mistroke
.82429 .36272 L
.82431 .11353 L
.82433 .10924 L
.82436 .19946 L
.82438 .28109 L
.8244 .3842 L
.82442 .3928 L
.82445 .41857 L
.82447 .36702 L
.82449 .16079 L
.82451 .14361 L
.82453 .25102 L
.82456 .3928 L
.82458 .3885 L
.8246 .25961 L
.82462 .28109 L
.82465 .28968 L
.82467 .28968 L
.82469 .31546 L
.82471 .31546 L
.82474 .31117 L
.82476 .25102 L
.82478 .25102 L
.8248 .21235 L
.82483 .28968 L
.82485 .3928 L
.82487 .30257 L
.82489 .32405 L
.82491 .37991 L
.82494 .31117 L
.82496 .25531 L
.82498 .21664 L
.825 .18227 L
.82503 .27679 L
.82505 .31117 L
.82507 .32405 L
.82509 .35843 L
.82512 .41857 L
.82514 .36702 L
.82516 .22953 L
.82518 .24672 L
.8252 .1565 L
.82523 .23813 L
.82525 .31976 L
.82527 .31546 L
.82529 .35413 L
.82532 .3842 L
.82534 .30687 L
.82536 .25102 L
.82538 .29398 L
Mistroke
.82541 .34554 L
.82543 .28109 L
.82545 .18227 L
.82547 .28109 L
.82549 .33694 L
.82552 .35843 L
.82554 .34554 L
.82556 .31117 L
.82558 .31976 L
.82561 .28539 L
.82563 .19516 L
.82565 .21235 L
.82567 .30687 L
.8257 .30687 L
.82572 .31546 L
.82574 .41428 L
.82576 .44435 L
.82579 .23813 L
.82581 .16509 L
.82583 .25531 L
.82585 .24672 L
.82587 .2682 L
.8259 .29828 L
.82592 .29398 L
.82594 .40998 L
.82596 .36702 L
.82599 .22953 L
.82601 .23813 L
.82603 .42717 L
.82605 .34554 L
.82608 .16938 L
.8261 .18657 L
.82612 .19087 L
.82614 .31546 L
.82616 .37131 L
.82619 .37991 L
.82621 .42287 L
.82623 .40139 L
.82625 .19516 L
.82628 .19516 L
.8263 .20805 L
.82632 .17798 L
.82634 .34554 L
.82637 .3842 L
.82639 .34124 L
.82641 .33694 L
.82643 .25961 L
.82646 .25102 L
.82648 .31117 L
.8265 .40139 L
Mistroke
.82652 .24672 L
.82654 .20376 L
.82657 .2725 L
.82659 .30687 L
.82661 .37131 L
.82663 .33694 L
.82666 .30257 L
.82668 .31117 L
.8267 .28539 L
.82672 .18227 L
.82675 .24242 L
.82677 .31117 L
.82679 .31117 L
.82681 .35413 L
.82683 .41857 L
.82686 .36702 L
.82688 .22953 L
.8269 .27679 L
.82692 .23383 L
.82695 .19946 L
.82697 .28539 L
.82699 .29398 L
.82701 .31117 L
.82704 .31117 L
.82706 .3885 L
.82708 .30257 L
.8271 .28109 L
.82712 .41428 L
.82715 .33694 L
.82717 .20805 L
.82719 .16509 L
.82721 .16509 L
.82724 .2725 L
.82726 .34124 L
.82728 .3928 L
.8273 .37561 L
.82733 .45724 L
.82735 .37991 L
.82737 .11783 L
.82739 .16079 L
.82742 .16509 L
.82744 .27679 L
.82746 .37991 L
.82748 .37131 L
.8275 .40139 L
.82753 .41857 L
.82755 .24242 L
.82757 .12212 L
.82759 .19946 L
.82762 .22524 L
Mistroke
.82764 .44865 L
.82766 .40569 L
.82768 .22094 L
.82771 .34983 L
.82773 .29828 L
.82775 .26391 L
.82777 .30257 L
.82779 .28109 L
.82782 .2725 L
.82784 .32835 L
.82786 .24242 L
.82788 .24242 L
.82791 .33265 L
.82793 .31117 L
.82795 .29828 L
.82797 .3928 L
.828 .44006 L
.82802 .20805 L
.82804 .22953 L
.82806 .2725 L
.82809 .19087 L
.82811 .31117 L
.82813 .29398 L
.82815 .31976 L
.82817 .3928 L
.8282 .30687 L
.82822 .20805 L
.82824 .37991 L
.82826 .44435 L
.82829 .23383 L
.82831 .21235 L
.82833 .12642 L
.82835 .23383 L
.82838 .33694 L
.8284 .32405 L
.82842 .3885 L
.82844 .40569 L
.82846 .47013 L
.82849 .19516 L
.82851 .14361 L
.82853 .20376 L
.82855 .19516 L
.82858 .35413 L
.8286 .35413 L
.82862 .33694 L
.82864 .41428 L
.82867 .30687 L
.82869 .18657 L
.82871 .23383 L
.82873 .36702 L
Mistroke
.82875 .34554 L
.82878 .21235 L
.8288 .28539 L
.82882 .28968 L
.82884 .33694 L
.82887 .34554 L
.82889 .31546 L
.82891 .29398 L
.82893 .30257 L
.82896 .22094 L
.82898 .16938 L
.829 .29398 L
.82902 .2725 L
.82905 .33694 L
.82907 .44435 L
.82909 .44865 L
.82911 .2725 L
.82913 .19087 L
.82916 .23383 L
.82918 .19946 L
.8292 .26391 L
.82922 .31546 L
.82925 .31117 L
.82927 .40569 L
.82929 .35843 L
.82931 .22524 L
.82934 .28968 L
.82936 .39709 L
.82938 .31546 L
.8294 .31546 L
.82942 .25961 L
.82945 .19087 L
.82947 .21235 L
.82949 .30257 L
.82951 .31117 L
.82954 .31976 L
.82956 .34983 L
.82958 .45724 L
.8296 .34554 L
.82963 .20805 L
.82965 .19946 L
.82967 .16938 L
.82969 .28539 L
.82971 .29828 L
.82974 .30687 L
.82976 .37131 L
.82978 .3842 L
.8298 .30257 L
.82983 .24672 L
.82985 .25102 L
Mistroke
.82987 .34983 L
.82989 .28968 L
.82992 .21235 L
.82994 .28109 L
.82996 .2725 L
.82998 .35843 L
.83001 .35843 L
.83003 .32835 L
.83005 .33694 L
.83007 .2725 L
.83009 .18657 L
.83012 .19087 L
.83014 .25102 L
.83016 .28968 L
.83018 .35843 L
.83021 .34554 L
.83023 .48302 L
.83025 .34983 L
.83027 .20805 L
.8303 .25531 L
.83032 .13072 L
.83034 .22953 L
.83036 .31117 L
.83038 .30687 L
.83041 .3842 L
.83043 .35413 L
.83045 .30687 L
.83047 .29398 L
.8305 .37131 L
.83052 .3885 L
.83054 .22953 L
.83056 .16079 L
.83059 .1565 L
.83061 .28968 L
.83063 .30257 L
.83065 .37131 L
.83068 .39709 L
.8307 .42287 L
.83072 .41857 L
.83074 .16079 L
.83076 .16509 L
.83079 .16938 L
.83081 .23813 L
.83083 .34124 L
.83085 .32835 L
.83088 .37561 L
.8309 .39709 L
.83092 .2725 L
.83094 .20805 L
.83097 .24672 L
Mistroke
.83099 .36702 L
.83101 .32405 L
.83103 .20805 L
.83105 .2725 L
.83108 .27679 L
.8311 .37131 L
.83112 .31546 L
.83114 .30687 L
.83117 .33694 L
.83119 .28539 L
.83121 .23813 L
.83123 .18227 L
.83126 .22094 L
.83128 .27679 L
.8313 .35413 L
.83132 .35413 L
.83134 .45724 L
.83137 .36702 L
.83139 .19946 L
.83141 .2725 L
.83143 .17368 L
.83146 .19516 L
.83148 .27679 L
.8315 .30687 L
.83152 .3842 L
.83155 .32405 L
.83157 .26391 L
.83159 .29828 L
.83161 .41428 L
.83164 .39709 L
.83166 .23813 L
.83168 .17368 L
.8317 .17368 L
.83172 .24672 L
.83175 .23383 L
.83177 .23383 L
.83179 .32405 L
.83181 .3928 L
.83184 .45295 L
.83186 .45295 L
.83188 .2682 L
.8319 .16938 L
.83193 .1565 L
.83195 .22094 L
.83197 .25102 L
.83199 .29828 L
.83201 .3842 L
.83204 .39709 L
.83206 .31546 L
.83208 .25102 L
Mistroke
.8321 .28109 L
.83213 .42717 L
.83215 .29828 L
.83217 .16938 L
.83219 .22953 L
.83222 .22953 L
.83224 .34983 L
.83226 .34124 L
.83228 .34124 L
.83231 .36272 L
.83233 .35413 L
.83235 .19946 L
.83237 .16509 L
.83239 .23813 L
.83242 .2682 L
.83244 .44006 L
.83246 .40569 L
.83248 .28968 L
.83251 .32405 L
.83253 .29398 L
.83255 .26391 L
.83257 .19946 L
.8326 .19516 L
.83262 .25531 L
.83264 .35413 L
.83266 .36702 L
.83268 .28539 L
.83271 .42287 L
.83273 .37991 L
.83275 .31117 L
.83277 .28968 L
.8328 .11353 L
.83282 .19946 L
.83284 .24242 L
.83286 .2725 L
.83289 .32405 L
.83291 .37131 L
.83293 .43146 L
.83295 .46154 L
.83297 .32405 L
.833 .19946 L
.83302 .17798 L
.83304 .17798 L
.83306 .20805 L
.83309 .2725 L
.83311 .33265 L
.83313 .3928 L
.83315 .37991 L
.83318 .37131 L
.8332 .37561 L
Mistroke
.83322 .36702 L
.83324 .21235 L
.83327 .1522 L
.83329 .17798 L
.83331 .2725 L
.83333 .29828 L
.83335 .33694 L
.83338 .39709 L
.8334 .37991 L
.83342 .28968 L
.83344 .28109 L
.83347 .2682 L
.83349 .28539 L
.83351 .30687 L
.83353 .26391 L
.83356 .25102 L
.83358 .28968 L
.8336 .34554 L
.83362 .31976 L
.83364 .28109 L
.83367 .26391 L
.83369 .30687 L
.83371 .31546 L
.83373 .31976 L
.83376 .29398 L
.83378 .29398 L
.8338 .34124 L
.83382 .29828 L
.83385 .24672 L
.83387 .25531 L
.83389 .26391 L
.83391 .25102 L
.83394 .28109 L
.83396 .33694 L
.83398 .37131 L
.834 .42717 L
.83402 .32835 L
.83405 .2725 L
.83407 .22953 L
.83409 .23813 L
.83411 .22094 L
.83414 .22094 L
.83416 .25102 L
.83418 .32405 L
.8342 .34983 L
.83423 .32405 L
.83425 .28968 L
.83427 .33694 L
.83429 .36272 L
.83431 .40139 L
Mistroke
.83434 .22953 L
.83436 .22953 L
.83438 .25102 L
.8344 .25531 L
.83443 .25961 L
.83445 .25102 L
.83447 .30257 L
.83449 .36272 L
.83452 .37561 L
.83454 .35843 L
.83456 .3842 L
.83458 .26391 L
.8346 .2725 L
.83463 .24672 L
.83465 .19087 L
.83467 .22953 L
.83469 .2682 L
.83472 .31976 L
.83474 .29828 L
.83476 .35413 L
.83478 .35843 L
.83481 .42717 L
.83483 .32835 L
.83485 .26391 L
.83487 .23813 L
.8349 .19946 L
.83492 .21235 L
.83494 .20805 L
.83496 .32405 L
.83498 .34554 L
.83501 .31117 L
.83503 .37561 L
.83505 .33694 L
.83507 .39709 L
.8351 .35413 L
.83512 .19516 L
.83514 .20805 L
.83516 .22953 L
.83519 .26391 L
.83521 .22094 L
.83523 .32835 L
.83525 .31117 L
.83527 .35413 L
.8353 .37991 L
.83532 .30687 L
.83534 .3842 L
.83536 .31117 L
.83539 .31117 L
.83541 .20805 L
.83543 .20376 L
Mistroke
.83545 .21235 L
.83548 .24242 L
.8355 .31117 L
.83552 .2682 L
.83554 .3928 L
.83557 .41857 L
.83559 .42287 L
.83561 .34124 L
.83563 .25531 L
.83565 .24242 L
.83568 .19087 L
.8357 .20376 L
.83572 .20805 L
.83574 .29828 L
.83577 .34554 L
.83579 .30687 L
.83581 .36272 L
.83583 .37991 L
.83586 .3842 L
.83588 .36702 L
.8359 .22524 L
.83592 .19516 L
.83594 .22524 L
.83597 .23383 L
.83599 .19946 L
.83601 .30687 L
.83603 .33694 L
.83606 .31117 L
.83608 .37561 L
.8361 .34983 L
.83612 .3885 L
.83615 .32835 L
.83617 .28109 L
.83619 .21664 L
.83621 .21235 L
.83623 .19087 L
.83626 .21235 L
.83628 .30257 L
.8363 .2725 L
.83632 .35843 L
.83635 .40569 L
.83637 .40569 L
.83639 .3842 L
.83641 .28968 L
.83644 .23813 L
.83646 .22094 L
.83648 .20376 L
.8365 .20376 L
.83653 .18657 L
.83655 .25961 L
Mistroke
.83657 .33265 L
.83659 .29398 L
.83661 .32405 L
.83664 .40139 L
.83666 .3842 L
.83668 .3928 L
.8367 .33694 L
.83673 .23383 L
.83675 .22524 L
.83677 .22094 L
.83679 .16079 L
.83682 .24242 L
.83684 .31546 L
.83686 .28109 L
.83688 .37131 L
.8369 .3885 L
.83693 .3928 L
.83695 .41857 L
.83697 .32405 L
.83699 .22953 L
.83702 .20805 L
.83704 .18227 L
.83706 .17798 L
.83708 .24242 L
.83711 .2725 L
.83713 .31976 L
.83715 .40139 L
.83717 .42287 L
.8372 .40569 L
.83722 .34554 L
.83724 .30257 L
.83726 .27679 L
.83728 .19516 L
.83731 .13931 L
.83733 .21235 L
.83735 .28109 L
.83737 .31117 L
.8374 .28109 L
.83742 .32405 L
.83744 .42717 L
.83746 .42717 L
.83749 .36272 L
.83751 .28109 L
.83753 .2682 L
.83755 .23813 L
.83757 .16509 L
.8376 .1522 L
.83762 .25531 L
.83764 .31546 L
.83766 .30687 L
Mistroke
.83769 .3842 L
.83771 .3885 L
.83773 .36272 L
.83775 .39709 L
.83778 .34124 L
.8378 .24672 L
.83782 .20805 L
.83784 .19087 L
.83786 .19516 L
.83789 .26391 L
.83791 .2682 L
.83793 .28109 L
.83795 .37561 L
.83798 .39709 L
.838 .3842 L
.83802 .36272 L
.83804 .33694 L
.83807 .33694 L
.83809 .26391 L
.83811 .1522 L
.83813 .18227 L
.83816 .25531 L
.83818 .2725 L
.8382 .26391 L
.83822 .31546 L
.83824 .37991 L
.83827 .42287 L
.83829 .41428 L
.83831 .33265 L
.83833 .30257 L
.83836 .28968 L
.83838 .19516 L
.8384 .16079 L
.83842 .20376 L
.83845 .25102 L
.83847 .29398 L
.83849 .34124 L
.83851 .37131 L
.83853 .3842 L
.83856 .37561 L
.83858 .34554 L
.8386 .30687 L
.83862 .28968 L
.83865 .24242 L
.83867 .19516 L
.83869 .20805 L
.83871 .26391 L
.83874 .26391 L
.83876 .2725 L
.83878 .34983 L
Mistroke
.8388 .33694 L
.83883 .35843 L
.83885 .36702 L
.83887 .36702 L
.83889 .33265 L
.83891 .34554 L
.83894 .29828 L
.83896 .22524 L
.83898 .21664 L
.839 .21235 L
.83903 .22094 L
.83905 .2725 L
.83907 .30687 L
.83909 .33694 L
.83912 .36702 L
.83914 .34124 L
.83916 .34124 L
.83918 .35843 L
.8392 .34983 L
.83923 .28109 L
.83925 .22524 L
.83927 .24242 L
.83929 .24242 L
.83932 .22524 L
.83934 .25102 L
.83936 .29398 L
.83938 .32835 L
.83941 .34554 L
.83943 .35843 L
.83945 .34983 L
.83947 .37991 L
.83949 .36272 L
.83952 .26391 L
.83954 .22953 L
.83956 .22524 L
.83958 .20805 L
.83961 .23383 L
.83963 .25531 L
.83965 .29828 L
.83967 .34554 L
.8397 .34983 L
.83972 .32405 L
.83974 .37131 L
.83976 .37131 L
.83979 .31117 L
.83981 .30687 L
.83983 .23813 L
.83985 .22953 L
.83987 .24242 L
.8399 .22524 L
Mistroke
.83992 .25531 L
.83994 .28109 L
.83996 .28109 L
.83999 .31546 L
.84001 .36702 L
.84003 .35413 L
.84005 .3842 L
.84008 .36272 L
.8401 .31546 L
.84012 .2682 L
.84014 .20805 L
.84016 .20805 L
.84019 .22094 L
.84021 .23813 L
.84023 .2682 L
.84025 .29398 L
.84028 .31976 L
.8403 .35843 L
.84032 .3885 L
.84034 .37561 L
.84037 .34554 L
.84039 .32405 L
.84041 .30687 L
.84043 .21235 L
.84046 .17798 L
.84048 .23383 L
.8405 .25961 L
.84052 .25531 L
.84054 .2682 L
.84057 .32405 L
.84059 .36702 L
.84061 .37131 L
.84063 .33265 L
.84066 .33265 L
.84068 .35843 L
.8407 .31976 L
.84072 .23383 L
.84075 .19087 L
.84077 .24672 L
.84079 .2682 L
.84081 .25531 L
.84083 .2725 L
.84086 .29398 L
.84088 .34554 L
.8409 .36272 L
.84092 .33694 L
.84095 .30687 L
.84097 .34124 L
.84099 .34554 L
.84101 .2682 L
Mistroke
.84104 .24672 L
.84106 .23383 L
.84108 .25531 L
.8411 .29828 L
.84112 .26391 L
.84115 .28539 L
.84117 .32835 L
.84119 .32835 L
.84121 .31117 L
.84124 .31117 L
.84126 .29828 L
.84128 .29828 L
.8413 .32835 L
.84133 .31117 L
.84135 .25961 L
.84137 .28539 L
.84139 .27679 L
.84142 .2725 L
.84144 .31546 L
.84146 .28968 L
.84148 .28968 L
.8415 .28539 L
.84153 .28539 L
.84155 .29398 L
.84157 .28968 L
.84159 .28968 L
.84162 .31976 L
.84164 .33694 L
.84166 .30257 L
.84168 .30687 L
.84171 .28539 L
.84173 .28109 L
.84175 .31976 L
.84177 .2725 L
.84179 .26391 L
.84182 .27679 L
.84184 .28109 L
.84186 .29828 L
.84188 .2725 L
.84191 .28109 L
.84193 .33265 L
.84195 .34983 L
.84197 .31546 L
.842 .29398 L
.84202 .31546 L
.84204 .29398 L
.84206 .28109 L
.84209 .2725 L
.84211 .2725 L
.84213 .28109 L
Mistroke
.84215 .27679 L
.84217 .27679 L
.8422 .29828 L
.84222 .31976 L
.84224 .31976 L
.84226 .34124 L
.84229 .32835 L
.84231 .30687 L
.84233 .31117 L
.84235 .26391 L
.84238 .27679 L
.8424 .28968 L
.84242 .25102 L
.84244 .28109 L
.84246 .29398 L
.84249 .29398 L
.84251 .30257 L
.84253 .29828 L
.84255 .31546 L
.84258 .34124 L
.8426 .32405 L
.84262 .29398 L
.84264 .29828 L
.84267 .27679 L
.84269 .25961 L
.84271 .27679 L
.84273 .28109 L
.84275 .29398 L
.84278 .29828 L
.8428 .28539 L
.84282 .30257 L
.84284 .31546 L
.84287 .30257 L
.84289 .31546 L
.84291 .32405 L
.84293 .29398 L
.84296 .28539 L
.84298 .28109 L
.843 .25961 L
.84302 .31117 L
.84305 .30257 L
.84307 .2725 L
.84309 .29828 L
.84311 .28109 L
.84313 .29398 L
.84316 .30257 L
.84318 .29398 L
.8432 .30687 L
.84322 .32405 L
.84325 .31117 L
Mistroke
.84327 .28539 L
.84329 .28539 L
.84331 .28968 L
.84334 .29828 L
.84336 .29828 L
.84338 .25961 L
.8434 .29398 L
.84342 .31117 L
.84345 .29398 L
.84347 .29398 L
.84349 .29398 L
.84351 .31976 L
.84354 .32835 L
.84356 .31546 L
.84358 .31546 L
.8436 .29828 L
.84363 .29828 L
.84365 .30687 L
.84367 .27679 L
.84369 .2682 L
.84372 .29398 L
.84374 .28539 L
.84376 .29398 L
.84378 .29828 L
.8438 .27679 L
.84383 .29828 L
.84385 .30687 L
.84387 .30687 L
.84389 .32405 L
.84392 .31546 L
.84394 .29828 L
.84396 .29398 L
.84398 .25961 L
.84401 .2725 L
.84403 .29398 L
.84405 .2725 L
.84407 .29398 L
.84409 .30257 L
.84412 .28968 L
.84414 .29828 L
.84416 .31117 L
.84418 .30687 L
.84421 .31546 L
.84423 .31117 L
.84425 .28968 L
.84427 .28539 L
.8443 .2725 L
.84432 .2725 L
.84434 .28539 L
.84436 .29398 L
Mistroke
.84438 .29828 L
.84441 .28968 L
.84443 .30257 L
.84445 .28539 L
.84447 .28539 L
.8445 .30257 L
.84452 .29828 L
.84454 .29398 L
.84456 .30257 L
.84459 .29828 L
.84461 .29398 L
.84463 .29828 L
.84465 .27679 L
.84468 .29398 L
.8447 .30687 L
.84472 .29398 L
.84474 .29398 L
.84476 .28539 L
.84479 .30257 L
.84481 .29398 L
.84483 .28539 L
.84485 .31117 L
.84488 .30687 L
.8449 .31117 L
.84492 .31546 L
.84494 .30257 L
.84497 .29398 L
.84499 .29828 L
.84501 .28109 L
.84503 .29398 L
.84505 .30687 L
.84508 .28539 L
.8451 .28539 L
.84512 .29828 L
.84514 .28539 L
.84517 .28539 L
.84519 .30687 L
.84521 .31117 L
.84523 .31546 L
.84526 .31976 L
.84528 .29398 L
.8453 .28539 L
.84532 .28968 L
.84534 .28109 L
.84537 .28539 L
.84539 .28968 L
.84541 .2725 L
.84543 .28968 L
.84546 .28968 L
.84548 .28968 L
Mistroke
.8455 .31117 L
.84552 .31117 L
.84555 .31546 L
.84557 .31117 L
.84559 .29398 L
.84561 .28539 L
.84564 .28109 L
.84566 .28539 L
.84568 .28539 L
.8457 .27679 L
.84572 .28539 L
.84575 .28968 L
.84577 .28539 L
.84579 .29828 L
.84581 .29828 L
.84584 .31117 L
.84586 .31546 L
.84588 .30257 L
.8459 .29828 L
.84593 .28968 L
.84595 .28968 L
.84597 .28539 L
.84599 .28968 L
.84601 .28968 L
.84604 .29828 L
.84606 .30257 L
.84608 .29828 L
.8461 .29398 L
.84613 .30257 L
.84615 .30257 L
.84617 .30687 L
.84619 .30687 L
.84622 .30257 L
.84624 .29828 L
.84626 .29398 L
.84628 .28968 L
.84631 .28968 L
.84633 .29828 L
.84635 .30257 L
.84637 .30257 L
.84639 .30257 L
.84642 .29828 L
.84644 .29398 L
.84646 .28968 L
.84648 .28968 L
.84651 .30257 L
.84653 .29398 L
.84655 .30257 L
.84657 .30257 L
.8466 .29398 L
Mistroke
.84662 .29398 L
.84664 .29398 L
.84666 .29398 L
.84668 .30257 L
.84671 .29828 L
.84673 .29398 L
.84675 .29398 L
.84677 .27679 L
.8468 .27679 L
.84682 .28968 L
.84684 .29398 L
.84686 .30687 L
.84689 .31117 L
.84691 .30257 L
.84693 .28968 L
.84695 .28968 L
.84697 .28539 L
.847 .29828 L
.84702 .29828 L
.84704 .29398 L
.84706 .28968 L
.84709 .28539 L
.84711 .28109 L
.84713 .28968 L
.84715 .29398 L
.84718 .30687 L
.8472 .30687 L
.84722 .29828 L
.84724 .30687 L
.84727 .29828 L
.84729 .29398 L
.84731 .30257 L
.84733 .28968 L
.84735 .29398 L
.84738 .29828 L
.8474 .30257 L
.84742 .29828 L
.84744 .29828 L
.84747 .29828 L
.84749 .29828 L
.84751 .30687 L
.84753 .30687 L
.84756 .30687 L
.84758 .30257 L
.8476 .29398 L
.84762 .28539 L
.84764 .28109 L
.84767 .29398 L
.84769 .29828 L
.84771 .30257 L
Mistroke
.84773 .30687 L
.84776 .30257 L
.84778 .29828 L
.8478 .29828 L
.84782 .29828 L
.84785 .29398 L
.84787 .30257 L
.84789 .29828 L
.84791 .29398 L
.84794 .28539 L
.84796 .28109 L
.84798 .28539 L
.848 .28539 L
.84802 .29828 L
.84805 .29828 L
.84807 .29398 L
.84809 .29828 L
.84811 .28968 L
.84814 .28968 L
.84816 .29398 L
.84818 .30257 L
.8482 .29828 L
.84823 .30257 L
.84825 .29828 L
.84827 .28539 L
.84829 .28109 L
.84831 .28109 L
.84834 .28539 L
.84836 .28539 L
.84838 .29828 L
.8484 .28968 L
.84843 .29398 L
.84845 .29828 L
.84847 .28539 L
.84849 .28968 L
.84852 .29828 L
.84854 .29828 L
.84856 .30257 L
.84858 .30257 L
.8486 .29398 L
.84863 .29398 L
.84865 .28968 L
.84867 .28539 L
.84869 .29398 L
.84872 .29828 L
.84874 .30687 L
.84876 .30257 L
.84878 .30257 L
.84881 .30687 L
.84883 .29828 L
Mistroke
.84885 .29828 L
.84887 .29828 L
.8489 .29828 L
.84892 .29828 L
.84894 .29828 L
.84896 .29398 L
.84898 .28539 L
.84901 .28539 L
.84903 .28968 L
.84905 .29398 L
.84907 .29398 L
.8491 .30687 L
.84912 .30257 L
.84914 .29398 L
.84916 .28968 L
.84919 .28968 L
.84921 .29828 L
.84923 .29828 L
.84925 .29828 L
.84927 .29398 L
.8493 .28968 L
.84932 .28968 L
.84934 .28539 L
.84936 .29398 L
.84939 .30257 L
.84941 .30687 L
.84943 .29828 L
.84945 .29398 L
.84948 .28539 L
.8495 .28539 L
.84952 .28968 L
.84954 .28968 L
.84957 .28968 L
.84959 .29828 L
.84961 .28539 L
.84963 .28539 L
.84965 .28968 L
.84968 .28968 L
.8497 .29398 L
.84972 .29828 L
.84974 .30257 L
.84977 .29828 L
.84979 .29828 L
.84981 .29398 L
.84983 .28968 L
.84986 .29398 L
.84988 .28968 L
.8499 .29828 L
.84992 .29828 L
.84994 .29828 L
Mistroke
.84997 .29398 L
.84999 .29398 L
.85001 .29398 L
.85003 .29828 L
.85006 .30687 L
.85008 .29828 L
.8501 .30687 L
.85012 .30257 L
.85015 .29398 L
.85017 .29398 L
.85019 .28968 L
.85021 .29398 L
.85023 .29828 L
.85026 .29398 L
.85028 .29828 L
.8503 .30257 L
.85032 .29828 L
.85035 .28968 L
.85037 .28968 L
.85039 .29828 L
.85041 .30257 L
.85044 .30687 L
.85046 .30257 L
.85048 .29398 L
.8505 .28539 L
.85053 .28968 L
.85055 .28968 L
.85057 .29828 L
.85059 .30257 L
.85061 .29828 L
.85064 .29828 L
.85066 .29398 L
.85068 .29398 L
.8507 .29398 L
.85073 .29398 L
.85075 .29398 L
.85077 .29828 L
.85079 .29398 L
.85082 .28968 L
.85084 .29398 L
.85086 .28539 L
.85088 .28968 L
.8509 .29398 L
.85093 .29398 L
.85095 .30257 L
.85097 .30257 L
.85099 .29828 L
.85102 .28968 L
.85104 .28968 L
.85106 .28539 L
Mistroke
.85108 .29398 L
.85111 .29828 L
.85113 .30257 L
.85115 .30257 L
.85117 .29398 L
.8512 .29828 L
.85122 .29398 L
.85124 .28968 L
.85126 .30257 L
.85128 .30687 L
.85131 .29398 L
.85133 .30257 L
.85135 .30257 L
.85137 .29398 L
.8514 .29828 L
.85142 .29828 L
.85144 .29828 L
.85146 .29828 L
.85149 .30257 L
.85151 .29828 L
.85153 .29828 L
.85155 .29828 L
.85157 .29398 L
.8516 .29828 L
.85162 .29828 L
.85164 .29828 L
.85166 .29828 L
.85169 .29828 L
.85171 .28968 L
.85173 .29828 L
.85175 .29398 L
.85178 .29828 L
.8518 .30257 L
.85182 .29828 L
.85184 .29398 L
.85186 .29398 L
.85189 .28968 L
.85191 .28968 L
.85193 .29398 L
.85195 .29828 L
.85198 .29828 L
.852 .29398 L
.85202 .29398 L
.85204 .28968 L
.85207 .28539 L
.85209 .29828 L
.85211 .29398 L
.85213 .29398 L
.85216 .28968 L
.85218 .28968 L
Mistroke
.8522 .28968 L
.85222 .28539 L
.85224 .28968 L
.85227 .30257 L
.85229 .30257 L
.85231 .29398 L
.85233 .29828 L
.85236 .28968 L
.85238 .28968 L
.8524 .29398 L
.85242 .29398 L
.85245 .29828 L
.85247 .30257 L
.85249 .29828 L
.85251 .28968 L
.85253 .29828 L
.85256 .29828 L
.85258 .29828 L
.8526 .30257 L
.85262 .29828 L
.85265 .29828 L
.85267 .29828 L
.85269 .29398 L
.85271 .29828 L
.85274 .29398 L
.85276 .29398 L
.85278 .29398 L
.8528 .29828 L
.85283 .30257 L
.85285 .29828 L
.85287 .29828 L
.85289 .29398 L
.85291 .29398 L
.85294 .29398 L
.85296 .29828 L
.85298 .29828 L
.853 .29828 L
.85303 .29398 L
.85305 .29398 L
.85307 .28968 L
.85309 .28968 L
.85312 .28968 L
.85314 .29828 L
.85316 .30257 L
.85318 .29398 L
.8532 .28968 L
.85323 .28968 L
.85325 .28539 L
.85327 .29398 L
.85329 .29398 L
Mistroke
.85332 .30257 L
.85334 .28968 L
.85336 .28968 L
.85338 .28968 L
.85341 .28539 L
.85343 .29398 L
.85345 .29828 L
.85347 .29828 L
.85349 .29398 L
.85352 .29398 L
.85354 .29398 L
.85356 .28968 L
.85358 .29398 L
.85361 .29398 L
.85363 .29828 L
.85365 .29398 L
.85367 .29828 L
.8537 .29398 L
.85372 .29398 L
.85374 .29828 L
.85376 .29828 L
.85379 .29828 L
.85381 .30687 L
.85383 .30257 L
.85385 .29828 L
.85387 .29828 L
.8539 .29398 L
.85392 .29398 L
.85394 .29828 L
.85396 .30257 L
.85399 .29828 L
.85401 .30257 L
.85403 .29398 L
.85405 .29398 L
.85408 .29828 L
.8541 .29828 L
.85412 .30257 L
.85414 .30257 L
.85416 .29828 L
.85419 .29398 L
.85421 .29398 L
.85423 .29398 L
.85425 .28968 L
.85428 .29828 L
.8543 .29828 L
.85432 .29828 L
.85434 .29398 L
.85437 .29398 L
.85439 .29398 L
.85441 .29398 L
Mistroke
.85443 .30257 L
.85446 .29398 L
.85448 .29398 L
.8545 .29398 L
.85452 .28539 L
.85454 .28539 L
.85457 .28968 L
.85459 .29398 L
.85461 .30257 L
.85463 .29828 L
.85466 .29828 L
.85468 .29398 L
.8547 .28539 L
.85472 .28968 L
.85475 .29828 L
.85477 .30257 L
.85479 .29398 L
.85481 .29828 L
.85483 .28968 L
.85486 .28539 L
.85488 .28968 L
.8549 .29398 L
.85492 .30687 L
.85495 .29828 L
.85497 .30687 L
.85499 .29398 L
.85501 .29398 L
.85504 .29398 L
.85506 .29398 L
.85508 .30257 L
.8551 .29828 L
.85512 .29828 L
.85515 .29828 L
.85517 .29398 L
.85519 .29398 L
.85521 .29828 L
.85524 .30257 L
.85526 .29828 L
.85528 .30257 L
.8553 .29828 L
.85533 .29398 L
.85535 .29398 L
.85537 .29398 L
.85539 .29398 L
.85542 .29398 L
.85544 .29398 L
.85546 .30257 L
.85548 .29398 L
.8555 .29828 L
.85553 .29828 L
Mistroke
.85555 .29398 L
.85557 .29398 L
.85559 .29828 L
.85562 .29398 L
.85564 .29828 L
.85566 .28968 L
.85568 .28968 L
.85571 .28968 L
.85573 .28968 L
.85575 .29828 L
.85577 .29828 L
.85579 .29398 L
.85582 .29398 L
.85584 .28968 L
.85586 .28968 L
.85588 .29828 L
.85591 .29398 L
.85593 .29828 L
.85595 .29398 L
.85597 .28968 L
.856 .28968 L
.85602 .28968 L
.85604 .28968 L
.85606 .29828 L
.85609 .30257 L
.85611 .29828 L
.85613 .29398 L
.85615 .29828 L
.85617 .28968 L
.8562 .29398 L
.85622 .29828 L
.85624 .30257 L
.85626 .30257 L
.85629 .29828 L
.85631 .29398 L
.85633 .29828 L
.85635 .29398 L
.85638 .30257 L
.8564 .30257 L
.85642 .30687 L
.85644 .30257 L
.85646 .29398 L
.85649 .30257 L
.85651 .28968 L
.85653 .29828 L
.85655 .29828 L
.85658 .30257 L
.8566 .30257 L
.85662 .29828 L
.85664 .29398 L
Mistroke
.85667 .29398 L
.85669 .30257 L
.85671 .28968 L
.85673 .29828 L
.85675 .30257 L
.85678 .29398 L
.8568 .29398 L
.85682 .28539 L
.85684 .29398 L
.85687 .29398 L
.85689 .29828 L
.85691 .29828 L
.85693 .29398 L
.85696 .28968 L
.85698 .28539 L
.857 .28968 L
.85702 .29398 L
.85705 .30257 L
.85707 .29828 L
.85709 .28968 L
.85711 .28539 L
.85713 .28109 L
.85716 .28968 L
.85718 .29828 L
.8572 .30257 L
.85722 .29828 L
.85725 .28968 L
.85727 .28109 L
.85729 .28968 L
.85731 .29398 L
.85734 .29828 L
.85736 .29828 L
.85738 .29828 L
.8574 .28968 L
.85742 .29398 L
.85745 .28968 L
.85747 .29398 L
.85749 .29828 L
.85751 .30257 L
.85754 .30257 L
.85756 .29828 L
.85758 .29828 L
.8576 .29398 L
.85763 .28968 L
.85765 .29828 L
.85767 .30257 L
.85769 .30687 L
.85772 .30257 L
.85774 .29828 L
.85776 .28968 L
Mistroke
.85778 .28968 L
.8578 .28539 L
.85783 .29828 L
.85785 .29828 L
.85787 .30257 L
.85789 .30257 L
.85792 .29828 L
.85794 .29828 L
.85796 .28539 L
.85798 .28968 L
.85801 .29828 L
.85803 .30257 L
.85805 .30257 L
.85807 .28968 L
.85809 .28539 L
.85812 .28539 L
.85814 .28968 L
.85816 .29398 L
.85818 .30257 L
.85821 .29828 L
.85823 .28968 L
.85825 .28539 L
.85827 .28539 L
.8583 .29828 L
.85832 .29398 L
.85834 .28968 L
.85836 .29828 L
.85838 .28539 L
.85841 .28968 L
.85843 .28968 L
.85845 .29398 L
.85847 .29828 L
.8585 .29398 L
.85852 .29398 L
.85854 .28968 L
.85856 .28968 L
.85859 .28968 L
.85861 .29828 L
.85863 .29828 L
.85865 .29828 L
.85868 .29398 L
.8587 .28968 L
.85872 .29398 L
.85874 .29828 L
.85876 .29828 L
.85879 .30687 L
.85881 .30257 L
.85883 .29828 L
.85885 .29828 L
.85888 .29398 L
Mistroke
.8589 .29828 L
.85892 .30257 L
.85894 .30257 L
.85897 .29828 L
.85899 .29828 L
.85901 .29398 L
.85903 .29828 L
.85905 .30257 L
.85908 .30257 L
.8591 .30687 L
.85912 .30257 L
.85914 .29828 L
.85917 .29398 L
.85919 .28968 L
.85921 .28968 L
.85923 .30257 L
.85926 .30257 L
.85928 .29828 L
.8593 .29828 L
.85932 .28968 L
.85935 .28539 L
.85937 .29398 L
.85939 .30257 L
.85941 .29828 L
.85943 .29398 L
.85946 .28968 L
.85948 .28109 L
.8595 .28968 L
.85952 .29398 L
.85955 .30257 L
.85957 .30257 L
.85959 .28968 L
.85961 .28539 L
.85964 .28109 L
.85966 .29398 L
.85968 .29398 L
.8597 .30257 L
.85972 .29398 L
.85975 .28539 L
.85977 .28539 L
.85979 .28109 L
.85981 .29398 L
.85984 .29828 L
.85986 .30257 L
.85988 .29398 L
.8599 .28968 L
.85993 .28968 L
.85995 .28968 L
.85997 .29828 L
.85999 .30257 L
Mistroke
.86001 .30257 L
.86004 .30257 L
.86006 .29828 L
.86008 .29398 L
.8601 .29828 L
.86013 .30257 L
.86015 .30257 L
.86017 .30687 L
.86019 .30687 L
.86022 .29828 L
.86024 .29828 L
.86026 .30257 L
.86028 .29828 L
.86031 .30257 L
.86033 .30257 L
.86035 .29828 L
.86037 .29398 L
.86039 .30257 L
.86042 .29398 L
.86044 .29828 L
.86046 .30257 L
.86048 .29828 L
.86051 .29828 L
.86053 .29398 L
.86055 .28968 L
.86057 .29398 L
.8606 .29828 L
.86062 .29828 L
.86064 .29398 L
.86066 .29398 L
.86068 .28968 L
.86071 .28968 L
.86073 .29398 L
.86075 .29828 L
.86077 .29828 L
.8608 .29398 L
.86082 .29398 L
.86084 .28109 L
.86086 .28968 L
.86089 .29398 L
.86091 .29828 L
.86093 .29398 L
.86095 .29398 L
.86097 .28968 L
.861 .28109 L
.86102 .29398 L
.86104 .29398 L
.86106 .29828 L
.86109 .29828 L
.86111 .28968 L
Mistroke
.86113 .28968 L
.86115 .28539 L
.86118 .29398 L
.8612 .29828 L
.86122 .30257 L
.86124 .29828 L
.86127 .29398 L
.86129 .29828 L
.86131 .28968 L
.86133 .29828 L
.86135 .30257 L
.86138 .30257 L
.8614 .30257 L
.86142 .30257 L
.86144 .29828 L
.86147 .29828 L
.86149 .30257 L
.86151 .30257 L
.86153 .30257 L
.86156 .30257 L
.86158 .30257 L
.8616 .29828 L
.86162 .29398 L
.86164 .29828 L
.86167 .29828 L
.86169 .29828 L
.86171 .30257 L
.86173 .29828 L
.86176 .29398 L
.86178 .28968 L
.8618 .29398 L
.86182 .30257 L
.86185 .29828 L
.86187 .29398 L
.86189 .28968 L
.86191 .28539 L
.86194 .28968 L
.86196 .29828 L
.86198 .30257 L
.862 .29398 L
.86202 .29398 L
.86205 .28968 L
.86207 .28539 L
.86209 .29828 L
.86211 .29828 L
.86214 .29828 L
.86216 .29398 L
.86218 .28968 L
.8622 .28109 L
.86223 .28539 L
Mistroke
.86225 .29398 L
.86227 .29828 L
.86229 .29398 L
.86231 .28968 L
.86234 .28539 L
.86236 .28968 L
.86238 .28968 L
.8624 .29828 L
.86243 .30257 L
.86245 .29398 L
.86247 .29828 L
.86249 .29828 L
.86252 .29398 L
.86254 .29398 L
.86256 .29828 L
.86258 .29828 L
.8626 .30257 L
.86263 .30257 L
.86265 .30257 L
.86267 .29828 L
.86269 .29828 L
.86272 .29828 L
.86274 .30257 L
.86276 .30687 L
.86278 .30257 L
.86281 .29828 L
.86283 .29828 L
.86285 .29398 L
.86287 .29828 L
.8629 .29828 L
.86292 .30257 L
.86294 .29828 L
.86296 .29828 L
.86298 .29398 L
.86301 .29398 L
.86303 .29828 L
.86305 .29828 L
.86307 .29828 L
.8631 .29828 L
.86312 .28968 L
.86314 .29398 L
.86316 .29398 L
.86319 .29828 L
.86321 .29828 L
.86323 .29398 L
.86325 .29398 L
.86327 .29398 L
.8633 .29398 L
.86332 .29398 L
.86334 .29828 L
Mistroke
.86336 .29398 L
.86339 .28968 L
.86341 .29398 L
.86343 .28968 L
.86345 .29398 L
.86348 .29398 L
.8635 .29398 L
.86352 .29398 L
.86354 .28968 L
.86357 .29398 L
.86359 .28968 L
.86361 .28968 L
.86363 .28968 L
.86365 .28968 L
.86368 .29398 L
.8637 .29828 L
.86372 .29398 L
.86374 .29398 L
.86377 .28968 L
.86379 .29398 L
.86381 .29398 L
.86383 .30257 L
.86386 .30257 L
.86388 .30257 L
.8639 .29828 L
.86392 .29398 L
.86394 .29398 L
.86397 .29828 L
.86399 .30257 L
.86401 .31117 L
.86403 .30257 L
.86406 .29828 L
.86408 .29398 L
.8641 .29398 L
.86412 .29828 L
.86415 .30257 L
.86417 .30257 L
.86419 .30257 L
.86421 .29398 L
.86423 .29398 L
.86426 .29398 L
.86428 .29828 L
.8643 .29828 L
.86432 .29828 L
.86435 .29398 L
.86437 .29398 L
.86439 .29398 L
.86441 .29398 L
.86444 .29398 L
.86446 .29398 L
Mistroke
.86448 .29398 L
.8645 .29398 L
.86453 .29398 L
.86455 .29398 L
.86457 .29398 L
.86459 .29398 L
.86461 .28968 L
.86464 .29398 L
.86466 .29398 L
.86468 .29398 L
.8647 .28968 L
.86473 .28539 L
.86475 .28968 L
.86477 .28968 L
.86479 .29398 L
.86482 .29398 L
.86484 .28968 L
.86486 .28968 L
.86488 .28968 L
.8649 .28539 L
.86493 .28539 L
.86495 .28968 L
.86497 .29398 L
.86499 .29828 L
.86502 .29398 L
.86504 .29398 L
.86506 .28968 L
.86508 .28968 L
.86511 .29398 L
.86513 .29828 L
.86515 .30257 L
.86517 .30257 L
.8652 .29828 L
.86522 .29398 L
.86524 .29398 L
.86526 .29828 L
.86528 .30257 L
.86531 .30257 L
.86533 .30257 L
.86535 .29828 L
.86537 .29398 L
.8654 .29398 L
.86542 .29398 L
.86544 .29828 L
.86546 .29828 L
.86549 .29828 L
.86551 .29398 L
.86553 .29398 L
.86555 .29398 L
.86557 .29398 L
Mistroke
.8656 .29828 L
.86562 .29828 L
.86564 .29828 L
.86566 .29398 L
.86569 .28968 L
.86571 .29398 L
.86573 .28968 L
.86575 .29398 L
.86578 .29828 L
.8658 .29398 L
.86582 .29398 L
.86584 .29398 L
.86586 .28968 L
.86589 .28968 L
.86591 .29398 L
.86593 .29398 L
.86595 .29398 L
.86598 .29398 L
.866 .28968 L
.86602 .28968 L
.86604 .28968 L
.86607 .28968 L
.86609 .29398 L
.86611 .29398 L
.86613 .29398 L
.86616 .28968 L
.86618 .28968 L
.8662 .28539 L
.86622 .28968 L
.86624 .29398 L
.86627 .29828 L
.86629 .30257 L
.86631 .29828 L
.86633 .28968 L
.86636 .28968 L
.86638 .29398 L
.8664 .29828 L
.86642 .30257 L
.86645 .30687 L
.86647 .29828 L
.86649 .29828 L
.86651 .29398 L
.86653 .29398 L
.86656 .29828 L
.86658 .30687 L
.8666 .30257 L
.86662 .30257 L
.86665 .29828 L
.86667 .29398 L
.86669 .29398 L
Mistroke
.86671 .29828 L
.86674 .29828 L
.86676 .29828 L
.86678 .29828 L
.8668 .29828 L
.86683 .29398 L
.86685 .29398 L
.86687 .29398 L
.86689 .29398 L
.86691 .29828 L
.86694 .30257 L
.86696 .29828 L
.86698 .29398 L
.867 .29398 L
.86703 .28968 L
.86705 .28968 L
.86707 .29828 L
.86709 .30257 L
.86712 .29828 L
.86714 .29828 L
.86716 .28968 L
.86718 .28539 L
.8672 .28968 L
.86723 .28968 L
.86725 .29398 L
.86727 .29828 L
.86729 .29828 L
.86732 .29828 L
.86734 .28968 L
.86736 .28109 L
.86738 .28539 L
.86741 .28968 L
.86743 .29828 L
.86745 .30257 L
.86747 .29828 L
.86749 .28968 L
.86752 .28539 L
.86754 .28539 L
.86756 .29398 L
.86758 .30257 L
.86761 .30257 L
.86763 .29828 L
.86765 .29828 L
.86767 .29398 L
.8677 .29398 L
.86772 .29828 L
.86774 .29828 L
.86776 .30257 L
.86779 .30257 L
.86781 .30257 L
Mistroke
.86783 .29828 L
.86785 .29398 L
.86787 .29398 L
.8679 .29398 L
.86792 .30257 L
.86794 .30257 L
.86796 .30257 L
.86799 .29828 L
.86801 .29398 L
.86803 .28968 L
.86805 .28968 L
.86808 .29828 L
.8681 .29828 L
.86812 .30257 L
.86814 .29828 L
.86816 .29398 L
.86819 .28968 L
.86821 .28968 L
.86823 .29398 L
.86825 .29828 L
.86828 .30257 L
.8683 .30257 L
.86832 .29398 L
.86834 .28968 L
.86837 .28539 L
.86839 .28968 L
.86841 .29828 L
.86843 .30257 L
.86846 .30257 L
.86848 .29398 L
.8685 .28968 L
.86852 .28109 L
.86854 .28968 L
.86857 .29398 L
.86859 .30257 L
.86861 .29828 L
.86863 .29398 L
.86866 .28539 L
.86868 .28539 L
.8687 .28968 L
.86872 .29398 L
.86875 .29828 L
.86877 .29828 L
.86879 .29828 L
.86881 .28968 L
.86883 .28968 L
.86886 .28968 L
.86888 .29398 L
.8689 .30257 L
.86892 .30257 L
Mistroke
.86895 .30257 L
.86897 .29828 L
.86899 .29398 L
.86901 .29398 L
.86904 .29828 L
.86906 .29828 L
.86908 .30257 L
.8691 .30687 L
.86912 .30257 L
.86915 .30257 L
.86917 .29398 L
.86919 .29398 L
.86921 .29398 L
.86924 .30257 L
.86926 .30257 L
.86928 .30257 L
.8693 .30257 L
.86933 .29398 L
.86935 .28968 L
.86937 .28968 L
.86939 .29828 L
.86942 .30687 L
.86944 .30687 L
.86946 .29828 L
.86948 .28968 L
.8695 .28539 L
.86953 .28968 L
.86955 .29828 L
.86957 .30257 L
.86959 .30257 L
.86962 .30257 L
.86964 .29828 L
.86966 .28968 L
.86968 .28539 L
.86971 .28968 L
.86973 .29398 L
.86975 .29828 L
.86977 .29828 L
.86979 .29398 L
.86982 .28968 L
.86984 .28539 L
.86986 .28968 L
.86988 .28968 L
.86991 .29398 L
.86993 .29828 L
.86995 .29398 L
.86997 .28968 L
.87 .28539 L
.87002 .28968 L
.87004 .28968 L
Mistroke
.87006 .29398 L
.87009 .29828 L
.87011 .29398 L
.87013 .29398 L
.87015 .28968 L
.87017 .29398 L
.8702 .29828 L
.87022 .29828 L
.87024 .29828 L
.87026 .29828 L
.87029 .29828 L
.87031 .30257 L
.87033 .29828 L
.87035 .29828 L
.87038 .29828 L
.8704 .29398 L
.87042 .29828 L
.87044 .30257 L
.87046 .30257 L
.87049 .30257 L
.87051 .29828 L
.87053 .28968 L
.87055 .29398 L
.87058 .29828 L
.8706 .30257 L
.87062 .30257 L
.87064 .30257 L
.87067 .29398 L
.87069 .28539 L
.87071 .28968 L
.87073 .29398 L
.87075 .30257 L
.87078 .30257 L
.8708 .29828 L
.87082 .28968 L
.87084 .28539 L
.87087 .28968 L
.87089 .29828 L
.87091 .30257 L
.87093 .29828 L
.87096 .28968 L
.87098 .28539 L
.871 .28539 L
.87102 .29398 L
.87105 .29828 L
.87107 .29828 L
.87109 .29398 L
.87111 .28968 L
.87113 .28539 L
.87116 .28968 L
Mistroke
.87118 .29398 L
.8712 .29398 L
.87122 .29398 L
.87125 .28968 L
.87127 .28968 L
.87129 .28968 L
.87131 .28968 L
.87134 .28968 L
.87136 .29398 L
.87138 .29398 L
.8714 .29398 L
.87142 .29398 L
.87145 .29828 L
.87147 .29828 L
.87149 .29398 L
.87151 .29398 L
.87154 .29828 L
.87156 .29828 L
.87158 .30257 L
.8716 .30257 L
.87163 .30257 L
.87165 .29828 L
.87167 .29398 L
.87169 .29828 L
.87172 .29828 L
.87174 .30257 L
.87176 .30257 L
.87178 .29828 L
.8718 .29398 L
.87183 .29398 L
.87185 .29398 L
.87187 .29828 L
.87189 .29828 L
.87192 .29828 L
.87194 .29828 L
.87196 .29828 L
.87198 .29398 L
.87201 .29398 L
.87203 .29398 L
.87205 .29398 L
.87207 .29828 L
.87209 .29828 L
.87212 .29398 L
.87214 .29398 L
.87216 .28968 L
.87218 .28968 L
.87221 .29398 L
.87223 .29828 L
.87225 .29828 L
.87227 .29398 L
Mistroke
.8723 .28968 L
.87232 .28539 L
.87234 .28968 L
.87236 .29398 L
.87238 .29828 L
.87241 .29828 L
.87243 .28968 L
.87245 .28539 L
.87247 .28539 L
.8725 .28968 L
.87252 .29828 L
.87254 .29828 L
.87256 .29398 L
.87259 .28539 L
.87261 .28539 L
.87263 .28968 L
.87265 .29828 L
.87268 .30257 L
.8727 .30257 L
.87272 .29828 L
.87274 .29398 L
.87276 .29398 L
.87279 .29398 L
.87281 .30257 L
.87283 .30687 L
.87285 .30687 L
.87288 .30257 L
.8729 .29828 L
.87292 .29398 L
.87294 .29828 L
.87297 .30257 L
.87299 .30687 L
.87301 .30257 L
.87303 .30257 L
.87305 .29828 L
.87308 .29828 L
.8731 .29828 L
.87312 .29398 L
.87314 .29828 L
.87317 .29828 L
.87319 .29828 L
.87321 .29828 L
.87323 .29398 L
.87326 .29398 L
.87328 .29398 L
.8733 .29398 L
.87332 .29398 L
.87335 .29398 L
.87337 .29398 L
.87339 .29398 L
Mistroke
.87341 .29398 L
.87343 .28968 L
.87346 .29398 L
.87348 .29398 L
.8735 .29398 L
.87352 .29398 L
.87355 .29398 L
.87357 .29398 L
.87359 .28968 L
.87361 .28968 L
.87364 .28968 L
.87366 .29398 L
.87368 .29398 L
.8737 .29398 L
.87372 .28968 L
.87375 .28539 L
.87377 .28968 L
.87379 .28968 L
.87381 .29398 L
.87384 .29398 L
.87386 .29828 L
.87388 .29398 L
.8739 .28968 L
.87393 .29398 L
.87395 .29828 L
.87397 .30257 L
.87399 .30257 L
.87401 .30257 L
.87404 .30257 L
.87406 .29398 L
.87408 .29828 L
.8741 .29828 L
.87413 .30687 L
.87415 .30687 L
.87417 .30257 L
.87419 .30257 L
.87422 .28968 L
.87424 .29828 L
.87426 .30257 L
.87428 .30257 L
.87431 .30257 L
.87433 .30257 L
.87435 .29828 L
.87437 .29398 L
.87439 .28968 L
.87442 .29398 L
.87444 .29828 L
.87446 .30257 L
.87448 .29828 L
.87451 .29398 L
Mistroke
.87453 .29398 L
.87455 .28968 L
.87457 .29398 L
.8746 .29828 L
.87462 .29828 L
.87464 .29398 L
.87466 .29398 L
.87468 .28968 L
.87471 .28968 L
.87473 .29828 L
.87475 .29828 L
.87477 .29398 L
.8748 .29398 L
.87482 .28539 L
.87484 .28968 L
.87486 .28968 L
.87489 .29398 L
.87491 .29828 L
.87493 .28539 L
.87495 .28968 L
.87498 .29398 L
.875 .28539 L
.87502 .29398 L
.87504 .29398 L
.87506 .29828 L
.87509 .28968 L
.87511 .29398 L
.87513 .29398 L
.87515 .29398 L
.87518 .30257 L
.8752 .30257 L
.87522 .30257 L
.87524 .29828 L
.87527 .29828 L
.87529 .30257 L
.87531 .29398 L
.87533 .30687 L
.87535 .30687 L
.87538 .30687 L
.8754 .29828 L
.87542 .29828 L
.87544 .30257 L
.87547 .29398 L
.87549 .30687 L
.87551 .30687 L
.87553 .30687 L
.87556 .30257 L
.87558 .28968 L
.8756 .29828 L
.87562 .29398 L
Mistroke
.87564 .29828 L
.87567 .30257 L
.87569 .29828 L
.87571 .29828 L
.87573 .28968 L
.87576 .29828 L
.87578 .30257 L
.8758 .30257 L
.87582 .29828 L
.87585 .29398 L
.87587 .29828 L
.87589 .29398 L
.87591 .29398 L
.87594 .30257 L
.87596 .30257 L
.87598 .28968 L
.876 .28968 L
.87602 .28968 L
.87605 .29828 L
.87607 .29398 L
.87609 .28968 L
.87611 .28968 L
.87614 .28968 L
.87616 .28968 L
.87618 .28539 L
.8762 .29398 L
.87623 .29828 L
.87625 .28968 L
.87627 .28968 L
.87629 .28968 L
.87631 .29398 L
.87634 .29398 L
.87636 .29398 L
.87638 .29828 L
.8764 .29398 L
.87643 .29828 L
.87645 .30257 L
.87647 .28539 L
.87649 .29828 L
.87652 .31546 L
.87654 .29828 L
.87656 .28968 L
.87658 .29828 L
.87661 .29828 L
.87663 .29828 L
.87665 .30257 L
.87667 .29828 L
.87669 .29828 L
.87672 .30687 L
.87674 .31117 L
Mistroke
.87676 .29398 L
.87678 .29828 L
.87681 .30257 L
.87683 .29398 L
.87685 .29398 L
.87687 .29828 L
.8769 .29398 L
.87692 .31117 L
.87694 .28968 L
.87696 .2725 L
.87698 .31546 L
.87701 .29828 L
.87703 .27679 L
.87705 .29398 L
.87707 .28968 L
.8771 .28968 L
.87712 .29828 L
.87714 .28968 L
.87716 .28968 L
.87719 .31976 L
.87721 .28968 L
.87723 .27679 L
.87725 .29828 L
.87727 .28539 L
.8773 .28109 L
.87732 .28968 L
.87734 .28968 L
.87736 .31117 L
.87739 .27679 L
.87741 .2682 L
.87743 .31117 L
.87745 .29398 L
.87748 .2682 L
.8775 .28539 L
.87752 .28968 L
.87754 .29398 L
.87757 .30257 L
.87759 .28539 L
.87761 .29398 L
.87763 .33265 L
.87765 .28968 L
.87768 .2725 L
.8777 .30257 L
.87772 .29828 L
.87774 .27679 L
.87777 .28109 L
.87779 .30687 L
.87781 .32405 L
.87783 .2725 L
.87786 .29398 L
Mistroke
.87788 .32405 L
.8779 .30257 L
.87792 .28968 L
.87794 .28968 L
.87797 .29828 L
.87799 .33265 L
.87801 .30687 L
.87803 .28539 L
.87806 .31546 L
.87808 .33694 L
.8781 .27679 L
.87812 .2725 L
.87815 .30257 L
.87817 .28539 L
.87819 .2725 L
.87821 .26391 L
.87823 .32835 L
.87826 .28539 L
.87828 .25531 L
.8783 .32405 L
.87832 .29398 L
.87835 .28109 L
.87837 .30257 L
.87839 .27679 L
.87841 .31546 L
.87844 .34124 L
.87846 .28539 L
.87848 .2725 L
.8785 .35413 L
.87853 .30257 L
.87855 .25102 L
.87857 .27679 L
.87859 .28539 L
.87861 .28109 L
.87864 .25102 L
.87866 .31117 L
.87868 .28968 L
.8787 .24672 L
.87873 .33265 L
.87875 .28109 L
.87877 .2682 L
.87879 .31546 L
.87882 .30687 L
.87884 .29398 L
.87886 .33694 L
.87888 .32835 L
.8789 .27679 L
.87893 .34554 L
.87895 .33694 L
.87897 .25961 L
Mistroke
.87899 .28968 L
.87902 .2725 L
.87904 .2725 L
.87906 .2725 L
.87908 .25961 L
.87911 .31546 L
.87913 .30687 L
.87915 .23383 L
.87917 .34124 L
.8792 .30687 L
.87922 .2682 L
.87924 .31117 L
.87926 .32405 L
.87928 .33694 L
.87931 .33694 L
.87933 .30257 L
.87935 .28109 L
.87937 .35843 L
.8794 .33694 L
.87942 .21664 L
.87944 .27679 L
.87946 .30257 L
.87949 .23813 L
.87951 .22953 L
.87953 .32405 L
.87955 .2725 L
.87957 .23813 L
.8796 .34983 L
.87962 .28109 L
.87964 .26391 L
.87966 .32835 L
.87969 .32835 L
.87971 .31117 L
.87973 .31976 L
.87975 .32835 L
.87978 .29828 L
.8798 .31546 L
.87982 .27679 L
.87984 .25102 L
.87986 .2725 L
.87989 .25102 L
.87991 .23813 L
.87993 .2682 L
.87995 .31117 L
.87998 .22524 L
.88 .2682 L
.88002 .34124 L
.88004 .29398 L
.88007 .30687 L
.88009 .31546 L
Mistroke
.88011 .35843 L
.88013 .32405 L
.88016 .28968 L
.88018 .32835 L
.8802 .32405 L
.88022 .31117 L
.88024 .25102 L
.88027 .28539 L
.88029 .26391 L
.88031 .22953 L
.88033 .25102 L
.88036 .28109 L
.88038 .33265 L
.8804 .24672 L
.88042 .28539 L
.88045 .35843 L
.88047 .32405 L
.88049 .31976 L
.88051 .31546 L
.88053 .37131 L
.88056 .37561 L
.88058 .31976 L
.8806 .27679 L
.88062 .28109 L
.88065 .32835 L
.88067 .23813 L
.88069 .21664 L
.88071 .24672 L
.88074 .23813 L
.88076 .27679 L
.88078 .31546 L
.8808 .23383 L
.88083 .2682 L
.88085 .37561 L
.88087 .35413 L
.88089 .30257 L
.88091 .31117 L
.88094 .40998 L
.88096 .39709 L
.88098 .25961 L
.881 .22953 L
.88103 .31117 L
.88105 .30687 L
.88107 .19946 L
.88109 .21235 L
.88112 .23383 L
.88114 .31546 L
.88116 .30257 L
.88118 .19946 L
.8812 .29828 L
Mistroke
.88123 .35413 L
.88125 .36702 L
.88127 .32835 L
.88129 .28109 L
.88132 .40139 L
.88134 .35413 L
.88136 .26391 L
.88138 .25102 L
.88141 .25102 L
.88143 .32835 L
.88145 .29398 L
.88147 .22094 L
.88149 .31117 L
.88152 .2682 L
.88154 .25961 L
.88156 .32405 L
.88158 .29828 L
.88161 .28968 L
.88163 .2725 L
.88165 .37991 L
.88167 .35413 L
.8817 .25531 L
.88172 .33265 L
.88174 .33265 L
.88176 .31976 L
.88179 .30687 L
.88181 .32835 L
.88183 .29828 L
.88185 .27679 L
.88187 .32835 L
.8819 .23383 L
.88192 .18657 L
.88194 .25961 L
.88196 .33265 L
.88199 .33265 L
.88201 .24672 L
.88203 .28539 L
.88205 .37131 L
.88208 .36702 L
.8821 .28968 L
.88212 .28539 L
.88214 .34554 L
.88216 .34124 L
.88219 .31117 L
.88221 .24242 L
.88223 .22953 L
.88225 .29398 L
.88228 .28109 L
.8823 .23383 L
.88232 .22953 L
Mistroke
.88234 .26391 L
.88237 .33694 L
.88239 .31117 L
.88241 .25531 L
.88243 .33265 L
.88246 .3928 L
.88248 .35843 L
.8825 .29398 L
.88252 .29398 L
.88254 .2725 L
.88257 .23383 L
.88259 .25531 L
.88261 .25531 L
.88263 .2682 L
.88266 .25531 L
.88268 .29828 L
.8827 .30687 L
.88272 .31117 L
.88275 .34983 L
.88277 .32405 L
.88279 .39709 L
.88281 .34554 L
.88283 .23813 L
.88286 .2725 L
.88288 .28109 L
.8829 .25531 L
.88292 .21235 L
.88295 .2725 L
.88297 .28109 L
.88299 .29828 L
.88301 .36272 L
.88304 .29398 L
.88306 .30687 L
.88308 .37991 L
.8831 .43146 L
.88312 .34124 L
.88315 .19946 L
.88317 .25102 L
.88319 .28539 L
.88321 .24672 L
.88324 .17798 L
.88326 .20805 L
.88328 .28968 L
.8833 .29398 L
.88333 .34554 L
.88335 .29398 L
.88337 .28968 L
.88339 .37991 L
.88342 .44006 L
.88344 .42287 L
Mistroke
.88346 .26391 L
.88348 .22094 L
.8835 .31117 L
.88353 .2725 L
.88355 .18227 L
.88357 .1522 L
.88359 .23813 L
.88362 .26391 L
.88364 .24672 L
.88366 .34554 L
.88368 .31976 L
.88371 .28109 L
.88373 .42717 L
.88375 .43146 L
.88377 .43146 L
.88379 .2725 L
.88382 .25961 L
.88384 .3885 L
.88386 .25961 L
.88388 .17368 L
.88391 .27679 L
.88393 .24242 L
.88395 .25531 L
.88397 .31976 L
.884 .31976 L
.88402 .33694 L
.88404 .31546 L
.88406 .35843 L
.88409 .2725 L
.88411 .17368 L
.88413 .29828 L
.88415 .40139 L
.88417 .30687 L
.8842 .21235 L
.88422 .33694 L
.88424 .37991 L
.88426 .30257 L
.88429 .27679 L
.88431 .30257 L
.88433 .32405 L
.88435 .29828 L
.88438 .30687 L
.8844 .29828 L
.88442 .27679 L
.88444 .30687 L
.88446 .33265 L
.88449 .27679 L
.88451 .18227 L
.88453 .22524 L
.88455 .29398 L
Mistroke
.88458 .25961 L
.8846 .25961 L
.88462 .43576 L
.88464 .3842 L
.88467 .29828 L
.88469 .35413 L
.88471 .37991 L
.88473 .31976 L
.88475 .20376 L
.88478 .28968 L
.8848 .24672 L
.88482 .22524 L
.88484 .27679 L
.88487 .2682 L
.88489 .28968 L
.88491 .25961 L
.88493 .28968 L
.88496 .21664 L
.88498 .2682 L
.885 .43576 L
.88502 .43146 L
.88505 .30257 L
.88507 .23383 L
.88509 .3885 L
.88511 .37561 L
.88513 .22953 L
.88516 .19087 L
.88518 .22953 L
.8852 .28968 L
.88522 .29398 L
.88525 .28539 L
.88527 .2682 L
.88529 .29828 L
.88531 .37561 L
.88534 .35843 L
.88536 .23383 L
.88538 .1479 L
.8854 .37991 L
.88542 .52169 L
.88545 .25102 L
.88547 .19946 L
.88549 .34124 L
.88551 .3842 L
.88554 .2725 L
.88556 .23383 L
.88558 .25102 L
.8856 .25102 L
.88563 .37131 L
.88565 .36702 L
.88567 .28968 L
Mistroke
.88569 .22953 L
.88572 .31117 L
.88574 .39709 L
.88576 .25961 L
.88578 .12212 L
.8858 .18657 L
.88583 .44006 L
.88585 .43576 L
.88587 .22524 L
.88589 .2725 L
.88592 .36702 L
.88594 .37131 L
.88596 .28968 L
.88598 .28968 L
.88601 .21664 L
.88603 .22524 L
.88605 .34124 L
.88607 .35843 L
.88609 .27679 L
.88612 .23383 L
.88614 .23383 L
.88616 .33265 L
.88618 .31546 L
.88621 .19946 L
.88623 .16509 L
.88625 .19516 L
.88627 .35843 L
.8863 .46583 L
.88632 .32405 L
.88634 .2725 L
.88636 .36272 L
.88638 .3885 L
.88641 .29398 L
.88643 .23383 L
.88645 .22524 L
.88647 .22524 L
.8865 .2725 L
.88652 .34124 L
.88654 .32835 L
.88656 .27679 L
.88659 .30687 L
.88661 .34124 L
.88663 .27679 L
.88665 .17798 L
.88668 .19516 L
.8867 .28109 L
.88672 .44006 L
.88674 .41428 L
.88676 .25531 L
.88679 .33694 L
Mistroke
.88681 .3928 L
.88683 .31117 L
.88685 .2725 L
.88688 .26391 L
.8869 .20376 L
.88692 .19946 L
.88694 .31546 L
.88697 .34983 L
.88699 .29828 L
.88701 .30257 L
.88703 .34983 L
.88705 .30257 L
.88708 .19516 L
.8871 .19087 L
.88712 .22094 L
.88714 .32835 L
.88717 .48302 L
.88719 .34983 L
.88721 .25102 L
.88723 .32405 L
.88726 .34124 L
.88728 .31117 L
.8873 .26391 L
.88732 .22524 L
.88735 .19516 L
.88737 .26391 L
.88739 .34124 L
.88741 .31117 L
.88743 .29828 L
.88746 .32405 L
.88748 .31546 L
.8875 .27679 L
.88752 .23383 L
.88755 .1565 L
.88757 .18657 L
.88759 .43146 L
.88761 .48302 L
.88764 .28109 L
.88766 .28109 L
.88768 .34124 L
.8877 .30687 L
.88772 .29398 L
.88775 .28539 L
.88777 .23383 L
.88779 .20805 L
.88781 .30257 L
.88784 .33265 L
.88786 .29398 L
.88788 .28968 L
.8879 .31117 L
Mistroke
.88793 .32835 L
.88795 .29828 L
.88797 .21235 L
.88799 .16938 L
.88801 .3885 L
.88804 .50021 L
.88806 .30687 L
.88808 .25531 L
.8881 .32835 L
.88813 .32835 L
.88815 .25961 L
.88817 .2725 L
.88819 .25531 L
.88822 .19946 L
.88824 .31117 L
.88826 .36702 L
.88828 .31976 L
.88831 .27679 L
.88833 .27679 L
.88835 .34124 L
.88837 .28109 L
.88839 .16509 L
.88842 .16938 L
.88844 .42287 L
.88846 .48302 L
.88848 .25531 L
.88851 .25531 L
.88853 .2682 L
.88855 .34983 L
.88857 .30257 L
.8886 .25531 L
.88862 .27679 L
.88864 .25961 L
.88866 .19087 L
.88868 .31117 L
.88871 .40998 L
.88873 .32835 L
.88875 .2682 L
.88877 .28968 L
.8888 .32405 L
.88882 .21664 L
.88884 .1522 L
.88886 .18227 L
.88889 .33265 L
.88891 .49161 L
.88893 .35843 L
.88895 .31117 L
.88898 .35413 L
.889 .31976 L
.88902 .27679 L
Mistroke
.88904 .25531 L
.88906 .25531 L
.88909 .19946 L
.88911 .22953 L
.88913 .36272 L
.88915 .35413 L
.88918 .33694 L
.8892 .32405 L
.88922 .32405 L
.88924 .28109 L
.88927 .21235 L
.88929 .18657 L
.88931 .20376 L
.88933 .40569 L
.88935 .47872 L
.88938 .30257 L
.8894 .30687 L
.88942 .34554 L
.88944 .29828 L
.88947 .26391 L
.88949 .25961 L
.88951 .24242 L
.88953 .18227 L
.88956 .28968 L
.88958 .3928 L
.8896 .34124 L
.88962 .31117 L
.88964 .29398 L
.88967 .31976 L
.88969 .25102 L
.88971 .19946 L
.88973 .16938 L
.88976 .2682 L
.88978 .47872 L
.8898 .3885 L
.88982 .28539 L
.88985 .32835 L
.88987 .30687 L
.88989 .28968 L
.88991 .26391 L
.88994 .24242 L
.88996 .19946 L
.88998 .22953 L
.89 .36702 L
.89002 .33694 L
.89005 .33265 L
.89007 .31117 L
.89009 .30257 L
.89011 .28109 L
.89014 .22953 L
Mistroke
.89016 .19516 L
.89018 .18227 L
.8902 .3928 L
.89023 .48732 L
.89025 .31546 L
.89027 .29398 L
.89029 .33694 L
.89031 .31976 L
.89034 .28109 L
.89036 .28539 L
.89038 .26391 L
.8904 .18657 L
.89043 .27679 L
.89045 .37131 L
.89047 .32835 L
.89049 .33694 L
.89052 .29398 L
.89054 .32835 L
.89056 .27679 L
.89058 .20805 L
.89061 .1565 L
.89063 .29828 L
.89065 .51309 L
.89067 .36702 L
.89069 .25961 L
.89072 .31546 L
.89074 .29828 L
.89076 .28109 L
.89078 .2725 L
.89081 .29398 L
.89083 .21664 L
.89085 .23383 L
.89087 .23383 L
.8909 .37561 L
.89092 .32405 L
.89094 .33694 L
.89096 .28968 L
.89098 .32405 L
.89101 .30257 L
.89103 .20376 L
.89105 .14361 L
.89107 .22094 L
.8911 .47443 L
.89112 .43146 L
.89114 .2682 L
.89116 .32405 L
.89119 .31546 L
.89121 .27679 L
.89123 .25961 L
.89125 .28968 L
Mistroke
.89127 .25102 L
.8913 .19946 L
.89132 .34983 L
.89134 .33694 L
.89136 .31546 L
.89139 .29398 L
.89141 .30687 L
.89143 .32405 L
.89145 .22524 L
.89148 .16938 L
.8915 .20805 L
.89152 .44006 L
.89154 .47013 L
.89157 .28968 L
.89159 .32835 L
.89161 .35413 L
.89163 .28109 L
.89165 .25531 L
.89168 .27679 L
.8917 .2725 L
.89172 .20376 L
.89174 .31546 L
.89177 .35843 L
.89179 .31976 L
.89181 .31546 L
.89183 .31117 L
.89186 .33694 L
.89188 .25961 L
.8919 .19087 L
.89192 .16079 L
.89194 .33265 L
.89197 .50021 L
.89199 .33694 L
.89201 .27679 L
.89203 .34124 L
.89206 .30257 L
.89208 .25961 L
.8921 .26391 L
.89212 .28968 L
.89215 .20805 L
.89217 .25531 L
.89219 .3842 L
.89221 .33694 L
.89224 .30687 L
.89226 .2682 L
.89228 .33265 L
.8923 .26391 L
.89232 .17368 L
.89235 .16079 L
.89237 .28968 L
Mistroke
.89239 .49161 L
.89241 .37991 L
.89244 .27679 L
.89246 .35413 L
.89248 .30257 L
.8925 .25961 L
.89253 .25531 L
.89255 .2725 L
.89257 .22953 L
.89259 .22094 L
.89261 .35843 L
.89264 .32405 L
.89266 .32405 L
.89268 .31117 L
.8927 .34554 L
.89273 .29828 L
.89275 .21664 L
.89277 .17798 L
.89279 .18657 L
.89282 .40569 L
.89284 .48302 L
.89286 .31546 L
.89288 .31546 L
.8929 .33694 L
.89293 .29828 L
.89295 .25961 L
.89297 .2725 L
.89299 .2725 L
.89302 .21235 L
.89304 .28968 L
.89306 .34124 L
.89308 .31546 L
.89311 .30687 L
.89313 .29828 L
.89315 .32835 L
.89317 .25531 L
.8932 .19516 L
.89322 .16079 L
.89324 .16079 L
.89326 .35413 L
.89328 .5045 L
.89331 .31976 L
.89333 .2725 L
.89335 .34554 L
.89337 .28968 L
.8934 .24242 L
.89342 .25961 L
.89344 .29398 L
.89346 .21664 L
.89349 .25531 L
Mistroke
.89351 .35843 L
.89353 .31117 L
.89355 .29828 L
.89357 .28539 L
.8936 .33694 L
.89362 .2725 L
.89364 .18227 L
.89366 .1479 L
.89369 .27679 L
.89371 .49161 L
.89373 .37561 L
.89375 .2725 L
.89378 .34124 L
.8938 .31117 L
.89382 .24672 L
.89384 .25102 L
.89386 .28539 L
.89389 .22953 L
.89391 .23813 L
.89393 .36272 L
.89395 .32405 L
.89398 .28968 L
.894 .27679 L
.89402 .34983 L
.89404 .31117 L
.89407 .19946 L
.89409 .1479 L
.89411 .28539 L
.89413 .5088 L
.89416 .3842 L
.89418 .24672 L
.8942 .33694 L
.89422 .32835 L
.89424 .24672 L
.89427 .23813 L
.89429 .28968 L
.89431 .24672 L
.89433 .22953 L
.89436 .34983 L
.89438 .34983 L
.8944 .29828 L
.89442 .27679 L
.89445 .33265 L
.89447 .31546 L
.89449 .21235 L
.89451 .14361 L
.89453 .20376 L
.89456 .41857 L
.89458 .46154 L
.8946 .28968 L
Mistroke
.89462 .30257 L
.89465 .34124 L
.89467 .27679 L
.89469 .23813 L
.89471 .2682 L
.89474 .25961 L
.89476 .20805 L
.89478 .28968 L
.8948 .34124 L
.89483 .30687 L
.89485 .28109 L
.89487 .30687 L
.89489 .32405 L
.89491 .25102 L
.89494 .18227 L
.89496 .16509 L
.89498 .35413 L
.895 .50021 L
.89503 .31117 L
.89505 .25961 L
.89507 .33694 L
.89509 .31117 L
.89512 .25102 L
.89514 .2682 L
.89516 .28539 L
.89518 .22524 L
.8952 .28539 L
.89523 .36272 L
.89525 .33265 L
.89527 .28539 L
.89529 .28968 L
.89532 .35843 L
.89534 .28968 L
.89536 .18227 L
.89538 .14361 L
.89541 .34124 L
.89543 .52598 L
.89545 .34983 L
.89547 .25961 L
.89549 .34554 L
.89552 .31976 L
.89554 .25102 L
.89556 .25531 L
.89558 .28968 L
.89561 .28968 L
.89563 .21664 L
.89565 .27679 L
.89567 .3928 L
.8957 .34983 L
.89572 .26391 L
Mistroke
.89574 .25531 L
.89576 .35413 L
.89579 .28968 L
.89581 .19946 L
.89583 .1479 L
.89585 .28109 L
.89587 .50021 L
.8959 .40139 L
.89592 .2682 L
.89594 .34983 L
.89596 .33694 L
.89599 .25961 L
.89601 .22094 L
.89603 .26391 L
.89605 .22094 L
.89608 .23383 L
.8961 .37131 L
.89612 .37131 L
.89614 .32405 L
.89616 .28539 L
.89619 .31546 L
.89621 .28968 L
.89623 .23813 L
.89625 .17798 L
.89628 .16938 L
.8963 .34554 L
.89632 .5088 L
.89634 .35413 L
.89637 .29398 L
.89639 .34983 L
.89641 .31546 L
.89643 .2682 L
.89646 .2725 L
.89648 .2725 L
.8965 .22094 L
.89652 .2682 L
.89654 .35413 L
.89657 .34124 L
.89659 .33694 L
.89661 .31976 L
.89663 .33694 L
.89666 .29398 L
.89668 .24242 L
.8967 .16509 L
.89672 .19087 L
.89675 .45295 L
.89677 .46583 L
.89679 .28109 L
.89681 .29828 L
.89683 .33694 L
Mistroke
.89686 .30257 L
.89688 .25961 L
.8969 .27679 L
.89692 .2682 L
.89695 .22094 L
.89697 .31546 L
.89699 .33694 L
.89701 .33694 L
.89704 .29398 L
.89706 .28109 L
.89708 .33694 L
.8971 .29398 L
.89712 .19946 L
.89715 .13501 L
.89717 .33265 L
.89719 .51309 L
.89721 .33265 L
.89724 .25531 L
.89726 .32835 L
.89728 .31117 L
.8973 .25531 L
.89733 .25531 L
.89735 .29828 L
.89737 .21664 L
.89739 .25961 L
.89742 .36272 L
.89744 .33694 L
.89746 .30687 L
.89748 .25961 L
.8975 .32835 L
.89753 .30687 L
.89755 .21664 L
.89757 .13501 L
.89759 .25531 L
.89762 .5045 L
.89764 .41428 L
.89766 .25102 L
.89768 .32405 L
.89771 .32405 L
.89773 .2725 L
.89775 .24672 L
.89777 .30687 L
.89779 .24242 L
.89782 .21664 L
.89784 .37991 L
.89786 .36702 L
.89788 .31976 L
.89791 .24672 L
.89793 .31117 L
.89795 .33694 L
Mistroke
.89797 .33694 L
.898 .22953 L
.89802 .1479 L
.89804 .18227 L
.89806 .40998 L
.89809 .49161 L
.89811 .30257 L
.89813 .31117 L
.89815 .33265 L
.89817 .27679 L
.8982 .25102 L
.89822 .25961 L
.89824 .2682 L
.89826 .17798 L
.89829 .30257 L
.89831 .3885 L
.89833 .34124 L
.89835 .31546 L
.89838 .29398 L
.8984 .31117 L
.89842 .2725 L
.89844 .19516 L
.89846 .1522 L
.89849 .20376 L
.89851 .41857 L
.89853 .47013 L
.89855 .30257 L
.89858 .30257 L
.8986 .31546 L
.89862 .30257 L
.89864 .27679 L
.89867 .2682 L
.89869 .22094 L
.89871 .18657 L
.89873 .29398 L
.89875 .37131 L
.89878 .34124 L
.8988 .33694 L
.89882 .30257 L
.89884 .30257 L
.89887 .27679 L
.89889 .19946 L
.89891 .1479 L
.89893 .20805 L
.89896 .46154 L
.89898 .46583 L
.899 .27679 L
.89902 .28109 L
.89905 .32835 L
.89907 .31976 L
Mistroke
.89909 .29828 L
.89911 .25531 L
.89913 .22953 L
.89916 .21235 L
.89918 .31117 L
.8992 .34983 L
.89922 .33265 L
.89925 .31976 L
.89927 .29398 L
.89929 .32835 L
.89931 .29828 L
.89934 .18657 L
.89936 .13072 L
.89938 .25102 L
.8994 .49161 L
.89942 .42717 L
.89945 .23813 L
.89947 .28539 L
.89949 .33265 L
.89951 .31546 L
.89954 .28539 L
.89956 .25102 L
.89958 .22524 L
.8996 .22524 L
.89963 .34554 L
.89965 .37561 L
.89967 .31976 L
.89969 .2725 L
.89972 .27679 L
.89974 .32835 L
.89976 .2725 L
.89978 .1522 L
.8998 .1565 L
.89983 .33694 L
.89985 .5088 L
.89987 .36702 L
.89989 .23813 L
.89992 .31546 L
.89994 .31976 L
.89996 .29828 L
.89998 .2725 L
.90001 .23813 L
.90003 .20376 L
.90005 .25102 L
.90007 .3885 L
.90009 .37561 L
.90012 .31117 L
.90014 .28109 L
.90016 .30687 L
.90018 .31546 L
Mistroke
.90021 .23813 L
.90023 .13501 L
.90025 .17798 L
.90027 .40569 L
.9003 .51739 L
.90032 .51739 L
.90034 .31546 L
.90036 .25102 L
.90038 .34554 L
.90041 .33265 L
.90043 .29398 L
.90045 .26391 L
.90047 .23813 L
.9005 .19516 L
.90052 .27679 L
.90054 .40139 L
.90056 .37131 L
.90059 .30257 L
.90061 .27679 L
.90063 .31976 L
.90065 .30687 L
.90068 .21664 L
.9007 .13072 L
.90072 .19946 L
.90074 .41857 L
.90076 .50021 L
.90079 .30257 L
.90081 .2682 L
.90083 .35413 L
.90085 .32835 L
.90088 .28109 L
.9009 .25102 L
.90092 .21235 L
.90094 .21235 L
.90097 .30687 L
.90099 .3885 L
.90101 .34554 L
.90103 .31117 L
.90105 .30257 L
.90108 .31546 L
.9011 .29398 L
.90112 .21235 L
.90114 .13501 L
.90117 .20805 L
.90119 .40569 L
.90121 .48732 L
.90123 .31117 L
.90126 .26391 L
.90128 .35413 L
.9013 .34124 L
Mistroke
.90132 .28968 L
.90135 .24242 L
.90137 .20805 L
.90139 .23813 L
.90141 .28968 L
.90143 .37561 L
.90146 .34124 L
.90148 .30687 L
.9015 .30687 L
.90152 .32405 L
.90155 .31117 L
.90157 .21664 L
.90159 .12642 L
.90161 .23383 L
.90164 .44865 L
.90166 .46583 L
.90168 .27679 L
.9017 .26391 L
.90172 .34983 L
.90175 .31546 L
.90177 .28109 L
.90179 .25102 L
.90181 .22524 L
.90184 .23383 L
.90186 .33265 L
.90188 .3928 L
.9019 .30687 L
.90193 .25961 L
.90195 .29828 L
.90197 .34124 L
.90199 .27679 L
.90201 .16938 L
.90204 .14361 L
.90206 .28109 L
.90208 .46583 L
.9021 .44435 L
.90213 .2682 L
.90215 .28539 L
.90217 .33265 L
.90219 .29398 L
.90222 .2682 L
.90224 .22524 L
.90226 .20805 L
.90228 .23813 L
.90231 .36702 L
.90233 .3842 L
.90235 .31546 L
.90237 .28968 L
.90239 .29828 L
.90242 .28968 L
Mistroke
.90244 .25961 L
.90246 .17798 L
.90248 .16509 L
.90251 .2725 L
.90253 .44435 L
.90255 .45295 L
.90257 .28109 L
.9026 .28968 L
.90262 .34124 L
.90264 .31117 L
.90266 .2682 L
.90268 .2682 L
.90271 .22524 L
.90273 .20376 L
.90275 .25102 L
.90277 .33265 L
.9028 .3885 L
.90282 .33265 L
.90284 .31976 L
.90286 .30257 L
.90289 .28109 L
.90291 .28109 L
.90293 .19516 L
.90295 .14361 L
.90298 .25531 L
.903 .45724 L
.90302 .47443 L
.90304 .2725 L
.90306 .25961 L
.90309 .34554 L
.90311 .30687 L
.90313 .25961 L
.90315 .22953 L
.90318 .22524 L
.9032 .24672 L
.90322 .31546 L
.90324 .37991 L
.90327 .33694 L
.90329 .28539 L
.90331 .2682 L
.90333 .31117 L
.90335 .29398 L
.90338 .17798 L
.9034 .13501 L
.90342 .25102 L
.90344 .46154 L
.90347 .47443 L
.90349 .2682 L
.90351 .2725 L
.90353 .34124 L
Mistroke
.90356 .29828 L
.90358 .25102 L
.9036 .23383 L
.90362 .22953 L
.90364 .23813 L
.90367 .32835 L
.90369 .3885 L
.90371 .34554 L
.90373 .28968 L
.90376 .2682 L
.90378 .30257 L
.9038 .28539 L
.90382 .19087 L
.90385 .16509 L
.90387 .22524 L
.90389 .40569 L
.90391 .50021 L
.90394 .31546 L
.90396 .25961 L
.90398 .34124 L
.904 .32835 L
.90402 .2725 L
.90405 .23813 L
.90407 .22524 L
.90409 .22953 L
.90411 .30257 L
.90414 .40139 L
.90416 .36702 L
.90418 .33265 L
.9042 .28539 L
.90423 .27679 L
.90425 .29398 L
.90427 .23383 L
.90429 .18227 L
.90431 .19087 L
.90434 .31976 L
.90436 .51739 L
.90438 .3842 L
.9044 .23813 L
.90443 .31117 L
.90445 .34554 L
.90447 .30687 L
.90449 .25102 L
.90452 .22094 L
.90454 .22524 L
.90456 .25531 L
.90458 .37991 L
.90461 .37561 L
.90463 .31976 L
.90465 .27679 L
Mistroke
.90467 .2682 L
.90469 .33265 L
.90472 .2725 L
.90474 .16938 L
.90476 .16938 L
.90478 .29828 L
.90481 .50021 L
.90483 .41428 L
.90485 .23383 L
.90487 .29398 L
.9049 .34124 L
.90492 .31117 L
.90494 .2725 L
.90496 .23383 L
.90498 .22953 L
.90501 .24242 L
.90503 .37131 L
.90505 .37131 L
.90507 .3928 L
.9051 .31976 L
.90512 .2725 L
.90514 .25961 L
.90516 .31976 L
.90519 .30257 L
.90521 .19087 L
.90523 .17368 L
.90525 .23383 L
.90527 .44435 L
.9053 .49591 L
.90532 .29398 L
.90534 .26391 L
.90536 .32405 L
.90539 .32835 L
.90541 .30687 L
.90543 .24672 L
.90545 .21235 L
.90548 .23383 L
.9055 .34124 L
.90552 .39709 L
.90554 .33694 L
.90557 .31117 L
.90559 .25531 L
.90561 .30687 L
.90563 .32835 L
.90565 .22953 L
.90568 .14361 L
.9057 .16509 L
.90572 .36272 L
.90574 .52169 L
.90577 .35413 L
Mistroke
.90579 .22953 L
.90581 .29398 L
.90583 .34983 L
.90586 .32405 L
.90588 .25531 L
.9059 .22094 L
.90592 .20805 L
.90594 .28109 L
.90597 .37561 L
.90599 .34983 L
.90601 .30687 L
.90603 .24672 L
.90606 .29398 L
.90608 .35413 L
.9061 .2725 L
.90612 .1479 L
.90615 .12212 L
.90617 .30687 L
.90619 .52169 L
.90621 .40139 L
.90624 .22524 L
.90626 .2682 L
.90628 .34554 L
.9063 .33265 L
.90632 .25961 L
.90635 .22953 L
.90637 .21235 L
.90639 .26391 L
.90641 .36272 L
.90644 .36702 L
.90646 .31976 L
.90648 .25531 L
.9065 .28539 L
.90653 .36272 L
.90655 .30257 L
.90657 .18227 L
.90659 .12642 L
.90661 .22953 L
.90664 .45295 L
.90666 .48302 L
.90668 .30257 L
.9067 .24672 L
.90673 .32835 L
.90675 .35413 L
.90677 .28539 L
.90679 .23813 L
.90682 .19946 L
.90684 .23813 L
.90686 .32405 L
.90688 .37561 L
Mistroke
.9069 .34554 L
.90693 .28968 L
.90695 .25961 L
.90697 .33265 L
.90699 .34124 L
.90702 .25102 L
.90704 .12642 L
.90706 .14361 L
.90708 .30257 L
.90711 .49161 L
.90713 .41428 L
.90715 .24242 L
.90717 .2682 L
.9072 .37561 L
.90722 .33694 L
.90724 .25961 L
.90726 .20805 L
.90728 .20805 L
.90731 .26391 L
.90733 .34554 L
.90735 .36702 L
.90737 .30257 L
.9074 .25961 L
.90742 .25961 L
.90744 .29828 L
.90746 .36702 L
.90749 .30687 L
.90751 .18657 L
.90753 .11353 L
.90755 .22094 L
.90757 .42287 L
.9076 .47872 L
.90762 .29398 L
.90764 .23383 L
.90766 .34124 L
.90769 .37991 L
.90771 .29828 L
.90773 .23813 L
.90775 .20805 L
.90778 .23813 L
.9078 .31546 L
.90782 .3842 L
.90784 .35413 L
.90787 .2725 L
.90789 .25961 L
.90791 .34554 L
.90793 .34124 L
.90795 .25531 L
.90798 .13931 L
.908 .16938 L
Mistroke
.90802 .32405 L
.90804 .49161 L
.90807 .39709 L
.90809 .22953 L
.90811 .27679 L
.90813 .3842 L
.90816 .34124 L
.90818 .26391 L
.9082 .19946 L
.90822 .21235 L
.90824 .28109 L
.90827 .34983 L
.90829 .37991 L
.90831 .31976 L
.90833 .2682 L
.90836 .30257 L
.90838 .33694 L
.9084 .29828 L
.90842 .19516 L
.90845 .13931 L
.90847 .21235 L
.90849 .34983 L
.90851 .48732 L
.90853 .36272 L
.90856 .22524 L
.90858 .31976 L
.9086 .3885 L
.90862 .31546 L
.90865 .24242 L
.90867 .19087 L
.90869 .23383 L
.90871 .28968 L
.90874 .35413 L
.90876 .34983 L
.90878 .29828 L
.9088 .28539 L
.90883 .32835 L
.90885 .32405 L
.90887 .28109 L
.90889 .17798 L
.90891 .13931 L
.90894 .22953 L
.90896 .42717 L
.90898 .49591 L
.909 .29398 L
.90903 .23813 L
.90905 .37991 L
.90907 .39709 L
.90909 .29398 L
.90912 .22094 L
Mistroke
.90914 .20805 L
.90916 .25531 L
.90918 .29398 L
.9092 .37991 L
.90923 .35413 L
.90925 .28968 L
.90927 .28968 L
.90929 .33694 L
.90932 .33265 L
.90934 .25531 L
.90936 .13931 L
.90938 .16079 L
.90941 .2682 L
.90943 .47013 L
.90945 .44865 L
.90947 .24672 L
.9095 .2682 L
.90952 .40569 L
.90954 .35843 L
.90956 .2682 L
.90958 .19516 L
.90961 .21235 L
.90963 .25102 L
.90965 .31976 L
.90967 .3885 L
.9097 .31976 L
.90972 .2725 L
.90974 .30257 L
.90976 .34124 L
.90979 .34124 L
.90981 .30687 L
.90983 .22094 L
.90985 .13501 L
.90987 .16509 L
.9099 .27679 L
.90992 .48302 L
.90994 .41857 L
.90996 .24242 L
.90999 .28968 L
.91001 .40998 L
.91003 .35413 L
.91005 .25102 L
.91008 .18657 L
.9101 .21664 L
.91012 .25961 L
.91014 .34124 L
.91016 .36702 L
.91019 .30257 L
.91021 .30257 L
.91023 .32405 L
Mistroke
.91025 .34983 L
.91028 .29398 L
.9103 .21664 L
.91032 .13501 L
.91034 .18657 L
.91037 .31546 L
.91039 .48302 L
.91041 .40139 L
.91043 .25531 L
.91046 .31117 L
.91048 .41857 L
.9105 .33265 L
.91052 .24242 L
.91054 .20376 L
.91057 .21664 L
.91059 .2682 L
.91061 .34124 L
.91063 .34554 L
.91066 .30257 L
.91068 .29398 L
.9107 .31117 L
.91072 .34124 L
.91075 .28539 L
.91077 .20376 L
.91079 .12642 L
.91081 .18657 L
.91083 .32405 L
.91086 .48302 L
.91088 .39709 L
.9109 .24672 L
.91092 .29398 L
.91095 .40569 L
.91097 .32405 L
.91099 .24672 L
.91101 .19946 L
.91104 .20805 L
.91106 .2682 L
.91108 .33265 L
.9111 .34124 L
.91112 .30257 L
.91115 .28539 L
.91117 .30687 L
.91119 .33265 L
.91121 .28109 L
.91124 .19946 L
.91126 .13072 L
.91128 .19516 L
.9113 .32405 L
.91133 .49161 L
.91135 .40569 L
Mistroke
.91137 .23383 L
.91139 .29398 L
.91142 .41428 L
.91144 .33694 L
.91146 .25531 L
.91148 .19946 L
.9115 .22524 L
.91153 .27679 L
.91155 .34124 L
.91157 .35413 L
.91159 .31117 L
.91162 .28968 L
.91164 .31976 L
.91166 .33694 L
.91168 .28968 L
.91171 .19516 L
.91173 .12642 L
.91175 .21664 L
.91177 .32835 L
.91179 .47013 L
.91182 .41428 L
.91184 .24672 L
.91186 .28539 L
.91188 .40998 L
.91191 .33265 L
.91193 .26391 L
.91195 .19946 L
.91197 .22094 L
.912 .28109 L
.91202 .32835 L
.91204 .33694 L
.91206 .28539 L
.91209 .29398 L
.91211 .31976 L
.91213 .33265 L
.91215 .33265 L
.91217 .28968 L
.9122 .21664 L
.91222 .13072 L
.91224 .20805 L
.91226 .30257 L
.91229 .46154 L
.91231 .42287 L
.91233 .23813 L
.91235 .27679 L
.91238 .40569 L
.9124 .33694 L
.91242 .26391 L
.91244 .20376 L
.91246 .21664 L
Mistroke
.91249 .28109 L
.91251 .31976 L
.91253 .34983 L
.91255 .28968 L
.91258 .28539 L
.9126 .31117 L
.91262 .34124 L
.91264 .29398 L
.91267 .23813 L
.91269 .16079 L
.91271 .22524 L
.91273 .27679 L
.91275 .42287 L
.91278 .46583 L
.9128 .29398 L
.91282 .25102 L
.91284 .40139 L
.91287 .37131 L
.91289 .28539 L
.91291 .20376 L
.91293 .20805 L
.91296 .28968 L
.91298 .30687 L
.913 .33265 L
.91302 .30257 L
.91305 .31117 L
.91307 .30687 L
.91309 .33265 L
.91311 .28968 L
.91313 .26391 L
.91316 .18657 L
.91318 .19516 L
.9132 .24242 L
.91322 .32835 L
.91325 .46154 L
.91327 .3842 L
.91329 .23813 L
.91331 .34554 L
.91334 .39709 L
.91336 .31546 L
.91338 .23383 L
.9134 .17798 L
.91342 .26391 L
.91345 .27679 L
.91347 .31117 L
.91349 .31117 L
.91351 .30687 L
.91354 .29398 L
.91356 .31976 L
.91358 .32835 L
Mistroke
.9136 .28539 L
.91363 .22094 L
.91365 .17368 L
.91367 .22524 L
.91369 .27679 L
.91372 .40998 L
.91374 .41857 L
.91376 .28109 L
.91378 .28539 L
.9138 .41428 L
.91383 .34983 L
.91385 .27679 L
.91387 .19516 L
.91389 .23813 L
.91392 .28539 L
.91394 .31546 L
.91396 .33694 L
.91398 .29828 L
.91401 .28539 L
.91403 .30687 L
.91405 .34124 L
.91407 .29398 L
.91409 .2725 L
.91412 .19946 L
.91414 .20376 L
.91416 .24672 L
.91418 .3842 L
.91421 .46154 L
.91423 .31976 L
.91425 .24242 L
.91427 .3842 L
.9143 .3842 L
.91432 .28539 L
.91434 .21235 L
.91436 .20805 L
.91438 .28968 L
.91441 .27679 L
.91443 .31976 L
.91445 .30257 L
.91447 .29398 L
.9145 .28109 L
.91452 .28109 L
.91454 .34124 L
.91456 .31546 L
.91459 .2682 L
.91461 .19516 L
.91463 .20805 L
.91465 .24242 L
.91468 .28968 L
.9147 .44006 L
Mistroke
.91472 .39709 L
.91474 .24672 L
.91476 .31976 L
.91479 .39709 L
.91481 .31546 L
.91483 .24672 L
.91485 .19087 L
.91488 .2682 L
.9149 .2682 L
.91492 .29828 L
.91494 .30687 L
.91497 .29828 L
.91499 .29828 L
.91501 .32835 L
.91503 .32835 L
.91505 .27679 L
.91508 .25531 L
.9151 .20376 L
.91512 .22524 L
.91514 .23383 L
.91517 .34554 L
.91519 .47872 L
.91521 .37131 L
.91523 .24672 L
.91526 .36272 L
.91528 .37131 L
.9153 .32405 L
.91532 .22524 L
.91535 .21664 L
.91537 .2682 L
.91539 .2725 L
.91541 .31976 L
.91543 .30687 L
.91546 .28968 L
.91548 .29828 L
.9155 .34124 L
.91552 .31546 L
.91555 .29398 L
.91557 .24672 L
.91559 .19946 L
.91561 .20376 L
.91564 .25102 L
.91566 .3885 L
.91568 .46154 L
.9157 .31117 L
.91572 .24672 L
.91575 .36272 L
.91577 .36702 L
.91579 .31117 L
.91581 .19087 L
Mistroke
.91584 .22953 L
.91586 .25961 L
.91588 .29398 L
.9159 .30687 L
.91593 .28539 L
.91595 .28539 L
.91597 .31117 L
.91599 .34554 L
.91601 .30257 L
.91604 .26391 L
.91606 .24242 L
.91608 .20376 L
.9161 .19946 L
.91613 .2682 L
.91615 .40139 L
.91617 .46583 L
.91619 .28539 L
.91622 .25531 L
.91624 .3842 L
.91626 .37561 L
.91628 .28968 L
.91631 .19516 L
.91633 .23383 L
.91635 .2725 L
.91637 .29398 L
.91639 .31546 L
.91642 .30257 L
.91644 .28539 L
.91646 .33694 L
.91648 .36272 L
.91651 .31976 L
.91653 .26391 L
.91655 .23383 L
.91657 .20376 L
.9166 .22094 L
.91662 .27679 L
.91664 .35843 L
.91666 .46154 L
.91668 .33694 L
.91671 .26391 L
.91673 .35843 L
.91675 .3928 L
.91677 .30257 L
.9168 .19516 L
.91682 .21235 L
.91684 .2725 L
.91686 .28109 L
.91689 .28109 L
.91691 .28968 L
.91693 .27679 L
Mistroke
.91695 .30257 L
.91698 .34554 L
.917 .34983 L
.91702 .31546 L
.91704 .25961 L
.91706 .23813 L
.91709 .21235 L
.91711 .20805 L
.91713 .26391 L
.91715 .29828 L
.91718 .42287 L
.9172 .40569 L
.91722 .25961 L
.91724 .30257 L
.91727 .40139 L
.91729 .32835 L
.91731 .21664 L
.91733 .19516 L
.91735 .25961 L
.91738 .29828 L
.9174 .2725 L
.91742 .27679 L
.91744 .30687 L
.91747 .33694 L
.91749 .35413 L
.91751 .32835 L
.91753 .25531 L
.91756 .25961 L
.91758 .25531 L
.9176 .22094 L
.91762 .23813 L
.91764 .2725 L
.91767 .3842 L
.91769 .47013 L
.91771 .30257 L
.91773 .2682 L
.91776 .37991 L
.91778 .35413 L
.9178 .2725 L
.91782 .20376 L
.91785 .25102 L
.91787 .29398 L
.91789 .25961 L
.91791 .30257 L
.91794 .32405 L
.91796 .31976 L
.91798 .33265 L
.918 .32405 L
.91802 .28968 L
.91805 .26391 L
Mistroke
.91807 .25102 L
.91809 .24242 L
.91811 .22094 L
.91814 .25102 L
.91816 .28968 L
.91818 .42717 L
.9182 .42717 L
.91823 .25531 L
.91825 .2725 L
.91827 .37991 L
.91829 .33265 L
.91831 .23383 L
.91834 .20376 L
.91836 .26391 L
.91838 .2725 L
.9184 .28109 L
.91843 .31546 L
.91845 .30687 L
.91847 .29828 L
.91849 .29398 L
.91852 .32835 L
.91854 .29828 L
.91856 .25102 L
.91858 .25102 L
.91861 .22094 L
.91863 .22094 L
.91865 .28109 L
.91867 .33694 L
.91869 .45295 L
.91872 .34983 L
.91874 .22094 L
.91876 .33694 L
.91878 .3842 L
.91881 .30257 L
.91883 .22953 L
.91885 .22524 L
.91887 .28968 L
.9189 .29398 L
.91892 .30687 L
.91894 .31117 L
.91896 .2725 L
.91898 .31117 L
.91901 .34554 L
.91903 .31546 L
.91905 .27679 L
.91907 .25531 L
.9191 .25531 L
.91912 .22953 L
.91914 .25531 L
.91916 .30687 L
Mistroke
.91919 .3842 L
.91921 .42287 L
.91923 .42287 L
.91925 .28968 L
.91927 .25531 L
.9193 .37131 L
.91932 .35413 L
.91934 .26391 L
.91936 .20376 L
.91939 .25531 L
.91941 .30257 L
.91943 .29398 L
.91945 .29828 L
.91948 .2725 L
.9195 .29398 L
.91952 .32835 L
.91954 .33694 L
.91957 .30687 L
.91959 .24242 L
.91961 .25531 L
.91963 .25531 L
.91965 .22094 L
.91968 .27679 L
.9197 .27679 L
.91972 .36702 L
.91974 .42717 L
.91977 .28968 L
.91979 .26391 L
.91981 .35413 L
.91983 .34124 L
.91986 .28109 L
.91988 .21664 L
.9199 .2682 L
.91992 .30687 L
.91994 .2725 L
.91997 .28109 L
.91999 .28539 L
.92001 .31976 L
.92003 .32405 L
.92006 .31976 L
.92008 .31976 L
.9201 .27679 L
.92012 .2682 L
.92015 .2682 L
.92017 .23813 L
.92019 .27679 L
.92021 .30687 L
.92024 .32835 L
.92026 .40569 L
.92028 .33694 L
Mistroke
.9203 .25531 L
.92032 .33265 L
.92035 .35843 L
.92037 .31117 L
.92039 .25102 L
.92041 .25102 L
.92044 .30257 L
.92046 .28539 L
.92048 .28968 L
.9205 .27679 L
.92053 .28968 L
.92055 .31546 L
.92057 .31976 L
.92059 .32835 L
.92061 .28539 L
.92064 .25961 L
.92066 .26391 L
.92068 .25961 L
.9207 .26391 L
.92073 .28968 L
.92075 .28109 L
.92077 .34554 L
.92079 .3928 L
.92082 .2725 L
.92084 .28539 L
.92086 .35843 L
.92088 .33265 L
.9209 .27679 L
.92093 .22524 L
.92095 .28968 L
.92097 .29828 L
.92099 .2682 L
.92102 .2725 L
.92104 .27679 L
.92106 .31976 L
.92108 .30687 L
.92111 .31117 L
.92113 .31546 L
.92115 .2725 L
.92117 .28968 L
.9212 .28539 L
.92122 .25102 L
.92124 .25531 L
.92126 .27679 L
.92128 .2725 L
.92131 .36702 L
.92133 .3885 L
.92135 .2725 L
.92137 .29828 L
.9214 .35843 L
Mistroke
.92142 .35843 L
.92144 .27679 L
.92146 .23383 L
.92149 .30687 L
.92151 .30257 L
.92153 .28109 L
.92155 .25531 L
.92157 .28109 L
.9216 .28109 L
.92162 .33265 L
.92164 .30687 L
.92166 .34124 L
.92169 .31117 L
.92171 .2725 L
.92173 .28968 L
.92175 .2682 L
.92178 .25102 L
.9218 .24242 L
.92182 .28539 L
.92184 .28539 L
.92187 .32405 L
.92189 .3885 L
.92191 .28968 L
.92193 .27679 L
.92195 .34983 L
.92198 .34554 L
.922 .28109 L
.92202 .23383 L
.92204 .28539 L
.92207 .30257 L
.92209 .2682 L
.92211 .25102 L
.92213 .29398 L
.92216 .33694 L
.92218 .29398 L
.9222 .30257 L
.92222 .31117 L
.92224 .27679 L
.92227 .2682 L
.92229 .25961 L
.92231 .25102 L
.92233 .25102 L
.92236 .28968 L
.92238 .28109 L
.9224 .31117 L
.92242 .39709 L
.92245 .30257 L
.92247 .28539 L
.92249 .34124 L
.92251 .33694 L
Mistroke
.92253 .29828 L
.92256 .23383 L
.92258 .28968 L
.9226 .31117 L
.92262 .28539 L
.92265 .28539 L
.92267 .28539 L
.92269 .32835 L
.92271 .29828 L
.92274 .30257 L
.92276 .33265 L
.92278 .27679 L
.9228 .28109 L
.92283 .28968 L
.92285 .25961 L
.92287 .23813 L
.92289 .2725 L
.92291 .29828 L
.92294 .2725 L
.92296 .36272 L
.92298 .37991 L
.923 .25961 L
.92303 .28539 L
.92305 .34983 L
.92307 .34983 L
.92309 .2725 L
.92312 .24672 L
.92314 .30687 L
.92316 .30687 L
.92318 .2725 L
.9232 .25961 L
.92323 .29828 L
.92325 .30257 L
.92327 .27679 L
.92329 .31546 L
.92332 .29828 L
.92334 .2725 L
.92336 .2725 L
.92338 .2682 L
.92341 .25961 L
.92343 .26391 L
.92345 .29828 L
.92347 .2682 L
.9235 .2682 L
.92352 .37991 L
.92354 .35413 L
.92356 .25102 L
.92358 .28109 L
.92361 .34554 L
.92363 .36272 L
Mistroke
.92365 .26391 L
.92367 .26391 L
.9237 .31546 L
.92372 .30257 L
.92374 .28109 L
.92376 .2682 L
.92379 .29828 L
.92381 .30257 L
.92383 .27679 L
.92385 .32405 L
.92387 .28968 L
.9239 .27679 L
.92392 .27679 L
.92394 .2725 L
.92396 .2725 L
.92399 .29398 L
.92401 .28539 L
.92403 .29398 L
.92405 .28109 L
.92408 .25531 L
.9241 .36272 L
.92412 .3885 L
.92414 .25531 L
.92416 .27679 L
.92419 .35843 L
.92421 .3842 L
.92423 .26391 L
.92425 .23383 L
.92428 .33265 L
.9243 .31976 L
.92432 .26391 L
.92434 .25531 L
.92437 .28109 L
.92439 .31117 L
.92441 .26391 L
.92443 .31546 L
.92446 .30257 L
.92448 .2725 L
.9245 .29398 L
.92452 .31976 L
.92454 .28539 L
.92457 .22094 L
.92459 .25102 L
.92461 .32835 L
.92463 .26391 L
.92466 .22953 L
.92468 .3885 L
.9247 .33265 L
.92472 .25961 L
.92475 .31117 L
Mistroke
.92477 .3842 L
.92479 .35413 L
.92481 .24242 L
.92483 .28539 L
.92486 .34554 L
.92488 .28109 L
.9249 .25102 L
.92492 .25102 L
.92495 .31117 L
.92497 .25961 L
.92499 .2725 L
.92501 .32835 L
.92504 .28968 L
.92506 .29398 L
.92508 .29398 L
.9251 .31976 L
.92513 .2725 L
.92515 .24242 L
.92517 .29828 L
.92519 .31546 L
.92521 .25531 L
.92524 .28109 L
.92526 .3885 L
.92528 .34124 L
.9253 .25102 L
.92533 .33265 L
.92535 .3842 L
.92537 .34554 L
.92539 .25531 L
.92542 .28539 L
.92544 .31976 L
.92546 .28539 L
.92548 .26391 L
.9255 .27679 L
.92553 .28968 L
.92555 .25961 L
.92557 .28968 L
.92559 .32405 L
.92562 .28539 L
.92564 .28968 L
.92566 .29828 L
.92568 .31546 L
.92571 .25102 L
.92573 .23813 L
.92575 .29398 L
.92577 .29828 L
.92579 .25961 L
.92582 .23813 L
.92584 .37991 L
.92586 .40139 L
Mistroke
.92588 .24672 L
.92591 .28109 L
.92593 .37131 L
.92595 .37561 L
.92597 .25102 L
.926 .25102 L
.92602 .33265 L
.92604 .28109 L
.92606 .25531 L
.92609 .25961 L
.92611 .28968 L
.92613 .28109 L
.92615 .2725 L
.92617 .34124 L
.9262 .29398 L
.92622 .2725 L
.92624 .29398 L
.92626 .32835 L
.92629 .29398 L
.92631 .22953 L
.92633 .22953 L
.92635 .2725 L
.92638 .32835 L
.9264 .30257 L
.92642 .23813 L
.92644 .27679 L
.92646 .43146 L
.92649 .33265 L
.92651 .24242 L
.92653 .32835 L
.92655 .3928 L
.92658 .31117 L
.9266 .22094 L
.92662 .31117 L
.92664 .33694 L
.92667 .27679 L
.92669 .25961 L
.92671 .28109 L
.92673 .30687 L
.92675 .25531 L
.92678 .29828 L
.9268 .31117 L
.92682 .25961 L
.92684 .27679 L
.92687 .31117 L
.92689 .32835 L
.92691 .23813 L
.92693 .25102 L
.92696 .31117 L
.92698 .31546 L
Mistroke
.927 .27679 L
.92702 .24242 L
.92705 .31117 L
.92707 .3885 L
.92709 .30257 L
.92711 .24672 L
.92713 .29828 L
.92716 .36702 L
.92718 .30257 L
.9272 .25102 L
.92722 .29398 L
.92725 .32405 L
.92727 .28968 L
.92729 .27679 L
.92731 .2682 L
.92734 .29398 L
.92736 .2725 L
.92738 .28968 L
.9274 .28968 L
.92742 .2725 L
.92745 .29398 L
.92747 .32405 L
.92749 .30687 L
.92751 .2682 L
.92754 .28109 L
.92756 .31117 L
.92758 .30257 L
.9276 .28539 L
.92763 .28109 L
.92765 .2725 L
.92767 .33694 L
.92769 .37131 L
.92772 .27679 L
.92774 .2682 L
.92776 .34983 L
.92778 .37131 L
.9278 .28539 L
.92783 .24672 L
.92785 .32835 L
.92787 .33265 L
.92789 .27679 L
.92792 .24672 L
.92794 .29828 L
.92796 .31546 L
.92798 .2682 L
.92801 .28109 L
.92803 .28109 L
.92805 .30257 L
.92807 .30257 L
.92809 .30257 L
Mistroke
.92812 .28968 L
.92814 .2725 L
.92816 .30687 L
.92818 .29398 L
.92821 .2725 L
.92823 .28109 L
.92825 .28539 L
.92827 .28109 L
.9283 .32405 L
.92832 .35413 L
.92834 .24242 L
.92836 .2682 L
.92838 .35413 L
.92841 .35843 L
.92843 .2682 L
.92845 .26391 L
.92847 .34554 L
.9285 .32835 L
.92852 .2725 L
.92854 .25531 L
.92856 .31117 L
.92859 .31117 L
.92861 .25961 L
.92863 .29828 L
.92865 .2682 L
.92868 .29398 L
.9287 .29398 L
.92872 .30257 L
.92874 .30257 L
.92876 .29828 L
.92879 .29828 L
.92881 .32405 L
.92883 .28109 L
.92885 .2725 L
.92888 .30257 L
.9289 .29398 L
.92892 .28109 L
.92894 .28109 L
.92897 .37991 L
.92899 .29398 L
.92901 .25531 L
.92903 .34124 L
.92905 .36272 L
.92908 .29398 L
.9291 .26391 L
.92912 .34983 L
.92914 .34983 L
.92917 .25961 L
.92919 .28109 L
.92921 .30257 L
Mistroke
.92923 .31117 L
.92926 .25961 L
.92928 .28539 L
.9293 .28109 L
.92932 .2725 L
.92935 .30257 L
.92937 .30257 L
.92939 .29398 L
.92941 .28539 L
.92943 .30687 L
.92946 .30687 L
.92948 .26391 L
.9295 .28968 L
.92952 .29398 L
.92955 .28109 L
.92957 .24672 L
.92959 .32835 L
.92961 .37131 L
.92964 .25102 L
.92966 .2682 L
.92968 .35413 L
.9297 .34554 L
.92972 .25531 L
.92975 .26391 L
.92977 .37131 L
.92979 .31546 L
.92981 .24672 L
.92984 .2682 L
.92986 .31117 L
.92988 .29828 L
.9299 .23813 L
.92993 .28968 L
.92995 .29828 L
.92997 .28539 L
.92999 .29828 L
.93001 .29398 L
.93004 .29828 L
.93006 .28968 L
.93008 .31976 L
.9301 .30257 L
.93013 .26391 L
.93015 .28968 L
.93017 .30687 L
.93019 .28968 L
.93022 .24672 L
.93024 .32405 L
.93026 .36702 L
.93028 .25102 L
.93031 .2725 L
.93033 .35843 L
Mistroke
.93035 .34554 L
.93037 .25102 L
.93039 .25961 L
.93042 .37561 L
.93044 .31117 L
.93046 .24672 L
.93048 .28109 L
.93051 .32405 L
.93053 .31117 L
.93055 .23383 L
.93057 .28968 L
.9306 .30257 L
.93062 .28109 L
.93064 .29398 L
.93066 .28539 L
.93068 .30257 L
.93071 .28539 L
.93073 .29828 L
.93075 .29828 L
.93077 .26391 L
.9308 .29828 L
.93082 .28539 L
.93084 .28109 L
.93086 .25531 L
.93089 .2682 L
.93091 .36702 L
.93093 .28109 L
.93095 .23383 L
.93098 .32835 L
.931 .34983 L
.93102 .28539 L
.93104 .23813 L
.93106 .23813 L
.93109 .34554 L
.93111 .34554 L
.93113 .25961 L
.93115 .28109 L
.93118 .30257 L
.9312 .32835 L
.93122 .25102 L
.93124 .25531 L
.93127 .31546 L
.93129 .28539 L
.93131 .28968 L
.93133 .2725 L
.93135 .30687 L
.93138 .31976 L
.9314 .27679 L
.93142 .30687 L
.93144 .28968 L
Mistroke
.93147 .30257 L
.93149 .2682 L
.93151 .2682 L
.93153 .30257 L
.93156 .26391 L
.93158 .27679 L
.9316 .34554 L
.93162 .28968 L
.93164 .26391 L
.93167 .31117 L
.93169 .35843 L
.93171 .28539 L
.93173 .25531 L
.93176 .34124 L
.93178 .34124 L
.9318 .2682 L
.93182 .2682 L
.93185 .30687 L
.93187 .34124 L
.93189 .25102 L
.93191 .25961 L
.93194 .31976 L
.93196 .30257 L
.93198 .2682 L
.932 .2725 L
.93202 .32835 L
.93205 .31117 L
.93207 .25531 L
.93209 .28539 L
.93211 .29828 L
.93214 .29398 L
.93216 .24672 L
.93218 .27679 L
.9322 .30687 L
.93223 .26391 L
.93225 .25531 L
.93227 .34124 L
.93229 .30687 L
.93231 .25102 L
.93234 .30687 L
.93236 .35843 L
.93238 .29398 L
.9324 .25531 L
.93243 .32405 L
.93245 .34983 L
.93247 .2725 L
.93249 .28109 L
.93252 .31976 L
.93254 .33694 L
.93256 .26391 L
Mistroke
.93258 .26391 L
.93261 .33265 L
.93263 .30257 L
.93265 .27679 L
.93267 .28968 L
.93269 .31976 L
.93272 .30257 L
.93274 .25961 L
.93276 .30257 L
.93278 .30687 L
.93281 .28968 L
.93283 .26391 L
.93285 .28968 L
.93287 .30687 L
.9329 .27679 L
.93292 .25531 L
.93294 .30257 L
.93296 .34554 L
.93298 .2682 L
.93301 .28109 L
.93303 .35413 L
.93305 .31546 L
.93307 .26391 L
.9331 .29398 L
.93312 .34983 L
.93314 .30687 L
.93316 .2725 L
.93319 .31117 L
.93321 .32405 L
.93323 .30687 L
.93325 .26391 L
.93327 .30687 L
.9333 .32405 L
.93332 .28539 L
.93334 .28968 L
.93336 .29398 L
.93339 .29828 L
.93341 .2725 L
.93343 .2725 L
.93345 .28109 L
.93348 .30687 L
.9335 .28968 L
.93352 .28109 L
.93354 .2725 L
.93357 .28109 L
.93359 .28109 L
.93361 .2725 L
.93363 .28539 L
.93365 .31117 L
.93368 .32405 L
Mistroke
.9337 .26391 L
.93372 .29828 L
.93374 .33694 L
.93377 .29828 L
.93379 .28968 L
.93381 .30687 L
.93383 .34124 L
.93386 .31117 L
.93388 .28539 L
.9339 .31117 L
.93392 .31546 L
.93394 .31976 L
.93397 .28539 L
.93399 .31117 L
.93401 .32405 L
.93403 .28968 L
.93406 .28109 L
.93408 .28539 L
.9341 .30257 L
.93412 .28539 L
.93415 .28109 L
.93417 .30257 L
.93419 .29398 L
.93421 .2682 L
.93424 .2682 L
.93426 .29828 L
.93428 .28539 L
.9343 .2725 L
.93432 .29398 L
.93435 .29398 L
.93437 .31976 L
.93439 .28109 L
.93441 .2682 L
.93444 .33694 L
.93446 .31976 L
.93448 .28968 L
.9345 .29828 L
.93453 .32405 L
.93455 .31976 L
.93457 .27679 L
.93459 .31117 L
.93461 .32405 L
.93464 .31117 L
.93466 .29828 L
.93468 .28968 L
.9347 .31546 L
.93473 .29828 L
.93475 .28109 L
.93477 .29828 L
.93479 .29828 L
Mistroke
.93482 .29398 L
.93484 .26391 L
.93486 .28539 L
.93488 .29828 L
.9349 .27679 L
.93493 .28109 L
.93495 .28968 L
.93497 .28968 L
.93499 .28109 L
.93502 .26391 L
.93504 .28968 L
.93506 .28539 L
.93508 .31546 L
.93511 .30257 L
.93513 .26391 L
.93515 .33265 L
.93517 .30687 L
.9352 .27679 L
.93522 .31117 L
.93524 .31976 L
.93526 .32835 L
.93528 .29398 L
.93531 .30257 L
.93533 .32405 L
.93535 .30257 L
.93537 .30687 L
.9354 .28539 L
.93542 .31976 L
.93544 .31117 L
.93546 .2725 L
.93549 .28968 L
.93551 .29828 L
.93553 .29398 L
.93555 .2725 L
.93557 .28539 L
.9356 .30687 L
.93562 .2725 L
.93564 .2682 L
.93566 .28968 L
.93569 .28968 L
.93571 .27679 L
.93573 .2725 L
.93575 .29828 L
.93578 .28539 L
.9358 .28539 L
.93582 .27679 L
.93584 .29398 L
.93587 .30257 L
.93589 .27679 L
.93591 .30257 L
Mistroke
.93593 .31546 L
.93595 .28539 L
.93598 .29828 L
.936 .29828 L
.93602 .29828 L
.93604 .30687 L
.93607 .29398 L
.93609 .30687 L
.93611 .30257 L
.93613 .29828 L
.93616 .28968 L
.93618 .29398 L
.9362 .31117 L
.93622 .30257 L
.93624 .29398 L
.93627 .29828 L
.93629 .29828 L
.93631 .29398 L
.93633 .28109 L
.93636 .28968 L
.93638 .29828 L
.9364 .28968 L
.93642 .28109 L
.93645 .28539 L
.93647 .29398 L
.93649 .28968 L
.93651 .28539 L
.93653 .28968 L
.93656 .30257 L
.93658 .29398 L
.9366 .28539 L
.93662 .28968 L
.93665 .30257 L
.93667 .28539 L
.93669 .28109 L
.93671 .30687 L
.93674 .29828 L
.93676 .28968 L
.93678 .29398 L
.9368 .28968 L
.93683 .29398 L
.93685 .29828 L
.93687 .29828 L
.93689 .30257 L
.93691 .30687 L
.93694 .29398 L
.93696 .29398 L
.93698 .30257 L
.937 .29828 L
.93703 .30257 L
Mistroke
.93705 .29828 L
.93707 .30257 L
.93709 .29398 L
.93712 .29398 L
.93714 .29828 L
.93716 .29398 L
.93718 .30257 L
.9372 .29398 L
.93723 .29398 L
.93725 .29398 L
.93727 .28539 L
.93729 .29398 L
.93732 .28968 L
.93734 .29828 L
.93736 .29828 L
.93738 .28539 L
.93741 .28539 L
.93743 .28968 L
.93745 .28539 L
.93747 .28968 L
.9375 .29828 L
.93752 .29828 L
.93754 .28539 L
.93756 .28539 L
.93758 .28968 L
.93761 .29828 L
.93763 .29398 L
.93765 .30257 L
.93767 .30257 L
.9377 .29828 L
.93772 .28968 L
.93774 .29828 L
.93776 .31117 L
.93779 .30257 L
.93781 .30257 L
.93783 .30687 L
.93785 .30257 L
.93787 .29828 L
.9379 .29398 L
.93792 .30687 L
.93794 .30257 L
.93796 .29398 L
.93799 .30257 L
.93801 .29828 L
.93803 .28968 L
.93805 .28539 L
.93808 .30257 L
.9381 .30687 L
.93812 .29398 L
.93814 .29398 L
Mistroke
.93816 .29398 L
.93819 .29828 L
.93821 .29398 L
.93823 .28539 L
.93825 .28968 L
.93828 .30687 L
.9383 .29828 L
.93832 .28109 L
.93834 .28539 L
.93837 .29398 L
.93839 .28968 L
.93841 .28539 L
.93843 .29828 L
.93846 .30257 L
.93848 .28968 L
.9385 .28109 L
.93852 .28968 L
.93854 .29398 L
.93857 .29828 L
.93859 .29828 L
.93861 .30257 L
.93863 .29828 L
.93866 .28968 L
.93868 .28968 L
.9387 .30257 L
.93872 .30257 L
.93875 .30687 L
.93877 .30257 L
.93879 .30257 L
.93881 .29828 L
.93883 .29398 L
.93886 .30257 L
.93888 .30687 L
.9389 .30687 L
.93892 .30257 L
.93895 .30257 L
.93897 .30257 L
.93899 .29398 L
.93901 .29828 L
.93904 .30257 L
.93906 .30257 L
.93908 .30257 L
.9391 .29828 L
.93913 .29828 L
.93915 .28968 L
.93917 .28968 L
.93919 .29398 L
.93921 .29828 L
.93924 .29828 L
.93926 .28968 L
Mistroke
.93928 .28968 L
.9393 .28539 L
.93933 .28539 L
.93935 .28968 L
.93937 .29398 L
.93939 .29828 L
.93942 .28968 L
.93944 .28539 L
.93946 .28539 L
.93948 .28968 L
.9395 .29828 L
.93953 .29828 L
.93955 .29828 L
.93957 .29828 L
.93959 .29398 L
.93962 .28968 L
.93964 .29828 L
.93966 .30257 L
.93968 .30687 L
.93971 .30257 L
.93973 .29828 L
.93975 .29828 L
.93977 .29398 L
.93979 .29828 L
.93982 .30257 L
.93984 .30257 L
.93986 .29398 L
.93988 .29398 L
.93991 .29828 L
.93993 .29398 L
.93995 .29398 L
.93997 .29398 L
.94 .30257 L
.94002 .30257 L
.94004 .29398 L
.94006 .29398 L
.94009 .28968 L
.94011 .29398 L
.94013 .29398 L
.94015 .29828 L
.94017 .30257 L
.9402 .29398 L
.94022 .28968 L
.94024 .28968 L
.94026 .28968 L
.94029 .29398 L
.94031 .29398 L
.94033 .29828 L
.94035 .29398 L
.94038 .28968 L
Mistroke
.9404 .28968 L
.94042 .28968 L
.94044 .29398 L
.94046 .29828 L
.94049 .29828 L
.94051 .29828 L
.94053 .29398 L
.94055 .29398 L
.94058 .29398 L
.9406 .29398 L
.94062 .29828 L
.94064 .30257 L
.94067 .29828 L
.94069 .28968 L
.94071 .28968 L
.94073 .29398 L
.94076 .28968 L
.94078 .29398 L
.9408 .29828 L
.94082 .29828 L
.94084 .28968 L
.94087 .28968 L
.94089 .28968 L
.94091 .29398 L
.94093 .29398 L
.94096 .29398 L
.94098 .29828 L
.941 .29398 L
.94102 .28539 L
.94105 .28539 L
.94107 .28968 L
.94109 .29828 L
.94111 .29828 L
.94113 .29398 L
.94116 .28968 L
.94118 .28968 L
.9412 .28968 L
.94122 .28968 L
.94125 .29398 L
.94127 .29828 L
.94129 .29828 L
.94131 .29828 L
.94134 .29398 L
.94136 .29398 L
.94138 .29398 L
.9414 .30257 L
.94142 .30687 L
.94145 .30257 L
.94147 .30257 L
.94149 .30257 L
Mistroke
.94151 .29828 L
.94154 .29828 L
.94156 .30257 L
.94158 .30687 L
.9416 .30687 L
.94163 .30257 L
.94165 .29398 L
.94167 .29398 L
.94169 .29398 L
.94172 .29398 L
.94174 .29828 L
.94176 .29828 L
.94178 .29828 L
.9418 .29398 L
.94183 .28968 L
.94185 .29398 L
.94187 .29828 L
.94189 .29398 L
.94192 .29828 L
.94194 .29828 L
.94196 .29398 L
.94198 .28539 L
.94201 .28539 L
.94203 .29398 L
.94205 .29398 L
.94207 .29398 L
.94209 .28968 L
.94212 .28968 L
.94214 .28539 L
.94216 .28539 L
.94218 .28968 L
.94221 .29398 L
.94223 .29398 L
.94225 .28968 L
.94227 .28968 L
.9423 .28968 L
.94232 .28968 L
.94234 .28968 L
.94236 .29398 L
.94239 .29828 L
.94241 .29828 L
.94243 .29828 L
.94245 .29828 L
.94247 .29828 L
.9425 .29828 L
.94252 .30257 L
.94254 .30687 L
.94256 .30687 L
.94259 .30257 L
.94261 .30257 L
Mistroke
.94263 .29828 L
.94265 .29828 L
.94268 .29828 L
.9427 .30257 L
.94272 .30257 L
.94274 .29828 L
.94276 .29828 L
.94279 .29398 L
.94281 .29398 L
.94283 .29398 L
.94285 .29398 L
.94288 .29398 L
.9429 .29828 L
.94292 .29398 L
.94294 .29398 L
.94297 .29398 L
.94299 .28968 L
.94301 .28968 L
.94303 .28968 L
.94305 .29398 L
.94308 .29398 L
.9431 .29398 L
.94312 .28968 L
.94314 .28539 L
.94317 .28539 L
.94319 .28968 L
.94321 .29398 L
.94323 .28968 L
.94326 .28968 L
.94328 .28968 L
.9433 .28968 L
.94332 .28968 L
.94335 .28968 L
.94337 .29828 L
.94339 .29398 L
.94341 .28968 L
.94343 .29398 L
.94346 .29398 L
.94348 .29398 L
.9435 .29398 L
.94352 .29828 L
.94355 .29828 L
.94357 .29398 L
.94359 .29398 L
.94361 .29828 L
.94364 .29828 L
.94366 .30257 L
.94368 .29828 L
.9437 .30257 L
.94372 .30257 L
Mistroke
.94375 .29828 L
.94377 .29828 L
.94379 .30257 L
.94381 .30257 L
.94384 .30257 L
.94386 .29828 L
.94388 .29828 L
.9439 .29828 L
.94393 .29828 L
.94395 .29398 L
.94397 .29828 L
.94399 .29828 L
.94401 .29398 L
.94404 .29398 L
.94406 .29398 L
.94408 .29398 L
.9441 .29398 L
.94413 .29398 L
.94415 .29398 L
.94417 .29398 L
.94419 .29398 L
.94422 .28968 L
.94424 .29398 L
.94426 .29398 L
.94428 .29398 L
.94431 .29828 L
.94433 .29828 L
.94435 .29398 L
.94437 .29398 L
.94439 .29398 L
.94442 .29398 L
.94444 .29398 L
.94446 .29398 L
.94448 .29398 L
.94451 .29398 L
.94453 .29398 L
.94455 .29398 L
.94457 .29398 L
.9446 .29398 L
.94462 .29398 L
.94464 .29398 L
.94466 .29398 L
.94468 .29398 L
.94471 .28968 L
.94473 .29398 L
.94475 .29828 L
.94477 .29828 L
.9448 .29828 L
.94482 .29828 L
.94484 .29828 L
Mistroke
.94486 .29828 L
.94489 .29828 L
.94491 .30257 L
.94493 .30257 L
.94495 .30257 L
.94498 .29828 L
.945 .29828 L
.94502 .29828 L
.94504 .29828 L
.94506 .29828 L
.94509 .30257 L
.94511 .29828 L
.94513 .29828 L
.94515 .29398 L
.94518 .29828 L
.9452 .29828 L
.94522 .29828 L
.94524 .29828 L
.94527 .29828 L
.94529 .29828 L
.94531 .29398 L
.94533 .29398 L
.94535 .29398 L
.94538 .29828 L
.9454 .29828 L
.94542 .29828 L
.94544 .29398 L
.94547 .29828 L
.94549 .29398 L
.94551 .29398 L
.94553 .29398 L
.94556 .29398 L
.94558 .29398 L
.9456 .29398 L
.94562 .29398 L
.94564 .28968 L
.94567 .29398 L
.94569 .28968 L
.94571 .29398 L
.94573 .29398 L
.94576 .28968 L
.94578 .29398 L
.9458 .28968 L
.94582 .28968 L
.94585 .28968 L
.94587 .29398 L
.94589 .29398 L
.94591 .29398 L
.94594 .28968 L
.94596 .29398 L
Mistroke
.94598 .29398 L
.946 .29398 L
.94602 .29398 L
.94605 .29828 L
.94607 .29828 L
.94609 .29828 L
.94611 .30257 L
.94614 .30257 L
.94616 .29828 L
.94618 .29828 L
.9462 .29828 L
.94623 .30257 L
.94625 .29828 L
.94627 .29828 L
.94629 .29828 L
.94631 .29828 L
.94634 .29828 L
.94636 .29398 L
.94638 .29828 L
.9464 .29398 L
.94643 .29398 L
.94645 .29398 L
.94647 .29828 L
.94649 .29398 L
.94652 .29398 L
.94654 .29828 L
.94656 .28968 L
.94658 .28968 L
.94661 .29398 L
.94663 .29398 L
.94665 .29398 L
.94667 .29398 L
.94669 .29398 L
.94672 .28968 L
.94674 .28968 L
.94676 .28968 L
.94678 .29398 L
.94681 .29398 L
.94683 .28968 L
.94685 .28968 L
.94687 .28539 L
.9469 .28539 L
.94692 .28968 L
.94694 .28968 L
.94696 .29398 L
.94698 .28968 L
.94701 .28968 L
.94703 .28968 L
.94705 .28968 L
.94707 .28968 L
Mistroke
.9471 .28968 L
.94712 .28968 L
.94714 .29398 L
.94716 .29398 L
.94719 .29398 L
.94721 .29398 L
.94723 .29398 L
.94725 .29398 L
.94727 .29828 L
.9473 .29828 L
.94732 .30257 L
.94734 .30257 L
.94736 .30257 L
.94739 .29828 L
.94741 .29828 L
.94743 .30257 L
.94745 .30257 L
.94748 .29828 L
.9475 .29828 L
.94752 .29828 L
.94754 .29828 L
.94757 .29828 L
.94759 .29828 L
.94761 .29828 L
.94763 .29828 L
.94765 .29828 L
.94768 .29828 L
.9477 .29398 L
.94772 .29398 L
.94774 .29398 L
.94777 .29398 L
.94779 .29828 L
.94781 .29398 L
.94783 .29398 L
.94786 .29398 L
.94788 .29398 L
.9479 .29398 L
.94792 .29398 L
.94794 .29398 L
.94797 .29398 L
.94799 .29398 L
.94801 .28968 L
.94803 .28968 L
.94806 .28968 L
.94808 .29398 L
.9481 .29398 L
.94812 .29398 L
.94815 .28968 L
.94817 .28968 L
.94819 .28968 L
Mistroke
.94821 .28968 L
.94824 .29398 L
.94826 .29398 L
.94828 .29398 L
.9483 .29398 L
.94832 .28968 L
.94835 .28968 L
.94837 .29398 L
.94839 .29828 L
.94841 .30257 L
.94844 .30257 L
.94846 .29828 L
.94848 .29398 L
.9485 .29398 L
.94853 .29828 L
.94855 .30257 L
.94857 .30687 L
.94859 .30687 L
.94861 .30257 L
.94864 .29828 L
.94866 .29398 L
.94868 .29828 L
.9487 .29828 L
.94873 .30257 L
.94875 .30257 L
.94877 .29828 L
.94879 .29828 L
.94882 .29398 L
.94884 .29828 L
.94886 .29828 L
.94888 .30257 L
.9489 .30257 L
.94893 .30257 L
.94895 .29828 L
.94897 .29398 L
.94899 .29398 L
.94902 .29828 L
.94904 .29828 L
.94906 .30257 L
.94908 .30257 L
.94911 .29828 L
.94913 .29398 L
.94915 .29398 L
.94917 .29828 L
.9492 .29398 L
.94922 .29398 L
.94924 .29398 L
.94926 .29398 L
.94928 .29398 L
.94931 .28968 L
Mistroke
.94933 .29398 L
.94935 .29398 L
.94937 .29398 L
.9494 .29398 L
.94942 .29398 L
.94944 .29398 L
.94946 .28968 L
.94949 .29398 L
.94951 .29398 L
.94953 .29398 L
.94955 .29398 L
.94957 .29398 L
.9496 .29398 L
.94962 .29828 L
.94964 .29828 L
.94966 .30257 L
.94969 .30257 L
.94971 .29828 L
.94973 .29398 L
.94975 .29828 L
.94978 .30687 L
.9498 .30257 L
.94982 .30257 L
.94984 .30257 L
.94987 .29828 L
.94989 .29398 L
.94991 .29828 L
.94993 .30257 L
.94995 .30257 L
.94998 .30257 L
.95 .29828 L
.95002 .29828 L
.95004 .29828 L
.95007 .29398 L
.95009 .29828 L
.95011 .29828 L
.95013 .29828 L
.95016 .29828 L
.95018 .29828 L
.9502 .29398 L
.95022 .29398 L
.95024 .29828 L
.95027 .29398 L
.95029 .29828 L
.95031 .29828 L
.95033 .29828 L
.95036 .29828 L
.95038 .29398 L
.9504 .29398 L
.95042 .29398 L
Mistroke
.95045 .28968 L
.95047 .29398 L
.95049 .29398 L
.95051 .29398 L
.95053 .28968 L
.95056 .28968 L
.95058 .28539 L
.9506 .28968 L
.95062 .29398 L
.95065 .28968 L
.95067 .29398 L
.95069 .28968 L
.95071 .28539 L
.95074 .28968 L
.95076 .28968 L
.95078 .29398 L
.9508 .29398 L
.95083 .29398 L
.95085 .28968 L
.95087 .28968 L
.95089 .29398 L
.95091 .29828 L
.95094 .29828 L
.95096 .29828 L
.95098 .29828 L
.951 .29828 L
.95103 .29828 L
.95105 .29828 L
.95107 .30257 L
.95109 .29828 L
.95112 .29828 L
.95114 .30257 L
.95116 .29828 L
.95118 .29398 L
.9512 .29398 L
.95123 .29398 L
.95125 .29828 L
.95127 .29398 L
.95129 .29398 L
.95132 .29398 L
.95134 .29398 L
.95136 .29398 L
.95138 .28968 L
.95141 .29398 L
.95143 .29828 L
.95145 .29398 L
.95147 .29398 L
.9515 .29398 L
.95152 .29398 L
.95154 .29398 L
Mistroke
.95156 .29398 L
.95158 .29828 L
.95161 .29398 L
.95163 .29398 L
.95165 .28968 L
.95167 .28968 L
.9517 .28968 L
.95172 .29398 L
.95174 .28968 L
.95176 .28968 L
.95179 .29398 L
.95181 .28539 L
.95183 .28109 L
.95185 .28968 L
.95187 .28968 L
.9519 .29398 L
.95192 .28968 L
.95194 .28539 L
.95196 .28968 L
.95199 .28968 L
.95201 .28968 L
.95203 .29398 L
.95205 .29828 L
.95208 .29398 L
.9521 .29398 L
.95212 .29398 L
.95214 .29398 L
.95216 .29828 L
.95219 .29828 L
.95221 .29828 L
.95223 .30257 L
.95225 .30257 L
.95228 .29828 L
.9523 .29828 L
.95232 .29828 L
.95234 .29828 L
.95237 .29828 L
.95239 .30257 L
.95241 .29828 L
.95243 .29828 L
.95246 .29828 L
.95248 .29398 L
.9525 .29398 L
.95252 .29398 L
.95254 .29828 L
.95257 .29828 L
.95259 .29828 L
.95261 .29398 L
.95263 .29398 L
.95266 .29398 L
Mistroke
.95268 .29398 L
.9527 .29828 L
.95272 .30257 L
.95275 .30257 L
.95277 .29828 L
.95279 .29398 L
.95281 .29398 L
.95283 .29398 L
.95286 .29828 L
.95288 .29828 L
.9529 .29828 L
.95292 .29398 L
.95295 .29398 L
.95297 .28968 L
.95299 .28968 L
.95301 .29398 L
.95304 .29398 L
.95306 .29398 L
.95308 .28968 L
.9531 .28968 L
.95313 .28968 L
.95315 .28968 L
.95317 .28968 L
.95319 .29398 L
.95321 .29828 L
.95324 .29398 L
.95326 .29398 L
.95328 .29398 L
.9533 .29398 L
.95333 .29828 L
.95335 .30257 L
.95337 .30257 L
.95339 .30257 L
.95342 .30257 L
.95344 .30257 L
.95346 .30257 L
.95348 .30257 L
.9535 .30257 L
.95353 .30257 L
.95355 .30687 L
.95357 .30257 L
.95359 .30257 L
.95362 .29828 L
.95364 .29828 L
.95366 .29828 L
.95368 .29828 L
.95371 .29828 L
.95373 .29828 L
.95375 .29828 L
.95377 .29828 L
Mistroke
.95379 .29828 L
.95382 .29828 L
.95384 .29828 L
.95386 .29828 L
.95388 .29828 L
.95391 .29828 L
.95393 .29828 L
.95395 .30257 L
.95397 .29828 L
.954 .29828 L
.95402 .29828 L
.95404 .29828 L
.95406 .29828 L
.95409 .29828 L
.95411 .29828 L
.95413 .29398 L
.95415 .29398 L
.95417 .28968 L
.9542 .29398 L
.95422 .29398 L
.95424 .29398 L
.95426 .29398 L
.95429 .28968 L
.95431 .28968 L
.95433 .28539 L
.95435 .28968 L
.95438 .28968 L
.9544 .29398 L
.95442 .29398 L
.95444 .29398 L
.95446 .29398 L
.95449 .28968 L
.95451 .28968 L
.95453 .29398 L
.95455 .29828 L
.95458 .30257 L
.9546 .30257 L
.95462 .30257 L
.95464 .29828 L
.95467 .29828 L
.95469 .29828 L
.95471 .29828 L
.95473 .30257 L
.95476 .30687 L
.95478 .30257 L
.9548 .29828 L
.95482 .29398 L
.95484 .29398 L
.95487 .29398 L
.95489 .29398 L
Mistroke
.95491 .29828 L
.95493 .29828 L
.95496 .29398 L
.95498 .28968 L
.955 .28968 L
.95502 .28968 L
.95505 .29398 L
.95507 .29828 L
.95509 .29828 L
.95511 .29828 L
.95513 .28968 L
.95516 .28968 L
.95518 .28968 L
.9552 .29398 L
.95522 .29828 L
.95525 .29828 L
.95527 .29828 L
.95529 .28968 L
.95531 .28968 L
.95534 .28968 L
.95536 .28968 L
.95538 .29398 L
.9554 .29398 L
.95542 .29398 L
.95545 .28968 L
.95547 .28539 L
.95549 .28539 L
.95551 .28968 L
.95554 .28968 L
.95556 .28968 L
.95558 .28968 L
.9556 .28968 L
.95563 .28968 L
.95565 .28968 L
.95567 .28968 L
.95569 .28968 L
.95572 .28968 L
.95574 .29398 L
.95576 .29398 L
.95578 .29398 L
.9558 .29828 L
.95583 .29828 L
.95585 .29398 L
.95587 .29398 L
.95589 .29828 L
.95592 .29828 L
.95594 .30257 L
.95596 .29828 L
.95598 .29828 L
.95601 .29828 L
Mistroke
.95603 .29398 L
.95605 .29398 L
.95607 .29828 L
.95609 .29828 L
.95612 .29398 L
.95614 .29398 L
.95616 .28968 L
.95618 .28968 L
.95621 .28968 L
.95623 .29398 L
.95625 .29398 L
.95627 .29398 L
.9563 .29398 L
.95632 .28968 L
.95634 .28968 L
.95636 .29398 L
.95639 .29398 L
.95641 .29828 L
.95643 .29828 L
.95645 .29398 L
.95647 .29398 L
.9565 .28968 L
.95652 .28968 L
.95654 .29398 L
.95656 .29828 L
.95659 .29828 L
.95661 .29398 L
.95663 .28968 L
.95665 .28968 L
.95668 .28968 L
.9567 .28968 L
.95672 .29398 L
.95674 .29398 L
.95676 .28968 L
.95679 .28968 L
.95681 .28539 L
.95683 .28968 L
.95685 .29398 L
.95688 .29398 L
.9569 .28968 L
.95692 .28968 L
.95694 .28968 L
.95697 .29398 L
.95699 .29828 L
.95701 .29828 L
.95703 .29828 L
.95705 .29828 L
.95708 .29398 L
.9571 .29398 L
.95712 .29828 L
Mistroke
.95714 .29828 L
.95717 .30257 L
.95719 .30257 L
.95721 .29828 L
.95723 .29398 L
.95726 .29398 L
.95728 .29828 L
.9573 .30257 L
.95732 .30257 L
.95735 .29828 L
.95737 .29398 L
.95739 .28968 L
.95741 .28968 L
.95743 .29398 L
.95746 .30257 L
.95748 .30257 L
.9575 .29828 L
.95752 .29398 L
.95755 .28968 L
.95757 .28968 L
.95759 .29398 L
.95761 .30257 L
.95764 .30257 L
.95766 .29828 L
.95768 .29398 L
.9577 .28968 L
.95772 .28968 L
.95775 .29828 L
.95777 .30257 L
.95779 .30257 L
.95781 .29828 L
.95784 .29398 L
.95786 .28968 L
.95788 .28968 L
.9579 .29398 L
.95793 .29828 L
.95795 .30257 L
.95797 .29398 L
.95799 .28968 L
.95802 .28539 L
.95804 .28968 L
.95806 .29398 L
.95808 .29828 L
.9581 .29828 L
.95813 .29398 L
.95815 .28968 L
.95817 .28968 L
.95819 .29398 L
.95822 .29828 L
.95824 .30257 L
Mistroke
.95826 .30257 L
.95828 .30257 L
.95831 .29828 L
.95833 .29828 L
.95835 .29828 L
.95837 .30257 L
.95839 .30687 L
.95842 .30687 L
.95844 .30257 L
.95846 .30257 L
.95848 .29828 L
.95851 .29828 L
.95853 .30257 L
.95855 .30257 L
.95857 .30257 L
.9586 .29828 L
.95862 .29398 L
.95864 .29398 L
.95866 .29398 L
.95868 .29828 L
.95871 .30257 L
.95873 .29828 L
.95875 .29398 L
.95877 .29398 L
.9588 .29398 L
.95882 .29828 L
.95884 .29828 L
.95886 .29828 L
.95889 .29828 L
.95891 .29398 L
.95893 .29398 L
.95895 .29398 L
.95898 .29828 L
.959 .29828 L
.95902 .29828 L
.95904 .29398 L
.95906 .29398 L
.95909 .28968 L
.95911 .29398 L
.95913 .29398 L
.95915 .29828 L
.95918 .29398 L
.9592 .28968 L
.95922 .28539 L
.95924 .28539 L
.95927 .28968 L
.95929 .29398 L
.95931 .29828 L
.95933 .29398 L
.95935 .28968 L
Mistroke
.95938 .28539 L
.9594 .28539 L
.95942 .28539 L
.95944 .29398 L
.95947 .29828 L
.95949 .29828 L
.95951 .30257 L
.95953 .29828 L
.95956 .29398 L
.95958 .29398 L
.9596 .29828 L
.95962 .30257 L
.95964 .30687 L
.95967 .30687 L
.95969 .30257 L
.95971 .29828 L
.95973 .29398 L
.95976 .29828 L
.95978 .29828 L
.9598 .30257 L
.95982 .30257 L
.95985 .30257 L
.95987 .29398 L
.95989 .28968 L
.95991 .28968 L
.95994 .29398 L
.95996 .29828 L
.95998 .29828 L
.96 .29828 L
.96002 .29398 L
.96005 .28968 L
.96007 .28539 L
.96009 .28968 L
.96011 .29828 L
.96014 .29828 L
.96016 .29828 L
.96018 .29398 L
.9602 .28968 L
.96023 .28968 L
.96025 .28968 L
.96027 .29828 L
.96029 .30257 L
.96031 .29828 L
.96034 .29398 L
.96036 .28968 L
.96038 .28539 L
.9604 .28968 L
.96043 .29398 L
.96045 .29828 L
.96047 .29398 L
Mistroke
.96049 .28968 L
.96052 .28968 L
.96054 .28539 L
.96056 .28968 L
.96058 .29398 L
.96061 .29398 L
.96063 .29398 L
.96065 .29398 L
.96067 .29398 L
.96069 .29398 L
.96072 .29398 L
.96074 .29828 L
.96076 .29828 L
.96078 .29828 L
.96081 .29828 L
.96083 .29828 L
.96085 .29828 L
.96087 .29828 L
.9609 .29828 L
.96092 .30257 L
.96094 .30257 L
.96096 .30257 L
.96098 .30257 L
.96101 .29828 L
.96103 .29828 L
.96105 .29398 L
.96107 .29398 L
.9611 .29828 L
.96112 .29828 L
.96114 .29398 L
.96116 .29398 L
.96119 .28968 L
.96121 .28968 L
.96123 .28968 L
.96125 .29398 L
.96127 .29398 L
.9613 .29398 L
.96132 .29398 L
.96134 .28968 L
.96136 .28968 L
.96139 .29398 L
.96141 .29828 L
.96143 .29828 L
.96145 .29398 L
.96148 .28968 L
.9615 .28968 L
.96152 .29398 L
.96154 .29398 L
.96157 .29828 L
.96159 .29828 L
Mistroke
.96161 .29398 L
.96163 .28968 L
.96165 .28968 L
.96168 .28968 L
.9617 .29398 L
.96172 .29398 L
.96174 .29398 L
.96177 .28968 L
.96179 .28968 L
.96181 .28968 L
.96183 .28968 L
.96186 .29398 L
.96188 .29398 L
.9619 .29398 L
.96192 .29398 L
.96194 .29398 L
.96197 .29398 L
.96199 .29398 L
.96201 .29398 L
.96203 .29828 L
.96206 .30257 L
.96208 .30257 L
.9621 .30257 L
.96212 .29828 L
.96215 .29828 L
.96217 .29828 L
.96219 .30257 L
.96221 .30257 L
.96224 .30687 L
.96226 .30257 L
.96228 .29828 L
.9623 .29398 L
.96232 .29398 L
.96235 .29828 L
.96237 .29828 L
.96239 .29828 L
.96241 .29828 L
.96244 .29398 L
.96246 .28968 L
.96248 .28968 L
.9625 .28968 L
.96253 .29398 L
.96255 .29398 L
.96257 .29398 L
.96259 .29398 L
.96261 .28968 L
.96264 .28968 L
.96266 .28968 L
.96268 .29398 L
.9627 .29828 L
Mistroke
.96273 .29398 L
.96275 .29398 L
.96277 .28968 L
.96279 .28968 L
.96282 .29398 L
.96284 .29398 L
.96286 .29828 L
.96288 .29398 L
.9629 .28968 L
.96293 .28968 L
.96295 .28968 L
.96297 .29398 L
.96299 .29398 L
.96302 .29398 L
.96304 .29398 L
.96306 .28968 L
.96308 .28968 L
.96311 .28968 L
.96313 .29398 L
.96315 .29398 L
.96317 .29398 L
.9632 .29398 L
.96322 .29398 L
.96324 .29398 L
.96326 .29398 L
.96328 .29828 L
.96331 .29828 L
.96333 .29828 L
.96335 .29828 L
.96337 .29828 L
.9634 .29828 L
.96342 .30257 L
.96344 .29828 L
.96346 .29828 L
.96349 .29828 L
.96351 .29828 L
.96353 .29828 L
.96355 .29828 L
.96357 .29828 L
.9636 .29828 L
.96362 .29398 L
.96364 .29398 L
.96366 .29398 L
.96369 .29398 L
.96371 .29398 L
.96373 .29398 L
.96375 .28968 L
.96378 .28968 L
.9638 .29398 L
.96382 .29398 L
Mistroke
.96384 .29398 L
.96387 .29398 L
.96389 .29398 L
.96391 .29398 L
.96393 .29398 L
.96395 .29398 L
.96398 .29398 L
.964 .29398 L
.96402 .29398 L
.96404 .29398 L
.96407 .29828 L
.96409 .29398 L
.96411 .29828 L
.96413 .29828 L
.96416 .29398 L
.96418 .29398 L
.9642 .29398 L
.96422 .29398 L
.96424 .29398 L
.96427 .29828 L
.96429 .29828 L
.96431 .29828 L
.96433 .29398 L
.96436 .28968 L
.96438 .28968 L
.9644 .29398 L
.96442 .29398 L
.96445 .29828 L
.96447 .30257 L
.96449 .29828 L
.96451 .29828 L
.96453 .29398 L
.96456 .29398 L
.96458 .29828 L
.9646 .30687 L
.96462 .30687 L
.96465 .30257 L
.96467 .30257 L
.96469 .29828 L
.96471 .29398 L
.96474 .30257 L
.96476 .30687 L
.96478 .30687 L
.9648 .30257 L
.96483 .29828 L
.96485 .29398 L
.96487 .29398 L
.96489 .29398 L
.96491 .29828 L
.96494 .29828 L
Mistroke
.96496 .29828 L
.96498 .29828 L
.965 .29398 L
.96503 .28968 L
.96505 .28968 L
.96507 .29398 L
.96509 .29828 L
.96512 .30257 L
.96514 .29828 L
.96516 .29398 L
.96518 .28968 L
.9652 .28968 L
.96523 .29398 L
.96525 .30257 L
.96527 .30257 L
.96529 .29828 L
.96532 .29398 L
.96534 .28968 L
.96536 .28968 L
.96538 .29398 L
.96541 .29828 L
.96543 .29828 L
.96545 .29828 L
.96547 .28968 L
.9655 .28968 L
.96552 .28968 L
.96554 .29398 L
.96556 .29828 L
.96558 .29828 L
.96561 .29828 L
.96563 .29398 L
.96565 .28968 L
.96567 .29398 L
.9657 .29398 L
.96572 .29828 L
.96574 .30257 L
.96576 .29828 L
.96579 .29828 L
.96581 .29398 L
.96583 .29828 L
.96585 .29828 L
.96587 .30257 L
.9659 .30257 L
.96592 .30257 L
.96594 .29828 L
.96596 .29828 L
.96599 .29828 L
.96601 .29828 L
.96603 .29828 L
.96605 .29828 L
Mistroke
.96608 .29828 L
.9661 .29828 L
.96612 .29828 L
.96614 .29398 L
.96616 .29398 L
.96619 .29398 L
.96621 .29398 L
.96623 .29398 L
.96625 .29398 L
.96628 .29398 L
.9663 .29398 L
.96632 .28968 L
.96634 .28968 L
.96637 .29398 L
.96639 .29398 L
.96641 .29398 L
.96643 .29398 L
.96646 .29398 L
.96648 .29398 L
.9665 .29398 L
.96652 .29398 L
.96654 .29398 L
.96657 .29398 L
.96659 .29398 L
.96661 .29398 L
.96663 .29398 L
.96666 .29398 L
.96668 .29398 L
.9667 .29398 L
.96672 .28968 L
.96675 .28968 L
.96677 .28968 L
.96679 .28968 L
.96681 .29398 L
.96683 .29398 L
.96686 .28968 L
.96688 .28968 L
.9669 .29398 L
.96692 .28968 L
.96695 .29398 L
.96697 .29398 L
.96699 .29398 L
.96701 .29828 L
.96704 .29398 L
.96706 .29398 L
.96708 .29398 L
.9671 .29398 L
.96713 .29828 L
.96715 .30257 L
.96717 .30257 L
Mistroke
.96719 .29828 L
.96721 .29828 L
.96724 .29398 L
.96726 .29828 L
.96728 .29828 L
.9673 .30257 L
.96733 .30257 L
.96735 .30257 L
.96737 .29828 L
.96739 .29398 L
.96742 .28968 L
.96744 .28968 L
.96746 .29398 L
.96748 .29828 L
.9675 .29828 L
.96753 .29398 L
.96755 .28968 L
.96757 .28539 L
.96759 .28968 L
.96762 .29398 L
.96764 .29828 L
.96766 .29828 L
.96768 .29398 L
.96771 .28968 L
.96773 .28539 L
.96775 .28968 L
.96777 .29828 L
.96779 .30257 L
.96782 .29828 L
.96784 .28968 L
.96786 .28539 L
.96788 .28539 L
.96791 .29828 L
.96793 .30257 L
.96795 .29828 L
.96797 .28968 L
.968 .28109 L
.96802 .28109 L
.96804 .28968 L
.96806 .29828 L
.96809 .29828 L
.96811 .29398 L
.96813 .28539 L
.96815 .28109 L
.96817 .28539 L
.9682 .29398 L
.96822 .29828 L
.96824 .29828 L
.96826 .29828 L
.96829 .28968 L
Mistroke
.96831 .28968 L
.96833 .28968 L
.96835 .29828 L
.96838 .30257 L
.9684 .30257 L
.96842 .29828 L
.96844 .29398 L
.96846 .29398 L
.96849 .29828 L
.96851 .29828 L
.96853 .30257 L
.96855 .30257 L
.96858 .29828 L
.9686 .29398 L
.96862 .28968 L
.96864 .29398 L
.96867 .29828 L
.96869 .29828 L
.96871 .29828 L
.96873 .28968 L
.96876 .28968 L
.96878 .28968 L
.9688 .29398 L
.96882 .29398 L
.96884 .29398 L
.96887 .29398 L
.96889 .28968 L
.96891 .29398 L
.96893 .29828 L
.96896 .29828 L
.96898 .29828 L
.969 .29828 L
.96902 .29398 L
.96905 .28968 L
.96907 .29398 L
.96909 .29828 L
.96911 .29828 L
.96913 .29828 L
.96916 .29828 L
.96918 .28968 L
.9692 .28968 L
.96922 .28968 L
.96925 .29398 L
.96927 .29828 L
.96929 .29828 L
.96931 .29398 L
.96934 .28968 L
.96936 .28968 L
.96938 .28968 L
.9694 .29828 L
Mistroke
.96942 .30257 L
.96945 .29828 L
.96947 .29398 L
.96949 .28968 L
.96951 .29398 L
.96954 .29828 L
.96956 .30257 L
.96958 .30687 L
.9696 .30257 L
.96963 .29828 L
.96965 .29828 L
.96967 .29828 L
.96969 .30257 L
.96972 .30687 L
.96974 .30687 L
.96976 .30687 L
.96978 .30257 L
.9698 .29398 L
.96983 .29828 L
.96985 .29828 L
.96987 .30257 L
.96989 .30257 L
.96992 .30257 L
.96994 .29828 L
.96996 .28968 L
.96998 .28968 L
.97001 .29828 L
.97003 .29828 L
.97005 .30257 L
.97007 .29828 L
.97009 .29398 L
.97012 .29398 L
.97014 .29398 L
.97016 .30257 L
.97018 .30257 L
.97021 .30257 L
.97023 .29828 L
.97025 .29398 L
.97027 .29398 L
.9703 .29398 L
.97032 .29828 L
.97034 .29828 L
.97036 .29398 L
.97039 .28968 L
.97041 .28968 L
.97043 .29398 L
.97045 .29828 L
.97047 .29828 L
.9705 .29398 L
.97052 .28968 L
Mistroke
.97054 .28968 L
.97056 .29398 L
.97059 .29398 L
.97061 .29828 L
.97063 .29828 L
.97065 .29398 L
.97068 .29398 L
.9707 .29398 L
.97072 .29398 L
.97074 .29828 L
.97076 .30257 L
.97079 .30257 L
.97081 .30257 L
.97083 .29828 L
.97085 .29828 L
.97088 .29828 L
.9709 .30257 L
.97092 .30257 L
.97094 .30257 L
.97097 .30257 L
.97099 .29828 L
.97101 .29398 L
.97103 .29828 L
.97105 .29828 L
.97108 .29828 L
.9711 .29828 L
.97112 .29398 L
.97114 .29398 L
.97117 .28968 L
.97119 .29398 L
.97121 .29398 L
.97123 .29398 L
.97126 .29828 L
.97128 .29398 L
.9713 .29398 L
.97132 .29398 L
.97135 .29398 L
.97137 .29398 L
.97139 .29398 L
.97141 .29398 L
.97143 .29398 L
.97146 .29398 L
.97148 .29398 L
.9715 .29398 L
.97152 .28968 L
.97155 .28968 L
.97157 .28968 L
.97159 .28968 L
.97161 .29398 L
.97164 .29398 L
Mistroke
.97166 .29398 L
.97168 .28968 L
.9717 .28539 L
.97172 .28539 L
.97175 .28968 L
.97177 .29398 L
.97179 .29828 L
.97181 .29398 L
.97184 .28539 L
.97186 .28539 L
.97188 .28539 L
.9719 .29398 L
.97193 .29828 L
.97195 .30257 L
.97197 .29828 L
.97199 .29398 L
.97202 .28968 L
.97204 .29398 L
.97206 .29828 L
.97208 .30687 L
.9721 .30687 L
.97213 .30257 L
.97215 .29828 L
.97217 .29398 L
.97219 .29828 L
.97222 .30257 L
.97224 .30257 L
.97226 .30257 L
.97228 .29828 L
.97231 .29398 L
.97233 .28968 L
.97235 .28968 L
.97237 .29398 L
.97239 .29828 L
.97242 .29398 L
.97244 .29398 L
.97246 .28968 L
.97248 .28539 L
.97251 .29398 L
.97253 .29398 L
.97255 .29828 L
.97257 .29398 L
.9726 .29398 L
.97262 .28968 L
.97264 .28968 L
.97266 .29398 L
.97268 .29828 L
.97271 .29828 L
.97273 .29398 L
.97275 .28968 L
Mistroke
.97277 .28968 L
.9728 .28968 L
.97282 .29398 L
.97284 .29398 L
.97286 .29398 L
.97289 .28539 L
.97291 .28539 L
.97293 .28968 L
.97295 .29398 L
.97298 .29398 L
.973 .29398 L
.97302 .28968 L
.97304 .28968 L
.97306 .28968 L
.97309 .29398 L
.97311 .29828 L
.97313 .29828 L
.97315 .29828 L
.97318 .29828 L
.9732 .29828 L
.97322 .29828 L
.97324 .30257 L
.97327 .30257 L
.97329 .30687 L
.97331 .30687 L
.97333 .30257 L
.97335 .30257 L
.97338 .30257 L
.9734 .30257 L
.97342 .30257 L
.97344 .30257 L
.97347 .30257 L
.97349 .30257 L
.97351 .29828 L
.97353 .29398 L
.97356 .29398 L
.97358 .29398 L
.9736 .29828 L
.97362 .29828 L
.97365 .29828 L
.97367 .29398 L
.97369 .28968 L
.97371 .29398 L
.97373 .29828 L
.97376 .29828 L
.97378 .29828 L
.9738 .29828 L
.97382 .28968 L
.97385 .28968 L
.97387 .28968 L
Mistroke
.97389 .29398 L
.97391 .29828 L
.97394 .29828 L
.97396 .29828 L
.97398 .29398 L
.974 .28968 L
.97402 .28968 L
.97405 .29398 L
.97407 .29398 L
.97409 .29828 L
.97411 .29398 L
.97414 .28539 L
.97416 .28539 L
.97418 .28968 L
.9742 .29398 L
.97423 .29398 L
.97425 .29828 L
.97427 .29398 L
.97429 .28968 L
.97431 .28968 L
.97434 .28968 L
.97436 .29828 L
.97438 .30257 L
.9744 .30257 L
.97443 .30257 L
.97445 .29828 L
.97447 .29828 L
.97449 .29828 L
.97452 .30687 L
.97454 .30687 L
.97456 .31117 L
.97458 .30687 L
.97461 .30257 L
.97463 .29828 L
.97465 .29828 L
.97467 .30257 L
.97469 .30257 L
.97472 .30257 L
.97474 .29828 L
.97476 .29828 L
.97478 .29828 L
.97481 .29398 L
.97483 .29398 L
.97485 .29398 L
.97487 .29828 L
.9749 .29828 L
.97492 .29828 L
.97494 .29398 L
.97496 .29398 L
.97498 .28968 L
Mistroke
.97501 .29398 L
.97503 .29828 L
.97505 .29828 L
.97507 .29828 L
.9751 .29398 L
.97512 .28968 L
.97514 .28968 L
.97516 .29398 L
.97519 .29398 L
.97521 .29828 L
.97523 .29398 L
.97525 .28968 L
.97528 .28539 L
.9753 .28539 L
.97532 .28968 L
.97534 .29398 L
.97536 .29398 L
.97539 .28968 L
.97541 .28968 L
.97543 .28539 L
.97545 .28968 L
.97548 .28968 L
.9755 .29398 L
.97552 .29398 L
.97554 .28968 L
.97557 .28968 L
.97559 .29398 L
.97561 .29398 L
.97563 .29828 L
.97565 .29828 L
.97568 .29828 L
.9757 .29828 L
.97572 .30257 L
.97574 .30257 L
.97577 .30257 L
.97579 .30257 L
.97581 .30257 L
.97583 .29828 L
.97586 .30257 L
.97588 .30257 L
.9759 .30257 L
.97592 .29828 L
.97594 .29828 L
.97597 .29398 L
.97599 .29398 L
.97601 .29398 L
.97603 .29398 L
.97606 .29398 L
.97608 .29398 L
.9761 .28968 L
Mistroke
.97612 .29398 L
.97615 .29398 L
.97617 .29398 L
.97619 .29828 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0003gooooo0ol0000mooooo`Go0000
??ooool3o`0003gooooo000Oooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0
?Oooool01?l0003oooooooooool0000kooooo`05o`000?ooooooooooooooool00000??ooool001oo
oooo00Co0000oooooooooooo0000?Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0>_ooool001oooooo00Co0000oooooooooooo0000?Oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo03cooooo0_l0000mooooo`007oooool01?l0003o
ooooooooool0000mooooo`03o`000?oooooooooo03cooooo00Go0000ooooooooooooooooo`00000o
ooooo`03o`000?oooooooooo03[ooooo000Oooooo`04o`000?ooooooooooo`0003cooooo0_l0000n
ooooo`05o`000?ooooooooooooooool00000>oooool01Ol0003ooooooooooooooooo000003cooooo
000Pooooo`;o0000?_ooool00ol0003oooooooooo`0mooooo`?o0000?Oooool3o`0003gooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Kooooo`0300000?l0
003o00000?oo00000Ol000010000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<00000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`05ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool00oooool00`00003oooooooooo`0mooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0iooooo`4000000Oooool001_ooooo00<00000oooooooo
ool0ooooool1ooooo`4000000Oooool001_ooooo00<00000ooooooooool02oooool00`000?oooooo
ooooo`3booooo`4000000Oooool001_ooooo00<00000ooooooooool02oooool00`000?oooooooooo
o`3booooo`4000000Oooool001_ooooo00<00000o`000?ooool02oooool00`000?ooooooooooo`3a
ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`030000oooooooooooo
0?;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`80003oloooool10000007o
oooo000Kooooo`0300000?oooooooooo00_ooooo0P000?nnooooo`030000oooooooooooo03;ooooo
0@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`80003o__ooool00`000?oooooooooo
o`0booooo`4000000Oooool001_ooooo00<00000ooooooooool02oooool20000okkooooo00<0003o
ooooooooool0<_ooool10000007ooooo000Kooooo`0300000?oooooooooo00_ooooo0P000?nnoooo
o`030000oooooooooooo03;ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0;ooooo`<0
003o_Oooool00`000?ooooooooooo`0aooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`0;ooooo`<0003o_Oooool00`000?ooooooooooo`0booooo`4000000Oooool001_ooooo00<0
0000ooooooooool02oooool30000o`03ooooo`000?oooooo08Kooooo00<0003oooooooooool0<Ooo
ool00`000?ooooooooooo`0booooo`4000000Oooool001_ooooo00<00000ooooooooool02oooool3
0000o`03ooooo`000?oooooo07gooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0a
ooooo`030000oooooooooooo03;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0;oooo
o`D0003oO_ooool00`000?ooooooooooo`06ooooo`030000oooooooooooo037ooooo0P000?lcoooo
o`4000000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03
00000?oooooooooo00_ooooo1P000?l[ooooo`030000oooooooooooo04oooooo00<0003ooooooooo
ool01_ooool00`000?ooooooooooo`0aooooo`80003o<oooool10000007ooooo0007ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`0;ooooo`H0
003o:Oooool00`000?oooooo0000o`1@ooooo`80003o2?ooool00`000?ooooooooooo`0aooooo`80
003o1Oooool00`000?ooooooooooo`0[ooooo`4000000Oooool000Go00000_ooool01?l0003ooooo
ooooool00007ooooo`Go00001?ooool00`00003o0000ooooo`0;ooooo`H0003o00?ooooo0000oooo
ool02oooool00`000?ooooooooooo`0Hooooo`030000ooooool0003o04kooooo10000?l8ooooo`03
0000oooooooooooo037ooooo0P000?l4ooooo`80003o;?ooool1o`00004000000Oooool000Oooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo
00_ooooo1P000?l00oooool0003oooooo`0;ooooo`030000oooooooooooo017ooooo00<0003ooooo
ooooool01?ooool00`000?oooooo0000o`1>ooooo`@0003o2?ooool00`000?ooooooooooo`0aoooo
o`80003o1?ooool20000obgooooo0@000001ooooo`001oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo000000Gooooo00<00000ooooooooool02oooool60000o`03ooooo`000?oooooo
00[ooooo0P000?l3ooooo`030000oooooooooooo00gooooo00<0003oooooo`000?l01?ooool01@00
0?oooooo0000ooooool0003o04cooooo10000?l8ooooo`030000oooooooooooo01oooooo00<0003o
ooooooooool03oooool20000o`Cooooo0P000?l]ooooo`4000000Oooool000Oooooo00Co0000oooo
oooooooo00002Oooool2o`0000Gooooo00<00000ooooooooool02oooool60000o`03ooooo`000?oo
oooo00[ooooo0P000?l3ooooo`030000oooooooooooo00gooooo00<0003oooooo`000?l01?ooool0
1@000?oooooo0000ooooool0003o04cooooo10000?l8ooooo`030000oooooooooooo01oooooo00<0
003oooooooooool03oooool20000o`Cooooo0P000?l]ooooo`4000000Oooool000Sooooo0_l0000;
ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool02oooool60000o`03ooooo`000?l0
003o00[ooooo0P000?l01?ooool0003oooooo`000?l?ooooo`030000ooooool0003o00Cooooo00@0
003oooooo`000?oooooo0P000?m;ooooo`@0003o2?ooool00`000?ooooooooooo`0Nooooo`80003o
4Oooool20000o`;ooooo00@0003oooooo`000?l0003o;Oooool10000007ooooo000Kooooo`030000
0?oooooooooo00_ooooo1P000?l00oooool0003o0000o`0:ooooo`80003o00Cooooo0000o`000?l0
003o3oooool01@000?oooooo0000ooooool0003o00;ooooo0`000?l00oooool0003o0000o`1;oooo
o`@0003o2?ooool00`000?oooooo0000o`0Nooooo`80003o4Oooool20000o`;ooooo00@0003ooooo
o`000?l0003o;Oooool10000007ooooo000Kooooo`0300000?oooooooooo00_ooooo1P000?l01?oo
ool0003o0000o`000?l8ooooo`<0003o00Cooooo0000o`000?l0003o3oooool01@000?oooooo0000
ooooool0003o00;ooooo0`000?l00oooool0003o0000o`1;ooooo`@0003o2?ooool00`000?oooooo
0000o`0Nooooo`80003o4Oooool30000o`03ooooo`000?oooooo0080003o;Oooool10000007ooooo
000Kooooo`0300000?l0003ooooo00_ooooo1P000?l01?ooool0003o0000o`000?l7ooooo`@0003o
00Cooooo0000o`000?l0003o3oooool01@000?oooooo0000ooooool0003o00;ooooo0`000?l00ooo
ool0003o0000o`04ooooo`030000oooooooooooo02oooooo00<0003oooooooooool04Oooool50000
o`Sooooo00<0003oooooo`000?l07_ooool20000oa7ooooo0`000?l00oooool0003oooooo`020000
obcooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00_ooooo1P000?l01?ooool0
003o0000o`000?l7ooooo`@0003o00Cooooo0000o`000?l0003o3oooool01@000?oooooo0000oooo
ool0003o00;ooooo1`000?l3ooooo`030000oooooooooooo02oooooo00<0003oooooooooool00_oo
ool00`000?ooooooooooo`0<ooooo`D0003o2?ooool00`000?oooooo0000o`0Nooooo`80003o4Ooo
ool30000o`03ooooo`000?l0003o00<0003o;?ooool10000007ooooo000Kooooo`0300000?oooooo
oooo00_ooooo1P000?l01?ooool0003o0000o`000?l7ooooo`@0003o00?ooooo0000o`000?l00P00
0?l>ooooo`030000ooooool0003o00<0003o00?ooooo0000o`000?l01@000?l3ooooo`030000oooo
oooooooo02oooooo00@0003ooooooooooooooooo0P000?l>ooooo`D0003o2?ooool00`000?oooooo
0000o`0Looooo`@0003o4Oooool30000o`03ooooo`000?l0003o00<0003o00?ooooo0000ooooool0
4Oooool00`000?ooooooooooo`0Eooooo`4000000Oooool001_ooooo00<00000ooooooooool02ooo
ool60000o`04ooooo`000?l0003o0000o`Oooooo10000?l00oooool0003o0000o`020000o`kooooo
00<0003oooooo`000?l00`000?l00oooool0003o0000o`050000o`?ooooo00<0003oooooooooool0
;oooool010000?ooooooooooooooool20000o`kooooo1@000?l8ooooo`030000ooooool0003o01co
oooo10000?lAooooo`<0003o00?ooooo0000o`000?l00`000?l00oooool0003oooooo`0Aooooo`03
0000oooooooooooo01Gooooo0@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`X0003o
1oooool40000o`03ooooo`000?l0003o0080003o3Oooool20000o`03ooooo`000?l0003o0080003o
00?ooooo0000o`000?l01@000?l3ooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0
0_ooool00`000?ooooooooooo`0Aooooo`040000ooooooooooooooooo`<0003o3Oooool60000o`Go
oooo00D0003oooooo`000?oooooo0000o`0Looooo`@0003o4Oooool30000o`03ooooo`000?l0003o
00D0003o4_ooool00`000?ooooooooooo`0Eooooo`4000000Oooool001_ooooo00<00000oooooooo
ool02oooool:0000o`Oooooo10000?l00oooool0003o0000o`030000o`_ooooo0`000?l00oooool0
003o0000o`020000o`03ooooo`000?l0003o00D0003o0oooool00`000?ooooooooooo`0Fooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool04Oooool010000?ooooooooooooooool30000
o`cooooo1`000?l5ooooo`050000ooooool0003oooooo`000?l07?ooool40000oa7ooooo0`000?l0
0oooool0003o0000o`050000o`gooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0E
ooooo`4000000Oooool001_ooooo00<00000ooooooooool02oooool:0000o`Oooooo2P000?l;oooo
o`<0003o00?ooooo0000o`000?l00P000?l00oooool0003o0000o`070000o`03ooooo`000?oooooo
01Oooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0@ooooo`80003o0oooool30000
o`cooooo1`000?l5ooooo`050000ooooool0003oooooo`000?l07?ooool40000oa7ooooo2`000?l=
ooooo`040000ooooooooooooooooo`<0003o5_ooool10000007ooooo000Kooooo`0300000?oooooo
oooo00_ooooo2P000?l7ooooo`X0003o2oooool30000o`03ooooo`000?l0003o0080003o00?ooooo
0000o`000?l01`000?l00oooool0003oooooo`0Gooooo`040000ooooooooooooooooo`80003o4_oo
ool30000o`;ooooo0`000?l<ooooo`L0003o1Oooool01@000?oooooo0000ooooool0003o01cooooo
10000?lAooooo`/0003o3Oooool00`000?ooooooooooo`050000oaGooooo0@000001ooooo`006ooo
ool00`00003o0000ooooo`0;ooooo`X0003o1oooool:0000o`_ooooo0`000?l00oooool0003o0000
o`020000o`03ooooo`000?l0003o00L0003o00?ooooo0000ooooool05oooool010000?oooooooooo
ooooool20000oa;ooooo0`000?l00oooool0003o0000o`020000o`cooooo1`000?l4ooooo`80003o
00Cooooo0000ooooool0003o7?ooool40000oa7ooooo2`000?l=ooooo`030000oooooooooooo00D0
003o5?ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool02_ooool;0000o`Oooooo
2P000?l;ooooo`<0003o00?ooooo0000o`000?l00P000?l00oooool0003o0000o`070000o`03oooo
o`000?oooooo01Oooooo00<0003oooooooooool00`000?lBooooo`<0003o00?ooooo0000o`000?l0
0P000?l<ooooo`L0003o1?ooool20000o`06ooooo`000?l0003o0000ooooool0003o6_ooool50000
oa3ooooo30000?l<ooooo`030000oooooooooooo00D0003o5Oooool10000007ooooo000Kooooo`03
00000?oooooooooo00[ooooo2`000?l7ooooo`X0003o2oooool30000o`03ooooo`000?l0003o00`0
003o00?ooooo0000ooooool05oooool00`000?ooooooooooo`030000oa;ooooo0`000?l00oooool0
003o0000o`020000o`_ooooo20000?l3ooooo`<0003o00Kooooo0000o`000?l0003oooooo`000?lJ
ooooo`D0003o4?ooool<0000o`cooooo20000?lEooooo`4000000Oooool001_ooooo00<00000oooo
ooooool02_ooool;0000o`Oooooo2P000?l;ooooo`<0003o00?ooooo0000o`000?l030000?l00ooo
ool0003oooooo`0Gooooo`030000oooooooooooo00@0003o4Oooool30000o`03ooooo`000?l0003o
0080003o2oooool80000o`?ooooo0`000?l00oooool0003o0000o`030000oa[ooooo1@000?l@oooo
o``0003o3?ooool80000oaGooooo0@000001ooooo`006oooool00`00003oooooooooo`0:ooooo`/0
003o1oooool:0000o`_ooooo4P000?l00oooool0003oooooo`0Gooooo`030000oooooooooooo00@0
003o4Oooool30000o`03ooooo`000?l0003o0080003o2oooool80000o`?ooooo2P000?lIooooo`D0
003o4?ooool<0000o`_ooooo2@000?lEooooo`4000000Oooool001_ooooo00<00000ooooooooool0
2_ooool;0000o`Oooooo2P000?l;oooooa80003o00?ooooo0000ooooool05oooool00`000?oooooo
ooooo`040000oa7ooooo0`000?l00oooool0003o0000o`020000o`_ooooo20000?l3ooooo`X0003o
6Oooool50000oa3ooooo30000?l;ooooo`T0003o5Oooool10000007ooooo000Kooooo`0300000?oo
oooooooo00[ooooo2`000?l7ooooo`X0003o2ooooolB0000o`03ooooo`000?oooooo01Oooooo00<0
003oooooo`000?l010000?l>ooooo`030000oooooooooooo00<0003o00?ooooo0000o`000?l00P00
0?l;ooooo`P0003o0oooool:0000oaWooooo1@000?l@ooooo``0003o2oooool90000oaGooooo0@00
0001ooooo`006oooool00`00003o0000ooooo`0:ooooo`/0003o1oooool:0000o`_ooooo50000?lH
ooooo`L0003o3_ooool00`000?ooooooooooo`030000o`03ooooo`000?l0003o0080003o2oooool8
0000o`?ooooo2P000?lIooooo`D0003o4?ooool90000o`03o`00o`000?l0003o00_ooooo2@000?lD
ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0:ooooo``0003o1_ooool:0000
o`_ooooo50000?lHooooo`L0003o3_ooool00`000?ooooooooooo`030000o`03ooooo`000?l0003o
0080003o2oooool80000o`?ooooo2P000?lHooooo`H0003o4?ooool90000o`03o`00o`000?l0003o
00_ooooo00<0003oo`00o`000?l01P000?lEooooo`4000000Oooool001_ooooo00<00000oooooooo
ool02_ooool<0000o`Gooooo30000?l:oooooa@0003o6?ooool00ol00?l0003o0000o`040000o`ko
oooo00<0003oooooooooool00`000?l00oooool0003o0000o`030000o`[ooooo20000?l3ooooo`X0
003o6?ooool60000o`oooooo3@000?l;ooooo`T0003o5Oooool10000007ooooo000Kooooo`030000
0?oooooooooo00Wooooo3@000?l5ooooo``0003o2_oooolD0000oaSooooo1`000?l=ooooo`L0003o
00?ooooo0000o`000?l00P000?l;ooooo`P0003o0oooool:0000oaSooooo1`000?l>ooooo`d0003o
2oooool90000oaGooooo0@000001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo
1Ol00004ooooo`0300000?oooooooooo00Wooooo3@000?l5ooooo``0003o2_oooolE0000oaOooooo
1`000?l=ooooo`L0003o00?ooooo0000o`000?l00P000?l;ooooo`T0003o0_ooool:0000oaSooooo
1`000?l>ooooo`h0003o2_ooool90000oaGooooo0@000001ooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02Oooool=0000o`Go
oooo3@000?l9oooooaD0003o5oooool70000o`gooooo1`000?l00oooool0003o0000o`020000o`_o
oooo2@000?l2ooooo`X0003o6?ooool70000o`kooooo3P000?l:ooooo`T0003o5Oooool10000007o
oooo0005o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03
00000?oooooooooo00Wooooo3@000?l5ooooo`d0003o2OoooolE0000oaOooooo20000?l;ooooo`P0
003o00?ooooo0000o`000?l00P000?l;ooooo`T0003o0_ooool;0000oaOooooo1`000?l>ooooo`h0
003o2_ooool90000oaGooooo0@000001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00?ooooo00<00000o`000?ooool02Oooool=0000o`Gooooo3@000?l9oooooaD0
003o5oooool80000o`_ooooo20000?l00oooool0003o0000o`030000o`[ooooo2@000?l2ooooo`/0
003o5oooool70000o`kooooo3P000?l:ooooo`X0003o4oooool1o`00004000000Oooool000Oooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00<00000oooo
ooooool02Oooool=0000o`Gooooo3@000?l9oooooaD0003o5oooool80000o`_ooooo20000?l00ooo
ool0003o0000o`030000o`[ooooo2@000?l2ooooo`/0003o5oooool70000o`kooooo3P000?l:oooo
o`X0003o5?ooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`0300000?oooooooooo00Wooooo3@000?l5ooooo`d0003o2OoooolE
0000oaOooooo20000?l:ooooo`T0003o00?ooooo0000o`000?l00`000?l:ooooo`T0003o0_ooool;
0000oaOooooo1`000?l>ooooo`h0003o2_ooool:0000oaCooooo0@000001ooooo`002?ooool2o`00
00Wooooo0ol00005ooooo`0300000?oooooooooo00Wooooo3@000?l5ooooo`d0003o2OoooolE0000
oaKooooo2@000?l:ooooo`T0003o00?ooooo0000o`000?l00`000?l:ooooo`T0003o0_ooool;0000
oaGooooo2@000?l>ooooo`h0003o2Oooool90000o`03o`00o`000?oooooo01?ooooo0@000001oooo
o`006oooool00`00003oooooooooo`09ooooo`d0003o1Oooool=0000o`Wooooo30000?l00ol00?l0
003o0000o`060000oaKooooo2@000?l:ooooo`T0003o00?ooooo0000o`000?l00`000?l:ooooo`T0
003o0_ooool;0000oaGooooo2@000?l>ooooo`h0003o2Oooool;0000oaCooooo0@000001ooooo`00
6oooool00`00003oooooooooo`09ooooo`d0003o1Oooool=0000o`Wooooo5@000?lFooooo`T0003o
2_ooool90000o`03ooooo`000?l0003o00<0003o2_ooool90000o`;ooooo2`000?lDooooo`X0003o
3_ooool>0000o`Wooooo2`000?lDooooo`4000000Oooool001_ooooo00<00000ooooooooool02Ooo
ool=0000o`Gooooo3P000?l8oooooaD0003o5_ooool90000o`[ooooo3`000?l:ooooo`T0003o0_oo
ool;0000oaCooooo2`000?l=ooooo`h0003o2Oooool;0000oaCooooo0@000001ooooo`006oooool0
0`00003o0000ooooo`09ooooo`d0003o1Oooool>0000o`Sooooo5@000?lFooooo`T0003o2_ooool?
0000o`[ooooo2@000?l2ooooo`/0003o5?ooool;0000o`gooooo3P000?l9ooooo``0003o4_ooool1
o`00004000000Oooool001_ooooo00<00000ooooooooool02Oooool=0000o`Gooooo3P000?l8oooo
oaD0003o5_ooool90000o`[ooooo3`000?l:ooooo`T0003o0_ooool;0000oaCooooo2`000?l=oooo
o`h0003o2Oooool=0000oa;ooooo0@000001ooooo`006oooool00`00003oooooooooo`09ooooo`d0
003o1Oooool>0000o`Sooooo5@000?lFooooo`T0003o2_ooool?0000o`[ooooo2@000?l2ooooo`/0
003o5?ooool<0000o`cooooo3P000?l9ooooo`d0003o4_ooool10000007ooooo000Kooooo`030000
0?oooooooooo00Wooooo3@000?l5ooooo`h0003o2?oooolE0000oaKooooo2@000?l:ooooo`l0003o
2_ooool90000o`;ooooo2`000?lDooooo``0003o3?ooool>0000o`Wooooo3@000?lBooooo`400000
0Oooool001_ooooo00<00000ooooooooool02Oooool=0000o`Gooooo3P000?l8oooooaD0003o5_oo
ool90000o`[ooooo00?o003o0000o`000?l030000?l9ooooo`X0003o0_ooool;0000oaCooooo3000
0?l<ooooo`h0003o2Oooool=0000oa;ooooo0@000001ooooo`006oooool00`00003oooooooooo`09
ooooo`d0003o1Oooool>0000o`Sooooo3P000?l00ol00?l0003o0000o`030000o`03o`00oooooooo
oooo01Cooooo2@000?l:ooooo`l0003o2Oooool:0000o`;ooooo2`000?lDooooo``0003o3?ooool>
0000o`Wooooo3`000?l@ooooo`4000000Oooool001_ooooo00<00000ooooooooool02Oooool>0000
o`Cooooo3P000?l8oooooaD0003o5_ooool90000o`[ooooo3`000?l9ooooo`X0003o0_ooool;0000
oaCooooo2`000?l00ol00?ooooooooooo`0:ooooo`h0003o2Oooool>0000oa7ooooo0@000001oooo
o`006oooool00`00003o0000ooooo`09ooooo`h0003o1?ooool>0000o`Sooooo5@000?lFooooo`X0
003o2Oooool?0000o`Wooooo60000?lCooooo``0003o3?ooool>0000o`Wooooo3P000?l@ooooo`7o
00000@000001ooooo`006oooool00`00003oooooooooo`09ooooo`d0003o00?o003oooooooooool0
0_ooool>0000o`Sooooo5@000?lFooooo`X0003o2?ooool00ol00?l0003o0000o`0=0000o`Sooooo
6@000?lCooooo``0003o00?o003oooooooooool02Oooool>0000o`Wooooo3`000?l@ooooo`400000
0Oooool001_ooooo00<00000ooooooooool02Oooool?0000o`?ooooo3P000?l8oooooaD0003o5_oo
ool:0000o`Oooooo4@000?l8oooooa00003o00?o003o0000o`000?l01P000?lBooooo`80003o00?o
003o0000o`000?l020000?l00ol00?ooooooooooo`09ooooo`h0003o2Oooool?0000oa3ooooo0@00
0001ooooo`006oooool00`00003oooooooooo`09ooooo`l0003o0_ooool?0000o`Oooooo5`000?lE
ooooo`X0003o1ooooolA0000o`Sooooo6@000?lBooooo`h0003o2oooool>0000o`Wooooo3`000?l@
ooooo`4000000Oooool001_ooooo00<00000ooooooooool02Oooool@0000o`03ooooo`000?l0003o
00H0003o00?o003o0000o`000?l010000?l7oooooaL0003o5Oooool:0000o`Gooooo00<0003ooooo
o`000?l040000?l7oooooa/0003o4Oooool>0000o`_ooooo3`000?l8ooooo`/0003o00Co003o0000
o`000?l0003o4?ooool10000007ooooo000Kooooo`0300000?oooooooooo00Wooooo80000?l7oooo
oaP0003o00?ooooo0000ooooool04Oooool:0000o`Gooooo4`000?l7oooooa/0003o4Oooool>0000
o`[ooooo40000?l8oooooa00003o3oooool10000007ooooo000Kooooo`0300000?oooooooooo00Wo
oooo80000?l7oooooaP0003o00?ooooo0000ooooool04Oooool:0000o`Gooooo4`000?l7oooooa/0
003o4Oooool>0000o`[ooooo40000?l8oooooa00003o3oooool10000007ooooo000Kooooo`030000
0?l0003ooooo00Wooooo8@000?l6oooooaP0003o00?ooooo0000ooooool04Oooool:0000o`Gooooo
4`000?l00ol00?ooooooooooo`04oooooa/0003o4Oooool>0000o`[ooooo40000?l8oooooa00003o
3_ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool02OoooolA0000o`03o`00o`00
0?l0003o00d0003o1_oooolH0000o`03ooooo`000?oooooo017ooooo2P000?l00ol00?oooooooooo
o`02oooooa@0003o1_oooolM0000o`oooooo3P000?l:oooooa00003o1ooooolA0000o`oooooo0@00
0001ooooo`006oooool00`00003oooooooooo`09oooooa40003o00?o003o0000o`000?l030000?l0
0ol00?ooooooooooo`02ooooo`03o`00o`000?l0003o01L0003o00?o003o0000o`000?l04Oooool;
0000o`Cooooo2P000?l00ol00?l0003o0000o`070000o`Kooooo6`000?l3o`00o`Gooooo00?o003o
ooooooooool00_l00?l3ooooo`H0003o00?o003o0000o`000?l01P000?l00ol00?ooooooooooo`02
ooooo`05o`00o`000?oooooo0000ool00?l04@000?l6oooooa40003o3oooool10000007ooooo000K
ooooo`0300000?oooooooooo00Gooooo00@0003oo`00oooooooooooo80000?l3o`00o`;ooooo6`00
0?l00ol00?ooooooooooo`02o`00o`kooooo2`000?l3oooooa@0003o0_l00?l010000?oo003oo`00
ooooool>0000o`03o`00o`000?l0003o00X0003o00Oo003o0000ool00?oo003o0000ool00?l0003o
00;ooooo0P000?l01?ooool0003oo`00ool00?l2ooooo`d0003o0_l00?l010000?oo003oo`00oooo
ool3o`00o`03ooooo`000?l0003o0100003o00Oo003oooooo`000?l0003oo`00o`000?oooooo0140
003o0oooool01@000?oooooooooooooooooo003o00Oooooo0@000001ooooo`006oooool00`00003o
ooooooooo`03ooooo`?o003o00<0003oo`00o`000?l03@000?l00ol00?l0003o0000o`0A0000o`Go
003o6P000?l2o`00o`03ooooool00?oo003o00;o003o00Gooooo0000o`000?oo003o0000o`03o`00
o`030000ool00?oo003o00`0003o0ol00?l30000o`03o`00o`000?l0003o00h0003o1_l00?lK0000
o`03o`00o`000?oo003o00;o003o00<0003oo`00ooooool01?l00?l20000o`;o003o00?ooooo0000
o`000?l030000?l2o`00o`030000ool00?oo003o0080003o0_l00?lA0000o`;o003o00<0003oo`00
o`000?l00ol00?lA0000o`Ko003o00Cooooo0000ool00?oo003o1Oooool10000007ooooo000Doooo
o`;o00001Oooool00`00003oooooooooo`03ooooo`;o003o00<0003oo`00ool00?l03P000?l00ol0
0?l0003o0000o`0B0000o`Co003o60000?l00ol00?l0003oo`00o`02o`00o`030000ool00?oo003o
00?o003o00<0003oo`00ool00?l01_l00?l;0000o`Co003o5@000?l01Ol00?l0003o0000o`000?oo
003o01h0003o0_l00?l00`000?oo003oo`00o`04o`00o`80003o0ol00?lA0000o`;o003o0P000?l2
o`00oa80003o0_l00?l010000?oo003oo`00ool00?lB0000o`[o003o1Oooool10000007ooooo000C
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00oooool2o`00o`030000ool0
0?oo003o0180003o00?o003o0000o`000?l03@000?l5o`00oaP0003o00?o003o0000o`000?l00_l0
0?l00`000?oo003oo`00o`0=o`00o`X0003o1?l00?lE0000o`07o`00o`000?l0003o0000ool00?l0
003oo`00o`0L0000o`Ko003o00@0003oo`00ool00?l0003o1?l00?l?0000o`04o`00o`000?oo003o
o`00o`80003o0_l00?lB0000o`;o003o0P000?l00ol00?l0003oo`00o`0A0000o`[o003o1Oooool1
0000007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo1P0000000ol00?l0003oo`00o`02
o`00ob80003o1Ol00?lH0000o`03o`00o`000?l0003o00;o003o00<0003oo`00ool00?l03Ol00?l9
0000o`Go003o5@000?l7o`00oa`0003o0_l00?l01@000?oo003oo`00ool00?l0003o00;o003o00<0
003oo`00ool00?l00_l00?l?0000o`03o`00o`000?oo003o00;o003o00<0003oo`00ool00?l04@00
0?l3o`00o`80003o00?o003o0000ool00?l04@000?l00ol00?l0003oo`00o`07o`00o`H000000Ooo
ool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`03ooooo`Ko003o8@00
0?l00ol00?l0003oo`00o`02o`00oa/0003o4_l00?l:0000o`Co003o50000?l00ol00?l0003oo`00
o`04o`00oah0003o00Ko003o0000ool00?l0003oo`00o`000?l6o`00oa00003o1?l00?l20000o`;o
003o00<0003oo`00o`000?l03P000?l00ol00?l0003o0000o`03o`00o`030000ool00?l0003o00l0
003o1Ol00?l00`000?oo003oo`00o`03o`00o`Gooooo0@000001ooooo`004oooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo00Cooooo:@000?l00oooool0003o0000o`0K0000o`04
ooooo`000?l0003o0000o`?ooooo1@000?l00oooool0003o0000o`0V0000o`03ooooo`000?l0003o
02<0003o00?ooooo0000o`000?l01P000?l00oooool0003o0000o`190000o`Gooooo0@000001oooo
o`004oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Cooooo9`000?l00ol0
0?l0003oooooo`0M0000o`04ooooo`000?l0003o0000o`?ooooo1@000?l01Oooool0003o0000o`00
0?oooooo02@0003o00?ooooo0000o`000?l08`000?l00oooool0003o0000o`060000o`03ooooo`00
0?l0003o00`0003o00?o003o0000o`000?l0<@000?l00oooool0003o0000o`060000o`Gooooo0@00
0001ooooo`005?ooool2o`0000Gooooo00<00000ooooooooool02OoooolQ0000o`03ooooool00?oo
003o00;ooooo70000?l:ooooo`05o`00ooooooooooooooooool00?l00_ooool;0000o`?ooooo5@00
0?l00ol00?ooooooooooo`03oooooad0003o00?o003oooooooooool00oooool3o`00o`030000ool0
0?oooooo00;ooooo00<0003oo`00o`000?l02`000?l00ol00?l0003oo`00o`02ooooo`?o003o00?o
oooo0000o`000?l04@000?l3ooooo`050000oooooooooooo0000ool00?l03`000?l9ooooo`03o`00
oooooooooooo00?ooooo0@000001ooooo`006oooool00`00003oooooooooo`09ooooob40003o1Ooo
oolK0000o`03o`00oooooooooooo00oooooo2`000?l3oooooaD0003o1_oooolN0000o`Wooooo0P00
0?l2ooooo`030000ool00?l0003o00`0003o0_l00?l7ooooo`03o`00o`000?l0003o00h0003o1ooo
oolA0000o`oooooo0@000001ooooo`006oooool00`00003oooooooooo`09oooooa00003o00?o003o
0000o`000?l03@000?l7oooooa/0003o4Oooool:0000o`Gooooo4P000?l00ol00?l0003oooooo`05
oooooa/0003o00?o003o0000ooooool03_ooool00ol00?l0003o0000o`0:0000o`03o`00oooooooo
oooo00Sooooo40000?l7oooooa40003o3oooool10000007ooooo000Kooooo`0300000?oooooooooo
00Wooooo3P000?l00ol00?l0003o0000o`0?0000o`Oooooo6@000?l00ol00?ooooooooooo`0@oooo
o`X0003o1OoooolD0000o`Kooooo7@000?l?ooooo``0003o00?o003o0000ooooool02Oooool@0000
o`Sooooo40000?l?ooooo`4000000Oooool001_ooooo00<00000o`000?ooool02Oooool@0000o`03
o`00o`000?l0003o00d0003o1ooooolH0000o`03ooooo`000?oooooo017ooooo2P000?l5oooooa@0
003o1_oooolL0000oa3ooooo3P000?l:oooooa00003o2?ooool@0000o`kooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo00Wooooo3P000?l00oooool0003oooooo`0?0000o`Oooooo
5`000?l2ooooo`030000oooooooooooo013ooooo2P000?l5oooooa<0003o1ooooolL0000oa7ooooo
30000?l00ol00?ooooooooooo`08oooooa00003o2?ooool@0000o`oooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`09ooooo`h0003o00?ooooo0000ooooool03`000?l7oooooaL0003o5Ooo
ool:0000o`Gooooo4`000?l9oooooaX0003o4Oooool=0000o`[ooooo40000?l8ooooo`l0003o4?oo
ool10000007ooooo000Kooooo`0300000?oooooooooo00Wooooo3`000?l3ooooo`h0003o2?oooolE
0000oaKooooo2P000?l5ooooo`030000ooooool0003o0100003o2OoooolJ0000oa7ooooo3@000?l:
oooooa00003o2?ooool?0000oa3ooooo0@000001ooooo`006oooool00`00003oooooooooo`09oooo
o`h0003o1?ooool>0000o`Sooooo5@000?lFooooo`X0003o1Oooool00`000?oooooo0000o`0@0000
o`Wooooo6P000?lAooooo`d0003o2_ooool@0000o`Sooooo3`000?l@ooooo`4000000Oooool001_o
oooo00<00000ooooooooool02Oooool>0000o`Cooooo3P000?l8oooooaD0003o5_ooool:0000o`So
oooo40000?l9oooooaT0003o4_ooool=0000o`[ooooo3`000?l9ooooo`l0003o4?ooool10000007o
oooo000Kooooo`0300000?oooooooooo00Wooooo3P000?l4ooooo`h0003o2?oooolE0000oaKooooo
2P000?l8oooooa00003o2OoooolI0000oa;ooooo3@000?l:ooooo`l0003o2Oooool?0000oa3ooooo
0@000001ooooo`006oooool00`00003o0000ooooo`09ooooo`d0003o00?o003oooooooooool00_oo
ool>0000o`Sooooo5@000?lFooooo`X0003o2Oooool=0000o`03o`00o`000?oooooo00Sooooo6@00
0?lBooooo`/0003o00?o003oooooooooool02Oooool?0000o`Wooooo3`000?l?ooooo`7o00000@00
0001ooooo`006oooool00`00003oooooooooo`09ooooo`h0003o1?ooool>0000o`Sooooo5@000?lF
ooooo`X0003o2Oooool?0000o`Wooooo6@000?lBooooo``0003o2oooool90000o`03o`00o`000?l0
003o00<0003o2Oooool?0000oa3ooooo0@000001ooooo`006oooool00`00003oooooooooo`09oooo
o`h0003o1?ooool>0000o`Sooooo5@000?lFooooo`X0003o2Oooool?0000o`Wooooo2P000?l00ol0
0?l0003o0000o`0;0000oa?ooooo30000?l;ooooo`l0003o2Oooool>0000oa7ooooo0@000001oooo
o`006oooool00`00003oooooooooo`09ooooo`h0003o1?ooool>0000o`Sooooo5@000?lFooooo`T0
003o2_ooool?0000o`Wooooo2P000?l2ooooo``0003o4oooool<0000o`cooooo3P000?l9ooooo`h0
003o4Oooool10000007ooooo000Kooooo`0300000?oooooooooo00Wooooo3@000?l5ooooo`h0003o
2?oooolE0000oaOooooo20000?l:ooooo`l0003o2Oooool:0000o`;ooooo30000?lCooooo`X0003o
00?o003o0000ooooool02oooool>0000o`Wooooo3P000?lAooooo`4000000Oooool001_ooooo00<0
0000ooooooooool02Oooool=0000o`Gooooo3P000?l8oooooaD0003o5oooool80000o`[ooooo3000
0?l00ol00?l0003o0000o`09ooooo`X0003o0_ooool<0000oa?ooooo30000?l<ooooo`h0003o2Ooo
ool>0000oa7ooooo0@000001ooooo`006oooool00`00003oooooooooo`09ooooo`d0003o1Oooool>
0000o`Sooooo5@000?lGooooo`P0003o2_ooool?0000o`Wooooo2P000?l2ooooo``0003o4oooool:
0000o`kooooo3P000?l9ooooo`h0003o4Oooool10000007ooooo000Kooooo`0300000?l0003ooooo
00Wooooo3@000?l5ooooo`h0003o2?oooolE0000oaOooooo20000?l:ooooo`l0003o2Oooool:0000
o`;ooooo30000?lCooooo`X0003o3_ooool>0000o`Wooooo3P000?l@ooooo`7o00000@000001oooo
o`006oooool00`00003oooooooooo`09ooooo`d0003o1Oooool>0000o`Sooooo5@000?lGooooo`P0
003o2_ooool?0000o`Wooooo2P000?l2ooooo`/0003o5?ooool:0000o`kooooo3P000?l9ooooo`d0
003o4_ooool10000007ooooo000Kooooo`0300000?oooooooooo00Wooooo3@000?l5ooooo`h0003o
2?oooolE0000oaOooooo20000?l:ooooo`l0003o2Oooool:0000o`;ooooo2`000?lDooooo`X0003o
3_ooool>0000o`Wooooo3@000?lBooooo`4000000Oooool001_ooooo00<00000ooooooooool02Ooo
ool=0000o`Gooooo3P000?l8oooooaD0003o5oooool80000o`[ooooo3`000?l:ooooo`T0003o0_oo
ool;0000oaCooooo2P000?l>ooooo`d0003o2_ooool=0000oa;ooooo0@000001ooooo`002?ooool2
o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`0300000?oooooooooo00[ooooo3000
0?l5ooooo`h0003o2?oooolE0000oaOooooo20000?l:ooooo`l0003o2_ooool90000o`;ooooo2`00
0?lEooooo`T0003o3_ooool=0000o`[ooooo3@000?lBooooo`4000000Oooool000Oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00[ooooo
1@000?l00ol00?l0003o0000o`030000o`03o`00oooooooooooo00?ooooo3P000?l8oooooaD0003o
5oooool80000o`[ooooo3`000?l:ooooo`T0003o0_ooool;0000oaGooooo2@000?l>ooooo`d0003o
2_ooool=0000oa;ooooo0@000001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Cooooo00<00000ooooooooool02_ooool;0000o`03o`00oooooooooooo00?ooooo
3@000?l9oooooaD0003o5oooool80000o`[ooooo3`000?l:ooooo`T0003o0_ooool;0000oaGooooo
20000?l@ooooo``0003o2_ooool=0000oa;ooooo0@000001ooooo`001oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00?ooooo00<00000o`000?ooool02_ooool<0000o`Gooooo
3@000?l9ooooo`L0003o00?o003o0000o`000?l02`000?lGooooo`P0003o2_ooool?0000o`[ooooo
2@000?l2ooooo`/0003o5Oooool80000oa3ooooo30000?l:ooooo`d0003o4Oooool1o`0000400000
0Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Co
oooo00<00000ooooooooool02_ooool<0000o`Gooooo3@000?l9oooooaD0003o5oooool80000o`[o
oooo3`000?l:ooooo`T0003o0_ooool;0000oaGooooo20000?l@ooooo``0003o2oooool<0000oa;o
oooo0@000001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001?ooool00`00003oooooooooo`0:ooooo``0003o1Oooool=0000o`Wooooo5@000?lGoooo
o`P0003o2_ooool?0000o`[ooooo2@000?l2ooooo`/0003o5Oooool80000oa3ooooo30000?l;oooo
o``0003o4_ooool10000007ooooo0008ooooo`;o00002Oooool3o`0000Gooooo00<00000oooooooo
ool02_ooool<0000o`Gooooo3@000?l9oooooaD0003o5oooool80000o`[ooooo3`000?l:ooooo`T0
003o0_ooool;0000oaGooooo20000?l@ooooo``0003o2oooool<0000oa;ooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0:ooooo``0003o1Oooool=0000o`Wooooo5@000?lGooooo`P0003o
2_ooool?0000o`[ooooo2@000?l2ooooo`/0003o5oooool50000oa7ooooo2@000?l00ol00?l0003o
0000o`0;ooooo``0003o4_ooool10000007ooooo000Kooooo`0300000?oooooooooo00[ooooo3000
0?l5ooooo`d0003o2OoooolE0000oaOooooo20000?l:ooooo`l0003o2_ooool90000o`;ooooo2`00
0?lGooooo`D0003o4Oooool<0000o`_ooooo30000?lBooooo`4000000Oooool001_ooooo00<00000
ooooooooool02_ooool<0000o`Gooooo3@000?l9oooooaD0003o5oooool80000o`[ooooo3`000?l:
ooooo`T0003o0_ooool;0000oaOooooo1@000?lAooooo`/0003o3?ooool:0000o`03ooooo`000?oo
oooo017ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0:ooooo``0003o1Oooool=0000
o`Wooooo5@000?lGooooo`P0003o2_ooool?0000o`[ooooo2@000?l2ooooo`/0003o6?ooool40000
oa7ooooo2`000?l<ooooo`X0003o4oooool1o`00004000000Oooool001_ooooo00<00000oooooooo
ool02_ooool<0000o`Gooooo30000?l:oooooaD0003o5oooool80000o`_ooooo3P000?l:ooooo`T0
003o0_ooool:0000oaWooooo10000?lAooooo`/0003o3?ooool:0000oaCooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0:ooooo``0003o1Oooool<0000o`[ooooo5@000?lGooooo`P0003o
2oooool>0000o`[ooooo2@000?l2ooooo`X0003o6Oooool40000oa7ooooo2`000?l=ooooo`T0003o
5?ooool10000007ooooo000Kooooo`0300000?oooooooooo00[ooooo30000?l5ooooo``0003o2_oo
oolE0000oaOooooo20000?l<ooooo`d0003o2_ooool90000o`;ooooo2P000?lIooooo`@0003o4Ooo
ool;0000o`gooooo2@000?lDooooo`4000000Oooool001_ooooo00<00000ooooooooool02_ooool<
0000o`Gooooo30000?l:oooooaD0003o5oooool80000o`cooooo3@000?l:ooooo`T0003o0_ooool:
0000oaWooooo10000?lAooooo`/0003o3Oooool90000oaCooooo0@000001ooooo`006oooool00`00
003oooooooooo`0:ooooo``0003o1Oooool<0000o`[ooooo5@000?lGooooo`P0003o3?ooool=0000
o`[ooooo2@000?l2ooooo`X0003o6Oooool40000oa7ooooo2`000?l=ooooo`T0003o5?ooool10000
007ooooo000Kooooo`0300000?oooooooooo00[ooooo30000?l5ooooo``0003o2_oooolE0000oaOo
oooo20000?l<ooooo`d0003o2_ooool90000o`;ooooo2P000?lIooooo`@0003o4Oooool;0000o`go
oooo2@000?lDooooo`4000000Oooool001_ooooo00<00000o`000?ooool02_ooool;0000o`Kooooo
2`000?l;ooooo`D0003o00?ooooo0000o`000?l03@000?lGooooo`P0003o3?ooool20000o`03oooo
o`000?l0003o00P0003o2_ooool80000o`?ooooo2P000?lJooooo`030000ool00?l0003o017ooooo
2`000?l=ooooo`T0003o4oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool02ooo
ool:0000o`Kooooo2`000?l;ooooo`D0003o0oooool=0000oaOooooo1`000?l=ooooo`80003o00?o
oooo0000o`000?l020000?l:ooooo`P0003o0oooool:0000oa[ooooo0`000?lAooooo`X0003o3_oo
ool90000oaCooooo0@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`X0003o1_ooool;
0000o`_ooooo1@000?l3ooooo`d0003o5oooool70000o`kooooo00<0003oooooo`000?l02@000?l:
ooooo`P0003o0oooool:0000oa[ooooo0`000?lAooooo`X0003o3_ooool90000oaCooooo0@000001
ooooo`006oooool00`00003oooooooooo`0;ooooo`X0003o1_ooool;0000o`_ooooo0`000?l00ooo
ool0003oooooo`02ooooo`d0003o5oooool70000o`kooooo00@0003ooooooooooooooooo0P000?l0
0oooool0003o0000o`030000o`[ooooo20000?l3ooooo`T0003o6oooool20000oa;ooooo10000?l0
0oooool0003o0000o`030000o`kooooo20000?lEooooo`4000000Oooool001_ooooo00<00000oooo
ooooool02oooool:0000o`Kooooo2`000?l;ooooo`<0003o00?ooooo0000ooooool00_ooool=0000
oaOooooo1`000?l>ooooo`040000ooooooooooooooooo`80003o00?ooooo0000o`000?l00`000?l:
ooooo`P0003o0oooool90000oa_ooooo0P000?lBooooo`@0003o00?ooooo0000o`000?l00`000?l>
ooooo`P0003o5Oooool10000007ooooo000Kooooo`0300000?oooooooooo00_ooooo2P000?l6oooo
o`/0003o2oooool30000o`03ooooo`000?oooooo00;ooooo30000?lHooooo`L0003o3_ooool01000
0?ooooooooooooooool20000o`03ooooo`000?l0003o00<0003o2_ooool00`000?oooooo0000o`05
0000o`?ooooo2@000?l_ooooo`@0003o00?ooooo0000o`000?l00`000?l>ooooo`L0003o5_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo00_ooooo2P000?l6ooooo`/0003o2oooool30000
o`03ooooo`000?oooooo00;ooooo1P000?l00oooool0003o0000o`030000oaSooooo1`000?l>oooo
o`040000ooooooooooooooooo`80003o00?ooooo0000o`000?l00`000?l<ooooo`H0003o0oooool9
0000oboooooo0P000?l00oooool0003oooooo`040000o`oooooo1`000?lFooooo`4000000Oooool0
01_ooooo00<00000o`000?ooool02oooool:0000o`Oooooo2P000?l;ooooo`<0003o00?ooooo0000
ooooool00_ooool30000o`04ooooo`000?l0003oooooo`D0003o6?ooool70000oa;ooooo0P000?l0
0oooool0003o0000o`030000o`cooooo1P000?l3ooooo`T0003o;oooool20000o`03ooooo`000?oo
oooo0080003o00?ooooo0000ooooool03_ooool70000oaGooooo0Ol000010000007ooooo000Koooo
o`0300000?oooooooooo00_ooooo2P000?l7ooooo`X0003o2oooool30000o`03ooooo`000?oooooo
00;ooooo0`000?l01?ooool0003o0000ooooool50000oaSooooo1`000?lBooooo`80003o00?ooooo
0000o`000?l00`000?l<ooooo`H0003o0oooool90000oboooooo0P000?l00oooool0003oooooo`02
0000o`03ooooo`000?oooooo00kooooo1`000?lFooooo`4000000Oooool001_ooooo00<00000oooo
ooooool02oooool60000o`04ooooo`000?l0003o0000o`Oooooo2P000?l;ooooo`<0003o00?ooooo
0000ooooool00_ooool010000?ooooooooooooooool20000o`03ooooo`000?l0003o00<0003o6?oo
ool70000oa;ooooo0P000?l00oooool0003o0000o`030000o`cooooo1P000?l3ooooo`T0003o;ooo
ool20000o`?ooooo0P000?l00oooool0003oooooo`0>ooooo`L0003o5_ooool10000007ooooo000K
ooooo`0300000?oooooooooo00_ooooo1P000?l01?ooool0003oooooo`000?l7ooooo`030000oooo
ool0003o00L0003o2oooool30000o`Gooooo00D0003ooooooooooooooooo0000o`03ooooo`@0003o
6?ooool70000oa;ooooo0P000?l00oooool0003o0000o`020000o`gooooo1P000?l3ooooo`T0003o
;oooool20000o`?ooooo0P000?l00oooool0003oooooo`0>ooooo`H0003o5oooool10000007ooooo
000Kooooo`0300000?oooooooooo00_ooooo1P000?l;ooooo`030000ooooool0003o00L0003o2ooo
ool30000o`Gooooo00D0003ooooooooooooooooo0000o`03ooooo`040000oooooooooooo0000oaSo
oooo1`000?lBooooo`80003o00?ooooo0000o`000?l00P000?l=ooooo`H0003o0oooool90000oboo
oooo0P000?l3ooooo`80003o00?ooooo0000ooooool03_ooool40000o`03ooooo`000?oooooo01Ko
oooo0@000001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo
00<00000ooooooooool02oooool60000o`_ooooo00<0003oooooo`000?l01@000?l00oooool0003o
ooooo`0:ooooo`<0003o2Oooool01@000?ooooooooooooooool0003o00;ooooo00<0003ooooooooo
ool05_ooool70000oa;ooooo00<0003oooooooooool010000?l=ooooo`H0003o0oooool80000oc3o
oooo0P000?l6ooooo`030000oooooooooooo00gooooo10000?l00oooool0003oooooo`0Fooooo`40
00000Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03
00000?oooooooooo00_ooooo10000?l00oooool0003oooooo`0:ooooo`030000ooooool0003o00D0
003o00?ooooo0000ooooool02_ooool30000oa3ooooo00<0003oooooooooool05_ooool70000oa;o
oooo00<0003oooooooooool010000?l=ooooo`H0003o0oooool80000oc3ooooo0P000?l6ooooo`03
0000oooooooooooo00gooooo10000?l00oooool0003oooooo`0Fooooo`4000000Oooool000Oooooo
00Co0000oooooooooooo00001oooool5o`0000Cooooo00<00000o`000?ooool02oooool40000o`03
ooooo`000?oooooo00[ooooo00<0003oooooo`000?l01@000?l00oooool0003oooooo`0:ooooo`<0
003o4?ooool00`000?ooooooooooo`0Fooooo`L0003o4_ooool00`000?ooooooooooo`040000o`go
oooo1P000?l3ooooo`P0003o<?ooool20000o`Kooooo00<0003oooooooooool03Oooool00`000?oo
oooo0000o`030000oaKooooo0Ol000010000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0;ooooo`<0003o0_ooool00`00
0?ooooooooooo`0;ooooo`D0003o3_ooool30000oa3ooooo00<0003oooooooooool05_ooool70000
oa;ooooo00H0003oooooooooool0003oooooo`000?l>ooooo`H0003o0oooool70000oc7ooooo0P00
0?lFooooo`030000ooooool0003o00;ooooo00<0003oooooooooool05Oooool10000007ooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001Oooool00`00003ooooooooo
o`0;ooooo`<0003o4?ooool40000o`oooooo0`000?l@ooooo`030000oooooooooooo01Kooooo1000
0?l2ooooo`030000oooooooooooo013ooooo00<0003oooooooooool00_ooool00`000?oooooooooo
o`0<ooooo`H0003o0oooool70000oc7ooooo0P000?lHooooo`030000oooooooooooo01Sooooo0@00
0001ooooo`001oooool01?l0003oooooooooool00009ooooo`;o00001Oooool00`00003ooooooooo
o`0;ooooo`<0003o4Oooool20000oa3ooooo0`000?lYooooo`@0003o5Oooool00`000?oooooooooo
o`02ooooo`030000oooooooooooo00cooooo1P000?l3ooooo`L0003o<_ooool00`000?oooooooooo
o`0aooooo`4000000Oooool000Sooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00<00000
ooooooooool02oooool30000oa7ooooo0P000?l@ooooo`<0003o:Oooool40000oaGooooo00<0003o
ooooooooool00_ooool00`000?ooooooooooo`0<ooooo`H0003o0oooool70000oc;ooooo00<0003o
ooooooooool0<Oooool10000007ooooo000Kooooo`0300000?oooooooooo00_ooooo0`000?lAoooo
o`80003o4?ooool30000obWooooo10000?lJooooo`030000oooooooooooo00cooooo1P000?l3oooo
o`L0003o<_ooool00`000?ooooooooooo`0aooooo`4000000Oooool001_ooooo00<00000oooooooo
ool02oooool30000oa7ooooo0P000?l@ooooo`<0003o:Oooool20000oacooooo00<0003ooooooooo
ool03?ooool50000o`Cooooo00<0003oooooo`000?l00P000?l00oooool0003oooooo`0aooooo`03
0000oooooooooooo037ooooo0@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`<0003o
4Oooool00`000?ooooooooooo`0?ooooo`<0003o:Oooool20000ob_ooooo1@000?l4ooooo`030000
ooooool0003o0080003oJ?ooool10000007ooooo000Kooooo`0300000?l0003ooooo00_ooooo0`00
0?lSooooo`<0003o:Oooool00`000?ooooooooooo`0Zooooo`D0003o1?ooool010000?oooooo0000
o`000?mXooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`030000oooo
ool0003o02?ooooo0`000?lYooooo`030000oooooooooooo02[ooooo1@000?l4ooooo`040000oooo
ool0003o0000ofWooooo0@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`030000oooo
oooooooo02?ooooo0`000?lYooooo`030000oooooooooooo02[ooooo1@000?l6ooooo`80003oJOoo
ool10000007ooooo000Kooooo`0300000?oooooooooo00_ooooo00<0003oooooooooool08oooool0
0`000?oooooo0000o`0Yooooo`030000oooooooooooo02[ooooo10000?l7ooooo`030000oooooooo
oooo06Sooooo0@000001ooooo`006oooool00`00003oooooooooo`0;ooooo`030000oooooooooooo
02?ooooo00<0003oooooo`000?l0Eoooool30000o`Oooooo00<0003oooooooooool0J?ooool10000
007ooooo000Kooooo`0300000?oooooooooo00_ooooo00<0003oooooooooool08oooool00`000?oo
oooo0000o`1Gooooo`<0003o1oooool00`000?ooooooooooo`1Xooooo`4000000Oooool001_ooooo
00<00000ooooooooool02oooool00`000?ooooooooooo`0Sooooo`030000ooooool0003o05Oooooo
0`000?l7ooooo`030000oooooooooooo06Sooooo0@000001ooooo`006oooool00`00003o0000oooo
o`0cooooo`030000oooooooooooo05Gooooo0`000?l7ooooo`030000oooooooooooo06Oooooo0Ol0
00010000007ooooo000Kooooo`0300000?oooooooooo08_ooooo0P000?l8ooooo`030000oooooooo
oooo06Sooooo0@000001ooooo`006oooool00`00003oooooooooo`2;ooooo`80003oLoooool10000
007ooooo000Kooooo`0300000?oooooooooo08_ooooo0P000?mcooooo`4000000Oooool001_ooooo
00<00000ooooooooool0Roooool00`000?ooooooooooo`1booooo`4000000Oooool001_ooooo00<0
0000ooooooooool0Roooool00`000?ooooooooooo`1booooo`4000000Oooool001_ooooo00<00000
ooooooooool0Roooool00`000?ooooooooooo`1booooo`4000000Oooool001_ooooo00<00000o`00
0?ooool0Roooool00`000?ooooooooooo`1aooooo`7o00000@000001ooooo`006oooool00`00003o
ooooooooo`2;ooooo`030000oooooooooooo07;ooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`3oooooo`7ooooo0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01Oooool10000007ooooo000Kooooool000001@000001
ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.518143, -0.642978, \
0.0155028, 0.00700387}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zoom in a little", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Take[sound1, {11000, 12000}], \ PlotRange \[Rule] All, \ 
        PlotStyle \[Rule] Blue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-10.4524 10.5971 0.284992 0.768789 [
[.14476 -0.0125 -3 -9 ]
[.14476 -0.0125 3 0 ]
[.3567 -0.0125 -12 -9 ]
[.3567 -0.0125 12 0 ]
[.56865 -0.0125 -12 -9 ]
[.56865 -0.0125 12 0 ]
[.78059 -0.0125 -12 -9 ]
[.78059 -0.0125 12 0 ]
[.99253 -0.0125 -12 -9 ]
[.99253 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .13123 -24 -4.5 ]
[-0.0125 .13123 0 4.5 ]
[-0.0125 .28499 -6 -4.5 ]
[-0.0125 .28499 0 4.5 ]
[-0.0125 .43875 -18 -4.5 ]
[-0.0125 .43875 0 4.5 ]
[-0.0125 .59251 -18 -4.5 ]
[-0.0125 .59251 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14476 0 m
.14476 .00625 L
s
[(1)] .14476 -0.0125 0 1 Mshowa
.3567 0 m
.3567 .00625 L
s
[(1.02)] .3567 -0.0125 0 1 Mshowa
.56865 0 m
.56865 .00625 L
s
[(1.04)] .56865 -0.0125 0 1 Mshowa
.78059 0 m
.78059 .00625 L
s
[(1.06)] .78059 -0.0125 0 1 Mshowa
.99253 0 m
.99253 .00625 L
s
[(1.08)] .99253 -0.0125 0 1 Mshowa
.125 Mabswid
.19775 0 m
.19775 .00375 L
s
.25073 0 m
.25073 .00375 L
s
.30372 0 m
.30372 .00375 L
s
.40969 0 m
.40969 .00375 L
s
.46268 0 m
.46268 .00375 L
s
.51566 0 m
.51566 .00375 L
s
.62163 0 m
.62163 .00375 L
s
.67462 0 m
.67462 .00375 L
s
.7276 0 m
.7276 .00375 L
s
.83358 0 m
.83358 .00375 L
s
.88656 0 m
.88656 .00375 L
s
.93955 0 m
.93955 .00375 L
s
.09178 0 m
.09178 .00375 L
s
.03879 0 m
.03879 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .13123 m
.00625 .13123 L
s
[(-0.2)] -0.0125 .13123 1 0 Mshowa
0 .28499 m
.00625 .28499 L
s
[(0)] -0.0125 .28499 1 0 Mshowa
0 .43875 m
.00625 .43875 L
s
[(0.2)] -0.0125 .43875 1 0 Mshowa
0 .59251 m
.00625 .59251 L
s
[(0.4)] -0.0125 .59251 1 0 Mshowa
.125 Mabswid
0 .16967 m
.00375 .16967 L
s
0 .20811 m
.00375 .20811 L
s
0 .24655 m
.00375 .24655 L
s
0 .32343 m
.00375 .32343 L
s
0 .36187 m
.00375 .36187 L
s
0 .40031 m
.00375 .40031 L
s
0 .47719 m
.00375 .47719 L
s
0 .51563 m
.00375 .51563 L
s
0 .55407 m
.00375 .55407 L
s
0 .0928 m
.00375 .0928 L
s
0 .05436 m
.00375 .05436 L
s
0 .01592 m
.00375 .01592 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.14476 .61178 m
.14476 .61803 L
s
.3567 .61178 m
.3567 .61803 L
s
.56865 .61178 m
.56865 .61803 L
s
.78059 .61178 m
.78059 .61803 L
s
.99253 .61178 m
.99253 .61803 L
s
.125 Mabswid
.19775 .61428 m
.19775 .61803 L
s
.25073 .61428 m
.25073 .61803 L
s
.30372 .61428 m
.30372 .61803 L
s
.40969 .61428 m
.40969 .61803 L
s
.46268 .61428 m
.46268 .61803 L
s
.51566 .61428 m
.51566 .61803 L
s
.62163 .61428 m
.62163 .61803 L
s
.67462 .61428 m
.67462 .61803 L
s
.7276 .61428 m
.7276 .61803 L
s
.83358 .61428 m
.83358 .61803 L
s
.88656 .61428 m
.88656 .61803 L
s
.93955 .61428 m
.93955 .61803 L
s
.09178 .61428 m
.09178 .61803 L
s
.03879 .61428 m
.03879 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .13123 m
1 .13123 L
s
.99375 .28499 m
1 .28499 L
s
.99375 .43875 m
1 .43875 L
s
.99375 .59251 m
1 .59251 L
s
.125 Mabswid
.99625 .16967 m
1 .16967 L
s
.99625 .20811 m
1 .20811 L
s
.99625 .24655 m
1 .24655 L
s
.99625 .32343 m
1 .32343 L
s
.99625 .36187 m
1 .36187 L
s
.99625 .40031 m
1 .40031 L
s
.99625 .47719 m
1 .47719 L
s
.99625 .51563 m
1 .51563 L
s
.99625 .55407 m
1 .55407 L
s
.99625 .0928 m
1 .0928 L
s
.99625 .05436 m
1 .05436 L
s
.99625 .01592 m
1 .01592 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .28499 m
1 .28499 L
s
0 0 1 r
.5 Mabswid
.02381 .32704 m
.02476 .17088 L
.02571 .24295 L
.02667 .21892 L
.02762 .28499 L
.02857 .36307 L
.02952 .35106 L
.03048 .35106 L
.03143 .30902 L
.03238 .22493 L
.03333 .20091 L
.03429 .20091 L
.03524 .27899 L
.03619 .50722 L
.03714 .38109 L
.0381 .1949 L
.03905 .28499 L
.04 .26097 L
.04095 .23094 L
.0419 .23694 L
.04286 .26697 L
.04381 .36908 L
.04476 .33905 L
.04571 .23094 L
.04667 .24896 L
.04762 .20691 L
.04857 .23694 L
.04952 .54326 L
.05048 .32103 L
.05143 .14084 L
.05238 .32103 L
.05333 .21292 L
.05429 .27899 L
.05524 .28499 L
.05619 .20091 L
.05714 .32704 L
.0581 .30902 L
.05905 .23094 L
.06 .27298 L
.06095 .20091 L
.0619 .3931 L
.06286 .50121 L
.06381 .10481 L
.06476 .23694 L
.06571 .291 L
.06667 .1949 L
.06762 .37508 L
.06857 .27899 L
.06952 .24295 L
.07048 .33905 L
Mistroke
.07143 .21892 L
.07238 .20691 L
.07333 .27899 L
.07429 .30301 L
.07524 .47118 L
.07619 .42914 L
.07714 .15286 L
.0781 .20691 L
.07905 .27899 L
.08 .297 L
.08095 .291 L
.0819 .26697 L
.08286 .35106 L
.08381 .34505 L
.08476 .24295 L
.08571 .28499 L
.08667 .26097 L
.08762 .291 L
.08857 .46518 L
.08952 .21892 L
.09048 .1949 L
.09143 .33304 L
.09238 .25496 L
.09333 .25496 L
.09429 .297 L
.09524 .297 L
.09619 .27298 L
.09714 .35707 L
.0981 .31502 L
.09905 .1949 L
.1 .21292 L
.10095 .24295 L
.1019 .32103 L
.10286 .47118 L
.10381 .26697 L
.10476 .20691 L
.10571 .33304 L
.10667 .23694 L
.10762 .22493 L
.10857 .22493 L
.10952 .26697 L
.11048 .33304 L
.11143 .27899 L
.11238 .24295 L
.11333 .26697 L
.11429 .17688 L
.11524 .36908 L
.11619 .50722 L
.11714 .0928 L
.1181 .22493 L
Mistroke
.11905 .33905 L
.12 .1949 L
.12095 .30902 L
.1219 .25496 L
.12286 .23694 L
.12381 .33304 L
.12476 .21292 L
.12571 .23094 L
.12667 .25496 L
.12762 .297 L
.12857 .56728 L
.12952 .25496 L
.13048 .11682 L
.13143 .31502 L
.13238 .21292 L
.13333 .28499 L
.13429 .30902 L
.13524 .27899 L
.13619 .3871 L
.13714 .27899 L
.1381 .1949 L
.13905 .24295 L
.14 .22493 L
.14095 .34505 L
.1419 .53124 L
.14286 .21892 L
.14381 .14685 L
.14476 .33304 L
.14571 .26697 L
.14667 .22493 L
.14762 .24295 L
.14857 .35106 L
.14952 .38109 L
.15048 .27298 L
.15143 .18289 L
.15238 .21292 L
.15333 .23694 L
.15429 .41112 L
.15524 .47719 L
.15619 .0928 L
.15714 .22493 L
.1581 .39911 L
.15905 .25496 L
.16 .23694 L
.16095 .21892 L
.1619 .30902 L
.16286 .33304 L
.16381 .1949 L
.16476 .21292 L
.16571 .24896 L
Mistroke
.16667 .20691 L
.16762 .53725 L
.16857 .41112 L
.16952 .01472 L
.17048 .28499 L
.17143 .27899 L
.17238 .21292 L
.17333 .30301 L
.17429 .23094 L
.17524 .33905 L
.17619 .34505 L
.17714 .15886 L
.1781 .24295 L
.17905 .21892 L
.18 .21292 L
.18095 .60332 L
.1819 .30301 L
.18286 .07478 L
.18381 .37508 L
.18476 .24896 L
.18571 .24896 L
.18667 .26097 L
.18762 .24896 L
.18857 .39911 L
.18952 .28499 L
.19048 .18889 L
.19143 .31502 L
.19238 .30301 L
.19333 .35707 L
.19429 .35707 L
.19524 .42914 L
.19619 .15886 L
.19714 .23694 L
.1981 .32704 L
.19905 .21892 L
.2 .27899 L
.20095 .27298 L
.2019 .30902 L
.20286 .35707 L
.20381 .27298 L
.20476 .22493 L
.20571 .23094 L
.20667 .27298 L
.20762 .45917 L
.20857 .291 L
.20952 .15286 L
.21048 .32103 L
.21143 .297 L
.21238 .24896 L
.21333 .24896 L
Mistroke
.21429 .26097 L
.21524 .35707 L
.21619 .30902 L
.21714 .20691 L
.2181 .22493 L
.21905 .20691 L
.22 .30301 L
.22095 .50722 L
.2219 .20691 L
.22286 .17088 L
.22381 .39911 L
.22476 .25496 L
.22571 .23094 L
.22667 .20091 L
.22762 .24295 L
.22857 .36307 L
.22952 .26097 L
.23048 .20691 L
.23143 .30902 L
.23238 .18889 L
.23333 .32704 L
.23429 .57329 L
.23524 .14685 L
.23619 .20691 L
.23714 .35106 L
.2381 .21892 L
.23905 .26697 L
.24 .21292 L
.24095 .28499 L
.2419 .3931 L
.24286 .25496 L
.24381 .24295 L
.24476 .27298 L
.24571 .35707 L
.24667 .4832 L
.24762 .1949 L
.24857 .17088 L
.24952 .36908 L
.25048 .25496 L
.25143 .23694 L
.25238 .28499 L
.25333 .291 L
.25429 .36908 L
.25524 .26097 L
.25619 .20091 L
.25714 .27298 L
.2581 .30301 L
.25905 .43515 L
.26 .28499 L
.26095 .17088 L
Mistroke
.2619 .33905 L
.26286 .291 L
.26381 .1949 L
.26476 .26097 L
.26571 .33304 L
.26667 .33905 L
.26762 .30301 L
.26857 .23694 L
.26952 .24896 L
.27048 .24295 L
.27143 .24295 L
.27238 .41112 L
.27333 .30902 L
.27429 .16487 L
.27524 .33304 L
.27619 .32704 L
.27714 .24295 L
.2781 .23094 L
.27905 .24295 L
.28 .30902 L
.28095 .27899 L
.2819 .21292 L
.28286 .27298 L
.28381 .26697 L
.28476 .24896 L
.28571 .45316 L
.28667 .32704 L
.28762 .16487 L
.28857 .37508 L
.28952 .27298 L
.29048 .1949 L
.29143 .25496 L
.29238 .24295 L
.29333 .291 L
.29429 .28499 L
.29524 .28499 L
.29619 .26097 L
.29714 .32103 L
.2981 .21892 L
.29905 .42313 L
.3 .47719 L
.30095 .11081 L
.3019 .30902 L
.30286 .32103 L
.30381 .16487 L
.30476 .291 L
.30571 .23694 L
.30667 .297 L
.30762 .37508 L
.30857 .18289 L
Mistroke
.30952 .27899 L
.31048 .27899 L
.31143 .36908 L
.31238 .4892 L
.31333 .10481 L
.31429 .18889 L
.31524 .41112 L
.31619 .23094 L
.31714 .21292 L
.3181 .24896 L
.31905 .30902 L
.32 .37508 L
.32095 .24295 L
.3219 .26097 L
.32286 .30301 L
.32381 .22493 L
.32476 .28499 L
.32571 .3871 L
.32667 .23694 L
.32762 .20691 L
.32857 .33304 L
.32952 .27899 L
.33048 .24295 L
.33143 .27899 L
.33238 .24896 L
.33333 .30902 L
.33429 .28499 L
.33524 .20091 L
.33619 .23694 L
.33714 .23094 L
.3381 .42313 L
.33905 .38109 L
.34 .14685 L
.34095 .32704 L
.3419 .35707 L
.34286 .21292 L
.34381 .22493 L
.34476 .21292 L
.34571 .291 L
.34667 .32103 L
.34762 .18889 L
.34857 .27899 L
.34952 .26697 L
.35048 .31502 L
.35143 .53725 L
.35238 .23694 L
.35333 .18889 L
.35429 .41112 L
.35524 .20691 L
.35619 .18889 L
Mistroke
.35714 .26097 L
.3581 .22493 L
.35905 .35106 L
.36 .24295 L
.36095 .21892 L
.3619 .32704 L
.36286 .30902 L
.36381 .4892 L
.36476 .297 L
.36571 .11682 L
.36667 .35106 L
.36762 .28499 L
.36857 .15886 L
.36952 .24896 L
.37048 .26697 L
.37143 .33304 L
.37238 .297 L
.37333 .20691 L
.37429 .32704 L
.37524 .297 L
.37619 .36908 L
.37714 .36307 L
.3781 .12883 L
.37905 .26097 L
.38 .33304 L
.38095 .18889 L
.3819 .24295 L
.38286 .30902 L
.38381 .297 L
.38476 .33905 L
.38571 .24295 L
.38667 .23094 L
.38762 .26097 L
.38857 .30301 L
.38952 .41112 L
.39048 .1949 L
.39143 .18289 L
.39238 .40512 L
.39333 .27298 L
.39429 .21892 L
.39524 .27899 L
.39619 .27899 L
.39714 .26697 L
.3981 .33905 L
.39905 .24896 L
.4 .18889 L
.40095 .297 L
.4019 .22493 L
.40286 .297 L
.40381 .50722 L
Mistroke
.40476 .24295 L
.40571 .20691 L
.40667 .44716 L
.40762 .28499 L
.40857 .21292 L
.40952 .24896 L
.41048 .21292 L
.41143 .32103 L
.41238 .23094 L
.41333 .18889 L
.41429 .31502 L
.41524 .23694 L
.41619 .3931 L
.41714 .50121 L
.4181 .18289 L
.41905 .27298 L
.42 .42313 L
.42095 .20691 L
.4219 .18889 L
.42286 .21892 L
.42381 .26097 L
.42476 .32103 L
.42571 .17688 L
.42667 .24896 L
.42762 .35106 L
.42857 .30301 L
.42952 .43515 L
.43048 .32704 L
.43143 .18289 L
.43238 .36908 L
.43333 .297 L
.43429 .14084 L
.43524 .22493 L
.43619 .26097 L
.43714 .297 L
.4381 .28499 L
.43905 .20091 L
.44 .291 L
.44095 .297 L
.4419 .35106 L
.44286 .38109 L
.44381 .20091 L
.44476 .297 L
.44571 .3871 L
.44667 .1949 L
.44762 .20091 L
.44857 .30301 L
.44952 .26697 L
.45048 .28499 L
.45143 .24896 L
Mistroke
.45238 .23694 L
.45333 .24295 L
.45429 .32704 L
.45524 .40512 L
.45619 .27298 L
.45714 .291 L
.4581 .37508 L
.45905 .291 L
.46 .26697 L
.46095 .24896 L
.4619 .24295 L
.46286 .30301 L
.46381 .26697 L
.46476 .24295 L
.46571 .24295 L
.46667 .24896 L
.46762 .35106 L
.46857 .35707 L
.46952 .25496 L
.47048 .31502 L
.47143 .33304 L
.47238 .297 L
.47333 .291 L
.47429 .23094 L
.47524 .26097 L
.47619 .31502 L
.47714 .24896 L
.4781 .24295 L
.47905 .27899 L
.48 .26697 L
.48095 .297 L
.4819 .31502 L
.48286 .25496 L
.48381 .28499 L
.48476 .32103 L
.48571 .291 L
.48667 .27298 L
.48762 .25496 L
.48857 .27298 L
.48952 .30301 L
.49048 .25496 L
.49143 .25496 L
.49238 .28499 L
.49333 .25496 L
.49429 .27298 L
.49524 .30902 L
.49619 .26697 L
.49714 .26697 L
.4981 .27899 L
.49905 .30902 L
Mistroke
.5 .27899 L
.50095 .26097 L
.5019 .27899 L
.50286 .291 L
.50381 .27298 L
.50476 .27298 L
.50571 .291 L
.50667 .27298 L
.50762 .26697 L
.50857 .28499 L
.50952 .30301 L
.51048 .32103 L
.51143 .28499 L
.51238 .27298 L
.51333 .30301 L
.51429 .297 L
.51524 .27899 L
.51619 .26697 L
.51714 .27298 L
.5181 .30301 L
.51905 .27899 L
.52 .26697 L
.52095 .28499 L
.5219 .27899 L
.52286 .28499 L
.52381 .32103 L
.52476 .28499 L
.52571 .24896 L
.52667 .297 L
.52762 .30301 L
.52857 .26697 L
.52952 .26097 L
.53048 .27298 L
.53143 .28499 L
.53238 .28499 L
.53333 .26097 L
.53429 .27899 L
.53524 .28499 L
.53619 .26697 L
.53714 .30902 L
.5381 .30301 L
.53905 .22493 L
.54 .28499 L
.54095 .30301 L
.5419 .26697 L
.54286 .26697 L
.54381 .26697 L
.54476 .26697 L
.54571 .28499 L
.54667 .25496 L
Mistroke
.54762 .28499 L
.54857 .291 L
.54952 .27899 L
.55048 .27899 L
.55143 .30301 L
.55238 .25496 L
.55333 .25496 L
.55429 .297 L
.55524 .297 L
.55619 .26097 L
.55714 .26097 L
.5581 .27298 L
.55905 .28499 L
.56 .28499 L
.56095 .28499 L
.5619 .297 L
.56286 .291 L
.56381 .28499 L
.56476 .297 L
.56571 .291 L
.56667 .26697 L
.56762 .30301 L
.56857 .291 L
.56952 .26697 L
.57048 .27298 L
.57143 .291 L
.57238 .28499 L
.57333 .297 L
.57429 .291 L
.57524 .28499 L
.57619 .27298 L
.57714 .26097 L
.5781 .291 L
.57905 .32704 L
.58 .25496 L
.58095 .26097 L
.5819 .297 L
.58286 .291 L
.58381 .26097 L
.58476 .27298 L
.58571 .27899 L
.58667 .291 L
.58762 .27298 L
.58857 .26697 L
.58952 .27298 L
.59048 .24896 L
.59143 .26697 L
.59238 .33905 L
.59333 .26097 L
.59429 .23094 L
Mistroke
.59524 .30902 L
.59619 .30301 L
.59714 .27298 L
.5981 .27298 L
.59905 .26697 L
.6 .25496 L
.60095 .27298 L
.6019 .27899 L
.60286 .26097 L
.60381 .28499 L
.60476 .25496 L
.60571 .26097 L
.60667 .32704 L
.60762 .26097 L
.60857 .24295 L
.60952 .32704 L
.61048 .30902 L
.61143 .27298 L
.61238 .26697 L
.61333 .26697 L
.61429 .27899 L
.61524 .291 L
.61619 .27899 L
.61714 .291 L
.6181 .27298 L
.61905 .26697 L
.62 .31502 L
.62095 .30301 L
.6219 .27298 L
.62286 .30902 L
.62381 .30301 L
.62476 .291 L
.62571 .27298 L
.62667 .26697 L
.62762 .28499 L
.62857 .297 L
.62952 .26697 L
.63048 .27899 L
.63143 .26097 L
.63238 .26697 L
.63333 .31502 L
.63429 .297 L
.63524 .26697 L
.63619 .291 L
.63714 .291 L
.6381 .27899 L
.63905 .27298 L
.64 .27298 L
.64095 .291 L
.6419 .27899 L
Mistroke
.64286 .26097 L
.64381 .27298 L
.64476 .26697 L
.64571 .26697 L
.64667 .27298 L
.64762 .31502 L
.64857 .27899 L
.64952 .24896 L
.65048 .28499 L
.65143 .291 L
.65238 .28499 L
.65333 .26097 L
.65429 .26097 L
.65524 .27298 L
.65619 .28499 L
.65714 .27298 L
.6581 .28499 L
.65905 .26697 L
.66 .26097 L
.66095 .297 L
.6619 .31502 L
.66286 .23694 L
.66381 .27298 L
.66476 .297 L
.66571 .28499 L
.66667 .27899 L
.66762 .27298 L
.66857 .27298 L
.66952 .291 L
.67048 .28499 L
.67143 .291 L
.67238 .27899 L
.67333 .27298 L
.67429 .28499 L
.67524 .32704 L
.67619 .28499 L
.67714 .26097 L
.6781 .30902 L
.67905 .291 L
.68 .297 L
.68095 .291 L
.6819 .27298 L
.68286 .27899 L
.68381 .28499 L
.68476 .27899 L
.68571 .291 L
.68667 .27899 L
.68762 .28499 L
.68857 .28499 L
.68952 .30301 L
Mistroke
.69048 .27298 L
.69143 .27298 L
.69238 .297 L
.69333 .28499 L
.69429 .28499 L
.69524 .26697 L
.69619 .26097 L
.69714 .26697 L
.6981 .28499 L
.69905 .28499 L
.7 .28499 L
.70095 .28499 L
.7019 .27298 L
.70286 .26697 L
.70381 .27298 L
.70476 .297 L
.70571 .28499 L
.70667 .27298 L
.70762 .27298 L
.70857 .27899 L
.70952 .27899 L
.71048 .27298 L
.71143 .27298 L
.71238 .27899 L
.71333 .27899 L
.71429 .27899 L
.71524 .27899 L
.71619 .27298 L
.71714 .27899 L
.7181 .28499 L
.71905 .297 L
.72 .291 L
.72095 .26097 L
.7219 .27899 L
.72286 .297 L
.72381 .30301 L
.72476 .27899 L
.72571 .27899 L
.72667 .28499 L
.72762 .297 L
.72857 .291 L
.72952 .291 L
.73048 .291 L
.73143 .28499 L
.73238 .27899 L
.73333 .291 L
.73429 .32103 L
.73524 .27298 L
.73619 .27298 L
.73714 .297 L
Mistroke
.7381 .291 L
.73905 .27298 L
.74 .27899 L
.74095 .28499 L
.7419 .28499 L
.74286 .27298 L
.74381 .27899 L
.74476 .27899 L
.74571 .27298 L
.74667 .27899 L
.74762 .291 L
.74857 .297 L
.74952 .24896 L
.75048 .28499 L
.75143 .28499 L
.75238 .28499 L
.75333 .27899 L
.75429 .27899 L
.75524 .26697 L
.75619 .27298 L
.75714 .27298 L
.7581 .28499 L
.75905 .27899 L
.76 .27298 L
.76095 .27298 L
.7619 .28499 L
.76286 .30301 L
.76381 .25496 L
.76476 .27899 L
.76571 .297 L
.76667 .28499 L
.76762 .27899 L
.76857 .27298 L
.76952 .26697 L
.77048 .28499 L
.77143 .27899 L
.77238 .28499 L
.77333 .291 L
.77429 .27298 L
.77524 .27899 L
.77619 .28499 L
.77714 .30902 L
.7781 .27298 L
.77905 .27899 L
.78 .30301 L
.78095 .291 L
.7819 .291 L
.78286 .27899 L
.78381 .27899 L
.78476 .28499 L
Mistroke
.78571 .297 L
.78667 .291 L
.78762 .28499 L
.78857 .27298 L
.78952 .28499 L
.79048 .28499 L
.79143 .291 L
.79238 .30301 L
.79333 .27298 L
.79429 .27298 L
.79524 .27899 L
.79619 .291 L
.79714 .27899 L
.7981 .27899 L
.79905 .27298 L
.8 .27298 L
.80095 .27298 L
.8019 .27298 L
.80286 .27899 L
.80381 .27899 L
.80476 .27298 L
.80571 .28499 L
.80667 .27899 L
.80762 .28499 L
.80857 .27899 L
.80952 .27298 L
.81048 .27899 L
.81143 .27298 L
.81238 .27899 L
.81333 .27298 L
.81429 .26697 L
.81524 .27298 L
.81619 .27899 L
.81714 .27899 L
.8181 .27298 L
.81905 .27899 L
.82 .28499 L
.82095 .27899 L
.8219 .26697 L
.82286 .291 L
.82381 .27899 L
.82476 .26097 L
.82571 .27899 L
.82667 .28499 L
.82762 .291 L
.82857 .27899 L
.82952 .26697 L
.83048 .27899 L
.83143 .291 L
.83238 .28499 L
Mistroke
.83333 .291 L
.83429 .28499 L
.83524 .28499 L
.83619 .27899 L
.83714 .28499 L
.8381 .30301 L
.83905 .27298 L
.84 .291 L
.84095 .291 L
.8419 .291 L
.84286 .28499 L
.84381 .27298 L
.84476 .27899 L
.84571 .291 L
.84667 .27298 L
.84762 .27899 L
.84857 .28499 L
.84952 .27899 L
.85048 .28499 L
.85143 .27298 L
.85238 .28499 L
.85333 .291 L
.85429 .26097 L
.85524 .27298 L
.85619 .27899 L
.85714 .28499 L
.8581 .28499 L
.85905 .26097 L
.86 .26697 L
.86095 .27899 L
.8619 .27298 L
.86286 .27899 L
.86381 .27899 L
.86476 .27899 L
.86571 .27899 L
.86667 .26697 L
.86762 .27298 L
.86857 .291 L
.86952 .27298 L
.87048 .26697 L
.87143 .27899 L
.87238 .28499 L
.87333 .28499 L
.87429 .26097 L
.87524 .26697 L
.87619 .28499 L
.87714 .27298 L
.8781 .27298 L
.87905 .27899 L
.88 .27298 L
Mistroke
.88095 .28499 L
.8819 .27298 L
.88286 .27899 L
.88381 .297 L
.88476 .291 L
.88571 .27899 L
.88667 .27899 L
.88762 .291 L
.88857 .30301 L
.88952 .27899 L
.89048 .27298 L
.89143 .297 L
.89238 .28499 L
.89333 .28499 L
.89429 .291 L
.89524 .291 L
.89619 .291 L
.89714 .27899 L
.8981 .27899 L
.89905 .28499 L
.9 .28499 L
.90095 .30301 L
.9019 .27899 L
.90286 .27298 L
.90381 .27899 L
.90476 .297 L
.90571 .297 L
.90667 .26097 L
.90762 .27899 L
.90857 .291 L
.90952 .26697 L
.91048 .27298 L
.91143 .28499 L
.91238 .27899 L
.91333 .28499 L
.91429 .27298 L
.91524 .27298 L
.91619 .28499 L
.91714 .28499 L
.9181 .27899 L
.91905 .28499 L
.92 .28499 L
.92095 .30301 L
.9219 .26097 L
.92286 .25496 L
.92381 .28499 L
.92476 .27899 L
.92571 .27298 L
.92667 .27298 L
.92762 .27298 L
Mistroke
.92857 .27899 L
.92952 .27298 L
.93048 .27298 L
.93143 .27298 L
.93238 .291 L
.93333 .291 L
.93429 .26697 L
.93524 .27899 L
.93619 .30902 L
.93714 .30902 L
.9381 .26697 L
.93905 .27298 L
.94 .291 L
.94095 .27899 L
.9419 .27899 L
.94286 .27899 L
.94381 .291 L
.94476 .28499 L
.94571 .27899 L
.94667 .27899 L
.94762 .27899 L
.94857 .32103 L
.94952 .27899 L
.95048 .27899 L
.95143 .30301 L
.95238 .32103 L
.95333 .30301 L
.95429 .26097 L
.95524 .291 L
.95619 .291 L
.95714 .27899 L
.9581 .27899 L
.95905 .27298 L
.96 .27899 L
.96095 .28499 L
.9619 .27298 L
.96286 .26097 L
.96381 .27298 L
.96476 .31502 L
.96571 .27298 L
.96667 .26097 L
.96762 .297 L
.96857 .31502 L
.96952 .297 L
.97048 .26697 L
.97143 .27298 L
.97238 .27298 L
.97333 .26097 L
.97429 .27298 L
.97524 .26697 L
Mistroke
.97619 .27298 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00?Oooool3o`0002Wooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo0_l00002oooo
o`Go00007oooool3o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol0000Ooooo
o`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`00023ooooo0ol00004oooo
o`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00000oooool003kooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00008?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`7o00000Oooool1ooooo`00?_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo0000ooooo`05o`00023ooooo00?o
0000ooooooooool02?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo00000oooool1
o`00007ooooo0Oooool003kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`08oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00Sooooo00Go0000oooooooooooo0000ooooo`04o`00027ooooo00?o0000oooooooo
ool02?ooool01?l0003oooooooooool00002ooooo`?o00000oooool003kooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooo`00000Qooooo`03o`000?oooooooooo00Sooooo00Ko0000oooooooooooo0000
ooooool0000Tooooo`03o`000?oooooooooo00Sooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`7o00000Oooool1ooooo`00?Oooool2o`0002[ooooo0_l0000:ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`0Mooooo`;o00002_ooool01?l0003ooooooooo
ool00003ooooo`;o00008?ooool2o`0000[ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Pooooo`;o00002_ooool01_l0003oooooooooool0003oooooo`0000?ooooo0Ol00001
ooooo`7ooooo000nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool2o`00
00?ooooo0ol0000Qooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool02Oooool2o`0000Cooooo0_l0000Qooooo`03o`000?oooooooooo
00Wooooo0_l00003ooooo`?o00000oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool001_ooooonP00000;ooooo`006oooool00`00003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000000003ooooo00[ooooo000Kooooo`0300000?oooooooooo0?Kooooo00<00000ooooooooool0
2Oooool001_ooooo00<00000ooooooooool0m_ooool00`00003oooooooooo`09ooooo`006oooool0
0`00003o0000ooooo`0Wooooo`03o`00oooooooooooo0<_ooooo00?o000000000?ooool02_ooool0
01_ooooo00<00000ooooooooool09oooool00ol00?ooooooooooo`3<ooooo`0300000?oooooooooo
00Wooooo000Kooooo`0300000?oooooooooo02Oooooo00?o003oooooooooool0c?ooool00`00003o
ooooooooo`09ooooo`006oooool00`00003oooooooooo`0Wooooo`03o`00oooooooooooo0<cooooo
00<00000ooooooooool02Oooool001_ooooo00<00000ooooooooool09oooool00ol00?oooooooooo
o`3<ooooo`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo02Oooooo00?o003o
ooooooooool0c?ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`0Woooo
o`03o`00oooooooooooo0<cooooo00<00000ooooooooool02Oooool001_ooooo00<00000oooooooo
ool09oooool00ol00?ooooooooooo`3<ooooo`0300000?oooooooooo00Wooooo000Kooooo`030000
0?oooooooooo02Oooooo00?o003oooooooooool0c?ooool00`00003oooooooooo`09ooooo`006ooo
ool00`00003o0000ooooo`0Wooooo`03o`00oooooooooooo0<_ooooo00?o000000000?ooool02_oo
ool001_ooooo00<00000ooooooooool09oooool00ol00?ooooooooooo`3<ooooo`0300000?oooooo
oooo00Wooooo000Kooooo`0300000?oooooooooo02Oooooo00?o003oooooooooool0c?ooool00`00
003oooooooooo`09ooooo`006oooool00`00003oooooooooo`0Wooooo`03o`00oooooooooooo0<co
oooo00<00000ooooooooool02Oooool001_ooooo00<00000ooooooooool09oooool00ol00?oooooo
ooooo`3<ooooo`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo02Oooooo00?o
003oooooooooool0c?ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`0W
ooooo`04o`00ooooooooooooo`00ol_ooooo00<00000ooooooooool02Oooool001_ooooo00<00000
ooooooooool09oooool01?l00?ooooooooooool00?o;ooooo`0300000?oooooooooo00Wooooo000K
ooooo`0300000?oooooooooo02Oooooo00Co003ooooooooooooo003oboooool00`00003ooooooooo
o`09ooooo`006oooool00`00003oooooooooo`0Wooooo`04o`00ooooooooooooo`00ol_ooooo00<0
0000ooooooooool02Oooool001_ooooo00<00000o`000?ooool06_ooool00ol00?ooooooooooo`07
ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool0b?ooool00ol000000000oooo
o`0:ooooo`006oooool00`00003oooooooooo`0Jooooo`03o`00oooooooooooo00Oooooo00Co003o
oooooooooooo003o0_ooool00ol00?ooooooooooo`39ooooo`0300000?oooooooooo00Wooooo000K
ooooo`0300000?oooooooooo01[ooooo00?o003oooooooooool01oooool01?l00?ooooooooooool0
0?l2ooooo`03o`00oooooooooooo0<Wooooo00<00000ooooooooool02Oooool001_ooooo00<00000
ooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00Co003o
oooooooooooo003o0_ooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo0:Sooooo00<0
0000ooooooooool02Oooool001_ooooo00<00000ooooooooool03Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o0_ooool00ol00?oooooooooo
o`0Nooooo`03o`00oooooooooooo0:Sooooo00<00000ooooooooool02Oooool001_ooooo00<00000
ooooooooool03Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Oooooo00Co003o
oooooooooooo003o0_ooool00ol00?ooooooooooo`0Kooooo`04o`00ooooooooooooo`00oj[ooooo
00<00000ooooooooool02Oooool001_ooooo00<00000ooooooooool03Oooool00ol00?oooooooooo
o`0:ooooo`04o`00ooooooooooooo`00o`Kooooo00Co003ooooooooooooo003o0_ooool00ol00?oo
ooooooooo`0Kooooo`04o`00ooooooooooooo`00o`cooooo00?o003oooooooooool0Voooool00`00
003oooooooooo`09ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004oooo
o`0300000?oooooooooo00gooooo00?o003oooooooooool02_ooool01?l00?ooooooooooool00?l6
ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool06oooool01?l00?oooooooooo
ool00?l<ooooo`03o`00oooooooooooo09_ooooo00<00000ooooooooool02Oooool000Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00go
oooo00?o003oooooooooool02_ooool01?l00?ooooooooooool00?l6ooooo`04o`00oooooooooooo
o`00o`;ooooo00?o003oooooooooool06oooool01?l00?ooooooooooool00?l<ooooo`03o`00oooo
oooooooo09_ooooo00<00000ooooooooool02Oooool000Go00000_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool03Oooool00ol00?oooooooooo
o`0:ooooo`04o`00ooooooooooooo`00o`Kooooo00Co003ooooooooooooo003o0_ooool00ol00?oo
ooooooooo`0Kooooo`04o`00ooooooooooooo`00o`cooooo00Co003ooooooooooooo003oV_ooool0
0`00003oooooooooo`09ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00?ooooo00<00000o`000?ooool03Oooool00ol00?ooooooooooo`0:ooooo`04o`00oooooooo
ooooo`00o`Kooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`0Kooooo`04o`00
ooooooooooooo`00o`cooooo00Co003ooooooooooooo003oVOooool00ol000000000ooooo`0:oooo
o`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0`00003oooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00Co003ooooooooooooo003o1_oo
ool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo01_ooooo00Co003ooooooooooooo
003o3?ooool01?l00?ooooooooooool00?nJooooo`0300000?oooooooooo00Wooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooo
oooo00Wooooo00Go003oooooooooooooooooo`00o`0<ooooo`04o`00ooooooooooooo`00o`Kooooo
00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`0Kooooo`04o`00ooooooooooooo`00
o`cooooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`2:ooooo`0300000?oooooo
oooo00Wooooo0008ooooo`;o00002Oooool3o`0000Gooooo00<00000ooooooooool02Oooool01Ol0
0?oooooooooooooooooo003o00cooooo00Co003ooooooooooooo003o1_ooool01?l00?oooooooooo
ool00?l2ooooo`03o`00oooooooooooo01_ooooo00Co003ooooooooooooo003o3?ooool01?l00?oo
ooooooooool00?l=ooooo`03o`00oooooooooooo08[ooooo00<00000ooooooooool02Oooool001_o
oooo00<00000ooooooooool02Oooool01Ol00?oooooooooooooooooo003o00cooooo00Co003ooooo
oooooooo003o0oooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`cooooo
00?o003oooooooooool03_ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00?o
oooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`2:ooooo`0300000?oooooooooo
00Wooooo000Kooooo`0300000?oooooooooo00Wooooo00Go003oooooooooooooooooo`00o`02oooo
o`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool0
0?l2ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0>ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool00oooool01?l00?oo
ooooooooool00?l=ooooo`03o`00oooooooooooo08[ooooo00<00000ooooooooool02Oooool001_o
oooo00<00000ooooooooool02Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooo
ooooool01oooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Co
003ooooooooooooo003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00kooooo
00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00
o`gooooo00?o003oooooooooool0R_ooool00`00003oooooooooo`09ooooo`006oooool00`00003o
ooooooooo`09ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`07oooo
o`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01?l00?ooooooo`00
ool00?l3ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool03_ooool01?l00?oo
ooooooooool00?l6ooooo`03o`00oooooooooooo00?ooooo0_l00?l00ooooooo003oooooo`0<oooo
o`03o`00oooooooooooo08[ooooo00<00000ooooooooool02Oooool001_ooooo00<00000oooooooo
ool02Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01oooool01?l0
0?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003oooooool00?oo003o
0oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooo
oooo003o0oooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00?ooooo0_l00?l0
0ooooooo003oooooo`0<ooooo`03o`00oooooooooooo08[ooooo00<00000ooooooooool02Oooool0
01_ooooo00<00000o`000?ooool02Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003o
ooooooooool01oooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo
00Co003oooooool00?oo003o0oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo
00Oooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l6ooooo`03o`00oooo
oooooooo00?ooooo0_l00?l00ooooooo003oooooo`0<ooooo`03o`00oooooooooooo08Wooooo00?o
000000000?ooool02_ooool001_ooooo00<00000ooooooooool00oooool00ol00?ooooooooooo`03
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`07ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01?l00?ooooooo`00ool00?l3oooo
o`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?oooooooooo
ool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o1_ooool00ol0
0?ooooooooooo`03ooooo`;o003o00?oooooo`00ooooool03?ooool00ol00?ooooooooooo`2:oooo
o`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00?ooooo00?o003ooooooooo
ool00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01_ooool2o`00
o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooo`00ooooool00_l0
0?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?oo
ooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o1_oo
ool00ol00?ooooooooooo`03ooooo`;o003o00?oooooo`00ooooool02_ooool00ol00?ooooooo`00
o`2<ooooo`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00?ooooo00?o003o
ooooooooool00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01_oo
ool2o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooo`00oooo
ool00_l00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2oooo
o`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?oooooooooo
ool00?l6ooooo`03o`00oooooooooooo00?ooooo0_l00?l00ooooooo003oooooo`0:ooooo`03o`00
oooooooo003o08cooooo00<00000ooooooooool02Oooool001_ooooo00<00000ooooooooool00ooo
ool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`06ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`06ooooool00?oooooooooo
ool00?oooooo0_l00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l0
0?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?oo
ooooo`00ool00?l6ooooo`03o`00oooooooooooo00?ooooo0_l00?l01Ooooooo003ooooooooooooo
003o00Kooooo00?o003oooooool00?l00_l00?n<ooooo`0300000?oooooooooo00Wooooo000Koooo
o`0300000?oooooooooo00?ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool01_ooool2o`00o`;ooooo00?o003oooooooooool00ol00?l0
1_oooooo003ooooooooooooo003oooooo`;o003o00Coooooo`00oooooooo003o0_ooool01?l00?oo
ooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool01?l00?ooooooooooool00?l2
ooooo`06o`00ooooooooooooooooool00?oooooo0_l00?l6ooooo`;o003o00Coooooo`00ool00?oo
oooo0_l00?l01Ooooooo003oo`00oooooooo003o00;ooooo00?o003oooooooooool01_l00?n<oooo
o`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00?ooooo00?o003ooooooooo
ool00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01_ooool2o`00
o`;ooooo00?o003oooooooooool00ol00?l01_oooooo003ooooooooooooo003oooooo`;o003o00Co
ooooo`00oooooooo003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool0
0?l00_ooool01?l00?ooooooooooool00?l2ooooo`06o`00ooooooooooooooooool00?oooooo0_l0
0?l6ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l01Ooooooo003oo`00oooooooo003o00;o
oooo00?o003oooooooooool01_l00?n<ooooo`0300000?oooooooooo00Wooooo000Kooooo`030000
0?oooooooooo00?ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o
00;ooooo00Ko003ooooooooooooo003oooooool00?l3ooooo`?o003o00?oooooo`00ooooool01?l0
0?l00ooooooo003oooooo`02o`00o`07ooooool00?oo003oooooool00?ooooooo`00o`02ooooo`04
o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`;o003o00Coooooo`00
oooooooooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`Kooooo0_l00?l01?oooooo003oo`00
ooooool2o`00o`05ooooool00?oo003oooooool00?l00_ooool00ol00?ooooooooooo`06o`00o`;o
oooo00?o003oooooooooool0Qoooool00`00003oooooooooo`09ooooo`006oooool00`00003ooooo
ooooo`03ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003oooooool00?l00_l00?l2ooooo`06
o`00ooooooooooooo`00oooooooo003o0oooool3o`00o`03ooooool00?oooooo00Ko003o00Cooooo
o`00ool00?oooooo0_l00?l01?oooooo003oooooool00?l2ooooo`03o`00oooooooooooo00;o003o
00Coooooo`00ool00?oooooo0_l00?l01_oooooo003oo`00ool00?ooooooo`00o`;ooooo0_l00?l2
ooooo`04o`00oooooooo003oo`00o`Cooooo00Go003oooooool00?oo003oooooo`02o`00o`04oooo
ool00?oo003oooooo`;o003o00Goooooo`00ooooooooooooo`00o`02ooooo`Wo003oROooool00`00
003oooooooooo`09ooooo`006oooool00`00003oooooooooo`03ooooo`04o`00oooooooo003oo`00
o`;ooooo00?o003oooooool00?l00_l00?l2ooooo`06o`00ooooooooooooo`00oooooooo003o0ooo
ool3o`00o`03ooooool00?oooooo00Ko003o00Coooooo`00ool00?oooooo0_l00?l01?oooooo003o
ooooool00?l2ooooo`03o`00oooooooooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l01_oo
oooo003oo`00ool00?ooooooo`00o`;ooooo0_l00?l2ooooo`04o`00oooooooo003oo`00o`Cooooo
00Go003oooooool00?oo003oooooo`02o`00o`04ooooool00?oo003oooooo`;o003o00Goooooo`00
ooooooooooooo`00o`02ooooo`Wo003oROooool00`00003oooooooooo`09ooooo`006oooool00`00
003o0000ooooo`03ooooo`04o`00oooooooo003oo`00o`;ooooo00?o003oooooool00?l00_l00?l0
0ooooooo003oo`00o`02ooooo`03o`00oooooooo003o00;o003o00Ooooooo`00ool00?oo003ooooo
ool00?oooooo00Ko003o00Coooooo`00ool00?oooooo0_l00?l01?oooooo003oooooool00?l2oooo
o`03o`00oooooooo003o00Go003o00Coooooo`00ool00?oooooo0ol00?l01?oooooo003ooooooooo
ool2o`00o`;ooooo00Co003oooooool00?oo003o0_ooool01?l00?ooooooo`00ooooool2o`00o`04
ooooool00?oo003oooooo`Go003o00Coooooo`00oooooooooooo0_l00?l00ooooooo003oo`00o`07
o`00ohSooooo00?o000000000?ooool02_ooool001_ooooo00<00000ooooooooool00oooool01?l0
0?ooooooo`00ool00?l2ooooo`Go003o00?oooooo`00ool00?l00_ooool00ol00?ooooooo`00o`02
o`00o`03ooooool00?oo003o00[o003o00?oooooo`00ool00?l00ol00?l01?oooooo003oooooool0
0?l2ooooo`03o`00oooooooo003o00So003o00Ooooooo`00ool00?oo003oooooool00?oooooo00?o
003o0_ooool00ol00?ooooooo`00o`02o`00o`05ooooool00?ooooooo`00ooooool00_l00?l01?oo
oooo003oo`00ooooool5o`00o`04ooooool00?ooooooooooo`co003oROooool00`00003ooooooooo
o`09ooooo`006oooool00`00003oooooooooo`03ooooo`04o`00oooooooo003oo`00o`;ooooo2?l0
0?l2ooooo`03o`00oooooooo003o00;o003o00?oooooo`00ool00?l02_l00?l00ooooooo003oo`00
o`03o`00o`04ooooool00?ooooooo`00o`;ooooo00?o003oooooool00?l02?l00?l01ooooooo003o
o`00ool00?ooooooo`00ooooool00ol00?l2ooooo`03o`00oooooooo003o00;o003o00Goooooo`00
oooooooo003oooooo`02o`00o`04ooooool00?oo003oooooo`Go003o00Coooooo`00oooooooooooo
3?l00?n9ooooo`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00?ooooo00Co
003oooooool00?oo003o0_ooool8o`00o`;ooooo00?o003oooooool00?l00_l00?l00ooooooo003o
o`00o`0@o`00o`04ooooool00?ooooooo`00o`;ooooo00?o003oooooool00?l02?l00?l01ooooooo
003oo`00ool00?ooooooo`00ooooool00ol00?l01?oooooo003oo`00ooooool3o`00o`03ooooool0
0?oooooo00Co003o00?oooooo`00ool00?l01_l00?l00ooooooo003oo`00o`0=o`00ohWooooo00<0
0000ooooooooool02Oooool001_ooooo00<00000ooooooooool00oooool01?l00?ooooooo`00ool0
0?l2ooooo`So003o0_ooool00ol00?ooooooo`00o`0Eo`00o`05ooooool00?ooooooo`00ooooool0
0_l00?l00ooooooo003oo`00o`07o`00o`07ooooool00?oo003oo`00oooooooo003oooooo`03o`00
o`04ooooool00?oo003oooooo`Go003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`06
o`00o`03ooooool00?oo003o00go003o5_ooool00ol00?ooooooooooo`1`ooooo`0300000?oooooo
oooo00Wooooo000Kooooo`0300000?oooooooooo00?ooooo00Co003oooooool00?oo003o0_ooool8
o`00o`;ooooo00?o003oooooool00?l05ol00?l00ooooooo003oooooo`02o`00o`03ooooool00?oo
003o00Oo003o00Ooooooo`00ool00?oo003oooooool00?oooooo00?o003o00Coooooo`00ool00?oo
oooo1Ol00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ool0
0?l03Ol00?lFooooo`03o`00oooooooooooo073ooooo00<00000ooooooooool02Oooool001_ooooo
00<00000ooooooooool00oooool00ol00?ooooooo`00o`0;o`00o`;ooooo00?o003oooooool00?l0
5ol00?l00ooooooo003oooooo`02o`00o`03ooooool00?oo003o00_o003o00?oooooo`00ool00?l0
0ol00?l00ooooooo003oo`00o`06o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l0
5_l00?l6ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`1Rooooo`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00?ooooo00?o
003oooooool00?l02ol00?l2ooooo`03o`00oooooooo003o01Oo003o00?oooooo`00ooooool00_l0
0?l00ooooooo003oo`00o`0Ao`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ool00?l06ol0
0?l00ooooooo003oooooo`03ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo057ooooo00<00000ooooooooool02Ooo
ool001_ooooo00<00000ooooooooool00oooool00ol00?ooooooo`00o`0;o`00o`;ooooo00?o003o
ooooool00?l05ol00?l00ooooooo003oooooo`02o`00o`03ooooool00?oo003o017o003o00?ooooo
o`00ool00?l01_l00?l00ooooooo003oo`00o`0Ko`00o`03ooooool00?oooooo00?ooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool0DOooool00`00003oooooooooo`09ooooo`006oooool00`00003o0000ooooo`03oooo
o`03o`00oooooooo003o00_o003o00Coooooo`00ool00?oooooo6?l00?l00ooooooo003oooooo`02
o`00o`03ooooool00?oo003o03[o003o00Coooooo`00ool00?oooooo0_l00?l>ooooo`03o`00oooo
oooooooo00_ooooo00Go003oooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo053ooooo
00?o000000000?ooool02_ooool001_ooooo00<00000ooooooooool00oooool00ol00?ooooooo`00
o`0;o`00o`04ooooool00?oo003ooooooaSo003o00?oooooo`00ooooool0?ol00?l01?oooooo003o
o`00ooooool2o`00o`_ooooo00Co003ooooooooooooo003o3?ooool2o`00o`?ooooo00?o003ooooo
ooooool01oooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooooooo03_ooooo00<00000
ooooooooool02Oooool001_ooooo00<00000ooooooooool00oooool00ol00?ooooooo`00o`0;o`00
o`04ooooool00?oo003ooooooaSo003o00?oooooo`00ool00?l0?ol00?l01?oooooo003oo`00oooo
ool2o`00o`_ooooo00Co003ooooooooooooo003o3?ooool2o`00o`?ooooo00?o003oooooooooool0
1oooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooooooo03_ooooo00<00000oooooooo
ool02Oooool001_ooooo00<00000ooooooooool00oooool>o`00o`03ooooool00?oo003o01Wo003o
00?oooooo`00ool00?l0?ol00?l00ooooooo003oo`00o`07o`00o`Oooooo00So003ooooooooooooo
003oooooool00?ooooooo`00o`Gooooo00?o003oooooooooool00ol00?l00ooooooo003oo`00o`09
ooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o9oooool00ol00?oooooo
ooooo`0@ooooo`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00?ooooo3_l0
0?l00ooooooo003oo`00o`0Io`00o`03ooooool00?oo003o03oo003o00?oooooo`00ool00?l01ol0
0?l00ooooooo003oooooo`04ooooo`Co003o00?oooooo`00ooooool00_l00?l4ooooo`;o003o00?o
ooooo`00ool00?l01?l00?l4ooooo`05o`00ooooooooooooo`00ooooool01?l00?l3ooooo`05o`00
ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00
o`oooooo00?o003oooooooooool01?ooool2o`00o`?ooooo00?o003oooooooooool01Oooool01Ol0
0?oooooooooooooooooo003o00Oooooo00Ko003oooooool00?oo003oooooool00?l5ooooo`030000
0?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00?ooooo3_l00?l00ooooooo003oo`00
o`0Io`00o`03ooooool00?oo003o03oo003o00?oooooo`00ool00?l01ol00?l00ooooooo003ooooo
o`04ooooo`Co003o00?oooooo`00ooooool00_l00?l4ooooo`;o003o00?oooooo`00ool00?l01?l0
0?l4ooooo`05o`00ooooooooooooo`00ooooool01?l00?l3ooooo`05o`00ooooooooooooooooool0
0?l01_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`oooooo00?o003ooooo
ooooool01?ooool2o`00o`?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo
003o00Oooooo00Ko003oooooool00?oo003oooooool00?l5ooooo`0300000?oooooooooo00Wooooo
000Kooooo`0300000?oooooooooo00?ooooo:_l00?l00ooooooo003oo`00o`0oo`00o`03ooooool0
0?oo003o00[o003o0_ooool00ol00?ooooooo`00o`05o`00o`04ooooool00?oo003oooooo`;o003o
00?oooooo`00ool00?l02Ol00?l01Ooooooo003oo`00ool00?oooooo00Ko003o0oooool01?l00?oo
ooooooooooooool3o`00o`Cooooo00?o003oooooooooool01?ooool2o`00o`04ooooool00?oooooo
o`00o`[ooooo00?o003oooooool00?l00_l00?l5ooooo`;o003o00Coooooo`00ool00?oo003o1ooo
ool2o`00o`;ooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooo003o00?o003o1Ooo
ool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`03ooooob[o003o00?ooooo
o`00ool00?l0C?l00?l01?oooooo003oo`00ooooool6o`00o`04ooooool00?oo003oooooo`;o003o
00?oooooo`00ool00?l06Ol00?l00ooooooo003oo`00o`05o`00o`04ooooool00?ooooooooooo`co
003o0_ooool;o`00o`03ooooool00?oo003o00[o003o00Coooooo`00oooooooooooo1?l00?l00ooo
oooo003oo`00o`03o`00o`?ooooo1_l00?l5ooooo`0300000?oooooooooo00Wooooo000Dooooo`;o
00001Oooool00`00003oooooooooo`03ooooob[o003o00?oooooo`00ool00?l0C?l00?l01?oooooo
003oo`00ooooool6o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ool00?l06Ol00?l0
0ooooooo003oo`00o`05o`00o`04ooooool00?ooooooooooo`co003o0_ooool;o`00o`03ooooool0
0?oo003o00[o003o00Coooooo`00oooooooooooo1?l00?l00ooooooo003oo`00o`03o`00o`?ooooo
1Ol00?l6ooooo`0300000?oooooooooo00Wooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool00ooooolZo`00o`03ooooool00?oo003o05Wo003o00?oooooo`00ool00?l0
9ol00?l00ooooooo003oo`00o`0Vo`00o`03ooooool00?oo003o017o003o1_ooool00`00003ooooo
ooooo`09ooooo`004oooool01?l0003oooooooooool00004ooooo`H00000:_l00?l00`00003o003o
o`00o`1no`00o`8000005Ol00?l01000003o003o00000000000;o`00o`8000000_l00?l00`00003o
003oo`00o`09o`00o`0300000?l00?oo003o00Wo003o1`00000;ooooo`004oooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo00?ooooo:_l00?l00ooooooo003oo`00o`1Ao`00o`;o
oooo1Ol00?l00ooooooo003oo`00o`08o`00o`03ooooool00?oo003o00_o003o00?oooooo`00ool0
0?l01ol00?l2ooooo`03o`00oooooooooooo00Ko003o00?oooooo`00ool00?l00_ooool2o`00o`03
ooooool00?oo003o00Co003o1_ooool9o`00o`?ooooo00?o003oooooooooool02?l00?l01?oooooo
003oo`00ooooool7o`00o`04ooooool00?oo003oo`00o`Kooooo00<00000ooooooooool02Oooool0
01?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`03ooooob[o003o00?ooooo
o`00ool00?l0DOl00?l2ooooo`;o003o00Coooooo`00ool00?oooooo2_l00?l00ooooooo003oo`00
o`0:o`00o`;ooooo2Ol00?l2ooooo`03o`00oooooooooooo00Ko003o00?oooooo`00ool00?l00_oo
ool2o`00o`03ooooool00?oo003o00Co003o1_ooool7o`00o`03ooooool00?oooooo00;ooooo00?o
003oooooooooool02?l00?l01?oooooo003oo`00ooooool7o`00o`04ooooool00?oo003oo`00o`Ko
oooo00<00000ooooooooool02Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`03oooood?o003o00?oooooo`00ool00?l0<Ol00?l2ooooo`Go003o0_ooool2o`00o`04
ooooool00?oo003oooooo`Ko003o00Goooooo`00ool00?oo003oooooo`02o`00o`03ooooool00?oo
003o00?o003o0_ooool2o`00o`;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`;o003o0_ooool0
0ol00?ooooooooooo`03o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool00_l00?l0
0ooooooo003oo`00o`04o`00o`[ooooo00?o003oooooooooool02?ooool3o`00o`;ooooo0_l00?l3
ooooo`03o`00oooooooooooo00;o003o00Coooooo`00ool00?oo003o0_ooool2o`00o`Kooooo00<0
0000ooooooooool02Oooool001Cooooo0_l00005ooooo`0300000?oooooooooo00?ooooo4Ol00?l0
0ooooooo003oo`00o`0_o`00o`03ooooool00?oo003o027o003o00?oooooo`00ool00?l03Ol00?l2
ooooo`Go003o0_ooool2o`00o`03ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o0_oo
ool3o`00o`04ooooool00?oo003oooooo`;o003o0_ooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooooooo00;o003o0_ooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00
o`Kooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;o003o00Co
ooooo`00ool00?oo003o0_ooool2o`00o`Kooooo00<00000ooooooooool02Oooool001_ooooo00<0
0000ooooooooool00oooool:o`00o`03ooooool00?oo003o00Co003o00?oooooo`00ool00?l0;ol0
0?l00ooooooo003oo`00o`0Qo`00o`03ooooool00?oo003o00go003o0_ooool5o`00o`;ooooo0_l0
0?l00ooooooo003oooooo`02ooooo`04o`00ooooooooooooo`00o`;ooooo0ol00?l01?oooooo003o
o`00ooooool2o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`02o`00
o`;ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l6ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02o`00o`;ooooo0_l00?l2ooooo`;o003o
1_ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`03ooooo`[o003o00?o
ooooo`00ool00?l01?l00?l00ooooooo003oo`00o`0_o`00o`03ooooool00?oo003o027o003o00Co
ooooo`00ool00?oooooo0_l00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oo003o00;ooooo
00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`07ooooo`05o`00oooooooooooooooo
ool00?l00_ooool2o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`02o`00o`gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0T
ooooo`;o003o0_ooool2o`00o`;ooooo0_l00?l6ooooo`0300000?oooooooooo00Wooooo000Koooo
o`0300000?oooooooooo00?ooooo2_l00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oo003o
00Co003o00?oooooo`00ool00?l09Ol00?l01?oooooo003oo`00ooooool9o`00o`03ooooool00?oo
003o01Oo003o00Coooooo`00ool00?oooooo0_l00?l00ooooooo003oo`00o`04o`00o`Gooooo00Co
003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l00ooooooo
003oooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o3_ooool0
0ol00?ooooooooooo`0cooooo`;o003o0_ooool2o`00o`Kooooo00<00000ooooooooool02Oooool0
01_ooooo00<00000ooooooooool00oooool:o`00o`03ooooool00?oo003o00Co003o00?oooooo`00
ool00?l01?l00?l00ooooooo003oo`00o`0Uo`00o`04ooooool00?oo003oooooo`Wo003o00?ooooo
o`00ool00?l05ol00?l01?oooooo003oo`00ooooool2o`00o`04ooooool00?oo003oooooo`?o003o
1Oooool01?l00?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l00_ooool2o`00
o`03ooooool00?oooooo00;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool0
0?l>ooooo`03o`00oooooooooooo03?ooooo00Co003ooooooooooooooooo0_l00?l6ooooo`030000
0?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00?ooooo1?l00?l00ooooooo003oo`00
o`03o`00o`03ooooool00?oo003o00Co003o00?oooooo`00ool00?l01?l00?l00ooooooo003oo`00
o`0Uo`00o`04ooooool00?oo003oooooo`Wo003o00?oooooo`00ool00?l04Ol00?l00ooooooo003o
o`00o`03o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ool00?l00oooool00ol00?oo
ooooooooo`03ooooo`04o`00ooooooooooooo`00o`gooooo00Go003oooooooooooooooooo`00o`02
ooooo`;o003o3oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo03?ooooo00?o003o
ooooooooool02Oooool00`00003oooooooooo`09ooooo`006oooool00`00003o0000ooooo`03oooo
o`Co003o00Coooooo`00ool00?oooooo0_l00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oo
003o00Co003o00?oooooo`00ool00?l09Ol00?l01?oooooo003oo`00ooooool9o`00o`04ooooool0
0?oo003oooooo`oo003o0_ooool5o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ool0
0?l06_ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l?ooooo`03o`00oooooooooooo
04gooooo00?o000000000?ooool02_ooool001_ooooo00<00000ooooooooool00oooool4o`00o`04
ooooool00?oo003oooooo`;o003o00?oooooo`00ool00?l01?l00?l00ooooooo003oo`00o`04o`00
o`03ooooool00?oo003o02Go003o00Coooooo`00ool00?oooooo2Ol00?l01?oooooo003oo`00oooo
ool?o`00o`;ooooo1Ol00?l01?oooooo003oo`00ooooool2o`00o`03ooooool00?oo003o01[ooooo
00Go003oooooooooooooooooo`00o`02ooooo`;o003o3oooool00ol00?ooooooooooo`1>ooooo`03
00000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00Cooooo0ol00?l00ooooooo003o
o`00o`02ooooo`03o`00oooooooo003o00Go003o00?oooooo`00ool00?l01?l00?l00ooooooo003o
o`00o`0@o`00o`03ooooool00?oo003o00oo003o00Coooooo`00oooooooooooo0_l00?l00ooooooo
003oo`00o`07o`00o`04ooooool00?oo003oooooo`oo003o0_ooool5o`00o`04ooooool00?oo003o
ooooo`;o003o00?oooooo`00ool00?l07_ooool00ol00?ooooooooooo`1Rooooo`0300000?oooooo
oooo00Wooooo000Kooooo`0300000?oooooooooo00Cooooo0ol00?l00ooooooo003oo`00o`02oooo
o`03o`00oooooooo003o00Go003o00Goooooo`00ool00?oo003oooooo`02o`00o`04ooooool00?oo
003oooooo`;o003o00Goooooo`00ool00?oo003oooooo`08o`00o`03ooooool00?oo003o00;o003o
00?oooooo`00ool00?l02_l00?l01?oooooo003oooooooooool2o`00o`03ooooool00?oo003o00Ko
003o0_ooool2o`00o`03ooooool00?oo003o00?o003o0_ooool00ol00?ooooooo`00o`05o`00o`;o
oooo1Ol00?l01?oooooo003oo`00ooooool2o`00o`03ooooool00?oo003o01kooooo00?o003ooooo
ooooool0H_ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`04ooooo`?o
003o00?oooooo`00ool00?l00_ooool00ol00?ooooooo`00o`05o`00o`05ooooool00?oo003oo`00
ooooool00_l00?l01?oooooo003oo`00ooooool2o`00o`05ooooool00?oo003oo`00ooooool02?l0
0?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00[o003o00Coooooo`00oooooooooooo
0_l00?l00ooooooo003oo`00o`06o`00o`;ooooo0_l00?l00ooooooo003oo`00o`03o`00o`;ooooo
00?o003oooooool00?l01Ol00?l2ooooo`Go003o00Coooooo`00ool00?oooooo0_l00?l00ooooooo
003oo`00o`0Nooooo`03o`00oooooooooooo06;ooooo00<00000ooooooooool02Oooool001_ooooo
00<00000ooooooooool01?ooool3o`00o`03ooooool00?oo003o00;ooooo00?o003oooooool00?l0
1Ol00?l01Ooooooo003oo`00ool00?oooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l01Ooo
oooo003oo`00ool00?oooooo00;o003o00?oooooo`00ool00?l00ol00?l00ooooooo003oo`00o`02
o`00o`03ooooool00?oo003o00Wo003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo
003o00?o003o00?oooooo`00ool00?l00_ooool2o`00o`03ooooool00?oo003o00?o003o0_ooool0
0ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo1Ol00?l01?oooooo003oo`00oooo
ool2o`00o`03ooooool00?oo003o08?ooooo00<00000ooooooooool02Oooool001_ooooo00<00000
ooooooooool01?ooool3o`00o`03ooooool00?oo003o00;ooooo00?o003oooooool00?l01Ol00?l0
1Ooooooo003oo`00ool00?oooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l01Ooooooo003o
o`00ool00?oooooo00;o003o0_ooool4o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool0
0?l02Ol00?l2ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00ol00?l00ooooooo
003oo`00o`02ooooo`;o003o00?oooooo`00ool00?l00ol00?l2ooooo`03o`00oooooooooooo00;o
003o00?oooooo`00ool00?l00_ooool5o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00
ool00?l0Poooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`04ooooo`?o
003o00?oooooo`00ool00?l00_ooool00ol00?ooooooo`00o`03o`00o`03ooooool00?oooooo00?o
003o00Coooooo`00ool00?oooooo0_l00?l01?oooooo003oo`00ooooool3o`00o`03ooooool00?oo
003o00;ooooo1?l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00Wo003o0_ooool0
0ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l00_ooool2
o`00o`03ooooool00?oo003o00?o003o0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo
003o00;ooooo1Ol00?l01?oooooo003oo`00ooooool2o`00o`03ooooool00?oo003o08?ooooo00<0
0000ooooooooool02Oooool001_ooooo00<00000ooooooooool01?ooool3o`00o`03ooooool00?oo
003o00;ooooo00?o003oooooool00?l00_l00?l2ooooo`03o`00oooooooo003o00;o003o00Cooooo
o`00ool00?oooooo0_l00?l01?oooooo003oo`00ooooool3o`00o`03ooooool00?oo003o00;ooooo
1?l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00;o003o00?oooooo`00ool00?l0
1?l00?l2ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00ol00?l00ooooooo003o
o`00o`02ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l2ooooo`03o`00oooooooooooo00;o
003o00?oooooo`00ool00?l00_ooool2o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00
ool00?l00_ooool00ol00?ooooooooooo`21ooooo`0300000?oooooooooo00Wooooo000Kooooo`03
00000?l0003ooooo00Cooooo0ol00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooo003o00;o
003o0_ooool00ol00?ooooooooooo`02o`00o`04ooooool00?oo003oooooo`;o003o00Coooooo`00
ool00?oooooo0ol00?l00ooooooo003oo`00o`02ooooo`Co003o0_ooool2o`00o`;ooooo1?l00?l0
0ooooooo003oo`00o`04o`00o`;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`03
o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02
ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool2o`00o`04ooooool00?oo
003oooooo`;o003o00?oooooo`00ool00?l0QOooool00ol000000000ooooo`0:ooooo`006oooool0
0`00003oooooooooo`04ooooo`?o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooo`00o`02
o`00o`;ooooo00?o003oooooooooool00_l00?l01?oooooo003oo`00ooooool2o`00o`04ooooool0
0?oo003oooooo`?o003o00?oooooo`00ool00?l00_ooool4o`00o`;ooooo0_l00?l2ooooo`Co003o
00?oooooo`00ool00?l00ol00?l3ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l0
0ol00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l0
0_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo0_l00?l01?oooooo003o
o`00ooooool2o`00o`03ooooool00?oo003o08Kooooo00<00000ooooooooool02Oooool001_ooooo
00<00000ooooooooool01Oooool2o`00o`03ooooool00?oo003o00;ooooo00?o003oooooool00?l0
0_l00?l2ooooo`03o`00oooooooooooo00;o003o00Coooooo`00ool00?oooooo0_l00?l01?oooooo
003oo`00ooooool3o`00o`03ooooool00?oo003o00;ooooo1?l00?l2ooooo`;o003o0_ooool2o`00
o`03ooooool00?oooooo00Go003o0oooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o
00?o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o
00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02ooooo`;o003o00Coooooo`00
ool00?oooooo0_l00?l00ooooooo003oo`00o`26ooooo`0300000?oooooooooo00Wooooo000Koooo
o`0300000?oooooooooo00Gooooo0_l00?l2ooooo`05o`00ooooooooooooo`00ooooool00ol00?l2
ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l01?oooooo003oo`00ooooool2o`00o`05oooo
ool00?oo003oo`00ooooool00_l00?l2ooooo`Co003o0_ooool2o`00o`;ooooo0_l00?l00ooooooo
003oooooo`02o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`;o003o00?oooooo`00
ool00?l00ol00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00
ool00?l01Oooool2o`00o`03ooooool00?oo003o00;ooooo0_l00?l01?oooooo003oooooooooool2
o`00o`03ooooool00?oo003o08Kooooo00<00000ooooooooool02Oooool001_ooooo00<00000oooo
ooooool01Oooool2o`00o`;ooooo00Go003ooooooooooooo003oooooo`03o`00o`;ooooo00Co003o
oooooooooooo003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o00Goooooo`00ool00?oo
003oooooo`02o`00o`;ooooo1?l00?l2ooooo`;o003o0_ooool2o`00o`03ooooool00?oooooo00;o
003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo0_l00?l00ooooooo003oo`00o`03o`00
o`03ooooool00?oo003o00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`05oooo
o`;o003o00?oooooo`00ool00?l00_ooool2o`00o`04ooooool00?ooooooooooo`;o003o00?ooooo
o`00ool00?l0Q_ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`05oooo
o`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool0
0?l2ooooo`;o003o00Coooooo`00ool00?oooooo0_l00?l01Ooooooo003oo`00ool00?oooooo00;o
003o0_ooool01?l00?ooooooo`00ool00?l2ooooo`04o`00ooooooooooooooooo`;o003o00?ooooo
o`00ooooool00_l00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`02o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`03oooo
ool00?oo003o00Gooooo0_l00?l00ooooooo003oo`00o`02ooooo`;o003o00Coooooo`00oooooooo
oooo0_l00?l00ooooooo003oooooo`26ooooo`0300000?oooooooooo00Wooooo000Kooooo`030000
0?oooooooooo00Gooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04
o`00ooooooooooooo`00o`;ooooo0_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo0_l00?l0
0ooooooo003oo`00o`02ooooo`04o`00oooooooo003oo`00o`;ooooo00Co003ooooooooooooooooo
0_l00?l00ooooooo003oooooo`02o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo00;o003o00?oooooo`00ool00?l00_ooool01?l00?ooooooooooool00?l2oooo
o`;o003o00?oooooo`00ool00?l01Oooool2o`00o`03ooooool00?oo003o00;ooooo0_l00?l00ooo
oooo003oooooo`02ooooo`03o`00oooooooo003o08Oooooo00<00000ooooooooool02Oooool001_o
oooo00<00000ooooooooool01Oooool2o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00
o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o0_oo
ool2o`00o`03ooooool00?oo003o00;ooooo00Co003oooooool00?oo003o0_ooool01?l00?oooooo
ooooooooool2o`00o`03ooooool00?oooooo00;o003o0_ooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`02ooooo`04o`00oooooooooooo
o`00o`;ooooo0_l00?l00ooooooo003oo`00o`05ooooo`;o003o00?oooooo`00ool00?l00_ooool2
o`00o`03ooooool00?oooooo00;ooooo00?o003oooooool00?l0Qoooool00`00003oooooooooo`09
ooooo`006oooool00`00003oooooooooo`05ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2
ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_oo
ool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo00Co003oooooool00?oo003o
0_ooool01?l00?ooooooooooooooool2o`00o`03ooooool00?oooooo00;o003o0_ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`05oooo
o`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l01Oooool2o`00o`03ooooool00?oo003o
00;ooooo0_l00?l00ooooooo003oooooo`04ooooo`03o`00oooooooooooo08Gooooo00<00000oooo
ooooool02Oooool001_ooooo00<00000ooooooooool01_ooool01?l00?ooooooooooool00?l2oooo
o`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?ooooo
o`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;ooooo00Co003o
ooooool00?oo003o0_ooool01?l00?ooooooooooooooool2o`00o`05ooooool00?ooooooooooool0
0?l00_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00_l00?l00ooo
oooo003oo`00o`05ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ooooool01Oooool2o`00
o`03ooooool00?oo003o00;ooooo0_l00?l00ooooooo003oooooo`04ooooo`03o`00oooooooooooo
08Gooooo00<00000ooooooooool02Oooool001_ooooo00<00000o`000?ooool01_ooool01?l00?oo
ooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?ooooooooooool00?l2
ooooo`;o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooooooo`02o`00o`03ooooool00?oo
003o00;ooooo00Co003oooooool00?oo003o0_ooool01?l00?ooooooooooooooool2o`00o`05oooo
ool00?ooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooo
ooooool00_l00?l00ooooooo003oo`00o`05ooooo`03o`00oooooooooooo00;o003o00?oooooo`00
ooooool01Oooool2o`00o`03ooooool00?oo003o00;ooooo0_l00?l00ooooooo003oooooo`04oooo
o`03o`00oooooooooooo08Cooooo00?o000000000?ooool02_ooool001_ooooo00<00000oooooooo
ool01_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l0
0?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool01?l00?ooooooooooool0
0?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool0
0?l00_ooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00Gooooo00?o003oooooooooool00_l00?l0
0ooooooo003oooooo`05ooooo`;o003o00?oooooo`00ool00?l00_ooool2o`00o`03ooooool00?oo
oooo00Cooooo00?o003oooooooooool0QOooool00`00003oooooooooo`09ooooo`006oooool00`00
003oooooooooo`06ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2
ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00oooo
ooooooooo`00o`;ooooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l01Oooool00ol00?oooooooooo
o`02o`00o`03ooooool00?oooooo00Gooooo00?o003oooooooooool00_l00?l2ooooo`;o003o00?o
ooooo`00ooooool0S?ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`06
ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00oooo
ooooooooo`00o`;ooooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;o
oooo0_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02
ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00
oooooooooooo00;o003o00?oooooo`00ool00?l01Oooool00ol00?ooooooooooo`02o`00o`03oooo
ool00?oooooo00Gooooo00?o003oooooooooool00_l00?l2ooooo`;o003o00?oooooo`00ooooool0
S?ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`06ooooo`04o`00oooo
ooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;o
oooo0_l00?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2oooo
o`04o`00ooooooooooooo`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00oooo
ooooooooo`00o`;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02o`00o`03oooo
ool00?oo003o00Gooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`07ooooo`;o
003o0_ooool2o`00o`03ooooool00?oooooo08cooooo00<00000ooooooooool02Oooool001_ooooo
00<00000ooooooooool01_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o
003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool01?l0
0?ooooooooooool00?l2ooooo`;o003o0_ooool01?l00?ooooooooooool00?l2ooooo`05o`00oooo
ooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool00_l00?l00ooooooo003oo`00o`05ooooo`04o`00ooooooooooooo`00
o`;ooooo00?o003oooooooooool01oooool2o`00o`;ooooo0_l00?l00ooooooo003oooooo`2<oooo
o`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo00Kooooo00Co003ooooooooo
oooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0_ooool2
o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo00Co
003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003ooooooooo
oooo003o0_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;o003o00?oooooo`00
ool00?l01Oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00Oooooo0_l00?l2
ooooo`;o003o00?oooooo`00ooooool0S?ooool00`00003oooooooooo`09ooooo`002?ooool2o`00
00Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`0300000?oooooooooo00Kooooo00Co003o
oooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o
0_ooool2o`00o`03ooooool00?oo003o00;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;o
oooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Co003o
oooooooooooo003o0_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;o003o00?o
ooooo`00ool00?l02?ooool01?l00?ooooooooooool00?l9ooooo`;o003o0_ooool01?l00?oooooo
ooooool00?n=ooooo`0300000?oooooooooo00Wooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`06ooooo`04o`00oooooooooooo
o`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l0
0?l00ooooooo003oo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00
oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00
o`;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003ooooo
ooooool01_ooool01?l00?ooooooooooool00?l9ooooo`;o003o0_ooool01?l00?ooooooooooool0
0?n=ooooo`0300000?oooooooooo00Wooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01?ooool00`00003o0000ooooo`06ooooo`04o`00ooooooooooooo`00o`;ooooo
00?o003oooooooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`04
o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo
00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool01_oo
ool01?l00?ooooooooooool00?l9ooooo`;o003o0_ooool01?l00?ooooooooooool00?n<ooooo`03
o`000000003ooooo00[ooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool00oooool00`00003oooooooooo`06ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003ooooo
ooooool00_l00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_oo
ool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`05o`00
ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l9ooooo`03o`00oooooooooooo
00;o003o0_ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Wooooo0_l00?l2
ooooo`03o`00oooooooooooo08kooooo00<00000ooooooooool02Oooool000Oooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00<00000ooooooooool01_oo
ool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;o003o0_ooool01?l00?oooooo
ooooool00?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0_ooool2
o`00o`;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00;ooooo00Co
003ooooooooooooo003o2Oooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003oooooooooool0
1_ooool01?l00?ooooooooooool00?l9ooooo`;o003o0_ooool00ol00?ooooooooooo`2>ooooo`03
00000?oooooooooo00Wooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`0300000?oooooooooo00Kooooo00Co003ooooooooooooo003o0_ooool0
0ol00?ooooooooooo`02o`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?oooooooooo
ool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00?o
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003o
ooooooooool00_l00?l2ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o2Ooo
ool2o`00o`;ooooo00?o003oooooooooool0S_ooool00`00003oooooooooo`09ooooo`002?ooool2
o`0000Wooooo0ol00005ooooo`0300000?oooooooooo00Kooooo00Co003ooooooooooooo003o0_oo
ool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooo
oooo003o0_ooool01?l00?ooooooooooool00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03
ooooo`05o`00ooooooooooooooooool00?l00_ooool01?l00?ooooooooooool00?l9ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00
o`Wooooo00Go003oooooooooooooooooo`00o`2@ooooo`0300000?oooooooooo00Wooooo000Koooo
o`0300000?oooooooooo00Kooooo00Co003ooooooooooooo003o0_ooool01?l00?ooooooooooool0
0?l3ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0_ooool01?l00?oo
ooooooooool00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`05o`00oooooooooooo
ooooool00?l00_ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Sooooo
00Co003ooooooooooooo003o2Oooool01Ol00?oooooooooooooooooo003o093ooooo00<00000oooo
ooooool02Oooool001_ooooo00<00000ooooooooool01_ooool01?l00?ooooooooooool00?l2oooo
o`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o0oooool01?l00?oooooooooo
ool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo0_l00?l2ooooo`03o`00oooooooooooo00?o
oooo00Go003oooooooooooooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`gooooo00Co003o
oooooooooooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`05o`00ooooooooooooooooool0
0?l0T?ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`06ooooo`04o`00
ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooooooool00?l3
ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o0_ooool2o`00o`;ooooo
00?o003oooooooooool01oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00_o
oooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`05o`00oooooooo
ooooooooool00?l0T?ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`06
ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o1_ooool01Ol00?oooooo
oooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02o`00
o`;ooooo00?o003oooooooooool01oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo
oooo00_ooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9ooooo`05o`00
ooooooooooooooooool00?l0T?ooool00`00003oooooooooo`09ooooo`006oooool00`00003ooooo
ooooo`06ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o1_ooool01Ol0
0?oooooooooooooooooo003o00;ooooo00Co003ooooooooooooo003o0_ooool00ol00?oooooooooo
o`02o`00o`;ooooo00?o003oooooooooool01oooool01?l00?ooooooooooool00?l2ooooo`03o`00
oooooooooooo00_ooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l9oooo
o`05o`00ooooooooooooooooool00?l0T?ooool00`00003oooooooooo`09ooooo`006oooool00`00
003o0000ooooo`06ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool02oooool0
1?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`;ooooo00Go003ooooooooooooo
ooooo`00o`09ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool02oooool01?l0
0?ooooooooooool00?l8ooooo`04o`00ooooooooooooo`00o`Wooooo00Go003ooooooooooooooooo
o`00o`2?ooooo`03o`000000003ooooo00[ooooo000Kooooo`0300000?oooooooooo00Kooooo00Co
003ooooooooooooo003o0_ooool00ol00?ooooooooooo`0;ooooo`04o`00ooooooooooooo`00o`;o
oooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00Wooooo00Co003ooooo
oooooooo003o0_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00Co003o
oooooooooooo003o2Oooool01Ol00?oooooooooooooooooo003o093ooooo00<00000ooooooooool0
2Oooool001_ooooo00<00000ooooooooool01_ooool01?l00?ooooooooooool00?l2ooooo`03o`00
oooooooooooo00_ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`03ooooo`05
o`00ooooooooooooooooool00?l02Oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?l9ooooo`05o`00oooo
ooooooooooooool00?l0T?ooool00`00003oooooooooo`09ooooo`006oooool00`00003ooooooooo
o`06ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool02oooool01?l00?oooooo
ooooool00?l2ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`09oooo
o`04o`00ooooooooooooo`00oa?ooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool0
0?l9ooooo`05o`00ooooooooooooooooool00?l0T?ooool00`00003oooooooooo`09ooooo`006ooo
ool00`00003oooooooooo`06ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool0
2oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00?ooooo00Go003ooooooooo
ooooooooo`00o`09ooooo`04o`00ooooooooooooo`00oacooooo00?o003oooooooooool02_ooool0
1Ol00?oooooooooooooooooo003o093ooooo00<00000ooooooooool02Oooool001_ooooo00<00000
ooooooooool01_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00_ooooo00Co
003ooooooooooooo003o0_ooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool0
0?l02Oooool01?l00?ooooooooooool00?lLooooo`03o`00oooooooooooo00[ooooo00Go003ooooo
ooooooooooooo`00o`2@ooooo`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooooooo
00Kooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`0;ooooo`04o`00oooooooo
ooooo`00o`;ooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00Wooooo
00Co003ooooooooooooo003o7?ooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooooooo
ool00?l0T?ooool00`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`06ooooo`04
o`00ooooooooooooo`00oa3ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`03
ooooo`05o`00ooooooooooooooooool00?l02Oooool01?l00?ooooooooooool00?lLooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool0T_ooool00`00003oooooooooo`09ooooo`006ooo
ool00`00003oooooooooo`06ooooo`04o`00ooooooooooooo`00oa3ooooo00Co003ooooooooooooo
003o0_ooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l02Oooool01?l0
0?ooooooooooool00?lLooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0T_ooool0
0`00003oooooooooo`09ooooo`006oooool00`00003oooooooooo`09ooooo`03o`00oooooooooooo
017ooooo00Co003ooooooooooooo003o1Oooool01Ol00?oooooooooooooooooo003o00cooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`2Oooooo`0300000?oooooooooo00Wooooo000K
ooooo`0300000?l0003ooooo00Wooooo00?o003oooooooooool04Oooool01?l00?ooooooooooool0
0?l5ooooo`05o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`0Jooooo`03o`00
oooooooooooo09kooooo00?o000000000?ooool02_ooool001_ooooo00<00000ooooooooool02Ooo
ool00ol00?ooooooooooo`0Aooooo`04o`00ooooooooooooo`00o`Gooooo00Go003ooooooooooooo
ooooo`00o`0<ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0Woooool00`00003o
ooooooooo`09ooooo`006oooool00`00003oooooooooo`09ooooo`03o`00oooooooooooo017ooooo
00Co003ooooooooooooo003o1Oooool01Ol00?oooooooooooooooooo003o00cooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`2Oooooo`0300000?oooooooooo00Wooooo000Kooooo`03
00000?oooooooooo00Wooooo00?o003oooooooooool04Oooool01?l00?ooooooooooool00?l5oooo
o`05o`00ooooooooooooooooool00?l03?ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo
oooo09oooooo00<00000ooooooooool02Oooool001_ooooo00<00000ooooooooool02Oooool00ol0
0?ooooooooooo`0Aooooo`04o`00ooooooooooooo`00o`Gooooo00Go003oooooooooooooooooo`00
o`0<ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0Woooool00`00003ooooooooo
o`09ooooo`006oooool00`00003oooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00cooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`2Oooooo`0300000?oooooooooo00Wooooo000Kooooo`0300000?oooooo
oooo00Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool0_?ooool00`00003oooooooooo`09ooooo`006oooool00`00
003oooooooooo`09ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo0;cooooo00<00000ooooooooool02Oooool001_o
oooo00<00000ooooooooool07Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool0_?ooool00`00003oooooooooo`09ooooo`006oooool00`00003o0000
ooooo`0Mooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`2kooooo`03o`000000003ooooo00[ooooo000Kooooo`0300000?oooooooooo01gooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo0;cooooo00<0
0000ooooooooool02Oooool001_ooooo00<00000ooooooooool07Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0_?ooool00`00003oooooooooo`09
ooooo`006oooool00`00003oooooooooo`0Mooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`2looooo`0300000?oooooooooo00Wooooo000Kooooo`03
00000?oooooooooo01gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo0;cooooo00<00000ooooooooool02Oooool001_ooooo00<00000ooooooooool0
:_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo0;cooooo00<00000ooooooooool0
2Oooool001_ooooo00<00000ooooooooool0:_ooool00ol00?ooooooooooo`39ooooo`0300000?oo
oooooooo00Wooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool0
0`00003oooooooooo`0Zooooo`03o`00oooooooooooo0<Wooooo00<00000ooooooooool02Oooool0
00Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`0300000?oooooo
oooo02[ooooo00?o003oooooooooool0bOooool00`00003oooooooooo`09ooooo`001oooool01?l0
003oooooooooool00007ooooo`Go00001?ooool00`00003oooooooooo`0Zooooo`03o`00oooooooo
oooo0<Wooooo00<00000ooooooooool02Oooool000Oooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool00005ooooo`0300000?l0003ooooo02[ooooo00?o003oooooooooool0b?oo
ool00ol000000000ooooo`0:ooooo`001oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Gooooo00<00000ooooooooool0:_ooool00ol00?ooooooooooo`39ooooo`0300000?oo
oooooooo00Wooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`0300000?oo
oooooooo02[ooooo00?o003oooooooooool0bOooool00`00003oooooooooo`09ooooo`002?ooool2
o`0000_ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`0Zooooo`03o`00oooooooo
oooo0<Wooooo00<00000ooooooooool02Oooool001_ooooo00<00000ooooooooool0m_ooool00`00
003oooooooooo`09ooooo`006oooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000000003ooooo00[o
oooo000KooooooX000002oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.976097, -0.461098, \
0.000377853, 0.00520838}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zooming in some more", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g1\  = 
        ListPlot[Take[sound1, {11000, 11100}], \ PlotRange \[Rule] All, \ 
          PlotStyle \[Rule] Blue];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-104.738 105.971 0.265853 1.00455 [
[.17362 -0.0125 -12 -9 ]
[.17362 -0.0125 12 0 ]
[.38556 -0.0125 -15 -9 ]
[.38556 -0.0125 15 0 ]
[.5975 -0.0125 -15 -9 ]
[.5975 -0.0125 15 0 ]
[.80945 -0.0125 -15 -9 ]
[.80945 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06494 -24 -4.5 ]
[-0.0125 .06494 0 4.5 ]
[-0.0125 .1654 -24 -4.5 ]
[-0.0125 .1654 0 4.5 ]
[-0.0125 .26585 -6 -4.5 ]
[-0.0125 .26585 0 4.5 ]
[-0.0125 .36631 -18 -4.5 ]
[-0.0125 .36631 0 4.5 ]
[-0.0125 .46676 -18 -4.5 ]
[-0.0125 .46676 0 4.5 ]
[-0.0125 .56722 -18 -4.5 ]
[-0.0125 .56722 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17362 0 m
.17362 .00625 L
s
[(0.99)] .17362 -0.0125 0 1 Mshowa
.38556 0 m
.38556 .00625 L
s
[(0.992)] .38556 -0.0125 0 1 Mshowa
.5975 0 m
.5975 .00625 L
s
[(0.994)] .5975 -0.0125 0 1 Mshowa
.80945 0 m
.80945 .00625 L
s
[(0.996)] .80945 -0.0125 0 1 Mshowa
.125 Mabswid
.2266 0 m
.2266 .00375 L
s
.27959 0 m
.27959 .00375 L
s
.33258 0 m
.33258 .00375 L
s
.43855 0 m
.43855 .00375 L
s
.49153 0 m
.49153 .00375 L
s
.54452 0 m
.54452 .00375 L
s
.65049 0 m
.65049 .00375 L
s
.70348 0 m
.70348 .00375 L
s
.75646 0 m
.75646 .00375 L
s
.12063 0 m
.12063 .00375 L
s
.06765 0 m
.06765 .00375 L
s
.01466 0 m
.01466 .00375 L
s
.86243 0 m
.86243 .00375 L
s
.91542 0 m
.91542 .00375 L
s
.9684 0 m
.9684 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06494 m
.00625 .06494 L
s
[(-0.2)] -0.0125 .06494 1 0 Mshowa
0 .1654 m
.00625 .1654 L
s
[(-0.1)] -0.0125 .1654 1 0 Mshowa
0 .26585 m
.00625 .26585 L
s
[(0)] -0.0125 .26585 1 0 Mshowa
0 .36631 m
.00625 .36631 L
s
[(0.1)] -0.0125 .36631 1 0 Mshowa
0 .46676 m
.00625 .46676 L
s
[(0.2)] -0.0125 .46676 1 0 Mshowa
0 .56722 m
.00625 .56722 L
s
[(0.3)] -0.0125 .56722 1 0 Mshowa
.125 Mabswid
0 .08503 m
.00375 .08503 L
s
0 .10512 m
.00375 .10512 L
s
0 .12522 m
.00375 .12522 L
s
0 .14531 m
.00375 .14531 L
s
0 .18549 m
.00375 .18549 L
s
0 .20558 m
.00375 .20558 L
s
0 .22567 m
.00375 .22567 L
s
0 .24576 m
.00375 .24576 L
s
0 .28594 m
.00375 .28594 L
s
0 .30603 m
.00375 .30603 L
s
0 .32613 m
.00375 .32613 L
s
0 .34622 m
.00375 .34622 L
s
0 .3864 m
.00375 .3864 L
s
0 .40649 m
.00375 .40649 L
s
0 .42658 m
.00375 .42658 L
s
0 .44667 m
.00375 .44667 L
s
0 .48685 m
.00375 .48685 L
s
0 .50694 m
.00375 .50694 L
s
0 .52704 m
.00375 .52704 L
s
0 .54713 m
.00375 .54713 L
s
0 .04485 m
.00375 .04485 L
s
0 .02476 m
.00375 .02476 L
s
0 .00467 m
.00375 .00467 L
s
0 .58731 m
.00375 .58731 L
s
0 .6074 m
.00375 .6074 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.17362 .61178 m
.17362 .61803 L
s
.38556 .61178 m
.38556 .61803 L
s
.5975 .61178 m
.5975 .61803 L
s
.80945 .61178 m
.80945 .61803 L
s
.125 Mabswid
.2266 .61428 m
.2266 .61803 L
s
.27959 .61428 m
.27959 .61803 L
s
.33258 .61428 m
.33258 .61803 L
s
.43855 .61428 m
.43855 .61803 L
s
.49153 .61428 m
.49153 .61803 L
s
.54452 .61428 m
.54452 .61803 L
s
.65049 .61428 m
.65049 .61803 L
s
.70348 .61428 m
.70348 .61803 L
s
.75646 .61428 m
.75646 .61803 L
s
.12063 .61428 m
.12063 .61803 L
s
.06765 .61428 m
.06765 .61803 L
s
.01466 .61428 m
.01466 .61803 L
s
.86243 .61428 m
.86243 .61803 L
s
.91542 .61428 m
.91542 .61803 L
s
.9684 .61428 m
.9684 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06494 m
1 .06494 L
s
.99375 .1654 m
1 .1654 L
s
.99375 .26585 m
1 .26585 L
s
.99375 .36631 m
1 .36631 L
s
.99375 .46676 m
1 .46676 L
s
.99375 .56722 m
1 .56722 L
s
.125 Mabswid
.99625 .08503 m
1 .08503 L
s
.99625 .10512 m
1 .10512 L
s
.99625 .12522 m
1 .12522 L
s
.99625 .14531 m
1 .14531 L
s
.99625 .18549 m
1 .18549 L
s
.99625 .20558 m
1 .20558 L
s
.99625 .22567 m
1 .22567 L
s
.99625 .24576 m
1 .24576 L
s
.99625 .28594 m
1 .28594 L
s
.99625 .30603 m
1 .30603 L
s
.99625 .32613 m
1 .32613 L
s
.99625 .34622 m
1 .34622 L
s
.99625 .3864 m
1 .3864 L
s
.99625 .40649 m
1 .40649 L
s
.99625 .42658 m
1 .42658 L
s
.99625 .44667 m
1 .44667 L
s
.99625 .48685 m
1 .48685 L
s
.99625 .50694 m
1 .50694 L
s
.99625 .52704 m
1 .52704 L
s
.99625 .54713 m
1 .54713 L
s
.99625 .04485 m
1 .04485 L
s
.99625 .02476 m
1 .02476 L
s
.99625 .00467 m
1 .00467 L
s
.99625 .58731 m
1 .58731 L
s
.99625 .6074 m
1 .6074 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .26585 m
1 .26585 L
s
0 0 1 r
.5 Mabswid
.02381 .32079 m
.03333 .11674 L
.04286 .21092 L
.05238 .17952 L
.0619 .26585 L
.07143 .36788 L
.08095 .35218 L
.09048 .35218 L
.1 .29724 L
.10952 .18737 L
.11905 .15598 L
.12857 .15598 L
.1381 .258 L
.14762 .55623 L
.15714 .39142 L
.16667 .14813 L
.17619 .26585 L
.18571 .23446 L
.19524 .19522 L
.20476 .20307 L
.21429 .24231 L
.22381 .37573 L
.23333 .33649 L
.24286 .19522 L
.25238 .21876 L
.2619 .16383 L
.27143 .20307 L
.28095 .60332 L
.29048 .31294 L
.3 .0775 L
.30952 .31294 L
.31905 .17168 L
.32857 .258 L
.3381 .26585 L
.34762 .15598 L
.35714 .32079 L
.36667 .29724 L
.37619 .19522 L
.38571 .25016 L
.39524 .15598 L
.40476 .40712 L
.41429 .54838 L
.42381 .03041 L
.43333 .20307 L
.44286 .2737 L
.45238 .14813 L
.4619 .38357 L
.47143 .258 L
.48095 .21092 L
.49048 .33649 L
Mistroke
.5 .17952 L
.50952 .16383 L
.51905 .258 L
.52857 .2894 L
.5381 .50914 L
.54762 .45421 L
.55714 .0932 L
.56667 .16383 L
.57619 .258 L
.58571 .28155 L
.59524 .2737 L
.60476 .24231 L
.61429 .35218 L
.62381 .34433 L
.63333 .21092 L
.64286 .26585 L
.65238 .23446 L
.6619 .2737 L
.67143 .50129 L
.68095 .17952 L
.69048 .14813 L
.7 .32864 L
.70952 .22661 L
.71905 .22661 L
.72857 .28155 L
.7381 .28155 L
.74762 .25016 L
.75714 .36003 L
.76667 .30509 L
.77619 .14813 L
.78571 .17168 L
.79524 .21092 L
.80476 .31294 L
.81429 .50914 L
.82381 .24231 L
.83333 .16383 L
.84286 .32864 L
.85238 .20307 L
.8619 .18737 L
.87143 .18737 L
.88095 .24231 L
.89048 .32864 L
.9 .258 L
.90952 .21092 L
.91905 .24231 L
.92857 .12459 L
.9381 .37573 L
.94762 .55623 L
.95714 .01472 L
.96667 .18737 L
Mistroke
.97619 .33649 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00?_ooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool2o`0000Cooooo0_l0000Qooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0000?ooooo1Ol0000Looooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0000Gooooo0ol0000Looooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0000Cooooo0ol0000Vooooo`00?Oooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
01Wooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Sooooo`00?Ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000004o`0001_ooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool08oooool003gooooo00Co0000
oooooooooooo00002?ooool4o`0000;ooooo1?l0000Nooooo`04o`000?ooooooooooo`0000Sooooo
1?l00002ooooo`Co00001?ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000So
oooo1?l00002ooooo`Co000000Goooooo`000?ooooooooooo`00000Looooo`04o`000?oooooooooo
o`0000Sooooo1?l00002ooooo`Co000000?oooooo`000?l000000_l0000Vooooo`00?Oooool01?l0
003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo01cooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000
ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo01Wooooo00Co0000
oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01_l0003o
ooooooooool0003oooooo`0001cooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooo
oooooooo0000ooooool000000oooool00ol0003oooooo`00000Yooooo`00?Oooool01?l0003ooooo
ooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooo
oooo00001oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01?l0003ooooooooo
ooooool2o`0001cooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000
ooooool000000oooool01?l0003oooooooooool0000Xooooo`00?_ooool2o`0000Wooooo0ol00003
ooooo`?o00008?ooool2o`0000Wooooo0ol00003ooooo`?o00000oooool3o`0001gooooo0_l00009
ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool06oooool2o`0000Wooooo0ol00003
ooooo`?o00001?ooool2o`0002Kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo000Kooooool000001@000001ooooo`006oooool01@00003o0000oooooooooooo
000000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`0300000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00<00000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00`00003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`0300000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Cooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool0=?ooool00`00003oooooooooo`0dooooo`0300000?oooooooooo03Cooooo00<00000oooo
ooooool0;_ooool10000007ooooo000Kooooo`0300000?oooooooooo0?oooooo0Oooool10000007o
oooo000Kooooo`0300000?oooooooooo0?Gooooo00?o003oooooooooool02?ooool10000007ooooo
000Kooooo`0300000?oooooooooo0?Gooooo00?o003oooooooooool02?ooool10000007ooooo000K
ooooo`0300000?l0003ooooo0?Gooooo00?o003oooooooooool01oooool1o`00004000000Oooool0
01_ooooo00<00000ooooooooool0mOooool00ol00?ooooooooooo`08ooooo`4000000Oooool001_o
oooo00<00000ooooooooool0Joooool00ol00?ooooooooooo`27ooooo`03o`00oooooooooooo00So
oooo0@000001ooooo`006oooool00`00003oooooooooo`1[ooooo`03o`00oooooooooooo08Oooooo
00?o003oooooooooool02?ooool10000007ooooo000Kooooo`0300000?oooooooooo06_ooooo00?o
003oooooooooool0Qoooool00ol00?ooooooooooo`08ooooo`4000000Oooool001_ooooo00<00000
ooooooooool0Joooool00ol00?ooooooooooo`27ooooo`03o`00oooooooooooo00Sooooo0@000001
ooooo`006oooool00`00003o0000ooooo`1[ooooo`03o`00oooooooooooo08Oooooo0_l00?l8oooo
o`7o00000@000001ooooo`006oooool00`00003oooooooooo`1[ooooo`03o`00oooooooooooo08Oo
oooo0_l00?l9ooooo`4000000Oooool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go
00001?ooool00`00003oooooooooo`1[ooooo`03o`00oooooooooooo08Oooooo0_l00?l9ooooo`40
00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo06_ooooo00?o003oooooooooool0Qoooool2o`00o`Wooooo0@000001oooo
o`001Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00`00
003oooooooooo`1[ooooo`03o`00oooooooooooo08Oooooo0_l00?l9ooooo`4000000Oooool000Oo
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`0300000?l0003ooooo
06_ooooo00?o003oooooooooool0Qoooool2o`00o`Sooooo0Ol000010000007ooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooo
oooo06_ooooo00?o003oooooooooool0Qoooool2o`00o`Wooooo0@000001ooooo`001oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00`00003ooooooooo
o`1[ooooo`03o`00oooooooooooo08Oooooo0_l00?l9ooooo`4000000Oooool000Sooooo0_l00009
ooooo`?o00001Oooool00`00003oooooooooo`1;ooooo`03o`00oooooooooooo01gooooo0_l00?n8
ooooo`;o003o2Oooool10000007ooooo000Kooooo`0300000?oooooooooo04_ooooo00?o003ooooo
ooooool07Oooool2o`00ohSooooo0_l00?l9ooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool0Boooool00ol00?ooooooooooo`0Mooooo`;o003oR?ooool2o`00o`Sooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo04_ooooo00?o003oooooooooool07Oooool2o`00ohSooooo
0_l00?l9ooooo`4000000Oooool001_ooooo00<00000ooooooooool0Boooool00ol00?oooooooooo
o`0Mooooo`;o003o8?ooool00ol00?ooooooooooo`1Uooooo`;o003o2Oooool10000007ooooo000K
ooooo`0300000?oooooooooo04_ooooo00?o003oooooooooool07Oooool2o`00ob3ooooo00?o003o
ooooooooool0IOooool2o`00o`Wooooo0@000001ooooo`006oooool00`00003oooooooooo`1;oooo
o`03o`00oooooooooooo01gooooo0_l00?lPooooo`03o`00oooooooooooo06Gooooo0_l00?l9oooo
o`4000000Oooool001_ooooo00<00000o`000?ooool0Boooool00ol00?ooooooooooo`0Mooooo`;o
003o8?ooool00ol00?ooooooooooo`1Uooooo`03o`00oooooooo003o00Oooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo04_ooooo00?o003oooooooooool07Oooool2o`00ob3ooooo
0_l00?mVooooo`03o`00oooooooo003o00Sooooo0@000001ooooo`006oooool00`00003ooooooooo
o`1;ooooo`03o`00oooooooooooo01gooooo0_l00?lPooooo`;o003oI_ooool00ol00?ooooooo`00
o`08ooooo`4000000Oooool001_ooooo00<00000ooooooooool01Oooool00ol00?ooooooooooo`13
ooooo`03o`00oooooooooooo01gooooo0_l00?lPooooo`;o003oI_ooool00ol00?ooooooo`00o`08
ooooo`4000000Oooool001_ooooo00<00000ooooooooool01Oooool00ol00?ooooooooooo`12oooo
o`;o003o7_ooool00ol00?ooooooo`00o`0Pooooo`;o003oI_ooool00ol00?ooooooo`00o`08oooo
o`4000000Oooool001_ooooo00<00000o`000?ooool01Oooool00ol00?ooooooooooo`12ooooo`;o
003o7_ooool00ol00?ooooooo`00o`0Pooooo`;o003oGoooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooo003o00Oooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00Gooooo
00?o003oooooooooool0@_ooool2o`00oakooooo00?o003oooooool00?l08?ooool2o`00oeoooooo
00?o003oooooooooool01?ooool00ol00?ooooooo`00o`08ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool01Oooool00ol00?ooooooooooo`12ooooo`;o003o7_ooool00ol00?ooooooo`00
o`0Pooooo`03o`00oooooooo003o05kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00
o`08ooooo`4000000Oooool001_ooooo00<00000ooooooooool01Oooool2o`00od?ooooo0_l00?lN
ooooo`03o`00oooooooo003o023ooooo00?o003oooooool00?l0G_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooo003o00Sooooo0@000001ooooo`006oooool00`00003oooooooooo`05oooo
o`;o003o@oooool00ol00?ooooooo`00o`0Mooooo`03o`00oooooooo003o023ooooo00?o003ooooo
ool00?l0G_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Sooooo0@000001oooo
o`006oooool00`00003oooooooooo`05ooooo`;o003o@oooool00ol00?ooooooo`00o`0Mooooo`03
o`00oooooooo003o023ooooo00?o003oooooool00?l0G_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooo003o00Sooooo0@000001ooooo`006oooool00`00003o0000ooooo`05ooooo`;o003o
8Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo003o01gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooo003o023ooooo00?o003oooooooooool0
4oooool00ol00?ooooooooooo`0Tooooo`;o003o1_ooool00ol00?ooooooo`00o`07ooooo`7o0000
0@000001ooooo`006oooool00`00003oooooooooo`05ooooo`;o003o8Oooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooo003o01gooooo00?o003oooooool00?l01Oooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooo003o023ooooo00?o003oooooooooool04oooool00ol00?oooooooooo
o`0Tooooo`;o003o1_ooool00ol00?ooooooo`00o`08ooooo`4000000Oooool000Sooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`0300000?oooooooooo00Gooooo0_l00?lE
ooooo`?o003o2Oooool00ol00?ooooooooooo`0Oooooo`03o`00oooooooo003o00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooooooool06?ooool01?l00?ooooooooooool00?lOooooo`03o`00oooooooooooo01?ooooo0_l0
0?lUooooo`;o003o1Oooool01?l00?ooooooooooool00?l8ooooo`4000000Oooool000Oooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Gooooo
0_l00?lEooooo`03o`00oooooooo003o00Wooooo00?o003oooooooooool07oooool00ol00?oooooo
o`00o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooooooo01Sooooo00Co003ooooooooooooo003o7_ooool2o`00oaGo
oooo0_l00?lUooooo`;o003o1Oooool01?l00?ooooooooooool00?l8ooooo`4000000Oooool000Go
00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<00000oooo
ooooool01Oooool2o`00oaCooooo00Co003ooooooooooooo003o2Oooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Wooooo00Co003ooooooooooooo003o7_ooool2o`00oaGooooo00?o
003oooooool00?l03?ooool00ol00?ooooooooooo`0Eooooo`;o003o1Oooool01Ol00?oooooooooo
oooooooo003o00Oooooo0@000001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Cooooo00<00000o`000?ooool01Oooool00ol00?ooooooo`00o`0Cooooo`04o`00
ooooooooooooo`00o`Wooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooo003o00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`09oooo
o`04o`00ooooooooooooo`00oakooooo0_l00?lEooooo`03o`00oooooooo003o00cooooo00?o003o
ooooooooool05Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`06ooooo`7o00000@00
0001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<0
0000ooooooooool01?ooool01?l00?ooooooooooool00?lCooooo`04o`00ooooooooooooo`00o`Wo
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo003o00?o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Co
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`0;ooooo`;o003o2oooool01?l0
0?ooooooooooool00?lNooooo`;o003o5Oooool01?l00?ooooooooooool00?l;ooooo`03o`00oooo
oooooooo01Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l01oooool10000007ooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`0300000?oooooooooo00Cooooo
00Co003ooooooooooooo003o4_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool05Oooool2o`00o`Sooooo00?o003oooooool00?l00oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00_ooooo0_l00?l;ooooo`04o`00oooooooooooo
o`00oakooooo0_l00?lEooooo`04o`00ooooooooooooo`00o`_ooooo00?o003oooooooooool05Ooo
ool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`07ooooo`4000000Oooool000Sooooo0_l0
000:ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool01?ooool01?l00?oooooooooo
ool00?lBooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooo003o00Oooooo00?o003oooooool00?l00oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00_ooooo0_l00?l;ooooo`04o`00ooooooooooooo`00
oagooooo00?o003oooooool00?l05Oooool01?l00?ooooooooooool00?l;ooooo`03o`00oooooooo
oooo01Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l01oooool10000007ooooo000K
ooooo`0300000?oooooooooo00Cooooo00Co003ooooooooooooo003o0_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool2o`00oaKooooo00?o
003oooooool00?l01oooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool02?ooool2o`00o`Kooooo00Co003ooooooooooooo003o0oooool2o`00o`cooooo
00Co003ooooooooooooo003o2_ooool01?l00?ooooooooooool00?lMooooo`03o`00oooooooo003o
01Gooooo00Co003ooooooooooooo003o2oooool00ol00?ooooooooooo`0Eooooo`;o003o1Oooool0
1Ol00?oooooooooooooooooo003o00Oooooo0@000001ooooo`006oooool00`00003o0000ooooo`04
ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Kooooo0_l00?lFooooo`03o`00oooooooo003o00Oooooo00?o
003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`;o003o2_ooool2o`00o`Kooooo00Co
003ooooooooooooo003o0oooool2o`00o`cooooo00Co003ooooooooooooo003o2Oooool01Ol00?oo
oooooooooooooooo003o01gooooo00?o003oooooool00?l05Oooool01Ol00?oooooooooooooooooo
003o00Wooooo0_l00?lFooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00
o`06ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`04ooooo`04o`00oooooooo
ooooo`00o`;ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Kooooo0_l00?lFooooo`03o`00oooooooo003o00Oooooo00?o003oooooool00?l00ooo
ool00ol00?ooooooooooo`03ooooo`;o003o2_ooool2o`00o`Kooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooo`00o`0;ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo003o01Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`07ooooo`;o003o1oooool3o`00o`cooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?ooooooooooooooool0003o00Oooooo0@000001ooooo`006oooool00`00
003oooooooooo`04ooooo`05o`00ooooooooooooo`00ooooool00_l00?l>ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool01_ooool2o`00oaGooooo00Co003ooooooooooooo003o1ooo
ool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo0_l00?l:ooooo`;o003o1_oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00_ooooo00Co003ooooooooooooo
003o2Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003oooooool0
0?l05?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooool0
0?l01_ooool00ol00?ooooooo`00o`0<ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
oooooooooooo0000o`07ooooo`4000000Oooool001_ooooo00<00000ooooooooool01?ooool01Ol0
0?ooooooooooool00?oooooo00;o003o3_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Kooooo0_l00?l5ooooo`;o003o2oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooo`00o`04ooooo`;o003o
1_ooool01?l00?ooooooooooooooool2o`00o`Kooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooo`00o`0;ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Jooooo`04o`00ooooooooooooo`00oa?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o
3?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooo`000?l01oooool10000
007ooooo000Kooooo`0300000?oooooooooo00Cooooo00Co003ooooooooooooooooo0_l00?l00ooo
oooo003oooooo`0<ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01_ooool2o`00
o`Gooooo00?o003oooooool00?l02_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo00?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooo
oooo003o00Gooooo00Oo003oooooooooooooooooo`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooo`00o`0;ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Jooooo`04o`00ooooooooooooo`00oa?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`0<ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooo
oooooooo0000o`07ooooo`4000000Oooool001_ooooo00<00000o`000?ooool01?ooool01?l00?oo
ooooooooooooool2o`00o`03ooooool00?oooooo00cooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`06ooooo`;o003o1Oooool01?l00?ooooooooooool00?l9ooooo`;o003o00?ooooo
o`00ooooool00_ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`;ooooo00?o
003oooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`07o`00ooooooooooooooooool00?oo
ooooo`00o`05ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l02oooool01?l0
0?ooooooooooool00?l9ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool06_ooool0
1?l00?ooooooooooool00?lCooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02Ooo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooo`000?l01_ooool1o`000040
00000Oooool001_ooooo00<00000ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Go
oooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l02Oooool2o`00o`03ooooool00?oooooo
00;ooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo
003o00Cooooo00?o003oooooool00?l01Oooool2o`00o`;ooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l3ooooo`03o`00oooooooo003o00_ooooo00Co003ooooooooooooo003o
2Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00Co003ooooooooooooo
003o4oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool0
0?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?ooooooooooooooool0003o00Oooooo0@000001ooooo`006oooool00`00
003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l02Oooool3o`00o`Cooooo00?o003oooooooooool00ooo
ool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l0
1Oooool2o`00o`;ooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooo003o00Kooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00[ooooo00Co003ooooooooooooo003o4oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00Kooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooo
ooooooooooooo`000?l01oooool10000007ooooo000Kooooo`0300000?oooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool01?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00?ooooo00Co
003ooooooooooooo003o0_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo
0_l00?l2ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooo`00o`06ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0:oooo
o`04o`00ooooooooooooo`00oa?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`06
ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
ooooool0003o00Oooooo0@000001ooooo`006oooool00`00003oooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`04o`00oooo
ooooooooo`00o`;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`;o003o
0_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooo`00o`06ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0:oooo
o`04o`00ooooooooooooo`00oa?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`06
ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
ooooool0003o00Oooooo0@000001ooooo`006oooool00`00003oooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`04o`00oooo
ooooooooo`00o`;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooo003o00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooool00?l01Oooool2o`00o`?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool2o`00o`_o
oooo00Co003ooooooooooooo003o4oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Gooooo00Go003oooooool00?ooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00Go003o
oooooooooooooooo0000o`07ooooo`4000000Oooool001_ooooo00<00000o`000?ooool01?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00?ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool0
1?l00?ooooooooooool00?l2ooooo`03o`00oooooooo003o00Cooooo00?o003oooooool00?l01?oo
ool02?l00?ooooooooooool00?ooooooo`00oooooooo003o1Oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooool00?l01Oooool2o`00o`?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool2
o`00o`_ooooo00Co003ooooooooooooo003o0oooool3o`00o`gooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`05ooooo`04o`00oooooooo003oo`00o`?ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`030000oooooooooooo00?ooooo0Ol000010000007o
oooo000Kooooo`0300000?oooooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?oooooo
o`00o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o0_ooool00ol00?oo
ooooo`00o`04ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_l00?l2ooooo`03
o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo003o
00Gooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo0_l00?l;ooooo`04o`00oooooooooooo
o`00o`?ooooo00?o003oooooool00?l03Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Cooooo00Co003oooooool00?oo003o0oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00<0003oooooooooool01?ooool10000007ooooo000Kooooo`0300000?oo
oooooooo00Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00?ooooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooo003o00Cooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00?ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo003o00Gooooo0_l00?l3ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00gooooo0_l00?l3ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooo`00o`0=ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool01?ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool01?ooool01?l00?ooooooo`00ool00?l3ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00`000?ooooooooooo`04ooooo`4000000Oooool001_ooooo00<00000
ooooooooool01?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`;ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool00oooool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02o`00o`;ooooo00?o003ooooooooo
ool00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00cooooo0_l00?l3ooooo`03o`00oooooooooooo
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`cooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`;ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00<0003ooooooooo
ool01?ooool10000007ooooo000Kooooo`0300000?oooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
0oooool01_l00?ooooooooooool00?ooooooo`00o`Oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00Ko003ooooooooooooo003oooooool0
0?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`02o`00o`;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`05o`00
oooooooo003oooooool00?l01?ooool00ol00?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`cooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00<0003oooooooooool0
1?ooool10000007ooooo000Kooooo`0300000?l0003ooooo00Cooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00ooo
ool01_l00?ooooooooooool00?ooooooo`00o`Oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00Ko003ooooooooooooo003oooooool00?l3
ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`02ooooo`;o003o
0_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`03ooooo`08o`00ooooooooooooo`00oooooooo003oooooool0
0?l5ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00co
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`07o`00oooooooooooooooo
ool00?ooooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00<0003oooooooooool00oooool1
o`00004000000Oooool001_ooooo00<00000ooooooooool01?ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03oooo
o`06o`00ooooooooooooo`00oooooooo003o1oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool00oooool01_l00?ooooooooooool00?ooooooo`00o`?o
oooo00Co003ooooooooooooo003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo0_l00?l2
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`04ooooo`;o003o1Oooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o1Oooool01Ol0
0?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`07o`00oooo
ooooooooooooool00?ooooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00<0003ooooooooo
ool01?ooool10000007ooooo000Dooooo`;o00001Oooool00`00003oooooooooo`04ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool00_l00?l8ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`06o`00ooooooooooooo`00oooo
oooo003o0oooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo0_l00?l2
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`;o003o
1Oooool02?l00?ooooooooooool00?ooooooo`00oooooooo003o1Oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`07o`00ooooooooooooooooool0
0?ooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00<0003oooooooooool01?ooool10000
007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool01?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o2?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool01?l00?ooooooooooooooool2
o`00o`?ooooo0_l00?l01Ooooooo003ooooooooooooo003o00Cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`;o003o1Oooool01_l00?oo
ooooooooool00?ooooooo`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`;o003o1Ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00Oo003ooooooooooooooooo
o`00oooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00`000?ooooooooooo`04ooooo`40
00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`04ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00_l00?l8ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`03ooooo`04o`00oooooooooooooooo
o`;o003o1Oooool2o`00o`;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`;o003o
1Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00Oo003ooooooooooooo
ooooo`00oooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00`000?ooooooooooo`04ooooo`4000000Oooool0
01?ooooo00Co0000oooooooooooo00001?ooool700000003o`00o`000000000000H0000000?o003o
000000000000200000000ol00?l000000000000600000003o`00o`000000000000<0000000Co003o
00000000003o003o2@0000000ol00?l000000000000400000003o`00o`000000000000D0000000?o
003o0000000000000`0000001?l00?l00000000000000002o`00o`H0000000Co003o00000000003o
003o100000000ol00?l000000000000400000003o`00o`000000000000<0000000?o003o00000000
00000`0000001?l00?l0000000000?l00?l300000007o`00o`000000000000000?l00?l00000o`00
o`0600000003o`00o`000000000000D0000000?o003o000000000000100000000ol00?l000000000
000200000003o`00o`00003o003o00D0000000Go003o0000000000000000o`00o`0300000003o`00
o`00000000000080000000Go003o0000000000000000o`00o`0200000003o`00o`00000000000080
000000?o003o0000000000000P000002o`00o`D0000000?o003o0000000000001@0000000ol00?l0
00000000000300000007o`00o`000000000000000?l00?l00000o`00o`0800000005o`00o`000000
000000000?l00?l0200000000ol00?l000000000000200000003o`00o`00000000000080000000<0
003o0000000000001@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo00Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`04o`00oooo
ooooooooooooo`;o003o2Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`05o`00ooooooooooooooooool0
0?l00_ooool01ol00?oooooooooooooooooo003oooooool00?l01oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Oo003oooooooooooooooooo`00oooooooo003o00Cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`03ooooo`07o`00ooooooooooooooooool00?ooooooo`00
o`08ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00<0003oooooooooool01?ooool10000007ooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000ooooooooool00oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooooooo0_l00?l9ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`07ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003ooooooooooooo003o1?ooool01ol00?oooooooooooooooooo003oooooool00?l0
1?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00Oo003ooooooooooooo
ooooo`00oooooooo003o00Sooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool00_ooool00`000?ooooooooooo`04ooooo`4000000Oooool0
01Cooooo0_l00005ooooo`0300000?oooooooooo00?ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool01Ol0
0?oooooooooooooooooo003o00Cooooo0_l00?l9ooooo`05o`00ooooooooooooooooool00?l01ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
1_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool01_l0
0?ooooooooooool00?ooooooo`00o`Cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`03ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`08ooooo`04o`00ooooooooooooo`00
o`Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`030000oooooooooooo
00Cooooo0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oo
oooo00Go003oooooooooooooooooo`00o`04ooooo`;o003o2_ooool01?l00?ooooooooooool00?l7
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooo003o00Oooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`06ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooo`00o`06ooooo`?o003o
0oooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool00oooool01ol00?oo
oooooooooooooooo003oooooool00?l02?ooool01?l00?ooooooooooool00?l9ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00`000?ooooooooooo`04ooooo`4000000Ooo
ool001_ooooo00<00000o`000?ooool00oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`05o`00oooooooo
ooooooooool00?l01?ooool2o`00o`[ooooo00Co003ooooooooooooo003o2?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Oooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`04oooo
o`;o003o3?ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool00oooool0
1ol00?oooooooooooooooooo003oooooool00?l02?ooool01?l00?ooooooooooool00?l9ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00`000?ooooooooooo`03ooooo`7o
00000@000001ooooo`006oooool00`00003oooooooooo`03ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo
00Go003oooooooooooooooooo`00o`04ooooo`;o003o2_ooool01?l00?ooooooooooool00?l8oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool01Ol00?oooooooooooooo
oooo003o00Cooooo0_l00?l<ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l02Oooool00ol00?oooooo
o`00o`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00`000?oooooo
ooooo`04ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`07ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`09ooooo`04o`00
ooooooooooooo`00o`Sooooo00Go003oooooooooooooooooo`00o`0:ooooo`03o`00oooooooo003o
00Cooooo00?o003oooooool00?l02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooo
ooooool00?l01?ooool2o`00o`cooooo00Go003oooooooooooooooooo`00o`08ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`09ooooo`03o`00oooo
oooo003o00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`030000oooo
oooooooo00Cooooo0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00Oooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Wooooo00Co
003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o00[ooooo00?o003oooooool0
0?l01?ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`;o003o3?ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Wooooo00?o003o
ooooool00?l02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00<0003o
ooooooooool01?ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool02Oooool0
1?l00?ooooooooooool00?l8ooooo`05o`00ooooooooooooooooool00?l02_ooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool01Ol00?oooooo
oooooooooooo003o00Cooooo0_l00?l<ooooo`05o`00ooooooooooooooooool00?l02Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo0_l00?l:ooooo`03o`00oooooooo003o00Wooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`03ooooo`030000oooooooooooo00?ooooo0@000001
ooooo`006oooool00`00003o0000ooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooool00?l02Oooool0
1Ol00?oooooooooooooooooo003o00[ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00
o`08ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`04ooooo`;o003o
3?ooool01Ol00?oooooooooooooooooo003o00Wooooo00Go003oooooooooooooooooo`00o`05oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooool00?l02Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00?ooooo00<0003oooooooooool00_ooool1o`00004000000Oooool001_o
oooo00<00000ooooooooool00oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo003o00Wooooo00Go003ooooo
ooooooooooooo`00o`0:ooooo`03o`00oooooooo003o00Gooooo0_l00?l8ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00Kooooo00Go003oooooooooooooooooo`00o`04ooooo`;o003o3?ooool01Ol00?oooooooooo
oooooooo003o00Wooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00So
oooo00?o003oooooool00?l02Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?o
oooo00<0003oooooooooool00oooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`05o`00ooooooooooooooooool0
0?l02Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool02Oooool2o`00
o`[ooooo00Go003oooooooooooooooooo`00o`0:ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00cooooo00Go003o
ooooooooooooooooo`00o`09ooooo`05o`00ooooooooooooooooool00?l01?ooool2o`00o`cooooo
00Go003oooooooooooooooooo`00o`09ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol0
0?ooooooooooo`08ooooo`;o003o2_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00?ooooo00<0003oooooooooool00oooool10000007ooooo000Kooooo`0300000?oooooooooo00?o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`04o`00ooooooooooooo`00
o`[ooooo00Go003oooooooooooooooooo`00o`0@ooooo`;o003o2_ooool01Ol00?oooooooooooooo
oooo003o00[ooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03?ooool01Ol00?oooooooooooooooooo003o00Wooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooo
oooo003o2_ooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`05o`00ooooooooooooooooool00?l01Oooool00`000?oooooooooo
o`03ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00cooooo00Co003ooooooooooooo003o2_ooool01Ol00?oooooooooo
oooooooo003o013ooooo00?o003oooooooooool02Oooool01Ol00?oooooooooooooooooo003o00[o
oooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03?ooool01Ol00?oooooooooooooooooo003o00Wooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo003o2_oo
ool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`05o`00ooooooooooooooooool00?l01Oooool00`000?ooooooooooo`03ooooo`40
00000Oooool001_ooooo00<00000ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`04o`00
ooooooooooooo`00o`[ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00oooooooooooo
ooooool00?l02_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0<ooooo`05o`00ooooooooooooooooool00?l02Ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool02oooool01?l00?oooooo
ooooool00?l:ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`05ooooo`030000oooooooo
oooo00?ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00cooooo00Co003ooooooooooooo003o2_ooool01Ol00?oooooooooooooooooo003o01cooooo00Go
003oooooooooooooooooo`00o`0:ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00gooooo00Co003ooooooooooooo
003o2Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooooooool02oooool01?l0
0?ooooooooooool00?l:ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00Go003oooooooooooooooooo`00o`05ooooo`030000
oooooooooooo00;ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool03?ooool01?l00?ooooooooooool00?l:ooooo`05o`00ooooooooooooooooool0
0?l07?ooool01Ol00?oooooooooooooooooo003o00[ooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool01?l0
0?ooooooooooool00?l9ooooo`05o`00ooooooooooooooooool00?l04_ooool01?l00?oooooooooo
ool00?l:ooooo`05o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o
00Gooooo00<0003oooooooooool00oooool10000007ooooo000Kooooo`0300000?oooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooooooo
ool00?l03oooool01?l00?ooooooooooool00?l:ooooo`05o`00ooooooooooooooooool00?l07?oo
ool01Ol00?oooooooooooooooooo003o00[ooooo00?o003oooooool00?l01Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Oooool01?l00?oooooo
ooooool00?l:ooooo`04o`00ooooooooooooo`00oa?ooooo0_l00?l;ooooo`05o`00oooooooooooo
ooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00Gooooo00<0003oooooooooool00ooo
ool10000007ooooo000Kooooo`0300000?oooooooooo00kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool00?l03oooool01?l00?oooooooooo
ool00?l:ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o
00[ooooo00?o003oooooool00?l03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00gooooo00Co003ooooooooooooo003o2_ooool01?l00?ooooooooooool00?lCooooo`;o003o2ooo
ool01Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`0;ooooo`40
00000Oooool001_ooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0?ooooo`04o`00ooooooooooooo`00
o`[ooooo00Go003oooooooooooooooooo`00o`0Looooo`05o`00ooooooooooooooooool00?l02_oo
ool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03Ooo
ool01?l00?ooooooo`00ool00?l:ooooo`03o`00oooooooo003o01Cooooo0_l00?l;ooooo`05o`00
ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00_ooooo0@000001oooo
o`006oooool00`00003o0000ooooo`0?ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool02oooool01Ol00?oooooooooooooooooo003o00oooooo00?o003oooooool00?l02oooool01Ol0
0?oooooooooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`0:ooooo`03o`00oooo
oooo003o013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`;o003o3?oo
ool00ol00?ooooooo`00o`0Dooooo`;o003o2oooool01Ol00?oooooooooooooooooo003o01gooooo
00Go003oooooooooooooooooo`00o`0:ooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`0?ooooo`03o`00oooooooooooo00?o003o3Oooool01Ol00?oooooooooooooooooo003o00oo
oooo00?o003oooooool00?l02oooool01Ol00?oooooooooooooooooo003o01cooooo00Go003ooooo
ooooooooooooo`00o`0;ooooo`;o003o4?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool02oooool00ol00?ooooooo`00o`0Dooooo`;o003o2oooool0
1Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`0;ooooo`400000
0Oooool001_ooooo00<00000ooooooooool03oooool01?l00?ooooooooooool00?l?ooooo`05o`00
ooooooooooooooooool00?l04?ooool2o`00o`_ooooo00Go003oooooooooooooooooo`00o`0Loooo
o`05o`00ooooooooooooooooool00?l02oooool2o`00oa3ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooo003o01Cooooo00?o003oooooooooool02_ooool0
1Ol00?oooooooooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`0;ooooo`400000
0Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`0300000?oo
oooooooo00oooooo00?o003oooooool00?l04?ooool01Ol00?oooooooooooooooooo003o013ooooo
0_l00?l;ooooo`05o`00ooooooooooooooooool00?l07?ooool01Ol00?oooooooooooooooooo003o
00_ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
01_ooooo00?o003oooooool00?l05?ooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooo
ooooool00?l07Oooool01Ol00?oooooooooooooooooo003o00_ooooo0@000001ooooo`001oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool03ooo
ool2o`00oa7ooooo00Go003oooooooooooooooooo`00o`0@ooooo`;o003o2oooool01Ol00?oooooo
oooooooooooo003o01cooooo00Go003oooooooooooooooooo`00o`0;ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo003o
027ooooo00Go003oooooooooooooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l02ooo
ool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?oo
ool00`00003o0000ooooo`0?ooooo`03o`00oooooooooooo013ooooo00Go003ooooooooooooooooo
o`00o`0@ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0Looooo`05
o`00ooooooooooooooooool00?l02oooool00ol00?ooooooooooo`0?ooooo`05o`00oooooooooooo
ooooool00?l07_ooool00ol00?ooooooo`00o`0Rooooo`04o`00ooooooooooooo`00oagooooo00Go
003oooooooooooooooooo`00o`0:ooooo`7o00000@000001ooooo`001oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool08_ooool01Ol00?oooooo
oooooooooooo003o013ooooo00?o003oooooooooool02_ooool01Ol00?oooooooooooooooooo003o
01gooooo00Co003ooooooooooooo003o2oooool00ol00?ooooooooooo`0?ooooo`05o`00oooooooo
ooooooooool00?l07_ooool00ol00?ooooooo`00o`0Rooooo`04o`00ooooooooooooo`00oagooooo
00Go003oooooooooooooooooo`00o`0;ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo02;ooooo00Go003ooooooooo
ooooooooo`00o`0@ooooo`03o`00oooooooooooo00[ooooo00Go003oooooooooooooooooo`00o`0M
ooooo`04o`00ooooooooooooo`00o`_ooooo00?o003oooooooooool03oooool01Ol00?oooooooooo
oooooooo003o01kooooo00?o003oooooool00?l08_ooool01?l00?ooooooooooool00?lMooooo`05
o`00ooooooooooooooooool00?l02oooool10000007ooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo0_l00006ooooo`0300000?oooooooooo02;ooooo00Go003oooooooooooooooooo`00o`0M
ooooo`05o`00ooooooooooooooooool00?l07Oooool01?l00?ooooooooooool00?l;ooooo`03o`00
oooooooooooo00oooooo00Go003oooooooooooooooooo`00o`0Nooooo`03o`00oooooooo003o02;o
oooo00?o003oooooool00?l07_ooool01Ol00?oooooooooooooooooo003o00_ooooo0@000001oooo
o`002?ooool2o`0000[ooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0Rooooo`05
o`00ooooooooooooooooool00?l07Oooool01Ol00?oooooooooooooooooo003o01gooooo00Co003o
oooooooooooo003o2oooool00ol00?ooooooooooo`0?ooooo`05o`00ooooooooooooooooool00?l0
7_ooool00ol00?ooooooo`00o`0Rooooo`03o`00oooooooo003o01kooooo00Go003ooooooooooooo
ooooo`00o`0;ooooo`4000000Oooool001_ooooo00<00000o`000?ooool08_ooool01Ol00?oooooo
oooooooooooo003o01gooooo00Go003oooooooooooooooooo`00o`0Mooooo`04o`00oooooooooooo
o`00o`_ooooo00?o003oooooooooool03oooool01Ol00?oooooooooooooooooo003o01kooooo00?o
003oooooool00?l08_ooool00ol00?ooooooo`00o`0Nooooo`05o`00ooooooooooooooooool00?l0
2_ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool08_ooool01Ol00?oooooooooo
oooooooo003o01gooooo00Co003ooooooooooooo003o7_ooool01?l00?ooooooooooool00?lMoooo
o`05o`00ooooooooooooooooool00?l07_ooool00ol00?ooooooo`00o`0Rooooo`03o`00oooooooo
003o01kooooo00Go003oooooooooooooooooo`00o`0;ooooo`4000000Oooool001_ooooo00<00000
ooooooooool08_ooool01Ol00?oooooooooooooooooo003o01gooooo00Co003ooooooooooooo003o
7_ooool01?l00?ooooooooooool00?lMooooo`05o`00ooooooooooooooooool00?l07_ooool00ol0
0?ooooooo`00o`0Rooooo`03o`00oooooooo003o01kooooo00Go003oooooooooooooooooo`00o`0;
ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool01Ol00?oooooooooooooooooo
003o01gooooo00Co003ooooooooooooo003o7_ooool01?l00?ooooooooooool00?lMooooo`05o`00
ooooooooooooooooool00?l07_ooool00ol00?ooooooo`00o`0Rooooo`03o`00oooooooo003o01ko
oooo00Go003oooooooooooooooooo`00o`0;ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool08_ooool01Ol00?oooooooooooooooooo003o01gooooo00Co003ooooooooooooo003o7_ooool0
1?l00?ooooooooooool00?lMooooo`05o`00ooooooooooooooooool00?l07_ooool00ol00?oooooo
o`00o`0Rooooo`03o`00oooooooo003o01kooooo00Go003oooooooooooooooooo`00o`0;ooooo`40
00000Oooool001_ooooo00<00000o`000?ooool08_ooool01Ol00?oooooooooooooooooo003o01go
oooo00Co003ooooooooooooo003o7_ooool01?l00?ooooooooooool00?lMooooo`05o`00oooooooo
ooooooooool00?l07_ooool00ol00?ooooooo`00o`0Rooooo`03o`00oooooooo003o01kooooo00Go
003oooooooooooooooooo`00o`0:ooooo`7o00000@000001ooooo`006oooool00`00003ooooooooo
o`0Rooooo`05o`00ooooooooooooooooool00?l07_ooool00ol00?ooooooo`00o`0Nooooo`04o`00
ooooooooooooo`00oagooooo00Go003oooooooooooooooooo`00o`0Nooooo`03o`00oooooooo003o
02;ooooo00?o003oooooool00?l07oooool01?l00?ooooooooooool00?l;ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool08_ooool01Ol00?oooooooooooooooooo003o01kooooo00?o003o
ooooool00?l07_ooool01?l00?ooooooooooool00?lMooooo`05o`00ooooooooooooooooool00?l0
7_ooool00ol00?ooooooo`00o`0Rooooo`03o`00oooooooo003o01oooooo00Co003ooooooooooooo
003o2oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00Go003ooooooooooooo
ooooo`00o`0Nooooo`03o`00oooooooo003o01kooooo00Co003ooooooooooooo003o7Oooool01Ol0
0?oooooooooooooooooo003o01kooooo00?o003oooooool00?l08_ooool00ol00?ooooooo`00o`0O
ooooo`04o`00ooooooooooooo`00o`_ooooo0@000001ooooo`006oooool00`00003oooooooooo`0R
ooooo`05o`00ooooooooooooooooool00?l07_ooool00ol00?ooooooo`00o`0Nooooo`04o`00oooo
ooooooooo`00oagooooo00Go003oooooooooooooooooo`00o`0Nooooo`03o`00oooooooo003o02;o
oooo00?o003oooooool00?l07oooool01?l00?ooooooooooool00?l;ooooo`4000000Oooool001_o
oooo00<00000ooooooooool08_ooool01?l00?ooooooooooool00?lOooooo`03o`00oooooooo003o
01kooooo00Co003ooooooooooooo003o7Oooool01Ol00?oooooooooooooooooo003o01kooooo00?o
003oooooool00?l08_ooool00ol00?ooooooo`00o`0Oooooo`03o`00oooooooo003o00cooooo0@00
0001ooooo`006oooool00`00003o0000ooooo`0Rooooo`04o`00ooooooooooooo`00oaoooooo00?o
003oooooool00?l07_ooool01?l00?ooooooooooool00?lMooooo`05o`00ooooooooooooooooool0
0?l07_ooool00ol00?ooooooo`00o`0Rooooo`03o`00oooooooo003o01oooooo00?o003oooooool0
0?l02oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool08_ooool01?l00?oooooo
ooooool00?lOooooo`03o`00oooooooo003o01kooooo00Co003ooooooooooooo003o7Oooool01Ol0
0?oooooooooooooooooo003o01kooooo00?o003oooooool00?l08_ooool00ol00?ooooooo`00o`0O
ooooo`03o`00oooooooo003o00cooooo0@000001ooooo`006oooool00`00003oooooooooo`0Roooo
o`04o`00ooooooooooooo`00oaoooooo00?o003oooooool00?l07_ooool01?l00?ooooooooooool0
0?lMooooo`05o`00ooooooooooooooooool00?l07_ooool00ol00?ooooooo`00o`0Rooooo`03o`00
oooooooo003o01oooooo00?o003oooooool00?l03?ooool10000007ooooo000Kooooo`0300000?oo
oooooooo02;ooooo00Co003ooooooooooooo003o7oooool00ol00?ooooooo`00o`0Nooooo`04o`00
ooooooooooooo`00oagooooo00Go003oooooooooooooooooo`00o`0Nooooo`03o`00oooooooo003o
02;ooooo00?o003oooooool00?l07oooool00ol00?ooooooo`00o`0<ooooo`4000000Oooool001_o
oooo00<00000ooooooooool08_ooool01?l00?ooooooooooool00?lOooooo`03o`00oooooooo003o
01kooooo00Co003ooooooooooooo003o7Oooool01Ol00?oooooooooooooooooo003o01kooooo00?o
003oooooool00?l08_ooool00ol00?ooooooo`00o`0Oooooo`03o`00oooooooo003o00cooooo0@00
0001ooooo`006oooool00`00003o0000ooooo`0Rooooo`04o`00ooooooooooooo`00oaoooooo00?o
003oooooool00?l07oooool00ol00?ooooooo`00o`0Mooooo`05o`00ooooooooooooooooool00?l0
7oooool2o`00ob;ooooo00?o003oooooool00?l07oooool00ol00?ooooooo`00o`0;ooooo`7o0000
0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`04o`00ooooooooooooo`00oaoooooo
00?o003oooooool00?l07oooool00ol00?ooooooo`00o`0Mooooo`05o`00ooooooooooooooooool0
0?l07oooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo003o01oooooo00?o003oooooool0
0?l03?ooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00Co003ooooooooooooo
003o7oooool00ol00?ooooooo`00o`0Oooooo`03o`00oooooooo003o01gooooo00Go003ooooooooo
ooooooooo`00o`0Oooooo`03o`00oooooooooooo027ooooo00?o003oooooool00?l07oooool00ol0
0?ooooooo`00o`0<ooooo`4000000Oooool000Sooooo0_l00004ooooo`04o`000?oooooooooooooo
o`Go00001?ooool00`00003oooooooooo`0Rooooo`04o`00ooooooooooooo`00oaoooooo00?o003o
ooooool00?l07oooool00ol00?ooooooo`00o`0Nooooo`04o`00ooooooooooooo`00oaoooooo00?o
003oooooooooool08Oooool00ol00?ooooooo`00o`0Oooooo`03o`00oooooooo003o00cooooo0@00
0001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool08_ooool01?l00?ooooooooooool00?lOooooo`03o`00oooooooo003o01oo
oooo00?o003oooooool00?l07_ooool01?l00?ooooooooooool00?lOooooo`03o`00oooooooooooo
02;ooooo0_l00?lOooooo`03o`00oooooooo003o00cooooo0@000001ooooo`001oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<00000o`000?ooool08_ooool01?l0
0?ooooooooooool00?lOooooo`03o`00oooooooo003o01oooooo0_l00?lOooooo`03o`00oooooooo
003o023ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Oooooo`;o003o2oooool1
o`00004000000Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03
ooooo`0300000?oooooooooo02;ooooo00Co003ooooooooooooo003o7oooool00ol00?ooooooo`00
o`0Oooooo`;o003o7oooool00ol00?ooooooo`00o`0Pooooo`03o`00oooooooooooo02;ooooo00?o
003oooooooooool07oooool2o`00o`cooooo0@000001ooooo`001oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001?ooool00`00003oooooooooo`0Rooooo`04o`00
ooooooooooooo`00oaoooooo00?o003oooooool00?l07oooool2o`00oaoooooo00?o003oooooool0
0?l08?ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo01oooooo0_l00?l<ooooo`40
00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00<00000ooooooooool08_ooool00ol00?ooooooo`00o`0Pooooo`03o`00oooooooo003o
01oooooo0_l00?lOooooo`03o`00oooooooo003o023ooooo00?o003oooooooooool08_ooool00ol0
0?ooooooooooo`0Oooooo`;o003o3?ooool10000007ooooo0008ooooo`;o00002Oooool3o`0000Go
oooo00<00000ooooooooool08_ooool00ol00?ooooooo`00o`0Pooooo`03o`00oooooooo003o01oo
oooo0_l00?lOooooo`03o`00oooooooo003o023ooooo00?o003oooooooooool08_ooool00ol00?oo
ooooooooo`0Oooooo`;o003o3?ooool10000007ooooo000Kooooo`0300000?l0003ooooo02?ooooo
0_l00?lPooooo`03o`00oooooooo003o01oooooo0_l00?lOooooo`;o003o8Oooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo01oooooo0_l00?l;ooooo`7o00000@000001ooooo`006ooo
ool00`00003oooooooooo`0Sooooo`;o003o8?ooool00ol00?ooooooo`00o`0Oooooo`;o003o7ooo
ool2o`00ob7ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Oooooo`;o003o3?oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02?ooooo0_l00?lPooooo`03o`00oooooooo
003o01oooooo0_l00?lOooooo`;o003o8Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo
oooo01oooooo0_l00?l<ooooo`4000000Oooool001_ooooo00<00000ooooooooool08oooool2o`00
ob3ooooo00?o003oooooool00?l07oooool2o`00oaoooooo0_l00?lQooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool07oooool2o`00o`cooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0Sooooo`;o003o8?ooool00ol00?ooooooo`00o`0Oooooo`;o003o7oooool2o`00ob7o
oooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Oooooo`;o003o3?ooool10000007o
oooo000Kooooo`0300000?oooooooooo02?ooooo0_l00?lPooooo`03o`00oooooooo003o01oooooo
0_l00?lOooooo`03o`00oooooooooooo04Gooooo00?o003oooooooooool07oooool2o`00o`cooooo
0@000001ooooo`006oooool00`00003o0000ooooo`0Sooooo`;o003o8?ooool00ol00?ooooooo`00
o`0Oooooo`;o003o7oooool00ol00?ooooooooooo`15ooooo`03o`00oooooooooooo01oooooo0_l0
0?l;ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`;o003o8?ooool0
0ol00?ooooooo`00o`0Oooooo`;o003oROooool2o`00o`cooooo0@000001ooooo`006oooool00`00
003oooooooooo`0Sooooo`;o003o8?ooool00ol00?ooooooo`00o`0Pooooo`03o`00oooooooooooo
08Oooooo0_l00?l<ooooo`4000000Oooool001_ooooo00<00000ooooooooool08oooool2o`00ob3o
oooo00?o003oooooool00?l08?ooool00ol00?ooooooooooo`27ooooo`;o003o3?ooool10000007o
oooo000Kooooo`0300000?oooooooooo02?ooooo0_l00?lPooooo`03o`00oooooooo003o023ooooo
00?o003oooooooooool0Qoooool2o`00o`cooooo0@000001ooooo`006oooool00`00003o0000oooo
o`0Sooooo`;o003o8?ooool00ol00?ooooooo`00o`0Pooooo`03o`00oooooooooooo08Sooooo00?o
003oooooooooool02Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool08oooool0
0ol00?ooooooooooo`0Oooooo`03o`00oooooooo003o023ooooo00?o003oooooooooool0R?ooool0
0ol00?ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000ooooooooool08oooool00ol0
0?ooooooooooo`0Oooooo`;o003o8Oooool00ol00?ooooooooooo`28ooooo`03o`00oooooooooooo
00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`03o`00oooooooooooo01oo
oooo0_l00?lQooooo`03o`00oooooooooooo08Sooooo00?o003oooooooooool02_ooool10000007o
oooo000Kooooo`0300000?oooooooooo02?ooooo00?o003oooooooooool08?ooool00ol00?oooooo
ooooo`0Oooooo`03o`00oooooooooooo08Sooooo00?o003oooooooooool02_ooool10000007ooooo
000Kooooo`0300000?l0003ooooo02?ooooo00?o003oooooooooool08?ooool00ol00?oooooooooo
o`0Oooooo`03o`00oooooooooooo08Sooooo00?o003oooooooooool02Oooool1o`00004000000Ooo
ool001_ooooo00<00000ooooooooool08oooool00ol00?ooooooooooo`0Pooooo`03o`00oooooooo
oooo0:[ooooo00?o003oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooooooo
02?ooooo00?o003oooooooooool08?ooool00ol00?ooooooooooo`2Zooooo`03o`00oooooooooooo
00[ooooo0@000001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Go
oooo00<00000ooooooooool0A_ooool00ol00?ooooooooooo`2gooooo`4000000Oooool000Oooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00<00000oooo
ooooool0A_ooool00ol00?ooooooooooo`2gooooo`4000000Oooool000Oooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooooooo`02ooooo`0300000?l0003ooooo04Kooooo00?o003ooooo
ooooool0]_ooool1o`00004000000Oooool000Oooooo00Co0000oooooooooooo00002Oooool2o`00
00Gooooo00<00000ooooooooool0A_ooool00ol00?ooooooooooo`2gooooo`4000000Oooool000Oo
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo
04Kooooo00?o003oooooooooool0]oooool10000007ooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooooooo04Kooooo00?o003o
ooooooooool0]oooool10000007ooooo0008ooooo`;o00002Oooool3o`0000Gooooo00<00000oooo
ooooool0A_ooool00ol00?ooooooooooo`2gooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool0A_ooool00ol00?ooooooooooo`2fooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`16ooooo`03o`00oooooooooooo0;Oooooo0@000001ooooo`006oooool00`00003ooooooooo
o`16ooooo`03o`00oooooooooooo0;Oooooo0@000001ooooo`006oooool00`00003oooooooooo`16
ooooo`03o`00oooooooooooo0;Oooooo0@000001ooooo`006oooool00`00003oooooooooo`16oooo
o`03o`00oooooooooooo0;Oooooo0@000001ooooo`006oooool00`00003oooooooooo`16ooooo`03
o`00oooooooooooo0;Oooooo0@000001ooooo`006oooool00`00003o0000ooooo`3oooooo`7o0000
0@000001ooooo`006oooool01@00003ooooooooooooooooo000000cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo0@000001ooooo`006ooo
oooo000000D000000Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.987374, -0.319719, \
3.63465*^-5, 0.00383423}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot above waveform as a discrete-time sequence", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g2\  = 
        DiscreteListPlot[Take[sound1, {11000, 11100}], \ Blue, 
          PlotRange \[Rule] All, \ Frame \[Rule] True, \ 
          Axes \[Rule] {True, False}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-104.738 105.971 0.265853 1.00455 [
[.17362 -0.0125 -12 -9 ]
[.17362 -0.0125 12 0 ]
[.38556 -0.0125 -15 -9 ]
[.38556 -0.0125 15 0 ]
[.5975 -0.0125 -15 -9 ]
[.5975 -0.0125 15 0 ]
[.80945 -0.0125 -15 -9 ]
[.80945 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06494 -24 -4.5 ]
[-0.0125 .06494 0 4.5 ]
[-0.0125 .1654 -24 -4.5 ]
[-0.0125 .1654 0 4.5 ]
[-0.0125 .26585 -6 -4.5 ]
[-0.0125 .26585 0 4.5 ]
[-0.0125 .36631 -18 -4.5 ]
[-0.0125 .36631 0 4.5 ]
[-0.0125 .46676 -18 -4.5 ]
[-0.0125 .46676 0 4.5 ]
[-0.0125 .56722 -18 -4.5 ]
[-0.0125 .56722 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17362 0 m
.17362 .00625 L
s
[(0.99)] .17362 -0.0125 0 1 Mshowa
.38556 0 m
.38556 .00625 L
s
[(0.992)] .38556 -0.0125 0 1 Mshowa
.5975 0 m
.5975 .00625 L
s
[(0.994)] .5975 -0.0125 0 1 Mshowa
.80945 0 m
.80945 .00625 L
s
[(0.996)] .80945 -0.0125 0 1 Mshowa
.125 Mabswid
.2266 0 m
.2266 .00375 L
s
.27959 0 m
.27959 .00375 L
s
.33258 0 m
.33258 .00375 L
s
.43855 0 m
.43855 .00375 L
s
.49153 0 m
.49153 .00375 L
s
.54452 0 m
.54452 .00375 L
s
.65049 0 m
.65049 .00375 L
s
.70348 0 m
.70348 .00375 L
s
.75646 0 m
.75646 .00375 L
s
.12063 0 m
.12063 .00375 L
s
.06765 0 m
.06765 .00375 L
s
.01466 0 m
.01466 .00375 L
s
.86243 0 m
.86243 .00375 L
s
.91542 0 m
.91542 .00375 L
s
.9684 0 m
.9684 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06494 m
.00625 .06494 L
s
[(-0.2)] -0.0125 .06494 1 0 Mshowa
0 .1654 m
.00625 .1654 L
s
[(-0.1)] -0.0125 .1654 1 0 Mshowa
0 .26585 m
.00625 .26585 L
s
[(0)] -0.0125 .26585 1 0 Mshowa
0 .36631 m
.00625 .36631 L
s
[(0.1)] -0.0125 .36631 1 0 Mshowa
0 .46676 m
.00625 .46676 L
s
[(0.2)] -0.0125 .46676 1 0 Mshowa
0 .56722 m
.00625 .56722 L
s
[(0.3)] -0.0125 .56722 1 0 Mshowa
.125 Mabswid
0 .08503 m
.00375 .08503 L
s
0 .10512 m
.00375 .10512 L
s
0 .12522 m
.00375 .12522 L
s
0 .14531 m
.00375 .14531 L
s
0 .18549 m
.00375 .18549 L
s
0 .20558 m
.00375 .20558 L
s
0 .22567 m
.00375 .22567 L
s
0 .24576 m
.00375 .24576 L
s
0 .28594 m
.00375 .28594 L
s
0 .30603 m
.00375 .30603 L
s
0 .32613 m
.00375 .32613 L
s
0 .34622 m
.00375 .34622 L
s
0 .3864 m
.00375 .3864 L
s
0 .40649 m
.00375 .40649 L
s
0 .42658 m
.00375 .42658 L
s
0 .44667 m
.00375 .44667 L
s
0 .48685 m
.00375 .48685 L
s
0 .50694 m
.00375 .50694 L
s
0 .52704 m
.00375 .52704 L
s
0 .54713 m
.00375 .54713 L
s
0 .04485 m
.00375 .04485 L
s
0 .02476 m
.00375 .02476 L
s
0 .00467 m
.00375 .00467 L
s
0 .58731 m
.00375 .58731 L
s
0 .6074 m
.00375 .6074 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.17362 .61178 m
.17362 .61803 L
s
.38556 .61178 m
.38556 .61803 L
s
.5975 .61178 m
.5975 .61803 L
s
.80945 .61178 m
.80945 .61803 L
s
.125 Mabswid
.2266 .61428 m
.2266 .61803 L
s
.27959 .61428 m
.27959 .61803 L
s
.33258 .61428 m
.33258 .61803 L
s
.43855 .61428 m
.43855 .61803 L
s
.49153 .61428 m
.49153 .61803 L
s
.54452 .61428 m
.54452 .61803 L
s
.65049 .61428 m
.65049 .61803 L
s
.70348 .61428 m
.70348 .61803 L
s
.75646 .61428 m
.75646 .61803 L
s
.12063 .61428 m
.12063 .61803 L
s
.06765 .61428 m
.06765 .61803 L
s
.01466 .61428 m
.01466 .61803 L
s
.86243 .61428 m
.86243 .61803 L
s
.91542 .61428 m
.91542 .61803 L
s
.9684 .61428 m
.9684 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06494 m
1 .06494 L
s
.99375 .1654 m
1 .1654 L
s
.99375 .26585 m
1 .26585 L
s
.99375 .36631 m
1 .36631 L
s
.99375 .46676 m
1 .46676 L
s
.99375 .56722 m
1 .56722 L
s
.125 Mabswid
.99625 .08503 m
1 .08503 L
s
.99625 .10512 m
1 .10512 L
s
.99625 .12522 m
1 .12522 L
s
.99625 .14531 m
1 .14531 L
s
.99625 .18549 m
1 .18549 L
s
.99625 .20558 m
1 .20558 L
s
.99625 .22567 m
1 .22567 L
s
.99625 .24576 m
1 .24576 L
s
.99625 .28594 m
1 .28594 L
s
.99625 .30603 m
1 .30603 L
s
.99625 .32613 m
1 .32613 L
s
.99625 .34622 m
1 .34622 L
s
.99625 .3864 m
1 .3864 L
s
.99625 .40649 m
1 .40649 L
s
.99625 .42658 m
1 .42658 L
s
.99625 .44667 m
1 .44667 L
s
.99625 .48685 m
1 .48685 L
s
.99625 .50694 m
1 .50694 L
s
.99625 .52704 m
1 .52704 L
s
.99625 .54713 m
1 .54713 L
s
.99625 .04485 m
1 .04485 L
s
.99625 .02476 m
1 .02476 L
s
.99625 .00467 m
1 .00467 L
s
.99625 .58731 m
1 .58731 L
s
.99625 .6074 m
1 .6074 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .26585 m
1 .26585 L
s
0 0 1 r
.5 Mabswid
.02381 .26585 m
.02381 .32079 L
s
.03333 .26585 m
.03333 .11674 L
s
.04286 .26585 m
.04286 .21092 L
s
.05238 .26585 m
.05238 .17952 L
s
.0619 .26585 m
.0619 .26585 L
s
.07143 .26585 m
.07143 .36788 L
s
.08095 .26585 m
.08095 .35218 L
s
.09048 .26585 m
.09048 .35218 L
s
.1 .26585 m
.1 .29724 L
s
.10952 .26585 m
.10952 .18737 L
s
.11905 .26585 m
.11905 .15598 L
s
.12857 .26585 m
.12857 .15598 L
s
.1381 .26585 m
.1381 .258 L
s
.14762 .26585 m
.14762 .55623 L
s
.15714 .26585 m
.15714 .39142 L
s
.16667 .26585 m
.16667 .14813 L
s
.17619 .26585 m
.17619 .26585 L
s
.18571 .26585 m
.18571 .23446 L
s
.19524 .26585 m
.19524 .19522 L
s
.20476 .26585 m
.20476 .20307 L
s
.21429 .26585 m
.21429 .24231 L
s
.22381 .26585 m
.22381 .37573 L
s
.23333 .26585 m
.23333 .33649 L
s
.24286 .26585 m
.24286 .19522 L
s
.25238 .26585 m
.25238 .21876 L
s
.2619 .26585 m
.2619 .16383 L
s
.27143 .26585 m
.27143 .20307 L
s
.28095 .26585 m
.28095 .60332 L
s
.29048 .26585 m
.29048 .31294 L
s
.3 .26585 m
.3 .0775 L
s
.30952 .26585 m
.30952 .31294 L
s
.31905 .26585 m
.31905 .17168 L
s
.32857 .26585 m
.32857 .258 L
s
.3381 .26585 m
.3381 .26585 L
s
.34762 .26585 m
.34762 .15598 L
s
.35714 .26585 m
.35714 .32079 L
s
.36667 .26585 m
.36667 .29724 L
s
.37619 .26585 m
.37619 .19522 L
s
.38571 .26585 m
.38571 .25016 L
s
.39524 .26585 m
.39524 .15598 L
s
.40476 .26585 m
.40476 .40712 L
s
.41429 .26585 m
.41429 .54838 L
s
.42381 .26585 m
.42381 .03041 L
s
.43333 .26585 m
.43333 .20307 L
s
.44286 .26585 m
.44286 .2737 L
s
.45238 .26585 m
.45238 .14813 L
s
.4619 .26585 m
.4619 .38357 L
s
.47143 .26585 m
.47143 .258 L
s
.48095 .26585 m
.48095 .21092 L
s
.49048 .26585 m
.49048 .33649 L
s
.5 .26585 m
.5 .17952 L
s
.50952 .26585 m
.50952 .16383 L
s
.51905 .26585 m
.51905 .258 L
s
.52857 .26585 m
.52857 .2894 L
s
.5381 .26585 m
.5381 .50914 L
s
.54762 .26585 m
.54762 .45421 L
s
.55714 .26585 m
.55714 .0932 L
s
.56667 .26585 m
.56667 .16383 L
s
.57619 .26585 m
.57619 .258 L
s
.58571 .26585 m
.58571 .28155 L
s
.59524 .26585 m
.59524 .2737 L
s
.60476 .26585 m
.60476 .24231 L
s
.61429 .26585 m
.61429 .35218 L
s
.62381 .26585 m
.62381 .34433 L
s
.63333 .26585 m
.63333 .21092 L
s
.64286 .26585 m
.64286 .26585 L
s
.65238 .26585 m
.65238 .23446 L
s
.6619 .26585 m
.6619 .2737 L
s
.67143 .26585 m
.67143 .50129 L
s
.68095 .26585 m
.68095 .17952 L
s
.69048 .26585 m
.69048 .14813 L
s
.7 .26585 m
.7 .32864 L
s
.70952 .26585 m
.70952 .22661 L
s
.71905 .26585 m
.71905 .22661 L
s
.72857 .26585 m
.72857 .28155 L
s
.7381 .26585 m
.7381 .28155 L
s
.74762 .26585 m
.74762 .25016 L
s
.75714 .26585 m
.75714 .36003 L
s
.76667 .26585 m
.76667 .30509 L
s
.77619 .26585 m
.77619 .14813 L
s
.78571 .26585 m
.78571 .17168 L
s
.79524 .26585 m
.79524 .21092 L
s
.80476 .26585 m
.80476 .31294 L
s
.81429 .26585 m
.81429 .50914 L
s
.82381 .26585 m
.82381 .24231 L
s
.83333 .26585 m
.83333 .16383 L
s
.84286 .26585 m
.84286 .32864 L
s
.85238 .26585 m
.85238 .20307 L
s
.8619 .26585 m
.8619 .18737 L
s
.87143 .26585 m
.87143 .18737 L
s
.88095 .26585 m
.88095 .24231 L
s
.89048 .26585 m
.89048 .32864 L
s
.9 .26585 m
.9 .258 L
s
.90952 .26585 m
.90952 .21092 L
s
.91905 .26585 m
.91905 .24231 L
s
.92857 .26585 m
.92857 .12459 L
s
.9381 .26585 m
.9381 .37573 L
s
.94762 .26585 m
.94762 .55623 L
s
.95714 .26585 m
.95714 .01472 L
s
.96667 .26585 m
.96667 .18737 L
s
.97619 .26585 m
.97619 .33649 L
s
.015 w
.02381 .32079 Mdot
.03333 .11674 Mdot
.04286 .21092 Mdot
.05238 .17952 Mdot
.0619 .26585 Mdot
.07143 .36788 Mdot
.08095 .35218 Mdot
.09048 .35218 Mdot
.1 .29724 Mdot
.10952 .18737 Mdot
.11905 .15598 Mdot
.12857 .15598 Mdot
.1381 .258 Mdot
.14762 .55623 Mdot
.15714 .39142 Mdot
.16667 .14813 Mdot
.17619 .26585 Mdot
.18571 .23446 Mdot
.19524 .19522 Mdot
.20476 .20307 Mdot
.21429 .24231 Mdot
.22381 .37573 Mdot
.23333 .33649 Mdot
.24286 .19522 Mdot
.25238 .21876 Mdot
.2619 .16383 Mdot
.27143 .20307 Mdot
.28095 .60332 Mdot
.29048 .31294 Mdot
.3 .0775 Mdot
.30952 .31294 Mdot
.31905 .17168 Mdot
.32857 .258 Mdot
.3381 .26585 Mdot
.34762 .15598 Mdot
.35714 .32079 Mdot
.36667 .29724 Mdot
.37619 .19522 Mdot
.38571 .25016 Mdot
.39524 .15598 Mdot
.40476 .40712 Mdot
.41429 .54838 Mdot
.42381 .03041 Mdot
.43333 .20307 Mdot
.44286 .2737 Mdot
.45238 .14813 Mdot
.4619 .38357 Mdot
.47143 .258 Mdot
.48095 .21092 Mdot
.49048 .33649 Mdot
.5 .17952 Mdot
.50952 .16383 Mdot
.51905 .258 Mdot
.52857 .2894 Mdot
.5381 .50914 Mdot
.54762 .45421 Mdot
.55714 .0932 Mdot
.56667 .16383 Mdot
.57619 .258 Mdot
.58571 .28155 Mdot
.59524 .2737 Mdot
.60476 .24231 Mdot
.61429 .35218 Mdot
.62381 .34433 Mdot
.63333 .21092 Mdot
.64286 .26585 Mdot
.65238 .23446 Mdot
.6619 .2737 Mdot
.67143 .50129 Mdot
.68095 .17952 Mdot
.69048 .14813 Mdot
.7 .32864 Mdot
.70952 .22661 Mdot
.71905 .22661 Mdot
.72857 .28155 Mdot
.7381 .28155 Mdot
.74762 .25016 Mdot
.75714 .36003 Mdot
.76667 .30509 Mdot
.77619 .14813 Mdot
.78571 .17168 Mdot
.79524 .21092 Mdot
.80476 .31294 Mdot
.81429 .50914 Mdot
.82381 .24231 Mdot
.83333 .16383 Mdot
.84286 .32864 Mdot
.85238 .20307 Mdot
.8619 .18737 Mdot
.87143 .18737 Mdot
.88095 .24231 Mdot
.89048 .32864 Mdot
.9 .258 Mdot
.90952 .21092 Mdot
.91905 .24231 Mdot
.92857 .12459 Mdot
.9381 .37573 Mdot
.94762 .55623 Mdot
.95714 .01472 Mdot
.96667 .18737 Mdot
.97619 .33649 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00?_ooool2o`0000Cooooo00?o0000ooooooooool0
0_ooool2o`0000Cooooo0_l0000Qooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0000?ooooo1Ol0000Looooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0000Gooooo0ol0000Looooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o0000
1?ooool2o`0000Cooooo0ol0000Vooooo`00?Oooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
01Wooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Sooooo`00?Ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000004o`0001_ooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool08oooool003gooooo00Co0000
oooooooooooo00002?ooool4o`0000;ooooo1?l0000Nooooo`04o`000?ooooooooooo`0000Sooooo
1?l00002ooooo`Co00001?ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000So
oooo1?l00002ooooo`Co000000Goooooo`000?ooooooooooo`00000Looooo`04o`000?oooooooooo
o`0000Sooooo1?l00002ooooo`Co000000?oooooo`000?l000000_l0000Vooooo`00?Oooool01?l0
003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo01cooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000
ooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo01Wooooo00Co0000
oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01_l0003o
ooooooooool0003oooooo`0001cooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooo
oooooooo0000ooooool000000oooool00ol0003oooooo`00000Yooooo`00?Oooool01?l0003ooooo
ooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo01cooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool0
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooo
oooo00001oooool01ol0003ooooooooooooooooo0000ooooool000000oooool01?l0003ooooooooo
ooooool2o`0001cooooo00Co0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000
ooooool000000oooool01?l0003oooooooooool0000Xooooo`00?_ooool2o`0000Wooooo0ol00003
ooooo`?o00008?ooool2o`0000Wooooo0ol00003ooooo`?o00000oooool3o`0001gooooo0_l00009
ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool06oooool2o`0000Wooooo0ol00003
ooooo`?o00001?ooool2o`0002Kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo000Kooooool000001@000001ooooo`006oooool01@00003o0000oooooooooooo
000000cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`0300000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00<00000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00`00003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`0300000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Cooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool0=?ooool00`00003oooooooooo`0dooooo`0300000?oooooooooo03Cooooo00<00000oooo
ooooool0;_ooool10000007ooooo000Kooooo`0300000?oooooooooo0?Cooooo0ol00?l9ooooo`40
00000Oooool001_ooooo00<00000ooooooooool0m?ooool3o`00o`Wooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`3dooooo`?o003o2Oooool10000007ooooo000Kooooo`0300000?l0003o
oooo0?Gooooo00<0003oooooooooool01oooool1o`00004000000Oooool001_ooooo00<00000oooo
ooooool0JOooool3o`00ohWooooo00<0003oooooooooool02?ooool10000007ooooo000Kooooo`03
00000?oooooooooo06Wooooo0ol00?n9ooooo`030000oooooooooooo00Sooooo0@000001ooooo`00
6oooool00`00003oooooooooo`1Yooooo`?o003oROooool00`000?ooooooooooo`08ooooo`400000
0Oooool001_ooooo00<00000ooooooooool0Joooool00`000?ooooooooooo`27ooooo`030000oooo
oooooooo00Sooooo0@000001ooooo`006oooool00`00003oooooooooo`1[ooooo`030000oooooooo
oooo08Oooooo00<0003oooooooooool02?ooool10000007ooooo000Kooooo`0300000?l0003ooooo
06_ooooo00<0003oooooooooool0Qoooool00`000?ooooooooooo`07ooooo`7o00000@000001oooo
o`006oooool00`00003oooooooooo`1[ooooo`030000oooooooooooo08Oooooo00<0003ooooooooo
ool02?ooool10000007ooooo0008ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Co
oooo00<00000ooooooooool0Joooool00`000?ooooooooooo`27ooooo`030000oooooooooooo00So
oooo0@000001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool0Joooool00`000?ooooooooooo`27ooooo`030000oooooooooooo
00Sooooo0@000001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01?ooool00`00003oooooooooo`1[ooooo`030000oooooooooooo08Oooooo00<0003ooooo
ooooool02?ooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool00oooool00`00003o0000ooooo`1[ooooo`030000oooooooooooo08Oooooo00<0003ooooo
ooooool01oooool1o`00004000000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00<00000ooooooooool0Joooool00`000?ooooooooooo`27
ooooo`030000oooooooooooo00Sooooo0@000001ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00`00003oooooooooo`19ooooo`?o003o7ooo
ool00`000?ooooooooooo`27ooooo`030000oooooooooooo00Sooooo0@000001ooooo`002?ooool2
o`0000Wooooo0ol00005ooooo`0300000?oooooooooo04Wooooo0ol00?lOooooo`030000oooooooo
oooo08Oooooo00<0003oooooooooool02?ooool10000007ooooo000Kooooo`0300000?oooooooooo
04Wooooo0ol00?lOooooo`030000oooooooooooo08Oooooo00<0003oooooooooool02?ooool10000
007ooooo000Kooooo`0300000?l0003ooooo04_ooooo00<0003oooooooooool07Oooool00`000?oo
ooooooooo`27ooooo`030000oooooooooooo00Oooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo04_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`27ooooo`030000
oooooooooooo00Sooooo0@000001ooooo`006oooool00`00003oooooooooo`1;ooooo`030000oooo
oooooooo01gooooo00<0003oooooooooool07_ooool3o`00ofKooooo00<0003oooooooooool02?oo
ool10000007ooooo000Kooooo`0300000?oooooooooo04_ooooo00<0003oooooooooool07Oooool0
0`000?ooooooooooo`0Nooooo`?o003oI_ooool00`000?ooooooooooo`08ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0Boooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo
01kooooo0ol00?mVooooo`030000oooooooooooo00Sooooo0@000001ooooo`006oooool00`00003o
0000ooooo`1;ooooo`030000oooooooooooo01gooooo00<0003oooooooooool07oooool00`000?oo
ooooooooo`1Uooooo`030000oooooooooooo00Oooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo04_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Oooooo`030000
oooooooooooo06Gooooo00<0003oooooooooool02?ooool10000007ooooo000Kooooo`0300000?oo
oooooooo04_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Oooooo`030000oooo
oooooooo06Gooooo00<0003oooooooooool02?ooool10000007ooooo000Kooooo`0300000?oooooo
oooo00Cooooo0ol00?m4ooooo`030000oooooooooooo01gooooo00<0003oooooooooool07oooool0
0`000?ooooooooooo`1Uooooo`030000oooooooooooo00Sooooo0@000001ooooo`006oooool00`00
003oooooooooo`04ooooo`?o003oA?ooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo
01oooooo00<0003oooooooooool0IOooool00`000?ooooooooooo`08ooooo`4000000Oooool001_o
oooo00<00000o`000?ooool01?ooool3o`00odCooooo00<0003oooooooooool07Oooool00`000?oo
ooooooooo`0Oooooo`030000oooooooooooo05cooooo0ol00?l6ooooo`030000oooooooooooo00Oo
oooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00Gooooo00<0003oooooooooool0
@oooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01oooooo00<0003oooooooooool0
G?ooool3o`00o`Kooooo00<0003oooooooooool02?ooool10000007ooooo000Kooooo`0300000?oo
oooooooo00Gooooo00<0003oooooooooool0@oooool00`000?ooooooooooo`0Mooooo`030000oooo
oooooooo01oooooo00<0003oooooooooool0G?ooool3o`00o`Kooooo00<0003oooooooooool02?oo
ool10000007ooooo000Kooooo`0300000?oooooooooo00Gooooo00<0003oooooooooool0@oooool0
0`000?ooooooooooo`0Mooooo`030000oooooooooooo01oooooo00<0003oooooooooool0G_ooool0
0`000?ooooooooooo`04ooooo`030000oooooooooooo00Sooooo0@000001ooooo`006oooool00`00
003oooooooooo`05ooooo`030000oooooooooooo04?ooooo00<0003oooooooooool07Oooool00`00
0?ooooooooooo`0Oooooo`030000oooooooooooo05kooooo00<0003oooooooooool01?ooool00`00
0?ooooooooooo`08ooooo`4000000Oooool001_ooooo00<00000ooooooooool01Oooool00`000?oo
ooooooooo`13ooooo`030000oooooooooooo01gooooo00<0003oooooooooool07oooool00`000?oo
ooooooooo`1Nooooo`030000oooooooooooo00Cooooo00<0003oooooooooool02?ooool10000007o
oooo000Kooooo`0300000?l0003ooooo00Gooooo00<0003oooooooooool07oooool3o`00ob7ooooo
00<0003oooooooooool07Oooool00`000?ooooooooooo`03ooooo`?o003o6Oooool00`000?oooooo
ooooo`0Oooooo`?o003o4oooool3o`00obKooooo00<0003oooooooooool01?ooool00`000?oooooo
ooooo`07ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`05ooooo`030000oooo
oooooooo01oooooo0ol00?lQooooo`030000oooooooooooo01gooooo00<0003oooooooooool00ooo
ool3o`00oaWooooo00<0003oooooooooool07oooool3o`00oa?ooooo0ol00?lVooooo`030000oooo
oooooooo00Cooooo00<0003oooooooooool02?ooool10000007ooooo0008ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`?o00001Oooool00`00003oooooooooo`05ooooo`030000oooooooo
oooo01;ooooo1_l00?l7ooooo`?o003o8Oooool00`000?ooooooooooo`08ooooo`?o003o2Oooool3
o`00o`Kooooo00<0003oooooooooool00oooool3o`00oaWooooo00<0003oooooooooool07oooool3
o`00oa?ooooo0ol00?lVooooo`030000oooooooooooo00Cooooo00<0003oooooooooool02?ooool1
0000007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool0
0`00003oooooooooo`05ooooo`030000oooooooooooo01;ooooo1_l00?l8ooooo`030000oooooooo
oooo023ooooo00<0003oooooooooool02?ooool3o`00o`Wooooo0ol00?l6ooooo`030000oooooooo
oooo00Cooooo00<0003oooooooooool06?ooool00`000?ooooooooooo`0Pooooo`030000oooooooo
oooo01?ooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`04ooooo`030000oooooooo
oooo00Sooooo0@000001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01?ooool00`00003oooooooooo`05ooooo`030000oooooooooooo01;ooooo1_l00?l8
ooooo`030000oooooooooooo01Cooooo0ol00?l9ooooo`030000oooooooooooo00Sooooo0ol00?l9
ooooo`?o003o1_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00_ooooo0ol00?l:
ooooo`040000ool00?oo003oo`00oaoooooo00<0003oooooooooool04oooool00`000?oooooooooo
o`0;ooooo`?o003o5oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Sooooo0@00
0001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<0
0000o`000?ooool01Oooool00`000?ooooooooooo`0Dooooo`030000ooooool0003o00Wooooo00<0
003oooooooooool05?ooool3o`00o`Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool01?ooool00`000?oooooooooo
o`0;ooooo`?o003o2_ooool010000?oo003oo`00ool00?lOooooo`030000oooooooooooo01?ooooo
00<0003oooooooooool02oooool3o`00oaOooooo00<0003oooooooooool01?ooool00`000?oooooo
ooooo`07ooooo`7o00000@000001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Cooooo00<00000ooooooooool01Oooool00`000?ooooooooooo`0Dooooo`030000
ooooool0003o00Wooooo00<0003oooooooooool05?ooool3o`00o`Wooooo00<0003oooooooooool0
0ol00?l6ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool01Oooool00`000?oooooo
ooooo`04ooooo`030000oooooooooooo00_ooooo0ol00?l:ooooo`040000ool00?oo003oo`00oaoo
oooo00<0003oooooooooool04oooool010000?oo003oo`00ool00?l:ooooo`?o003o5oooool00`00
0?ooooooooooo`04ooooo`030000oooooooooooo00Sooooo0@000001ooooo`001oooool01?l0003o
ooooooooool00008ooooo`;o00001_ooool00`00003oooooooooo`05ooooo`030000oooooooooooo
01Cooooo00<0003oooooo`000?l02Oooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo
00Oooooo00<0003oooooooooool00ol00?l6ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool01Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00cooooo00<0003ooooo
ooooool02Oooool010000?ooooooooooo`000?lOooooo`030000oooooooooooo01?ooooo00@0003o
o`00ool00?oo003o2oooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo00Cooooo00<0
003oooooooooool02?ooool10000007ooooo0008ooooo`;o00002_ooool00ol0003oooooooooo`04
ooooo`0300000?oooooooooo00Gooooo00@0003ooooooooooooooooo0ol00?l@ooooo`030000oooo
ool0003o00Wooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`07ooooo`030000oooo
oooooooo00?o003o1_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Gooooo00<0
003oooooooooool01?ooool00`000?ooooooooooo`08ooooo`?o003o00?ooooo0000ooooool02_oo
ool010000?ooooooooooo`000?lKooooo`?o003o00?ooooo0000ooooool05?ooool010000?oo003o
o`00ool00?l;ooooo`030000oooooooooooo01Kooooo00<0003oooooooooool01?ooool00`000?oo
ooooooooo`08ooooo`4000000Oooool001_ooooo00<00000ooooooooool01Oooool010000?oooooo
ooooooooool3o`00oa3ooooo00<0003oooooo`000?l02Oooool00`000?ooooooooooo`0Fooooo`03
0000oooooooooooo00Oooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`04ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`04ooooo`03
0000oooooooooooo00Sooooo0ol00?l00oooool0003oooooo`0:ooooo`040000oooooooooooo0000
oa_ooooo0ol00?l00oooool0003oooooo`0Dooooo`040000oooooooooooo0000o`_ooooo00<0003o
ooooooooool05_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Sooooo0@000001
ooooo`006oooool00`00003o0000ooooo`05ooooo`040000ooooooooooooooooo`?o003o3?ooool3
o`00o`04ooooo`000?oooooo0000o`Wooooo00<0003oooooooooool05_ooool00`000?oooooooooo
o`07ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool01?ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool01?ooool00`000?oooooooooo
o`08ooooo`?o003o00?ooooo0000ooooool02_ooool010000?ooooooooooo`000?lKooooo`?o003o
00?ooooo0000ooooool05?ooool010000?ooooooooooo`000?l;ooooo`030000oooooooooooo00?o
oooo1_l00?l=ooooo`030000oooooooooooo00Cooooo00@0003oo`00ool00?oo003o1_ooool1o`00
004000000Oooool001_ooooo00<00000ooooooooool01Oooool00`000?ooooooooooo`02ooooo`03
0000oooooooooooo00_ooooo0ol00?l01?ooool0003oooooo`000?l9ooooo`030000oooooooooooo
01Kooooo00<0003oooooooooool01oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo
00Cooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo
00Cooooo00<0003oooooooooool02_ooool00`000?oooooo0000o`0;ooooo`040000oooooooooooo
0000oagooooo00<0003oooooo`000?l05Oooool010000?ooooooooooo`000?l;ooooo`030000oooo
oooooooo00?ooooo1_l00?l=ooooo`030000oooooooooooo00Cooooo00@0003oo`00ool00?oo003o
1oooool10000007ooooo000Kooooo`0300000?oooooooooo00Gooooo00<0003oooooooooool00_oo
ool00`000?ooooooooooo`0;ooooo`?o003o00Cooooo0000ooooool0003o2Oooool00`000?oooooo
ooooo`03ooooo`?o003o2Oooool3o`00o`Cooooo00<0003oooooooooool01oooool00`000?oooooo
ooooo`02ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool00oooool3o`00o`?ooooo
00<0003oooooooooool01Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00[ooooo
00<0003oooooo`000?l02oooool010000?ooooooooooo`000?lMooooo`030000ooooool0003o01Go
oooo00@0003oooooooooool0003o2oooool00`000?ooooooooooo`03ooooo`Ko003o3Oooool00`00
0?ooooooooooo`04ooooo`040000ool00?oo003oo`00o`Oooooo0@000001ooooo`006oooool00`00
003oooooooooo`05ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool03?ooool01P00
0?ooooooooooo`000?oooooo0000o`Wooooo00<0003oooooooooool00oooool3o`00o`Wooooo0ol0
0?l4ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool00_ooool00`000?oooooooooo
o`04ooooo`030000oooooooooooo00?ooooo0ol00?l3ooooo`030000oooooooooooo00Gooooo00<0
003oooooooooool01?ooool00`000?ooooooooooo`0:ooooo`030000ooooool0003o00_ooooo00@0
003oooooooooool0003o7Oooool00`000?oooooo0000o`0Eooooo`040000oooooooooooo0000o`_o
oooo00<0003oooooooooool01Oooool00`000?oooooo0000o`0>ooooo`030000oooooooooooo00Co
oooo00@0003oooooooooool0003o1oooool10000007ooooo000Kooooo`0300000?oooooooooo00Go
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0<ooooo`060000oooooooooooo0000
ooooool0003o2Oooool00`000?ooooooooooo`03ooooo`Go003o1oooool3o`00o`Cooooo00@0003o
o`00ool00?oo003o1_ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00Cooooo00<0
003oooooooooool00oooool3o`00o`?ooooo00<0003oooooooooool01Oooool010000?oo003oo`00
ool00?l3ooooo`030000oooooooooooo00[ooooo00<0003oooooo`000?l02oooool010000?oooooo
ooooo`000?lMooooo`030000ooooool0003o01Gooooo00@0003oooooooooool0003o2oooool01000
0?ooooooooooooooool3o`00o`04ooooo`000?oooooo0000o`kooooo00<0003oooooooooool01?oo
ool010000?ooooooooooo`000?l7ooooo`4000000Oooool001_ooooo00<00000o`000?ooool01Ooo
ool00`000?ooooooooooo`02ooooo`030000oooooooooooo00cooooo00H0003oooooooooool0003o
ooooo`000?l9ooooo`030000oooooooooooo00Cooooo00@0003oo`00ool00?oo003o2Oooool00`00
0?ooooooooooo`02ooooo`040000ool00?oo003oo`00o`Kooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`04ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`05ooooo`040000ool00?oo003oo`00o`?ooooo00<0003oooooooooool02_oo
ool00`000?oooooo0000o`0;ooooo`040000oooooooooooo0000oagooooo00<0003oooooo`000?l0
5Oooool010000?ooooooooooo`000?l;ooooo`040000ooooooooooooooooo`?o003o00Cooooo0000
ooooool0003o3_ooool00`000?ooooooooooo`04ooooo`040000oooooooooooo0000o`Kooooo0Ol0
00010000007ooooo000Kooooo`0300000?oooooooooo00Gooooo00H0003oo`00ool00?oo003ooooo
o`000?l>ooooo`060000oooooooooooo0000ooooool0003o2Oooool00`000?ooooooooooo`04oooo
o`040000ool00?oo003oo`00o`Wooooo00<0003oooooooooool00_ooool010000?oo003oo`00ool0
0?l6ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool01?ooool00`000?oooooooooo
o`04ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool01Oooool010000?oo003oo`00
ool00?l3ooooo`030000oooooooooooo00?ooooo0ol00?l4ooooo`030000ooooool0003o00_ooooo
00@0003oooooooooool0003o3oooool3o`00o`_ooooo00<0003oooooo`000?l05Oooool010000?oo
ooooooooo`000?l3o`00o`Sooooo00@0003ooooooooooooooooo0ol00?l01?ooool0003oooooo`00
0?l7ooooo`?o003o1?ooool00`000?ooooooooooo`04ooooo`040000oooooooooooo0000o`Oooooo
0@000001ooooo`006oooool00`00003oooooooooo`05ooooo`060000ool00?oo003oo`00ooooool0
003o3_ooool01P000?ooooooooooo`000?oooooo0000o`Wooooo00<0003oooooooooool01?ooool0
10000?ooooooooooo`000?l9ooooo`030000oooooooooooo00;ooooo00<0003oooooo`000?l01ooo
ool00`000?ooooooooooo`02ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool01?oo
ool00`000?ooooooooooo`02ooooo`030000oooooooooooo00Gooooo00<0003oooooo`000?l01?oo
ool00`000?ooooooooooo`03ooooo`?o003o1?ooool00`000?oooooo0000o`0;ooooo`040000oooo
oooooooo0000o`oooooo0ol00?l;ooooo`030000ooooool0003o01Gooooo00@0003oooooooooool0
003o0ol00?l8ooooo`030000oooooooooooo00;ooooo00H0003oooooooooool0003oooooo`000?l7
ooooo`?o003o1?ooool00`000?ooooooooooo`04ooooo`040000oooooooooooo0000o`Oooooo0@00
0001ooooo`006oooool00`00003oooooooooo`05ooooo`060000ool00?oo003oo`00ooooool0003o
3_ooool01P000?ooooooooooo`000?oooooo0000o`Wooooo00<0003oooooooooool01?ooool01000
0?ooooooooooo`000?l9ooooo`080000ool00?oo003oo`00ooooool0003oooooo`000?l7ooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`04ooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool01Oooool00`000?oooooo0000o`04ooooo`03
0000oooooooooooo00?ooooo0ol00?l4ooooo`030000ooooool0003o00_ooooo00@0003ooooooooo
ool0003o3oooool3o`00o`_ooooo00<0003oooooo`000?l05Oooool010000?ooooooooooo`000?l3
o`00o`Sooooo00<0003oooooooooool00_ooool01P000?ooooooooooo`000?oooooo0000o`Oooooo
0ol00?l4ooooo`030000oooooooooooo00Cooooo00@0003oooooooooool0003o1oooool10000007o
oooo000Kooooo`0300000?oooooooooo00Gooooo00H0003oooooooooool0003oooooo`000?l>oooo
o`060000oooooooooooo0000ooooool0003o2Oooool00`000?ooooooooooo`04ooooo`040000oooo
oooooooo0000o`Wooooo00P0003oo`00ool00?oo003oooooo`000?oooooo0000o`Oooooo00<0003o
ooooooooool00_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Cooooo00<0003o
ooooooooool00_ooool00`000?ooooooooooo`05ooooo`030000ooooool0003o00Cooooo00<0003o
ooooooooool01Oooool00`000?ooooooooooo`02ooooo`030000ooooool0003o00_ooooo00@0003o
ooooooooool0003o4?ooool00`000?ooooooooooo`0:ooooo`030000ooooool0003o01Gooooo00H0
003oooooooooool0003oooooo`000?l9ooooo`030000oooooooooooo00;ooooo00H0003ooooooooo
ool0003oooooo`000?l9ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool01?ooool0
10000?ooooooooooo`000?l7ooooo`4000000Oooool001_ooooo00<00000ooooooooool01Oooool0
1P000?ooooooooooo`000?oooooo0000o`kooooo00H0003oooooooooool0003oooooo`000?l9oooo
o`030000oooooooooooo00Cooooo00@0003oooooooooool0003o2Oooool020000?oo003oo`00ool0
0?oooooo0000ooooool0003o1oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00Co
oooo00<0003oooooooooool01?ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00Go
oooo00<0003oooooo`000?l01?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00;o
oooo00<0003oooooo`000?l02oooool010000?ooooooooooo`000?l@ooooo`030000oooooooooooo
00[ooooo00<0003oooooo`000?l00oooool5o`00o`gooooo00H0003oooooooooool0003oooooo`00
0?l9ooooo`030000oooooooooooo00;ooooo00H0003oooooooooool0003oooooo`000?l9ooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool01?ooool010000?ooooooooooo`000?l7oooo
o`4000000Oooool001_ooooo00<00000o`000?ooool01Oooool01P000?ooooooooooo`000?oooooo
0000o`kooooo00H0003oooooooooool0003oooooo`000?l9ooooo`030000oooooooooooo00Cooooo
00@0003oooooooooool0003o2Oooool00`000?oooooo0000o`02ooooo`030000ooooool0003o00Oo
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Co
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`05ooooo`030000ooooool0003o00Co
oooo00<0003oooooooooool01Oooool00`000?ooooooooooo`02ooooo`030000ooooool0003o00_o
oooo00@0003oooooooooool0003o4?ooool00`000?ooooooooooo`0:ooooo`030000ooooool0003o
00?ooooo1Ol00?l=ooooo`060000oooooooooooo0000ooooool0003o2Oooool00`000?oooooooooo
o`02ooooo`060000oooooooooooo0000ooooool0003o2Oooool00`000?ooooooooooo`02ooooo`03
0000oooooooooooo00Cooooo00@0003oooooooooool0003o1_ooool1o`00004000000Oooool001_o
oooo00<00000ooooooooool01Oooool01P000?ooooooooooo`000?oooooo0000o`kooooo00H0003o
ooooooooool0003oooooo`000?l9ooooo`040000ooooooooooooooooo`?o003o00@0003ooooooooo
ool0003o2Oooool00`000?oooooo0000o`02ooooo`030000ooooool0003o00Oooooo00<0003ooooo
ooooool00_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Cooooo00<0003ooooo
ooooool00_ooool00`000?ooooooooooo`05ooooo`030000ooooool0003o00Cooooo00<0003ooooo
ooooool01Oooool00`000?ooooooooooo`02ooooo`030000ooooool0003o00_ooooo00@0003ooooo
ooooool0003o4?ooool010000?ooooooooooooooool3o`00o`Kooooo00<0003oooooo`000?l00ooo
ool5o`00o`gooooo00H0003oooooooooool0003oooooo`000?l9ooooo`030000oooooooooooo00;o
oooo00H0003oooooooooool0003oooooo`000?l9ooooo`030000oooooooooooo00;ooooo00<0003o
ooooooooool01?ooool010000?ooooooooooo`000?l7ooooo`4000000Oooool001_ooooo00<00000
ooooooooool01Oooool01P000?ooooooooooo`000?oooooo0000o`kooooo00H0003oooooooooool0
003oooooo`000?l9ooooo`040000ooooooooooooooooo`?o003o00@0003oooooooooool0003o2Ooo
ool00`000?oooooo0000o`02ooooo`030000ooooool0003o00Oooooo00<0003oooooooooool00_oo
ool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool00_oo
ool00`000?ooooooooooo`05ooooo`030000ooooool0003o00Cooooo00<0003oooooooooool01Ooo
ool00`000?ooooooooooo`02ooooo`030000ooooool0003o00_ooooo00@0003oooooooooool0003o
4?ooool010000?ooooooooooooooool3o`00o`Kooooo00<0003oooooo`000?l01?ooool00`000?oo
oooo0000o`0>ooooo`060000oooooooooooo0000ooooool0003o2Oooool00`000?ooooooooooo`02
ooooo`060000oooooooooooo0000ooooool0003o2Oooool00`000?ooooooooooo`02ooooo`030000
oooooooooooo00Cooooo00@0003oooooooooool0003o1oooool10000007ooooo000Kooooo`030000
0?oooooooooo00Gooooo00H0003oooooooooool0003oooooo`000?l>ooooo`060000oooooooooooo
0000ooooool0003o2Oooool010000?ooooooooooooooool3o`00o`040000oooooooooooo0000o`?o
003o1_ooool00`000?oooooo0000o`02ooooo`030000ooooool0003o00Oooooo00<0003ooooooooo
ool00_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Cooooo00<0003ooooooooo
ool00_ooool00`000?ooooooooooo`05ooooo`030000ooooool0003o00Cooooo00<0003ooooooooo
ool01Oooool00`000?ooooooooooo`02ooooo`030000ooooool0003o00_ooooo00@0003ooooooooo
ool0003o1oooool3o`00o`Kooooo00@0003ooooooooooooooooo0ol00?l6ooooo`030000ooooool0
003o00Cooooo00<0003oooooo`000?l03_ooool01P000?ooooooooooo`000?oooooo0000o`Gooooo
0ol00?l00oooool0003oooooo`03ooooo`060000oooooooooooo0000ooooool0003o0ol00?l6oooo
o`060000ool00?oo003oo`00ooooool0003o1_ooool010000?ooooooooooo`000?l7ooooo`400000
0Oooool001_ooooo00<00000ooooooooool01Oooool01P000?ooooooooooo`000?oooooo0000o`ko
oooo00H0003oooooooooool0003oooooo`000?l9ooooo`030000oooooooooooo00;ooooo00<0003o
ooooo`000?l00_ooool010000?oo003oo`00ool00?l6ooooo`030000ooooool0003o00;ooooo00<0
003oooooo`000?l01oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00Cooooo00<0
003oooooooooool01?ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00Gooooo00<0
003oooooo`000?l01?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00;ooooo00<0
003oooooo`000?l02oooool010000?ooooooooooo`000?l7ooooo`?o003o1_ooool00`000?oooooo
ooooo`02ooooo`030000oooooooooooo00Gooooo00<0003oooooo`000?l01?ooool00`000?oooooo
0000o`0>ooooo`060000oooooooooooo0000ooooool0003o1Oooool3o`00o`03ooooo`000?oooooo
00?ooooo00H0003oooooooooool0003oooooo`000?l3o`00o`Kooooo00H0003oo`00ool00?oo003o
ooooo`000?l6ooooo`040000oooooooooooo0000o`Oooooo0@000001ooooo`006oooool00`00003o
0000ooooo`05ooooo`060000oooooooooooo0000ooooool0003o3_ooool01P000?ooooooooooo`00
0?oooooo0000o`Wooooo00<0003oooooooooool00_ooool00`000?oooooo0000o`02ooooo`040000
ool00?oo003oo`00o`Kooooo00<0003oooooo`000?l00_ooool00`000?oooooo0000o`07ooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`04ooooo`06
0000ool00?oo003oo`00ooooool0003o1oooool00`000?oooooo0000o`04ooooo`030000oooooooo
oooo00Gooooo00<0003oooooooooool00_ooool00`000?oooooo0000o`0;ooooo`040000oooooooo
oooo0000o`Oooooo0ol00?l6ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool01Ooo
ool00`000?oooooo0000o`04ooooo`030000ooooool0003o00Gooooo0ol00?l6ooooo`060000oooo
oooooooo0000ooooool0003o1Oooool3o`00o`03ooooo`000?oooooo00?ooooo00H0003ooooooooo
ool0003oooooo`000?l3o`00o`Kooooo00H0003oo`00ool00?oo003oooooo`000?l6ooooo`040000
oooooooooooo0000o`Kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00Gooooo
00H0003oooooooooool0003oooooo`000?l>ooooo`060000oooooooooooo0000ooooool0003o2Ooo
ool00`000?ooooooooooo`02ooooo`030000ooooool0003o00;ooooo00<0003oooooo`000?l01ooo
ool00`000?oooooo0000o`02ooooo`030000ooooool0003o00Oooooo00<0003oooooooooool00_oo
ool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Cooooo00H0003oo`00ool00?oo003o
ooooo`000?l7ooooo`030000ooooool0003o00Cooooo00<0003oooooooooool01Oooool00`000?oo
ooooooooo`02ooooo`030000ooooool0003o00_ooooo00@0003oooooooooool0003o2Oooool00`00
0?ooooooooooo`04ooooo`030000oooooooooooo00;ooooo00<0003oooooooooool01Oooool00`00
0?oooooo0000o`04ooooo`030000ooooool0003o00Gooooo0ol00?l6ooooo`060000oooooooooooo
0000ooooool0003o1oooool00`000?oooooo0000o`04ooooo`080000oooooooooooo0000ooooool0
003oooooo`000?l7ooooo`030000ooooool0003o00;ooooo00<0003oooooooooool01?ooool01000
0?ooooooooooo`000?l7ooooo`4000000Oooool001Cooooo0_l00005ooooo`0300000?oooooooooo
00Gooooo00H0003oooooooooool0003oooooo`000?l>ooooo`060000oooooooooooo0000ooooool0
003o0ol00?l6ooooo`030000oooooooooooo00;ooooo00<0003oooooo`000?l00_ooool00`000?oo
oooo0000o`07ooooo`030000ooooool0003o00;ooooo00<0003oooooo`000?l01oooool00`000?oo
ooooooooo`02ooooo`040000ool00?oo003oo`00o`?ooooo00<0003oooooooooool01?ooool01P00
0?oo003oo`00ool00?oooooo0000o`Oooooo00<0003oooooo`000?l01?ooool010000?oooooooooo
ooooool3o`00o`03ooooo`000?oooooo00?ooooo00<0003oooooo`000?l00ol00?l8ooooo`040000
oooooooooooo0000o`?o003o1_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00;o
oooo00<0003oooooooooool01Oooool00`000?oooooo0000o`04ooooo`030000ooooool0003o00Go
oooo0ol00?l6ooooo`060000oooooooooooo0000ooooool0003o1oooool00`000?oooooo0000o`04
ooooo`080000oooooooooooo0000ooooool0003oooooo`000?l3ooooo`?o003o00Cooooo0000oooo
ool0003o0_ooool00`000?ooooooooooo`04ooooo`040000oooooooooooo0000o`Oooooo0@000001
ooooo`004oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Gooooo00H0003o
ooooooooool0003oooooo`000?l>ooooo`060000oooooooooooo0000ooooool0003o0ol00?l6oooo
o`030000oooooooooooo00;ooooo00<0003oooooo`000?l00_ooool00`000?oooooo0000o`07oooo
o`030000ooooool0003o00;ooooo00<0003oooooo`000?l01oooool00`000?ooooooooooo`02oooo
o`040000ool00?oo003oo`00o`?ooooo00<0003oooooooooool01?ooool01P000?ooooooooooo`00
0?oooooo0000o`Oooooo00<0003oooooo`000?l01?ooool010000?ooooooooooooooool3o`00o`03
ooooo`000?oooooo00?ooooo00<0003oooooo`000?l00ol00?l8ooooo`040000oooooooooooo0000
o`?o003o1_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00;ooooo00<0003ooooo
ooooool01Oooool00`000?oooooo0000o`04ooooo`030000ooooool0003o00Oooooo00<0003ooooo
ooooool01?ooool01P000?ooooooooooo`000?oooooo0000o`Oooooo00<0003oooooo`000?l01?oo
ool020000?ooooooooooo`000?oooooo0000ooooool0003o0oooool3o`00o`04ooooo`000?oooooo
0000o`;ooooo00<0003oooooooooool01?ooool010000?ooooooooooo`000?l7ooooo`4000000Ooo
ool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`05ooooo`060000oooo
oooooooo0000ooooool0003o0ol00?l;ooooo`060000oooooooooooo0000ooooool0003o0ol00?l6
ooooo`080000ool00?oo003oo`00ooooool0003oooooo`000?l2ooooo`030000ooooool0003o00Oo
oooo00<0003oooooo`000?l00_ooool00`000?oooooo0000o`07ooooo`030000oooooooooooo00;o
oooo00<0003oo`00ool00?l00ol00?l00oooool0003oooooo`05ooooo`060000oooooooooooo0000
ooooool0003o1oooool00`000?oooooo0000o`04ooooo`040000ooooooooooooooooo`?o003o00?o
oooo0000ooooool00oooool00`000?oooooo0000o`03o`00o`Sooooo00@0003oooooooooool0003o
0ol00?l6ooooo`030000oooooooooooo00Cooooo00H0003oo`00ool00?oo003oooooo`000?l7oooo
o`030000ooooool0003o00Cooooo00<0003oooooo`000?l01oooool00`000?ooooooooooo`04oooo
o`060000oooooooooooo0000ooooool0003o1oooool00`000?oooooo0000o`04ooooo`080000oooo
oooooooo0000ooooool0003oooooo`000?l3ooooo`?o003o00Cooooo0000ooooool0003o0_ooool0
0`000?ooooooooooo`04ooooo`040000oooooooooooo0000o`Oooooo0@000001ooooo`004oooool0
1?l0003oooooooooool00004ooooo`H0000000<0003o000000000?l00P0000000`000?l000000000
o`03o`00o`07000000000?l00000000000000?l000000000o`02000000030000o`000000003o0080
000000<0003o000000000?l00P0000000`000?l000000000o`02000000030000o`000000003o00?o
003o00@000000000o`000000003o0P0000000`000?l000000000o`02000000030000o`000000003o
0080000000<0003o000000000?l00P0000000`000?l000000000o`02000000030000o`000000003o
0080000000<0003o000000000?l00P0000000`000?l000000000o`03o`00o`04000000000?l00000
0000o`80000000<0003o000000000?l00P0000000`000?l000000000o`02000000030000o`000000
003o0080000000<0003o000000000?l00P0000000`000?l000000000o`02000000030000o`000000
003o0080000000<0003o000000000?l00P0000000`000?l000000000o`02000000050000o`000000
003o000000000?l00P0000000`000?l000000000o`02000000030000o`000000003o0080000000<0
003o000000000?l00P0000000`000?l000000000o`02000000030000o`000000003o00?o003o00L0
00000000o`00000000000000o`000000003o0080000000D0003o000000000?l000000000o`020000
00030000o`000000003o0080000000<0003o000000000?l00P0000000`000?l000000000o`020000
00030000o`000000003o0080000000<0003o000000000?l00P0000000`000?l000000000o`020000
00030000o`000000003o0080000000<0003o000000000?l00P0000001@000?l000000000o`000000
003o0080000000<0003o000000000?l00P0000000`000?l000000000o`02000000030000o`000000
003o0080000000<0003o000000000?l00P0000000`000?l000000000o`060000007ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00oooool00`000?ooooooooooo`05
ooooo`?o003o00Oooooo0000oooooooooooo0000ooooool0003o00;ooooo00<0003oooooooooool0
2Oooool010000?ooooooooooo`000?l2ooooo`?o003o2oooool00`000?oooooo0000o`0<ooooo`03
0000ooooool0003o00Cooooo00<0003oooooooooool00oooool3o`00o`?ooooo00@0003ooooooooo
ool0003o2Oooool00`000?oooooo0000o`05ooooo`?o003o1?ooool00`000?ooooooooooo`04oooo
o`030000oooooooooooo00Oooooo00<0003oooooo`000?l00_ooool00`000?ooooooooooo`07oooo
o`040000ool00?oo003oo`00o`?ooooo00@0003oooooooooool0003o0_ooool3o`00o`;ooooo0ol0
0?l00oooool0003oooooo`05ooooo`030000oooooooooooo00Gooooo00<0003oooooo`000?l01?oo
ool010000?ooooooooooo`000?l9ooooo`030000ooooool0003o00Oooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`040000oooooooooooo0000o`Kooooo00<0003ooooooooo
ool00oooool10000007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool00oooool00`000?ooooooooooo`09ooooo`060000oooooooooooo0000ooooool0003o0_ooool0
0`000?ooooooooooo`09ooooo`040000oooooooooooo0000oa3ooooo00<0003oooooo`000?l03?oo
ool00`000?oooooo0000o`04ooooo`030000oooooooooooo00Wooooo00@0003oooooooooool0003o
2Oooool00`000?oooooo0000o`05ooooo`?o003o1?ooool00`000?ooooooooooo`04ooooo`030000
oooooooooooo00Oooooo00<0003oooooo`000?l00_ooool00`000?ooooooooooo`07ooooo`040000
ool00?oo003oo`00o`?ooooo00@0003oooooooooool0003o1oooool3o`00o`03ooooo`000?oooooo
00Gooooo00<0003oooooooooool01Oooool00`000?oooooo0000o`04ooooo`040000oooooooooooo
0000o`Wooooo00<0003oooooo`000?l01oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00@0003oooooooooool0003o1_ooool00`000?ooooooooooo`03ooooo`4000000Ooo
ool001Cooooo0_l00005ooooo`0300000?oooooooooo00?ooooo00<0003oooooooooool02Oooool0
1P000?ooooooooooo`000?oooooo0000o`;ooooo00<0003oooooooooool02Oooool010000?oooooo
ooooo`000?l@ooooo`030000ooooool0003o00cooooo00<0003oooooo`000?l01?ooool00`000?oo
ooooooooo`09ooooo`040000oooooooooooo0000o`Wooooo00<0003oooooo`000?l01Oooool3o`00
o`Cooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`07ooooo`030000ooooool0003o
00;ooooo00<0003oooooooooool01Oooool6o`00o`?ooooo00@0003oooooooooool0003o1oooool3
o`00o`03ooooo`000?oooooo00Gooooo00<0003oooooooooool00oooool6o`00o`?ooooo00@0003o
ooooooooool0003o2Oooool00`000?oooooo0000o`07ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02Oooool010000?ooooooooooo`000?l6ooooo`030000oooooooooooo00?ooooo
0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`030000oooooooooooo00Wooooo00H0
003oooooooooool0003oooooo`000?l2ooooo`030000oooooooooooo00Wooooo00@0003ooooooooo
ool0003o4?ooool00`000?oooooo0000o`0<ooooo`030000ooooool0003o00Cooooo00<0003ooooo
ooooool02Oooool010000?ooooooooooo`000?l9ooooo`030000ooooool0003o00cooooo00<0003o
ooooooooool01?ooool00`000?ooooooooooo`07ooooo`030000ooooool0003o00;ooooo00<0003o
ooooooooool01Oooool3o`00o`Kooooo00@0003oooooooooool0003o2oooool00`000?oooooooooo
o`04ooooo`030000oooooooooooo00?ooooo1_l00?l3ooooo`040000oooooooooooo0000o`Wooooo
00<0003oooooo`000?l01oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00@0003oooooooooool0003o1_ooool00`000?ooooooooooo`03ooooo`4000000Oooool001_ooooo
00<00000o`000?ooool00oooool00`000?ooooooooooo`09ooooo`060000oooooooooooo0000oooo
ool0003o0_ooool00`000?ooooooooooo`09ooooo`040000oooooooooooo0000oa3ooooo00<0003o
ooooo`000?l03?ooool00`000?oooooo0000o`04ooooo`030000oooooooooooo00Wooooo00@0003o
ooooooooool0003o2Oooool00`000?oooooo0000o`0<ooooo`030000oooooooooooo00Cooooo00<0
003oooooooooool01_ooool3o`00o`040000oooooooooooo0000o`Oooooo0ol00?l6ooooo`040000
oooooooooooo0000o`_ooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`03ooooo`Ko
003o0oooool010000?ooooooooooo`000?l9ooooo`030000ooooool0003o00Oooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`040000oooooooooooo0000o`Kooooo00<0003o
ooooooooool00_ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool00oooool00`00
0?ooooooooooo`09ooooo`060000oooooooooooo0000ooooool0003o0_ooool00`000?oooooooooo
o`09ooooo`040000oooooooooooo0000oa3ooooo00<0003oooooo`000?l03?ooool00`000?oooooo
0000o`04ooooo`030000oooooooooooo00Wooooo00@0003oooooooooool0003o2Oooool00`000?oo
oooo0000o`0<ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool01_ooool3o`00o`04
0000oooooooooooo0000oa3ooooo00@0003oooooooooool0003o2oooool00`000?ooooooooooo`04
ooooo`030000oooooooooooo00cooooo00@0003oooooooooool0003o2Oooool00`000?oooooo0000
o`07ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool010000?oooooooooo
o`000?l6ooooo`030000oooooooooooo00?ooooo0@000001ooooo`006oooool00`00003ooooooooo
o`03ooooo`030000oooooooooooo00Wooooo00H0003oooooooooool0003oooooo`000?l2ooooo`03
0000oooooooooooo00Wooooo00@0003oooooooooool0003o4?ooool00`000?oooooo0000o`0<oooo
o`030000ooooool0003o00Cooooo00<0003oooooooooool02Oooool010000?ooooooooooo`000?l9
ooooo`030000ooooool0003o00cooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`06
ooooo`?o003o00@0003oooooooooool0003o4?ooool010000?ooooooooooo`000?l;ooooo`030000
oooooooooooo00Cooooo00<0003oooooooooool03?ooool010000?ooooooooooo`000?l9ooooo`03
0000ooooool0003o00Oooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`04
0000oooooooooooo0000o`Kooooo00<0003oooooooooool00oooool10000007ooooo000Kooooo`03
00000?oooooooooo00?ooooo00<0003oooooooooool02Oooool01P000?ooooooooooo`000?oooooo
0000o`?o003o2oooool010000?ooooooooooo`000?l@ooooo`030000ooooool0003o00cooooo00<0
003oooooo`000?l01?ooool00`000?ooooooooooo`09ooooo`030000oooooooo003o00;o003o2?oo
ool00`000?oooooo0000o`0<ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool02Ooo
ool010000?ooooooooooo`000?l@ooooo`040000oooooooooooo0000o`_ooooo00<0003ooooooooo
ool01?ooool00`000?ooooooooooo`0<ooooo`040000oooooooooooo0000o`Wooooo00<0003ooooo
o`000?l01oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00@0003ooooo
ooooool0003o1_ooool00`000?ooooooooooo`03ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool00oooool00`000?ooooooooooo`09ooooo`060000oooooooooooo0000ooooool0003o0ol0
0?l;ooooo`040000oooooooooooo0000oa3ooooo00<0003oooooo`000?l03?ooool00`000?oooooo
0000o`04ooooo`030000oooooooooooo00Wooooo00<0003oooooool00?l00_l00?l8ooooo`030000
ooooool0003o00cooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`09ooooo`040000
oooooooooooo0000oa3ooooo00@0003oooooooooool0003o2oooool00`000?ooooooooooo`04oooo
o`030000oooooooooooo00cooooo00@0003oooooooooool0003o2Oooool00`000?oooooo0000o`07
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool010000?ooooooooooo`00
0?l6ooooo`030000oooooooooooo00?ooooo0@000001ooooo`006oooool00`00003o0000ooooo`03
ooooo`030000oooooooooooo00Wooooo00H0003oooooooooool0003oooooo`000?l3o`00o`_ooooo
00@0003oooooooooool0003o4?ooool00`000?oooooo0000o`0<ooooo`030000ooooool0003o00Co
oooo00<0003oooooooooool02Oooool00`000?ooooooo`00o`02o`00o`Sooooo00<0003oooooo`00
0?l03?ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Wooooo00@0003ooooooooo
ool0003o4?ooool010000?ooooooooooo`000?l;ooooo`030000oooooooooooo00Cooooo00<0003o
ooooooooool03?ooool010000?oo003oo`00ool00?l9ooooo`030000ooooool0003o00Oooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`040000oooooooooooo0000o`Kooooo
00<0003oooooooooool00_ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool00ooo
ool00`000?ooooooooooo`09ooooo`060000oooooooooooo0000ooooool0003o3_ooool010000?oo
ooooooooo`000?l@ooooo`030000ooooool0003o00cooooo00<0003oooooo`000?l01?ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooo`000?l03?ooool00`00
0?ooooooooooo`04ooooo`030000oooooooooooo00Wooooo00@0003oooooooooool0003o4?ooool0
10000?ooooooooooo`000?l;ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool03?oo
ool010000?oo003oo`00ool00?l9ooooo`030000ooooool0003o00Oooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`040000oooooooooooo0000o`Kooooo00<0003ooooooooo
ool00oooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0003oooooooooool0
2Oooool01P000?ooooooooooo`000?oooooo0000o`kooooo00@0003oooooooooool0003o4?ooool0
0`000?oooooo0000o`0<ooooo`040000ool00?oo003oo`00o`;ooooo0ol00?l:ooooo`030000oooo
oooooooo00[ooooo00<0003oooooo`000?l03?ooool00`000?ooooooooooo`04ooooo`030000oooo
oooooooo00Wooooo00@0003oooooooooool0003o4?ooool010000?ooooooooooo`000?l;ooooo`03
0000oooooooooooo00Cooooo00<0003oooooooooool03?ooool010000?oo003oo`00ool00?l7oooo
o`?o003o00?ooooo0000ooooool01_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00@0003oooooooooool0003o1_ooool00`000?ooooooooooo`03ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool00oooool00`000?ooooooooooo`09ooooo`060000oooooooooooo
0000ooooool0003o3_ooool010000?ooooooooooo`000?l@ooooo`030000ooooool0003o00cooooo
00@0003oo`00ool00?oo003o0_ooool3o`00o`[ooooo00<0003oooooooooool02_ooool00`000?oo
oooo0000o`0<ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool02Oooool010000?oo
ooooooooo`000?l@ooooo`040000oooooooooooo0000o`_ooooo00<0003oooooooooool01?ooool0
0`000?ooooooooooo`0<ooooo`030000oooooooooooo00Sooooo0ol00?l00oooool0003oooooo`06
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool010000?ooooooooooo`00
0?l6ooooo`030000oooooooooooo00?ooooo0@000001ooooo`006oooool01000003ooooooooooooo
ool3o`00o`_ooooo00H0003oooooooooool0003oooooo`000?l>ooooo`040000oooooooooooo0000
oa3ooooo00<0003oooooo`000?l03?ooool010000?oo003oo`00ool00?l2ooooo`?o003o2Oooool3
o`00o`_ooooo00<0003oooooo`000?l03?ooool00`000?ooooooooooo`04ooooo`030000oooooooo
oooo00Wooooo00@0003oooooooooool0003o4?ooool010000?ooooooooooo`000?l;ooooo`030000
oooooooooooo00Cooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`08ooooo`?o003o
00?ooooo0000ooooool01_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00@0003oooooooooool0003o1_ooool00`000?ooooooooooo`03ooooo`4000000Oooool001_ooooo
00@00000oooooooooooooooo0ol00?l;ooooo`060000oooooooooooo0000ooooool0003o3_ooool0
10000?ooooooooooo`000?l@ooooo`030000ooooool0003o00cooooo00<0003oooooooooool03ooo
ool3o`00o`_ooooo00<0003oooooo`000?l03?ooool00`000?ooooooooooo`04ooooo`030000oooo
oooooooo00Wooooo00@0003oooooooooool0003o4?ooool010000?ooooooooooo`000?l;ooooo`03
0000oooooooooooo00Cooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`0<ooooo`03
0000oooooooooooo00Gooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`04
0000oooooooooooo0000o`Kooooo00<0003oooooooooool00oooool10000007ooooo000Kooooo`04
00000?l0003oooooooooo`?o003o2oooool01P000?ooooooooooo`000?oooooo0000o`kooooo00@0
003oooooooooool0003o4?ooool00`000?oooooo0000o`0<ooooo`030000oooooooooooo00oooooo
0ol00?l;ooooo`030000ooooool0003o00cooooo00<0003oooooooooool01?ooool00`000?oooooo
ooooo`09ooooo`040000oooooooooooo0000oa3ooooo00@0003oooooooooool0003o2oooool00`00
0?ooooooooooo`03ooooo`?o003o3Oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo
00?ooooo0ol00?l:ooooo`?o003o2_ooool010000?ooooooooooo`000?l6ooooo`030000oooooooo
oooo00;ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00oooooo00H0003ooooo
ooooool0003oooooo`000?l>ooooo`040000oooooooooooo0000oa3ooooo00<0003oooooo`000?l0
3?ooool00`000?ooooooooooo`0Mooooo`030000ooooool0003o00cooooo00<0003oooooooooool0
1?ooool00`000?ooooooooooo`09ooooo`040000oooooooooooo0000oa3ooooo00@0003ooooooooo
ool0003o2oooool00`000?ooooooooooo`03ooooo`?o003o3Oooool00`000?ooooooooooo`0<oooo
o`030000oooooooooooo00?ooooo0ol00?l:ooooo`?o003o2_ooool010000?ooooooooooo`000?l6
ooooo`030000oooooooooooo00?ooooo0@000001ooooo`006oooool00`00003oooooooooo`0?oooo
o`060000oooooooooooo0000ooooool0003o3_ooool010000?ooooooooooo`000?l@ooooo`040000
ool00?oo003oo`00o`_ooooo00<0003oooooooooool07Oooool00`000?oooooo0000o`0<ooooo`03
0000oooooooooooo00?ooooo0ol00?l:ooooo`040000oooooooooooo0000oa3ooooo00@0003ooooo
ooooool0003o2oooool00`000?ooooooooooo`03ooooo`?o003o3Oooool00`000?ooooooooooo`0<
ooooo`030000oooooooooooo00?ooooo0ol00?l:ooooo`?o003o2_ooool010000?ooooooooooo`00
0?l5ooooo`?o003o1?ooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00H0003o
ooooooooool0003oooooo`000?l>ooooo`040000oooooooooooo0000oa3ooooo00@0003oo`00ool0
0?oo003o2oooool00`000?ooooooooooo`0Mooooo`030000ooooool0003o00cooooo00<0003ooooo
ooooool00oooool3o`00o`[ooooo00@0003oooooooooool0003o4?ooool010000?ooooooooooo`00
0?l;ooooo`030000oooooooooooo01?ooooo00<0003oooooooooool03?ooool00`000?oooooooooo
o`0Mooooo`040000oooooooooooo0000o`Gooooo0ol00?l4ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool03oooool01P000?ooooooooooo`000?oooooo0000o`kooooo00@0003ooooooooo
ool0003o4?ooool010000?oo003oo`00ool00?l;ooooo`030000oooooooooooo01gooooo00<0003o
ooooo`000?l03?ooool00`000?ooooooooooo`03ooooo`?o003o2_ooool010000?ooooooooooo`00
0?l@ooooo`040000ool00?oo003oo`00o`_ooooo00<0003oooooooooool04oooool00`000?oooooo
ooooo`0<ooooo`030000oooooooooooo01gooooo00@0003oooooooooool0003o1Oooool3o`00o`Co
oooo0@000001ooooo`006oooool00`00003o0000ooooo`0?ooooo`060000oooooooooooo0000oooo
ool0003o3_ooool010000?ooooooooooo`000?l@ooooo`030000oooooooooooo00cooooo00<0003o
ooooooooool07Oooool00`000?oooooo0000o`0<ooooo`030000oooooooooooo013ooooo00@0003o
ooooooooool0003o4?ooool010000?oo003oo`00ool00?l;ooooo`030000oooooooooooo01?ooooo
00<0003oooooooooool03?ooool00`000?ooooooooooo`0Mooooo`040000oooooooooooo0000o`_o
oooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oo`00ool00?l0
1?l00?l=ooooo`040000oooooooooooo0000oa3ooooo00<0003oooooooooool03?ooool00`000?oo
ooooooooo`0Mooooo`030000ooooool0003o00cooooo00<0003oooooooooool04?ooool010000?oo
ooooooooo`000?l?ooooo`Go003o2oooool00`000?ooooooooooo`0Cooooo`030000oooooooooooo
00cooooo00<0003oooooooooool07Oooool010000?ooooooooooo`000?l<ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool03oooool00`000?oo003oo`00o`04o`00o`gooooo00@0003ooooo
ooooool0003o4?ooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo01gooooo00<0003o
ooooo`000?l03?ooool00`000?ooooooooooo`0@ooooo`040000oooooooooooo0000o`oooooo0ol0
0?l=ooooo`030000oooooooooooo01?ooooo00<0003oooooooooool03?ooool00`000?oooooooooo
o`0Mooooo`040000oooooooooooo0000o`cooooo0@000001ooooo`002?ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Gooooo00<00000ooooooooool03oooool00`000?oo003oo`00
o`04o`00o`gooooo00@0003oooooooooool0003o4?ooool00`000?ooooooooooo`0<ooooo`030000
oooooooooooo01gooooo00<0003oooooo`000?l03?ooool00`000?ooooooooooo`0@ooooo`040000
oooooooooooo0000o`oooooo0ol00?l=ooooo`030000oooooooooooo01;ooooo0ol00?l=ooooo`03
0000oooooooooooo01gooooo00@0003oooooooooool0003o3?ooool10000007ooooo0007ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0?oooo
o`030000oooooooooooo017ooooo00@0003oooooooooool0003o4?ooool00`000?ooooooooooo`0<
ooooo`030000oooooooooooo01gooooo00<0003oooooo`000?l03?ooool00`000?ooooooooooo`0@
ooooo`040000oooooooooooo0000oaoooooo00<0003oooooooooool04_ooool3o`00o`gooooo00<0
003oooooooooool07Oooool010000?ooooooooooo`000?l<ooooo`4000000Oooool000Oooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`0300000?l0003ooooo00kooooo
0ol00?lBooooo`040000oooooooooooo0000oa3ooooo00<0003oooooooooool03?ooool00`000?oo
ooooooooo`0Mooooo`030000ooooool0003o00cooooo00<0003oooooooooool04?ooool010000?oo
ooooooooo`000?lOooooo`030000oooooooooooo01;ooooo0ol00?l=ooooo`030000oooooooooooo
01gooooo00@0003oooooooooool0003o2oooool1o`00004000000Oooool000Oooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00kooooo0ol00?lB
ooooo`040000oooooooooooo0000oa3ooooo00<0003oooooooooool03?ooool00`000?oooooooooo
o`0Mooooo`030000ooooool0003o00cooooo00<0003oooooooooool04?ooool010000?oooooooooo
o`000?lOooooo`030000oooooooooooo02;ooooo00<0003oooooooooool07Oooool010000?oooooo
ooooo`000?l<ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`04ooooo`0300000?oooooooooo00kooooo0ol00?lBooooo`040000oooooooooooo0000
o`kooooo0ol00?l>ooooo`030000oooooooooooo01gooooo00<0003oooooo`000?l03?ooool00`00
0?ooooooooooo`0@ooooo`040000oooooooooooo0000oaoooooo00<0003oooooooooool08_ooool0
0`000?ooooooooooo`0Looooo`?o003o00?ooooo0000ooooool02oooool10000007ooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`0300000?oooooooooo02?ooooo00@0003o
ooooooooool0003o3_ooool3o`00o`kooooo00<0003oooooooooool07Oooool00`000?oooooo0000
o`0<ooooo`030000oooooooooooo013ooooo00@0003oooooooooool0003o7oooool00`000?oooooo
ooooo`0Rooooo`030000oooooooooooo01cooooo0ol00?l00oooool0003oooooo`0;ooooo`400000
0Oooool000Sooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool08ooo
ool010000?ooooooooooo`000?l>ooooo`?o003o3_ooool00`000?ooooooooooo`0Mooooo`030000
ooooool0003o00[ooooo0ol00?lBooooo`040000oooooooooooo0000oaoooooo00<0003ooooooooo
ool08_ooool00`000?ooooooooooo`0Looooo`?o003o00?ooooo0000ooooool02oooool10000007o
oooo000Kooooo`0300000?l0003ooooo02?ooooo00@0003oooooooooool0003o7oooool00`000?oo
ooooooooo`0Mooooo`030000ooooool0003o00[ooooo0ol00?lBooooo`040000oooooooooooo0000
oaoooooo00<0003oooooooooool08_ooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo
00Wooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02?ooooo00@0003oo`00ool0
0?oo003o7oooool00`000?ooooooooooo`0Mooooo`030000ooooool0003o00[ooooo0ol00?lBoooo
o`040000oooooooooooo0000oaoooooo00<0003oooooooooool08_ooool00`000?ooooooooooo`0P
ooooo`030000oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Soooo
o`040000ool00?oo003oo`00oaoooooo00<0003oooooooooool07Oooool00`000?oooooo0000o`0O
ooooo`040000oooooooooooo0000oaoooooo00<0003oooooooooool08_ooool00`000?oooooooooo
o`0Pooooo`030000oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0S
ooooo`040000ool00?oo003oo`00oaoooooo00<0003oooooooooool07Oooool00`000?oooooo0000
o`0Oooooo`040000oooooooooooo0000oaoooooo00<0003oooooooooool08_ooool00`000?oooooo
ooooo`0Pooooo`030000oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0Sooooo`030000oooooooooooo023ooooo00<0003oooooooooool07Oooool00`000?oooooo0000
o`0Oooooo`040000oooooooooooo0000oaoooooo00<0003oooooooooool08_ooool00`000?oooooo
ooooo`0Pooooo`030000oooooooooooo00[ooooo0@000001ooooo`006oooool00`00003o0000oooo
o`0Sooooo`030000oooooooooooo023ooooo00<0003oooooooooool06oooool3o`00o`03ooooo`00
0?oooooo01kooooo00@0003oooooooooool0003o7oooool00`000?ooooooooooo`0Rooooo`030000
oooooooooooo023ooooo00<0003oooooooooool02Oooool1o`00004000000Oooool001_ooooo00<0
0000ooooooooool08oooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo01_ooooo0ol0
0?l00oooool0003oooooo`0Nooooo`040000oooooooooooo0000oaoooooo00<0003oooooooooool0
8_ooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo00[ooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0Sooooo`030000oooooooooooo023ooooo00<0003oooooooooool06ooo
ool3o`00o`03ooooo`000?oooooo01kooooo00@0003oooooooooool0003o7oooool00`000?oooooo
ooooo`0Rooooo`030000oooooooooooo023ooooo00<0003oooooooooool02_ooool10000007ooooo
000Kooooo`0300000?oooooooooo02?ooooo00<0003oooooooooool08?ooool00`000?oooooooooo
o`0Oooooo`030000oooooooooooo01gooooo00@0003oooooooooool0003o7oooool00`000?oooooo
ooooo`0Rooooo`030000oooooooooooo023ooooo00<0003oooooooooool02_ooool10000007ooooo
000Kooooo`0300000?oooooooooo02?ooooo00<0003oooooooooool08?ooool00`000?oooooooooo
o`0Oooooo`030000oooooooooooo01gooooo00@0003oooooooooool0003o7oooool00`000?oooooo
ooooo`0Rooooo`030000oooooooooooo023ooooo00<0003oooooooooool02_ooool10000007ooooo
000Kooooo`0300000?oooooooooo02?ooooo00<0003oooooooooool08?ooool00`000?oooooooooo
o`0Oooooo`030000oooooooooooo01gooooo00@0003oooooooooool0003o7oooool00`000?oooooo
ooooo`0Rooooo`030000oooooooooooo023ooooo00<0003oooooooooool02_ooool10000007ooooo
000Kooooo`0300000?l0003ooooo02?ooooo00<0003oooooooooool08?ooool00`000?oooooooooo
o`0Oooooo`030000oooooooooooo01gooooo00@0003oooooooooool0003o7oooool00`000?oooooo
ooooo`0Rooooo`030000oooooooooooo023ooooo00<0003oooooooooool02Oooool1o`0000400000
0Oooool001_ooooo00<00000ooooooooool08oooool00`000?ooooooooooo`0Pooooo`030000oooo
oooooooo01oooooo00<0003oooooooooool07Oooool010000?ooooooooooo`000?lOooooo`030000
oooooooooooo02;ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0:ooooo`400000
0Oooool001_ooooo00<00000ooooooooool08oooool00`000?ooooooooooo`0Pooooo`030000oooo
oooooooo01oooooo00<0003oooooooooool07Oooool010000?ooooooooooo`000?lOooooo`030000
oooooooooooo02;ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0:ooooo`400000
0Oooool001_ooooo00<00000ooooooooool08oooool00`000?ooooooooooo`0Pooooo`030000oooo
oooooooo01oooooo00<0003oooooooooool07Oooool010000?ooooooooooo`000?lOooooo`030000
oooooooooooo02;ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0:ooooo`400000
0Oooool001_ooooo00<00000ooooooooool08oooool00`000?ooooooooooo`0Pooooo`030000oooo
oooooooo01oooooo00<0003oooooooooool07Oooool010000?ooooooooooo`000?lOooooo`030000
oooooooooooo02;ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0:ooooo`400000
0Oooool001_ooooo00<00000o`000?ooool08oooool00`000?ooooooooooo`0Pooooo`030000oooo
oooooooo01oooooo00<0003oooooooooool07Oooool010000?ooooooooooo`000?lOooooo`030000
oooooooooooo02;ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`09ooooo`7o0000
0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`030000oooooooooooo023ooooo00<0
003oooooooooool07oooool00`000?ooooooooooo`0Mooooo`040000ool00?oo003oo`00oaoooooo
00<0003oooooooooool08_ooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo00[ooooo
0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`030000oooooooooooo023ooooo00<0
003oooooooooool07oooool00`000?ooooooooooo`0Mooooo`040000ool00?oo003oo`00oaoooooo
00<0003oooooooooool08_ooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo00[ooooo
0@000001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`030000
0?oooooooooo02?ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Oooooo`030000
oooooooooooo01gooooo00@0003oo`00ool00?oo003o7oooool00`000?ooooooooooo`0Rooooo`03
0000oooooooooooo023ooooo00<0003oooooooooool02_ooool10000007ooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Soooo
o`030000oooooooooooo023ooooo00<0003oooooooooool07oooool00`000?ooooooooooo`0Moooo
o`030000oooooooooooo023ooooo00<0003oooooooooool08_ooool00`000?ooooooooooo`0Poooo
o`030000oooooooooooo00[ooooo0@000001ooooo`001oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Cooooo00<00000o`000?ooool08oooool00`000?ooooooooooo`0Poooo
o`030000oooooooooooo01oooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Poooo
o`030000oooooooooooo02;ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`09oooo
o`7o00000@000001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
00?ooooo00<00000ooooooooool08oooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo
01oooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo
02;ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0:ooooo`4000000Oooool000Oo
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00<00000
ooooooooool08oooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo01oooooo00<0003o
ooooooooool07Oooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo02;ooooo00<0003o
ooooooooool08?ooool00`000?ooooooooooo`0:ooooo`4000000Oooool000Oooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00<00000ooooooooool08ooo
ool00`000?ooooooooooo`0Pooooo`030000oooooooooooo01oooooo00<0003oooooooooool07Ooo
ool00`000?ooooooooooo`0Pooooo`030000oooooooooooo02;ooooo00<0003oooooooooool08?oo
ool00`000?ooooooooooo`0:ooooo`4000000Oooool000Sooooo0_l00009ooooo`?o00001Oooool0
0`00003oooooooooo`0Sooooo`030000oooooooooooo023ooooo00<0003oooooooooool07oooool0
0`000?ooooooooooo`0Mooooo`030000oooooooooooo023ooooo00<0003oooooooooool08_ooool0
0`000?ooooooooooo`0Pooooo`030000oooooooooooo00[ooooo0@000001ooooo`006oooool00`00
003o0000ooooo`0Sooooo`030000oooooooooooo023ooooo00<0003oooooooooool07oooool00`00
0?ooooooooooo`0Mooooo`030000oooooooooooo023ooooo00<0003oooooooooool08_ooool00`00
0?ooooooooooo`0Pooooo`030000oooooooooooo00Wooooo0Ol000010000007ooooo000Kooooo`03
00000?oooooooooo02?ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Oooooo`03
0000oooooooooooo01gooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Rooooo`03
0000oooooooooooo023ooooo00<0003oooooooooool02_ooool10000007ooooo000Kooooo`030000
0?oooooooooo02?ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Oooooo`030000
oooooooooooo01gooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Rooooo`030000
oooooooooooo023ooooo00<0003oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oo
oooooooo02?ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Oooooo`030000oooo
oooooooo01gooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Rooooo`030000oooo
oooooooo023ooooo00<0003oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oooooo
oooo02?ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Oooooo`030000oooooooo
oooo01gooooo00<0003oooooooooool07oooool3o`00ob?ooooo00<0003oooooooooool08?ooool0
0`000?ooooooooooo`0:ooooo`4000000Oooool001_ooooo00<00000ooooooooool08oooool00`00
0?ooooooooooo`0Pooooo`030000oooooooooooo01oooooo00<0003oooooooooool07Oooool00`00
0?ooooooooooo`0Oooooo`?o003o8oooool00`000?ooooooooooo`0Pooooo`030000oooooooooooo
00[ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Sooooo`030000oooooooooooo023o
oooo00<0003oooooooooool07oooool00`000?ooooooooooo`0Looooo`?o003o8?ooool3o`00ob;o
oooo0ol00?lQooooo`030000oooooooooooo00Wooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo02?ooooo00<0003oooooooooool08?ooool00`000?ooooooooooo`0Oooooo`030000
oooooooooooo01cooooo0ol00?m5ooooo`?o003o8Oooool00`000?ooooooooooo`0:ooooo`400000
0Oooool001_ooooo00<00000ooooooooool08oooool00`000?ooooooooooo`0Pooooo`030000oooo
oooooooo01oooooo00<0003oooooooooool07?ooool3o`00odGooooo0ol00?lQooooo`030000oooo
oooooooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`030000oooooooo
oooo023ooooo00<0003oooooooooool07oooool00`000?ooooooooooo`28ooooo`030000oooooooo
oooo00[ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Sooooo`030000oooooooooooo
023ooooo00<0003oooooooooool07oooool00`000?ooooooooooo`28ooooo`030000oooooooooooo
00[ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Sooooo`030000oooooooooooo023o
oooo00<0003oooooooooool07oooool00`000?ooooooooooo`28ooooo`030000oooooooooooo00Wo
oooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02?ooooo00<0003oooooooooool0
8?ooool00`000?ooooooooooo`0Oooooo`030000oooooooooooo08Sooooo00<0003oooooooooool0
2_ooool10000007ooooo000Kooooo`0300000?oooooooooo02?ooooo00<0003oooooooooool08?oo
ool00`000?ooooooooooo`0Oooooo`030000oooooooooooo08Sooooo00<0003oooooooooool02_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02?ooooo00<0003oooooooooool08?ooool0
0`000?ooooooooooo`0Oooooo`030000oooooooooooo08Sooooo00<0003oooooooooool02_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo02?ooooo00<0003oooooooooool08?ooool00`00
0?ooooooooooo`0Oooooo`030000oooooooooooo08Sooooo00<0003oooooooooool02_ooool10000
007ooooo000Kooooo`0300000?l0003ooooo02?ooooo00<0003oooooooooool08?ooool00`000?oo
ooooooooo`0Nooooo`?o003oROooool00`000?ooooooooooo`09ooooo`7o00000@000001ooooo`00
6oooool00`00003oooooooooo`0Sooooo`030000oooooooooooo023ooooo00<0003oooooooooool0
7_ooool3o`00ohWooooo00<0003oooooooooool02_ooool10000007ooooo000Kooooo`0300000?oo
oooooooo02;ooooo0ol00?lQooooo`030000oooooooooooo01kooooo0ol00?n7ooooo`?o003o3?oo
ool10000007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool0
0`00003oooooooooo`0Rooooo`?o003o8Oooool00`000?ooooooooooo`2Xooooo`?o003o3?ooool1
0000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`0300000?oooooooooo02;ooooo0ol00?lQooooo`030000oooooooooooo0:Sooooo0ol0
0?l<ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`02ooooo`0300000?l0003ooooo04Kooooo00<0003oooooooooool0]_ooool1o`00004000000Ooo
ool000Oooooo00Co0000oooooooooooo00002Oooool2o`0000Gooooo00<00000ooooooooool0A_oo
ool00`000?ooooooooooo`2gooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooooooo`02ooooo`0300000?oooooooooo04Kooooo00<0003oooooooooool0]ooo
ool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`0300000?oooooooooo04Kooooo00<0003oooooooooool0]oooool10000007ooooo
0008ooooo`;o00002Oooool3o`0000Gooooo00<00000ooooooooool0A_ooool00`000?oooooooooo
o`2gooooo`4000000Oooool001_ooooo00<00000o`000?ooool0A_ooool00`000?ooooooooooo`2f
ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`16ooooo`030000oooooooooooo
0;Oooooo0@000001ooooo`006oooool00`00003oooooooooo`16ooooo`030000oooooooooooo0;Oo
oooo0@000001ooooo`006oooool00`00003oooooooooo`16ooooo`030000oooooooooooo0;Oooooo
0@000001ooooo`006oooool00`00003oooooooooo`14ooooo`?o003o^Oooool10000007ooooo000K
ooooo`0300000?oooooooooo04Cooooo0ol00?niooooo`4000000Oooool001_ooooo00<00000o`00
0?ooool0A?ooool3o`00okSooooo0Ol000010000007ooooo000Kooooo`0500000?oooooooooooooo
ool000003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool10000007ooooo000Kooooool000001@000001ooooo`00oooooolQooooo`00oooo
oolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.987374, -0.319719, \
3.63465*^-5, 0.00383423}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Music signal", "Subsection"],

Cell[CellGroupData[{

Cell["Import wav file", "Subsubsection"],

Cell["\<\
Adjust the directory setting and input file below to your system \
configuration.\
\>", "Text"],

Cell[BoxData[{
    \(\(dir = "\</Users/nechyba/public_html/eel3135/data\>";\)\), "\
\[IndentingNewLine]", 
    \(\(file = "\<MusicShort32KHz.wav\>";\)\)}], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetDirectory[dir];\)\), "\n", 
    \(\(wav2 = ReadSoundFile[file, PrintHeader \[Rule] True];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Format: "\[InvisibleSpace]"Microsoft PCM WAVE \
RIFF"\),
      SequenceForm[ "Format: ", "Microsoft PCM WAVE RIFF"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Duration: "\[InvisibleSpace]23.0566875`\
\[InvisibleSpace]" seconds"\),
      SequenceForm[ "Duration: ", 23.056687499999999, " seconds"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Channels: "\[InvisibleSpace]1\),
      SequenceForm[ "Channels: ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Sampling rate: "\[InvisibleSpace]32000\),
      SequenceForm[ "Sampling rate: ", 32000],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Bits per sample: "\[InvisibleSpace]16\),
      SequenceForm[ "Bits per sample: ", 16],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Data size: \
"\[InvisibleSpace]1475628\[InvisibleSpace]" bytes"\),
      SequenceForm[ "Data size: ", 1475628, " bytes"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of samples: "\[InvisibleSpace]737814\),
      SequenceForm[ "Number of samples: ", 737814],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(sampleRate2 = 32000;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Listen to wav file", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(ListPlay[wav2, 
        SampleRate \[Rule] sampleRate2];\)\(\ \)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
32000 737814 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`00000Q
0000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`2>ooooo`03
o`000?oooooooooo08_ooooo0@000000000300000?oooooooooo0;kooooo00?o0000ooooooooool0
Foooool10000000000<00000ooooooooool0__ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`4000000000
0`00003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`00017ooooo0_l00005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_oo
ool2o`0000Gooooo00?o0000ooooooooool01oooool10000000000@00000oooooooooooo00003?oo
ool00ol0003oooooooooo`09ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool2o`0000?ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02o`0000cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`06o`000?ooooooooooooooool0003ooooo0ol00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool000000oooool2o`000003ooooool0003o000000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?oooooo0000o`0000gooooo00Co0000oooooooooooooooo1Ol00002ooooo`?o0000
0oooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`40000000000`00003ooooo
ooooo`0<ooooo`;o000000?oooooo`000?l000001?ooool7o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`04o`00
0?oooooo0000ooooo`;o000000?oooooo`000?ooool00oooool2o`0000?ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00001?oo
ool4o`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooo000000;ooooo0_l000000ooooooo0000o`000007o`0000;ooooo00?o0000oooo
ooooool00ol00002ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`00
0?l000000oooool2o`0000Gooooo00?o0000ooooool000001Ol00002ooooo`;o00000oooool01Ol0
003ooooooooooooooooo000000?ooooo1?l000000ooooooo0000ooooo`05o`000009ooooool0003o
ooooo`000?oooooo0000ooooool0003ooooo00;o00001oooool2o`0000Kooooo0_l00003ooooo`;o
00000_ooool00ol0003oooooooooo`04o`0000Kooooo0@000000000300000?oooooo000000Cooooo
0_l00002ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000ooooo`0<o`000004oooo
ool0003o0000o`0000Gooooo0_l00002ooooo`;o000000?oooooo`000?l000000ol000000ooooooo
0000ooooo`02ooooo`Oo000000?oooooo`000?l000002Ol00002ooooo`;o00000_ooool6o`0000?o
oooo0ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000004o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000002
o`0000;ooooo0_l00002ooooo`Ko000000?oooooo`000?ooool00_l000000ooooooo0000o`00000C
o`000003ooooool0003o000000Co00000_ooool4o`000005ooooool0003o0000o`000?ooool01_l0
0002ooooo`So000000?oooooo`000?l000001?l00002ooooo`;o00000_ooool3o`0000;ooooo0_l0
00000ooooooo0000o`00000;o`000003ooooool0003o000000Go000000Coooooo`000?l0003o0000
0_ooool01?l0003oooooo`000?ooool6o`0000;ooooo2?l000000ooooooo0000o`000008o`0000?o
oooo0@000000000300000?oooooo00000?oo00007?l00001ooooo`40000000000`00003oooooo`00
003oo`0001co00000Oooool10000000000<00000ooooooooool00_l000001?oooooo0000o`000?l0
0003ooooo`Go000000Ooooooo`000?l0003o0000ooooool0003ooooo01;o00000oooool6o`000003
ooooool0003o000000Go00000ooooolCo`0000;ooooo0_l000000ooooooo0000o`000006o`0000;o
oooo1ol000000ooooooo0000o`00000Eo`000003ooooool0003ooooo00Ko000000?oooooo`000?l0
00009?l000000ooooooo0000o`000002ooooo`oo00000_ooool8o`000003ooooool0003o000000Co
00000_ooool4o`000003ooooool0003o0000027o000000?oooooo`000?l000001_l00002oooooaCo
00000_ooool10000000000<00000ooooool000001?ooool2o`0000Kooooo0_l000001?oooooo0000
o`000?l00003ooooo`So00000_ooool01?l0003oooooooooool00007ooooo`;o00000oooool01Ol0
003oooooo`000?oooooo000000Oooooo0_l00003ooooo`;o000000?oooooo`000?l000001?l00000
0ooooooo0000ooooo`02o`0000;ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000o`00
0003ooooo`;o00000_ooool3o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000oooo
o`03o`0000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooooooool2o`000003ooooool0003ooooo00;ooooo00Go0000ooooool0003o0000ooooo`03o`00
0003ooooool0003o000000Go00000_ooool3o`000003ooooool0003o000000?ooooo0_l00002oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`Ko00000_ooool2
o`0000?ooooo0ol000000ooooooo0000o`000004o`0000;ooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o000000?oooooo`000?l000002ol000000ooooooo0000o`000003o`000003ooooool0
003ooooo00;o00000_ooool2o`0000?ooooo0ol00005ooooo`;o00000_ooool4o`000004ooooool0
003oooooooooo`?o00001oooool10000000000<00000ooooooooool03?ooool2o`0000Oooooo0ol0
00001?oooooo0000o`000?l00006ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02o`00
0003ooooool0003ooooo00;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`000004oooo
o`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo0000ooooo`03o`0000?ooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02o`0000;ooooo00?o
0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003o
ooooooooo`02o`0000?ooooo00?o0000ooooooooool00_ooool10000000000<00000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`;o00003oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000002Ko
oooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo0_l00008ooooo`40000000000`00003oooooooooo`1Qooooo`05o`000?oooooooooooooo
ool00000;Oooool2o`0002Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Koooo
o`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo0?oooooo
7Oooool10000000000<00000ooooooooool0oooooolMooooo`400000003o00000240000000000`00
003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo00gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0>ooooo`;o00001_ooool2o`0000?ooooo00Go0000oooooooo
ooooooooo`00000@ooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`04o`000?oooooo0000
o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Gooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Ooo
ool10000000000<00000ooooool000003oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00cooooo0_l0000Xooooo`40000000000`00003oooooooooo`1:ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`19ooooo`40000000000`00003o
ooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooo`00000Looooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0<_ooool100000000
00<00000ooooooooool03Oooool00ol0003oooooo`00000jooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo
0@000000000300000?oooooooooo00gooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`2Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool10000000000<00000
ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000<?oo
ool10000000000<00000ooooooooool0Joooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
0000o`0003[ooooo00?o0000ooooooooool03_ooool10000000000<00000ooooooooool0>oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0;7ooooo0@000000000300000?oooooooooo
01kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Pooooo`;o00006?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`40000000000`00003oooooooooo`16ooooo`05o`000?oooooo0000oooo
ool00000?oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03_ooool10000000000<00000ooooooooool0GOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0D_ooool10000000000<00000ooooooooool0
3oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo04kooooo0_l00002ooooo`03o`000?oooooooooo00ko
oooo0@000000000300000?oooooooooo063ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo
00?o0000ooooool000009_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000002;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Cooooo`40000000000`00003oooooooooo`0Uooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool06oooool01Ol0003oooooo`000?oooooo000003ko
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`40000000000`00003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00000Tooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool07oooool00ol0003oooooo`000004ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`40
000000000`00003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool00000
0_l0000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`05ooooo`?o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool00oooool00ol0003oooooo`00000Fooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`40000000000`00003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo00005_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Booooo`40000000000`00003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo
0_l00002ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`0Zooooo`07o`000?ooooooooooooooool0003oooooo`00000Rooooo`03o`000?oooooo
oooo00gooooo0@000000000300000?oooooooooo01kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooo`00000Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0>ooooo`;o00003oooool3o`0000Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`;o0000:_ooool10000000000<00000ooooooooool03Oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Eooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0@oooo
o`40000000000`00003oooooooooo`0=ooooo`03o`000?oooooo000000Kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`05ooooo`?o00007?ooool01_l0003oooooo`000?l0003ooooo
o`0000;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000Pooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`40000000000`00
003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo0ol00006ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo0_l0000Oooooo`05o`000?oooooo0000ooooool000001_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`04ooooo`03o`000?oooooo
000002;ooooo00?o0000ooooooooool01?ooool10000000000<00000ooooooooool09oooool00ol0
003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0B
ooooo`40000000000`00003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00ol0000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0
003oooooo`000002o`0000Wooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool4o`0000cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`05ooooo`;o00001oooool3o`0000Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001Cooooo00?o0000oooo
ooooool04_ooool10000000000<00000ooooooooool03Oooool00ol0003oooooo`00000>ooooo`05
o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`05ooooo`;o00005oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo0_l0000Hooooo`03o`000?oooooooooo00;ooooo0_l0000I
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool10000000000<00000oooo
ooooool07_ooool00ol0003oooooooooo`0Looooo`04o`000?ooooooooooo`00023ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`;o00001_ooool10000000000<00000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`;o00005oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Co00001_ooool00ol0003oooooooooo`0;ooooo`;o00001Oooool00ol0
003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00001Oooool3o`00
00Wooooo0_l00005ooooo`03o`000?oooooo000000Gooooo0_l0000Hooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000006?ooool2o`0000_ooooo0ol0000<ooooo`03o`000?oooooooooo
01_ooooo0@000000000300000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`00000[ooooo`03o`000?oooooo000000gooooo00Go0000ooooooooooooooooo`00000>oooo
o`;o00000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ool000001Oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
0000013ooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0_l000000ooooooo0000ooooo`0E
ooooo`04o`000?oooooo0000o`0000kooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo00Kooooo0@000000000300000?oooooooooo00?ooooo0_l0
000:ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Sooooo0_l0000^ooooo`;o00001Oooool2o`0000;ooooo00?o
0000ooooooooool02oooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02Oooool10000000000<00000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;o00000_ooool00ol0003oooooooooo`0Fooooo`09o`000?ooooooooooooooool0
003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool02oooool2o`0000oooooo00?o0000ooooooooool03ooo
ool01Ol0003ooooooooooooooooo000002;ooooo0_l00004ooooo`04o`000?oooooo0000o`0000?o
oooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0Booooo`40000000000`00003o
ooooooooo`04ooooo`;o00003oooool2o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo0ol00008ooooo`03o`000?oooooooooo01Ko
oooo1?l00006ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool4o`0000Ko
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`05o`000?oooooo0000ooooool000006_oo
ool00ol0003oooooooooo`03ooooo`?o00003?ooool01Ol0003oooooooooool0003ooooo00;o0000
0oooool4o`00023ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000Ko
oooo0@000000000300000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool2o`0001Gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0E?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool04oooool10000000000<00000ooooooooool04?ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo00cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo00?o
oooo0_l0000Booooo`?o00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Oo
oooo0ol00006ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool3o`0000Ko
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`06ooooo`40000000000`00003oooooooooo`03ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool00005
ooooo`?o00005?ooool4o`0000;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0001Sooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`00000;ooooo`04o`000?oooooo0000o`00023ooooo0_l0000?oooo
o`Co00001?ooool4o`0000Gooooo00?o0000ooooooooool05oooool2o`0000;ooooo00?o0000oooo
ooooool02_ooool10000000000<00000ooooooooool00oooool2o`0000_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00_l00006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool2o`0001Ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`;o00003oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000004_ooool10000
000000<00000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00oooool2o`0000Oooooo00?o0000ooooool000000ol0000Aooooo`?o000000?oooooo`00
0?ooool01_ooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool04?ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool3o`0000;ooooo00?o0000
ooooooooool00ol0000Oooooo`;o00001oooool00ol0003oooooooooo`04ooooo`?o00002Oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo0_l00008ooooo`03o`000?oo
oooooooo01Kooooo00Go0000ooooool0003o0000ooooo`02o`0000Cooooo00?o0000ooooooooool0
1Oooool10000000000<00000ooooooooool00oooool00ol0003oooooooooo`06ooooo`;o00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000Gooooo0_l000000ooooooo0000o`00
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000Oooooo00?o
0000ooooool000000_l00003ooooo`;o000000?oooooo`000?ooool02oooool2o`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l0
0002ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01Oooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo
0_l00005ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool00004ooooo`;o00000_ooool01?l0003oooooooooooooool10000000000<00000oooo
ooooool03oooool3o`0000?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`;o00000_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000000_l0000Booooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo
0_l000000ooooooo0000ooooo`02ooooo`;o00007_ooool00ol0003oooooooooo`0:ooooo`400000
00000`00003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool000001Ooo
ool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000003Oooool3o`000003oooo
ool0003ooooo00Gooooo0_l00003ooooo`03o`000?oooooooooo00oooooo0_l00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo1?l000000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00Kooooo0_l00002oooo
o`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooooooool2o`0000;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo0ol0
00001Ooooooo0000oooooooooooo000000?ooooo0ol000000ooooooo0000ooooo`02ooooo`?o0000
0_ooool01?l0003oooooooooool00005ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool0
0ol0003oooooooooo`0:ooooo`;o000000Coooooo`000?oooooo00000_ooool2o`0000Gooooo00?o
0000ooooooooool00oooool10000000000<00000ooooool000000oooool2o`0000cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo1?l00005ooooo`;o000000Coooooo`000?oooooooooo0_l0
00000ooooooo0000ooooo`0?ooooo`;o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00?o
0000ooooooooool00oooool2o`0000gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool2o`0000Gooooo00Co0000oooooooooooo
oooo0ol00003ooooo`03o`000?oooooooooo00;o00001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;o00002Oooool01?l0003oooooooooooooool3o`000005ooooool0003ooooo
ooooool000001Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000;o000000Co
ooooo`000?oooooo00001?ooool2o`000003ooooool0003o000001Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooo`000006ooooo`40000000000`00003oooooooooo`0?ooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo000001Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool0
1?ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Gooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000003oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`;o000000Coooooo`000?l0
003o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool2
o`000003ooooool0003o000000Cooooo00?o0000ooooooooool06oooool2o`0000cooooo0@000000
000300000?oooooooooo00Cooooo0_l0000>ooooo`;o000000Coooooo`000?oooooooooo0_l00005
ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00000oooool01_l0003oooooo`000?oooooo0000ooooo`;o000000Coooooo`00
0?l0003o00000oooool00ol0003oooooooooo`0:ooooo`?o00000oooool00ol0003oooooooooo`03
o`000003ooooool0003ooooo00Gooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003oooooo`000?oooooo000000Gooooo
00Co0000ooooool0003o00000oooool00ol0003oooooo`000003o`0000?ooooo00Go0000oooooooo
ooooooooo`000008ooooo`05o`000?oooooo0000ooooool000000oooool01_l0003oooooooooool0
003oooooo`0000Cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool00_l00004ooooo`;o00001?ooool00ol0003ooooo
o`000002o`0000Gooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`?o0000
00?oooooo`000?ooool00_ooool2o`0000Kooooo0@000000000300000?oooooooooo00?ooooo00Co
0000ooooool0003o00001oooool01?l0003oooooo`000?l00003ooooo`;o000000?oooooo`000?oo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00oooool2o`0000Gooooo1Ol000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?l000001?oooooo0000ooooool0000?ooooo`;o00000_ooool01_l0
003oooooooooool0003oooooo`0000Cooooo00?o0000ooooooooool00oooool2o`000004ooooool0
003o0000o`0000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool01Ol0003oooooo`000?oooooo000000[ooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo0000ooooool000001?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooo000000?ooooo0ol0000Fooooo`03o`000?oo
oooooooo00;ooooo00Co0000ooooool0003o00000oooool00ol0003oooooooooo`05ooooo`400000
00000`00003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o00003?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000005?ooool2o`000004
ooooool0003o0000o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02oooo
o`;o00003Oooool00ol0003oooooooooo`06ooooo`06o`000?ooooooooooo`000?oooooo00001ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`000008ooooo`;o00002Oooool2o`0000[ooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooooooool3o`000004ooooool0003oooooooooo`;o00002_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Gooooo0_l00006ooooo`40000000000`00003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000Oooooo0_l00003ooooo`;o00001?ooool01?l0003oooooooooooooool2
o`000003ooooool0003ooooo00?ooooo0ol00006ooooo`;o00001oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooool000000_ooool01?l0003oooooooooooooool3o`0000?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000o`0000Oooooo00?o0000
ooooooooool00_ooool2o`000004ooooool0003o0000o`0000Cooooo00Co0000ooooool0003o0000
1_ooool3o`0000Kooooo0_l00006ooooo`?o000000?oooooo`000?ooool00_ooool4o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooool000000_ooool2o`000004ooooool0003oooooo`0000;ooooo00Go0000oooo
ool0003oooooo`000003ooooo`04o`000?ooooooooooooooo`;o00000_ooool4o`000003ooooool0
003ooooo00?o000000Coooooo`000?oooooooooo0ol00002ooooo`03o`000?oooooooooo01Gooooo
0_l00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`40
000000000`00003oooooooooo`05ooooo`;o00001Oooool3o`0000Cooooo00?o0000ooooool00000
0_ooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`Co0000
00Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l00006ooooo`03o`000?oooooooooo00;o
oooo0_l000001?oooooo0000ooooool00003ooooo`?o000000Coooooo`000?oooooo00000_ooool2
o`000003ooooool0003ooooo00_ooooo0_l00003ooooo`06o`000?oooooo0000o`000?oooooo0000
0_ooool00ol0003oooooooooo`05ooooo`;o000000Goooooo`000?ooooooooooo`000005ooooo`03
o`000?oooooo000000;ooooo00Go0000ooooool0003oooooo`000006ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000ooooool0003ooooo0_l00003ooooo`;o00000oooool00ol0003oooooo`000005ooooo`04o`00
0?oooooo0000o`0000Cooooo00?o0000ooooool000000ol000000ooooooo0000o`000002ooooo`03
o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo1_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00@000000000300000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool3o`0000;o
oooo00Co0000oooooooooooo00000oooool2o`0000?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`06ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooo`000005
ooooo`;o00002_ooool00ol0003oooooooooo`08ooooo`06o`000?ooooooooooo`000?oooooo0000
1?ooool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000005ooooo`;o0000
1oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`00
0?ooool02?ooool00ol0003oooooooooo`06ooooo`;o00002_ooool00ol0003oooooooooo`02oooo
o`04o`000?oooooo0000o`0000_ooooo0_l00005ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`;o00000oooool3o`000005ooooool0003oooooooooool0
00000_ooool10000000000@00000oooooooooooo00000_ooool2o`0000Wooooo0ol000001?oooooo
0000o`000?ooool2o`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00005
ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oo
oooo000000Cooooo0_l00002ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool0
0_ooool01_l0003oooooooooool0003oooooo`00017ooooo0ol000001_oooooo0000ooooool0003o
ooooo`0000Oooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00Co0000ooooool0003o0000
0_ooool01Ol0003oooooo`000?oooooo000000Gooooo00?o0000ooooool000003?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool4o`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Cooooo0_l000000ooooooo
0000ooooo`02o`000003ooooool0003o000000Gooooo00?o0000ooooool000004_ooool01?l0003o
ooooooooooooool8o`000004ooooool0003o0000o`0000Kooooo0@000000000300000?oooooooooo
00?ooooo0_l00008ooooo`05o`000?oooooo0000ooooool000001?ooool3o`0000;ooooo0_l00002
ooooo`;o000000Coooooo`000?oooooooooo0_l00003ooooo`?o000000?oooooo`000?l000001?oo
ool00ol0003oooooooooo`04ooooo`06o`000?oooooo0000ooooool0003ooooo0_l00003ooooo`03
o`000?oooooooooo00;o000000Coooooo`000?oooooo00000_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo0_l00007ooooo`?o000000Soooooo`000?oooooo0000ooooool0
003oooooo`0000Sooooo00?o0000ooooooooool00_l000000ooooooo0000o`000004ooooo`03o`00
0?oooooooooo00Go00002?ooool2o`0000;ooooo00Co0000ooooool0003o00000oooool00ol0003o
ooooooooo`03o`000005ooooool0003oooooo`000?ooool00ol0000:ooooo`03o`000?oooooo0000
00;ooooo00Co0000oooooooooooooooo0_l000001?oooooo0000o`000?l00003ooooo`Go000000?o
ooooo`000?l000001?ooool3o`0000Kooooo00Co0000ooooool0003ooooo1?l000000ooooooo0000
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool3o`000003oooo
ool0003o000000;ooooo0_l00002ooooo`04o`000?oooooo0000o`0000Gooooo0@00000000030000
0?oooooooooo00oooooo00?o0000ooooooooool02?ooool2o`0000Cooooo00So0000oooooooooooo
0000ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03oooool4o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`00
000<ooooo`;o00000_ooool2o`000003ooooool0003ooooo00Go00002Oooool00ol0003oooooo`00
0008ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_l00006ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00oooool2o`0000Sooooo00Co0000ooooool0003o00001_ooool00ol0003o
ooooooooo`03o`0000Kooooo00Go0000ooooool0003oooooo`000006ooooo`03o`000?oooooooooo
00[ooooo0_l00002ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`40000000000`00003o
ooooooooo`03ooooo`?o00001oooool00ol0003oooooo`000003ooooo`06o`000?oooooo0000oooo
ool0003ooooo0ol00002ooooo`?o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000oooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000;ooooo1Ol0
0002ooooo`Ko00000_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo1_l00002ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00?o
00001_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00003oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`?o00000_ooool2o`0000Kooooo0ol000001_oo
oooo0000o`000?oooooo0000ooooo`Co000000?oooooo`000?ooool00_ooool00ol0003oooooo`00
0003o`000003ooooool0003ooooo00?ooooo00Co0000ooooool0003o00001Oooool01Ol0003ooooo
o`000?l0003ooooo00;o000000Coooooo`000?l0003o00001_ooool5o`0000?ooooo00Go0000oooo
ool0003oooooo`000007ooooo`?o00000_ooool2o`0000;ooooo00Oo0000oooooooooooo0000oooo
ool0003ooooo00;o00001?ooool10000000000<00000ooooool000000_ooool2o`000003ooooool0
003o000000Gooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00000_ooool2o`000003oooo
ool0003ooooo00;ooooo00[o0000ooooooooooooooooo`000?oooooo0000ooooool0003ooooo0ol0
00002?oooooo0000oooooooooooo0000ooooool0003ooooo0_l000001?oooooo0000o`000?l00002
ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool3o`0000Gooooo0_l000000ooooooo0000
o`000003ooooo`03o`000?oooooo000000Gooooo00Co0000ooooool0003ooooo0_l000000ooooooo
0000o`000002ooooo`;o00000_ooool2o`0000;ooooo0ol00008ooooo`06o`000?oooooooooooooo
ool0003ooooo1?l00002ooooo`04o`000?oooooo0000ooooo`Co00001Oooool2o`000004ooooool0
003oooooo`0000;ooooo0ol00003ooooo`05o`000?oooooo0000ooooool000000_ooool01?l0003o
ooooo`000?ooool2o`0000Cooooo00?o0000ooooooooool01?ooool6o`0000Gooooo00?o0000oooo
ooooool00_l00003ooooo`?o000000Coooooo`000?l0003o00001?ooool3o`000003ooooool0003o
000000Cooooo00Go0000ooooool0003o0000ooooo`02o`000007ooooool0003oooooooooool0003o
ooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Oo0000ooooooooooooooooo`000?oooooo
000000[ooooo0_l000001_oooooo0000oooooooooooo0000ooooo`Co00001?ooool10000000000<0
0000ooooooooool01_ooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00?ooooo
0_l00002ooooo`Co00000_ooool2o`0000;ooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`?o00000_ooool01?l0003oooooooooooooool5o`0000Cooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00_ooooo0_l000001_oooooo0000oooooooooooo0000ooooo`?o
00001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooool000002oooool01?l0003oooooo`000?oo
ool4o`0000;ooooo00Co0000oooooooooooo00001?ooool2o`000003ooooool0003o000000Kooooo
00?o0000ooooool000001Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00ol000000ooooooo
0000o`000002ooooo`03o`000?oooooooooo00Kooooo0@000000000300000?oooooooooo00Cooooo
0ol00004ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000004oooo
ool0003oooooooooo`;o000000Coooooo`000?oooooooooo0_l000000ooooooo0000ooooo`03oooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00000oooool00ol0
003oooooo`000004o`000003ooooool0003ooooo00;o00000oooool2o`0000Oooooo00?o0000oooo
ooooool00_ooool2o`0000;ooooo2_l00002ooooo`Co000000?oooooo`000?l000000_l000001?oo
oooo0000ooooooooool2o`0000?ooooo00?o0000ooooooooool01Ol000000ooooooo0000o`000004
ooooo`;o00001?ooool00ol0003oooooooooo`04o`000008ooooool0003o0000ooooool0003ooooo
o`000?ooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`?o000000Ooooooo`000?l0
003oooooo`000?oooooo000000?ooooo00Go0000ooooool0003oooooo`000002ooooo`;o000000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`Oo00000_ooool01?l0003oooooo`00
0?l00002ooooo`05o`000?ooooooooooooooool000001?ooool4o`000005ooooool0003ooooooooo
ool000000oooool2o`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Kooooo0_l00002ooooo`Ko000000?oooooo`000?l000000ol000001_oooooo0000oooooooo
oooo0000ooooo`40000000001@00003ooooooooooooooooo000000;ooooo0_l00002ooooo`;o0000
0_ooool3o`000003ooooool0003o000000;o00000_ooool00ol0003oooooooooo`02o`000003oooo
ool0003ooooo00Co00000_ooool3o`000003ooooool0003o000000;o00002?ooool01?l0003ooooo
ooooool00003ooooo`;o000000Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000005o`00
00Gooooo00Co0000oooooooooooooooo0ol00002ooooo`;o00000_ooool3o`0000;ooooo0ol00002
ooooo`Ko00000_ooool00ol0003oooooooooo`02o`0000Gooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Cooooo0_l000000ooooooo0000o`000003ooooo`Go00000oooool3o`000003oooo
ool0003o000000?o000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool00ol0003ooooo
o`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool3o`000003oooo
ool0003o000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l000000ooo
oooo0000ooooo`02o`000003ooooool0003o000000;ooooo0_l00002ooooo`?o00000_ooool6o`00
0003ooooool0003o000000Cooooo00Co0000ooooool0003ooooo0ol000001?oooooo0000oooooooo
ool3o`0000;ooooo0_l00006ooooo`04o`000?oooooo0000ooooo`Oo00000_ooool00ol0003ooooo
ooooo`02o`0000;ooooo0Ol00001ooooo`40000000000`00003oooooo`000003ooooo`;o00000_oo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooo`000?ooool00_l00003ooooo`Co
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o000000Ooooooo`00
0?ooooooooooo`000?oooooo000000Gooooo00Co0000ooooool0003o00001Oooool2o`000005oooo
ool0003oooooooooool000001_ooool01?l0003oooooo`000?l00002ooooo`06o`000?oooooooooo
o`000?oooooo00000_ooool01?l0003oooooooooooooool4o`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`000002o`0000Cooooo00Go0000oooooooooooo0000ooooo`02o`0000Ko
oooo0_l000001?oooooo0000ooooool00003ooooo`;o00000_ooool00ol0003oooooooooo`02oooo
o`0:o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooo`Co00000oooool00ol0003o
ooooooooo`02o`000004ooooool0003o0000ooooo`;o00000_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_oo
ool01Ol0003oooooo`000?oooooo000000;ooooo0ol000000ooooooo0000ooooo`03ooooo`Co0000
0oooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooo00000oooool01ol0003o
ooooooooool0003oooooo`000?ooool00_l000000ooooooo0000o`000002ooooo`?o00001Oooool0
0ol0003oooooooooo`010000000000<00000ooooool000000_l00002ooooo`?o00000_ooool00ol0
003oooooooooo`02o`000003ooooool0003ooooo00?o00000oooool00ol0003oooooo`000003o`00
0004ooooool0003oooooooooo`Co000000?oooooo`000?ooool01Ol000000ooooooo0000o`000003
ooooo`Co000000?oooooo`000?ooool01?ooool01?l0003oooooo`000?l00002ooooo`Co000000Ko
ooooo`000?l0003o0000ooooool00004ooooo`03o`000?oooooooooo00;o00000_ooool2o`0000;o
oooo0ol00002ooooo`Oo000000Ooooooo`000?oooooo0000ooooool0003ooooo00Go00000oooool4
o`0000;ooooo2?l00002ooooo`;o000000?oooooo`000?l000000_l000001_oooooo0000ooooool0
003oooooo`0000;ooooo00Co0000ooooool0003o00000_ooool3o`000003ooooool0003o000000?o
000000Goooooo`000?l0003o0000ooooo`03o`000006ooooool0003oooooo`000?oooooo00000_oo
ool2o`000003ooooool0003o000000Ko000000?oooooo`000?l000001?l000001Ooooooo0000oooo
ool0003ooooo00?o000000?oooooo`000?ooool00ol00004ooooo`;o000000?oooooo`000?ooool0
1ol000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooool0
00000ol000000ooooooo0000ooooo`03o`0000Gooooo00Co0000oooooooooooooooo0_l000001?oo
oooo0000ooooooooool3o`000003ooooool0003o000000Ko000000Coooooo`000?oooooooooo0@00
0000000400000?ooooooooooo`0000?ooooo0ol000001Ooooooo0000ooooool0003ooooo00_o0000
0_ooool01Ol0003oooooo`000?l0003ooooo00;o00000_ooool4o`000003ooooool0003o000000Go
00000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`03o`000?oooooo000000Oo
000000?oooooo`000?ooool00_l000000ooooooo0000o`000004o`0000?ooooo1?l00005ooooo`;o
000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000Oo00000_ooool00ol0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool5o`000005ooooool0003o
ooooo`000?ooool00_l000001?oooooo0000o`000?ooool3o`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000ooooo`05o`000004ooooool0003oooooooooo`;o000000Koooooo`00
0?ooooooooooo`000?ooool5o`000003ooooool0003o000000;ooooo00Go0000oooooooooooo0000
ooooo`02o`000003ooooool0003ooooo00[o000000Koooooo`000?l0003oooooo`000?ooool2o`00
00;ooooo0ol00002ooooo`?o000000?oooooo`000?ooool01?l000000ooooooo0000o`00000:o`00
0005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000006o`0000;ooooo00Go0000
oooooooooooo0000ooooo`09o`0000;ooooo00?o0000ooooool000001?l00002ooooo`4000000000
1000003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00Oo0000ooooool0003o0000
ooooool0003ooooo00;o000000Coooooo`000?l0003ooooo0_l000001_oooooo0000ooooool0003o
ooooo`0000;ooooo00?o0000ooooooooool01?l000000ooooooo0000ooooo`03ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool00ooo
ool3o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_ooool3o`000003ooooool0
003ooooo00;ooooo0_l00004ooooo`?o000000Goooooo`000?ooooooooooo`000007ooooo`04o`00
0?oooooo0000ooooo`?o00000oooool01?l0003oooooooooool00002ooooo`;o00000_ooool02Ol0
003ooooooooooooooooo0000ooooool0003oooooo`000002ooooo`;o00000oooool01?l0003ooooo
o`000?l00004ooooo`;o000000Goooooo`000?oooooo0000ooooo`06o`0000;ooooo0_l00002oooo
o`03o`000?oooooo000000Cooooo00?o0000ooooool000000oooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool00oooool01Ol0003oooooo`000?oooooo000000Gooooo00?o0000ooooooooool00_oo
ool3o`0000Cooooo00?o0000ooooool000000_ooool2o`0000?ooooo0ol00002ooooo`05o`000?oo
ooooooooooooool000002?ooool2o`0000?ooooo1?l000000ooooooo0000ooooo`04ooooo`03o`00
0?oooooooooo00;ooooo0@000000000500000?oooooo0000o`000?ooool00ol000002?oooooo0000
o`000?l0003oooooo`000?oooooo00000_ooool3o`000004ooooool0003o0000ooooo`Co00000_oo
ool2o`0000;ooooo00?o0000ooooool000000_l000000ooooooo0000o`000008o`000003ooooool0
003ooooo00;o00000_ooool3o`000005ooooool0003o0000o`000?ooool01?l00002ooooo`;o0000
0oooool2o`000005ooooool0003o0000ooooool000000oooool00ol0003oooooo`000002ooooo`;o
00000_ooool6o`000003ooooool0003o000000;o00000_ooool2o`000004ooooool0003ooooooooo
o`So00000oooool00ol0003oooooooooo`06o`000007ooooool0003o0000o`000?oooooo0000oooo
o`04o`000003ooooool0003ooooo00;ooooo0_l000001?oooooo0000o`000?ooool7o`000005oooo
ool0003oooooo`000?ooool00ol00003ooooo`Oo00001?ooool2o`000003ooooool0003o000000;o
00000_ooool5o`000004ooooool0003o0000o`0000;ooooo00?o0000ooooool000000_l000000ooo
oooo0000ooooo`03o`000003ooooool0003ooooo00Ko000000Goooooo`000?oooooo0000ooooo`02
o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l000000oooool3o`0000?ooooo00Co
0000ooooool0003ooooo1ol000000ooooooo0000ooooo`04ooooo`03o`000?oooooo000000;o0000
00?oooooo`000?l000001_l00002ooooo`40000000001000003oooooooooooooool7o`0000;ooooo
1Ol000000ooooooo0000o`00000>o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_l000001Ooooooo0000o`000?l0003ooooo00Oo000000Goooooo`000?l0003o0000ooooo`03o`00
0003ooooool0003o000000Go000000Coooooo`000?oooooooooo1_l000001?oooooo0000oooooooo
ool4o`000003ooooool0003o000000Ko000000?oooooo`000?l000000ol000000ooooooo0000o`00
000;o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_l000000ooooooo0000o`00
0005o`000003ooooool0003ooooo00;o00000oooool3o`000004ooooool0003oooooooooo`;o0000
00?oooooo`000?ooool00ol000000ooooooo0000o`000004o`000003ooooool0003o000000Go0000
0_ooool6o`0000?ooooo00?o0000ooooool000002?l000000ooooooo0000o`000004o`000006oooo
ool0003o0000o`000?oooooo00001_ooool5o`0000;ooooo00Go0000ooooool0003oooooo`000002
ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000009o`0000;ooooo00?o0000
ooooooooool01?l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000000ol00000
0ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o00000Oooool10000000000<00000
ooooool000001Oooool2o`0000;ooooo1?l00002ooooo`05o`000?ooooooooooo`000?ooool01_l0
00000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool0
0_ooool2o`000003ooooool0003o000000;ooooo00Co0000ooooool0003ooooo1?l00005ooooo`03
o`000?oooooo000000;ooooo00Ko0000ooooool0003oooooo`000?ooool4o`0000;ooooo0_l00002
ooooo`?o000000?oooooo`000?ooool00ol00006ooooo`03o`000?oooooo000000;o000000?ooooo
o`000?l000000_ooool00ol0003oooooo`000003o`000004ooooool0003oooooooooo`Co00000_oo
ool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool00oooool2o`000005ooooool0
003o0000ooooool000000_ooool3o`000003ooooool0003o000000;o000000Coooooo`000?l0003o
oooo0_l00002ooooo`04o`000?oooooo0000ooooo`?o00000_ooool2o`000003ooooool0003o0000
00;o00000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000?ooooo0_l000001?oo
oooo0000o`000?ooool3o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?ooool00_oo
ool2o`000003ooooool0003o000000?o000000?oooooo`000?ooool01_ooool3o`000003ooooool0
003o000000?ooooo0_l00002ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l000001?l0
0006ooooo`?o000000?oooooo`000?l000000ol000000ooooooo0000ooooo`03o`000004ooooool0
003oooooooooo`40000000001P00003oooooo`000?oooooo0000ooooo`;o000000?oooooo`000?l0
00003?l000001Ooooooo0000o`000?l0003ooooo00_o000000?oooooo`000?l000000_l000001Ooo
oooo0000o`000?l0003ooooo00_o000000?oooooo`000?l000001_l000001?oooooo0000o`000?oo
ool2o`000004ooooool0003oooooooooo`Co000000?oooooo`000?ooool03?l000001?oooooo0000
o`000?ooool3o`000005ooooool0003oooooo`000?ooool00_l000001Ooooooo0000o`000?l0003o
oooo00Co000000?oooooo`000?l000000_ooool00ol0003oooooooooo`02o`000005ooooool0003o
0000o`000?ooool02?l000000ooooooo0000o`000002o`000003ooooool0003ooooo00Co000000Go
ooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000Wo000000?oooooo`000?l00000
1Ol00002ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Go000000Coooooo`000?oooooo
oooo0ol000001Ooooooo0000ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`05
o`000003ooooool0003ooooo00;ooooo0_l00002ooooo`?o000000?oooooo`000?l000001_l00000
0ooooooo0000o`00000;o`000003ooooool0003o000000;ooooo00?o0000ooooool000001Ol00000
1Ooooooo0000o`000?l0003ooooo00?o000000Koooooo`000?ooooooooooo`000?ooool100000000
00<00000ooooooooool00ol000000ooooooo0000o`000005o`000004ooooool0003o0000ooooo`Go
000000?oooooo`000?l000002?l000000ooooooo0000o`00000Do`0000;ooooo2Ol000000ooooooo
0000o`000002o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?l000000_l000000ooo
oooo0000o`000003o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo1ol00003
ooooo`04o`000?oooooo0000ooooo`ko000000Goooooo`000?l0003o0000ooooo`07o`000003oooo
ool0003o000000Co00000_ooool2o`000003ooooool0003ooooo00?o000000?oooooo`000?l00000
1_l000000ooooooo0000o`00000<o`000003ooooool0003o000000go000000Coooooo`000?l0003o
oooo3?l000001Ooooooo0000ooooool0003ooooo00?o000000?oooooo`000?l000002Ol000000ooo
oooo0000ooooo`04o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_l000000ooo
oooo0000ooooo`05o`000003ooooool0003o000000Co000000?oooooo`000?l000002ol00002oooo
o`40000000000`00003oooooo`000002o`000005ooooool0003oooooo`000?ooool00_l000001?oo
oooo0000o`000?ooool2o`0000;ooooo00Ko0000ooooool0003o0000ooooool00002ooooo`05o`00
0?ooooooooooooooool000000_ooool5o`0000;ooooo1?l000000ooooooo0000o`000002o`0000?o
oooo00Go0000oooooooooooo0000ooooo`03o`0000;ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`02ooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool2o`000003oooo
ool0003o000000;o000000Coooooo`000?l0003ooooo0_l00002ooooo`co000000?oooooo`000?oo
ool00ol000001?oooooo0000o`000?l00002ooooo`co000000?oooooo`000?ooool00_l00002oooo
o`Go000000?oooooo`000?l000000_l00002ooooo`?o000000?oooooo`000?l000000ol000000ooo
oooo0000ooooo`06o`000003ooooool0003ooooo00?o000000Coooooo`000?l0003o00000oooool0
1Ol0003oooooooooool0003ooooo00Go000000?oooooo`000?ooool01Ol00005ooooo`Go000000Co
ooooo`000?l0003o00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000o`00
0?ooool00ol00006ooooo`Wo00000_ooool00ol0003oooooooooo`04o`000005ooooool0003o0000
o`000?ooool01?l000000ooooooo0000o`000002o`0000;ooooo1?l000000ooooooo0000ooooo`02
ooooo`?o00000_ooool10000000000D00000ooooool0003o0000ooooo`0;o`000004ooooool0003o
0000ooooo`;o000000?oooooo`000?l000001?l000000ooooooo0000o`000009o`000003ooooool0
003o000000[o000000?oooooo`000?l000001ol000000ooooooo0000o`000006o`000003ooooool0
003o000000Go000000Goooooo`000?l0003o0000ooooo`09o`0000Gooooo00?o0000ooooool00000
0ol000000ooooooo0000ooooo`0Lo`000003ooooool0003o000000Go000000?oooooo`000?l00000
1ol000000ooooooo0000o`000002o`000003ooooool0003o000000Go000000?oooooo`000?l00000
0_ooool;o`000006ooooool0003o0000o`000?oooooo00000_ooool01?l0003oooooo`000?ooool3
o`0000;ooooo0_l000000ooooooo0000o`000004o`000005ooooool0003o0000o`000?ooool00ol0
00000ooooooo0000o`00000>o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?l00000
1Ol00002ooooo`_o000000?oooooo`000?l000000ol000000ooooooo0000o`000005o`000003oooo
ool0003o000000Go00000Oooool10000000000<00000ooooooooool04Ol000000ooooooo0000o`00
000Go`000003ooooool0003o000000Go000000?oooooo`000?l000001_l00002ooooo`So000000?o
ooooo`000?ooool01?ooool8o`000003ooooool0003o000000?o000000?oooooo`000?l000002_l0
0003ooooo`Ko000000Goooooo`000?l0003o0000ooooo`0=o`000003ooooool0003o000000So0000
00Goooooo`000?l0003o0000ooooo`04o`0000;ooooo7Ol000000ooooooo0000o`000007o`000003
ooooool0003o000000_o00000_ooool<o`000003ooooool0003o000000?o000000?oooooo`000?l0
00002?l000001?oooooo0000o`000?l00002ooooo`Go000000?oooooo`000?l000002Ol00002oooo
o`Go000000?oooooo`000?ooool02Ol000001Ooooooo0000o`000?l0003ooooo0040000000001000
003oooooo`000?ooool4o`000003ooooool0003ooooo00?o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000003o`000008ooooool0003o0000ooooool0003oooooo`000?ooool2o`00
0003ooooool0003o000000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00Wo000000?ooooo
o`000?l000000ol000000ooooooo0000ooooo`02o`000003ooooool0003ooooo00Cooooo00Co0000
ooooool0003ooooo1ol000001_oooooo0000o`000?oooooo0000ooooo`;o000000Coooooo`000?oo
oooo00000oooool5o`000003ooooool0003ooooo00;ooooo0ol000001?oooooo0000o`000?ooool3
o`000003ooooool0003o000000?o000000Coooooo`000?l0003o00001?ooool2o`000003ooooool0
003o000000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo0ol000000ooooooo0000
o`000006o`0000;ooooo00?o0000ooooool000002ol000000ooooooo0000o`000003o`000007oooo
ool0003oooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000?o00000_ooool00ol0
003oooooo`000004o`000004ooooool0003oooooooooo`So000000Goooooo`000?l0003o0000oooo
o`08o`0000;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002ooooo`So0000
00?oooooo`000?l000000ol000001Ooooooo0000oooooooooooo000000;ooooo00Ko0000ooooool0
003oooooo`000?ooool3o`000003ooooool0003ooooo0040000000000`00003oooooo`00000no`00
0005ooooool0003o0000o`000?ooool01?l00002ooooo`go000000?oooooo`000?l000001_l00000
0ooooooo0000o`000007o`000003ooooool0003o000000oo000000?oooooo`000?l000001Ol00000
0ooooooo0000o`00000>o`0000;ooooo4ol000001Ooooooo0000o`000?l0003ooooo013o000000?o
ooooo`000?l000003_l000000ooooooo0000o`000008o`000003ooooool0003o000000[o000000?o
ooooo`000?l000008?l000000ooooooo0000o`000009o`000003ooooool0003o000000;o00000Ooo
ool10000000000<00000ooooool000001_l000000ooooooo0000o`000004o`000004ooooool0003o
0000ooooocSo00000_oooolCo`000004ooooool0003o0000ooooo`;o000000Ooooooo`000?l0003o
0000ooooool0003ooooo01?o000000?oooooo`000?l000002?l000000ooooooo0000o`000008o`00
0003ooooool0003o000000ko000000?oooooo`000?l00000:?l000000ooooooo0000o`000008o`00
0003ooooool0003o000000?o000000?oooooo`000?l000001?l000001?oooooo0000o`000?ooool6
o`000003ooooool0003o000001;o000000?oooooo`000?l000004Ol00001ooooo`40000000000`00
003oooooooooo`08o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000ooooo`02o`00
0005ooooool0003oooooo`000?ooool00_l000000ooooooo0000o`000004ooooo`03o`000?oooooo
oooo00;o00000oooool2o`000003ooooool0003ooooo00co00001?ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooooooo00?ooooo1?l000000ooooooo0000ooooo`0:o`000006ooooool0
003o0000ooooool0003ooooo1?l00002ooooo`03o`000?oooooooooo00Ko00000_ooool01Ol0003o
ooooo`000?l0003ooooo00?o000000Coooooo`000?l0003o00000_ooool;o`000004ooooool0003o
0000o`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo0_l00002ooooo`Ko0000
00Coooooo`000?oooooooooo1ol000001?oooooo0000o`000?ooool6o`000004ooooool0003o0000
o`0000;ooooo00?o0000ooooooooool00_l000000ooooooo0000o`000003ooooo`?o000000?ooooo
o`000?l000002Ol000000ooooooo0000ooooo`02ooooo`Co000000?oooooo`000?l000001?l00000
1Ooooooo0000o`000?oooooo000000;ooooo00?o0000ooooooooool02Ol000000ooooooo0000o`00
0006o`0000;ooooo0_l00002ooooo`Co00000_ooool00ol0003oooooooooo`06o`00007ooooo0@00
0000000300000?oooooo000000go000000?oooooo`000?l000002Ol000000ooooooo0000o`000003
o`000003ooooool0003o000000?o000000?oooooo`000?l000003?l000000ooooooo0000o`000008
o`000003ooooool0003ooooo00Co000000?oooooo`000?l000004?l000000ooooooo0000o`000002
o`000003ooooool0003o000000Ko000000?oooooo`000?l000002Ol000000ooooooo0000o`00000P
o`000003ooooool0003o000002Ko00000_ooool<o`000005ooooool0003o0000o`000?ooool01_l0
00000ooooooo0000o`00000<o`0000;ooooo<?l000000ooooooo0000ooooo`010000000000<00000
ooooool000008_l000000ooooooo0000o`000002o`000003ooooool0003o000000Go000000?ooooo
o`000?l000005?l000000ooooooo0000ooooo`0Go`000003ooooool0003o000000Wo000000?ooooo
o`000?l000006ol000001Ooooooo0000o`000?l0003ooooo00So000000?oooooo`000?l000000ol0
00000ooooooo0000o`00000jo`000003ooooool0003o000000[o00000ooooolRo`000003ooooool0
003o000000Co000000?oooooo`000?ooool01Ol00001ooooo`40000000000`00003oooooo`000004
o`000003ooooool0003o000000Co000000Goooooo`000?oooooo0000ooooo`05o`0000;ooooo0ol0
00000ooooooo0000o`000004ooooo`;o00000oooool7o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001?l000000ooooooo0000o`000002o`000003ooooool0003o000000Ko00001?oo
ool3o`000003ooooool0003o000001;o00000_ooool4o`000003ooooool0003ooooo00Go000000?o
ooooo`000?l000001_l000000ooooooo0000o`000005o`000003ooooool0003ooooo00;o000000Co
ooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool5o`000003ooooool0003o000000;o
000000?oooooo`000?l000001Ol000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`00
0?l000002?l000000ooooooo0000o`000003o`000003ooooool0003o000000Co000000?oooooo`00
0?l000001ol00003ooooo`?o00000_ooool5o`000005ooooool0003oooooo`000?ooool00_l00002
ooooo`;o000000Coooooo`000?oooooooooo2Ol000001Ooooooo0000ooooool0003ooooo00?o0000
0_ooool;o`0000;ooooo0_l00002ooooo`ko00000Oooool10000000000<00000ooooool000007_l0
00000ooooooo0000o`00001Ao`000003ooooool0003o000002So000000?oooooo`000?l000001Ol0
00000ooooooo0000o`000007o`000003ooooool0003o0000037o000000?oooooo`000?l000001?l0
00001?oooooo0000o`000?ooool]o`00007ooooo0@000000000300000?oooooo000000Wo000000Ko
ooooo`000?l0003o0000ooooool00003ooooo`Ko000000?oooooo`000?ooool01Ol000001_oooooo
0000o`000?l0003oooooo`0000;ooooo1ol000000ooooooo0000o`000003o`000003ooooool0003o
000000Co00000oooool00ol0003oooooo`000007o`000004ooooool0003o0000ooooo`?o000000?o
ooooo`000?l000001_l000000ooooooo0000o`000002o`000006ooooool0003o0000ooooool0003o
oooo1_l00002ooooo`Go000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo
00?o000000Ooooooo`000?l0003o0000ooooool0003ooooo00Co00000_ooool9o`000005ooooool0
003oooooo`000?ooool01?l00002ooooo`Co000000Ooooooo`000?l0003o0000ooooool0003ooooo
01Oo000000Koooooo`000?oooooo0000ooooool00002ooooo`;o000000?oooooo`000?l000004?l0
00001?oooooo0000ooooooooool4o`0000;ooooo00?o0000ooooooooool01_l000000ooooooo0000
o`000002o`000003ooooool0003o000000Co000000?oooooo`000?ooool06ol00001ooooo`400000
00000`00003oooooo`00000No`000003ooooool0003o000000Go000000?oooooo`000?l000005Ol0
00000ooooooo0000o`00000Po`000003ooooool0003o000000Ko000000?oooooo`000?l000006_l0
00000ooooooo0000o`00000Lo`000003ooooool0003o000001?o000000Koooooo`000?l0003ooooo
o`000?ooool<o`000003ooooool0003o000001oo000000?oooooo`000?l000000_l000000ooooooo
0000o`00000@o`000003ooooool0003o0000013o00000Oooool10000000000<00000ooooool00000
7_l000000ooooooo0000o`000007o`000003ooooool0003o000006?o000000?oooooo`000?l00000
5?l000000ooooooo0000o`000005o`000003ooooool0003o000001_o000000?oooooo`000?l00000
3?l000000ooooooo0000o`00000=o`000003ooooool0003o000000go000000?oooooo`000?l00000
5?l000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`40000000000`00003ooooo
o`000003o`000003ooooool0003ooooo00Oo00001?ooool=o`0000;ooooo00?o0000ooooool00000
1_l00002oooooa3o000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`000003oooo
ool0003o000000;o000000?oooooo`000?l000002Ol000000ooooooo0000o`000003o`0000?ooooo
00?o0000ooooool000000_l00002ooooo`04o`000?oooooo0000o`0000;ooooo0_l000001?oooooo
0000ooooooooool4o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000o`000004
o`000007ooooool0003o0000o`000?oooooo0000ooooo`09o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000000_l000001?oooooo0000ooooooooool5o`000003ooooool0003o0000
00Go000000?oooooo`000?l000001?l000001Ooooooo0000o`000?l0003ooooo00Ko00000oooool0
0ol0003oooooo`000002o`000003ooooool0003o000000Oo00000_ooool9o`000004ooooool0003o
0000o`0000;ooooo0_l000000ooooooo0000ooooo`04o`000004ooooool0003o0000ooooo`Oo0000
00?oooooo`000?l000001ol000001?oooooo0000o`000?l00002ooooo`Go000000?oooooo`000?l0
00001Ol00002ooooo`40000000000`00003oooooo`000005o`000003ooooool0003o000001ko0000
00?oooooo`000?l000007Ol000000ooooooo0000o`00000Oo`000004ooooool0003oooooooooo`Ko
00000_ooool7o`000003ooooool0003o000000Co000000?oooooo`000?l000004ol000000ooooooo
0000o`00000@o`000003ooooool0003o000001Wo000000?oooooo`000?l000000ol000000ooooooo
0000o`00000Go`0000;ooooo1ol000000ooooooo0000o`00000Ho`000003ooooool0003o000000go
00000Oooool10000000000<00000ooooool000004?l000000ooooooo0000o`00000Lo`000003oooo
ool0003o000000[o000000?oooooo`000?l000001ol000000ooooooo0000o`00000Ro`000003oooo
ool0003o000001So000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`000004oooo
ool0003o0000ooooo`Oo000000?oooooo`000?l000003_l000000ooooooo0000o`00000bo`000003
ooooool0003o000000;o00000_ooool3o`000003ooooool0003o000000Ko000000?oooooo`000?l0
00006_l000001Ooooooo0000o`000?l0003ooooo00?o00000Oooool10000000000@00000ooooool0
003ooooo0ol00002ooooo`Ko00000_ooool2o`000003ooooool0003o000000?o000000?oooooo`00
0?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`00000Do`00
0003ooooool0003ooooo00;o000000Koooooo`000?l0003o0000ooooool00002ooooo`03o`000?oo
oooo000000Go000000?oooooo`000?l000001_l000001?oooooo0000o`000?l00003ooooo`03o`00
0?oooooo000000;o000000Coooooo`000?l0003ooooo3_l000000ooooooo0000o`000005o`000004
ooooool0003o0000ooooo`Wo000000?oooooo`000?l000001Ol000000ooooooo0000o`000002o`00
0005ooooool0003oooooo`000?ooool00_l000000ooooooo0000o`000002o`0000?ooooo0ol00000
0ooooooo0000o`000002o`000003ooooool0003o000000_o00000_ooool2o`000004ooooool0003o
0000ooooo`?o000000?oooooo`000?l000000_l00003ooooo`03o`000?oooooo000000Co000000?o
ooooo`000?l000001Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool0
1Ol000000ooooooo0000ooooo`02o`000003ooooool0003o000000;o000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000006o`0000;ooooo1?l000001?oooooo0000ooooool00002ooooo`05
o`000?ooooooooooo`000?ooool00@000000000300000?oooooo000000oo000000?oooooo`000?l0
00002ol000000ooooooo0000o`00000Co`000003ooooool0003o000000co000000?oooooo`000?l0
00006Ol000000ooooooo0000o`00000Mo`000003ooooool0003o000000go000000?oooooo`000?l0
00007_l000000ooooooo0000o`00000No`000003ooooool0003o000000ko000000?oooooo`000?l0
00001Ol000000ooooooo0000o`00000_o`00007ooooo0@000000000300000?oooooo000000Co0000
00?oooooo`000?l000002?l000000ooooooo0000ooooo`0Fo`000003ooooool0003o000000Wo0000
00?oooooo`000?l000001ol000000ooooooo0000o`000002o`000003ooooool0003o000001So0000
00?oooooo`000?l000001ol000000ooooooo0000o`00000Qo`000003ooooool0003o000000Go0000
0ooooolGo`000003ooooool0003o000001oo000000?oooooo`000?l000000ol000000ooooooo0000
o`000009o`000003ooooool0003o000000;o000000?oooooo`000?l000007?l000000ooooooo0000
o`000006o`000003ooooool0003o000000Wo00000Oooool10000000000<00000ooooool000000ol0
0003ooooo`_o000000?oooooo`000?l000000ol000000ooooooo0000o`000003o`000004ooooool0
003o0000ooooo`ko000000?oooooo`000?ooool00ol000000ooooooo0000o`000008o`0000;ooooo
00?o0000ooooool000001?l000000ooooooo0000o`00000:o`0000;ooooo1?l00002ooooo`;o0000
00?oooooo`000?l000000ol000000ooooooo0000ooooo`04o`000005ooooool0003oooooo`000?oo
ool00ol000000ooooooo0000o`00000;o`000003ooooool0003o000000;o000000?oooooo`000?oo
ool01?l000000ooooooo0000ooooo`02o`000006ooooool0003o0000ooooool0003ooooo0_l00002
ooooo`;o00000_ooool6o`000003ooooool0003ooooo00Co00000_ooool00ol0003oooooo`000003
o`000003ooooool0003ooooo00;o000000?oooooo`000?l000000_l00002ooooo`Co000000?ooooo
o`000?l000001?l00002ooooo`?o000000?oooooo`000?l000001?l000000ooooooo0000o`000006
o`000005ooooool0003o0000o`000?ooool02?l00002ooooo`Co000000?oooooo`000?l000001Ol0
00001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?ooool01?l000000ooooooo0000
o`000002ooooo`04o`000?oooooo0000ooooo`Ko00000Oooool10000000000<00000ooooool00000
3ol000000ooooooo0000o`00000Ho`000003ooooool0003o000000_o000000?oooooo`000?l00000
7_l000000ooooooo0000o`000006o`000003ooooool0003o000000?o00000_ooool01Ol0003ooooo
o`000?l0003ooooo01So000000?oooooo`000?l000000_l000000ooooooo0000o`000008o`000003
ooooool0003o0000013o000000?oooooo`000?ooool02Ol000000ooooooo0000o`00000Eo`000003
ooooool0003o000000Oo00000_ooool6o`000003ooooool0003o000000Oo000000?oooooo`000?l0
00000_l000000ooooooo0000o`000007o`000003ooooool0003o000001oo00000Oooool100000000
00<00000ooooool000003?l000000ooooooo0000o`00000Po`000003ooooool0003ooooo00;ooooo
5Ol00003ooooo`03o`000?oooooo000001co00000_ooool<o`000003ooooool0003o000000Co0000
00?oooooo`000?l000003?l000000ooooooo0000o`000006o`000003ooooool0003o000001?o0000
00?oooooo`000?l000007ol000000ooooooo0000o`000005o`000003ooooool0003o000000Wo0000
00?oooooo`000?ooool00ol000000ooooooo0000o`00000;o`000003ooooool0003ooooo00_o0000
00?oooooo`000?l000002_l000000ooooooo0000o`000005o`00007ooooo0@000000000500000?oo
oooo0000o`000?ooool01_l000000ooooooo0000o`000005o`000003ooooool0003o000000;o0000
0_ooool5o`000003ooooool0003o000000?o000000Goooooo`000?oooooo0000ooooo`03o`0000?o
oooo0ol000000ooooooo0000ooooo`03o`0000;ooooo0_l000000ooooooo0000ooooo`03o`000004
ooooool0003o0000ooooo`?o000000?oooooo`000?l000001_l00002ooooo`Go000000Koooooo`00
0?l0003oooooo`000?ooool3o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol0
00000ooooooo0000o`000006o`000003ooooool0003o000000Ko000000?oooooo`000?l000001_l0
00000ooooooo0000o`000002ooooo`Oo000000?oooooo`000?l000001_ooool4o`000003ooooool0
003ooooo00?o000000?oooooo`000?ooool00_l000000ooooooo0000ooooo`04o`000003ooooool0
003ooooo00;o000000Coooooo`000?l0003ooooo0_l00002ooooo`04o`000?oooooo0000o`0000;o
oooo00?o0000ooooool000000_l00002ooooo`Ko000000?oooooo`000?ooool00ol00002ooooo`03
o`000?oooooo000000;ooooo0_l000001Ooooooo0000ooooool0003ooooo00?o00000_ooool3o`00
0005ooooool0003o0000o`000?ooool01ol00002ooooo`Co000000?oooooo`000?ooool01_l00000
2Ooooooo0000o`000?l0003oooooo`000?oooooo0000ooooo`02o`000003ooooool0003o000000;o
000000?oooooo`000?ooool00@000000000300000?oooooooooo00?o000000?oooooo`000?l00000
2_l000000ooooooo0000o`00000Do`000004ooooool0003oooooooooo`?o000000?oooooo`000?l0
00003_l000000ooooooo0000o`00000?o`000004ooooool0003o0000oooooa3o000000?oooooo`00
0?l000002_l000000ooooooo0000o`000002o`000003ooooool0003o000001[o00000_ooool2o`00
0003ooooool0003o000000_o000000?oooooo`000?l000003Ol000000ooooooo0000o`00000=o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000003ol000001Ooooooo0000o`000?l0003o
oooo00?o000000?oooooo`000?ooool03ol000000ooooooo0000o`000007o`000003ooooool0003o
000000Oo000000?oooooo`000?l000002Ol00001ooooo`40000000000`00003oooooo`000004o`00
0003ooooool0003o000000_o000000Goooooo`000?l0003o0000ooooo`0:o`000003ooooool0003o
oooo017o000000?oooooo`000?ooool00ol000000ooooooo0000o`000002o`0000;ooooo2Ol00000
0ooooooo0000ooooo`02o`000003ooooool0003ooooo00_o000000Coooooo`000?l0003ooooo0_l0
00000ooooooo0000o`000003o`000003ooooool0003ooooo02ko000000Goooooo`000?oooooo0000
ooooo`04o`000005ooooool0003oooooo`000?ooool00ol00002ooooo`Ko00000_ooool6o`000003
ooooool0003o000000Wo000000?oooooo`000?l000000ol00002ooooo`?o00000_ooool>o`000003
ooooool0003o000000So000000Goooooo`000?l0003o0000ooooo`04o`0000;ooooo2?l000000ooo
oooo0000o`00000Go`00007ooooo0@000000000600000?oooooo0000o`000?oooooo00000_ooool3
o`000003ooooool0003o000000;o00000_ooool2o`000007ooooool0003o0000o`000?oooooo0000
ooooo`02o`000004ooooool0003o0000ooooo`Co000000?oooooo`000?ooool00_l000000ooooooo
0000o`000002ooooo`03o`000?oooooo000000;o000000Coooooo`000?oooooooooo1Ol000000ooo
oooo0000o`000002o`000003ooooool0003ooooo00;ooooo1?l000000ooooooo0000o`000002o`00
0003ooooool0003ooooo00;o000000Koooooo`000?l0003o0000ooooool00005ooooo`Co000000?o
ooooo`000?ooool00_l000001ooooooo0000ooooool0003oooooo`000?ooool01Ol000000ooooooo
0000ooooo`04o`000005ooooool0003o0000ooooool000000_ooool4o`0000;ooooo0_l00002oooo
o`;o000000Koooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooo000000?o000000Ko
ooooo`000?ooooooooooo`000?ooool3o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`?o
000000?oooooo`000?ooool00_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o
000000Coooooo`000?oooooooooo1_l000001?oooooo0000o`000?ooool4o`000006ooooool0003o
0000o`000?oooooo00000_ooool00ol0003oooooo`000002o`000003ooooool0003o000000?o0000
00?oooooo`000?l000001?ooool6o`000003ooooool0003o000000Co00001Oooool01ol0003ooooo
o`000?l0003oooooo`000?ooool01?l000000ooooooo0000o`000004o`0000;ooooo0ol00002oooo
o`03o`000?oooooo000000?ooooo0@000000000300000?oooooo000000;o000000?oooooo`000?l0
00002?l000000ooooooo0000o`000007o`000003ooooool0003o000000;o000000Goooooo`000?l0
003o0000ooooo`08o`000003ooooool0003o000000;o000000?oooooo`000?l000007?l00002oooo
o`?o000000?oooooo`000?l000000ol000000ooooooo0000o`00000=o`000003ooooool0003o0000
00?o000000?oooooo`000?l000001?l00002ooooo`;o000000?oooooo`000?l000002?l000000ooo
oooo0000o`000005o`000003ooooool0003ooooo00?ooooo0_l000000ooooooo0000o`000005o`00
0004ooooool0003o0000ooooo`Go000000?oooooo`000?l000003?l00002ooooo`_o000000?ooooo
o`000?l000000ol000001?oooooo0000ooooooooool2o`000004ooooool0003o0000ooooo`Oo0000
00?oooooo`000?l000000oooool4o`000003ooooool0003o000000Go000000?oooooo`000?l00000
1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo
0000o`000002o`0000;ooooo00?o0000ooooooooool03_l000001?oooooo0000o`000?ooool10000
000000<00000ooooool000000ol000001Ooooooo0000o`000?l0003ooooo01?o000000?oooooo`00
0?l000005?l000000ooooooo0000o`000002ooooo`Co00000_ooool<o`0000?ooooo00So0000oooo
ool0003oooooo`000?oooooo0000ooooo`Go000000Coooooo`000?oooooooooo3?l000000ooooooo
0000o`000003o`0000;ooooo0_l00004ooooo`04o`000?oooooo0000ooooo`;o000000Coooooo`00
0?l0003o00000_ooool2o`000005ooooool0003oooooo`000?ooool00_l000001Ooooooo0000oooo
oooooooo000000;ooooo2?l000000ooooooo0000o`000004o`0000;ooooo0_l000000ooooooo0000
o`000008o`000005ooooool0003o0000o`000?ooool01Ol000001Ooooooo0000o`000?l0003ooooo
00Wo00000_ooool@o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol000000ooo
oooo0000o`000006o`000003ooooool0003o000000So000000Coooooo`000?l0003ooooo0ol00000
0ooooooo0000o`000002ooooo`?o000000?oooooo`000?l000000_l00002ooooo`Go000000?ooooo
o`000?l000000_l00001ooooo`40000000000`00003oooooo`000004ooooo`03o`000?oooooo0000
00?ooooo0_l00003ooooo`?o000000Koooooo`000?ooooooooooo`000?ooool3o`000004ooooool0
003oooooooooo`;o00001?ooool2o`0000;ooooo00?o0000ooooool000000ol00002ooooo`;o0000
0_ooool3o`0000?ooooo1Ol000001?oooooo0000o`000?ooool5o`000003ooooool0003ooooo00Co
oooo00?o0000ooooool000001_l00004ooooo`;o000000?oooooo`000?ooool01Ol000001ooooooo
0000ooooool0003oooooo`000?ooool01?l00003ooooo`;o000000?oooooo`000?l000000_ooool0
1Ol0003oooooooooool0003ooooo00Wo00000_ooool00ol0003oooooo`000003ooooo`04o`000?oo
oooo0000o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
0_ooool5o`000004ooooool0003o0000o`0000;ooooo00Go0000oooooooooooo0000ooooo`03o`00
0003ooooool0003ooooo00;o000000?oooooo`000?l000001Ol000001Ooooooo0000o`000?l0003o
oooo00;o000000Koooooo`000?l0003o0000ooooool00002ooooo`03o`000?oooooooooo00?ooooo
0ol000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000ooooo`02o`000003oooo
ool0003ooooo00?o00001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000001?l000000ooooooo0000ooooo`06o`000003ooooool0003o000000;ooooo
0@000000000400000?oooooo0000o`0000?ooooo1?l000000ooooooo0000ooooo`04o`000003oooo
ool0003o000000Ko000000?oooooo`000?l000000ol000000ooooooo0000o`000002o`0000;ooooo
2ol00003ooooo`;o000000Goooooo`000?l0003o0000ooooo`06o`000003ooooool0003o000000Oo
000000?oooooo`000?l000000_l000000ooooooo0000o`000005o`000003ooooool0003o000000_o
000000?oooooo`000?l000000_l000001?oooooo0000o`000?ooool7o`0000;ooooo0ol000000ooo
oooo0000o`000005o`000004ooooool0003o0000o`0000?ooooo0_l000001?oooooo0000o`000?l0
0002ooooo`03o`000?oooooo000000Oo00000_ooool00ol0003oooooo`000003ooooo`;o000000Co
ooooo`000?l0003ooooo1?l000000ooooooo0000o`000005o`0000Cooooo0ol00002ooooo`;o0000
00?oooooo`000?l000001Ol000000ooooooo0000ooooo`02o`000004ooooool0003o0000ooooo`Co
00000oooool3o`000003ooooool0003o000000?ooooo1?l00002ooooo`03o`000?oooooo000000;o
000000?oooooo`000?l000000ol000000ooooooo0000o`000004o`0000;ooooo00?o0000ooooool0
00000_l00003ooooo`04o`000?ooooooooooooooo`Co000000?oooooo`000?ooool02_l000001?oo
oooo0000o`000?ooool10000000000D00000ooooool0003oooooo`000002ooooo`05o`000?oooooo
ooooo`000?ooool00ol000000ooooooo0000o`000007o`000005ooooool0003o0000o`000?ooool0
1_l000000ooooooo0000ooooo`04o`000003ooooool0003o000000;o000000?oooooo`000?l00000
0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000_l000001?oooooo
0000o`000?l00002ooooo`?o000000?oooooo`000?ooool00ol000001?oooooo0000o`000?l00003
ooooo`Oo000000?oooooo`000?l000000ol000001?oooooo0000ooooooooool4o`000004ooooool0
003oooooooooo`;o00000oooool2o`0000?ooooo00?o0000ooooool000001_l000000ooooooo0000
ooooo`03o`000005ooooool0003oooooo`000?ooool01ol000000ooooooo0000ooooo`08o`000004
ooooool0003o0000o`0000;ooooo2_l000000ooooooo0000o`000008o`0000Cooooo2?l000000ooo
oooo0000o`000002o`000003ooooool0003o000000?o000000?oooooo`000?ooool00_l000000ooo
oooo0000ooooo`07o`000003ooooool0003o000000;o000000Coooooo`000?l0003o00001Oooool0
0ol0003oooooooooo`03o`000007ooooool0003oooooo`000?oooooo0000ooooo`03o`0000;ooooo
1_l000000ooooooo0000o`000006o`0000;ooooo0ol000000ooooooo0000o`000002o`000004oooo
ool0003oooooooooo`40000000000`00003oooooooooo`02ooooo`;o000000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`05o`0000Cooooo0_l000001Ooooooo0000oooooooooooo000000?o
oooo00?o0000ooooooooool01?l00002ooooo`03o`000?oooooo000000;o000000Koooooo`000?l0
003oooooo`000?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l00000
0ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000ooooo`04ooooo`Ko00000oooool0
0ol0003oooooo`000002o`000003ooooool0003ooooo00?o00000_ooool2o`000003ooooool0003o
000000;o000000Koooooo`000?l0003o0000ooooool00004ooooo`;o00000_ooool2o`0000Kooooo
1ol000000ooooooo0000ooooo`02ooooo`?o000000Coooooo`000?oooooooooo1?l000000ooooooo
0000ooooo`05ooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool2o`0000Oooooo00Co
0000ooooool0003ooooo1Ol000000ooooooo0000o`000002o`0000;ooooo0_l00002ooooo`Ko0000
00Goooooo`000?l0003o0000ooooo`02o`0000;ooooo00Co0000oooooooooooo00000oooool3o`00
0004ooooool0003oooooooooo`?o000000Coooooo`000?oooooo00002Oooool00ol0003oooooo`00
000=ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Kooooo00Co0000oooooooooooooooo
0@000000000500000?oooooo0000o`000?ooool00_l000000ooooooo0000o`000005ooooo`03o`00
0?oooooo000000?o000000?oooooo`000?l000001ol000000ooooooo0000ooooo`02o`000003oooo
ool0003o000000Co00000_ooool3o`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool5o`00
0003ooooool0003o000000Ko00000_ooool8o`000005ooooool0003oooooooooool000000oooool2
o`000004ooooool0003o0000o`0000;ooooo00?o0000ooooooooool00ol000001_oooooo0000oooo
oooooooo0000ooooo`;o000000?oooooo`000?ooool01Ol00003ooooo`06o`000?oooooo0000o`00
0?oooooo00000_ooool2o`0000;ooooo00?o0000ooooool000000_l000000ooooooo0000o`000006
o`0000?ooooo1ol00002ooooo`?o00000oooool5o`000005ooooool0003o0000o`000?ooool00_l0
00001ooooooo0000oooooooooooo0000ooooool000000_ooool01?l0003oooooooooooooool3o`00
0005ooooool0003oooooo`000?ooool01ol00003ooooo`;o000000?oooooo`000?l000000_ooool0
0ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo00Go0000ooooool0003o0000oooo
o`08o`000004ooooool0003o0000ooooo`Co000000Goooooo`000?l0003oooooo`000002ooooo`Co
000000?oooooo`000?ooool01?l000000ooooooo0000o`000006o`000003ooooool0003o000000?o
oooo0_l000001_oooooo0000o`000?oooooo0000ooooo`40000000001@00003ooooooooooooooooo
000000;ooooo1?l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooo000000Ko000000Co
ooooo`000?l0003o00000_ooool8o`000005ooooool0003o0000o`000?ooool00_l00002ooooo`05
o`000?ooooooooooo`000?ooool01Ol00004ooooo`co00000oooool01?l0003oooooo`000?l00006
ooooo`?o000000Goooooo`000?l0003o0000ooooo`06o`000005ooooool0003o0000o`000?ooool0
0_l000001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool00ol00003oooo
o`05o`000?oooooo0000ooooool000000oooool<o`0000Cooooo00?o0000ooooool000001_l00000
0ooooooo0000o`000003o`0000?ooooo1?l00002ooooo`07o`000?oooooo0000o`000?oooooo0000
ooooo`02o`0000?ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00Go0000
0oooool01?l0003oooooooooooooool2o`000004ooooool0003o0000ooooo`;o00000oooool9o`00
0005ooooool0003o0000o`000?ooool01Ol00003ooooo`04o`000?oooooo0000ooooo`;o000000Go
ooooo`000?l0003o0000ooooo`04o`0000Gooooo00?o0000ooooool000000_ooool01?l0003ooooo
ooooooooool6o`000005ooooool0003o0000ooooool000000oooool00ol0003oooooooooo`010000
000000D00000ooooooooooooooooo`00000;ooooo`;o00000oooool2o`000006ooooool0003o0000
ooooool0003ooooo0_l000000ooooooo0000o`000006ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000_ooool01Ol0003o
ooooo`000?l0003ooooo00;o00000oooool01Ol0003oooooooooool0003ooooo00;o000000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000;ooooo0ol00000
0ooooooo0000o`000002ooooo`?o000000?oooooo`000?ooool00oooool2o`0000Gooooo0_l00005
ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool00_l000001Ooooooo0000oooo
oooooooo000000;ooooo1Ol000001_oooooo0000o`000?l0003oooooo`0000;ooooo0_l000001Ooo
oooo0000oooooooooooo000000;ooooo00?o0000ooooooooool00ol00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00002ooooo`;o000000?o
ooooo`000?l000001oooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000ooooool0
003oooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo0ol00002ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool00_ooool4o`0000Gooooo0_l00002ooooo`;o000000Cooooo
o`000?l0003o00000_ooool10000000000<00000ooooool000000oooool4o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`000007o`0000;ooooo0_l00002ooooo`04o`000?oooooo
ooooooooo`?o000000?oooooo`000?l000000_l00005ooooo`04o`000?ooooooooooooooo`Ko0000
0_ooool3o`0000Gooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o000000Oooooo
1Ol00002ooooo`Go000000Coooooo`000?l0003o00000oooool4o`000003ooooool0003o000000Ko
00002?ooool01_l0003oooooo`000?l0003oooooo`0000?ooooo1?l00004ooooo`03o`000?oooooo
000000;ooooo00Go0000ooooool0003o0000ooooo`02o`0000;ooooo1_l00003ooooo`;o000000Co
ooooo`000?l0003ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
0000ooooo`02o`0000Cooooo0_l00004ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000oooo
ool000000oooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooooooo1ol00003
ooooo`06o`000?ooooooooooooooool0003ooooo1?l000000ooooooo0000o`000003ooooo`05o`00
0?ooooooooooooooool000000oooool2o`0000?ooooo3?l000000ooooooo0000ooooo`03o`0000?o
oooo0@000000000400000?oooooo0000o`0000;ooooo0_l00006ooooo`Co00000_ooool01_l0003o
ooooo`000?oooooo0000ooooo`Co000000Coooooo`000?l0003o00001_ooool2o`000003ooooool0
003o000000?o00000_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
0_ooool6o`000003ooooool0003o000000Ko000000?oooooo`000?l000000_ooool01Ol0003ooooo
ooooool0003ooooo00?o000000?oooooo`000?ooool00_ooool3o`000003ooooool0003o000000;o
oooo1?l00002ooooo`Oo000000Coooooo`000?oooooo00000oooool00ol0003oooooo`000002oooo
o`Co000000Goooooo`000?l0003oooooo`000003ooooo`03o`000?oooooo000000;o00001?ooool0
0ol0003oooooo`00000=o`000003ooooool0003o000000Go000000?oooooo`000?l000000_l00000
0ooooooo0000o`000003ooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`;o000000Cooooo
o`000?l0003o00000_ooool00ol0003oooooooooo`03o`0000;ooooo0_l00002ooooo`Co000000Go
ooooo`000?l0003o0000ooooo`04o`000003ooooool0003o000000?o000000Coooooo`000?oooooo
oooo1_l000001?oooooo0000o`000?l00006ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0003ooooo`;o000000?oooooo`000?l000000ol000001?oooooo0000ooooool00002ooooo`?o0000
0oooool10000000000<00000ooooooooool01?ooool2o`0000Kooooo0_l00008ooooo`?o000000?o
ooooo`000?ooool00ol000001?oooooo0000o`000?l00005ooooo`;o00000_ooool01?l0003ooooo
ooooool0000;ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooool0003oooooo`000003
ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000000_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool02?ooool3o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool01ol0003ooooooooooooooooo0000oooo
ool000001_ooool2o`0000;ooooo1Ol00004ooooo`;o00000oooool00ol0003oooooo`000002o`00
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`Co000000?oooooo`00
0?l000000_ooool3o`0000Sooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo0ol000000ooooooo0000ooooo`06ooooo`09o`000?oooooooooo
o`000?oooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_l00006ooooo`400000
00000`00003oooooo`000003ooooo`Co00001Oooool00ol0003oooooo`000002o`0000;ooooo00Oo
0000oooooooooooo0000ooooool0003ooooo00?o00000_ooool3o`0000?ooooo0ol00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000Go
000000?oooooo`000?ooool01Ol00003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000004ooooo`Ko000000Goooooo`000?l0003o0000ooooo`02o`000005ooooool0003o
ooooooooool000000_ooool3o`0000?ooooo00Co0000oooooooooooo00000oooool5o`0000?ooooo
00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo00000_ooool2o`0000;ooooo0ol0
0002ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000004o`0000Cooooo0ol0
0009ooooo`?o000000Coooooo`000?oooooo00000_ooool5o`0000Cooooo0_l000001?oooooo0000
ooooool00005ooooo`06o`000?oooooo0000o`000?oooooo00001?ooool4o`00000;ooooool0003o
0000o`000?oooooo0000ooooool0003oooooo`000?ooool01Ol0000:ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooool000001Oooool00ol0003oooooo`000002o`0000?ooooo00?o0000oooo
ooooool00_ooool10000000000P00000ooooooooooooooooo`000?oooooo0000ooooo`;o00001Ooo
ool00ol0003oooooooooo`02o`0000?ooooo0ol000000ooooooo0000o`000003o`0000;ooooo00?o
0000ooooool000000_ooool2o`000003ooooool0003o000000;o00002Oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool00oooool3o`0000?ooooo0_l00002ooooo`03o`00
0?oooooo000000?ooooo0_l00008ooooo`Go000000Koooooo`000?l0003o0000ooooool00003oooo
o`Co000000?oooooo`000?l000000oooool00ol0003oooooooooo`08ooooo`05o`000?oooooo0000
o`000?ooool00_l000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00Cooooo1?l00004
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool2o`0000;ooooo
0ol00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00003ooooo`Co00000_ooool3o`00
00;ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o000000?oooooo`000?l000000oooool0
2_l0003oooooooooool0003oooooo`000?oooooo0000ooooool00002ooooo`?o00002oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l000000oooool4o`00
00?ooooo0@000000000400000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool2o`00
00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooooooo
1?l000000ooooooo0000ooooo`03ooooo`05o`000?oooooo0000ooooool000001oooool2o`0000Ko
oooo00?o0000ooooool000002_ooool2o`000003ooooool0003o000000Oooooo0_l000000ooooooo
0000ooooo`04ooooo`Co000000?oooooo`000?ooool00_ooool2o`000004ooooool0003o0000o`00
00;ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`;o00001Oooool5o`0000?ooooo
00?o0000ooooool000001Oooool2o`000003ooooool0003o000000;ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007oooo
o`;o00002Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Kooooo1_l000000ooo
oooo0000ooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool2o`00
00?ooooo0_l00008ooooo`40000000000`00003oooooooooo`03ooooo`03o`000?oooooo000000So
oooo1?l000000ooooooo0000o`000004ooooo`?o00000_ooool3o`0000;ooooo00?o0000oooooooo
ool01?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`?o000000?oooooo`000?l000001?ooool3o`000006ooooool0003oooooo`000?oooooo00002ooo
ool01?l0003oooooooooooooool6o`0000;ooooo00?o0000ooooool000001?l00004ooooo`Co0000
2oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooo`000005ooooo`Co00001Oooool00ol0003oooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool2o`000003ooooool0003ooooo00;o00001Oooool00ol0003oooooooooo`02o`00
0003ooooool0003o000000;o00001oooool00ol0003oooooo`000004ooooo`03o`000?oooooo0000
00;o00001Oooool01?l0003oooooo`000?ooool2o`0000?ooooo0ol000001?oooooo0000ooooool0
0003ooooo`04o`000?oooooo0000ooooo`;o00003_ooool01?l0003oooooooooool00003ooooo`;o
00001?ooool01?l0003oooooo`000?l00004ooooo`?o000000?oooooo`000?ooool00_ooool10000
000000<00000ooooooooool00_ooool4o`0000?ooooo00?o0000ooooooooool00ol00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000000ol00002ooooo`;o00001?ooool3o`000003
ooooool0003ooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000;o
oooo00Ko0000ooooool0003o0000ooooool00002ooooo`;o000000?oooooo`000?ooool01_l00002
ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo0ol00003ooooo`;o00000_oo
ool3o`0000;ooooo0_l000000ooooooo0000ooooo`02o`0000Sooooo00Co0000oooooooooooooooo
0ol000000ooooooo0000ooooo`04ooooo`;o000000Coooooo`000?oooooo00001_ooool5o`0000;o
oooo0_l00002ooooo`;o00001?ooool6o`0000Cooooo00?o0000ooooooooool02Oooool01?l0003o
ooooo`000?l00002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`00
0?ooool01Oooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000oooo
ool000001?ooool6o`0000;ooooo00Go0000ooooool0003oooooo`00000;ooooo`06o`000?oooooo
0000o`000?oooooo00000_ooool2o`0000;ooooo0_l000001_oooooo0000o`000?l0003oooooo`00
00;ooooo0@000000000700000?ooooooooooooooool0003oooooo`000009ooooo`Go00001?ooool0
1?l0003oooooooooooooool2o`0000[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`?o000000?oooooo`000?ooool00oooool2o`0000cooooo0_l00009ooooo`Co
00001Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
00002Oooool4o`0000Oooooo00Go0000ooooool0003oooooo`000005ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooool0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000002ooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000;ooooo
00Go0000ooooooooooooooooo`00000Dooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`40
000000000`00003oooooooooo`03ooooo`;o00002?ooool02Ol0003oooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`?o00000ooo
ool01?l0003oooooooooooooool4o`000004ooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00ol00003oooo
o`?o00000oooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool2o`0000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool0
00000oooool00ol0003oooooooooo`0<ooooo`?o00001?ooool00ol0003oooooooooo`03o`0000Co
oooo0_l00009ooooo`;o000000?oooooo`000?l000000oooool3o`0000;ooooo1Ol00006ooooo`;o
00001_ooool2o`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo0_l00000
0ooooooo0000ooooo`02o`000005ooooool0003oooooooooool000001Oooool10000000000<00000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?ooool00_ooool0
1?l0003oooooo`000?l00003ooooo`;o00001?ooool5o`000005ooooool0003oooooooooool00000
4oooool2o`0000?ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo1?l00005ooooo`03o`000?oooooooooo00;o00001Oooool2o`0000_ooooo
00?o0000ooooooooool00oooool02?l0003oooooooooool0003oooooo`000?oooooo00000_ooool0
0ol0003oooooooooo`06ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`;o00000_ooool3
o`0000?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000008ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo000000Gooooo0_l00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?oo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooo
oooooooo0_l000001?oooooo0000ooooool00004ooooo`?o00001?ooool10000000000<00000oooo
ooooool02_ooool01Ol0003oooooooooool0003ooooo00;o00001Oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`00000@ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
3oooool2o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000
0_ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Ko
oooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`05ooooo`40000000000`00003o
ooooooooo`03ooooo`?o00001_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`000003
ooooool0003o000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001?ooool6o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooool000000_l000001Ooooooo0000
o`000?oooooo000000;ooooo0ol0000:ooooo`?o00000_ooool2o`0000?ooooo00Co0000ooooool0
003o00000_ooool00ol0003oooooooooo`03ooooo`?o00000_ooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?l000000oooool2o`000004
ooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool5o`0000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ool000000_l00005ooooo`03o`000?oooooooooo00Cooooo0@000000000300000?oooooooooo00go
oooo00?o0000ooooooooool01_ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00001Oooool2o`00013ooooo0_l00004ooooo`07o`000?ooooooooooooooool0003ooooo
o`000006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool01?l0003ooooo
o`000?ooool2o`0000Cooooo1?l00005ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000?o
oooo00Ko0000oooooooooooo0000ooooool0000>ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooool000000oooool3o`0000[ooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00?o0000
ooooool000000_l000001?oooooo0000ooooooooool3o`0000_ooooo00?o0000ooooooooool01Ooo
ool2o`0000Gooooo00?o0000ooooooooool03?ooool10000000000<00000ooooooooool08_ooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000;ooooo0ol00006ooooo`03o`000?oooooo000000kooooo0_l0
00000ooooooo0000ooooo`04ooooo`;o00003?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooooooool01?ooool2o`00017ooooo00?o0000ooooool000001ooo
ool00ol0003oooooooooo`05ooooo`05o`000?oooooo0000ooooool000003_ooool2o`0000Cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo
0@000000000300000?oooooooooo00Cooooo0_l0000:ooooo`;o000000?oooooo`000?ooool01_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`;o0000
1?ooool2o`0000;ooooo0_l00003ooooo`Ko000000?oooooo`000?ooool00_ooool2o`0001Kooooo
1?l000000ooooooo0000ooooo`03o`0000Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0
003o00001?ooool2o`000003ooooool0003ooooo00;o00000_ooool00ol0003oooooo`00000<oooo
o`04o`000?oooooo0000o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
0006ooooo`04o`000?ooooooooooo`0001oooooo0ol00006ooooo`40000000000`00003ooooooooo
o`03ooooo`;o00002Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00007ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`;o00000oooool01ol0003o
ooooooooool0003oooooo`000?ooool00_l0000Iooooo`03o`000?oooooooooo00?ooooo0_l00000
0ooooooo0000ooooo`05ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`?o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000000Gooooo0_l00007ooooo`40000000000`00003oooooooooo`0Oooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
o`000006ooooo`04o`000?oooooo0000o`0001?ooooo0_l00008ooooo`;o00001?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool100000000
00<00000ooooooooool00oooool2o`0000[ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooooooo`;o000000Goooooo`000?ooooooooooo`000005oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`04o`000?oooooo0000o`0001?ooooo00Co0000oooooooooooo00001oooool2o`000006ooooool0
003oooooooooool0003ooooo0_l0000@ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooooooo0ol000000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo00?ooooo0_l0000E
ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001oooool1
0000000000<00000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`;o0000:oooool2o`00
00;ooooo0_l00008ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01_ooool01ol0
003ooooooooooooooooo0000ooooool000002?ooool2o`000004ooooool0003oooooo`0000;ooooo
0ol0000?ooooo`;o00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool2o`0000?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool01_ooool01Ol0003o
ooooo`000?oooooo000000?ooooo00?o0000ooooool000001Oooool2o`0000?ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0@0000000003
00000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0000Tooooo`03o`000?oooooo
oooo02?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool05_ooool2o`00017ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool10000000000<00000
ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool2o`0000_ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooo
oooo000000Sooooo0_l000000ooooooo0000o`00000Aooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`;o00001_ooool2o`0000oooooo00?o0000ooooooooool0
4?ooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooo`000?ooool01?l00004ooooo`;o00007Oooool00ol0003oooooo`000002
ooooo`;o00001oooool10000000000<00000ooooooooool03Oooool00ol0003oooooo`000005oooo
o`;o00001Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001gooooo00?o0000
ooooooooool00ol000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo00_ooooo0_l00009
ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_oo
ool00ol0003oooooooooo`09ooooo`;o00002?ooool00ol0003oooooooooo`05ooooo`;o00002ooo
ool00ol0003oooooooooo`05ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`;o00000_oo
ool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`?o00001?oo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`40000000000`00003ooooooooo
o`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05_ooool2o`0001Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool00ol0003oooooo`00000<ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
0@000000000300000?oooooooooo013ooooo0_l00008ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Fooooo`;o00000oooool2o`0000Oooooo00Co0000oooooooooooo
00006?ooool01?l0003oooooooooooooool2o`0000Gooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0_l00002
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04
ooooo`?o00004?ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`0Wooooo`40000000000`00003oooooooooo`0=ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo013ooooo0_l00005ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000o`000002ooooo`;o000000?oooooo`000?l000005_ooool00ol0003ooooooooo
o`0=ooooo`05o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool0000Aooooo`03
o`000?oooooo000000[ooooo0_l0000Cooooo`03o`000?oooooooooo00Sooooo1Ol00004ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`40
000000000`00003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5Oooool01?l0003oooooo`000?ooool2o`00017ooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000001Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool01ol0003ooooooooooooooooo
0000ooooool00000;?ooool00ol0003oooooooooo`03ooooo`40000000000`00003oooooooooo`0=
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05oooool2o`0001Oooooo00?o0000ooooooooool01Ooo
ool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool05oooool2o`0000gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool05?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool10000000000<00000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0V
ooooo`;o00001oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo0_l00003
ooooo`?o00003_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Oooooo00Co
0000oooooooooooooooo0_l0000Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1Oooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooo00003?ooool10000000000<00000ooooooooool07Oooool3o`0002Kooooo1?l0000Cooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo02Kooooo00Co0000oooooooooooo0000:?ooool10000000000<00000oooooooo
ool03Oooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00Kooooo0_l0000Koooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0Dooooo`05o`000?ooooooooooooooool000002?ooool2o`0000Kooooo0@000000000300000?oo
oooooooo00oooooo0_l00005ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool2o`0000Oo
oooo00?o0000ooooooooool01Oooool2o`0000_ooooo00Co0000oooooooooooooooo0ol00005oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_l0000@ooooo`40000000000`00003o
ooooooooo`0Aooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooo`000005ooooo`?o00001oooool00ol0003o
ooooooooo`0Vooooo`40000000000`00003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo
0_l00008ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool01ol0003ooooo
oooooooooooo0000ooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01oooooo0@000000000300000?oooooooooo013ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000008Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool01?l0003ooooooooooooo
ool2o`0002;ooooo0_l00006ooooo`03o`000?oooooo000000Kooooo0@000000000300000?oooooo
oooo013ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01oooooo0@000000000300000?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`02o`0000Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=oooo
o`40000000000`00003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`00000Zooooo`03o`000?oooooooooo01[ooooo0_l0000Dooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`;o00006Oooool3o`00
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`40000000000`00003o
ooooooooo`2Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool02_ooool10000000000<00000ooooooooool0BOooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`?o00008_ooool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo01Cooooo
00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`0_ooooo`40000000000`00003ooooo
ooooo`0=ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0oooooo`04
o`000?ooooooooooo`00023ooooo00?o0000ooooooooool03_ooool10000000000<00000oooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool07?ooool2o`0003cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01;ooooo0@000000000300000?oooooooooo03oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000001?ooool2o`0001Oo
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Pooooo`40000000000`00003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000:_ooool10000000000<0
0000ooooooooool07_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0hooooo`40000000000`00003oooooooooo`1S
ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000006?ooool01Ol0003ooooooooooooooooo000000cooooo
0@000000000300000?oooooooooo00gooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo033ooooo0@000000000300000?oooooooooo00gooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0:Oooool10000000000<00000ooooooooool0L?ooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo02kooooo0@000000000300000?oooooooooo08kooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`1@ooooo`40000000000`00003oooooooooo`0kooooo`03o`00
0?oooooooooo0=kooooo0@000000000300000?oooooooooo01kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`1Sooooo`40000000000`00003oooooooooo`0=ooooo`05o`000?oooooo
0000ooooool000000oooool00ol0003oooooooooo`05ooooo`;o00003oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooooooo`;o00008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000002o`0000Cooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`0Oooooo`40000000000`00003oooooooooo`3ooooooagooooo
0@0000000?l000008@0000000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000]25Wd0000000000000000l002JTi2?
R81nPG]jN7aoQ8R6QWmlN79_Kfm_L7R2RHfAShb:QGmhLg9gOhF8QHB7Rh^7R8F0
Oh5oP8J5PX>8Qh5nP8>5Ph60P821QXN6QH>0OWYgM7EjOX:7RHJ9S8b:QWmiNG]h
M7AcLWAfN7McM7MiMgIgM75aM7UjMW9eNWMeMGAbKg5dMGIgN7QlO7akOGehLfi]
Kfi]LWIcM7EhOh1kMW=]IFIXJ6Y_M7MnQ8V:Rhj>SXR2OWanP7moOgn3R8V:RHF6
R8Z<S8b7RHf>Si2CTHnAUYVFU9FDTI2EVINHWJ2NW9NFUiJBS8jCTXj;Rhb=S8b<
SY2@TINOX9N@Sh^5PX:0P8B;SI:DT8f;T9RIUiJDVInTZ;2h^kZ[Uh^5Oh2=WZZ_
[kFh[j6?PGM^KGZ>WJVb]:ZMUHUhIUM?EEiYO8V?ShN0NW=^J6=NH6E/LG^5QGif
MgMdLGEjNGQiOWn7TIRLV9:?SHnGWIfJVIbU[;6e/JRMUIBCRhB3QhfAUYVIV9J@
R7egNG]mPh^:QXN;Qh:4PGmjMG^3PWekO7]eL6aZJ6IRGeeQHV=XKG5^JFMZKFUT
Fe9?D5IMIFmeNGinOGakNWj2Q8B3QhR7RH^:R85nQHN5QHR9QX>4Q8B6Qh>1QHZ8
Ogb3RXR5RHZ5PH>7Qh=nNWYhMWMhN7EbKFUYJfIOHFM/KFmhOgijMGQlNWUfL6US
H5eOHFAWJ6MYL7=hP8F2NWUjNGb1QHN5PhR@T8^7R8R6R8V6PX20PXN<Shn?UIbM
WI^HUI:=Rhb=RXF5QXF2PXN7Q8F5RH^8QXAoO7YiNgeoOWeoOWilNgIaL6i/KW=g
NWanP861PhR?U9BHUY6EUi:>Qh9oOHF?SXN5Q81nO7akO7f2RYVZ[j:1JVeXG6Ak
SYBGY;:]WhmmJeQ@EfAbPHnDS89mMFQGBdA5Be5TLW9aKfQND4U7@C`k@dmKK7^1
PWaeMGIgMgEfMgUnQ8bBUifOX9^CSHjCTI2BUYRLXjN[[jjZY:>VYZ:PYZBRYZf`
[jjZYYfARh^>SXn=TINGU9FERh=oP8F:SY6CVIfNW9VFT8EiLW5eOXNAUYFBSY6H
XJ:KUi>>TYZQXjR^/;Fm_K:TVIB<QHV=TINKX:BVXiZEUiB>Rhf@T96BT8n9Q8>2
PGegMgn3PGj0OWMcLgQhM79eNGUeMGEdMgUeM7MhKV=RIFMXJFegOGmnPXZ<RHN6
PWUgNG^0Q8=lNG]hLF]ZIV9SI6MYJFUYKG1_JFU[JfQUIVMYK7F1QXN<THb2OGUd
LW9cMWj4RHZ:RH=lNGYkO7alNWYmOG]mPX5mNGYmP8>4PhF;Qgj1R8f=RHB4PhF4
PXB6QhV=Ti:;Pg]iN7=_KVidO863Q89iNGeoOGIdMgQkOgmoOWn1PX5oOh:;RhEo
MVeVJWEmPHVGXZJWX9J7N79aM7QmQ8J3Ph9mNG9YIV=NGFEaP8Z=RhV4Og]fMGUh
N7f8TIFBR8=kMW9_LWAkQ8b@Si6FVibHTXb6QXJ:SXnATYJHVIbOX9fJVINAQh>3
Qh^;SYFLWIR>R81gM7MiNh22PH:2PXJ5OGEbLG5cNh>9SHf>SXZ7OGAbL6i]KG1b
L6]YJfi^JfUUHF9XJVMZK6ibMWamO7enPH:0PhJ9SHf:Q860P7mlOGYeNHF@UY>>
RhV5OgMcKFY]L7AlPh=oNW9aLgEjOhB1OWalOWinOGIgO824Q8:0NWEcLWEfLg5d
N7QhNWM^Jfm]JVM[LWIkOgijMWMfMgIcLgR1QXB1OW]aKVmdMWEjPhfFVYZJWinK
VYVDTYJJX:FZ[J^PVIVFTi>FVI^MW9jSYZZZZJ^^[Zf[ZZ^/ZjVZ[:bXXIjKVYfN
WI^LXJ>PWIfNWYjMUiFDTi2@THj=TIJFTXn>SI6CTYBASXjATYBDShnCTi6=R8N6
RYJNXjRZXY:2NgUdMX:?UYVMY:RSWI60MW=aL79hOGmnO7YeK5mDBdM8BTeBDeYQ
H5I?CTi?E5MGF5m/N822O7QiMg=_JfMTIFeiPhZ:RXf?SXV3PH20Oh23Ph:6T9BD
UIB=QH62Q8B6SI6CTI2@Ti>@SXV3PGemP8>7RX^9RXV6OgMaKg1cMG=bMgeoNWEa
Kg9fN7UiNganPX5lNW]jNgelNWE_L7MkOGanQ8R6QhR8QhZ;RXN1P8F9Rhj@THb1
MgIbKVmcMgQeMWMlPH>4QXR;S8R6Q8F5Q8:1OgaiNWMeMWMdLgEgNgYeLgEhNGQi
N75[JVibM7AfNh20NgE^If5PI6Q^KgInOWUdL6aZJfYZIVEZL7IjOGioNgIbL6i_
M7j3QXV>TYZKV9JBS8V7Q8:4QhZ?U9BASh^6PGn2Ph:2PH24QH1nOWf2RY:FThj>
T92?SXV7QhZ=S8R5PWeoPX:0Ogj0Oh61NgEcLG5`KVe_M7^1Ph1kM6a/KW5dN7Uj
NGb3R8N6QhN6QhV9RHZ?U9FCT92@RHR7QXR9R8R:QhJ5PWiiN7YkPHZ;QhZ=SXR2
NG=^IfIXKG1aNH>5Q8>1NgEaLgMhO8VDVIRFU96?T96BTi>@RhV6RXnDUI>BTYNQ
YJJXZZVY[[2a/:nb][Fa[ZfZY:2SZZj`/kRf[ZFHRhF4QhfHWYnMWijLUXj4P862
PhF5PGinP7mkMgAaL71eMgAcNgimNgUiMgIfNWakMWEeNGf4Ri6BSXR8RX^:RH^=
Si:CTY6@SX^<R8>1PX:0O7YjN75^K6YYJfmbMGQlPXR9Q7elNGMfNGMcLWAlOWYj
OGemP8>1Ng9^KFYWIFM[KVm`LFeVHf=VJFibLVi/JfUVI6ERHFI]MGUkNg]kMWEd
LFa]M7b0Q8R;RXR4P7ijN7UlNgUlOh21Q8b@U9VJUI6>SXf<S8^:Rhn?RhF4QXZ=
T9:?RHV?TY6<RhjATYBDThj;SY>BSX^5O7AbM7MjNg]lOGj0QHR=TI:BUIFBS8N5
QXJ8RXfATHf9RHV7QXF2PH>8QH62Q8>3PWmlOH64QHR7Q8bGVXQ]GV1KG6n3R7mf
NWeeK6UTGeUCEUeTKGEiNGQgLVEEBTM<EFIiPH61P7ifKFYXHemRIFYeQY:ESX=g
JfASHf5SJG1fOGilP8B1OGf5SYJJVI>@ShnBU9NHVIfRXifFTXb<Si>IWI^JVIF@
R85lO7UfN7b0QXfCT8V0NG5YJG1eN7b1R8b=RH=lN7AaKVm`L7AmQ8N8QhAmN79/
J6Q/KG5gNgf0QX=lNWn2Ph:1P822QXR7QhB3R8j9QHF4PhJ<TI2;S9>HUiVKVIRJ
VYVETY:DUi^LW9RAQGinP7emPXF:T9FHVYVFThn>TYBEVJ2RXj2MViNDU9>@T9>E
UIJDTI6BRhF4QhZ:RHV7Ph:4QHJ9R8Z?ShV2N75aM7n:SXn>SXn=RhV5P7enPHB4
Q8J:SHj@TI6=RhnEV9NETY6@SY2CUIFCTi>CT8b9RXZ9QX>2OgYhM6m/KVe^LWIf
NGmmN7MlOgagMG9_L79dN7amOh64QGmiMgMhO7moNgIcMGAbM71^LgEdLgAdMGIi
NgUiNgUcLgMjNWj3R8R3Q8N9QWmfKVa_LGR8T9:BTY67NW1SEe9HGfMbNh>4Q7md
K6INEeEJGF9YLGMkO7UaJfUTGeUEF6=cPXR8Ph1mNW]lNgQlQXjBUINETHn=RXB2
P825RHb>TYNKWYVHVIRFV9jSXj6OX:BUYZRXXYbFU96;QHF7RhnEV9JDRh1kNgUi
Nh23P7n2QH9nNgIcL6m/JVMZL7InP820OWUfMWEbKg5hMgEeMGEgOH62Q8>2PH21
PhJ;TI>CTI2@SHR8Ri6FUYBATXf7QXJ0N71aLVi^NX:2Ph>0O7UcKF]]L75bMgIb
L79dN7]hM7MnP7miMgAbM7f0OGMcKfi`L6iXJ6e`KW1cLg=gOH60OGYfM7=cMGEm
PX5lNGQcLGAjPXR5PX:7RX^:RHJ1O7ajMGImQHZ=S8f=S8b:QhV;S8bCUiFDUIVJ
VIF>RY2EUY>@SHnBVZ2OW9VJVijRXj6RYJ>OWYfJU9:BSh^9QhF2QHN8Ri:BSXZ7
QX>2QXbCV9RHUIBBTI:CSXZ6QhV:SI6DShV9R8:0OWalP8J<SI6CShZ=ShnATHn=
SXb:PGEfOhJ@VZ2RWYJ@R7]`JVMZKgAmPX21QXR5OgadJf=RHfI/NH21PH1oO7Ug
NGUgLW5aL75bM7IfM71]K6UWJg=gNX:;SHf<R7mlNgf0QHN4PXF>UYZKW9VIWIfG
ShV7RI2GVYZFTXn<RH9iMGEgMGMiNG^2S92=R8=lMG9`KW1eNGUhMGA`K6]aMGMh
NG]hMGAgNWUgM7=cLG9gOGekNWYiNgaoOh>5Q8F7RHB0PXR<SY6ASHb=RXAlMgEi
PhjDTi6BTYBCTY6=RhZ6Ph9nOX64Q8:3PGafKf]YK7=gMgYoQ8F5QHF3OgioOgal
OhB9SHf9PgihLFmdM7AgOGmmOWijMG=cMGMjM6e[Kg1^JfQSIVifN7EaLG9gOh5l
MGAbL6i]KFa^M7EdLgAeNGj3QHF4Q89lNg]oQ8bBUIRIVIVKWinJUiBBRhJ6RHZ=
Si6@Shb9QXR9QH>4QXB2Q8B2PhB6Qh^6P864QhZ=THj<SXn>RhN4PX>9SHb7Pgmj
N7IdLW1cMWUjNgenOX27S8^3O7MdLFmaMGQhNWn2Ph>2OgYiO7ijNGn7Rhj?ShR1
OgAZKgQkP8ZCThf8QGYaKW5bLg=dN7aoPhB0MfeZJFQSH65VKgZ3QXJ7QXB2OWUe
LgIkOh65RHZ9QhJ6QH>1OWioQHjHWj2RXZ6SYjV[Zk2e]kFc/kFe^Kbl^;>_ZZFS
Xj:SY:NWZ:b^ZJ>RX9ZFShV7R8Z<T9:@S8f?SXR4P7emPXR8Q89nNWQdLG1`MGIe
Mg=cMGMiNWeoP7adLG5fOXB:SI6@Shn?SXj;RXJ1NgEfNGb3R8J2PX>2P7n0P7im
Ng=`MW]iMg]nOGeoOW]iMgQiNgn0Q8N7QH1gLFi`LgAbLG=`KFe^K6]/LgEeN7io
NgUhNGakMW1]KW9fMgYmOGQfMgYkO7inOGQcL75eMganOGUdLg=bL71`Kg1`LWIm
Og]jOGmoPH5nO7]kNGYkNgYhOHN0OXB1R8n>Shn?TI:?TYB@T9:ET8f?SH^6QXZ:
S96AS8R8R8J9Shf>T9BGVIRLWY^MV9>DT8nBUYB>R8V;QXB4RXb>SXV4PH9nMgMj
O7]mP7egLVi^L79fNX68SH^6PWafMgQdM7MdLgAkOWQeN7QhNWQgM79bMg^1RH^:
RXf=SHImOH60PH:7Rhj>RhElLVMLG69WKW5`LG=cK6ERG5EAD4mBFEaKGEmPI6QX
IF=RIFMVK7AfNGj4P7alNWQkO7M`L7=bLGZ4RHfCVIVKW9ZGUYRHVYnPW9RFVIZH
VYbGU9NIVINBT9:FVIJ@RXZ:QHR:QH>5Q7miMg]oOgahN7Z1PgioQ8B1Q8=iLFma
LgEgNGEhOX>1NgMhOHJ>TYRKVYFDTY6>S8^;RXjCTHj=SHjAUYVES8V;S8nDViZL
WinMViZMXjFPWIJ<R8^=T9:DU96AShZ;TY6<TI:@RX:<RhF:R7mnOgYfOH>=ShnB
SY2JX8]oS8^8Shj7QGfM[WU_WZ=gN9b:OIjMMF9cR8^<U9B=SI:COH>ZW8B6ViB5
UGeULX2<MfejK7VBRWmdKWETGVY^IVQmJ51MGV9dLUeHLH9iLVe_LW20S8j9Q9BM
Qgf5NWZ6S8V9Uhb0Q8ZAShV4Pi>MShF<VHb5RiBPUXR8R7edOYR@Oh24Og^1QHbC
TXF0NG=_JgR2O7UmOW5ZKfUYMGamO8::SHZ4LG22PGE]LgikLgAfOXV1LgAhNWin
P8><UiF@QGf1Shb5R8>9SHV:PH23NW5_OH9dJVi]LgYlO6i[KVQTI6EUHVmjMgEY
I71hJUaQHV=THeaRMWmfIfmlMg5hHEedLG=cLGAiPXMnP8J;V96;UiR>Qgj4Sj:X
Wj2TZJ2OXiR=QhN:SijNSXbCUZ:]ZjB@Rhb:UYnJRhfCU9>@TIBGT8>1O7ahMGak
NX24O6iVNGiYIFaeLfU_KF]/K7EcK6n2S7U_OhR0OGmoP8:<S7ifMgQbO8V@Qg^3
QHB6PhEoLWV0O7IhMfmTLHN:PG5WLG]kM6a_JVQ[KFMUKWN6OGV2Mg5cNgicJfIZ
LW5bNG9`Q8IlMGEoNfmcNh5gMX5iN7EhPh1gJgAmR95oOhb4PHfEVYNSWhV4RY:B
PWb4RI2@QWeaLWn:R7QaNH:2P85bNXMnN7^;UiB>TJRLUYIgO8fFT8>;VIn^Xj6Y
XjR`ZIV<X[6FTibSXIjh^ZVU/KNcZZj^ZZN]^K>XXj6RXIRO[JZISI6HU8Z;QX5l
R9>1OHJ5QHZCVIN?O7f;Si:EVI:8T9J2Pi>>RHbBTI6FUHQnP7elO7f4R89gPHN3
NGn1N71dN6UXMWf0O8:>Q7]oR860PWajM75WKgEeNGf1OGMiNWV4Ph>>ThYlOWik
LVmYI6U_OWn0OWQlNW=aJf9GC5]^KfeQH71aK6i_IUeMGUmTIfMQHVEVM7IeM7J1
RXEoOgaeLGEoO7QiO8>8QhZAVYR=T8^2RHR5RhnJW96?Si>MVY25P8>4NWAhLgV2
QX1lOWQZIFIYKfm`LWIdLWE^Jg1bKFUXK7IbJVAPK7IoP7]iNGIcNh:0N7=aL75h
P827RHR;R8J2OhJ5PXZ7O7^3RHAnOhV;RHJ1QWmfLgEmPGmmMg5iNWMgMgQlQ8b?
RhV3P8J8QhF;V9>8Qi:KVI><RI2ITY:IV9JKXInKUYFBSX^9SiJ@RXb=RHVCTXj>
T9JARHV>U9B<SHZ3Ph1mMg9bNGegL7QnOGAYLWAeN7AhMG5eL6]/KWYlMWA[I6ig
KVI^MgQfMWEdNWaiMh68QX9nPH64Q863RXb6QXfDTiRRWIFBTINFTi:ATYBFTHb:
Ri2:Q8J@VI:6PhF:Shf7RiB=QhN:S8^=S8n@Rhf@SXV3P8:7QH1nP8>2OganP869
S8b>Shj=R8F1OGIlRhb?TYJHUYNKUHR6P7^4RXF4RXb7PXB6R8n<P7^1R8^8NWIl
Nh2;Qh63QhIlOHF3Ph:3Pg]kO7Q]JFYVIfQXJ6EUJFi^HemYIeU>FfMUIVQ_KFMY
JVUTHfQWJFU]Lfi[KWAfMgYjNG]mOh>9RXJ7QXB6SIJHUYRRZ:Z[Zk:g/k2_ZjNW
YJ:JV9^KXZRXXiREVIB<Q8J;THb8S8f8OWQjOHF:Qh1jOH>0N7IkPXF6QhZ=VIbE
SHZ?VIfDTYNDTI2CVIbFT9NKW9nRWYZIUINHShZ;SY2DSh^=S8f;RXF5Sh^3NgQn
OWamP7mnPWijNWMdNGegJVU^JfIMFemPGemSJFYVI6YeMgEcKfiaLG5cMGUeMWMe
O8>5Q8F5QXf9Q8QmLGAmO7=dOHJ?S8^;RHEoOWUdM7IgLfadPhMoO821OWYjMVi`
Kfi_K6IRH65SIfmcLgA`KG5aLG=_LGEgMGR2QXJ8Ri2=Rhb4NWV0OGMmP8><T92;
QXN8RXZ4OGEhOGAbNGiiMGYiNh1kO863R8b4MG9hMWUiOH:7QWelOX21Ph5lM7Io
PgmjNhF6OgimOgUeM75cMW]mNGYmP863PG]kO7YmOhB4PhN5P8B8Qh9oOGMfMgIg
NGb3QH5mPHF7S8f<SiFFTYBESi6FTiBJWJ:MWZF]/:VVZ:RWZjZSWJ:WXIRGUHV1
R8R5QhV;PG5WI6QTG5MIF5AFFf1OGF1QH5iHEUiRHfM^NGn1QHZ?TY>BUIjWZ:JW
ZZjb]:jWYZBRYjf^[k>f/jf/[JjYXifPYZZ/[jj[ZjNMUIFCSHJ6RX^9Ph1nN7If
NWM^KgEiNWn4QXZASXZ9R8R;SH^;SHnAT92@U9FFV9VFUYJ?S8Z;SY2:QhAmN7Ie
MW^0P7eiMWUkMG9gNWb0OgYgMGQgLfaZJfMUJ6Q[LG=bL6m[K6e[KFe]M7UjLVi^
J65RJW1cLg=bLG=_J6QXJ6QWIVYbM71dM7AcKFicN7MjPhbCVY66OW5SHF9QIfU^
MgYlOh:4P7YbJ6IWIVMTIfacM7EeMGMhNWn6Rhb=TI:>QgihN7MkPH>2QHR:RhV9
Qh61PhB1Oh:0P8F7PX1oPHB8QXZ?TI6BUi>>RXF3RHb9QXZ=Shj?TY:AT8n;Qh=o
PXZ;SI>IWJ6RW9VHUYJFV9VHUI6CUI>@SHV6PX>7QhB4Q8N8P7EaLG1aM7f5RHV:
Rh^<RH5nO7emO7UkOWmmOX:6R8R9SHb3OgmjLW=hNGQgM7EnOGYnOWekOWemP7il
PHN6Qhf;QXV<TY>EVIFCTH^7PGUcLVm/KVa_K6Q]L7A_J6EQG5EACDa9Ada@DE=D
EEiWKg5eN7IgNWQcKVUXK6mbMgZ2S9BJWIbLV9NLXJFVYJ>QXYjCSiFLXZNZ[k:b
/:jSVYJDT8n>RHJ9SY>GU96BU8n>SHV5P7ioP7afM7AeLgMkOX1oPH>4Ph:0OX23
PhB5QXF6R8bBUYZQYZJTXJ6QWi^JV9F@RXJ6QHJ8RHZ9Ph62PX5kN7Z1QhZ<SHZ9
S96>RH9nOWn4PX61P7mmNgUhMFiYIV]^Kg5bLgAeMWMlPH>7S8b>TiFEUYRGWJ2N
W9bKTXR0OGmmNg]kO7j3Ph1mN7A`Kfi/Jf][JFMQGf1PHVAYLGMjOh61OGilNWQd
LFm]L7ImQ8fFV9ZPY:BNUY6BUYRIV9JBSXb?TY:CUYVGUYVKVi^KWIRBRh9kMgAc
MGUlOh20P7mnPX:1PhB2O7QfMGEeN7YhNh:7RH^6QXZ?TY:DTHj:R8V>THj9QHB:
Si:HVYZGUI6=QG]bKVa]KFe_LG1/JV]ZIV=SIFASHV9OGU]IFemPHFEXJVmaLgEi
O7QfM7AcLG9fMgIcMGUjNgf0PX20P8>3Q8J8SiBGV9ZFRgmfL71dNW]kOX:3OWUd
KFMTIVUWHf5RHUiJEE5>BTM=F61WKWImOgaeKVUWI6AYLGMiO825RXfBUIRGUI:@
Ti>GVY^JUI2;R8N8SI:HVIZLWYnOViRFUiFAT8n=R8N9Rh^9QXN;SiFJW9^IUY>A
SHN0NgYiNGaoOG]jNh25RXb>TiRKVYB?RhR7QhN:Shn>Shn<QhF5QhN8RXV7QhJ7
Rh^9QXB4QHJ8Rhj?SXf;RX^;RXb?T8n=Rh^:RHV;SY2?T96>Si6AShb;SY>ESXN4
OgeoPH5oOWamOhB6QHB6R8R3O7UgL6YZK6e]Kg9gO8B:TYRKV9B?S8Z7Qh^?Shb8
QH5mN7MiO7]lOGj0Q8R:S8f?SY2>RhZ;SI6BTY2=S8f>SXn?SHV<TI><QH>2PGmo
OW]iNGZ1Qhb@U9NJW9^HThZ4PX>7Rhf>T96@SX^;SH^9QhN6Q8:2PhF2OGUgMgQh
NgioOG]mOGYgLg9eMWUjNWIbL6m_Kfi/KVm`M7UkOWmoP8>6Qh=kM6m/KWAkOWel
NgYiNGUhNGj2QHN7QH>0O7YhMgQhN7A`L79eMgUhN7QfMWMhO7moOG]hMWEfN7Yn
PHB5QHB4Q8N9RX^>T8b4OX22PhF5Ph61Ph>5QXF2P862OgQbK6]^M7QgLg1^KF]X
IfMZKVm^KFi_KV]ZJV]/KW5cLFm`LWIjOH23Q8>3Q8J8RXV6Q8>3PhF8S8j<RhZ9
RH^?TiJIWJ6RX9ZETi:BTI:CTi6ATiFFTi2?TI:@SHV4P7elO7ajNWeoOWajNWj0
PH64QXF3PX>3Ph:1PH61PH:5RHb>SXb8Q85oOWn3QXR8Q81nOh1mNg]mOG]jOGin
P8B5QhJ3OGIeMGIgNGQiO822QHF2OgimNgQdLW9bLgMiNGQiOH21PhN<Shj=RX=k
MG1/JfeaLgQkOWmnP8:4Q8>3Q8>0OGakOH23Q8>1PhN:SY6@Shn?S8Z<SXj=Rh^<
SH^6PX61Q8V>T9>HWZ>TXIjKVIRFUI:?RhV<TiJGVIbMWY^DSHR9RX^>T96?RhN6
Q8J8R8R;SY6EV9^NXJ2LUHn:R8b?SXj=RhJ1OGYjO7eoQHR6Q8B7QhJ6R8Z:RHR8
RHZ<Rh^;RHN9RhV4OgajNWYiMWAbKg9hO7akNWUhMgIfNGYjNWaoP7n0PXF5Q8F4
PGejN7YlOGj1Ph9oNgUiMgEfO7inOG]jNg]hLg5bLgEgNWemOGimN7=_JVIVJ6Y/
Kg1_LGQlOGajNgeoP7iiLFUTIFMZJfa]Kg9dMG=cMGQiNW]kNGQfLg1^Kg9dLFm_
LG=fNGj1Ph>2PhJ8QhV;R8B2Q8F6QXJ8SIBHV9VIUiBDUIRIVifLVIJDU9BGV9BB
TYBDTXn<RXZ;SHn>S8V9RHJ3P7ilNGMgMgUkOX62Q8>0OGYhN7]nPXB3PH61PH23
Qhb@TY2>SHb=Si6ASXZ6Q8>3PhB6R8N6QhN5P7n0Q8N5Q8B3PhF6QhV9QX>5QhN2
NgIdM7EfMgIbL7=iOX62QHJ5Ph1nOWejNWYhMGEgN7UjOH:9SY2ATHj:R8R8R8N6
Q89oNgUiMgA_K6]]LGMmPHB7QXF4PGafLW1aL6m_Kfi_LWMlPXJ7RXnDUiFBSHR7
QhV9QXF3PXJ9Ri2CUIJGV9ZLWI^IV9NDTXn<R8>0Oh1oOW]iMgMiOH65RXj>RXAo
OGj1PGmnOGemOGioPXF8RXZ9QH:1PH:3PGikNG]oQHZ=S8N2OginOgmoP8>5QhN6
Q860OgmoOgmoOWikNg]kNWYiNWalNgYhMGEhNg]kOGn0PX60PH>6QhJ3P7elOH62
OgajNgemO7anOgimO7alOX25Ri6GVi^HU9:>RH=oO7b0Q8J6QhR7QhZ<S8R3P7]f
LVi/Jfa/KG1bM7EgO866RH^;RHF3PhB5QH9oOgenPHN>TYFFU9:?SY2CUYRGUI>A
T8j>Si2BTiBDTY2<RXN5QHJ6R8V;SY6DUI>@SH^;RX^:RXJ4Q8F5Ph1mO7j0PhF4
Q8>2P7mlO7enP8:5QhR5PGn0PH:0Ogn1PGmnOh22Q8F5QH>0PHB7QhEoO7enOGn1
PX:3Ph5mNWMgN7]mOGekNGMgMgMdLg9bMGQjNGIcL71bM7MgMGAbLG=cLg9cM7Ef
N7YlO7ajN7EaKFQRG5]MHVI[LGEjOH65RXj?S8N3Og]iNG]lNgQfMgQiNgenOGio
PX>3PX60PH:5RH^;RXV:S8b;R8R;Si:DU9>@Si6CTi:@SXb;S8b;RXR6QXJ8Rhf?
U9RLWYnNViNCTY>DUIFEU9>BTI6BTi>CTHj;RHN7R8R5PX:2Ph>3PGmnPH>4PGag
M7AfNG]lNgUgMgUlOX21PhF5Q89oO7UgN7UjNgemO7]lO7j0PH60P863Q8J5PGag
MGIeMG=cLgEgN7QgMWEfMgUlOh61P7elOH66RXb;SHf>SHf;RHR:S8nBUYRGUIBC
THn<R8>1OgmoOgelOX:6Rhj>Shn@TI6>RXEoNGA_JfQVHf9SIVQ/LGIkOh:4QHB0
NgQfMWIgNG]kNWUjNWf2QXR8R8V<TINKW9bKV9BBTHj<R8N8RXb@U9JIW9nQXJ2M
VYVHVIRHUY>@SHZ9QhF2PH:3PX60OgahMG9`L75bLgEiNgalO7]jNW]lOGelNgan
OWn0P863PhB4Q8J8R8F2Ogn1PhF8RHZ7QX>1OgahMgEcLFm/JVU[K6i_KVm`LWAf
MWMhN7MgN7MdLFe[K6e[Jfa_LGAgNGamOGajN7QjO7n4R8jBTi6=R89mNGQgN7Mf
LW5`LG9eN7aoP864R8fBTi6<QhB1OWakNWUiMgIfMWMiOH:7Rhf<RhV9RX^;RHN3
OginPHB6QhV<SY2BTiBEUIFEUiZLWYjNWYbJUY:@Si2@TI6AT92@T92AT92?T96A
TYBEUiRFTi>EUIFDTHf9QH5mNWQhNWenOWmoOh21PhN:S8j>SHf<R8=nNWIfNGj3
QXN6Q85nNgQeLFiZJ6U[Kg=fN7UjNg]jNWYlOh62Ph5nO7alOH:5QhR7QHB4Q8B4
Q8:0Oh20PH:1OginOWimNW]kNg]kNg]iMWEgNWenOWj1Q8J6QH5lNGEbL6i[JV]/
KW9fN7YjNGUjNgenOgmmNWMaJV9KEeIGFUmSJ6]/KFm`L71`L7=fNX69T9>BShf;
S8jATiBCUINJW9fPXZ>TYJJXYjBQWifLVibKViZJVYZIVIVIV9RIVYRFThn<S8b<
SHj=SHf<Rh^:Qh>0OgmoP7mnOGelOGenOWmoPH62PX>2PGmoPHF:S8b;RHN8QhJ4
PWmmOX62PX>3Q8>3PhF7QhF5QXR9RXV9R8N6Q8:0OgioPHB5QHB1OG]iMWAcLFi[
JV]^LWIhNGQfMWMgMgQiNgj2Q8J7R8R8R8V:S8^:R8F2OgaiM6eZJFY^LWIiNWYj
NGMfMWIgN7MeLfiYIF=QHVAWJVa_LWAfN7]kNgj2QXV<SHj<RHN5Q8F5QhV:S8j@
TI6?SXjATi>EUiNIVIRHV9FCShj=RhZ9RHN3PH63R8b>SH^8QhR8QXB4Q8F6QXF5
QHB2PX:3PWmkN7IfMGEfMWMiO7j0PhF6QXN7QXF4Q8>2PXB5QXN7QXF5QHF5Q7mn
OGemO7]lOGenOh1nO7YhMgMgN7UjNWamP864QHF3P7moPH61Og]iMW=aLG=eN7]m
OX62PX63QHR8Rhj?T9BFV9ZLW9RFU92;Qh9mN7=^K6a[JVa^Kg1bMGIgN7UkOGn0
OgemNgUhMWEcL71aMGQjOGmoOWj0PhN<Shn=S8^:RXR5PhF9Rhb<S8Z9QhJ6QhR8
QhV;SY6CTi>CTiFGVibNWIVFThn<RXR7QXN:S8nATY:AShf=SHb9QhF4PX60OWal
O7]jN7EcL6i_LGEiOX21PH>6R8Z:RHJ3PX>5QXJ4Q8F6QXJ7RHZ:RXV6Ph1lNGYm
Oh65QXN9S8f?SXb9Q85nNgYhMG=cMGMiOX:3Ph5nNWYhMWIdM7IgN7QjNgUiNWYk
Ng]jNWYkOh:1PGmmOGioOWejLfm[JfibLg9dNGaoPH>5QHB4PX1mNGEdLgAfMgQi
NgenP8>6R8R9Rh^;S8b=S8^<S8^:Rhb<RhZ9RHV9R8R:Rhb>T9>EUi^NXZJXYjJT
XZ2PXZ:OW9ZIUiFCT8b7Q8B8S8j>SHZ7QH9mNGIcL71`L75`KVe]KG1eNGf0PXB7
R8R7QXF4Q8B5QXJ5PhB4Q8B4Q8>1OG]lOGinOGinOGeoP81nO7UgM75_KFYWIFAT
I6EWJfmdN7akMg1[J6Q/Kg9dMWYnP822Q8B4Q8B3QHF4PhJ8RXj>SY6@SXn=RH=m
N79^K6eaM7IjOX64R8V:RXN4PGmmNgMdLFiZIfARHEmOHFEXJFa^Kg5bM7QlP8:4
QXR<T9>DTHn=S8b>T8n@TYBFVIbNWYjNXJ:TY:BUZ:^_/[Ff]K6^ZJFPViVFUIFE
UIFDTi6=RhR6QHB2OgahMWEdLg=bLWAfN7anOgmoP822QHN8R8N6QXF1OginPHJ9
S8j<RHJ6QhV:RX^=S8V7QH9nNWMfMGAcLgAeM7AfMgQhN7UiNWUfLW1_L79gNgal
O7]hMG9`KFe]JficMgYmOh22QHR:SY2<QhAoMfmXHEYDDU1BE5EGG65VKWElP8:3
P7ajN7A^JfYYJFa]K6]ZJFUZK71hOXB:TIRNXJ>QWijJUYBDUiRKWj6SXj>TYJFT
Xj>SY:FWZ:Z/[Zn][:RSWibJV9F@RXJ4PGimNgYjNgf0Q8N;SXn=RhZ8Q7YeNG9a
Lg=fN7QiNgn1PX>3QX^<S9:@SHf=Si2@T92@Si2BT8n@Shb=SH^<S8f:QH5lMgA`
L6m]Kg5cMWIcLViXIVMWJFY_LWAgMWMjN7MfMGAdMGAcLW5`M7MlOgn3RHf>T9JH
UIFDTHZ5PgiiLVeZIVAUHF9UI6EWJ6]^LWQkOWmlNGE]IUiED4]9B4M;D59HGfE/
M7f4QX^BU9>DTXn>RhV7QXR9RHf?TYNIWj>UZ:V[[Jf][jn][:n_Zj^/YZ>QW9^I
UY6=SHf:R8V8QhN7R8Z;Rh^:R8=oOGakNWUhN7UkOH24RXf@Ti>CUIJGUiNGUYFB
Shf;RXZ;RhV7RHR5QHN9RX^=SY6BT8j=RXF1P7ajNgUhNgimOGelNWYiMWMkOGal
OWilNgQhNGQgNWamOh1oP8>6RXjBUYVIVY^MW9RFThf9Q7edJV1GD4Q4@TM=CU=N
HfM]LWAdLVeWIF9FBTE1?CXh>choA4eGI71iQ92FVIjTXY^FThb7QXF8RXfBUifQ
Y:JZ[:ja];Ji_;Zi]K6]ZJNSWibHTXf9QH9nNg]lO7]mPHB4PX>4PGagLg1^K6UV
I6ASI6M/Kg=jPXR<T92ATY2?T92AT9:DTY6@TI:AT92=S8f@TiRJVYVJV9FAShV4
P7]gM79aLgAcLW9eN7MfMG5^KFe]K6a]LWAbM7MfM7AdM7AfN7aoNg]oOh63QHZ@
V:2TZZj][k6VW9R>PGA/IUiED4mCEEEKI6Q[L6m]KFYTGUEACDM2@451?d=8C5EO
JWN2RY>KWIjSZ:VWZJbZZJJQWijNX::TYjZ^/KFi^kVk_Kfm^KB_YijFShV4P7im
OH1oP820PhB5QHB2OWYgM71[IV9PGUiPHfYbN7f1QHV>TIFJWIfLW9fLVIRHVIVI
VYVIUiFEU9:AT8nBTHf8QXF0NWMgMG9cNgQaM75]J6Q/L7=fMGEcMWIhMW9gMW5_
LWAeMWZ1QXJ5PhV@T96?SiJMXZNY/;W2bLBo_;:SUXM`Fdi9@c/h>ci3BTeBEUIJ
FE5<@c/f;bTU8AhO8RLa?TQ@FfQdOH>6RY6HWZ:Z/kRh][Ff/:JOWj:TYjfe^[c5
blk@bl?1`KFPTh]kKF9NEe1EGV=YKVe[JVe^LGEeN7QjNgUfMWIhO867S96EUiRK
WJ>^]KZn`Kjk^[NcZZ2LWIfLVIJCS8Z<T9FCTYBFVYNASHV3OgUhNWanPXR<SXR0
OgilO7YiNG^1Q85iL6meNgYdKfQPGemLH6Q[Kgj:Ri6PY:B[[k>k`<?4_k6VY9V4
MVYDA3hf<S@c=3Tm?dA8ATE4?SLd<C0^9b<U:2T/=d58DEaVKGV:VZ^e^Ko8c<gB
dLS2^kNc[JBMWjFZ[K6f][Fb[:RXXYZAQWIUFeICD51BEUUNHF=SHfIaNGb2Ri:C
UYfQX:2OWj>YZZVZZ:Z_[jjc^[Rg^[bk]ZfUXYZARXB0Oh26RXb6Q85gLW5^K6YZ
JfYXHUeOJVmbMWYlO7YiNWamO7n3RH^<TIJFTi>FUI>ASXMlNGakMG1_KF]bOhV@
UIFFWZ:OY:ZXZ[6_ZJbWSgQ/H4e3@D0o@TQ8Bd]<CU1ABdI5@clm?cdb;34j?T=6
Ae5RKWR1Ri>KXjVc`L[9b<Fm/JbYYjJSXJ6RX9nOUhj?Ti:;QWmbHEMABdM6AdM;
DUQMHfQ]KVmgPHbCUYZNWYVKWj:VZjb/[k>f_/S8a/K3_[jo^kNc[ZBMU8V1OGQg
MWIiN71ZJ6UZK6maKf]YJg5fN7UkOh20Q8B0OHB=TIBKXZ>OWYjNWibFTY6ATY2>
SHb7P7ahL6]WK7=hOH:=UifT[;Fj]k[4b<O6_k:XWHQbI5U;ADM2?3hm?TA6A4A2
?S`j>SXh>CXl>cTk?dQBFVI^MGf;UifU/Kc4b]7?`kNb[JJQVYJIVi^LWYjKWI^J
Vi^DQg]`If1ECTmBDeAGG61VK7AmQ8V?UYfWZjZXYjJWZ:BQXJBYZjb][JbZYZ>R
WinQWiVDSXN3P7M]If1KG5mKE59DEEIKHFIVHfEXKG5fO867SI2AUibMUi2>TY:@
T96=QhJ4PhJ6PGeiLF]]Kfm/JfQPGF5VK6e/N7amRI2DV9fU/;Bf_Knn^;>YXi^6
LVaQC451@D59BDA6B48o@Cm0@T=7BTU5@dU?DUELHfYbNXNCVJ6V/;Zo`<6n_KVc
[Z^[[:b[[:ZTWJ>YZjf[X9NAQGM]H5A<Bde=BTU;D5]TJW9iPHZDX:BZ[kFm`;nn
_/34b/c7a/W8_kZg/J^WY:6JRWYdKfMNF5EFEe=AEEaUJFU_MW]iNWb0PH:7SYBG
VYjRXYnOXj>UZJb]ZZ>MV9>;QHJ<S8R3NWAeM71`KVQNFeYHGFM[M7YhO8N=TJ6Y
YZjk_<37aLG<`[6]YhQ]IUY=B4E4C517@d<m>clo=SLj=S<]:b`/;C<mBeEPL7b0
RY^]_LcEeM?=aLK8`;J_ZJJUWIB=RHB0OgmmN71YI5Y;?c/g<blb=CHkA4eDFfEe
PHZFXJFX[kRl`l:l_<33a<K5`/:n]K:_YijIU8j6NW1/J69PH5]KGEmTJFEQIg1g
OXB8RHN5QHbASXnFUiVIUYBFVIVJW9RDTHf;RXF1P85oO7YdLG=dLgEiNWIfL6MQ
FE=DDeEHG6]fQ9JT[;:g_/K7cMGFf<jk[J:;L6=NDTE6Cdi5ATQ7?cPi?3Tf>CTh
<2d_=3HiA55MJ7=lR9FT]/OCg=cEc/O0]k>d]K:[Yj2JU9:ASHb=RX=kL6AIBCXf
<bdW:34nBeUVLGV0Q8jMZ[6e^KZl_Kbl_l;4a<K8b<[?c/No]:fXXibFTXUlM75/
I5mMGV1SHV9UI6EYKgEfM7EfNh25RiFKX:>UYZBWZZZ[ZJ>KThn=S8J0Oh22PG]k
Ng]jNGEbLFmYIFAPGUiPGUYKFeMNJ75oRYBP[[Bc^lC6dMcLfMO</Y^;KUYEBcll
?T0k>SXf<S8`<3<`;bha<Bhb=ca5DEeWLh6BX[74e=kPhMkFc<>n_;N/YZBNVYVC
SXf@THn<R81fJEiEASH^:bTY;ca7D5i_OHN>U9nZ/KNob<[:bLW9b/S3`lK8bLG0
^k6VWiV?PGA/IV1HE59=ADE8BDQ<F5mUK79gNWUmP7mnNgj8SY2DVIbRYjZYZ:NR
VIFDS8AkLfmZJFY[KW1cNGIbMgUiNGIdM7=`LWZ0OX1oOGf4QhB=TiNGWZNW[KJn
bmWJeMC<]YB6NUe=CDM1>CDi>S/j?D4j;c4d<Bh^<c`k>S/oAeEULX2BY[G1cmgT
i>3NfLg3_KZf/Zn/XYRBT8n?TI2=RX9gKFELDdHi<2/W9BhnBeISKgQoRi^Z/KBi
^kZg]KJe][_1a<C8blo@c/S2]ZFDQGIWF55BDUAEEUIIH69QIFY`MGb3RXZ:Rhb=
S8^?UYNLY:b`[jj^[ZVOUi>@RXJ5Ph60O7emNgIdMWEhN7E`KVi[K79gNGQiMFm^
K6ESJFa^LgMkQHR7TJF][k[5blk=b/JlZHekJE53@3/d;bd]:bdd=S@_;Bd[:B/^
;bl`=CLnBee_PHjKZkc8eMoWj>;Kd/[4^[:`[ZVSV8j6P7ajOh5nNW5TDdDl<bdZ
:B`a>DEGIG1mRI:IXJ^c/Jna]KVm`<?6b<S6al_?dM3?clZm[9nBOF]NDdY4ADQ<
D5EMHfU[JV]_LgV2Ri6FUYFHVINGVj2VZjb]ZjRRVYJARHAmMg9aKfa]L7=dMGIg
MG=fNgenP7ejN7E`KFe`KfmdNGQkOgmiM6eQGFA]LWb7SiZVZ[30b]?MgMO<^9b<
PFiIC4Pn=3@lADQ<D516=bh^<C0b=CTk>SPmBUeaQ9FMYK>nb=7FeM38_KFaZjV]
/kJbYYnJUHn9QhEoMFULCD@o>cHd<30d@EIWM86<U9RLXJ>VZk2b/Jn_]lC9blc>
d<o?cm3@c<Bj[Yb7LfAHCda<CE1@DE=FEeQKG5]LGfAYL7MoQHJ6R8fCV9fRYJJY
ZjVSVY69QXJ6QhZ=Ti>ATY2=Rhb>RX>2PX1mO7]lNgMfN7j1P822Q8B2PX5kM6m[
JFa]KgN1Ri>KXjni`/cGh>3Ic/2UQ6YGAS`l?S`g>T96BTY;AST/;C0_<SDj?Shm
?TA@HgV<WJ^g`<O=dm;:`KR/XInQXjFWZJFJT8^9QX1jLfeTF4a6AdI1>cPj@4UI
L8>>UIVNWY^KWZFWYJFUZ;6maL[;b/[9a<?2`Kfh[Z:AOg9/IUiLG5]KG5UGF5]K
EeADEEUNIW5fMg]oQ8Z?TiNIVYbOXZBWZJFNUHf:R8V<Si2=QX:4PgmkMGEeLG5`
KW1`Kg1cM6m^KW1cM7EhNgUhMW=^JFY^KfidOHF7S9JLXJZb]Kc1a<c>aKBQRg=T
FE1@D4]:CU5BDDi9AC`a:2PZ;2lb>Cm2ADaIJGb@X[2h_lK9cLg:a/2i];Fh^[jo
_KVaYYjGT8Z3NW1TEda6@Shm?d55CEYWLgj7TIJHW9fOYJ^/[K2f_lG<d]?Aclg8
`/6m]ZnVWI64NW9[IV5KF5UMGf9WK71`L71aLgIgNh65RHjDW9jMW9bMWYfJVYZI
UHj9PW]hN7UlO7enNgQgMWQhMgEcLG9eMGQlOGajMgEdLg9dMgIbKf][KF]YJVUW
IFQdN7UlOXB=T9RSZ:ne_<WDe/^iYi1eI5A7ATE1@DM@EE18A3hf;BT^=C/o@412
A4A8DF=gR9JQ[;Fg]kNd/J^UXJ6UZZna/[2]ZJ6KVIJDTXYlK5eDDU1?DE=EEUYP
If]]LGAeM7AfNh65RY6HWjJ_]k_1`l6n_;bm_[nm]JVLTXQmMgMeLW9aLW5^K6]/
K6QUIVQZK79lPhJ5QXZAUiZNXJ>TYJJVXinIUIFDShb<SHf<RXV6QHN8R8N4Q8B1
Ogn1PXB8Qh:1QHJ5QHN9Q7emOW]eLgIjO7elNGMeMGEfNGb1RY>MZK:i_l[Gg=:j
Xh]bHU]HETi6B4eADe5@Bd@m=B`Y:c0f=C8`<CI1DVAgR9NSZK2i`<:o^K6UVI>H
YK2g_L;5a;jg/ZbSUhUkKV5HE5INI6=NFeYMHfeeN7IbLWAcLgImQHbBVjNa]ko5
b<K0^[Jc[ZRPVIJBSXZ9S8j<QX5oOG]hMG5/IEmMGEeNHVAVJg5hOX63QHN9RhnB
UINHVIZJVYVJVifJU8j=SHZ5P7emOgmmOgmmOGikM6]TGe]IG69SIFYZIV=WIV=S
IVUYJVigNGIfNWj0QHV?UijX/[c9f^?G_jZFO69FEEA@BTaADeADDe5>BD4g<34f
>c`l?d54CEY[OHfOZk:f^[jn^K>^Yj2LXJfkam3Ee]?<`kV]XIF3KEaBCdiCFemK
E4m?DE9DFEeMGEmRIF]ePHfHXZjia<_?dM3>bL2h][Fb[:NTXI^ETHn<RWmhMFe[
IF9OGUaFE5QQJFe_LWQnPX>5RHb@TY>CU9JIW:2SY:>PWj2MV9:>SH^6Ph62QHJ5
Q8F4PhB5Q8:2PGejNWajMWEfM6iYJVa]L7=fNW]iNGUjNWUjNWb3RiNQZ[FoalgC
f=>kXHikIUUDEE98ATaBEEEABclb9a/B6S5=H6YbM71WIFaiRINW/;Bf][>]YZ>O
V9NN[;W0`l2dZZ>DRhAgMW=]JVISH5iLFeEADe=DEEMMHF=RHfQ]MGf2RY2CVJ>/
/;6`[JZWY:BUZ;2e/ZfYYZ2JTXZ4PGikMg5]JVIRGUaJFUeRJFmcMgYkNWaoPX:2
QhnGWJF^/:bXYjNSW9RGU9>?R8B2P81nO7UjNgUgO85kM75aKVUSI6MWIf]cN7Uk
NWUlNGMgM75bM7EeNhF;S8jDWJFX[[Zm/Yf9O6iRGf1PGE]PJ6mbKfQOEU58?SY0
CUMGE5IKHFE[Mh69Si>GVIjRXjBVZ:FRXj^e_lG9b<:j]:bQUHb6OgI^K6ibMGAc
LVm[HeaLHVMXJ6Y^LgYmP8N>TIJNY:^`/JfZYjFSWifOX9nMW9ZEShV3PGmjMGEg
MgEcLW=eLg=cLgQkN7QlOh:4Q8B7RXb>U9NGUYVJV9FCTiBEUI28OViQKGn<Ui>F
]]cAZjF[/:ZDSi66PYBVY9F=THn4MFQNGV9NFEA=BDY6A4aBEV5^Q9na_Kk3`JBF
SgULEFn5NW1mPW=]NhZ6Ng1UGUA>E5YABD]=DUmaPi:JV9B?PGEmRHf=QX>6P7Em
UjJWXYJ4Mg=dNGeoNgMlN6IKFF9`MWZ0OGUgMWE]I5]FGVAVKGUlO8B8RXbDWjR`
/:BHUINOZZj_Y9B9R8b4NGF1SHYnN7j7Qh:0OW]`HEQEEV5[IEQEGFYhOGI[Jg=j
P7]^IVQ[KG=fLgR5SI:HWJ>`]:jRTHR:SXfAW:6NVYnQWIJCUI>BUIJ@QWmhO8N9
R8AoP7ajQI:MYZJMTiV_aM?=[iR:OgEZIfM[NHJ;RHB1QX=iMG=^IEaOJfiXJgAk
NgYmUIN?Wj:EP7R5RXnBTh^7R9>TZk6gZZ6Z[9^<Oh68MV]RGfMeL65ECD]6?C]0
@eQUHVUTH6M`KGInOHF=UIB@TXn:QHZFWjF/]k^m`;^YUY67OWQcMgj0OH:;SH=h
MgQkN7AcLg9aNgajOH66QhF8TYjWZJNPTXR7QhR:QH25SY:FUiRGSHF1PXN6OWMe
Lg=^IVEQG5iTJFMZMGj1P8:>UHb8TIF;PhbNY::X];k0]Yn7OWIWHfYRE5=MHV5T
Ge55@dPm9Ah]>CLh?Sm3ADQCHg=eLg=eMgUiN7MjO822PHZLZ:bYW9:@SHAoP8=m
KW20RY2IViRKY:JJRGeiN8NL[;2Y/IYhMG]jMWb8T9FMZ:ZVXj>YYZ>UYIjATY6<
TI^DQhV;RH^BU9>HUI2ATX^6QXZFUhn>RW]]IfANGVamPhB2NG5VGEIGG5iSJFaY
K6mYJ79jO7ijMg9`N7YiOh:1PXB0O863PWeiNWn6Rhb>UYfQV8R5RHAhP9RX/;_7
d]g@/JBVVYJJTj>kY9OHo<R4^__QVSHhQK?4f^CQaJ1mX]2bSEmPPhAcKFUWJg9K
>T9>CEENH4PlFG9H;ce]Je9BFEa[M4lmGgM;=61hJFb6PWZ2QiFUV8:3VjfHOGb>
X:RQVHR<VIV>T:Bd^:jFW;nkTXnWV8:L`kbUWJBZ[[^n[;:oZH=]JVimPVUHFe]M
G5=:BeMMDCde=2d_BEM08aTH:DUCACPeB6^:Sh1gP8V=UIjLS8>>VYV>Tj[0`JnL
X;O?dL2]XZo2c<c;e^_kn]fhZZB=OhZJX9n?OHj`^:60L6eSFEMOJW=cJfETHUY?
DVQWC3]6FE]AAc/k@493@C/iADm>BdPk=3Hi=c8];C8g?4=AFEYCACD[<3a0<RH^
AeEJIVaWJ75eMhBEViZHVJ:/^;^c[Jji_kZ^Z[6c/:RRWYfS[;:f]:bW[;:aZZNX
YjJZ[:>GU9B=QWaZHg>4PWQcM6i/M7=]K71cLVQLFF9/L6e/KVYMD4eHHemFFfai
LF1SMHB8QGigMhFHWinU[ZnWWYbV^LkBaJnJU9F9M6eiT:Fa^[^g/j^LUj:WX9^K
Vj>b_/G;b;fkc>3Sf]7Af=[@`K2SZ;Nj^Kbm_l:n/J2FThYmLFMRH6AbQYZSUh9o
QX1`HEiTKWV6Shj@TI6BUY>:S9NRY:2OY:NSXZJZZZNOUiBBRh5iM7IjP8N@U92?
UYfOX:>TXj6MU8jCVIJ@TI6@SHb=SiNSYj:LU92BU8j2O86<T8MeIEaMGUI<AD=3
B4]9Bdm=B4E3A4]EETPi>TaECTU9B4YCEe=EHG60R8EeHUeQG4L`:34n?cPh?dA<
E5A:?C<Y82<fDEiICe=XO7adM7j8SI6DTY2=Q7]fM71[K7R3QhR5P7YdKVELEeUR
Jf]NEUQKE48e=cTb9b<T:CQ6D65cO7YhOh9hLGEkOh62Q8V;RhbAV9VNXinGShV4
OG=^JF=RIVU[M7b0QH^?TI2;QH63RiFQZ[2d^;Vi^;Jh_/>n^;FaZJ>W[kBd/JbZ
Z:>JTI6AR7efMWQiNH2:SHZ4PH61O79eOWmkM7=fMgj8TIFBShf5O7UgL6U[N8ZG
W:6QVI6@THUmM6m_MX6:RX=nPXN7RHnETXV4P8B@WjJTX:6Y]Kfo`<74a;faZ:JV
YZRWYJ>V/;JbYYjJUi>?RhJ4RI:GUHj<T9ZPWinJT8bEXZbb]KJh_L?5a/W;c<g7
_Kg1b<c5`<;5`lK>b[faZjNNUYRJUHn=SXf>UYfPWYnOWIbIVIjNVI69QHJ:T9FA
SY:GUi2<Qh:0OGeoNgV0Ri:<PG]kNgf1O6mXJ6e/JFa^KW9bJV9SIFAXL7V7TX]g
JfAMF5EEFUiSJVe_L6UICde9@Ce2Bd]8BE5MJg9[GDm>E5UIEeYLG5iJEEEHGFEZ
KG=bJFEXJFUXHEeMGEaKGVEXJVIICD]BF5I=BTmFFeiMHVQWIVITHf=QGEmVKGR0
PH20PH>7SHf4Ng]nO7YlNg]kO8>:SXj>SHZ6PGmhJf5OHVI]MGEbLgAeMGA[HEeK
G5eKFU]OGe]GFF5VHUQ>BDaBE5EIGf1ICTI9DUULGUmNG5UFEeYKGfARGE]RKWAk
QHMlJEU>B44m?D=:CeIOJgEgLVUKCTY=Df1]LWAbMX6;TY::QXZ=SHnCVYjMVIRL
ZKRo`/K>e=OFd<Jo^[Ja[k>i^[Jd]kNc[:JRW9>AV:>ZZjZ[[K:bZYjCRX>3QhbC
Vj2PViNIWjFYZjb_]KNh^[Vg[jFQZ[Fh^k^j^kbj/jn][Jn^[[>i^kZh]K2_/[>a
/KBm_kVg^[^j_/C6`[^d/K6a/[Fe];>`[[Fm^[Fe];>a[Zj_[:JPW:6RWifLViRD
TYBHUXb5R8jHWijBPWQ^IUiIFUiWMh:4Ph=oN75[J6=RIfe`MG^2RI2HViVJUXn7
QhZ8QXN=TY>@SXb:SI6DTXf8Ph1oO7aiNGenO7f1PX:2PGegL6UPFeYKGfAWIV=U
K75^I5UGF5UJGV5SJg=iOGejMgMfKfERHfIWHUUEF5aJEUMLGUmTJF]ZJfm_K6Y/
LWAbKW1cLg5/JFQTGUMHHfYWI6IWIfU[KFi/K75cL75bMWn5OgUnQHInN7E`JfY^
L6m]K6Y[M7j1Qi2CRGE[Jf]RE4a?E5YSJVebMGE/Fdi9AdiGF5IHGEmOHfIVIF5N
GUiTJFU/KVmbLg5_K6ifO7n2Ph:1OgagNGenPX^ATY>HVYJ=Ph67Rh^8QH>5R8^<
SI2<QH61Qhn@SiFNXjJYYjFUYj>LV9ZJUiB?RhR:SXj9Q7mlNgYjO7emO7YhMWQm
Ph9oPHB7QX1iMWAdMGIjOX66R8N7Q860PhR6Q8ZATi6<RhnEV9VGUI>@SHZ:SY>H
VYZMX9fGT8f;QH1oP7ekOhR@V9nMTHF0OGM`LWb6R8N:SI6ARGifM7=]IfM]L75c
M7AhNgYiN7AeNWf2RXf<S8f>SY>KXJBSWIRFUI>@TI6;Ph63QXJ3PGeiMWAbL6e_
Lg9aLWEiNWUiN7MiO7inOWilOH64PGn0Q8Z=SXnAShnCTXn>T8n>SHf<Rhb<Qgmm
P8B7QX9oOWf0PX:1P7ajOH:7RXb>SXf:Ri2DU9>@SY6FUiNFUiFAT8n?TI>BShb<
TIJEUIROXIR<QXN8PgihMgUjN7IeNHJCW9b@PGMaJVAQIG1kOh22Qhf>R85mN71Y
JG1hNWYlOGamOgijLV]/LWQmPHN=TiZNXZBWZjZWYZR[Zj^/ZZBRYZjc];Bd/ZZO
V9BDUY>ATI:CVZ6SWiVBRXJ4Og]lP860PhZ>T8j:RHJ3PGmmOX:5QHJ2OGf2PWmj
M79aLFeWJ6ebMWMfMWIgNGYiNGYkNgUeMGMiNgaiMg=aKf]/L71_Kg9iOh60PXN8
Q7eeKVecNWafLWImP7n2R8j>R85lNWj5R8N=Uj6Y[ZjVUhj:QWmkOXB7R8jFW:6M
T8AmNgUfMgf3QhV;R8J8S8V3OgenPHF5Q8F6R8V:SHb=RXF6RXf<S8nATi>BU9ZR
YJJTWI67Ph5nOhF=TiJDT8^5P7mnNgUiMgUnPXF5Ph60OGQdMGIeM7AcKVibMWA]
IfM[LGMhM6m_L71^KFYYJV]YHeeIF5QED4a:AdQ;CU5AD5AHFEIBD51EGFEZKViZ
IfMXJVMPGVAXJfmaLg=aM7UkOGioOWelNWYfKVQWJVQWJ6Y[L7IkP7m`H5YBASho
AeITKW9aKFUQETe:Bda=CE9LIfmbL6]WHeaGDeMNIFUZKG=gNWalNWYmP8:3Q8B3
Ph:6S8n?SI2HX:JWY9^DTY6?Si6EW:>XZJRWYIjHTHj<S92GWJ6TY:>RWibKWInO
X:6TYJBW[;6g^KB^[:jc][Fb/Jn/ZZb][:ZYZjfZYJ6OWYZHUiJDT92AT8n>SHZ7
PgeiNGYkOGn0Ph5nOh:3PX5nNgYgNXB;Rhb?U9NFTYNOX9jJUY>@T96GWJBY[[Fh
/Ij>Qh9gKVaeOh62QhjCU8n0KVERH5ePIficMWUkOh1kMW1XHfI[L7IjOH24QXR8
QhJ6PgemPhV?THj=SXjAUY^QYZJVYZFUYZV]/[Rm`<;0_[bh]K>^Yj>TYZNUY:BT
WiRDTiBBSX^9R8R6QXF5QXN7Q85oOWn0P7ajNgj1Q8R;RhV8QhJ7RH^:QXF7Rhj=
RHB1P860NgEdMGMhMgMhMg=]I5aNIFQSG5YNIFQWIV9NG5UFDeMNH5mLGV=SHVAV
HeiNGUeHEe]PHfAUIfMQFE5;BD]>D4i>DE5DEeQDCTU9C4]<DUUPIFIVI6IWIVAT
IVQ[KW5eNGemNgQgN7aoOW]kOX>7QhV=T8b9RX^9QhJ2Ogn0P862Q8R?UY^LVi^L
WZ6TYZRXZ:^^/;6a/:n]Z:>RXj:QY:R[ZZJUZ:RUX9jRZJj_ZjRWZJb_/;2^ZjZZ
ZJBQWYnNVYNFV9^KVibKUi>CUYVIUiBDU96>SXj:QXF8RHR9Rh^:SHf7Ph:1PH60
PXJ7Q89oOGf2RHnCU9RMXYnDRhJ0N79dO863QXZ7PGaeIeU?BTQ9CUQSJVYZIf=M
F5==BDaEGfQ`MWMfMWYnOWamP862PX:5R8V:RHJ3QHfIWifFT8b6OgQcLWMmPHB7
RXR3OWn1P7eiMG=cMGMiOGilNgalNgYjOH21OgmnOGj0P7imOX22PX60P81nO7Yk
NgYgMGEgNG]nOgmnOX22PGmkMg9`L79cLW1`KfmaL6m`L6aVIFMYJVUWHe]IG5mQ
HEmLGEeNH65OFEIGFEeNGUiOH5mOHVEXK6mbMgj1PX:2PGijNGeoOWYhNGYkOG]f
K6EXKG1_KVmaLW1/JFMWIVAPHFM^L6i/KFm`KFQUHV9RI6Q^MgenO7anPH>4QXZ=
T9BJX:BUY:6MVIFDUIJHUYBEV9bOXJBVYjVZZjfa]KNf/Zj/Zj^][:b]/;6c][Fb
/:n^[Z^VXZ2PXjNYZZ^YYJ>UYjRXYJ6MVYNEUIFGUiFDU9JGUiRIV9FBTY:ATiJI
VijNWYjMVYRKX::RXJ6RXjBUZ:VVXI^HVIVIUY>?RhJ1Ogn0PhN9QX>4Q8B4Q85m
NWQeMGQiMgMfMgQfLVaXIFAUJ6a^LWMmPX>1P821P7ioPGmkNW]nPhJ9RhV7QH>3
Q8F5QH5mNWb0PX:2Q8J7QH1nO7UfMWEdMgUhN7]nOh21PX5lN7MhNgeoPH:2PhB5
QHB5QhJ6QXN9SHj<RhZ8QH:2QHN6PX22QHN6Ph:2PH:3Q8>2P7mmNGMhN7E_JfUX
If=OFUEBDE5AD4m=Bd]>DeQLGEaHEUQNHUmKFEeSIVEXJf]YJFUXIfY^Kfe/KG1d
N7QiNWYkOGn1Ph:3Q8F4Ph1nOG]gM7IhNGMcM7MgLg5cNG]mOh:5QXJ5QHF2Ogel
O7f1Q8R9R8F1OW]hMWQlOX23QhZ;SY6DUYRJW9jLVY^OYJBOWj:TY:BUZ:^YYZFV
Y9nKV9JFVI^LVYNFUiJBS8F2PhF4P7ilO7akO7amNgYjNWb0Q8R9RX^<T9:BTY>C
THn>TI>FUYJFUYJFV9VIUiBCU96<RHR8RHJ3PhB2Ogj0P7ilNgYfM7=cMWMhO7eo
OgioPXJ9RXAhKFMWIVEVJFmfO862PH9oMFYQGemNFeiVL7MjNGUiMFiWH5]HFUmX
LW^4S9BJVINHVI^KVI^MWI^JWJ>ZZjRSWY^JW9nMVIJEUYJGV9^PYJFSWYRBSi2A
TiFGVI^MWj6TYZNVXYbKW9bLWZ:TY:BRX9jMViRCSXb:RHZ9QhJ8QGmlNgUfMG9^
KFa[JVYXJ6QYJfi_KFYXIVATI6EUIFAUIFAUIF9MF5EGFUaLFUUIEeQMH5mMG5]I
EeMFEUUKFUUGF5]OHV=RHV5RIFIVIFIZKg9cLg=fNWenOWeiMG=bKfi_L79bL75b
L6eYJ6QVHUmNHVU^Kg1aLGAgN7YlOGioOh21PXF8RXV9Rhj=RXZ<SY6CU9>AT8n>
SHf<Si>DU9BFUiJDTiBDTHf;RXZ8R8V;RXV;SHj=SHf>TIBCTI:CTY2ATYJJWInO
WYZFTiBIVi^KW9bKVijSYjRXZ:RXZJ^][Zf[ZjZYZZf_/:fXYJNXYJ6PWinOWYfM
WIVETHj:QX:2PX1nOWmmOGQaKVi_KW5eMWEcLG9eN7McLG1`L79dM7EfMgMhN7Ym
PXJ6QXN9RHV9QhJ2P822QHB1OWakN7EdMGEdMWYlOh62Ph>2Q8J9RX^8QXN9RHZ;
RHF1P865QXV<SXj=RhR7R8^=SXb9Ph62Q8F4QhZ>SXZ8RXb9R8V<S8f<SI:GViVI
V9RHUYJGUiJFUiJCTY>FUi6<RH^>SY2@SH^:RH^=SH^:RXN3Oh22Q8B2PXF8Rh^9
QX>1OgahLfm/JFY[KW5bKf][K6m`L71aLW9_KFm_KFYXIfMZJF]]KFi]JFQXIV9Q
HEiOH69RGeeNHV=RHEmLFUMDE5EEEEMGEeQHFUaOGEYHEUAFF5]LFeMDE5MJGEmQ
I6IYJVY]Kg5cLgAcLgIlOWimO7eoPXF5QXN5Q8F7RHV9Rhf>SXnATiFDTi2>RXN6
QXN9RX^=Rh^9QhF2PX21PX>4Q8F6RHbBV9ZFUIJIVibPXJ6QWijQXj>TYjb_/:n`
/K:d/Zj/[Zn_/;6_ZjZXYZ:OWYfLVibLWIbHUIBDSXR4PhJ8RHV:SHj<RhjBUI6:
QX=mMgMgO8B;SY:CT8V5P7QbKFUSHFI^NH23QHB0OGakNGIeM7EeN7alOh>8RXR6
QhN6PGelNWUgN7]nPhVBV9VJVYJASHV6Q8J8Rhj@TI2ATiBETXb5PhN:S8jATi>A
Shj=Rh^=SXn>S8Z:R8B2Q8B5QhN9RHV7QHB1OgioPHB7R8V:R8R:RHV6PWmmO7Uj
O7amO7QcLgIgNGYjNWUiN7EdLg=cM7IeMGQhN7UkNWI`JfMUIFIYJfe/JVYZJVMT
HV5PGE]NHVEUI6AUIfMVJ6UZK6i_Kfi/Jf]/KW1cMWIfMWMgMGAdM79_Kg5eNG]l
OX21OgelOH20P7ilOH23Q8B4P7enOGalOX22QHJ7RHV:RXZ;S8b;RXZ8QhN8QhB4
QhR:RHJ3PX5oOGimOGemOWn0P8B7QXB0O7UhMgIfN7YkOGj0OgmnO7enOgilO7]l
OGn4QXJ7R8R8RXj?T9:EUYFFUINJVYZKW9nPXZBSY:>RX9nRYJJVYZJVXj2QXj2N
X:2QXjFUYJJTXj6MVIFCU9:@Si2BTI2=RX^<S8Z6QH:1PHB8RHR5Ph:2PX>3Ph1l
NganOX23QXN7RH^<SI6AT8f;RHZ<Rh^<SYBEU9:@SXf>S8R7QH:1PhJ6RH^<RhV9
S8j@T96@S8^8QH>2PX22PX60P8:4QHJ6R8V8QhF5QHB3Q8F6QhZ:R8V9RHN3PGim
O7]iMgIfMGMgNW]iN7EcL6m_KVmaL6i`LGAeMgQgMFm^KFa/Jfa[Jf][Jfi_L6m]
JVIUHf5OHFEWJ6MUI65PHV=VJF][Jfa/K71`L6i^Kfi`L75cLgAdLW9dMGIgNW]i
MgIgLg5_KVm`L71_KVm_L6m_KFe]JfUWJF]]KFa[KG1cM7AgN7]mP8F6QXJ4PWmn
OWf1Ph:2PX>2Q8N8RHZ:Rhb<RhZ:RHJ2P8:3QHB4QhR7PWmnOX20OWelOWn2QHJ6
QhR9R8J6QHF4QHF7Rhf=SHf=SHb<RhZ7QhV9RhfBUYRIV9VJVi^NX:6QXZ:PX9jO
WYfMWIbKWJ6RXZ>QX9jMViVIUY>@SH^8QXB1OW]iNgf0PHB7QXB1NWMdM7=bLW1a
LW=fNWf0PH>2PH21QHJ7QhJ7Q8B6R8V9R8N5QHR7R8R8QX>6R8Z9Rhj?T92?SXf:
QhF9SHn@SXj<RXR6QHB3Ph:2PX>6R8R5PhJ6R8R7RHb?Shf<Rhf=S8f>SXj=T96@
TI:ETi:AT9:ATY6@T92?T96BTY2ATYBEUi^KW9bLW9bLViRIVi^JV9VETY:BThn<
R8R:RhZ;Rh^7Ph9nOWekNgYkNgUgMgQiNGYjNWMcLW9eMgUlNg]iMW=aLgAdM7=f
NGUkNWQiN7MdLW5`LFm/J6IVHf1OG5eNH69RHf9PGeeNGEYJFEUJG5mPH69QHF5U
IVIXJ6UXJFeaMWMfM79_KfiaLG9eN7emOGalOG]iMW5`LG5cLgMhNGalOWelO7em
NgYkN7IfMgYkO7]jOGelNgUhM75_KFi^LWIhNGUhMgIeM79cLW9bMWUgMgMiNWen
O7YlOGenPHV:S8f>T92DUYRHVYfOXJ>SXZ:OW9NFUiJHUiRIW9jMViZJVYVETi2>
SY2CTY2?T96BTi>CUiVKW9nOWI^KVYbNX:2MW9^NWj2QWIVGUYBDUifOWijLW9bN
ViVGUIBDUYRJVIZIVIFDTXn@Si2?TYFDT8j>SXn>T8nASX^8QXJ1OgajNWQhNGQh
N7QfLFm/JV][KVe_LWAeMGEfM75^KW5cMWUkOh62Q8F7QhN8QhJ2PhB5R8R6QXJ7
QXB4PX>3QHN5Ph61PH>4Q81oOWelOH1lNg]lOWanP8B7RXZ9R8V9R8Z9RXN6QHB4
QHJ6QHF3OgikN7AbM7=cLgAeMGEfMGEeMgQfMWIhNW]kN7AfMgQgMgQiO7]jN7Uk
NWUhMgIeMGMeLg9`L6i`L6m_L75bLgEdLW=cMGIhN7EfMW]lOWmnO7YjNgYiNgb1
PX:1OGekNg]jMg=aLgAeMWEfLg5]Jfe^LWAdM75/J6EVI6ATIVQZJVa[KF]XI61Q
H65TIfa^L75aLFmZJ6IXJFMZJfi^LWMgMgIgMGEfN7UmOWn1PXJ4QhR:SXnATiFI
WZ2RX:6OWIbIVYNHVIVKVYZLWZ6QXJ6OWi^GUI2>SXn@SHb<S8f=T9:BTi:CTiBF
UI>CTI2=SY6CUiNGU96?SHb?T96>SHj;SHjATHn?SHb=SXn@TYJEU9BCU9:DTi>F
U9FDUYZJVY^NX9nOX9nNVYRFTY2=SY2@T8j=SHb=SXj>Rh^;S8nBUiZLX9nNVYVH
UI>DUYRGVIVGVYVHUiJGTi6CUYJBTiBASXf=SHb>SHj@T92>SXj:R8J5QHN9RHN7
Q8:1PH5lO7amOgn0P7mnOGalNWQeM7=`Kf]/KVm_KVi]Jf]]L79aLFm]K6YZJ6QW
Hf=TIFIXJVUXJ6MVIFEVI6EXJFYYJVYZJ6ITHF1QHF9TIFIWJFQTHf9RHF5RHF1P
HF9UJF]ZJFQWJF]]KW1cM7EdM7AbLG=gNWamOh20PH:0OWekNWQeM7AfNGYjN7Md
LgEhNgioP7elOGemOGimO7f0PX>5QhR8QhB0OGalO7ioPH1oP81nO7amOGakNGUl
P8F9RXV7QXF7RhjATI2>SY6CUIFEUIFEUiRLWj:TY:BSXIjLVYNEU92@TY>DTiFG
VIZKViNEU96>SHb=SXn?Si:CU9JFUiBDUIBCTI6ASXj>SHj@Ti>@SXb<S8f?S8Z9
RHZ9RXV8R8V<Shj=Rhb<S8n?SXb:RHV;SHf<SHf<RHV9RHZ:Rhb=SHb=T92>RhZ7
QHF4PX1nOGYjNgUgMG=aKfmaM7QkO7]lO7YhMWIeM7IgMgUkOGimOGalOGioOh63
QHB3Q8B2P7moOgimO7f0PX>1OWakO7amP821PX>3QHJ5PX:1PH61PH22Q8F4Ph5o
OG]jNGUiNGQiNWMcKfi^Kg1aLWAfN7UjO7amOGioP8:3PhB4QHN7R8F4PX:0OGan
OgmnOGelNgYhMgEdLFi]K6a[JVY[KW1`L6aZJFY[Jfi_KVi^KVmaMGAbLW9bLWAd
MWUiNgf0PX>3Ph:1PH:1OgmnOGenOWioOWUfM7EfN7]mOWmnP8:2PWmnOGaiN7Uj
NWYiN7QhNWUhNGUiN7UjNgajNWUhMgEeMGEfNGanOGakNgeoPX>6RHV9RXZ:Rhf>
SXj>Si6DUYVMWYfLVifNWYfIUiRHVIVKWI^KWJ2RXjJUXj6OWj2PX9jNX:6SXj>T
YJFSXJ6QXIfIUYJGVIbNWIbGTi2>SXj@Shf=SHj?SHb;RhZ9RHR;SHf>T9:DTi6?
S8b;RHN8R8N7QhF4Q8F5QHJ7RH^;RHN7QXB3PX>2OW]hMWIfMgQiNGMgMgMiNgj1
PX>1P7moOWelO7]lO7eoOWilNg]kNgYkO7eoOWmoOgmoOh5oOginP864QHF4Q8F6
QhR9RHV9RXN5QHF5QHJ6QHB1PH:1P820OgimNWQhMgMfMgUhN7MfMWAfMgIeM7Ig
NG]jNWYkNg]kO7anOGalNgUgN7MfM79aL6i`LG5aKfi[Jf]YJ6UZK6][JVUZJFY/
Kg5aLG5aM7IjOGinO7]kNgalOGn0Og]iMgEeM7AfN7YjOGmoOWenOWenOgmoOWj0
PXB3P7ajNWUiNWb0PXB5QhN5Ph5mNWQhNGUlOGagMGEaLG9aLG9`L6i/JV]]KW1b
LgAcLW=dMGIhNgeoP8:4QHJ7RHf=RhZ;SHj@TI6CTi>ATIBDTY2?Shn?SXf=S8Z;
S8j=SHf=SXj?TI:CTi:@Shj<SI2BU9FFV9VKW9^KVYRFU9>ASX^;S8b>Shn?SXb:
R8N4PhB5QH>2PhB6QXF8Rhf>Si6BU9BDU9BEUIBDU9BFUiVGUI:@SXj>SHf?SXb;
RhZ7QhN7R8R7QHB4Q8B4Q8>1OgimOGamP8B8RX^=SH^9R8R7QXF6QXF5Q8F6QXB4
QHF5QHF6QXF5QHN9RHV8QXB3PhF4Ph1nOh22PhB6QXF4QHJ5Q8>3QHJ7QhV:RXR5
Ph5oOG]iN7MfM7AfMgMeM79`Kfm^KVe]Kg5bLG5aLG5`LG9cM7EfNG]mOGioOWel
Ng]iNGUiN7QhMgMhMgIeM7=cLg=bKf]YJV]]KFi`L6m`LG=dMWQiNWYiN7UmOh21
P7ijNGMgMgIeMGQmOGalOGioPH:2PGmnOh63Q8B3PGilO7emOWn0PH:3PhF7QXB3
Q8F5QH:0OWelOX22PX:3Ph>1P7imO7]jNW]jNWYkO7amOWilNgYjNgalNWUiN7Qh
NWYiNW]mP860P8B6QhR8RH^;S8j?T92@T96BTY:BTY>BTY>DU9BEUYFDTYBFUYJE
U9BDTY2@TY>DTi>CTY>BTY:BTi:BTY6@TI:AT8nATY:@SX^8QX>4QHB3PhB5QhR8
R8Z;RhV8QXB2PX>6QhR8RHR6QXB5QXJ6QhR8QhV;SHn?Shn=S8Z9R8N5Ph:2PH1o
OWioP863Ph:2PX>2PH60PH60OginOWenP861PX>5QhZ:RHV:Rhb=SXf<SHnATY:A
Shf=SHf?TI2@T9:AT8j<RhV7QXB6QhN5Q8B3PhB5Q8>2PX:5R8V:R8F3PH60P7mn
P8:5QH>5QH>1PH1nOG]jNW]kNGUkO7akNWYiNGQgMWEcLG5cM7EfMgQgNGYiN7Eb
L6m`L75dMGEdLgAcLW9aLFm_K6Y[Jf]]KVi]KFi]K6UVI6AWJF]]KFe]Kg=eMgQh
N7YkO7enOh20OgilNgYhMgIfMGEfMG=aLG5bLgAcLViZJ6QZJVUZJFYYJVYYJf]/
K6a[Jf]]KVmbMGIeMGIgNG]kO7aoPH61PX>1P820P862PhB5QhR9RHR7RHb>T92A
TY>FUIFEUIFDU9BDUIBEUYFEU9FFV9ZKW9jMWI^IVIRGUIFEThn>SXf>Si:CU9:B
TiBCTI2BTY>CUIJGV9RGUI:?S8b>Shn@T96CU9JGVIVHUYBBTI6BTiBBT92>SHb<
SHj>S8^;RX^;SHj?TI2@T8n@TI:BShj=S8^:RHR9RX^:RHR8R8R8RHZ9RHV7QH5n
OGimNWUjNWenOgmnOGemOWemOGeoOgmoP861P7mnOgn0P821PH62PhB2PX:2Q8F6
QhJ5PX20P7mkN7IfN7YlOGinOWinOGakNWUiNGMgNW]kNgYkNg]kNgamOWinOgim
OGioOh20P820OgmnOGelO7]jNGYlOGimNgYiNGMdLg=bLW9dMWMhNGYjNGQhNW]k
NgalO7anPH>3PX1oOWioOgemOGenOGinOWn1PX5oOh21PX>3PhB3PX60OgmoPH61
PXB5Q8F6QhR7QH:0PH1oOWimO7alNWUhMgIeM75^K6YZJVa_L75aLG9aL6i]KVmb
MGQkNg]lOWmlNGUjNganP8:4QHB4PX5oOh21PX61PX61P7moOWimO7eoP820PX>4
QHF7RHZ:RX^<SHn?T8n=SHb<S8b>SXf=SXn?Shn>SXj@TI:DUIFEU9>BT8f:QhJ6
Q8>4Q8>3QHN8R8R8RHV8QhJ7QhN6QHF5QhV;S8^9R8N8R8R9Rhj@TI>DUIBBTI6?
SHb:R8J5QHN8RHZ;SHb:R8R9Rh^=SXj?Shn?SXb:RHV:S8f=SHj<Rh^:RHV7QhN7
QXN8QhF4PX:0OWinP8>5QhN:S8f=SXn@T96ATY>DUYRJViRETi6@TI:CTY6@T92?
SH^9QhF4Ph>2PX61PX5oOGYjNWUhMgQiNWYkO7]iNGYkNWQhN7QhMW=aLW=cLg9b
LG5cLg9aL6i/JVUYJ6UYJVYZJVUZJFQVIVMXJVYZK6e_L71aL75aLGAfMgMfMgQh
NGYkO7ioOh63Ph:1PH1oOWelNWUhMWAeMGIfMG5_Kg5cM7AcLW=dLg9bLW5bMGMg
N7YlOGmnO7YgMGAeMgQgN7MhNGQhMgIgN7UjNganOgmoPH:2PX:4QXV;SY6CU9:A
TI6ATY>CU9FFUiRJVYRFUYFEU9>AShf;RHR7RHV8RHV:Rhb=SY2AT8n=RhZ:Rhf?
TI6CU9JGV9NEUIBDUIBEUYNIVi^JUiFDTi>AShf;RXV9R8N8RH^;RHR7QXB4QXN7
QhR9RX^:QXF4PGmmOGenOWioP8:4QhZ<S8b;RXJ2PH61OgenOWmoOWekNWYjNg]l
O7anOh20OGYhMgMhNG]lOGn1Ph>2PH:3Ph>3Q8F5Q8B5QHB4Q8F3PH20P861PH20
PX>5QhN8R8R:Rh^<S8Z7QhJ7RXb=SHn?SHb<RhR5Q8:0OWmoOh20OgilO7]kNGQh
N7QiNWalO7emOGj0PX:1PH21PH1oOGelNg]iNGQhNGYmOh20P7mlNGUjNgaoPH1m
NgYkOGioOh62Q8B3PH20P822PhF6QXN6QHB2P7elNWYmOh64QhV:RHV8R8V8QXB4
QHF7R8N6QHB4Ph:1PH:2P7mnO7]iNGUhMWIeLg=dLg9`KVa[JV]/JfUXJ6QXJ6UZ
JFMUI6EVJFe_LWAfN7UiN7MfM7AeMGIgMgQiO7enP861P7moPH:2P7mnP8B7RHZ;
RXR7QXF4PhB4QHF6QhR:S8b>Shj?Shn?Shj=S8^;RhZ9RH^=Si6@SXf>SHb;S8j?
SH^;Rh^=SHn@T92@Shf=SXf<S8^:RX^=SXj?TI>EUiJEU96?SHb<S8Z6Q8B4QHR;
SHnATi:?S8Z8QXB3Q8J9SHn@Shf<Rh^:RX^;S8f?T8j=SHf<S8f;RHR9Rhf?SXb;
R8F4PX:3Ph>4Q8B4Ph61PGmoOgimOWinOWamPHB6R8V9R8N8RHV8QhJ6R8Z;RXV8
R8V<SXj<Rh^9QhN7QhN9RHN6QHF5Q8B4Q8B1Ogn1PH62Ph5oOh1nOX63Q8B1OGYi
NWYjNWYlNWIdLg9`L79cMWIeMGAbLW9cLViZJ6QXJVe`LgEcLG9`Kfm_LWIfMGMi
NGUkO7akNGMfMWQhNWalOWelO7anPH:0OWakN7UlOW]kO7UhN7UhN7QeLg9cMGEe
MWIdLg=dLgEgMgIdKfYYJfa/KW1_L75^JfaZIfIVIVU[KW1bLgEfMGIgNGUhNGYi
NW]nPH:2QXV<SXn@TYBDT8j>SHf>SXj=Si6@Shb=SXb>SX^:RHV;S8f<SHf<RhjA
TY6?S8^;S8f?TiJDTi>AT9:AT92BU9B@SiFIQXfKR92<R9JEShnBS8Z6Q8B3Q8:4
RHZ<S8b;RHZ;R8f<SI2?S8Z7RXN0Q8F7RHb8RXn?TI2@TI>?Rhf>SY2ATI6?S8Z9
R8Z;RXV=Si6ATY>CSXjBSXZ9RXb=S8R<SX^=Si2@SXZ6R8R6Q8>8RXN6QhN:S8N5
QXN7Pgn0P863PWmoPHV>SXf<S8Z;RHF6RH^=Si2BTi:@SXnBTHf<Si>?QXB5Q8>4
QXF8RXR5QHF5R8EoNWEjPgieO8N8N6agOWb0R96ISWigMW1QG65XLg]cHUUMK7f5
Pg]hNGmcCfV8DEQbHW^>RY:CP7j6OWIaNWejMfU^M6iSFVAZGV5THVQ_LWMeKgMi
If]bI6=XNWi`Lg9cNGEePgmkOH:8P7n3PhJ8Qi2@R8N7Oh>;R8V;RHZ9PGakOGE^
LV]TIfE]M6a[L7=cKfe[JVidLVmZJVYYJV1GFEaGEUYKHficJfEWJFaXHF1WL79h
P7mnPGinOX67QhN8Q8J7RHZ7RXjCV9fKSHV9RX^@V9ZKU8Z6S9NIShZIU8N<UiJ@
Vj:IT9:ESX^:S9>FTY2@RXF5PhB9RX>4RX^4Ph>2TY]`NiF=UYjJVYZNX9bLX9ZM
ViROW9jVZIbEVY^JSHbGTi:JX9JLZ:VXZJFBSY>DSX^EU9BBTiFFWj>RXInHVIjG
VIfFSXnGW9ZEU8f4Oh>8NW9aK6ebLFeeO7edKFe[K75gOhF0Mgj9S8V6SIRJUi:;
RHR9RHN4QXfBU9FFUIFBUHj9S8N6PXNBUHYnOGf3OWaoNGf0P7enPX:5PWamP820
Lf5NGUUEGVQVIfmYE6QdGU]WKVQKGEUBGFU/If5IF59MMdI2EVIRF65XO79TJG9`
KGb>QXF@W9FBUXjBWjJHTIJJUHnAQHRARhJ:OH27RHN1Ph:5QGmmPWYkM6e_IFUR
K75TI7AgJVecO7M_N7ibLgMcN7QlN7AkOgAaN6iZLG9]K6]YKGJ3Q7YcKfeVIG1h
NWmiN7emPHIoOHVBTi:CSXV6RYBFRX>7RY6KW9fJTXjBThZ8U9R=R8jDSi2@S8F=
Th^5QGmePXV?V:2FQiBAR92PW92@UinUWIfVZjn_[JZUXIjJVjRSWIZ;RHb;TIZE
Sh^8QgmmR8Z9PH>;S8j5R92@U9BBT96EThn@Shf=SY6>Ph:7RW]]J6EXJfa_KW5e
OX1hPHV7Q7AfNVmZKFmRGfacJVj3PW5`NG9/JFQeO7n2QHV7Q8B7OVeYKGQkMFi]
L7IjMGN0P7aiOHB0Mg9bLWAfMGEeOHN<PW^0PGj1Rhj;VJ6FT9BLVIfZXIR@T9jU
XIVFUiJFVInSWHnJZ:JSX9bDTY>;PHF>RiJLShR5Rh^:QGj2QXnCQGR0SiF:R8Yn
PGmhMG1iQ89jLgEeNH=mLFQZK6E/JFUaKF]MF6mcJfMZI5QWMf]TJfi]J6YaM7Qf
KVIOIFEWHeeWHF5YL7=cNG]kOgQ]Kf]]L6aQGWIoQXQmOWelNG5cLfidNgadMGf1
P7A]KF]/KW=dK71VH6ihNFahSiB?RXR4OWUkOHJ2Oh1bIfImTI>ITh5fMF]UNHeo
J6I_QY>EUYNDSiVHSHR1QH=oP8BJW929P7YhRI20MGn0N7Z8UYVYZ9F9S9jVZinI
YJZSTi:EVYfNX:6RZ:bLRhBAWIjVWhfBZjJDVJ6NVZRTShnJVYFHShN:SYFASX^5
QH=nLGR5NWQnT9B;VZ:BQ8BAUHV>Rh:1PHB:Thj@W9NDV9bBOgUjKg1oSY>2PhjI
WIFKViJ9QHB0TYjRWiV;Oh^?PfaLGF=[HeQAE5]HFVE]Kg]nJ65VLhJCRFULJ7ao
OXRFU7edJfQ^NXAhLFefRHn6O8fQW8n<TIRHV8UlQHfSZYQmLGj6TYVIUiVCP7=a
PI:PUW]aL7=gQhj0NH:;Q8Z8MgM]EUA_Q79THeI;CEUJDdU4AdU:CEm]JF5QJFUY
LGQ/GVEjR8R4RhEiOhBATI6JX:>BTjFh_[Fi][>`^L6o^:FUZZfSVZ:MWjb^Vi>P
X9N4N865QH62R85oQhn:RIJPWX9_MHNGU96@Qgj9UhZ0O7mkJ6QYKG=XG55JIg1k
MVQMLHb;PgE]KViXI6]jS8n;MfQ[Nh]iIV9RHVn3L5iaPX5hOXF6PVmOH6mjN7Ym
Lf5OJVa[IfARF5AHG5aUKfUQIG1YGfIaPHR2Ngn:QH29ThUmRIBEU8f1PHJ4PGel
LVelOWM/LHN@ShZ3MGRAUHMoQi:DUiF>Si:8QYRPShBBVHZ5SiRGSh^6Q8Z>R7]h
LWR0N7UhNFiWKgJ5RhV0LF9UNG][GF1/NgibL86IU8J3M7>9XZ2:Qi2MYZ>MQgAm
SXanMg1_LgA_MHR=QH>:RH:8WZNLUI>BTiB@UjFXY9ZKVIJLXijBUIB:R9>KWJ>U
X9bOYkFaUh5nV;BeXiJGU8n<T8j=Vj67L6a^NhVBP6YYLh2;S8B0Q8V=U:NcYYVL
Vi24S9ZJT8^6PhMmM6]YH5UKFf5[O7QaNXB2N7]mOhR@SXV7Q8b?Rg]aOY>GRh5m
PXjBTXj<U9JCQ7R0QhfASGYWJ7Z6QGifN89oMWZ2PGI/L7QfLWAgMWQjOXbBRX:2
OX28RHZ6S926OX:7QhAnN7MgKVIHC4Q@IVQKDf9lQ7mcJg9nOG1TGfEhQ7]bKWAm
QhinHUeYO89cIfQkRHZAVIjMWYjJRGeoRiN?PhB:OWUeK79jNfiOGf=[L7MnPh5k
M7J0QY:JUhZ3SIJFS8F:TIVDPgb3RH9jLVQUKW5YJ6YUIgZ6MfU]MgZ0PG5^MWYh
OH:5O7j=RhEnP8Z@RXF?V9bFRHR?WZ:IU9BGWYN?SYBGSHIoOH>DVhUhM7b7PW1J
G6aaJFAUL82;T8F5U9bHShJ1QYJ[YhYeN8FCUHYnOGm`GF5]L7MoO6mSIfihNWYl
PXQkKF5TLH62KV]gP7moPHJ?S8J5RHZFZJ>?QI>Y^[^TT9:MX9jIU92ASWmfP8jE
VIJ:N7J4TiF3L6agQ8V6OGj5QHZCUHnEZJjQTh^>UIRBR96LUXanLVmgL61QJW9e
NX65Rhb5PWakQYJGPG=dQIRJQG=kR8Z8R7]lSiVFTY^PYJf^X9FLZkRbX8J1SiVF
Si2ATi>DVYfJWZ6JQg^0PhR3LW>1RX^>S8R=Sh9cOY6?Ph62Q8J9RXR;SI>LS6eK
GFM[He9;DUeOGeUAFVIRF61YHV9VGU5?GVahN6=KHW5eJfQOF5IHFf5_NXBCSgik
P8f@S85jPhN8O6maNh5dKWQkL6MZKG5kPWaaIFMlSHE]J79nQX9eL7j@U8UgM82;
RWmiM7EkOg9JE5aeQ7]ZH7>3PGUgN86AUHf9R8^HXIb;Qi>KWibCSYBRWHn8Qi:H
THjJXYJ>TiVIWj>LSWmnU:6FR8B@Wj:LR7IdMg=[GUYVKVaZLW]mQ8j;N6egRYbG
QGn3R8Z=SXR7RHAlLVMUL85lLW1eNgYlLF]jQXQoO7n3OgAePXAmOH>7R9:ITXAo
RYZPSFm]OiJXXiNBVjJYZJBTYjZKRhF5SY^UU8:2TJ6OSWQaP8AlN7MhO8B:QhJ7
TZ2PTHF?ThjAQWb2SiJ;QX^?SWaWHFEVHFQaLW^8RgUZKX:PZiV3PHjMXYN1NhB9
RhR4Q8N7QHB6Q8^KWi:3PhnNXiJ6Q8V;RXb8N7MnOgijOXJCUHN1OX23P7ASHVec
L71iPHAoN7b0OWn5RH9nS8inM7B3V9j=MFIWLGAXEE5NJ6MVHEaPI6QZJVebNgUT
DU9PKVeREEERIFaeMFeWIV1GFF9fR8V0NhF:T969QXVBTH5kPhZ6NGMnQ85nPGac
OY6AP7EhRifRU8N9TYnRUH:2SYNLV9FBU9VESXbBWZVVTgmoT9NES8R9R8N5Q7ii
Q92GUY6GVijFS8Z@V9RES8JBWiZ>SiRES8Z;RhfAV9VAT:>f[iInNXNFUXAbLH:C
V8YnOhN<RGmZHVQ_JfEUKX2BTWaaMhJ?R89nP8F9R8F3QXbFTGieMh61NW5`NWn3
MVEQJgAZHFQdLfm]KFENHfi`JfUcQHAfM8BGY::<MFejRi:?R8V<TiJIVI^OVi>5
NWV8U8j2NX>>Si:@Q7QcLg1^I5]QJfeZL7^0Q89nNWMlPWmgNhB3MW1mQX=mO7U]
I6=RG5USNHEbEe1IJGYoMFIYNH>0MFe^N864O7UmPHJ4NWF5VZFKR8>=WjNVXYfK
WZ:TWYFDVij?QH^FWZ2PVIJJYJJER8>5OVYTK7IjOHN4Mg5lPg]cMXjOVHb3QiJZ
/::BTIRIUHA_HVUhNgMYGeiXKF5KIG^;QWMWJG9iO7Q`HUm[MWQgOhZ9OWAaLgQn
PWmiP8jDUYFLXIfET9FERHF=TH^<UYJ:Oh>?UiJ:OW^7UiV;OXBAV9>7N79kQXV9
RXZ>Ui:1N86@Ui22O8:9PgQgMW9bMGE]JW9eM75aNhN>Rh^7Qhb@Sh1jQHb;Ogb4
RHAoQHAoO7j0LV]dRIfXWhf6SIjSVXIgNhJ@SX5eMhF@THIdK6IQE4A8G6a[If=Y
LWAgN7I^KWMkMG=iPh^;Ph:7QhJ4OgYmSiN<PXJ8P7UeLg5bOHR8PGf;TXEhN8B@
TX=aKX6O/:F?PhF>TXj2O8>?VIVJX:J/[Z:BTj:WVHf9SYFLWj2LUIFDT8N3RHj=
PGMfOX^EWIZ@SY>BQXZIVi>9RXV6QXJ:RhN4R8=eI61ZNXInJUeTMWmnMG1hQI2;
OgIbNH22P7mnOWa/GV=dP7j0Q8F4Qhb<R8B3R8V2OhB=SXV4Ogf0Ri2;Ogn@UY>A
UIN;OWYfKfmcN7E_KgQnLfITKGb:RGQZKWb6Pg]fM7b3OgAYIfacMG=bLVmUEdY?
I7=cKVUTIVicL6MPHVESFeMSLWaiM6iWJg9gKFEYLWYlO8J?SXf?TXf9R8=iLWB4
Shb2OH2;VIN8P8RJXInIT9:NYjJQW9JBUIVHV:6XYIV=RiBNWinMVIBIXInBPGf:
U8]mMgMgNGagLgR9T8n<Ri2ETi2DUi:;TIB=SYBBQXJ@UYB9NgAiSj6PShJCXJVX
VXb8SXn:R8J1PXfET92MXIJ1KfagOGUeMgQgOH:0MW9fOgmeKW5hO7f2Q8>8SX^1
OH26R89oRI:;PWa^Gf9cLF9KGfUaLVEGGG>1NVMMHW63SH^4PhJ7QX5iLW1hNg9a
NhF8PgalQHf:QXEnN7j:Rh1jOHF6PGUeNWn1PGQ`LGUkNGf5R8=lNh6:S8bBSGak
R8Z2OhF<THilK6QcP81hK69TJ6UUHfEYKgAeMGAcMGA_LhJHUhMjMh26RHV=SXbB
V9REUj6TYInHVZ:UXZ2KUijXYI^KYZZSVY^PYZVYXi:5Qi>;N6i`NhJ2LfEXN8F9
QX20R8j>S8b=TIRNW9>:Q8F6OG^6T8I_HUaKH6M]Jf=QJGQhLFe_LVmWGeePJ71d
LFmgPGa`LGMeL71bMGQmPXAoP8ZDU8MhN8>=S85jOHN?S81gN8>9RXV5P7n3QH=n
OX22NFe_Q9F=QXJ7Q8:6QhR8R92FU8b:SHj<RH=jM7AgM6i]MWahM7^6R8:1Ph>5
R8j=QH23SXb0Mg^5RXIjLGB1SYBBRh^?V9bMWIfNXJBNThjBU966Pi:NWIF<Qgml
NGIaJFU_MWI/JG5jO7]iLg5hOgahNhB:R8F<Thf4Q8R:RY6GTXN1PX9mMG1cNWij
KVQ`P8^<QGYbMWn3Qh^<TIJKU8R5Qh^6PHFCXZ6GT92DVj6UXYVCVJ2KU9NNWj2O
UXV<UIVGTXf8Q7aeNHF8QXV:Q8>:THf9RHZ8OG1[LXB@Rg]aMH>?T8EfLG5cMgId
KVilQX5iMgQcJf9RKh26P7YeLG1eNgE]KW=gLVmgPhV;SHInNgn1P820QHR4PhjF
SX>6RXN8SXf5PHN?T8UiK6]eO7IWGEmVJf]UH6E`NGQhM6a]L7IgNGj0OWMcNHJ?
RgmiM6QPHFETHVI/K6ANHFE[KfeUH69WKFm/KG1bKW1iOGI^LGAbMh20N7EeMgj0
N79eP8N7P7YiP8nBRWiiOHFCUY6?VJNWW96BVIZ@QH>>VYfKV92=TY^LUYBGWj:N
UiNOZJ^SV8n:S8n<QHB7QhN;T96=S8f<SIFLV9>BUinUWHn:SiNHT8EjNhF;RhN9
RHV=T8f7QhZBVIJDUIB<Q8::TiJETi>?SI:GU8f5PWmhLW1bLg=cMGIaKg9bKW5e
M6m`NH63PH23PhB:RhN2P8>6QWa]Gf5/MWQ^GeIKIV]^KFY[MGn1OGQiPHAnNh63
O71/LGV1QHEnLF]`NWiiO8NCUY27P8B<TY68PX68RhZ?UYRFTHR1PHB8R8J5R8b<
RXJ7SI:=OWIjQHb;Q7YfNhB9R8J0O7ahLfm]KgA^IVYfP7M[IFQ`MWj3Q8B3Qh^9
QXN;RH>1PH67TIRLVYJDTY>EV9BASY6IX::PWj6SZ:ZYXiZHVYjSXIVBUIRFTHV1
NGUhNWYeM7R1Rh^4PHF7Pgf1S8n7O7UjOhN<ShIjM7=^Hf1UJg1fLVIPI6UXHf5S
I6IZKG5`JVM/LGIiNWE^K6miOW]dK6edMfmUIW1mQHAhJV]fPHJ8QGmlOgmiN7n;
U8j8RY6ARH5mOh>;TI6=R8J8RhZ9RH^>SHJ2Q8V>TiRGTi>?QhJ?Sh=iNGioQ8N6
Q8J<SXn:PX65TIJARHN9Ri2?QGUfNh24QX=oPhfDTXb;TYZJUIJKVI2;RXJ6Ri:C
S81mQ8fDUI:AT8^3NWIbL6m`LG1cM79eNWQ^KG=dNhF9Q821PHF8Q7agPi:ES85h
MWn:S8EiLVe_LVmZJgAnP7akO85oMG1gQ8J0N7=_LW^8TI6:P7QbKFiiQHf>S8^9
RHR8SY>FTXZ3QHb;RhjBU9JJThV2PXN=U967Q8bGUhn3NW^4RHN0MW5bNX62PHB<
THn4O869RWicM7n7QWicJFM[MG]iMWIlPh:0PH>2OWYdLgAeN7n3QHZ8Q8N:R8:4
QXF9TINDSXf?UInOTXJ5SI>ET8^?UYZJUHb2OhF6OGA_L7IkNgYlOWmjMgMjOGim
NWQgN7f3QhN6PgifL79eN7QbL75aJfATIFMVHV1RJ6YZJFMUIVa`LWAeLW=kO7Mf
O81kKf5JGVYgO7]dKFmdNWn4QXV:QX1nQXnCU9>JY:VRUXf7R8jEViZIVIVDSh^<
TIFFTHb9Q8N<Si2CThf9RXR6QXV:RHZ<R821Q8:1QhV0O8:<THb5OX6=VIbGS8:1
Ph9mNWb2Rhb4OGn4QX9oPXbEUHn;RH^@VYnNVYB>RXZ=U9bMW9VET8N2OgemO7Ea
M7]oOGQeMG=cN7UhNGUhOHJ6NW1fP8N5NVm/N8:5QGiiM75_If1OIfi]KW9`LGj6
O71fPhMoN7UeLWInQi>CPg9ZJVYdNgMgOHF6QH62Ri6BUI^MW:6WZZFRY:JQV964
N7ElO75XJWAiNG9WH6=^N7]bJVY/KFmbMgb5SHb7R8nDTHj;S8n>SHf<RhZ;SHj?
TI>EUIBIX::QX9bGUiJ?RX^?SI:KVY:AUYF<RI:LXjBOV9JT][^cYj>TYJFMU8n@
VJ6QVI:@TY68Ng9aM79^KWMoOGYfLgEjN71/JFU_NH63QhV8PgaiNh24QhN1NWUg
KVY^KVYVIfIUJW5cKVQRH6A[JV9QJG9cL6a]MGalLF=JFV9]LgIfMWE`K6]_MW]l
NgQhMG1/K75gOX20PH5iLgEiOGn2PWmjM7AjOhB6QHF4OgUkPhN7RHb9QXV@TiBE
UIBGViJ9OW^3RHJ1PHF<THn6NG5gPHF2Oh22PGU^JW1jP7mnP85oN6i]M7f5RH^5
O7^1R92HWInLU8Z4QHbGWYfKVIF@S8R0Ngj3PGf0Ph1hL6a/Kg5^IVE^NX:1O7Ui
OH64PWj0Qi2GVYNFW9jFS8Z<RhJ1Oh:6RXZ7Q7ihNX>6PW]eLG5gO822PWifKVYW
JfmcN7I`JfidMGEiOGilOH64QXR8S9FKVI>?T9NITXV7Ri2FUY6:R8N9SHf:S92B
SHN6RHf=RXR<UYfNWIbJV9jTXYN<Qh^DVYbLWIfJUHn>TYBBSXf<QhB3PGaiNG]k
Nh25PgehLg=nRXYkL7J2RHZ7QhV@Thb0Nh25RXjAU9^U[:ZRWIbLViB>SHn>Qh>0
OWj3R8V5O7AdNGj0P7ilNGIcMGYnPXB6PgUaKVe[JVYYIVAVJFa]JfIRIVi[HEaO
J6i]J6M/L7AbKfUKDU=LGUeMGUmPGeePJFm^JFeiOgikMg=eOXN;R8=oOGn2R8nF
Vi^CR8B6QH:4QhN8Qh=mO822P7enPhN9QhF3R9FKThN1PXF8Q7ejOX:2Q8J4PX62
Ph>4RY>GUHn<SY6AS8^@UINCRGehO8RCV9>9P7ioPXJ<TYZMUXj>TiFEV:2VZJJN
UiBCU9>ATYBFThj7PhJ<THn7Ogj4SHn9QHB3Ph1jL6]]LWYoOGUmQ89kN7]mO7I`
KW9mQXJ0NWYnPXN8PgekOH63Qi2JX9nFT8f<RhN3Oh5oNWMgN7QhNGQjOH20OWf0
R92DT8Z;TIFBRhF4QXV?S89jMgIhNGAaMgj0O7IeMgMcKfmcMWQgLW1eOh>1OGI/
IVIWJFmeNgagM7=_KFmcM7=fNGQfMWIfMGQlPXJ7QX:1QHnKViFBU9NKW9JGW:6U
Y:2ES8Z;S8R9TZ2TX9ZIVijQWYNBU9FARGagNhF;RXAgLGAhMgIlQX^8OW=`LWIj
OH63PgmgLFmbM71[Jfe/IV=XJV]bNWUbL7EkP7mmOH65RHf8OWQjOgmlN7UoQH9j
N7YkN7=^K71hPHAnNGUnQ8^=Q7n1Q89oQI2IWIjLUi:>Rh^;R8F6QXB4QHAnNgb0
PgmjNGUoS9RLVYFGVYN@QhF4PXB7Qh1iNG]iLfiZKGEiMg=bLgAdLgAjPH=oMVe[
LWYnO7QeMGEaL7AkOh22Q8F5P7enOWioQHR8RH^9QHN<SY2@QgacM7j7RH1iN7f1
OWYkPHV>ShYoMG9eN7Z1RY6CTXj=TYFESXEmOH60PXJ5PX>7QX1hMGMhMGElQXf@
TI:@RhN8SHj9Ph1nO7eoOW]iNgemOX21QHZAV9ZDTYJHVZ2QX9jOYJRQThV8S8b9
Q8B8R8B2PHB5QhJ1OH25QHB6QXN=UinNUHj>SHF2QXZ9Rhj@Sh^8RXV4OWYjNW]o
Ph5lN7UlP85mMG1bNXF:QH>6QhR6PWmoPXF7QGmkPHF2NgQjOX>7R8N6QHN7QHB9
S8Z5OgI`LGIhMW1/JVMRHVQ_LgEeMG9[IFI]MGUmP7miMG=aKVmbLg=cLFUTIFig
MVmXJW1cLg5^L7ElPGibJV]/JVIWJfe/JfUZKFi`L6YUIVY_MG]lO827RHN4Q8F4
P826SIBIWInOW9VJViRFUYRGUIRKUi:@T9:FUi69QHJ@VinLW:2SWibJUiBEV9RB
RhJ8RhV3P823QXF2Q8N9RXR5QXZ>T92?RH60Q8R9RHR5Q8>2QH^>T9>HVYZLXJ>Q
ViZNWYnQYJBRXjFX[K6]XiVEUibMUiJIVI>?SHN0PXR:QgebK6URG5aQIf]^JfIV
KW=cLFm`LG9cLfaWK7AdL6m`KF]YIfYaMWQkOWeiMWEdMGUkNgI`JfYZJ6ITHVAY
JFARIg>0PGQbMGZ1RH^6Q8bDUI28Ph>5P7MfNh25R8=lNgekMg=aL71cMG5XHfai
OGimOGekN7=cN7anPH>0OX22PhF4P7imOGeoP7n0PXB9SHb6PH:8T9>FWJ>SXZBT
WIVNY:FQViVNXj6MVYNCTiFCTi^QWijQY:BW[:n[XINCTiBFV9VEShR2PXF6Qhf>
RH=oOGanPhR:RXJ3PGijNGQhOhJ4NW=eO7mlMgEgMgQiMg5`MGeoOGUeM7=aKG1c
N7akLfi_L6e]KVeYIfY/JVY]LWMhMgUlO7QeMGMlP8B:TIBDUYNFU92=SI2@Shf;
Qh5mOH65P7=YJg9hNW]nPXN9RHN0OXF=Rh9lN7]lNWEaKg1aKFUWJV]ZJVi`KW5i
OWagLWAkOh20P81nNWIfNGenOgilOH23QHF4PGekNWUmPHF6R8fFWijFT8j>RhV8
R8^?UIN@QH64R8N4PhB3P7]dL75eMgMeMGQjNgn4QXJ9RHN5Ph:1PH62R8V8PGUc
L7InQ8Z<Qh:3PX64R8b?ShZ4PH1lM6a[LGE_HemUKG5dMWIfMWIdL71hP8R;Rh^6
PGafKfY[LGMhNWn3PWelOGajO85oNGAeNGf2RHnCThf9R8R9SY>EUI>CUiRGUiVG
UiRFTI2?SXf=TifRVXb7RhnAU9VKWZBZZJ>NW9nSX9bJVi^NWibKVY^KVYJDU9FI
Wj6OX:Rb]:nWXZ6UY9bJWj>SWYNASHjAU9FEUI><QhJ8RhjATY2?SHR1OGn6RH9l
OXF6Q85nNg^1PgidJfY`NGajN7AbKfQOGVM_LFmbLfmZJFaZIVAVIVETHf9UJF]]
LWMeKVYXJFmgOX>6RHb>SX^:RHN5QHN;TY>;OgZ1RXUoMgEfN7YkNGIiOh9nMg5`
M7MiNgUcKFi/If9RHV9QHV5MFUaMFeMGG61PGUUIGfIYJVmaKVYUHV5SJF][JVU/
LWEfMGAdMWMdL79fMFm`N8B:RhZ<Shn>S8R4QhnGW9ZDTI2AT8j<RXR6P7I`Lg=`
L79bL79cM7=aMX26QhF4QXV8PX25S8j<Qh>1PHF:SI2BTY2>RhfAUYZMWinSY9^A
SiFGU8j9Rhj?Si6?SY2DUY69QHN?V9nTYjNYZZ>GT8n<RHjFVYfQXinGTHnBU9:>
RXN7R8V:SHn>SXb9QXV>T8n@TI:EV9RETI2CU92>TI28P7j4S8n<Qh>1P8B8R8F:
UIfOW9NCUY^OWIF>S8^6PX:3PH23PgiiNWYhM7=jQHb<Rhj@ShZ4PhN<SXf;RHJ5
PgmnOh60OW]fLW9dMGEdMWUgKVMXKFi[IfMXJfa^KVUQHFM/JVIQGUeLGf=UIVAO
EDe=Cdm?EEaNH69PG5UHFf1THEaKG5aLGEePIfY[JF=PHVM/LGEgNWf1Q8:2Q8R<
S8nDUi><RXj@Si2@T8f;Rhf>RhfEVY^HUYBGWIfJUiNMWiN>S8Z7QHJ7Ph23QH9m
N7V0QXAoOWj0PhJ9TYZPXIjGU9FGUiNFUYJHVYZKWZ:QViFEVYV@RH^BUiRHVY^N
XZFRUXj?UIZKVYVGUiRFThn>Shf7PWmlNWYoPH1oOgilNGEfO820Q8V9QX5oP8:5
QhR9RHJ2OWn2Q8B2PX>0OWj0Q8R;T9FFT8V6Ph>5QHB3PH>3PGikO824Q81kMG=g
NW]mPhN5PH1oN6eWIVASIfa_L6i[KWEhM6m[Jf]ZJF]`MW]jMW=bMGQgMGEeMW]n
OGeoP7efLGEmOGI/JFQWJFYXIVQYJ6IPFUiWKG1bL71eNGQeMgj0OGQgMgMfMWId
M7MlOgmmNg]nQ8V=Shj>TI:@TIJMXJ6OWIjOWYnNWIfQY:>QXjJSWYfOXInHTY6A
TY6=R8N:SY2=R8B7S8j?SX^6PGijNWeoO7QdK6ANG5mSI6E[LgQgLFiaMGEcLWAd
LgAdM7QlOgmmNg]mOWn1Q8^BUi^MWYnOViNJX:>NUI6@UIjTY:2NWI^KViRFW::S
WYRFV9^KVYjSXYbMYJNOUI:>R8F7SYFET8j>T8n:Q81jLg5bLWAmR92AT9:BRWUY
IFigPYBTYj2GRgieM7QkNg]lO7j0PX5nO7f1Q8>3QHZ>T92>Rhb=RXJ;TiB?RhMn
M6]WJFe_L7AgMG1XHUmMG5aLH6M^M7MfMgUhMW9_Jfa`Kfi_M7YiLfi]K6MQHFM]
KV]YJ6UZK6i^K6]/JfMSH61QHfESGeePHUmKGEmOH6=VJVa/K6YVHF=YK6MQHVQ^
LWAdKfUUHf5RJ75gMgEdM7AgNGYhMW^5RhnBU9:9PHB:RhN4PhF9SXj8PH24QHF3
OgeoQ8bDVIbPXinHUY^RYZBTYJ>OVYRKViFBUj:ZZ::JV9^MWZ>Z[jf[ZZni_;^l
_[jm_;Vf]k^n_K^h]kNaZjR[[:ZVXYbJVibMVIFEUi^OXZ6IT9:LXZ:MV9BCTI2B
Ui^KU8^4P7iiLg5dNX25R8V8QhN6Q81lNGMgM7=eNGenOGM`KFi^JVU]L75`LWMk
Mg5]KFmcLfm[JVe^KVaXIfY]KVm]JVU]KfaXJ6YZJ6M/L71_L79bL6aXI5mMH6M]
Kg1`L6i]JfQUHf5QHF9RHVEZKW5aLG=cLFe_MW]iNWn5Q85oP81lMVm[J6Q/LGEf
MgUnPXB1MfYXLW]nOh24R8N4PXF4OWQgN7QgMgAbLgQmPX1fKVmfMgAcLGAmRH^4
Ogn3QX9lNGf;UiZMVHn;T9VMThZ7Qh^?Ti^LT8>1R8Z6S9bY[jfVWIVESh^>U9ZH
V:6Z[ZFIUXn2NgV2UIjNWZ6PW9VERX66UJ:VXJ2UXYNAU9^NViNJXZ^ZY:>RX:2Q
X:6W/[Jc][R]WIRFT8bCWjRZZZNNTXZ1OH1mNGj7SHb6PWUZHF=/Lg^1Ph>1OG]g
KfIQHFEZKWEiMW1ZHEYJGVAXJV]ZJg1bKfYZL7AdM7MlP81nOX21OgYfM7EhNgUe
LFe]KVeZJVecNGQ`Jfa_KVa_Mgn3QXJ3OGUfMG5YHfA[KFUUIfYZI5iKFUYNHVUc
NGQbK6aWGV5fQhMlM75^JVU^NH5oO8>8OgEdN7alNGb:TXf2P8=nLVihRHb0OHF=
TY29Ph1nNGj:S8b=SiNHTHf<RhInMWbDVhN2UjVNP75fQ92ARH:1OgekMG9dNgmi
JFb:X9nDSHjDUHn=TYNRZ[6n^Yn8Oh63QiZa^[R`ZZFPZKF^WiJDW;33cL>c[jfX
Y9fDUYnMTXf@TXn>T8]nMGJ1S8f7OGA`LW=hPX9mO7enPH:6SY>?OV]VLhNBT8Qn
MG1]JfMUJG1eN7YgNGn3OgE_KFQWL82=TYB@QGMYHV=XLGQlOgieJF=VKWEjOGYd
L6eYIfIVIfMWIV9PI6Y^Jf=LFUYHFF9aOH:1O7YiN7IdLWElP7egMGUoQXf>R81l
O7elO825QX>1QHZ;R8>2Ogj4RH^:RhfBUifOVi:=T8f2N7AmTZB^Zj>NTX9nOWb2
UJfo`KBLQhnSXI>CY[6^ZjRPYZbWXI^4J6EfR9ZX[ZJ=Lf9RNIBPVhMcK7Z>VZFK
LU1ENJBbW81cL7EbGDeBIh29PG5SJGIcH4Tl@51ROZJmZg]8=U5_Kf9UOIJNVijG
Pg5IBeMeS9NV/jnTSfI:F7Z4M7NH/:V>LF]gQhYmLX6OZib1KfioT8n2P8^BPFa`
T:ZUQVAHJXB9RIjg/Y=hJVefNW]lQ96HTH1dMh21MF]fQXZ6Q8ZCUi>7OW]gMG^3
QhZ8OgA]JFUeRYVLVY66OgaeKW1lR8f>S8b=SHIiL75eLV]^O8F3OGalMfm[KGJ2
RXMlLfm^Kg5eO8N@U9:@SXV3Q8^CV9jTY9bBSXf9Q865SH]oLfaZM8^LViN@OgnA
UXEiQiVSXiF7QH9nP8jUWgQJBTIPR:F`YIV=I2hWDhnd/i1]LhZ1FeMhPg=^Kfan
WZ69NVmSGFEhP8:N_kF>K5Q:CfZ1QY:Y]J^HQVY@E6EZM9Jn^iAoPH9U<RE5IhNH
TH]mI6AbO7IUE5QmW99jOH=lLFQaOGYeK7>K]9a`IGn?Q71/Rk_Edl6]XI1`GVf:
Ykk4^jbAO7ahJFj4UY63T[?1/HQVJ8:JYj:CUZF^Z:2QY9R0JU]NNY:BSY>IUH=[
FeMEEEEGI7F4Si64KEI>DEEMM96MTWicJfQXIVI[Mh><THf1N75/JVUaOXB;U9ND
SXZ8QX9iMGb>WJ6OW9J=R8Z>TY:<RXb;RXb?UIVNX9^@Pgb4T9FHYkBcXi27OW9^
Lh:EVHf4Q8EeG5edQ8j@P71oVHmjNhN<PFAIJgQ_KVmcNGfDZiahFeI^PHJ=[<nm
K3m/^<FDJFb7Q6aPLj2`V7IVN8I/G6YfPhioFT]]Si5kHD`nBW:7NhBT]JN2ED=K
L61SRkFiWH1bKfmQFVMSE5UWJFf5VI68OF1GJViWK8>MZZRNUIB5K5E1BWFM[JJO
WiR5Lf9GIX:DX:Z][ZnRQWA`NHF1Nh23PH20RI>@PGN2UiR9PHJ9QgYbNHF<QWUc
MX2=UINIUHE/EeAXPIFTZjVGPG9]L7AaLWQnP8:8RXF1Q8AkMXBDUXf3OX6:SX^>
VInSYYnBRXfDU8nBVinW];Ja[jj][JZRWJJ`/:ZOV9:9SJ2`[if3Kg=iN8BPZ9:4
RHn3KF=_RY^ITI:MU6Pf:UVK]JF4MGn2L4`lHHMnFe5^SHIK<2aPX9mI@6IjN60n
@g:Z_9a^CeImSWMPF5MXMW=dNHF6NWQL:3Y_NXRRX8=RG65YMVedR89nNUiLNX:5
UHeU@CeDJFmmVJfVT7=LE4mBMJ6h^J:;RX=XBDALNZC?`Xm`I5eVQj:W[;c0WV]=
CEf0Y;Bk_:Z<O7j5PWE`OY2QZZ>HV9R<OhFCW9bGTh]lKFaoTibTYj:HQgEYJgN5
TYJ>PWanO7IfOhJ:RhIkLWEeMX2<TY6GYJRQX::Z[jB?Qhj?Ti^LUhn:SiVLUY28
PGijPI^ZZ9bHXJ>FS9BQZjV;JFEkSYNEPG21WY5YGgN7R7YHEhf^XHn9M5iQHFAh
PXB9Q6mYK6=NI7^?S9>JQfUDBe]gPgUIDfV1V:1lBD=CF5]nZJfCJd=2I7b7Og9_
GE]L@3eCE59RL8>7FC]MQgeOBDAIQ9MeKhMoIeEJNYnIE1HNChc4dKb/W7aG?4Y`
T[cOl?KLY6U0?EU]MXj_a<c5]9b3MFaQHFUjRYbZ[kg1XGUXIgEmOHRBT96<OH2=
TXYeHV5cOWj0Q8=nKeA;GW5eMh>BV9B@R7abJfedOHN?W[6i/j:ARhQmLW1iQY^c
_K^aYjRVWjBQUYJRZk:i]k:f^JV@TZBTXJnbX9:;PXR:NVQ4;DQeZ/:hXZNn/9JD
]>3bfL75`/7=bJYnDU^Xc9aVLZS7]7eZU:5V9B8[3QUTXK^KAP@07UYTAcQQ[K9=
001CSD0002a0>4I[MdXS:RT`FE@K2DFK[g8V9WJ_R2l02dAhRGi]P[K4V5U1GX>E
/nK//7UgRhA/SMKQZH>B_=75b=?5ZjZk_K2ke>7ooooBYkWVh;JLUIZVY:Re][oC
e[bMQG=THW9nP8ZT/[[2]I=kKe@j;QhI<TmNHUmBBUUfT9:7OgAXGd`b9SABK6iL
FVb6U8Q]DdM9Ce9BHG^2MWR:UY>2G4==JWa]DdiQQY1W@Sm?IViQGV5UK6YeQGi/
MYV/ZXiLEW]mFTeQMX26S9boa9V0Ri2E]]O6ZK2ZRY2ga/G1]jVDU[2hT6A_VjfO
TY:[/YR;TiJCTHf8TjZZSgI^Mibm]h]LF6EXHFF3/;R<If1YOhb:UJbMFbP`D6A]
J5iVOI>PSgb1PW=PCDYHHfn5WJFQWI1hLG]lLgEnPXRO^<C7bmCOe[6:O8RCTI6G
WZ2Y^/2f[JBNZKFZVI^`b<o<bL_8a<W7_KF]Y9RBUYZFTIZ[/jBHVj2JQgQbJfAV
KgIjNg=dOXN5K4TV2P/ZCf9OCDULJUTn=cHhC5A>C4a5@3`Z7R<gBe9?Cdm9@2PG
>6QkN71VFCPL8T9JIg^1HTEDKFUKBDakXYIWC5Y/KW1iNgI`KG9cLWV9RFe5>5=W
HUe]Ph^4N6iXFe1YRXAiSZNlcM;6W5DE0111NZ6^YInLUiR<LFQXGeQGGFEgSiZI
WYR9PgMYIfANGVUiRXEiPiR[ZIZ?RXAnNGZ3Qhf:RYRSZ:F/^Kg1^Z>IUj:fa<[3
_l_Mhn;Nfm_;^kVd/l;BhOGkm_Ooooo_cl37eM_Xoooooooonn?=blW3`lG:c]3G
hNk^eLcLgLJSS9Rb^jf@PY2ERH:0Q8ElMW1LBTICJ6aQH69J@blb>2dM5b0X9aD0
01/Z=4=>CT8X000000@E9BL^@STE00P@1`lG52T`400673U=FG:@VhE700004Rm>
KgYjR9nVW8YcGDe9CeaUK8RW];2LQh:<ViYmH5aOJ7^8S8jFWj>Z/K2^[ZFGS8jE
TINY]KNncM_Qh=C3^:^QYK:f];oImOooongOdkj]Zk>mbMGTk^kam_CZel6XWJ6Z
^<WOl?Wek^[Pd/2VQFaUMI:NXkSEh]JnZ9^9KV1WM7UjR9BHUXEeKG9bJEY7A4UE
GEaCBeI]K5IEJ7E]H6=RD3@O:d]KFU9QQ8EYDd<e:RPZ;CY@DC4J<eIRGTT^;d4k
>UEeQgI:5P001@h<3a@[D7B4OgEWDR`500003BeHMG]dKg9`Gc/?00002c4nCfUg
P8AmID0N20000`hL>5UZKgb1P8EnJE95@TYMM7YdNX>@Y[Nh/JVFNFigNgIkSIjT
ZkcChnSNbK>OUjFd[:2U/lGQm?GjooCMa[J`/kW3c]ccooooooo/eL[3a<c@eMWD
hoSoooooi=G=^ZVOX;G;e>;Vh=SAa;F_[k6]ZJNKRY>aa/Rm[ZZe]ZZVZjRDPhF5
NW5eTK_Yooo^YW=SFD8gD6Q[N9K1j_KWc:MkA0/0018hF767WkO?eknAHCHH4aHG
83URSk71_jjEOV4j710F:S]2CV9fSZ>TUG]I?CI2De98CEMTOYBJW9^<MfQPFU]X
LW=`MH6?WZ>LSGiaJg1eL6ALEeEOLXFFVIBASXZ4PgQSDU5DF6QmRXb<R7YZI6IR
FD]2BUIGGG:5RXMoLfm]Gde6ATYFI6aaQIJET92>PVmLEEMIEe]cTYVEUiJ5L61M
NZkHgkZ5JEa9=ceFIfIXQ;WPh=;5[7Pf0P001B]AMiZ^`mW@Y6i06P000PdL=U^;
_^3J]iAa@QX:31heAeI[RJ_6e]FjTViED5e/K6eiSJg5aL30^::CUYF>T9:<QXN@
Y;c=e=?9^Jfc`;jdZYfBU:2^^[nl]KRm^k^m/jVPRgQfQIRRYj:KWjRYY::RTWIR
GVIhRiNIUi>GYjRBMf=JGUiQLh60N79fOGmjMGMdHU=CHFa^O:KFjm>XPVm<:2Y2
CdU4EWn]a;^/WhEM=1L5018Z?U]hSj>[W85TARlU80h000DP?6B7S7e^HE12>CLo
?R/I7SYJM8RAQF]HDf5gLemJHFYdOXN=SXMnPiBSZjZRVYF@RHbIWIVKWZ:bbnGe
l]c1[J:RZ:b/XiRQ]]3Si^3Ld;BOWYnNViJK[;o?fmgA_J>?QhJ8RHV;S8Z@XK2d
]JfIT9>HVIRKWY^HVYn/^KRWV9:CW;?Joooo`X]kNWMnTI^FVK7Dmooon^O;WW9L
BS]0EFj9/Momo^[4UFmMEThm:AdZBgRZc<nmXWmNBdM9C4e7>cmKPIj[XhI^IFUb
LVUMDe9NJg1`KfaTI723V:JYVhUnMgR0Qh9cHUeXPj>mbLJfXI:<QX9mKf1OKX:C
Y[Nm^:RFRH=lKUmGDDeDI7IoNgQjNgaoNg1VFTm@EeeVLGMcJV9TKWQkLF5MGE16
BU1DFVZ6[<g;Xg5QFd@iBDhk;cE>OZV^X9ZFOf1>Ac@T:BlbAfQmRHMdG4Y3B55:
=1hC52A6I6YNCd8b:cA3DUQ=?3HmC5URGT/j>dUKIVIRIFU]MGj1NViPF69hSIZR
Yj:FTYZZ^KNSShN8TZ:gb<_0/jje`l_9_k>[Zk6c];Ba[J^ZZJbf_;^d/kJg^[bh
Yi64R9FQ[K:[X9jOX:FVX9>1KV]iQhZAXJ^UWIjNVYbHSiRZ//7>/H9hPWekRY:0
LGR5UJno]Zj^VG5LET]8DEILJ7N7SXj2JUQGEe=??bTW<41ONG]eKea5@DiCD5IF
BT9@IGV5NfUQGUeVLWYmP8B:T9NJU8QlL71nSINNWYNBVJVe]jfMSHJ5QiRa^[>V
ViNR/KF]X9F>S8fBVj:TW9NLY:b_Z9J:S96DUi64OGYfM7MoPhN9PginOhB8PW1Q
Hf=KF6=cPhR3R9:DUJW8eKjAN7=ZHfYbLg5cPYZ^]kJ_[:JAOWQ^HeYCEf1]PiJH
RW=VKgf4PWQXH65VLGA^JV=HCTYILh>8RX9cKWJ0Pge_H59DI75jQi:EU9FFUI26
OGIeOHfT/[6][k6ham;>_JfRWIfW^lW;a[Z^[KFk_;B/Zj^[[kNo_kBXY::SXibG
THV4Qi:IUXj4O7YnO7MmQ7a]JG5kOgeoP7Q^Jg1cL6abO7UiR9jec]2_RWelKEiT
Lg1PGFj9XJb/[:ZKRgeZGUA4>3Y9FFEaNgAPEU][N7Q/Fd`o?DQ=CU5@AC4R9caB
HFUXIFAYKfePDTHm>C]4C59IHV]dOXN9QH1kLfU/O8N6QHF2OhJBUi68PWmlOHNE
Vi:6PH63RHn@SHf>R865T9NHTHR3P7emPH=nNW]lOGn1Ogf1OgYoS929PX63PH::
S89gMWf2P8>BW9jO[/kXh;bXYHedN8N0JF=eQXbDWZbk^:B@Q7moO7EdM75aN8>3
NG=cMGIlOWQaKVe_LFm]JUi>@3Y5GgEnP8>3O7^9Ui>3NG=^JVilRI2GWZBWZ:RT
Vi>?Tj>d_/C2^K6a];Nk^k2QVj2/^<;<dM77_[o3`KVb[:>QYjf_[k6c/ZZTXIjL
V969QH>0P8:0NWMkOWelP8Z:P7EeMg=^KFaSG65ZLgf7TIZU][^PRHb7L61PG4m5
BEQWKWB0QWiaJfELFEQCCe9ABTU;BD4g;BHX;2/[:RHW<3Lf=3@b:R8H310V<bdT
8R<V<TABDda7BDe=D5UJE4m9BU5GGVIYJW9oRY:JWiN:QXN7S9:CT8j?UZ:]];Rf
[JRWYJ6RZ[6c/k2ZYjNWXiZAR8>5RY2CUINKX:JYZJFMU8f7P7imO7inO7f4SiFA
SY6>Qh>8Si>AU:Bf_[V[Y:>JSi2ESX1lPHF6RiBS[ZRHSHjATi:8PH>6QHF;SHEl
N7IgNh><S8F1Q8V<RXb?RXF1OWj7TiRGU9NLX:>XZJ:IUibUZjja];>^ZJfb/k:d
/:RUZK6j`LC8cLc7a/G0^[Ng^Ko6cM3;a;jn`/K4_[>XXYnMWJ6RWiRDTHf>THj:
R8J5QhN3P7mmMg9cLFUTI6=PGeeIF5YNFeYPIVIUIfQUI6IYKgIdI5EDDTU8Cdi3
@TaDDe5?DUUEBd]AD51DDdi;BTI6BT]5@3lm?4A>DDi;BdiCE5=BCTDn?3`nADY9
AD0n?T==E5IHGF5TIf]cN7QeL6a[K6icNG]nR8nATIBEUINLX:2TZ:fc]KBf^[^k
^K:ZYjJXZ:R/];Zl^kZk^kF/XY^GUi^RYZFOWYnQXj2OWibFT8f?TiJHWInES8Z<
S8b=T9:AT96FW9bFTHn>Si6JZJjSVijKSXZCUXn8RI6FVIfRXj2JUiRFTi>DUIRH
U9NOXIVCUYNASY:CT8j@TiNDS8Z=S8F1OWUhNgamPXB4Ph:1P8>7Qh1gLW1bLgAe
LViZI69TIfMXJVU/MGj1PhR<RXR8RHR3OWYfLgV1Ph1nP7aiO822QHV8PWejN7Ql
PH:0OWaiMWQiNgYgM6e]MWn2QH=kMW=cLG1_K6MNF5EEEEYOHFAPFUQFD4a;CU1@
DUMKHVieKfQWHUI<B4E0@DeGEeEKH61NFeE>CE1EEeIHFUaOHV1JF5aNF5ELHfIZ
KVm/JFIWJfi]JVUWIVYaM75]Jfe_L79bLG1bMgUgMg^1Ph1mO7eoPXN:SYFJVijS
Z:f`[ZbZZZVXZJZ^/kJe]KBa[jf/Zjb_];Zj^KRh]kBe]kRf]KJg][Jj`<C3`l6l
]Zn[[[6`[Jb]ZjR//K>e]K6^ZJJUYjf_[Jjb][Fa[:NTYJBOVIBATiNLX:2KVIVF
THnAShZ9SH^5Q8N7QhZ=S8V8RHR4OgekMW1`M7UkOWaeLFmZH5YKG5UFEeULHFIW
I65OH65ME4m@E5YOHfMYIV5NFeYKGEiHCDU=E5QOJ6ebMWYhMGAhNWE`L6iZJFe_
KVi`L6eZJg1bLW5`KVibN7IbM7UiMG5_KVibMGIeMWUmOWYhMgMgN7IbL75cMGIh
NgalNGMfMWEeMWUlOG]jO7anPHF6PX22Q8>1PhN7QXV=SHfAUYNFVinJUIVJTHfC
W9jNXJBSX:2PWIRFUiB=R8N:TI^PX9nTZ:RVYJBPWYfKVYZIV9JEU9>BTi>=RHZ<
RhV8R8^>TI:CUYZIU96ATiBBShn<RXV9S9>IVIFBS8J7Rhn@TYFGUiJDUIJHUY:?
S8Z;RhV6QXfEVIRGUiBBTiJFUYBAS8R8S9:GVifNWIVGUYJGUYFDU9:>S92EVIfO
WIZGT8N1OgaiMgEdMgf5RXV6Ph>3P7]iNWYiNW]lOWmmMW9aJfMXK6a/KgEjO7Qd
LG1aKf]XIFARHV9SIFQZJV]YIF9NFUYJFEMDDUAGG65SHV5QGeUABTI5BDi?CU5G
GV5QGEQFEUABD4m?D51@DUEJH69QGeYHEeMEEEQMHVIYK75cLW1bMGUkNGEbLW=e
NWelNW]lOX>9T9:@S8Z;SHnCUYJEU9:>SHf<SHj@TI6BU9VLViNFVIbLW9bLWInP
XjFUY:6MW9fMW9RETHf;SiFFUiZKV9>ATiBDTHj=Shj>TI6<RH^=SXj>Si6AT8n?
TI>DT8Z6Qh^@TY2>SXj@TI:BTI2?SHf@U9JFUIFDU9BEUI6>RhV9RX^=S8IoO7j1
R8b9Q8:7SiFGUY>CU9:@S8J2PXF8S96GVYRBSHZ7QhN5PgmnPHN?UYNDT8^9RHV:
RHR5QX^@UIJFUiNGV9RFTY2>SHR6QXV=SXb6PX1nP8:2PH1mO7]kNWUfLg=dMGMf
MGAaKF]ZIfATIVIUIVY^LWAbKfe/KG1dMW=^Jf]^LGAdLg5^K6YXJ6QWJ6]_LWIk
PXJ6PG]hMgIfM75^KVi`M7AcLgIiNgUeLW5_KFiaMGQkOGioPH>4PWefLFm_LG=d
MGIgMgIdLg9`KVm_KVi_Kg5eNGamNWQiNWQfMgb2QHB1Oh23QhR6PWilNg]kNWYl
P8>6QhV>UIVDRXJ2OH6:SHjBUYNGUibQXZ:QWIRCS8F4QhfEW9jLVY^NWj:UXinK
UXj:SYFLX::QWIRDTY:DUiRGUYJCT92DVI^KVIRFU9FFUIBFVYRCShf?T92CUIFA
SXf=SXn>RhN6QH>0P8B9Rh^;QWmmP8B4PH1mNWMjOh20PH5nNWUjNWanPH>2PhB7
RX^9R8R:Rh^:R8J6Ri2DU9:=QWifLG9gOXJ:Rh^<SXj=SXf<RHJ5PgijPHF5QXV;
RHAoOgajOh>0Mfm]LW=bMWYkO7mmNWAVHFMYK6mfO7eiN7YgMWE_JfQSHfQ[KWAh
NgUgNGUgM6mZIVAVJVi_MGIbLg9^Kg1cL6MOH6=QH5eMH6=XKF]SGf5TIFITHfQ/
KfiYIfASHEiKGF9RIFQYJFUVHf9SHfETH65WKgIiNG]jMgEeMGAcLG5cMWf4RH^;
S8Z9RXF1P823RHnCUYRGV9NHVYZFUI:?T9RQYZ^[ZZJLUiRKWJ2OWIjNWInRWifO
WYfJUiRJVY^RXj6QX:2PWIbIUIBBTY>>SYJKVYfRW9>=S9BFTY6BT8fAVZ2TXIbP
VY6HWjFYZZbVX9bPXYZIVIZQY:JXZ::V[Jb/ZjFNVi6>TY:FUiVESXf=TXnCX:j^
YZNUWIBBT8V4Qh^5OGb3QhJ:RXV8QHN:QX1lN79^KW9eMWMfMGEbL6iYHUiMHVY`
MGMaK6e`LgAdJeeBBDQAG6=RHfIZKW1bL6]ZIf=SHfMXJF]]KW1`KVe]IEiMHVEV
J6MTHF9RGUeSJVMVIV]_LG]iLFQUIV=WKVm`MWIiQHb?Rh9iLf]VJ6UXIF9QHemS
L7EaLG=gNWMdMh9nPi>?R85eIUeJFEaXLW1dOH22PhV<R8N6Og9XJVY/MX><TI>B
UHn:S8R2NgAdNGf1Qh>1RHZ:S9FAQHZ:RHf@UiNBSH^=TiRHUI:ASXjATY:>Shf6
Q8J;TYJGTi:DVIfKUI2?Si:DTXf6RIBPZk2a[::JTXj>T9FMXJ>SYJjd][Fc[ZNV
Y:>VYj^_/K>i]jfTX9bNXYfOY:BXZ:^`[JRTXYfHU9JLWijOYk2b/JZQUXf3NGan
PXb>T968OgYhNG5ZKgAfNWmnMWEhNWaeL6]SIVa`LF]YJf9RJg=iK6AUH5QQLG^1
OXF7P75RGU=6AClk?DMQM8J>QGaZF5UEAchj>3@gBUYVJ6MXGe18C4i5>Sa1@d]F
HfMPG5aNGeePETU3@dYCH6Y]J61NIV]/JFQUGf1YL79aLG5fNh62OG]kNgYgMW5[
KG9kR9>FTXb9RHZ=SHb<Rhb<T96AUYZLUi>HV8n:S96=SiZKVY^MYJZYZZFMWIbH
VYfRYZjg]KFe/:^/[jj/[ZVPXInKZ;JbZZ^g^;Jn`/?6d=W7^knYThnEUXN:X[O7
dMKC`ZbSSg=[JFYXJ7Z4S9j[[jJHQW=XFTY0A4iCHGN6RH^AT8A[Fde0?TQHHf]g
OX>CY:^VUhIgKVmfOhVCXJ^c_L:m[inCR820Q8ZBVjF_]KNbZY^=QX1mNgf2QX^?
U9VKUY6?R81jM6aVIficMgYiN7IdN7QdL6mcL7=kNWUkOgaeMgj3P7]mOgYiOGih
MW^1PHBF[L_Tek>IPVmUIVQ@?4QTRjfj^::6KE8i:R<N3@043ahjDe]FBc/V4`00
0000118M:Sa?Ff5FACH_<3@kA4U?EUYXOIBY/k2YXIjPXZ:SYZZ/[;2e_/[AdLo9
`K^cZj:PVI2=SY6JXjJUWI69PWenOWYcL6]VJgEoQhN1Mfi[KFi]KFe]KWAkPhV=
TiRMXIjNXjFVYjV_[k6j`/O2`L>k^]?eoooojM;5^;6SQee4I9k;i^gOaZbCMeU6
>B`J1`04841@E5aC=1@<418J8QdB2PlWCgN<RGITGVIiR8jATI6GWZc4fn[aln_R
gmgJf=2o[j:S/L34a<C1^:^VYYn<Mf1=ATYFI6YSGEeLG65UHUeECda7CEm[KgAg
O8JCX:JVXj2HTI>FV9fOX:R_];_1a/G1_/2j/;:b/;S9enSoooooomZcViBANeTk
?FJG/kVYTgUM@BL@0000000000LW?dDe8a/L7A/K7QhK61/^CG:@VIBAVZVc];:[
WYNEUIbY_=CPhnOTgmK8^ZJDR81lMFiaMgA/GTm4>cH`8QLI7bD]=Ce3A4]FEE=P
LGUkPH^ATiROWYbPXZ6MVIZLVYJETi:DWJ2MW9nX/JbSWjBUW8f;R8FI/lkcnnGE
^YYnIEeK?RHT<U9cQ8N4M5e7<QdC6QX;0P823RM4HfUIDTi8BeMXLFaVG5IQMhbP
[[Bka/c4_lW=_k6^YYB8Rj6g_<77a;R/XYB2LF=HDUMMHFA/NWmiLgEjOGf2R8Z=
UIjUZk:i`L_DfmgPh^7Mf]gNdL6i]KFaZ:N`^;>c^[Re^;Jf][:a[:FXYYN@VinF
UIjehoooooo[`Ib7R7QK@BThJ8VT^[^^TVi><24S91l;000053EDHF=LF5UJGfj0
Pg9LD4mPOiFMUY>LWj2VY9R?THafH5MGEeUQHEePIFMREdm:@S`c9Q`I7R8T:c@n
AT]@FVQdN7IeLgAiOh65RY:GVY^MX::SXiN7OWE/H5EBE5UOGUiSK7=dNGajLfm/
JVa_MGYiN7b2SiFM[lGPn_ooj]JlX8f2ME/b8C53G7F1Qh1eIeA2<BLT6PX0000@
:DIQL7jCVI^S[;BbYj6JUIb]`Lc?e^;Yk_7`iMC:aKVOQWmnMG1hP8B6QGm_HEYE
CdY;Ce9HHFM_Oi6LWj:]_<S<cLo;a/C6a/?2al[:a/C3_[RaYY^ESHN1MW5bLWIn
PX^FUiFFUiB?RXN2P8>5RXj:QXjCX/3Ch?koooooilRSShI]AbDT=TiTKg9`LFMF
@R/H4A<8000000<O?U1MNI6FV:>_/kB_Y9R@TIZZ^Knl^[bl]ZjXWI:;PW1MD4U4
@3dm?CXi>c/i>3/l=Bh`>dQBGFinSIZPY:^a]KJc[jZVXj:RXIfJVYVET8j<QWU_
KV]SFUUFCE9JD4mMJ6ibNHF2O8F8OWamOGaeMWUiP8>0Q92@TJW9h_oooooohl>P
PFi>7`@56SeBK8:5SX=RAb/G82PM3`496c5ENI2Q]/C8`lWHgMkG`k2TVZ:a/k:e
^KffY9jOTXV4MF5>@S`e;B/^=Sm6CeEMJg9bMGUmQ8Z?V::]/kRna<gFfM_FclW1
]JVPVYNETHb6Ogb0P7UfMgIbM7IdN7j0PXZAUIJFX:^][:VUXj2DRH^<R8^GUiRS
XInWY9jbbmciooool=:fUW1C>Q0000<D;TQSNXEcDcla8A`T8QL@7BhgD7RAXk_4
`lS3aM;?a[b/V8n;RI:GU92DSGabKFaVETXl;B@P6Q/S9bdg@4MCH6aiPGn2QH^A
T92FVi^MWYbNXjBTXYV>Q7]hLVQOF5QFE59BDe9?EEUEG6IUJFmcNh:8S8R8SI:G
VYZIU9>AQHB6Q8B<SH>0PH:3PY6Z/k[7e??onN;8[9IoKeXf5`dS>Ce6D5e^LfA=
?3PjA4@e<RlhCf5mU:2eb<c9b]3Kh=W;`KJ_ZJ:RYZJVX9J=P821O7QbI5YIDTI4
B51IGfEePXfKYjV[/[>`/J^^^;Ri^;2//[Fg^;Je/ZfRThQlLg1/IV9WM7YoQXb?
TI>EUI:AUifKUibSY9nOY:FQWZ:PVifKU8^7QHB5R8R9RXJ8SYj[/<SWlOoon^S9
/9YmJeQ1<b4J820b>SY:BClg<c@g@4I1=RPV;cU?KHBHY:jg];W1alk5]::ESX>1
RHj>PgE[IVAUGeaJCChd<2PU;CDnATmGHW5mR8Z:S92EVI^PYJJTYZJNU9BJUXj6
QH>0O7=UFUQGD4U<DEEJHVi_JgJ2PWakP8N<QHFCVIFBTHf7OgUhMW=cLVaZJF9Z
OHN>SXV<RhfGWjZc_lKDm_okjM>jVgQYG48]7R8Y:2/]>U1GDDPh:C5;E5=FDU1I
I761SjS8g=_Eg>WfnO3Se<BfZZ2HSi6ET8^=RGaeMFeUFE9?B44g>Ci6DEmbPXnM
Yj^b_kje[jn^/l;<c/Rn_Kfe[:BLThn5NFeSHfQVH65TJ75kPXN>V9jOVIRIWYjI
VY^PX9NFU8b5PWinOG9aNWegMX6<Shj=TXYfMGf5SIbif>;XkoGii<JYQG9N@C@P
5B<d=2/g>RdoBSdc9b/k?TA2@U5LJGF3T9nhb]7Ig=gLdm7=_K6WWiF7OgaoOG9^
JV9GAcda:2//9RDV:B``@eIVN8B@V9ZIWZZ^YZ>YZjbZXjBZZjBGSXV1N79YGeUB
CTQ5@ci4DeiTKGJ5TY6@UIZIU96BTiBBT92<PWI/JVmaL75dMFYTL7alOhR9QGf0
R8:CZZnh/Z>]/lObo_g]b<W</9f2J4lT7Q`0000E<T9BBD5CDeigLVMKEe]GJX::
V;7:dm3Gh>Wbk>KQd/>aXi^7OGmlLUeCDe=?B4];AdM7A3T`=DAEJGN1SY^^`<S6
a=CMem36`/K:b<6l^KN/Vhj6OGMcKVQKD4]8BTeAGW>3QhfJY:V/Z:>UZZRXZJVR
UiBDSH>1N79hMW9eNX:<TiFFUiVGV9^CTZ6PVj>Z][Vba^;Si_oojl^kZY1/Ee<h
8BHZ:2@N83<h;2/]8aDL<T97D65WLX:7SY>K[<39c=?CbL?5`K6OVIF:MemGGeeD
E5M?@CT_8QhW;C4i?TE8DFb0R8fHYZj`[:fc][Jh]jn][J^WX9^QXiN:P79SF4a2
>cDa;bTZ=d=AHG61QXB8UYfJUI:@S8AkNh63PGajP8EkKVe/IEeGGVa_MhZJXjNU
[ZjQYIn2NI>JS9N_]kW8i_?Oc/N[SVm8;B8N7bLl;aTU;Rd]=d0a8c=8DEQSKW5h
PXJCWJK0gNg`j^?Mem39^ZRNU89]Ge]PIEmECTi>DUE@DE9AEEEAEV=`Q9VX]L;D
gN3Sh^;Tin7Dbl_<alBm[ZRZXY>8OGE/GE16@Cdi>T58C5M]R9n/];k4aLS;c]3:
^ZRKU8n>THn=R7edLg=cMWf4PW]lS9NEVIVEUiZPWhn8Uin>O8JV^<7Jk__gflNf
TGQ/DC/X5R8d=STi=cXn?SL/8R@nEVEdMGImPHR>UJ2[^/W:c<[4_[ZdZiZ:OFeM
DU9GFeM8>cLh=bhV:SE2BDU8CUeZL7R4Sij//[Rm`/K3_;B]YYnGTi6<QhV5OgYb
I5QACT0_;C0g?Ci4Cf5[LhJJYJfd]kg2`KRa[J6@QGmhKVU[L7=ZH5ePHU]BBdYG
IFY/M7f4PXFBUiRDT96?T9NT[k_<ho_omn[Kb[ZSQ5`h91h[?3/^:cM5A4=0=3@n
B5=NIW=oSYNIWZ>Z^l[Bem_LfmGAd<RhX8UnM6URFE=EFEIDE559@d0k?D95CUYW
LWj@Yk:e`Lc>d]KDcl[3_KZi]k2YYjJKRX>0O7E[If=NEU1BFV1PIgAmPhbJZKW0
`LO@dL>i_L:mZYB6P7egKfITIFUcN7A`JfU^LG9kR96FVI^Y^k^e/ZNSXYjQW9^Z
Y:K?j>kfkMc8YWmJ?b/C00073`/?7bTd?chj=SI1DF1/M7V3TYZFTIJU];fj^kjo
_KBWVXj3OG=QD3`_;BTX;2XW:S0g>Cdn?TA>EUmUKWV2SJ2`/K:e^;k1a/:cYIjK
UXf1MG1_JfQWHUeKEDU9D4a4?dA@G6EWKG^<X[6e[jVZ[:VNUhn8RhYnL6UZKFIJ
EEaVJ6Q^MGj0OX:=U96>UjZaZJJ][In<QHJ1P8fAU:Zf^mOkooobc;:OPUi3=C4/
>EiWAS]8EFekL5M6Bf9fNWb7VJV_ZIjEVK7FkNWGb/>n]JZTWIJARGQYHV9]MW=]
IfE[K6QRHFM`L6ebNX:4QI2P/Ko:dmSEdmGDdL^m/:ZRTH5hLgAaLGN0PWAWIg5e
KFATJW=kO8BBYKS6d=[Jdlo=`kBUWIN9O7IbK6QXIV9OHVQVIfeaL6ifOWeoR9:L
XJ:VXi^JUhj3PhUnL7R:TijfcNK/h]:aTWiUB2P>00059SLS6c=7DTm0<B<Y?51J
GVE/NH20PhB5TJNh^KZn_[NWVXaoLVEKC3dj>STg>DA=ACTh=2h`=Ce4ATYCE5ad
PXZIZ:f]]/77a/2m^[6PS7]cKV9HEUMNI5mKGUiNH69SJFYQGfIYKWV6S96HXZ^_
/[6/ZJFQVXb1NgMbJVARH65VKWQjO8:=W:>SXYnRYj^]];^j]kF`YIF:RHEnOHBB
WZR]^<KHmOoom=>cVG9EAc@/>55PBS4f>d=MLW5QDU5LIg9nQHnGVY^DR8bXc^Oa
kn?Dbl:fYYF:R89cGDa9DV1UIfaYI6=RHfQ/LW5`NX>4R92GXK2m`;jk_l_Cc/Jo
/jfWWI26O71SEe=CDeILIFaaM7EhN7UlO824Q864TYjVZjb^];Nf/J^UUhIjKf=H
DE1FFeiWM7^1QhbCU8b8Q862Ri6=RI2PYJ2LTXEoNG9dKFE[M8JGX[S@h^SD^J>8
LEPf5`007STe928`?4]BBS`X9CE6DEi_MWf6OgA_M8NN/[Ne/Zn[[ZnUUhb5OV]=
<20Y?DM7A4I8BDU9BU=MI6ehOgefN8ZPZK:n`/2j^/;=dm??a;BTUHIhKFMPEDa:
BDaEHfmhNGEbL6mbLg1^MGn7SiJP[KBc/;6`YIV?RHN6QgmcMgn0PXB5QXbAU9JD
UI^QZ:VTXjNVWY^LX9nER862QX61RH22UIRKY[?5f>goonK8^Yj0HTDi=D9@@b`W
<3Q;FeeE@S]8EfMjRiNJUXf;RXRB[<WIf];4^;Bb[ZFMUHQeHeUDFf=RHfESHf5H
DEIRJfi]Lg]nOH:@WJF//k:^[k6c]KZm]j^OTXQoMVaVGeMDEe]NHVYdNGb0P8:4
QXV>Uj2XZjjf_L2m]ZZQWifLUi6=QhJ4NW9[HUYJH6adMGf9TY6?T9:ETHJ3S8n<
T9fY/:ZGSHZ3Lf5VJV=bPhfU_<WBgN_Q]iAeD3HM4R4d?30J5bP`<3Te:24K7RTg
BE][N8>4OGIkSZ6gbLk:_kVf[Yn?R8R6NfE?@3i3B4Q;BTI4?Cm2@e1QJ6ASJFQN
GFj0QHRBW:2QY:bd^;:QSX5jM6QJEEUIDTU3ADaAEEQMHFEYLW^1Ph>9U9bMWJ2S
YZb`/k:[X9>5OWenOGMfM6m]KgV3RHb@U9FEV:B`/Jf^/kFe][Fe[::NVHn3O7ab
HfV0Tj2MXKoCgN;Rknk?/ib2Id]0Ae1HEd]0@e=NH5iBACi5F6]kPhVEW9VCTi^Z
_<oMi>SSf]C=aKNVV8UlKE]@C51KIF]WGUQFF5iUL7b5PWIgRYbU[[O1blg?dm?C
f=cKfM71[j2HU8aoMgA`K6Y[KF][Lh29QX9lN7EcNXF>Uj2SXjJ^/Zn]Zj:@PWaj
NW]fKVAMGVE/K71hNgEeP8R6Q8J3OhB=ShnDTXb<TH]hK6ULDUMOHFEiS8=iSj>d
`<;AdkZKOFQOETLo@3T]5@<>82T[9R0F2PLC:TEJJ7QnMFeZLGjBY[Fo`[Z^XiVB
SHR0M6UJBT52Be1>CTi9@CD^<cm@HFY/JFI^NGanR92BTYVQXZ6RYJN/[jVKRWme
KVaZIfESI6MYJfebOHR=SXb>TiVRZ:BPXJ>W/;Fe/ZVNV9JBRhN4NW9dMWEdNH61
PXR9QXB8SI:FVJ2WZj^[ZZ^c][2`/JbPU92AUJ2RWifSZjJ^_Ko?h^gel^;3YXQZ
I5Q;EUE3=2llCUIOJFULDE9DG7::X:jd/JBLXKC:e]SFdL_0[j:FRXF3OgAPDT]9
C4i<CDe9AClk?TQGIG9mQ8V?UYbRZK>oa/O7a;nk_<;7aKjaX9>9PGekLfIKDTY5
ADI6B4U:DEeYM7]oQXjDUYJETi>FThf7Ph>5R8R5PGYbKV]UHV=THfE[KFi`LG=k
PX>2QH5gLWEjNgUlOWY_Hf=`Lg9gLfi/KG=mRiFP]m7IdKnWTG5G@C<kA4Po91TS
<c`n?cH_;2`e?dYNKgIhLVe[J6f0V;2l_[R]ZJRRVi>>SHQmLfYWJ6QZIUmHCCle
>TUNM824R8N:Si:GWZBRWY^JWZZga<_8_K6TViF@Qg]bL79bKfiaNHJ?T8nAU9RP
YZ^b]K:a/kNj^[^l^;2XWiB:QhR6PhJ:QWmnPH61Q8R?UiZIVjB/[k6g]kNg/kNk
/jNQXInGT92@T9:CTiBGViZEU9ZU/Kk=gMS2ZHQ[Dd18GUdl7b8Y;3DnB4U2AD]@
EVV1T:2[Z9fCTifZ]l?8aKbf^[N]YJ2OUhA`G4a5B4mBDDa5?SPd>dUHIg9hN7b9
UZ:]/kJd/ZjXYjfg`<:n]ZbOSh1hM75TDd@j>Si0@D53Be5GGVQ^L7j;TIZIShV5
QHV<Shn<QWmkNWYjNG5YI61OGeiMFEUQJVmbLWAgLfmbNh5nNGUkOH5oN7=eLVea
L6ANH6=^Oh^@UIZLY;K:e]S@`:R<MFAIFfMP>QdI50l=2a0F72Lf?TILMXbIVi>6
Ngf>X:bc^;Vc/;6a/jjXXY=oKfYWHUaDCDa8ADI4ATiPM7f1PhJ:RHbGX:6NWZ6P
Xj^e`L[<b;fd[JVRUiFDRWY^JfUXK75aLG=iPXbDVj6UY9nOYZfa/[6b][:XY:FW
Y9ZCS8V6Ph=mKfQ`O7ehOHbHWjJd_KNb];Rf/K2[ZZZTVYFDSH^:R8J3QHF2PHNF
XJ2Y_lS8e^gdi/V/U7Q/LgIaGCTZ<c/k?dA1@4I<CUI`RYNS[Z^FQX^NYjBT/LC:
`[6TYK2maKbNLDDa>U=RHEaHCCPdB555A51FG5mSI5mHEf=YHEi/OHN@VZ2X/JfI
SI>HR6M;?cX]8RTk@dA8BdDkAV9nSH]nOXnGS7IeQYbX[k>]X9B@VJRVU7i]IfYe
O7ajLgB5TY6=TifMVYbPY:bj`;jo^j^ISHF4RI2<OgQdLW9gR9BGUI2@RXZI/LK>
c/ViXhYdIF5PFD@L000930DA5b0X92P]@EibNWUaK6UPIGF5THjCTi:MXZ2HS8F3
NV99>c]6CD]6A40oA4QAEeEMI6=LG6j6Uj6TY:^`/jjWZk2c[jNTXI^BQhB6Q7ee
K6EPFUAEEeQPJW5lRI2FWjZa][o5blk9b]3Ff]_Jf=KBd<g5_kbbZ[2k_kjl]k>b
];Vh[Jk0b/:f]l;6aL?1^kJc[jb/]KF[YZRSVYBFWYb@RI2NYZ_3f=[Gd/RgXI1n
K6IZJ4/V6adI4Q@X?4=9CTmIL8R:QXF2NFmZKWZ5T9^SWY6?SHF0Oh:4O7E/J6AF
CSdU5a@D4`l<5RPg?455ADaGGfM^LgE`M7^1RHF6TIjRV8f6OGYfKF]VH5]BC4]<
AdE7ATI6BeEPIF]bMGQlPhR5RHf8QHJ;SX^6Q89mNgUaIf9TKFaXLW]iNgj4TiR;
P8JEW9ZJW9jJUJ2a[inBSH^8PgIbLVUZLgMmPXN?X;K4b=3Jf<^eXiR=QWIK?BHX
9b4Y<T5AFVA/Kg9eNgaiM6IMGf9ZMgf7TY^Y]Kbn`L6m]JB;MfiUFD/m>3U0BE=H
Ff1WKWJ1QXN2PXZBV9N@T9BJWJ2[][B/ZkBi]Zj[ZjJLShF5QhV:QhF9TYRJW:2O
WjJ`];Ni_L;6b/kEeLo=cLW3`;b^XZ2QWiFBV9ZDSXb;RHbKYj6ETiZMWYbKXjBO
XZRZY9bMWYjJShAmO7n3QXfASHbHZkRi_/gHgn[koo?E`;>LS81/DbdA620L934f
?4MCFe]KHFedMW]mLf]aOh^FYZfc]kg4`kff/ZZHQ7EWF4a4@Cdl?Sdl?dUJIVUY
IFETHfETHFE`MWEhP8^FW9VFTHb@UYB;QH5mNgAYIFESHV5KDTe?CdiBEEIBC4a@
D5=GGVMVH5iQI6ARGUYFDTi<BDQ:BdaAEEEBD4a9Bd]>EEQHF5A@EEaMGEUHFe]M
HfIREe=IFTm3@dI2ATQ;E5a[M7UlOG]iPiN_^k>TWYR3LVMIAc8]<2T`@E1MGf=Z
JF=RJ6e^Kg1^JfmnSIRW/l37`lOEhNKKb[V/YYjCQWE]LWf:SHR6S9BDTHn;R81l
PH>7Tj:^][o@h>OYjo7fm?;[gmWHfMC=b<:m]:f^[J^^/:na];:`/:f//[Vi_<;7
c=7HfmG>dmkOfM;?b/;1`L6o^;>`/;2[XiZHW9jPXIbCSY>JW9ZIVibRZJFOX:R^
YYfNWIF:Q85mNVeVKGN0OWn4QY2S]/cKdKV/Y95lK5<_61493ADN<3i5D5MABdmG
GUaGDTa;EVIaN82AWZ2V[K2/XIJ=PgU]FdPl=SPj?dI9CE=JGEMEE51=BD4k@4Y@
F6EcNgj2QhZ>UIRIUHIhMGIiO7ioPXAoMgIjN7=bKFQUGEA<A411B4e=DEADFF9Y
LGQfL6Y[L7EfKfQ/LFiXIVY^JfYXIf=GCdi>BD4o?d12@T52ADQ>FF5TJFm[IVYZ
IF1PH5]CDEQGDU9GGUmNJGEkSZ>/_<RoZinGQgEMACdn>38f@UU/LWR:ShB4QhV@
SX9cI61YO8R<UjRha/oDg>?TgMG;`;BQShfAV9nPV9JOZ:f^Z9nJU8V0Mf]RIG5m
QHbFY[K2cmSNg=K>a;Vi_K^f^;o0^kJf^;Nd/:ZPUHb7R8jCUI2;QXRCWZVd_<C9
aKnm_[^g^Kno^[Jg_lK9a<2n^K2WXifBS8b>S8R5Qi:JVYNIXJZb]kBXWIFGV8j6
Q8B2Oh22PhJ9RhEjNX:1NWMhPI^id^;K_:VUSg1?=B`P3`P?7SI?FUQIFE=CEEYX
KFQQHfAPI6]cPiFQ[;:a];NaX8]gI5I9?Sa1CEYRIFETIVaeMg=]HeA7?3<a=Se4
CUYRJGAoPX>2O7IbKfiaLgEgO8>5PGanQHZ:RX^9PWQ`KFUOEUAFE5AKIWF1Qh^;
Qh9mO7inOGb0RI2@S8Z9R8N7QXF4QXJ5Ph>2O7I_KG1eNW]kN7IlQ8=nMgAjP7en
O7QgNgahMganO7AaMG1YJV]]KVmjO7j6SYBL[;>ZVhYkKf5DC4U<D59DFF5THf=P
FeQCCTmGGf5MEEAFGVQaOHREXjV[ZZ>HRhR:R89mOWn0PXR=TYJFTXV5Q8>1OWek
Ng]iNGQkP8N;R8N=U9FATI:ATI6ASX^9RY6HVIZNXJ:OWYjLVibOWIVDRhF1OGQc
K6U]LGIgLg5`Kf]ZK6e`MGYoPhNAWJJXYZV[ZJ2GU8j8QXF5QHfGUiFDThj9RXn?
S8N5QhV4PH>6Ri6GVYVGUYZJVJZi_lS<a[R_YY^GSXAlLF]`MhBEXJ:FRhJ3R8^8
SIJKViZHUYROYJb^[k:_ZZJUZJbXY9V>Ri2JY:JUYJJVXYfFU9VLVYF=R8B1OWal
OWemOGYlP8N<SHnGX:2NWZ2VZ:NTX9^HUYNKVI6:RH^4NgEgNGUgKVQUIfidNGA^
KVi`M7UmPHF8R8J4Q8B1NWMiMfeQG5aOI6ERG5MHGV9SI6Q/KW9cL6QOFeE@BdY?
DE=HH6EPG5mQGV5XJFQWJ6a_KFUZJfmcM75XI5mGDe5BEUICD51>CU1=Bde=Ce5?
E61YKVm_KFU]LgEhP8ZCU8n8Ph5lMW1]LWAdLVi/KG1cLW5cM7AbJV9RIfUZJfMT
IFU`MWMgNX24PG]hMWAdM7EhNgj2Qi2JWj>UYJBQX:6OW9ZKWZ2MW9nQXInLVY>=
RhZ8QXR:SY2FVibLVYbOW9ZKVIJJXJJYZZNPVYRLYJNRWYjKV9JDT8j?TiJCSi6E
UifUZjn^Z::KTi6CUYVHUHn;S8b:R8V9R8F1P8:5R8Z7OWMbLG=eMgYoQHV<RHB1
Q8R=SXQnN7MjOh1lNg]kOX>4PH65RX^:Q7ikN7MhMW5/K6mcN7n6R8EoO7QcLgIf
LVe/L7=aL7=lRY6BShZ9R8J3PhF3OGEcLG1cN7UgMG9`KVebNX1oOh20Ogn0PHB:
TYbPWYZDTHn>R85nOh:5R8R8RHZ=TI2>T8n8P7j1QhZ;RhnFWZFWXYZIWjBUXIjM
X:6PWIbNX::UYjZ][jf[ZJJTXZ6NVIFDTi>FVYnQW9J@S8V8R8J7RHZ<SXnCUYNF
UIBFV9RDTIJLWijLUi::Q8B4P7]kOGUaJFATI69QH5eKGfM^LWEkOgijO7inO7Yi
MgIdLgAdMgYjMg9^K6a^KfQOEE5BE5AEFEeRIVEOGEeMGemKEE=CDe9EF5UHE51>
CE5EFEYHFf5XJf]_MgioOWaiN7UmOGQaK6UYJ6ITHfI[K6i^JfMVJFidN7YkNgj0
PX:0O7MfNGYjNWUeLW=aKF]ZJV]]KFi_Kg1dNWmoNgQfMWQjOh>6Q85nO7imNgYi
NGMcLgQnPXJ8Q7eiMWIfM7IkOGf1RY:GVj2TXY^BS8^<Si6BShV4QX^@THj<Rhb:
R8J2PXB8S8f;RX^=TIJIVijQXYjIV9bOX:6QWYVDTI6CUY^NWIjTZ:RZZZZ/ZJBP
WY^LX:2LUYBDU96>TYRJV9FEVIfSZ:VXZJf`/[:b];Nj^;:^[:ZVX9bITHN2Ogem
OWinOgn1QXZ;S8b=SXnBShZ9Ri6FVj6UYZFUY:6LUXn7P7YgMGEfMgMfMg]kNWYk
NWA_KW5cM79^JVEVKW=aK6]aNWinOWeiM71`LG9_KFibMgMfN7anO7]hLVeZJVMT
H5aJEeEIGf5RIFQ]L79dMgMfN7MeLgEhN7UlOWakO823P7Q_IUiMH6=RGEeQI6EZ
M7f2PX5lMW=eMgQfN7b0Ph:5SYNJVIZIThb8QXB2OgamP861QX^AV9nQX9nOWifH
Ti2BU9>ASH^;SY:DTHZ6PgaiOXF8RHR7QXN:RXN1NgUjNG^0QHR:RHN5QHJ3OGA_
L7EjNW]nPX^EVYVDT92BUI:?Shj<RHB2Q8R;R8=mNGIiOX60OWaiMG9cMg]lNgQf
Mgb4RHb>S8Z9S96FUYB@SH^7PgafLFm`L6m_KfeXIfQ^LWAfNWahMWAdMgf3QhAo
P8F9SI2CTY:ASHV6PGekOh:2PH21PXB6QXB2Ph=nN7IhO7]eKfaYJFa]KWAkOgmk
M75eO8:8S8nDVZ6UZJb]ZZ:ITHb6PX60P8>8S8b7Q8J<TY>BSHJ1Oh64RY:JW9RC
UIfTYZJRWYfKUY29R8V:RhV6Qh^?Shn@UIfPWIZGU9:BTXj8P7]jNgn3RXb9Q7ii
NGanNWIcLW=cM7MmQ8R9QWehNWj1PX1nOX20OgajNgajM6eWH5iNGf9UJFa/Jf][
KgMkNWMbKVaZJVieNWQcKVUXIfU/K6]VHf5OGf1TIfUZJVYYJVicMg^0QHJ3PX1m
OGemOG]gLFi/Kg=eMG9bLg9aM7^1Q8F3PH20PGmkMgMfLg=dMWMhMgEcL6i_LW9b
LGAjP8J7QhN:SY2AT8j;QhB2PHB9RXEoNgUgN7UhMgEgNWQcLWImPhN8RXb<RXF2
P862Ogn0PXJ=UYbNWZ2QWIB>RhV8QhN<TYNJWIfMX:6SXJ2QY:Z_[jb^/[Bb[JVW
YZBQWIREUIRJW9bLX:BVZ:RXZ:VXXYfKWJ2QXJ6RXj>RXZ:RWIF=Q7aeLW=gNgem
OGelNWMdLG9eNWemO7]oQH^?SXb8Qh^@TY6ATYFFU9>EVIbJU92@Shb7QHB2Ogai
MG=aL71[HeiNGeeKFU]LFeaNH6=[LgMkPXZAU9FAS8Z=SH^3N7AeN7]lNWEdM7=b
Kfi]JfQUI6I/LWEdKfmaLFe/Kg=cLFi[Jfe^Kfm`LgEgN7IbKVibMWIcLG1`LGAh
OH62PH63QXV8QX9nNWI`KVm`L7ElP85oO7]oPhB7RXZ8Q7moQHfBTY2>S8Z9RhZ8
QXAoMg5`LgMiOXB7QXB4Q89nOGmnNgYhNWenPHF:SH^3NWEeMg]oPhN9RXjBUYZP
Xj>SY:R[[JbZZJNVYJ2JUiRHU8f5OgmnO7YiN7QgM79eN7UjOXJ:Rhb<SHjAUINE
Ti2;PgYdLW5aLW=eLfmaMgb1PhF7QhAoOX66S8n?S8R6QH>4QhV<SH^7QHF6QXN9
RXZ7PG]eM7QoPGmoOh64QXR7QHB2OgYfMGAdLg9aKfi`Lg=`Kg1_K6UYJfiaM7Aa
KVmbLW=fNgimO7f0PH>7RXb9Q81mNGAdMWQfLW5aLFi[Jg1eMWAcMWUmOgeiMGAf
N7QiNginOGakOGimOG]hNWn2Qhb=S8b>TY>@S8b>SXb;RXR6QHF6QhV7PWemPHJ9
SI:GViVFV9fPX::VZJVWXinNVYJDTY2<Q7ilOH24QhR:SHj?Si2AT8j9Q85oOh:9
SHf;RHV;S8f;Qh=oOGeoPH9oNWQhNWYfM7IjNW]lNgUjOGelOX>4PgefLW5dNh:8
R8B2PX:4RI2GVYVHVIfLVYZKW9VCS8J2P8:5Q8>1Og]dKfa/JFQXJ6ETJW9kPhR;
Si:EV9VGTi2=S8n@SHZ9S8nBTi>EUiJDTi6=RXV8QhV;S8f@TIBFUYFBSh^8QhN7
QhV9R8J2OWn4QhV7R8Z<T9:CTY2<RHJ2PH>5QXF4PWikNWanOWekN7IbK6aaOHVB
TY2@SXb<Shn;QH60Oh23RY6DTXj=S8N3P821PX>1O7IbLW=cLgIiNgUkP8V@Ti6@
TY>DUIJDT8b<SHb:Rhj?SXZ6PWmkNGMcKg1dN7b3RY2DUIB@RX9mOGimNGEcLG5c
LVi]K6]YIV=PGf1TJFe^Kfi]KgEkO7YdKVQQFeQHFUaNGf1NG5aPIFQVIVU[JVY^
MWaoOWakNGYnOgafLFe[J6ETI65NG5UCCdmBF5mSIFAQGUaLGV5UIVISGeaKH6U]
JVITI6IVIfQVIFEXJV]/L7IiNGUhMW9^KFmaLgMhMWAcLgEgMWAdM7AdLgMmPGmk
NgenOh1oNWEdN7b1QHR9RHZ;RHAoO7YiMWIhNW]kO825R8fATiJGUiJFVIjRYJJW
ZJfd^[fk^[Zk^KJaZjJUZ:RUXZ2QXInMWZ6RXZ:RYJNXZJZ][jj/Zj^ZZ:Z_];Ff
^;Ne/Jn][:b_/kBb/[6a[jf/[:^VXZ2NWj2QXJ2OWinNW9^HUYJHUiNIWjFXZJVY
ZJ^^/:fXXYjKVINGUI2<SHf;R8B3Ph5nO7anP8:7S9:EU9>CUIBBTiBCT8f<Rh^:
RXf<RHN2OgemO7inO7UiN7IeM7IkOWikNWb1R8j@SXZ6QXJ3OgenOGUdL6e_LWAd
LVm]JfMTHfIWIFASHEmNGf=VJFY/L71]JFESHf5OH6=UHf5RIV]]KVaZIfEVJFY/
L75`KFYWIF=PHF5PGUmSIVMUI6AVJ6UYJ6U]LgUmOgekOH21P7n0OgahLfm^KFe/
JVQXJVa/KFm_KF][KG9fN7YkO7alO7alNgQeM75aM7MgMGEgNWajN7MdL71cMGMi
O822Q8N9R8B2PH1oOGUfMWQjNW]lO7McLgIkOgmoOWYhNG]kO7enOWmoP862Q8R:
Rh^=Shn;RH^<RhR3OWenP8:2P822QHN7R8V;RXN5PhB6QXJ8Rhb<SHf9QH1mO7Yg
N7UhN7UkOX20PH>4Q8F:TiZJU8j:Rh^:QhN6PgikNW]oPh9nO7n3QXB2Q8V=T9>D
UIJHVYZJVYRDShV4PXB6QX=nO7eoP861PX>4QH=nO7]kNW]mPhN8R8R7QXB2P7in
Ogn0P863Q8J9RhjBUINETY2?SXf=Shn<RXZ;S8jBTi:AT8f9Ph66S8j:QXF6RHfB
UibNWYfJV9RHUY:=R8N9RhjBUYRHUI:?SHb>Shf<S8jATiBGVYbLW9^IUiFEUiZL
W9^IUYBDUINKWYbFTHn>Si6BT8Z8R8J3OX25RXf@TY:@TIBDT8b9QH1jMgMjOhB6
Q8B4QHJ5QXR7QH:1PXB7RHV7RXf?Sh^6P7emOG]hM79bLG5cN7f1QHN7R8^>SXf;
R8B3Q8J5OWQgMgEbLG5`KVi^KVi_L79aL7AiO7]iMgIgNGf1Q8=oOGeoP7moOWej
MgEeMGEdLg=bL6e/K6e`LgEgNWf0PH20PhJ7QhB0O7aoPH>3Q8B3Ph5nO7YjOH23
QHN7Q8B4PX1nOWejMW=`K6eaMWQfLVmZHUaLGF1TIVMYJVY]LGEiO7inP863QhZ9
QhN:RhR3OWQbKfe/JVY^LG1[IVIZKW9fMG9cN7j4QhN7RXnBTi6>S8V7Ph>3PGah
MGAeMgYoPGijNGYjNGQeKf][JVekTiMoKU]FFemPGVMaOXB2OGYjO82;Ti2=RX^?
TYBBPG5bMgAdOXR=QWQXFeYTJFijQH^7O71[L7QjNH>CUX^5RHj>UIjOVhb;UY66
NWQmQh^4MFUeMW1kPWeiN71^K7>@TViMLhnGSgj1T9f]ZifARhZEY:>MTh=bKgIX
GEmLJH6AU9B2IEUGGW1hNGEjPHNEWInJTI:MY9nGSHRHZ::9N8>O];J_/k:UW:>_
[:>>Q92NXZ6LUYjXYZ2@PXB2RIZFQHRQYIFCUYFDSi2F[;R_Yj:XY92<XJZMS9FY
Yj6XZ9fPZJFLUH^BXZV[Y9RAVZ^UU9BPYj>XZ9n>RIRHT92GUGmbPj6XVi60QYVE
Qh^HYZ^FSXbDY:>GR7ajO7YfNGf5QhR9LVEOGG>7OWEaKGMlMfUWPYjLQ7]mPXRF
XiInKg^<Rh=lKVj2ShIlLgEnMfecNWIcOXMmJ6YgMfmTHFANF5eZMgM`IfYkNVe^
L7EfN8J5NGanNganQHN1PXAdI6]iMFaQHfEFCUEJEeaYLViXKg5RIW=iLVMWLGaa
J6UWKWmjL6]QKGekNgUZHVY_If5HDUYWH5MNHF5[MFYLEDe<EV9[K6aYLGj5OVYH
EV5YMX><QgIYIFASJF]XL7UgKV]jOG^9RH28UjFQTiBLXJ:DMf5QMhZ6MVMPJ7Ih
M7MjMGEnPG]eNh:9RHR:PgQcM7V1Q8Z9PWj4RhEgK6inRHf;P7n?VYNJXjBDRiRC
NgZ7U9N;PWikPX=dMi2LShfDUiFGVifLV9nibLBg]kbh];6b]JnJSIZZZI=mOi:E
OV]_Q9B?Pgb4RXR?UYZAS9RTZJJNV9nOWIF6RY6KWi:6T:FQTXb=SY2BSh=_Jg]k
OhB2MVUXJW9eLGF2Q7M_JF]`K6U]Mh9oLVQ/OY6@O7IoR85`KWV1OWUlOWY`IF=P
HFilPH5jO8=mLg9hN7^0PH:1SI^LT8VAU8UjN7edJ6adKV5PHfI_MGA/JFaTFEa^
Mg=`NX5mOX24RhR4Qhn?Og1bR:FVRFeZOi:8OHBAVYbJVIJBVjNYXI>AWZZZ[;:^
Zk>dZjBWZJZ//kVe[ZJOWjVf[j2N[L;8`KZe^/:o/:BRY:NUY::PX9nKWZBSViB@
Si>DTIRQY9jESHfHWYR=RHZ>Vj>MUYJIV9RIVi^GUI:DThMmOhR7OgQeKfmfOX=o
MfmVHf1IGFmjMfeWIFETHV9UJFUVHeiLG5eKDTa9ATM;BCm0CEYRI5e;@TaMIF5P
IG9dIE97AD8o@dQ8@3dnADa@E5AAD59GDd]6C5MJDdQ3ATe?BD50A4E5AdU>EEQ<
?cXj?DQJI65GDDm=C51MIEmABD]>DeYPJVmZGEADG6E_MganNWIhPXfEV9ZKUH^7
R8^=T9VOWYbRZZb]ZZJVZ:JPWZ2U[KJn`l>o^kZj_lG:blc<b;nj`<_Dc/2ja=7C
b/;4c=;GfMG>bLkKhMcBc]7BclRo]Jna/k6]ZZRUX9fNVYBCUIJFW:R_/:nYWXj5
QHV8QXV8QXJ;RGijMgMiNg9ODE9QK6MPF59DFV5VHUYLI6]XGEMGF5mZK6IPH61K
EeQOIfU/L7AaIVM_N8:6Q7ihM7EoSiZGTY:?RhV9Rhb>T8n:Pgn2Q8:4RXj=R8F5
QHJ=UIJ@SHnATI6ATiRLWIVDTYFGU9>DUI:>SHn?Si2@S85hM7=fNG]nPXB6RXZ8
QX:4QhR7QXN6PhB5Ph5oNg]lNGMiOX:5QXF4Q8=oNgMeM7AdLgAfMG9]K6a[If5M
F5EFFEYLHVQ/L7IhNGYhNGYdK6U/KVi]KW5_JF9MFE]OH5aCCDe?DU=@C4e?CUAO
J6mbLW1]J6MZK6e/J6=NFf1YKVaWIFEWK6i]JVY]LWUlNg]lNg]jMgb6RX^?S85i
MWEcLgUiLfm[JW1kQH^>SHZ7RHb>TIBDTiBEW:6RXInLWjJ/[k6a/k>^ZjFTZJja
ZjBMW9nQXJ:W[K6_ZZVWZk6g^ko0^[6ZYjV`];>a/[6]ZJbc];:/Yj>OViJGV9N>
PgUdMgUkP8B7R8R6R8f>RX=mN7MhOXN>UIZJV9RMXZBX[Jn/ZZZZYZ6LVIZHUY>@
T9:@SXb:QX5nOWn0PhJ:SHnATHj;RHZ;RXbBTY2<R8J7R8F1NgEaLWMnPhR<SHf?
Shj>Si:CT8^8QhN4PX61Q8R;RXAmMG5cM7=_JVERHF9UIVQYIV=PGeaGEe]PGeQ?
AT91@457CeIIEU5?DUUKFEEAD4m=BTA2@dI<DeIGEE9DE5ADDU=EE4m<BDYBFfAY
JVibN7ekMgYiN7QfLF]ZKFeZJFMQGV1UJg1`LFi/Kfm`LG9iOh66RhnGWZ:UX9R@
QgmjMgIiOH>4Q8>1PXF4PWehM71aMWQeKV]]L7ElQ8Z>TiFGW:6RXI^DRhF5R8f@
T8n?Shj<R8N8Ri2FVYbMXZZ[YI^BSY2BUijV[Jn/Z:BRXInMVI:;QX>7SY>FThb4
P823Qh^AUIF@S8Z8QXN:SXn?Si6DUYNGVifLW9VETXn>TYJIUi2;R8F2P8>:T9JI
VYVHUI6;R8F1P8:3Q8R>TYNLWYbJVIRIV9NFUiRJW9bKVIZHTXj<S8V6QXR9RHR9
RX^>UIfOViJFUYBCU9ZSZ:ZZZJR//KBd[jbZYj>OVi^KV9RDRH>1PXJ<TiJEUYFA
SHZ=TY:<R8:0PXJ<SXb:RhV>THb<T9:DUIJIVi^LX:FXY9nGRhF0Ng]nOgehLfeY
IFEXK6m_JVITHfIXJFMSHV=VIfQ]LG5aKVYWIfQVIF9OG5UGE5=EFV1RHfASHV=W
JF]]L75]If9OH6=WJFUYJfYVHEiPHfIUHUiMH65TJ6U]KfeWGUYMIFmdLFi[JV]Z
JFUWIF5NGf9UIfESHV=WJfUVIFM]LW=aKVe_LgQlO7McL79eN7eoO7UeMGIhMW=c
MWQeLVm_LgQnPXN8QHB4QHJ4PGmlNWQgMWMjNgM_Jfe`M7UoPH:2PhB7R8R8Rhf=
S8f?TiNKWYjKVINEU9JGVIfOWYVBSXV5Ph:4QhZ;RXR8SiJJV9>=R8N5PhN=TIBJ
VI>=RH^AUYJBSXj@Shf<SY:DU96=RXV8QhR;SXf:R8R7RHV8QXF8R8N3OWb0Qh^;
RHR8Ri2BShf:R8F0OH24QXN6PGUgM71_L79fNgekNGQhN7UiNGQiOhJ;Si>GVibH
UYBFVijOX9^GUiZNX9nNWYfKW:6VZ:RTWYZJVibKWZ6RXjJY[:^YYjFSXZ:SY:N/
[[2d][Je/K2a];Ff];2][:f[ZZ^YYZ>RXZJXYJ:QXZFUXj6RYZNVY:BRWYfRYjJP
ViNCS8B0OgikNW]mNWMeLFm^KVYVIVY^L71aM7MiNWYiMgAdM7AeN7anOWahM75c
Lg5]JVMVIFEVI65QHfIVIfUXJ6Q/M7MdL6e/JVQVI6AUIfMVHemKF5IBCT]:BTM4
A4=5BTi=B4<n>ce0ADaADU1ADeEFEUQHEeECDU1=Bd]@EU]LFEQHF5UHE51=C4Y=
DE=DEEIGEUEDDU5CEEMHFeiRJ71dM7EfMgYlOX>7S92ASX^7Q81kNGUjNgYlOh62
PX>2PH>8SY:CUYRIVj2UZZ^YZ[2g_L31`;fh/k:b/[>d/Zn[YjBQX:6QWifLVYRI
WIjMX:JYZjb[Z:NY[:j_[JVUX9^IVIRFU9BCTiJGUiNGV9ZJUiJGV9NETY6DVInR
X9bJUiFCTHf:S8nBTi>CTY:ATI6ATiFFUiJFVIfOXJ>RX9fKVYRFUYJETi2=RXJ5
QHJ7QhN8R8V;S8b<RXV9R8N7QH>3PGejNWYgMWEcLW=fNgmoP8:3PX:3QHR;RhN0
NgamOWilNGIgNWamNgQdLG9fN7QhMgMhO7ilNGEbKfe[JV]_LWAcKf]TGeiOGf1T
IVIWJFibM7=aL79eN7YjNgioP8:3PG]hNWj0PH:3PhB5QXJ6RHjAT8n:QH>4QXR7
QH>1Ogj1Q8>3R8j@Shf;Rh^;RHJ3PX5nO7eoPXF6QhF2OWYfLFi/JfUWJFeaLg9b
M7IfMG5^KFa^L71_KVm`LG1]KFmbLg=bL6i]K6a[J6ETHV1OGUmOGeeKFU]LG5iR
JG5gNWf0PhB6R8N6QHJ6QH:3Q8J7QH=nMg9_KFe_LG5`LG1`LgIhNg]iNWn6RhnE
VIZJV9B?SHb<S8b<SI6DV9^KV9BBShj>S8V6QhbDV9VJVYRGUYFDTHj?TIBGVIZJ
VijQX9bIUIBDUiVIUiFEUYRJViZFTY6AT8n=S8b:QX>3Ph60Ogn1QHZ=Si6BTiFI
VibNWIbKVYZIVY^LViNEUiVHUYNIVIRFT8V5Ph:2Q8F7RXf?TI:EV9RDT8f;RHR6
QXR9RXb?TYBGV9RFTY2BUYVKWj:UYjBNV9JJWj:SXj>SXZ:RWibHUYJCSh^8RHb=
RhV7QH9mNGIdLg=dLW5bM7MlPXF4OgUdLW9cLW5aLg=`KVe[J6AQH5iKFEUIFEQG
EUABD59EFEiTIfMWIVISGeeKFUQHFEUJFUYLGV1PH61QHF5OFeQCDEAIFeI@Ce=F
F5UKGEeLFUQKH65MEeAEG6=WJ6Y^LgV1QXEoNWQgMgQiNGYjNW]lOGagLg1_L7=f
N7aoPH>2P820PX>0OGakO824QH=oOGalOH22QHR<Si:CU9FEUYVNXJ6QXJ:SYZba
/k:_[:VWYZR[[:bXY:2MXJFWZ:^^/;6`[Z^VY:BUYJBSXj6OWIfNXjNXXinMW9^F
Ti2<RHN7R8^>Si6BTi:@RhJ4Q8J8RHR8Qh=oO7]mOWimOG]iN7YlO7]hMWEcLW5d
NGn4QH9mNGMeMGMiMgEeN7YkNgj1Q8=mMgAdMgb0P7mnOh23QHV?UIRFTX^7R8Z=
T96?RHB1OginOX22PhB4PX62QHN9RXR4PX>4QHJ:SHf>Si6@SHV7QhR9R8B0OX24
QXR8QXB3Q8N9QXB2OGUgMW9]IV5RIV]_LG5_Kfe[JFMTHfEXK71cM7IgMG=cLg5^
Jf]^LGEhNGMdLg=eMWIgMgEcMgj3QHN8RXb>T8n=Rh^>TYJGUiVMX:>TXYjKVi^L
WIbOYJZ[ZjVWYZJWYZ6MWJ2SYJRWXYbDSXZ9RXj@T96DUI>BT8n<RHN5PhB6QX9o
O7anPH>5QX=oOG]jO7enOWekMgEfNGUfLFi/JV]bN7MeMgQdLFm]JVQXJ6U]L7Af
MW=bLgEeLVm^KW1bLG9fNG]lOGn3Qhb?SXf8Ph:2PGeiMW=cMgUjNWYjN7MeM79`
LG9dMgb0PX:0OGUjO7elNGQkPHJ9RHAmNGQgMgQhMgMiNW]jMW5^JVMWJVe]K6i_
KVe_KVYVH5YFF5aLFeeOH61PGf9XLGMkO7akNgf1PX1mO7YiO8><T92@SXZ9Rhn?
S8Z9QhJ7Rhj@TI6ATiNKWIfLWYjLV9BBTI6AT9:EUYBBShb9QXF7RHV8QhR9R8J7
RHV9RX^>TYJHV9FASXb;Rhb;QhJ8RXb>SXf:QH:0PXJ:S8b:RXb=S8Z6PhB6QhR9
RXR6QhR:Rh^9QGmiMWEfMWIcKfa]Kg1`KFUUHV5SJ6idNGn3QHF3OgaiMG1]L7Mo
PX:2PHB7RXb8QHB4QXN5PhB6QhF0OWajNWanOWakNgYlNgMcLGAjPHN9RXbBUYVI
UY:<R8F6RHb=SH^:RX^;SHf9Q861PhF6Q7mmOX24QhfEVj2RYJJVYZ:NWj>TXJ:Q
WIZKWj6RXZ:PXJBWZ:^][[2_ZZFRXJBY[Jn^[JVSXJ2KVIRIVYZMXJ>TXZ:VZJZZ
ZZVYYZ>QViRFShV5Ph>5RXV6QXF3PWeiNWelOhB:SXb:RH=mOGmlMFaVIVY]KV]Z
K6m_L6iZJFUXIVEXJFIUIfMUHf9RI6QZIVASHV9OGEeMG5iPIFUXJ6MXJ6QWIV=Q
H5aLGV9XK6e/Jf][KW=dMWUiMgQlP8:4QHAoN79`LW=dLg5_Kg5eNGMcKfe^LWMk
OGinOh1oOX1oNW1XHeiJFEUJEE1;Bde;BTY9B4e@CUALGUiNGUeKGEmQIVYZJFMS
H69UIfQYKG5fNWn7RhZ:RhfBUIJIW:6TX:6RWYbHUYNHWJ2RXj>SXj>TXZ:SXInM
W9fNX:2OXZNZZj^ZZjZUXJ6PVY>?ShnAU9NIVIF@RhN2Oh60Oh21PhF7QhJ1NWIa
KVicN7UmPX:1PH:2OgaiM79eMG9bMgYjNGUhNWn0OGYgMWMgMgQfL6meMgYiNgim
O7YlP7ijP8>5Pg^0Q8F7RXf@V::VY:BVXj:RX9nMWYjNXIjKVYVKV9>?SHb;Rhf?
SH^8RHZ=Shn;R8R:RhV7PX:6QhN6QhV9R8R:Rhf?THb5Q8J3PXZ;RXb=S8j<R8F3
PWmkN7UiO8:8T9>?RXJ4RYRPXInIU92>TiRJW:2W[:ZQVI6:QGn1Ri^aa<k:_k>R
ThR6R8bAVZ>TXIbES8F5QhV=TiJFUI24NGIjO8:8R8^?Ti>@S8R1OGYiOH:6Ph5o
NWMfMWMcKFUVI61IEUMFEUMHGFAYJg5hO7UaL75_KF]VHVI^MWb1Ph5mMgAeLF]Y
IV5RIVU[JfY^M7EhOWmjMgIiNWUfKf]ZK75bLG5^KVm`M7QjO7akN7EcM7EgLfe]
M7YiO8QnN7imP7edLg5XIfQSH5iPIFQ]KFmdMgEbM7A^JVe^J6elP7f2TI^ETYB=
QhJ<SXB9TY>@Q71XJgAmQ8jBS8F5PWY`K6a[I6Q_L7V0OGIeM6maO8:4QY:OXIjL
WYZ8OXB7S92?TiFGV9FCT8:6[/BiX7iSJZ3Pjl:KSWEDCDmFJh:<Rh^CW:>__;Zc
[Z6JVi>9QhjEUi>;OWEhNg]nN75`K71fNX68Rhj@SX^3MFQNGf9LFF1ZJf9MFUMH
EUUDAdUGK7^3S8YnL6EQJ7QlMfUKGVY`LgUiNGQcLWEgLVQSI6]fPXjCR7ibHV5Y
MGikMFiZKH2?TYjQXj^][;2aZJ2UXifCSXZ:SHnKY:VXY9nFSHN5R8bAUi><SI2B
SXb7Qi6JVY^RZjjYYJ6EQWUiQY:EUYJKYjRTVi>CUYBCSY2GUiBEShImOXF1Q8f>
RXnPYJ2PWY^OXZBQWJ6UYjV/[Jn/XjBa]K2ZXiN>SiBES8R:QhF9SHnCUY64NGMm
QH1hPIJKVIJ>RXjBTY^LVInQWI^OVY:>QW]jOH2AWIjPWIbQVXj6PX^>O7J<Ui>;
NG1dL79kPhF6QXV5Oh5lNGMfN6mSQ/J2<d5gV8JRK2XSG[N?<@`gMGik=094QWLX
;UAACEYT=@`]KVPg;2/XD7iQ:5>LQT<kPX=IAVE`E5Dn>6ag;A9TVFQHLfiOHVaG
BeI/KFV3ECEXMeUFGX2<IGJCQWU^JgUeN7YoSIJ2IGfCL82VRU]OUI1JCVUnNh^H
PVMoRgedMWAdV:JENGMjMgilNXB@Q8f@ShNMXhR1QXb9Q9F6NXR2O6YPK7VE[J6C
VIfVQG:2NF1IOhM[Lhn3LGbCWhn1SifHSj:e^:mkNJVVVYNS_<fm`<6aZ:S0_KNd
/[Rn_;FV/KJV/[Z/YjJQZJFSZZ2^/hioQiN9SYf5QYBMQfAIKH60S8adJXZDMGEm
KfV9V7UcNHB@Shn4Oh>;S7RCZIN;W[6DNH>GZ:FHZjFY_:>;V96>YjBY/:fY/JFP
ZZZWZ:JKUY^c^Jjc/jRYZJnYWkJlWI^b/:ZVTYR^/I5jQY>FYZRGT:6[TXAnMVeh
R8AeKGMfKfiiS8EjQWe`Ge5IJGaoK6i_HUEIHVMD@T]ME38[;bXhASXkC4mABD5V
KV1hO71iMf11=3e5@4eNDd@l@FAbGU1EDeQ@@40c8Bld5Q0B4RL[9C0h@eYABEM0
<CLn>390?cE0D5]ZIVegK7bEXj6=RY6BXJVJQIJWXI^]^;>`/Z^V[:Z^]:ZM/[Zj
[JNVViN5RiVS/[g2aKf[ZZfMTi:8TY^9QY2GXjJXX:2l_JO7e<^lZ:^NTY6CThbD
T7n<XJbKRHN;SHb<TH9^OhR7Pg9TLgIOD5UbNh64QGAUKiBJQFUJFe1BEUYYJ5U8
C4e>J7F9TiROOVEbKVadN7imRiJM/K^n^K[8dLZf/K2OSY6=LV9NEd=>IFY]R99o
OWUVE59DBc``5`0692Pa;SUFGG:6NWUkNHMoJFASJh5fDVEmQHVBZ;>/^/Ni^K>E
Rhe_F61OMh]kSYbD[;Vi`;:fal;3`IV2Rhj7N7bCW9NZ^;WCimk7^[k2_;B[[:no
d;ngaLcBh>;OkoooonoGbZVJVi>RY:Ja^[JRUJ6i[Z>IQhfBUiVNUi^OMF^@X9fQ
^Lg1ZiB;SY6FPGjJU8:6Ti9mNWV:XiUnKG62S7YbL5A7I7EXFVZ:R8na];c4[iZ?
MVQMBUMF>45OFeAVGDUJM79VF6b1L5XS00055Q4M7B<W<dU4<dIJDdM0>d99B5A=
CV9RB45FKGf2UZfQXZfGPHEgGV5cPhAXACQFOgQ/MXB7TZJYS79iU9]iFT<mC4e0
>eIlO6]cOXN:LV=NIGARAd54ATY?E418HVMfRHb:NG=fH5e]IDI6DeYLATmcPh^@
QW^=THR0PhEkKG=`E5EZMFeOKH1jKgUfL8N2Jg1oRXMiJWZ6T858EH1lNW5`QHbI
/JnggncUj]g9_Zff/Hj5R8V:OWf0UZZUTWU_O8EcJfYYKf14;S@f828c?DANM7Ad
OginM6QbK6mmLWMhNWEgU::IV9jb^kVl`KRTWYf;THj3SYRO[K2YThjO^K6MW:6X
]KV[ZZBJTXJ5LeYbUijQ[J^SX8jJ[j:QYYn_^[O6dmKHelk0`mOVcK_AhN7@_l[G
b<[Jg^CXh=G7Zi6<X[>NPX6ASGY/K8fBU8mkPi:@VjbKOi>DNWEkQXEePIRAPgae
QYbe^Y>;Y[kFc[bjc_?ffKo3a:BCT8^3M6eUI6=bPFiUIEaMGUY;E5]<<aXF82Tc
=CA6FUQHFFZ6U8=hO7^5RgEfQiZJQIRbZYNNZKK6b]2jViZIR7UUG6YbOH5]LXfB
QFi^L5i=EF1OHVYM?2Y2EDTh<D=TPHAlQ8fK]j=dKV]gPG9iTYJ6Hf5lP7QcRj6S
VinSThBGXHMZHfESCD=JLE]4?3M4B3Y1E6EdPG9[F4iTG599A5e[H5=TJ6EcOHj?
QiF<QiJGTH=jMG^EVHB8[/no[ko6dmBaW8R5SgQMARhd:c9DEdiGIUXoC5U;BVEa
FT<_510R;Rd<3Be=F5=TK7>AUgmZKFaRK7QdKgMkNG1RI6Q_O9fg_l>]SY6ESFQ4
BEYNET<d;RPL:51/IFQYK7U]MHZ5Rh]nMEI7HGJ5U8EdQH^M]Z_6f];=a;g7]YfJ
VZ>g`[:_]Jnj^jZ`/:jcZYZETgiaMViQEU9YOhB@WI^LTYb/W9JJWifKRX26XkN[
Z;Nl^l_Bakc8h??GUXN9R7I/QZBLTYR=NGF4/MKMe[JALgEkLf55?TQ;EDm3B5I_
THi`GU=bPUiCEem[IUiOBbTUAFb:RX>9N6ijRHb<Y;k4ZY6@QW]WI8:CXibDVij[
XIBX^;jbWi^<PjRhWHehNhQnOi2BYl2k]jjMVYN@WjN>TibJWIbGTiZIX[Jc/Zj_
`L2UT7ajTI9gHfagOWANDTiNLG^2Ng5/JVMZLViYLhV8JEaVQjBVVhQjPYFJS8RD
Yjnd]ZB:RZ>^VhVI[:nBK71fK7:2PG=ODF5aO864TJ:^];o2Y8nBS8j?NViVEda9
F6]jOUY9HgA`JFEfUj6PTWEE@E9jPVe^Mg9gJDho?5AbJUmWGeUUHFU_Gf1lQX5`
I7VAZ;fZQY6PV9:5Q[K8ZZFd[Z>MYkBca=KIcKNRWZV/]ZnGWJ6BRZBmWGijRXUZ
JWnJW9J7Kf]`NGAoQ6QWN75VIFf9Vh=_JWZQZ9NIXZfk]9Z=Yj6BY:FXX8JD^/2X
TY6mf]KK^HB5Ui>GTH>>QW=_Iee;C7B:HdMDEEURFUe_Mg5SFE]QNInb[i^5LVIM
FVMWBcQ=I5=8GF=OLGmnP8J>KC`N:TA29Pd?3`00000041PR:c0V;U5ZNYJLN6=X
KfMWKGN7TX9MGH2QZInU[[>_/<O8/Z^b_kVPVZF][j2I/;NTWIBAT923KGF:Q6EP
N8=dGU5=CU5BDe5=EDm@HfUjQ8jBRH1eNHB;R8>;SH5lQHJ:UIBETh^HXiVDTi>N
[JB;QiJHOgjDPfi/KG]oLF9?AUijIeaPIGmjIfY`OI:PUXMbHFI[KVeeNg=iOHZZ
^L71`Lk=_:jUWHaVB5MVIem3=BdV;c4nF6AZJVIQGVA/OWaL?cLe>TaHH6AHFeaG
IFYVKX>ATYZ/^;6GUjnh[JFcalNnb=W;`<[;bl>dYjg8f]>`X;>dUhZDV9VCQ8>;
VJ6:I6MmPGamPX^AOVmjTJNMQH6>WI63Q9BS[Z>8OX6:W[b_UjBX[:^YZj:IXkk2
`L>bZIF0UJJOVYJ@SIJIV9fT^<C4_JbAQ:k8]J6EUHJ2PXF7IF^GXZ2PXI:0PIJ>
HF5kQhj1M7f=WIfKXibCRGZ2QGj4QX=nK71oM61KJWn@TXEcJ5iCI7QbHU4nAF9L
>b/gFF]TFUmXOiJ<O7IWIGQfJ7FBY9j6N6]YNhAnP8fASXjATiBW^[^eUXfVXZc0
[Z6icKZMSY:U^<k@_9Z9Og><W81hPWe^E410BE5RK5Q<EEeUIfMRHW1lQ8B3PG=i
U9=gPY9oMG5`NXVFXYQeMIjfXgmXN:>`R6b0TIZNT8NHXIVRZIAS=TE/MV=DCC/d
>C0b?TMBG4e7DEUbOVYCBF5iLgjDVkK8[HN<ViNCUiAYHXFBTXR5NgAkN7imLW5i
OGj5OV9>AdQ0;bDY?THQ00XX=cdl>CHeG8B2OgIiT:2<OZ2]XInSTY>///2lWiVc
alk/jlgFm^OAf=?=clfoXY:MWhf@SG]/GU]SLWiiK6MWF69nOfaUMgIQDF:2R6iG
H79mMg=ULIbFP8:MZ[:n/9UnOZ2d[j6IUjo9]HUjRHMkO7U_K6IYMf]BGh5eGEUG
FEicP8B?QgEUJFa`N6j>Zi=gMgAZL6igRYJMSWjE]JfXbnO[kL^TYkc2[jbfYh=V
FdiHGU54<BHT<ST]=chnFgMXC4UHKFmK@3A1De]=?4=0>Sm8Ef]iU;JiY:Bd/kgG
jMc1`/g5^:bVYInDQWf7Y:F6P9ff[Y^Q]K>T[<79bK^gaLBMO8>IXiIoR8EePiV?
PH]gJGB1VJNDSI:;W:N@Ujng^j>0OGmoRi^IShb2IV1oQVYRNhamJG5kNH2?R89m
Lg9aL75mRIF_[I=jL7EfN8^XZJFSRWZ<ZJ68NGnBQW]oPhEfH5iKBC`mDFEK@TUV
O85dMhb6R9^AOXVJT7M`LEeMJVYJC4a9ATM3@UAUIUe/Ph=ZIXfILEiUJ5iCIGYS
>ce9>c@n@UESFf1_MhJ3NH><SH1gSIjNUHEeN8R7Qgf8UgQlWiF2SXZ?Wi6?WJB^
/YfNYZ2JT7nB]knTOgEnMV54@5eWCD14AT]0?49=B3@hAD]JHf1QL71`MF=OLhVF
SH^PXhZ5UK6bTInm/IjFXZfaZInKVJ^bVXnE/k^ORh^CUY=kQK6kYXRHWh=jPiB<
U9Z4N7MlSHmbHg1kTYZ6SIjAXKZh^L;3bmO3]LWUfl:dYjFTX9R8O7=cKVa[IV1I
IFm`NfY2Bg5Z@cY=FeA7CE18ACPeAeISGf=/MGR0TiNKUhRJ[Z6R[kOCil2Z/JV]
^;^eZJg0e>3LaJjQUZC3c<FbY9VNWiRGSHn?P6aDDF=`NWm^FV9[PIRMTXJBVhmn
PYZOR7UgPHQlN7Z3OG^>QH:DSi:U/:RBRYNVY:FVXYfMV8n2N7MgQYfPQGF3RXj9
O8R/ak6ITI>PUXZBVhQdLFYPIG=eQHI^IVASIfM]MWEeQI6BPH2@VKCC`Z2S[J6E
R82;QVU[PWEGDg1gFTE=G69KBD1BF5I>=c9@HThe=2l]CE]1:CmA=R<]@TY;EUYX
NgMWG5mTKWm`IXZWU75IBUUiLV9TNh9_KWE^Ni>?RhAlU9^?UIb=O7=fQWiSDE=M
GEmTIfIJBUEZFV:2T9>PYXejQiZOYJjTUHn>QXV7LF]WKHnUSFimTX^?/LBbUYFG
PX>BYjNY]XETN8R@TYng^hmZMj2jYhf5TJ>a/k:g]ZRQ]Jb7SJNBIVA]N89VDfIi
JUQZQ9ZOThj<PhJI^<o9_[2NWKBiZZZRVYR5O8N2MH:AQ6e8;TA/NGAZJ86MTfIH
G5MTOGiYJG9P@CA1Ad1:FDDV7biAI69XLW5dN86>RHVO^lFn]:B[]JJGTY^DVJf]
PV^5W9nR[KO1`KO2c=W^km>e^L[;^:>IWi^8RiJAOWV6QWQaPijCLV^8VHj4UZ^M
OVY]LgAeMfa[KV5KJW9bSJb:GW6R_[^_];FJV:nRSi2UZinJSHF9S7UOIW^5QX9i
LV]XJfIgTIJ0Hf=cOGmoP8J2KUM9D6mkHE1CFEUPETA?GEUNP9BCSI>UYH^2QY:[
ZhUYHUY7BV1Q@2@P5A0G5R4W8c95AShl@eenN65THe58D4hk>eID>cm7AT94Ffee
PX9fNYJ[[KnoZJVnc<W0`M7H]HjDYYj>Ph2AWZ6>QYnLQX>?UYj_/:Z@RYnNTIVd
YhUlMVicRiJ5KVAPJ7=eL7BAWXN2U964Tj>GRI2OY:JFR8>3SIFPY8f0R8RF[ZR/
^k:KVYZL^KN/^k^QTIRa^JRSUhZRZ8j8VijERHZN[ZfMRHRQ/j6>TYVIUI:@QH62
NG]kLEe@DFb>PfE/OgaXHf^5U9VVYj:EOgV1RHN5SXn0JV=RHVinLEmGE6AcLFmk
SiR9Lg1hP7M]M8jIR7IiPX9ZDEUeSXE]HEMOLg=hRGiTJHJ;P9bTU:2VU8V5ShUi
PINRXYb3NY>SYIVCZ;bn[:BQWjJiaJZ7PHjKYZ^TZJZLRW]iP6iEFVefKeM3BeQH
Hg5jO7AXGEIUPI:EOV]TGEiCDEmdNeLi?DeWMg^8R81lQhUnQX^;W:n^W9V<MWQj
KFeeLfY[H51:Aea`K5IBF5UJGfQhQWeZG5QcT8=YIW5kOh5hL7aaEEj7UhZBZ:JL
THZO^LBoYYJ;SIfAPGM`HTLnDVMHAE5FEEE7B5YQFdi?IFiRH6=TDD=JLGUaIF5M
FeMRMX>>PV5JM9>ER8VCY:ZRZ;>[[KB/ZZR_^;N/T8j[Zin[^ZjGRHBF[;B_WiZX
Whj;VInAR89cO9f=JG9oK5m_Oh1gJ7f^aZbBX[N/TWb7W:VXVHAeO81/MHf0Kf=N
MHZ7NgV7UibANh6OXYje`kNm_J>LYK2k/:nYWj>FSYRFPH6P/;2PSYJRVi2HW9VK
VYnLTYRLUX^DVGm`LWj6Ph=_MYjHL6Q_LGR3QhN5R9NTT7EhSIFJX962QHUmMWf3
T:><L7EcHEAUNFEMJfQVH4E>JFmgJ5=FEUeMEU9DJGanLfITHF=cOY2@Si^JTH1h
T:JXVHZL[ZNZViFFSYf_[YbATHfH/[2LTIZYX8F2QXN:PWM[JFm_KfIXHEiXJW1b
IUU=F79cFTUPR81KEG25NV]WMH:8RgiiOVi/OX=oMGZDQgMjQ89dNWASL7ETH6Mb
KVE[NGiiNgUHD75oNgAaLF9JE4UEO7mIAfV0Qh9ZKgifL79nS8A^HFQ^JfIWNhUo
NgMaPY:9S9>?Q9>ENGN3QXj=PF]ECeISH4]9FEmNG516DEUEIWa`GU=QIei^KeaT
M6Y2<e1`IeaMJH24Og:5WXajRZB_Z967YkjZW9B<VK6cP7JT/JBKUijUVHAlW[6B
R:6_]Kfk];bjZ:b`^LW1_;jeZkS3]::P[9b3UJjZVYFCSHJ@[[J[VYNQ[KbdWZ:f
][J^Uj36`J6V]K6RRYVjYhnGY:ncXWf7Yj>OYYnDWZB?LfU_O7mfJ6]oOW1nQgj2
NW23S7ajPgidOHQdIfUhOVM[N8>>RX=oOi2U/;>NUIjRVHNEY9N3L8^UR6QRMXZ2
M6iYNh9VGG1nMgj9KEeVGeUWPIVLQFaIIGedH6=bJ5@j@FUMEV]gMG1dM7F:WhQh
PIVUVX=cO7I[PHb6LFU_GEMTLGmjOX9hKVf6Vhb0UJ6JUIZKTI2JUXb=TGmSMH9a
JemVIE]HCTa>HVaFDU=FCeEVHf]`Fd]PNGMSI7IdJfM`OWijO8V7NgUkP7M_OX5l
NgYnLEmKKHF6SZ:DM7EiNXV6NXNCPW=_H6YgLg1_M75IHWUWJ7UkOh>4PGUiOHfI
V:Bn`IYhOHZLZZJJUHQgJfMSF5=NGE=GCTYEEdE<IfIbO7QjMg=^NiFNPf]HB5Aa
KeQROh=lJ5E^RX5nQ8fX^ZnJT9nl]JNme]O4[:Vmb;o4a<S7Y8N8Y/C0VX>>Vjn^
ShFM]ZF>SZ2ZXIJ<Ngf:Qi>@NgEgNGeoJ61hSGm[MFi[OhQhEeIaRiB?V:6ES:2l
^ZfWZjn/Xh]lU[:]XhITIH>JW9J:TiNDYjRGPhRU[Z>RWH=oS8QiO9FDSXYgLG5k
T9V8OXB<Q6Y^Qh9eP85jRXA^K7ajK8>RRfASJF9[Lg1gOW9/LEQGK7=bJf]SFG1n
HTUQL6YgQhIcFDmPQI>0N92DQhf4NHbU[9n?Qgf:Xj>3J6YmX;:CJ5idPYFTV8N2
SjNNOgj@U9:GXHQMKXekGEibP96=Oh1hN8N;Qi^_YHj5TjRc[i5gOHamLGEfNVaD
FW:7P6IKEUn0OemTTjF=OG5YOiB8Mg1oQ7=`Oh9_GFYgO7adOGUoVXQWLj6VPVMY
MG1kMfUVFf9dJ4LiDWZGR6Q[PXN0QI5nIWZ<OWN=Sf]GEWJ;N6m/KfmTJ761W9am
HfYcIfj?TX5jKUYGH6ibJVM/MgIYIemKDUYaMh9/D51HJ65ONWY]Jf=>EGIiLH1n
Ng5OKhJ2K6bAXYZPZI63UZjSW<KIckR[_<g?`/[Lhmc8a=Ock<W8i>3Igl2N[<W5
Xj:e[iRCX9F9RhN:V9nHP82SWHN>W:2CUIB7NWF@U8>;RWahMG:3RhMhH6EiRiB1
K7B9QW=YM8F@Ti:<Q8V3NH:;NW1nPWemOW]SGHZILW24PGQ_LhV<QXN3P8Z3LGF@
]kZLUYF2Q9VSSH6GXI1oKVUbN6iRIEm:BUQ@>c]:E51<F6E97AdiE5]EECHO=T0_
;TIIFEE0?5iZIV5_OfMXSXn;SWY/OiV`[h]mRH^2O8VMVJ6ROG2?UXfFXJ>NS7j;
]KZ?PIV`Zj6[ZYZ>TYJFYjJGPgBBU7McNhj=GT]IDTiHIV]G@4ILH5MNJFADIH^>
LgJAV7iZP9F1LhZANfQcRHnAOemLOY>7TIF>RX6=ShnAUZFPUI>GWYjLTX^1KGZG
VXn9OVeYOh9XHf1HLXIoNgb=RG>8VX=mV[:^XHnKYYbNXjF;LH2IT7]^J7f6K5IM
LfEBGfY[JFIXKEmQNH5XHh>JTgj0Ohf]TWF5UY62SYZDQ7V8WZZKN7:;WZVSUj>b
/Jf`]:ZQ[LK;^jbS[;Ni[jJARjff[j:ASYRg_I61TY>KXi>5QIbb_KJLRiJYV8jN
XHaiSib?Ng>6TH=_O9B:Phb0Ifj?VX=^O8^8PWanSI:9PGAYMXInNHQiL7ihKgEa
CdI]PW5QHF^0MVISLI^PUGeNM9BOVhebGGREUhUfLhF@V9^FQW^;W923PX>>TI>D
QX2>X:nXT75`V:6@OFY]O7=DFFYNEd`k@UeRBdaXHTALNG9TKfeQLgYlOfMJIgE[
KH5aHW1eJf1JIFM_OVYBJHb7L720U9n>LgFCXI6:SYJa[hZ1RHjBUYnOSWI]O9>>
K5]SNHnBNVANJIBRPV=_SW]YLGA^HFenOW9SEUMeRgAAAE^6QV5EFEi[NGETIVMO
KH9fLHb@LfIiQ8FBQ6]dOhBETgmoU9AhNI:HSX:0NWN0Nh25O6eVIgRBSWebOHn9
S9RHUiVCS9FVUXbOU79bOg]mRGQIEW5fLGi`HVEWLXEcG6f3M5YPNfiIJWacHEUO
OH9SFVMWI7AgHfQhMX6ETGE[P9^YZIZB[LZo/;Jma[b][<3=`K6UYk[0/ZBbalk:
_k:Z^/noWZBh/Z^VUHbSYHj@WYR9U8mfQ9J:R8UgKhb>PGmiRIR@T9NV/9J5SHjU
aKNPY:^_[JFLZLFfPG6I]j:3O92UT6aLP9n4MWa/NiJ5N8RCQg=dQJRdUh6=Xj:F
Thf5RINLU8UoQYJBS9VOTgf0Rh:?TFe^R8EYE5]ZITe1DEeCA4Q><b55Gd<hCD/h
<3aEL6Y;Dea;CEefN767RWe^N8fIRfEVP7]_JFmeOGUTJXB2LWYkQ9B2NiVcZHef
OI::Ri^@PGebMXZJW9InLgb3QhnFRGYfQHikKWJ=VX5/MH:5O8b=Lg9^Gg61NF]B
B5UaNFeNF5MWM6eADH6PSFEJL8JBS8>9TI:DVYfYZ8f5TZR`UY2DR8f7LWB<Sh9n
LgB;UhMiPgYoSgMdOWj4M69SHFIdLfY]H5IYLVUbNWj6NG>7P6][Kh61E45NJEiC
Acm;DU5FB3U7GVUNBEU_LVaNFUUFHGR<R7]oRjBWSW=`T;6jV75mSIZVU8j=PIN`
ZYnKXK:kaKfQV:6]/:ZV[[>XXjf]XIn//Z6T^KVg/Zjg[jF`_kBFWkR`YIjJXiV>
V:FLTiRPWY65SXn<Wif3M8:W/YF1PYJMTYB?SXN7Y:2;UZR_^:f:QYb`_;BLQh>2
TjVMRhjOZJ5lEF^DVXeiKWQmPGmRAe1[NHVALU5<G7IkIU]/OWMIEVA_PIbQPgIi
N864NWQjRY:4L6M[KG=hLfmdPXUaHfiZJWihFDiCI6UCBDUBJFeREeQLIg=aMWI[
Ifn;VXQlNHFKXXa`PZViYi2>XkF^YZFUZjn[[:VIT9:KZ9N<TGj1SG1JJWb4M5eF
GFikLEUHJGN8O5mXK59PRI63LgQkK6Q^MG^9R8=hI6j:T89mO7AdLFehM6=NI6QW
F5a_CCY>EfEkNVYMDUf3SgadKg1bJW=hKGR:PG=aIFJ3V9bCQh6GWiBBX;:VWjNX
/kBRTXRDYJ>=Og]fK59@LVi=CEMA@c4/BVESF4Tg;CiBDU1ZRgIEKhZ6LfYhRXQk
OX:8Vi9gQYjOYJNUWXbH[J>R^;^/YjZ_]:jga/Bl/Zjob<FhWYj_^Kk4[YBK/[^[
YKo>/9fa]Zb`[:Z/VH^QWgYjTiBAQWf4QIVDL7EkJg9nMVmfKVakNG=fLg1nVIn4
M8VGTYjJN7ZJX9BCU8b6T9ZCSXZ3TJ6BP7UlTZncTWV3Ti>8SIjOXZ>BQ86BW927
RiB@T9^CTHilPiVXX7meQga`OWmXGfmgEC8nF5M8BC`[<d509a8WCEDj:CYHES/i
E6]bL7>7QgM[HgF=PVmfQhR8R7IjUINCT8UgJI:gXXVDYYjMZ9f<O7nX]Y=oRI^L
SGeaNHR@PVmhNF1GIFa^JEI>FU]?B5ARMG5ICeaZKFeKCVR7RG1GIVaLL8AlL6]]
Ifi]J69NNHeiG622Y:>3S9bEW:f_UXNDX:o0/8V1UiR<TYRDUI:>PGf:VZNLRgih
Rhn=UXf2OGnBT7QfSZ>KPFimWIRDTGUmTIRBRWadLEiIMhYiIFAbKE9CJg=nLTY3
DUi`O7YdL7B0L5mbOWb>RgIhOXZASHYeLH^GVI^6M8naUh2IZJVUX9ZJYKO>d;JM
SHjR]LFaSHjKYZbQTinW[j>>TIRY^[2GR9ROW:FQSX6;X:RWV8^@U9FJ/kJHW:fF
NGfAUhjK[9F1T:2OTI6UWi:7P8N7PhN@TIFGSXV0Kg6K/9N:VI5oPhF8RHJBUHb2
M7RASgidMYVOQW9gQXZ<UJ6SRgEkTIfMXib;UZ:AQ7mmP89oMFMDHG]XCDQCJfQB
CU5<E5ULKFa=?dYBE5=8B5]RFdHc>deFCDm@CFARG61KI79aHE]PHF5DFgR0N6e^
N7ehMgIiU[BZXYjJV9^_^<G;_kRf/kBbXj30d[jJOh6HXYJ?ShZ1P81gKUiKL7Eo
QF]A@4AON7iiKfe^Ie93DG67Me5<GV9UJ6Y]I5MMMWEMFfakJ6F4RWMUGGMlJh:@
QGilOGn2PXImNXb9L6IhQXJ1OG9[N8:5O7EmQH9hKVmVM9RKRWamQXEjNXNERhRI
SWMfMGB5PVU_L5eRGD/o>UA[DS0hDdHa>TeGEfIkM5YFHg9oMG5jNgYgN7ioLWfP
VGn0QhV=SXZ<VJB]Z9ZT][?4b:ZXb=o>^/6iY;SMhLNc[[Bg/[:e[j^ealFdYZFb
^ZRAV:2PX9nQSGnGZZ>@U9nFUiZDSXj@Ui^BPWV8VIVDS8F?YJVIShZ?Z[FKSZBn
`L>eVYj[Y9^Q[ZBAVIV1OWefNgiiL6]XM8=mKfM`OW]`K6UlTXYnMg9iTj1cFWFB
WINRZXecNH^AQHB7Q8::VX]`NHnDTWYXMhF6NGEcK7AhNf]CFeYFGV9MDeiZIeY4
AeQVNh5[H7>;TH=nRY^HNg=hP7MYP89/JfU[MWeeHVZ3VIn2KX6T[Yf:TjJRW9BH
V9FOXj28Pi2<SX^<QgV1Ng=lOGYgQ8UdIFZ0Rg9HGh:?OGEcIF]mMgAbJfILIf]G
CeMVJFeQB4]JKh5_Ef1UJH2;MeMFLXMmJ75cIFERGW9cGV1fP6]DCEekOgA`Kfml
SgEQOi>6LfQ_PXR6P7j8SiZFQ865THZ3TinQU8>4RhR1NhZKR6eYMgmnPWQaKVYb
KE]NNHn8MVaLH7EmN6QJGW9nKEU?Cem^KFmcK71dPib=JgJMZiamGfRG_[28QHnJ
ZJ2:SjNj^j^a/jZ[[KFXW[W<_:jl_JJJ[<?0YIZU/J64Qif^Zi>7S7U`T:6JTHND
YJFAQIFPYJ6<QZ>hWh:<VZ:/WHjASH:2Q7MjShAeQ8ioK6E`TJZ>LVmcSi^2KVmo
SHMoQ8Z@UIB3N8B9SIJMQfA]Oh6CUg]/P9R<OXJ5QY:;P8B>UI:3Li:TQH:GWYJ9
R8ImP8f>PgEXF61bK6APHE97F6QKATQXQ7AEAUYfO7aUCF5iQ8QoM6ecO71SMHMa
FUmQF55AHW9bJeQAIh6=Qg=fUjVHNFb3YiamNWfI[9F;TYZNV9JNY:FNShbK^/fk
YIjNW9b[ZiZEThA_Kh23JUaaPWQZF4YTNg]eFeEaPX=nM7IoRIVKRWmfM8fSU7mh
PH^7Og=[LHF>RhQmIVZ>X9N1JWbEOfIWNHF=TXIjOGj2PWQgP8Z;OVY[NGMZHfUm
QgIVJgIbKGV:WZAoIGJ8RH62S9VPTWefPHZAV8QbMh9lM61@G7F5Lea?A4UKNWUF
DVMeO6mMG6N4UHQ`JG1iOWQVDf29WGAAFf5aPhAkKW5kRhYoRiFJY9nJThNBWZRX
Vi>J/;BANHbRYIZKWI^Y[JBFU[7<b;R_/;S3b/S>e<>e`<:XR8:P];F[UXj7TZ>N
SX><W:bWQWb>XK>_XYf=QHbGW8QfSJ^TQ65EJGa]IFe[NH9]GV9[Oi1nJ6UXKX>A
Pfa[LG5`MFaHFf5[N71HDWMmHVEWK7QjPI2FRHJ>Ri:ERHB<VYjPXYB>THF1RI>R
UGMjRXV7P6]JLiB5DceBIgUlHeeRCT]EBCm9DTaDJeLe>TM@FUI5>4EVMFA;BF1b
JUaXMG=WFFEiNW]eLh28R81oQ7b7Y9j<VjBS[JFAU:k1`;6YYj2JW[O</9:K[;2R
T8bFYj:8PXR:R7b8U8EiOH1kOhalGf=oR7QVHGBBRfiPH765P71UHW20PgI^MgAV
IW^;PVYZQHeiLgMdQj6LQFiYQ9bRWHn5QhZ2PXZ:S7moSh:0Sh^0MGJAWiF>SHf:
RXElQI^RU85jNWAkSI>8LFIcNGN0NVQaRY65LW:6RYFQS7j>Z;:GOH>JVH=oOGQf
JVYgKeiQO8=XDE5UMX>BUhITFH>ZVGigP9ZNR7YfPiB@NW1iM7=oOhB1PHbAU9fL
THB6W;[7^;Fi/jNGW;;7b[R^/:bSVi:>UZV/WIRLWYnQYYjG[[nhXWefSjN`[9nI
XIN0RI>@TYJUXHQnOGAfRY:ATH^>UXeoMG:>XiAkJfMVJg=aIE]VQhQM>SiDIW5T
FVYcFdMKM75SG6EkPW1/M7R;T7M/NY>HSgUXP9VQV81/O9B4Kg^AWXidOXf4Mgf@
UXf0OhZKVh28W9bFPWb2Q8R;QFiRL79MCTm9AeQPCS@O7S=<F4`Z6SUPGD@a=V1f
GDQ8C5MRGe]IDeYgQVQAG6UkQhZ<S8J5TYnET9^U[K2SUZ:YYJFORHBIZ9UnNX^Q
/:B9PYRYX9JLYjROX;2]VINQWj2UV8J1TYj4KGfIWhEUH6EXNhQhF5AbPW=QGgJ?
SXAdI7=kM7AkM6UcPhQiHe=OMWV0R6aJL7]]JWf?W:VJNWB:TiVWWY23Oi2LS7Qh
RINDQgE^NhF3Q7a`MGf0OW9YIFYgPH5nLW1oQgi`Mh^VZ8mnOiFRY:>EShf6RH>1
V:ZJOFm_PiB3NH5mLWB2PWQbMGb0OWYoPhJ?P6mhRiF>RH9`IG:=Ui:DU8AgNh:4
QXNF[Zj6KG^GYJFUWYVNZK:aZ:F`_;fn]ZBS[[2^]l70`/C2]jVW]lkHelNe[[6b
XjW5aK>PR7ejS9Z8Ngj5OfUUKG5fQXI_JGR2M61IGgR8LVYaI5iQHfQZK6UQFEMH
DDQNRXU/IVAWN7Y_Lh>CVI9nJ6MfP865QX1dJW1dK6=XPhAeLFm_Kg=fQI^HQGb6
Si:IVINIVinGQG^1Q8N6OH62L6M`KF=OFVJ1NeI7C5=QKF=BCe]SEDM=EEY[HSTd
Bde>G5iIFEEJHfEQJ7AeO8IkJ6f5UI66QhV6Sj2JPX:I[ZjFOGnDWY>:SHZHYI65
RXfCWZFQXZfZW9^ITifVYJnZTXjDVIV@S96?RI:=LfMVO8ilKV]WKFYIFFEfR8^3
KF1aPWQePX=kNWQaLFaPIfmaQ8U/IgE^NhUgKgf=UH=]NiFV/:VBQYFXYXI_MhnM
SG9^NGedJFmaJV=QKgA^Lgn;R7ilMfj3YjnJMG6>TX=aL869QGmcIG2:SHV9QI2J
Thf=SiF]`lJ`UYfZXi>:RHjNYYn1H5]YOGm^HF5_MVYIBU=YN9>=Ec5?P964Kg:9
SgebLFEXOhJ7SX9dN8>7OW]kRIZPXHelRZF[Z;6k/ZJZ[[G1b]37[IFR^/>oYHjG
[kBWSG^@Y:JLS96CS9:FTHN:WinKVHE^LHfOVHj2JfQhKea>C6nALT@iA5i^IE]R
KFm^IeMLJ6IlS8>0MFamQh64R829UYF?PFU_S9fRV8ElRY^BQiVbZZfiWhR;VjbQ
Ri6]/iUoLfi_O81cN8EfG5QVMfm[OWn0RXMhOI:TWY2BU9R<O8B5QXn6K5YMKfiD
C5AOKFUOJ6AXJ6ikJFUmOg=_MWioQH^BRWEbOhjARH>9Rh:5NfihP8VKWWUdSYNV
WHBBXYF=QhB2QiVMU8EkO7MiP6YTQHUnNfIOIfI[S9IhL7f2PWihPY>JSh=/HWj>
RH^;O71oQW]YGgF2NFiMIh>4MVMIH7j2IF1XJg5dL7AjLW5eLWEmNgJ:WI60MWbE
U8Z:Qhn9Q9V;PI^HM7>AW:NIOGQjQXAmNg^5OfmKGgZ7QW]cKGJ2PX5nQHajOYJA
T:Vk^::FYJjUZ[R[TY>WZIF>XIEmPXbFTGI_LFajLeICHg1WGU]WJFYeLE]LK6UN
HFi_JV5PJFINHgZBTWU_OH2@WHf6TYVKW8f1RYRMWJ6JTYfXVHR4S:VaZYfDUIbW
XZnhXIjWZZ>6TJRGQh66TXR0OgI^LgR0RgeOB5MXFVF9UhInOeiANHb1O7inQWYa
NGn5RhJ4Ph=kJh63LXJEX:Z<JWB<TXFH`;JIVYRAT:>fY9FDWIUkMibbZ9V3NX>:
WIUoOhB>YI^0Nh>;QFb8UfiQR:jMLe=SSkVaQGIkP:2/YIZ4Qi1gIWUoRHn:Oe=9
I7F;MDHkBUQTMViIF65/KVabL6MKCU5KGg1kLgi_@D1]JEMNK7i]Ee5CG6ecIEaQ
IFMKH8A]AUafMgUaETMVQXMnN8AdHW=oV9Z7TXabNhnFUYB9T8AeUIUhJh2M/9YX
GgF7U7aWIVa[I7=dK7QeJ7J>R79YMXVFTX:;W8EnSWIkVhehNHR@NhNCQWmo^[Ua
NZ:fW8Z_glfJVj2IOH6PV8fbekZGPgnBYKfYY/Vl]kfbSgFTb;>W]jNm_:bo^k>^
T7:baYZid9Q8I]?EZg=7LiROVhA`K6]jN6YfKeYQMh1gKUmYOV]NDFfTSWN3X9al
IFMZIFF9Yi1bIW=mM8BNTVeUO9NIMFMf/<bHE76[ZZ:GTh9nY[bBKFYdLG63MW1h
Q7n;R5eMOX1BKZ:EM71cIgJ@RUeBIVIjMTMNM7J1LfY^PW0eDXZ7KfQ`F6:4S7IS
NHVOVGa^Ni6HW:fOS5MCQIB1O8F6T8MmQiZQP8NZ[[2@RINCWKV_Y:VSMVjOVXAj
PXj>S7icRhifSJNAPViLTKBHSIbXR7VGVX=TK9BJUH9WEDQ6GW=VD4QLMF]NIddT
>gB?HQ`iKGejL6QRBTYZOfmPC4m]R8ePBU@gDFM8CVQcPF/kC8UmHFIHEW65Sh9W
DEf<LcI;N85[FEMDEFj7Qg5IIG5hO9RYX7ebLh^`/hUCHhbEYYagOjBMXXUeOHBG
QXVMYjZRSXf>VZ>STX2Mb<V=LhRW^:2?SgaSM8YVB7V>N8J>R81^LhBCY:jfWX29
V;o5XZJed]VfZjRSYl36[Kg;V8o0fKJM/;G0aijM`:>O_=;C_Z^e/IfIO:G:[8J0
OfB4XGi>Fh6MQGigI8:I]:1LF6J0[IMHGW=dTHijI55?Mh]UCd5@HGV1I6IhASAK
LUeQLFYUMJ:7B6FEQgB@XWi[KW]eMWU_K65`Vj2KThb7Sk:aVY:9QiFRYKVaOg2O
/Z6DPHJ6THi`QXEdEDEaPXbHHUNXY71QQhJ0YXa]HUY^RY2PNDUCEW:DNUe4@DAR
S7mkKTMIOiBGTh1`Ni6EW9FHTH:BTI>bU7:N]ij=PXVBV[Fo[85SJIjVWJBHUj:i
[XElVZNSZiAoPhZJP4]ENWUPGeeEHUMPLFA^NUQ3DTLZ;UmaHV1D;2e@GF]X;RIR
QWm/?2a=OY67MEI6EGn8G4UNKHBFQg9CBgnLSh5aKFM[NF]=FH^<Oh5jMhfPSXZP
VjRbV9jXVIBRZHJ8XkBSU9jUZIB?R7ikNFb4ZYQ`Nhf:MWNOZIAlJHFOR71ZNHFR
U7EnLXF>Rh^@P6ICEIBHKgJ2QH:<Og23RYF<S9BAQgUlQXVHUh1fV[V<PYF7V::D
S92M]:bARIS8`YNB//ZjPIjnW8fGYYJDY9A]N::RPH21PGabQ95nM9>=J7^3LW9d
LfQLKW5CH7UKD6YlMeiKO6IJL7EhKGAgG3i:MhMjN7Q/IH2:R7a`QHR>WW5?PkVG
Ef=fHfYnP8n7NXRSZInXYH^<ZK6LTJ6QW96:[<Jg]J^>QYFZ/if6Q8bGRiNd/j6H
VZZKNGMcLi6IS75FF8BHJTISRW1XNGaNDfaTD5QaIFAUFEiSNh1ZJ6=EK81dK8VR
X;B]Mg6BZ[F<PKJ_V9VIWZFYV8>BdN:nXYBW^;[9]9BLXJ6V[KffZk2LO7J1SX1P
K8amIG=dFVIlMgIhIUiL?DQOE4MCCD]:?VQVBEiUJ6mVJF1;EWAYLHeWFFUgKeQQ
MgaSFVQ^HG=eI721T8iOHiB^W8R9TXinSiNLU79`Vl2jTg]dO8RI]KnSUYMoOZ6U
RW9ZQHAOJHb@Ng9^BEA`LW=jGSmVPGAZQGQ@IgQYOGQiN75aM7EdRIB@RhjPUWel
S9^NRfU_V9E_M9:FRh^CSXb0QYjPTXf[Z71gVIBP]]7:U7NL/9><W[2/UjVXWYNV
`[BP`<BKT9nYXh^6P7>EPeUZHe9EKHF2JEE?>D=BF5M9CTm>G4=4KV]<AfZCOUIT
MG>@Ufi]NWIaPjJEFWBLPFYjQgaLGWA_M89nJ69`JVM]JEM<Cf>KZ7eYOHa[MIF2
PH6<Vi^@R8V7TjB/[K2SSIJQWYjY`[VUZJNFS8FD/Z2NYHf0TX22QWj@QWF2NUaR
MYN>PXb0JeeWPGiePhU`If^<S5QRMg1ONk6/LEMnUHj^[HQoX/JTPhnM^=OG^Y67
Vj6]/jNCVkNj_k:@S9Nab;VTXJV`UHZ?V8mlTZ^LOXJJTHbSZhEQJ6mQD5eYEcI1
ABQ6IdQ6BDUQGFYXD3HhI89jQ7mCAVaaFUURLf@f>766L5aePVe^O7b2UifFPHBJ
SXR9TIJI/ZnP[IjESXVNWjFO[ZV=SI6AQIZgWXR4SY61VJZ3MY1kK6idLG68Sgml
KfaeP6aDHFa^NH1aDEigNeabXHadMgAXKYnjWhF4RGQ_LXZDSX]VEGAeNg9^OGYe
Q81lLVj<VYji_YVI[:^HX;G0YIN//YmmVknYYKF[VGUUP9ZI[;ZIIeeXIEieKUEL
LGafHDXj=F9nC2M5LEP^@f1QEU1LIUUJJ6e]Lh:=VYj3L7j2MH>Y_KV;G72>U8bF
NGbKV91YIInQK6MeKfN1T8b6TK>SX;>[XXf6Y/k2VHVI/J^QVGYi[=6lO6YmUZna
WWiaOY:?T9^ET9BLUi9nHV1mQ7B<QddoIWnDRgemPY=eAe1gRh1XIH5mPHAYMHR5
NhjIQ7]nLVQlQ71aIT9JMFMHJI>8NgI[LGbHVHb5P8J>[kVPYkN_Ujk4/Z^VWi^[
^ZbINgJGSGn<QWekOXZ9NGe`EUMNJGaXATaB=41EGE]5=Bi9KVM5A4iEKVeOLG5`
SIJ:PhN4KFe`O8f8S9J1KgI`HWNKSW^4PVIBG6^7NV9gS8U_LW=mUYF2R9n/VHb@
QJ2b/JEiKGf7RHZ1TIjHQWV<THNM/IQjOX:?UHZ=R6]XPWMUJfUDGgEYGg>7LE]R
MW5VNYFNSWf3RXbOWHF6S923NhJFTY2=LG^LSXJ8MiBVVInRSY6/_l?1];>c]/C<
dLnl^kf_^/Fk[::<XlK5a:N8SJFVRHZNU8JATINCUi1iM7nJP5UFGUQSKea3?dM3
?ce<GV]ZJg=`Gfj=QWQiNhBATH1kSHi`HgE/JeiFGEe]NfiVL79QDU=]T:2PQgf>
VZ:BQ9>0LXF6OgZATfabPh:9VgI;FgBAXHAVLhNMV8V@WZfXWK>YQWj=TX=oQWQP
EVQhKf5KJ7UmNX9YIX5hO8RCW8f3OgE^Mi27HeU/NG1XK5]=IgafIEYML8N9TiNA
Xk2QVjNTX:W0bZJW/JbYVJ:SQh^`/IRPYjNWXjnYXZ^Y[jZ[_K>e/ZfVYZ^GPWYc
Oge[Dd8n?dHo>3Pf=d=FGE]YGDM@NXQgHemfNfI_QGM]JfafNG9QE59:@dAAEeeJ
AU20UX1WK7b3OXB?PWYjPi:DRHEoPXfDWIR4PY6>PXf?NX6GXY^QXij[/jjLUiBV
^J^SYY>7WJZ?Mg1eMg]fKhb?LF5MFWFBRW=RKgZA]Z>2KgnARHQkJV5aLeMAF6QN
B4aML6eLDemYRK6=HW>:[k2a^IJ=Y/JmYi^SZ92R[9B:S9B5S9fOVhB<W9>AUiB<
TZfbX:ZRUYfWW8jER75IFfmVED@o>40o<S@S6c9>DSl`;2YIR7Y=A4i9EWnDOEI@
JF=DETDj?EAWHVAUJUmNL9>TRgImT9fKUJ_5[k?4`ZjEVJBc/;RkUH6=W:6/^jZI
UjFk`K2RX[_<akjeZ9ZS/;R_XYR8WZ^LPGR4OHNZZ7m]Ph=mTJ:KSI^MR8JPX7UQ
HFY`MGiJG7iiGDeeR6YUKgehE6:8T8R;U9JEZ[:VX9>LYJNZ[[2NWZJITIF?V:ZM
RXNOZjR^X9BBXj23PX>:VjBJWZNETI^HQVA]RHb@MEm>?f=kJ4e:Ee5HESXbBEmW
If1OJ6QNIWAiQ9jBMF]QJWZ<OeYTIf]eFeU_NW1XMWQMF6ERKg]cL5mPOGmdLVMT
Mhn9OX1nMWInOGZ?VWYhT9RGWkJTPiZl`;NhZYZbb[RNUi>>Qgj6RgE_Q8M/FFEn
PGMmQH5gMhB@S9>AS9RBOWbBTGaWLH=gL7=RCUIHEF9QH6EUGUmcPgadP8>0T8jA
TiRd[9BBW9B0R9B8T[BaViF8S9nc/:Z]ViBFX:nhYiN[^ZbHVZ^ZUWn<TheoKg]h
M7QYH6EG@deVLVUIIX6;RHM`E61]OH=dJFYZFT8j?Cdf?D0`>dY6?4ESOGITHeMF
KfiKHg=fJ6InQgIPHVa^KfagMEQEJ82DVY5oQ9ZHPHba]K;0/JNX[KVa[l3Fb[:_
Y9BCWJ6GZ:B1P8J3TYEnPhj>Thf=T8FDUHAkK6I/IE]OFf5/JfUiMUMAHUe>F7>1
MV][NXVDQgn@S7n6X;:`ZI:=Xl;0Y9::TJNc[:^UZ[jk][Nn]YnNYjVh`Kfn[i^U
]k6UUY2;MVj3LV=hOg1SIfi]HUaRIFUhMW9jSHicKh69V:F;MX>5NGeoNW=[I6QR
EeYQFTeAG6=WFTeLGDeBJ6aHDfUREV5WHf1UI61ZKVeZI7^6Lg9fPXF;V8]eP8V0
Tj:KSYBKVj2UYZ>QX:FUVY6IXJNUTY:RWXfFYjRLUjR_YIjQZ:NMYk2BOXBBZ9mm
M8>2QHAmLVIZNHIYL9B4NI2FPgJ6R79fOh66PgMoVI:4N6QlSg1OLGelOH^:T:fg
VhnKXjJf`[>T]Kj`WZ:YWYB:UhajQGe]OhYlL5];BEU]HU1IGdeAM8EjG5=^KfIj
RH]nLgUnOhF6RHN7OgecI6]iOFaXMfaPJ5]AFEeSHUMAAd]CD51ECDe<?T]LAdQR
L7amNg^7UXemPhN@VI>:T9FBUZ:_/ZZFOGfTZj2IVifOW8nDVY^MW9V?PGYnUYZ:
Q9:YYY5lMI6LRi2@MX>MRGZ7TYJ?OgYcLGn3Qi:ITW5WQHimOhIlM7EeQINLUGYU
MhF2Kf=nT8imMhfPVH>2TZ2UWibDXK6QSIne^:bGX;ZiZ9>AUH>3SX]oLgF3Nf]X
IfY^NHE`EDe]ThaTG79kMWIiOGMoUJNGOW]fKFmmLVn7Q79^L7R3THA^Kgj5PGMa
L6EZNGecJFUSHVa[DTYRIEiLHF=AF6aSGEmZNX:;Q6U[NXNJUgYfT8efLGZ4O7Z1
KG1jLW9cJVUiLFMePhJ5RY2MW9:>VjFIV:b^YZZNVIbAU:6NVI^DV:N^Yi:4R9ZK
SHjCXJZ/X9>SZInQXY^JWiUhMHfCUJ2STi6CTh]nPH1iQ92>ThUeOhfBW9f4MXfH
QX>8Mfi_NgUYIVaaK69LJ6IHHVQ[NX68R7F4XIf?T8jCVX^7UIJ4NXZHQgj0PW9h
Uj6EOWQfLWIhMgUhNh1hK7>;PficOgUZFeM/Q81]IFY/FTYCIFY/K5U2E7N1JD8k
DV=TJGY[CF1eJfQiQ7mZHVn4NfAMKgj9OFY^N8ZGShN5QXbEW9ZOYj>NV:>j`L:`
RGZQ]ZJGTI^NTYRMQhj^VIFER8fBWJRUV9>:PHBCVIVESIVQYJ2FUhZ?ZZRHU:>d
YHV>YZRNVj>f`[NPVIfBS8nBR7QiO8R8O7]^HWJ3M69DEfYmQ6m[Ng^1QXREXYZD
Xi5iQY6DTWe[Lh^BPG=]QGiLH71^H5MQHUQKGEUKNHI]EE9^NgEeKVajQ89hLG9h
M75aNhN5PGM^MGZ4RgikQHZ6PGQ[M7imMG=YFf=WM6eMF5EQL6e>AUm_L6USHEME
G6I^Ge]ZJg1_LW=[LW1YKX2IS79gR8j:QXZ4PY6PZJNTXjFSWijh^ZNOW;SA^JBc
a<WEc:REW/3>_ZBVZi^BUJ^/V9F>P7^C/:N<QHnCPGN0QWm`Mh1gHeEFE5UVET0b
<DIKGeUAG6A/OGUcLVmjTI67MfacOWiiNginPG]gMg5]N8:4RH9fMhV@Ng^BThn@
UijBSinSSiFl/8eiO9BMY9V5OW5iQ86:QgUcRIf<QI>JUH60SIVGPGMaJ6MPF5iK
EemND4=6F5QLH6ARI6=FFW:2OhJ<QHF?R7akRXf:X9QfO8ijKhB;ThijQHAiRjje
ThNEV8bD[JjXZZ^X/kVj]jjUYZZXYZZ`[k2WZ[B/[knfVY:S]KVaWHf@[JV9TY>=
T89kPHR7KEiPHF5NEEACBUiiL5aaOgQaOI61MH5kMHbCR81mPH:6RH1oQH=aJ6I`
Lfj6T7]YKH1nKW9mO7QoP75XL7EfOh5mM6idKf=YFUYkO5Y=Ig1aOh5jPIJXWH=e
RJ>TYZ:JTi>ATIbMShJ5LfAfO6AEFfQQFfaZEeYYJVYcLF=RKg=KBf9dJ6miLWYc
IFAPH6U`JG5eKg1ULXn2KWV9RY:>OXbMY;6eYj6_[ZBQX;C?d[Z]`/[4alRo_/>o
[ij^c<2b`MKF]9BS]Z:LYjFFR8^:N6]VIVETHddoD5aTIUABEV5`H4MKNgM_NG9X
IV1WJ61WLV5AH7EZEUeVH69/IVagK5aXPhUmNX26PhB@VY26UJBBKH2LS7UiRH=m
R7Y/M7^0O7UbJgB6U8UcLX:=RhN;SHZ:RGikNgZ2PWibFdaDIWAeIUIJK7AjKFM`
IeaVLFQGJGYXNHMbGeAWKUeNJG9[GV9aN7EoM6IbMh27RI26M8Z`/YRAWjNS[;6O
X:jc[9nPZZ^NSi6IYZjNW;Fo/Z:S[K>c^<:^Y;foZJ:X/K2UXY9jOHZ6PWUhP7Qd
MVinW9AmMhFHU92>Qh>>WX]lQ7n1MfQ/LG=cL71aI5IFGVURDEQYM7IgL769S9V[
VXN0S8ieKGJ0QX>1Nh1oIV5kPg1^NWUbPY2:Qj6gXhB;[;jbZk2XVYjLS8N4SY1n
L6mfNh25Mg5eMgUjR8ioPXb;SHVBWiJ?QG9fOGAVGEAACTI3@3Lb?TPi?EEE@dMX
NVAIHWF4SYJFTH^GW9VKV9JEW[>XTIRRS8>IYJVW[kZb/[Njbm[CaL3:dlFk_lK2
]JNGSiZ=PG]^KW]gJg5`H5Y[NG]]JgMeOWelQ8:<TYB1JfUWJFUREUQPET]EF4Dn
Ce=?H6=IGVYbLh>@Shf:UInKU8VDY9V<SHf@Qg]eKW9nRH=bJhNXVHJ=RYbbXjB`
Y9^N[K2OSi:7N7imPH5aLFiXIf1IH6I9BVafKFM`L7B8RXV1OYVFNWIfJf=TKfY@
AeMXGD0fBEYBCTa;FV1SKg5mPWioR96CUijQXZ2SZ:^YVhR6Qh:4Q92JRW1YKWR4
RXB7ShN5RHZQ/Z:MZJFLXJJHTIVLRWn@QWN9TIVPUi:ASI>GT8AdN8ZFVhjAV86<
WI26R8f?Rh65QG=`MW9QCeALFVQXJH1gKGMhMX>3N7Z7S8N6SXZ1N7F1OVQYK6E/
KeeGHFINKgQIFGB7Ti>6Rhn=U9nRVI6MW9bSTWEgU:RTSWalNG5bJfAcQYZMQX::
T9n]YYVKWiN:QhZ>XJV;IVIWIfI>B5MPDdUEEcPcDFEWLGQcJ6^6TWUTN9jTX:F6
NIFSUH:3T920KVUfQ7]fPHV;R8^;UInEVJZ_/KJPRi:M[;RZYkRcW92EZJbZ]:BK
[JRX/jbHVJBQY:VKPhVHRGQiPh1eMfmPFfU_HUiQFdPj>DQTN6m@@E1VIVAlR7]Z
Ih6IU8N;QFi`OWETKHJ=PWUnU9IoPYnYV8J7VK6eVhZP/::OW9BEY:nOSXnDRGj:
T7a[Ig5hKgR3LUi_THMjNG=nQH>:Q79dPGj7UhmlNGMVFFQcH5URE4iTLW=OBeUd
M6m/JG^>MVF:UXF1P7Z1T8b0T:ZQS8b;Q9>LS8N<TiVUZiJ6TIBBYJ64NgYnQh^<
TXn5PX28QXJ?SX>:WJNe[iFGVZ_<bK6NY:FOZ9b6QI>FRH67QViSM85nQ8=^HF1V
L7IkOH:0N7IkRY1gJGV1NWEdKV5JLg]aKfe]LG5SJWagOh=bLH:HTh5oPHjCV9Z5
NWQcLGV3OGEoRXj4KW63RI2JVXEZKXJ?P7V4RhUfK71`NGadK6i_Qij5IF=dMWAh
NGilO81nQ8n@PW=cLf5ON7QjPEi:IGQVCTaMJ7EeGEYULX60LfMeOgQkNGJ0VJBL
UXAkOh5eL7QiK6=NIganJ6j6PWmjMWj:V9nZa<k4^jn_^k^f/k>^ZZBLRgAgS8V8
ThYdIVUePi6LRFn3THEfLh66SYF=LfUXEUQ[L7AgJEiSIeUKJf][M7f2M79nPHRH
V92BRhjJTIfUWJ6FQXR6J5Q^Qh^0Qhn:Qh67Q7V8Z[FWShJGY;;0[YFASHf<PH64
MVYaL7=nMf=OIf5ZNFm]O8IgL8:@TX=cLgn2Lg=bGff>RW5WIFQVI69CE5iSKfm[
LXB4R8Q`M8:5R8J@XJZIQ7^0V95_JhB9LWZ=Qh1fLWn9QgefOib[/;V`XZ^h][F_
[KNg/jfOTHN;UinRVI2@RGU]M8^@RHf6MH6BQgQiSI^CUIAnNX1lQHUlJ5aYOWYS
EfEnPWn0L65mUH^5PX><UInW/JnOVIn[Z9R;OG5/JFEPLH1oNGM`FEibNgj>Uh]k
Ni6OX9^FY[2ZXY64S9>7QY>@PGacJF]mNfURLG]jP8n>OXJNX9FDUY69S9^IRH26
UH]bKWZ0MVMNHWMmLVa[JFQfN6IHFg67VYJ5OGioP8F5N71hKV1WKW=eNgM_Kf5I
GVYoTYfBRi^LX:RY[K2h]JVZYIjU/KJ`[JRPWYN8NWJ1RH^7Qhj:Q7eiSYB7OGEc
MhF1Jg6=UX=iL5aEDe1AGFMZH4`nAU1>Df9TIFUVJWJ6T8f:RXR0KfEVKGEjLg=i
N6iVKWYiLg5XKhZ8N7EhSIZHVIREUZJ[Wi>@XI^5N79dMgE]K71[Ge=EGf1KIG5Y
GUiTL7b1M6aeOX60PWmlQ8YoJV9NCeQ]KFIMHg1cJeULI61VLGUmN7V;VYjDQW]i
PH5nP82<TY::OWYhOWAUJgZG[9^AVJ6h`kZd^/?2_KF`//CA`kZaYJJZ[ZFDVj:A
MgB0P7n2NWAoO75]LH6BR79fOhVAQgemNGAhNgelOXJ1OX:0P8^EPgAnTjR^W96O
X9bZYHj3QWijOgYcM7f5PWQYFEQ`OgQgPX^3P8N<SXjKX9:CXIjFW9bHYZJIWZ>G
QhJ=TiJ6O7]lN7=[K7f4PGmeJGF4Q7ioRXF;YZV<O8J:RXb6Q8VFWXI`LGYhG5EI
FVAYIUeNPinBQXN:PGAfQhf8S8F4VIN1K6U^LW]bI6YfO6m]NXN?RXZ2OhN:VJNO
VJ6_]Jfb[YVP^;bWVI^MXZR/ZjFFTHimMG1XKGihJg5fPhj1LgZ:QGn0NgZ0RHYf
IVYZGeANKf]KFfUUHgJ2M6EZIVEaLWUiLV]ZMh>:RH5jMWEdMgUhOXMoKVefQ8V<
Si>QWhIeO96KVZF`X9FDSXJ6RWifMWA^I5eGFfMPFF1[J5YJI7b@Thb4Ogn3MgZ?
Rh:6RXYmK6]bJeeKCTA<BCXi@deFDdI5EEiKDe]jOGIoOXNBU9J;P8JAS7mnNWZ9
U8n:Rh:4WZ:CTiFCVjB]]KJ]VYNU];bbZjVOY:f_ZYfEShJ8PgEcOXAlQY:;PG]o
Q8B5SiFCT7]_Pi:=SH]gJFa`NW9QGV1aPGmoOW]gOHb?Pg]nP8JAVYFAUiF>QH2?
UXV2QX:3X:ZBP827RH>7RhZCVY^KUYBK[JnRW9RETHb6QGi^K6YUI6AZGe=IGEa/
PGmgMWZ9VIZ=Rij//JjHSjNh/:NKS7ikQ7eRFF=TH6edI5AQJ6I/HEAJGfeoQhR6
RHN6P7b5PWajMG=mPh1nOG5_R9^AOWfBW:>TTHbZ_;Fa/:j^YZjiXhnFZJRPWIBB
T8bFTGmTHHVIQhB7Q8R>Qh>FTX>7R96>Q8^6N6]XM7IXEe=GGFadIfIZIg9gHeYT
LG=_N7alO6m/O8=cH61bNW1ZIEiUKFe^KFa[JW=nNWZ=S823T9V@RHJ7SY:BSHV;
QGQcMWedHfYjLf]SFG6<RHF8R7mmQHV;UI^IWj6CRX^=TYRBP7MoQ7Y[JgV4Q79P
Ff5ZJ65TIVYbLF]WJVm]NhjDRWQjPh5eL7b2Qh^4OgR2VI^IVHZ8WJVSUiZX^L>g
/jZDWkG1`KbhZZ2MU8n@ShN8UIBCWZ6OX9><UIZLV9B;SJVe[Z6GTXb=R7mlN7Ql
LfYTIW1_HeaMFUUXIeYEFFYhP7aWHG>8SXV2MW=iSIB6Qh^DUhb?RH5kMG]nRHb7
RX:2SiFFRHJIYIR<ShjCW8UiMfeYJF1MHFafMG1^MGU`HfYoT9fXX8^AVXfBX:^Z
WIAoL7R3PGM`KFaZJFm_KFm[JfUHGVUUKFe]LVmcMgU_HE]EI7IgKF5YMWI^HfM`
Kfj0RgmkPXV:S96>RI6IU8^;SYFEUI:3OXZ4NW]gMX26P7IYHfUoUiJ4OHfNWYfL
XZBNWINCWZbUQWUnNWAiPgUbN6iTM7Y_LWQeLG5^JX2<OganPX=nP8fDRHB:Q7b9
Vi9lOXZ3OWn9WIV5P8nMT8F4RibMUiBCTh]oOHRASWm_IF5MF61WJ6ENGEeSL6mX
KHB>QHVBU9NRZjn_Zin@T96BVY^LY::CQh^<PG9XKH>@O5]GI6I_NfmKGfedKV9G
DeINHDi0@D]WIDi=D69aIVAXKGj5PhV@TiBDS8nPZ:>S/kfg[9F3R8Z7TiJAThf2
P8NBShf=SibQV9Vf_:Rgc/:[Yk6a[j^PUYJMVHnDUHf@Sh=lOXJ<RXj;N7V7S8f@
U8^3RHUkKGB0Ph1cNHAmO8J7OX29Pg]kKVR8W9B;R8B4V9f6OHJCV9RLV8UfLgE`
N7M[IFb1SHf2NgamOXVJU8J9SYBLWYZEThV5Ri6IV8I`Mhf3MFmYL824NW=cO8F3
NWQfMh:5OgUmPX9oMW=XEe]cQGUOFV5QJ6QIFVaWI7^8RXF9U8n7QiN[YiFDUiRV
]:jKU9>EUYBCR8nRVXMjN7YhNWj1PWn1SIF>QX:4TIfCQ8NCUI:HV9FCRH1nPHJ0
QY>9OgieK6abJEe_Og=[KVQTKgUeKFimQ89bGe]VMgefIV1WKGI_HVakN6AFF65Z
M7MgM7R3MVETHF9[JUiLFUILI61PGUELK7E`IE]JKXB3OHF>TH]jL7R=TXUoNh>:
THb3PX>>SGEeQ8MnLG>5TiB>SHV9SIJKTi2PXi64PhJ<VI9cIgV4M6QTIWb<QWE`
MWYdJVYcNgj7QGMkSI::Q822RHAiMGV0P8B@Sh1dLWF0QWb0SiFHVInRVI>P]jjK
X:nbZZ>OXZb`Zj:OU8Z;TX^7UI:9QhNDT862PhN5NW1XMH1jPHR1P8N:Oh6;SI6:
OGn;Sh:3TXn6R8QiMGmmQifNU8nEUHIiOXf?Q7M`MX65QH5kMW^;SGahPH>9ViAg
NI>HQH>9RY:OZ9f?Sh^:SIbRUjF^Vi>GSGf6WZ2CRH=nRI26Ogn1QXf?RhJ7R8In
MgYmNg]_IfUlS8^;SI6;SI27QH^?QhfJS86;PWYkOH5iKg1eLFUbOGUdKF9PIVQC
BEaSL7meHV1[O7e/JG5mPXb?NgQmNgn5R8>9R7YbNhN6OWQoTY^EPWYlPHfAVYn>
Qi:KXZNRUhj5Uj6BT9VPXJ:ORWn;SXIlL7:3TIFBQgj7PGV3PWUcMWIZHVASIVQO
FF=[JF]aKV5TP9J@NgMiNhZAS7]_LWj:PFmUK7b5QW]hO7ekO7mmM6ekQH1oOWed
LginLVY/LVi`NWMcLV]WHEYLHF9PI7QkLg5WJGEmPWM/LhBCUiNFViZ?SHZ;U9:A
RGUhM6efQh9lNF5FJgYdMGUeMGAfLgZ:PVMWL6mjOgE/Ig62QGacLgUnOgahQIfJ
V:NRUiVIUIBU[JFOVIbNTY:PXiVCUIbSYInFUIn]][FIQ96IShbGVinWXYR?T9JE
UYbNUXV7UinGU8j7S9BCUIVDS9NTWY>4S:BPRW=aQiJFQW9`NgY_IfIaOH5mL6ml
NfmZK7F1R8N1QHYoMgMaMXJ9NFmcN8N<N6EUKW9[If]XJFeUJh:=OVY`OX>3P8N9
RYVIRHRCVY68S9FPWH5fPHV?P71gQ8EbIVARLX:0NX29SI:;Q8J=X:6BTi>DWInF
SI6GSG]dLVa/LFMHGfMMEEAECDA=DeENHUMJKGAcM6i/NWE[Lg=jOWb4R8b7NW]k
NX68SXMkOhR>TiVFT96ATIRKSgekOG]mNgMgMgN1QWecNHbIVY6?WZjeZijOYJZ[
Y:>PVIjV[:F?RiBBSI2CSXR4PWUdMVY]Pgi/Ig21OW9bKg1gN6mcPHB4OGIcLW^8
Qh1oP7]gNhRAQ7MlQi2BTI2@SH9nPXR?UYbJQGYmOhAoMWQgLfUWIeiVN7ihMX69
PWE_PIJ>OWf4Qh1nOh>BSh>2NVmRGVAQI7N4O6aYK6aaN7UiNFmVKgI/K7=kPHB4
PXJ7PXZ:QiFPW9ZKSGM/MHF=SXMeKG^4QXZ6PX67ThYmQHZ7S8j7O7R2QX=jJWJ<
SHR=TXZ8T9:AU9>EWZ>NVj^j]k>a[;6i/JJZYibLZ;Bd]JnNVifKV9NIW9jRZ:FJ
WjNPUY>BU8j8Q7j3Pg]gL7=mOh64Q8:6UYZ:QXf?THZ1Ph63U:BCL69YN860MF5K
IG1fKV9PHeiHFEaKIVYSHEaMJGMjKV9SK7EoOWEhP7idKW5hM6]`Oga]L7MgLfY`
MW1_M7YkMgb7Ofm/LXNDOFU^P8EnQX5^M824Q7Y/JgV0MfU^NH68OgAhPHF3NVQY
LfaZK6UUH65UJfUIDV=oR7YjPH2;SXQoJVb3QGUcM86=RH:2RH^AWIZ:QYR/]kFU
UXj?UINHTi6HU9>HRG]hMGZ7QFmVKg5XIg=kMW1YJWMeKV]VM8ZDQg]oNGUnOX:5
RhZ1NGMlP8B0O85oNGa_G65`PXn9R8=jO8:1OhbKTh65TIB=RIR[/:FGWijLXiV>
S8fFWiZ5NhJ9PXbPXHj:Rg]dP8N6PX>7RHN5QHB9Si:IWiZLWYVJW9bNVHj1OhN<
S8^AW9J:PgUoTYB?UYbGR8>9S8elKWV4QWefOXR@T8MgNHJ0MWUoO7N0PXB;R7Uf
OWf0OG5XJ6ibMgAePXR6MfUZMWb1RX5hP8N;Qh26Shf5NgZ2Q89lOGiaKWimLVma
NHB?Y:nVV9^[/[2e]jj^[:2LX::OV9ZGR85oOX:1QX9kO8J4Lg5eLWj5Oh>=RhEg
L7Z6UYjCQgn1SYVHQX24O7n4NgUfMW]kNGR0QGYfP8EoP8MmLg=hNW1aPGmoPh>4
Og5XLHN=PWn3NW9fNWYiPhUnMWA]KfaPH6IZKVQJEEIEDdm>C51CDE9AGfmbN7n1
NWYoOW]kNgUfO8Z8OX65Ogn;THjCUIBFTXf?UZ2QT8B8S8IoOGj2Ph62QhZ4O8JA
SHN:TiRFTGm/KGYkLG9jMgMmOW9cSIRGSgmnPhRDTY6KUXV:TX=SGfYQEem^LFYZ
LW9fNgQgNhR?R7iiOHbMWIF;RiJ>OGn5QXb9OGUdLgYoNgEeLgN5Qh5eMX64P79Z
Mg]`LgMXH6U^K6]UH65UKg1ZMWa[GVM^I69]KW22TXb1S9J@TIbU[KBaY9^GTiNJ
TX1mS8UnOhZDShV>Rh>5TI67R8b?UiRBTiRMU8R7SIVGS8b?RXnNXIjOWijLViNJ
YJ6NZZZMTi>OWYVLVijMUI:CTX^5RHj7PXjBT8^7QY2SZZBPWjBYYiZ@UI^DUZ6O
UHZ<RXR:SY:4OXF6OWAdOgm`L7AYJ7UoMFYdRXA^IFUaLViZJG9hMVm`HDmKIfQU
Jg]jKF5QLGf5Q7UiP85lMWMlP81nO7b1PGekNh22PgelOGj6PGUkPhJ9ThikO860
Ogn6QhV?R81oN7=iP7mcKFe[KGUgLGf:RGYcN7YmOGj2PX=lOge`LG]nQ9JOV9BE
THNDY::UYJBRWijERHB5QXF;Q7=]KVYWKGUeKgUoM6Q/MgIcKfeaK6Y^KFeaNW5/
MW9/LW=dOGQaMH68Ph=kKfY[L6i/JfYZH5YWLWMkNGI^K6UXKFacS9R=QHV:Oh2H
X9JCUYjMQX>9PGb1Q7YgPWmkPXV:SY>:Qh^:QhF4Rhf7RYNUW92CUIjYZi^8RXn<
RhJ3P8J8Q8UnMHVDSHN?U8V8UZ2HQhR=S8>1Ph>2PWiaKWIiKG21RhAkO7mnO8VJ
U8V4PHjCU925QHF?VHYhMWalOXJ2OH:8Q7QdMWAeKfaeLF9KI6]XJF]/IEaEEV=Y
K71[JW5cNWY`N8JLZZ>OXJ6U[k^/UYn_/Z^RWibFVj:OUXMmOh61QXj?SIBBQWn0
TI20R96<RXN5PHV=R8jES8RBWIV9QH:3Ph5jKfY^OXf;RXj3OHZAR85nN7=iQHIl
NWUeMgU`KG1hO7IbLg=hOGU_MX9mMgMaLgaoNgEmQX20PXF5NG^2MfIKGVU[HEED
IW1PCTQBGV9WJF9GHW=bJ5eEH7R6PG^5UIF?Shj?TY:LWYVNZ;6i]ZZ][:RTXJ>R
XZRe^k>SXJ^[YInJUYFBTIF?RH22THMhNH>>Ti>9PhnPWXj9RXjBW:6CQWn2PWQm
OWYhLg5fN7f7QWn6RGikPXJ3OXNFTXR1OWYoSI1oMh28QgmkMg5^M7EhNGAaMW]f
KVakNgMgM6QGF69aLVYKFF5QHfMTJg9_IEUSKfeQFVIfMF5KJW1_LGEhNXRITGid
MGj6SINCTYNBS8ZBUiRIUHf4QINLV9NMYjBNTHN6RXYnNH:8S9F<P8NCVYNAUIZQ
VhjHYJFSWJ6HQ7j4RHV=SY6ARhV;QX60PGikQ8V7QWa_LgamOH63MF]hQ8J3P865
RHj8OgMfLW9gOGebK7R>W[:lYH9fL6U^NgMbMG=]GV1SDdmKK5a9CV9RC4A<FfUL
CEEHCTMIMW=MI7bAX[6oZYFjjO7I]9ZK_=6eTJ2lZH=^PZ_:d<:i][F/Y9ElHeUS
L7=VJHNV[8eF?g2NU6i2@F1oQgARF4@X7BDZ9A`G82<F4AhfB4LoAE1>CDU3@EI[
MHfMWi23S8b5QH^FYk;8f=3Fi>W[j>?^ooobi=gRk?3VdmSOemGEdm;AdM7>e=_B
`kVob<g>e=7>bKBYVHN:UJ2TY9nBR8IlJ5M;CdXn=CQ4DUiLJgegLUiJL6IGCBl_
AD]QCblZ@eeB>SeIGDe9ETlg?di4<dII?2M1DT0f=3<d;cUAFV=B?DA6>S<m@T54
<2hm;B<Z8R8_>C8T7B<a>34X;UAWI6idK6ANJ868R8B2UYV9PYJ[XY6JWYBHXZRJ
Si^/Z[:j]kFXZ;:^YYNQ/Kc3c^;UdlS=d=SFg__okMg/ooomj__lm?Gcf=7=`][K
a[^a/[G5dmoOb/:f^/_?c]_QfMgYooojiMkTj^OPe<G0bmO>`ko4b<2o^;^f[Z^X
[[BQPGfEWIJBU9RIR7=`L6MQFdmHGeUVJU]8?BlV9RHO9RXJ40PB71HH4a<O<dLm
:BXb:ALF6QXL3P0>60/0000000/J4P0782@O8ahI40hC6Rdi9a4M:3ICDTA5Ce1>
GF=MEU1GBSToAd]7C4]>F5<m>3]8Cclf?dQ9Cdm?IgQhMgInP8:CV9R_bL?0dn_n
nNkUi=cQooooooooooooooooj=__nOC]l?oom??lo_oolMOBfO7om/Fii?oek^GE
^:6P]<>m];2la[jk^K^o/k35bkRb[:BXYj>LTif_ZI^GQX:?RgEHEf]fMFEEBdaP
Kea@CTI4@d5;B49:@DADCU1GE4Q1B4Xj<SY7CDe>CcdoA3Q1AD11BEMA@3D]8BDZ
7bH^;S4]8Q/X;20P:RhW8R@i@R/K:SXj@UEXIE]YNgUjPHfDX:BQ[:>IV[C1/;:c
Z:^ZZjjTYKVfZJJVY:>SV8nCUI6GSginQXj@Uj>][JBbalo4`loFf]?AenOkmn_W
hn3RjN7Pj_;Zen7/g]gCaKk>f<kAf=oPd/g=c<Rk_=3Ti]Nj];Vg^KJ_VWMdSYB1
NWEcNVi/MWUkOX^=K5aVMGYUFfU[Dcdl>SHc:2<I2A@a;@/01@@00P/>5Q/M9BLK
7b0S<3@Y82H_@ClW7RXX92/W7bXZ6aPB3Q4B82d_:BHZ:cQAA34f?dM9@3I6BSlj
=2lQ5Rm>BD12IXj4L6]kRIJ[_/S=alOHck^h/:6SYJBMTYBIVX=fOHV3J5IIPXmn
NXRLWiVQ[[Fi`L;1^K6ocmC6^l:j/k2^^lW5/;WLiMgJjOoooo_bmOCan?ocfm_U
g]G:_[Nm^ij1S:JYYjb/V9V^[ZVVW9VIWjNJW:bUVY^JUiNO/kfk[Z>U/[Bb_knk
YY>DW:^RVIJBTH^=Rh1cOI68L6EZJ5eAGVm`GdY2DF]]M8F@VYJ;Og5QE5E?C65X
F3loFW5aIg60L5eOI6URC3Q3Gf]WHE]JDe5VHF9bKVadNVmYKWImP7QaNH:>UHZ7
Nf=JFEiSJf=LGEAAFfIRFUm/Jf=SI6IPFEidNFMULGZ5QGamOgakPXN=VJFaYY>B
UYJGYKB_YZZ`a]KCc=;KgNS_mOoml>kYe/[<fMg7^jRIX9N7Tj6NWYnAPX^KZZZI
THJ7U9BET8MoQ9FEQWf5QGUfQYjRUIBCTI2CTHJ;SY2FVI=eJ6m`IEE4>DMEEe=;
ASdj?Ca2AT8b92Dg@2lZ;bdR5A<K;R`S;34d=CU3CD`g;cPl<2@V<Sha61DO;CDh
>3e?GVMTGfEmQVmCBTe?C3di@T4g6`XS?2lX;BlmDE]NIGJ3Qhf;S9BHRX:7PWYj
O8JBTi2>VZR^/kW1^JV_`]?Cb<S>a[^kc>CYgMWKcm7Fc<[FfL2/^/kLg<c5aL[@
blS?dmGGc/[Ai>kOdm?=^ZJ^^;6RT92HTHZO[9nPZ:2JV9NJX[Fn/j:FU9B>PX2=
VYfHWJ:IQhF7O7QnPgecLVm]KFEXKFIYJf1JFVA[GDTh;bHY=3Tf>3d`9BTf@T4f
<cTk@U5BBSPb>TAMJ6MWIg9eMX>;T9:FTXV:RXV8OWAVDD]:ADE3>CM3EUQFG5eG
BCm@I6mkP7MTDTaIHEe[Mg=_KW5gOWinQXnFY[2c_KjncN;[i=?>eM_A_;>od]WJ
gMWCc;o0a/BoaLg2`=;Db/oIcKfhc>GWh<jdX9R<RI>OY9NCVi>8OHFR_M3Da;^g
^lC0ZXV3RH5jNWb9V9^ESHfEZkZcZ::NZ[ReYYB3NhAnKGZP`<>ZThfJ/[jhZZBU
X9Z=MVUQGV=TH5iWN7edK6ERHV=/M6aMJgY/I5]9DV9_RjB/Zjfa[j:@QGacK5m?
BDQ@FEU;9a`a>SLfBeiJD3lb=Sa2>1l<10`B3`d?5R4[<CLmBeQNJGR8UYnGQg9U
HV1[RYf;MFmUEEi`O8fMVhEhOX:3RHEcIEaOHf5NGUeKEe5@DE=UPHQgKWZ4SHj5
NGf9R8b9Phf>Qh65Rhb@WZJSX9^:Q9BFSXN3QX^<TYZMWYV@PH6HYjBITIBFVI>;
RWQXK7b<V9RAThekMW]kN7=aMGEkQ8J>R7E^MgmoMfAMIgEdJFASJFUZO9>NX:Fa
am;@a/2kYHj?UY:9Qh>7S85gId8L6CeKGeM=?BLY?dmFBcha7a400a@V<c@g@UAZ
P8j@THaiK6ioTiV=P7n:WJfk_kjn^K_8c=CUin3D`:fPY[NfZYbARhV7OWMgOHV@
VInIWJ6JX:^VWjNd^kc5dm75`;o1_[>c][Rl_kRXZkk:bkjYYZZWY:bg]Z^LUXQd
Nhf:PY2SYZ2X/[2_[JFQXIjERh9mNH>HWijX]KN]ZkK6a[JWS7=TEU9EGVIVI5<k
>DaIDdY;CdiDHFIgUK2dZZZ_/[Fe]KJ_Whn;Q7eiKg1WC3e1DE]?@D94@STc>CX]
60/0000000`T=dU5>TUPIV9SGUIFFf1UJ6McPXVEYkBm`/CAh>KRcJnLUY:9PGMg
OgagM7j1KVM]MWQcLf]MDd8j?d]OMh^HWibT]Kji/[:f^K2W[[>c/JBX_LG0_LS?
dmWCal2iY8^0Ke5>KXZARhJ7PWE_MW]jO81oMfMIG79oNWMjSJk4d]G<^jfa]kNU
V9B7M6AGEfEiQhEgK6egN7=^JFUKBd50CfB7]Lg3[jRFNW1^I6IYJFmdLf][N7aj
LfieOGaaHE1;BDM:E5aAASlg@U9PJVm[J6]`KfUSG5]RHEIDG6IlV:fo_kB^[:FL
Y[BnalRn[Yf:PhnDSXjDW:2JSHB6SHj6MVALG5I9@TQJKWUgK6IXKgf6QHF1N71c
P8RCWZnk/ZRb`/S?dL>f^;Va[Jn_[9j>RhZ;S9BGSh^?TiVMUI:GS7MZIV]fPX^H
WiVFVIF<RHF7SHb<T9>>PhZGUhn8TjJe^:VKUYJGUHYmOhbJVY:I[<CJi>OSb:VG
OfmTFf5]M6eaPhR?U8QcFdY;Ce9>?C8d>SXl@DE=Bcd^<dUIHfQTEDYCIVYNG5U8
=SAAMX9jLgAeLFY/NGIRFf5YKFe_L6YJAdA>HGAiNGU`HDi4BE1BE5]TIV5NHFEX
K6iZJW5oSiBCTX^0N7UiMH6BWZ:KU8j2NWQdLWAiOG]oQX9iN8B=R828X:n[X9RA
RXfBTY>LYjN//j^NV9bSVXAoQXQoN7eoP8J5PhJ9SiFFThn8OGYkKFYkPXR=Rhf<
RGe_LWj<X;G8gNgbkmc6/XETGem[M7b6P8F?S85`Iei@C4M3@SL`=3]5Ad51B4mG
Ig^9QWihMGEjP8VKY:>Y[:Z//[6][[6e]JbUW9JHVj2VZ:^VWZ>^]:bGO5m:@DiO
I6UcN7^2R8b;RXjCTI6EVjF/ZJRa`<Fn^Ko<e/jk]KNaYibHVj2NTh^7R8V=U9>?
RHN9QGUaKVESIF9SKgUeLGf>TXb;Shf:RY>KTXR;U9bQVHf2N6m[IVQiP7]dL79[
IVU]LW=YFU1AGVi_HeEBCTmNJ71kOhF<Q8:@/MKUhLJTThJ2Qh1iLFQWKgjCXIn?
Le<g<C]6Bd@g;Bhd>3TnBD4d<cU?IWIiKFMVHFIfQI6FWjNX[KFmaLO;d/F`[;6c
_<c@akFXYj:HSXb:OW=ZIFEYK7AnPH>3P7anQHJ1OGf1SYfNVj:X/K_1b<_8cmWI
fMSNh=[;]j:9Mg5oWk:^WXb4OgMhQHR2NfiTHUeMIFEPH6E/M8:@V9J:OG5WJg9k
SYfOUXjDYJfUW9B?RhEmNWn7QgabHU=>F6UcM7IcIV5LCdE2?C]4C5=JIg^I/[W0
akFFPg5_NganR8V1PI:^`<6gYY5hI5aFBdA3?30^?UARGUQKIFUUHUiKEe58?ce2
D6N5W:NXYZN[[J>?P8>?UINR]<[Rkn2oXi21MVUTKgE[G5=<ATQIKGAYGEeJDTa;
C4U3>392GgjL/;BZV8^:SI2BTY:IYJf`[JZa^;V_WI>AT8j4JUULETeBG6I_Kfi/
HeQABSh_:C8mA4eGH6MYJFMSK7YoOXB4OH:@UiJ@S9>Q[KF^XJ>YWi25OGYoQXEo
Lfa/K6YZJV9GFfYcOXJ@X:JVZK:j[9:4PGijO85kMh>L^<O5_K2SV9>@QG1IBChf
?eIXL7=bJUaADUACCd/n;RL_AU=BEUi[OHbDWjFRUXIoPHZAV:F`[jFQZZj//[^j
ZiJAVYjAPWilNWI_KgMnPhZBT8EoOWYdLW9`LgZ1R8N6SIf^^l6n^kbk_[jcYInV
/;>f_/?3aLC2aL:aWi>>SXQnNWYlPXF2P8:1OGU`IUeIGFEWIFIYKg^:TiBFWjFU
WiZGUY>;QY2V];_0^JRMUhf0NGMbJF5NFeAHJGf8PgMZJFi]LW]lPHB2OgYnRY:B
THj6OX>BW9N;QX9iLFmcNXV@SI>IUI:<O75aLfm_MGYiLfmaLgIaIVMXHfE/MGUe
LVe]OiVYZZNOV9VGSX^:RXjBUIFGXJbb/:bRTXf@THn7OhB>TI6DUIRRYZ>QWiVA
RGmhNhB<V::UYZNXYYjETHn;RX^<SY>GWjR^[k:dZiEmJ5M;ATaBCdmHIFYUIg=f
JemB?c0_>D53B4mDHGJ=WjRWVH=ZGEiQHEiNJ79fOXZ@SH5gMGYlLfedN6eUIF]b
Mg]mNG9bNWmdHeeNIFa`NWm`HFI_J5QEGfQYIVM`OH9nMfiUIFegMfYRHfQ[JVY[
LGV0Qhb>S8N0Mf]UHV5[L71ePHnKXIfDShnASH1mQi>@PWAdPiRRViVW[jna/JnW
U7]/JVQMFFb<X::OX:BPVY^RV8R6RXf>T9NNXZ:RZKS5blc2/JRTWYNBTiFBU9NI
VYVKX::KSh^?Shj=QGn4RHIoNWR1SI:@PGQmPWaYGFIaLWImNW=[IfedM79eMWAd
L6Y/KVi/IfM[Kg1TF5eZK6AVKg=`KG5hMFm^Lh28Q8>?W:Rd^kJ`[JVVVHN1NGEn
R8f=QXF>WIjBR7ijMW=eLF]cPX5fIe]MHVE[L6eWJViWHF9YK6][IF5TJWJ4Rh^:
QhB4Qi2KX9ZAT92;S92?RGm`Jf][K75kQHJ0O7YmPhfDU9:BTiBGW:>]]K:[/K^n
]Zj/ZJBKThf1MWZ7TY>@TYRJU8f=U8enNG]jM6Y/O8F2NgMfN7QiPXAjKfa`L6YW
LXFBVIRASHnEWJ6OV8f<V:2JSXZ?V9jHSH5iMViTHfabKVMVJFQQFeaMF4e<FEeC
CEESJ6Q^NhAoLFQUIFQ_O89jKfieO822Q8V6OgemOGijMgIdKVEJEUeRHfM/JfMT
GEA@CDiADeYPGF1`OGU`M7n2Ng^3S9RUYj6ES8nEUY:>SHjATiB>PWn9SH=gLWN3
RHZ6P7f0Ph:0O7Z4T9FFVjB^][Fa/kS0alS6aL6k^;^n`;bk`<6n^kBb]K:YXj:P
WYbLWIbKXjRKR7ijMF]SIf]XIVaaJEiOLH^ES8B5Rhf=RhbASXR?V9NBSHjBT8El
NWMcKfUSHEiKEeQMGF9ZK6m^JfmaKFMUHV9]Mh:?UIZOVi2;T9:?SH^9RHR=VZ:J
Ti6AU9RMViFATXj2LF]gPG]/IFQZJFEOFU=6>cTmAEERIVaZJG1hPY:JViJBUIND
TI:EU92>S8Z:TIVIRWEZKGMlN79aM7b1OGQjOGafJ5U?D5iYJFIWKW9aNXbBSHjE
ViN6Mgf>T8R8SiVPXjJXY9^GUi69RHf?S8AoOhF;QWmnP7ilNgYiO7ikNGQgMgj;
UInTXj2PXZ2HTIBSZYnGUiJFU96>SI2?RH5kM6aZKFiYGUQMH5aEFFI]L79_K6ec
OH5lN7^0P7enR9BJWjFZZZFRZJnZXIjIUIB>RhZ6QX^?ShZ6QHZDV966Oh20Ng9X
H5I>CE=OH5MOKgA]JG1jOWYgOH5nNWYoOgQfP8J6RiBERGIaNGUeLW5fO7YfMG=_
KgEjN7=`L79dMgYnPhV=S8V8RI6MXj>NVi^LW9fLViZIVI^JUIRPXibCTIJIT7me
M7MhO8F<RHB7SHn=RHJ4OgM^I5mTLWn3PXJ<TIBETHn?TiVNX:2KTHf=QWmlOGn1
OWMdMGQfLWQlN7AdN826Q7eiN7=WFf1bOWikNgj0O7Z2PgUgNgefJfihNG=[JFii
PHN=SXZ3NVeWJFYXIfEVJfa[JFQ^LfiXIF=RH5eLFeUGF5iXLWZ3R8^;RhZ:RXJ3
Q8B2QHV8Ph5oNW9/KGMkMW5/J6QYI5eLIFebNGioQY>MWYVDUYRDSh^8SINKWIfK
VYjSYjJRXZN/Zj>KUiJKX9ZBU9fQXJ2OX:6W/KNf]kRf/JZRW9J9NW=eP8nMYjZV
XInV/[:ZYZBPWYnLV9JCTi68PX:7S8UjJEeHF5QFDU9CE5=DFf1QJ79gO7mlNWQi
O7moOW]lPXR9R8N8R85kNGYgLW=gOHJ=Shf<SHQjKfMSIVMUI6EXJVm`JF9PHfec
LVi[KGN4R8=lO8F=SHf<SYZSWI:>SI2CThn;R8N7PgihLg9aKVYRHFQWGUeTKW^5
QX>6Rhj=RHJ1LfU/Mh69Tj2[ZjNWZZj^ZYj=QhnGU92CWJFZ[[:b[:FOThR5OgUj
OGioOGanOWn8Si6ATI2?TI>DVZ6MU9>HWj>UZ:je]k:XWifLTXZ5PX61P7edKVe^
KFUTGeeJF5YMHf9OHVETIfaeOhB6R8b>SH^<RXB2Qh^5PH1oRIFHUYJHViRBT96A
Rgm`HemQI6IVI5eGEeUMH5eJEUIMHVAUHeeIGV9NGVE]N8B;S8AmPXfDThYmMFm/
K6UTIFY]KF]UIg1bJEaABd8l?dA:DeUIFVIgPXAoP8^BTI>DTY6FVj2QW9^SZk6e
];Bf]k6UVY6?T9>EThn:R8f>RXJ1PXJ5OgYiNWYhMG=dNX>:SYJRYjJUXj6T[[Nf
/[2^/;Jh]K:^ZJR/ZJBNV9VGT8AaIFUbMFeSHF5OGEaHEEUXLW9aLWV0PGadL6m_
KG1eOHV>SY6AS8Z=SX^:RHV7OG=^LWMgL6aaN7YmPX=hJ5eHF5QFDeAJHFUaMGb;
UYJASiFNXI^DUIZNVi:9QXV=SHj?RH>0OGilLFi_KfeYHUaIFEMGEe]VK6e/J6EW
KWEiNGAaLWR3T9ZOXZR/ZjV[[kFl^JbV[;6c];6[ZJFRWiVHV9B;QhV:RHZ9QWef
NX:1OgaiOhF5RYFNYJRYZZJKTi^UXiZGXJf_Yi^GV968QhN5Q81mO7=THVARG5A>
CU5EFV1TI5mKGV=WJ6]`Mh28QhB6QhV>T9JMWINFVY^ETI6<RHb:Q81lNGIcL6eX
HEmUJ6ANGF9TI69OGU]KHVQWJ6ieNGMbM7b0PXJ;TIFASiFIThf8QhR9SYBGTH^9
QgaaKfi_LViZK6i/JFU]MGeoPh^:PWn4QhN8QhJ;UInU[;Bi^KRg/[2d^KJ]YZFT
WYF<PWQaL7EnP7mmNWQcKW1iNG1VH61SJG5gO7ikNh26RXnDUiRFT8R9Rhb;RHf?
Si>BRhjBSXZ5Ng9^IF1LEDm?DeeSFeEOKGEaJFeiNgA_J6Q[KgIgLG1gPHZ<QhN<
SX^=U9>?TIbUXYR@TI:EUHb9Ti^KThV4Q8F9RXEjM7N2Rhb>UINBSHfCU9:EUiVJ
Ui>@UYZKVY:?UINCTHYoNGIbL6m]IeeEF5aIE5EGFUmSHVE_M7=cKVMRHf]bMg^3
SHf7QXR5R96JX9nGTY6EV9VGShV=S8B1P829VInJTHR3QHB3PX62Q8=nNWb1SIRE
T9BJWYfKVIZGTHZ7RHZ6PX>9T9B?RXN6Ph22RHb<SH^6Q8F6QhR6QHF6QXJ8Rhj>
S8R:Si>CTiFIViNBTHj7Ph>9TIBDVIZET8n;PgenPWmhM7EhO8>7QH5kKf1IEeII
FEUOJg5/JFmhPhIlLfiWIVITH5eQIfQ/KfmaL6MPGEmPG5AADUMMGemVLGAeNGUm
PXJ>T8QmMWAgOXJ7P8:=SXb>Qh:=Th^2Q8^CUiRGU92=S8b:QH1nP81oOh24RiFH
THf=SYBGTXjAU9FDTY>NZZbVXJ2V[JfVX9jNY:RVWIFEVYfFQgj0PH60O7IcLWEk
OW]hNh1oMgMoPX60OGj2Q8J6PGenP7efLW=cKf]ZJ6ESIFa]JVMXKWQlMFm]K6UP
FeiQIV]]Lg]kMgYnO7YfM7YlMgIjQi6>SI:?RX^AUiJ;Ogn1O79`MWYnOgM[IFMW
H5M@DEiWGDm<DeiVKgMbJfiiPGaeMWb7Si6AUIZPYjRTWinMVI>?T9>FWZNYYjVZ
Zk2b[J>IUYNHV9RLX9^CTYBFV9NFU9>DV9jOVIJHXk2c/;G3bLBjZYjNX9jKUH^7
Qh1nQHR6OW=]K6]YJFijOG9YKgE`JVaeOH1hKVYbNGMhP8B:SXV4OGEiQ8V3Mg=i
NgQcLgMkOX63PWagMgf1Ph5mOGihLF]WJW9jMfaTIFefO7n1Ph1kNhB<SHjCUi:8
OG=`M7QjNgUhN7QiNGA/I5iTKF]XJfecMg=_LgQmPWmgKfmfOhZATY2AVJ:SXjJZ
[:VLRX26TYfVYYb@Rhf=SY>EU92;Q7mnOhB:Rh=kNh65QhR7QXEnNH27Q7MdO8B5
Ogj4Qh^?SXnCTXf8R8^7OGUlOg]eKf]ZKW=fLfibNWijL6YbPHIkL7=mQ8J1NW]n
PH=mNh61OX::Qh1hLgZ8RH62R8b:OgAhQHn@RXR:SiFGUI6<TijJSXEoP8>2P81n
NWf8Shf6PXNDVI>?SiBLWinKU92<QGefMGAfO7YeLVi^KFQUJ6Y[JVIUIVMWIfMY
KG1eMg=bLgR1QhB0Og]dLW9aLWMiLV]/LGAjOgmmN75cOXRATi6>QX1nOX25RXf9
OgYnQXZ9R8J6R8fGVY>?TI6=RHN8RY:LWiZHUY:CTi2?U9bNWiZEUiJAShZ3Q8b>
RXJ8Rh^9QhN:S92DU929QhZ;QWYaLGAdM7MfMGV2R89fKFi`KF]/KgN5Rh^8QXZ@
THj:Q865SiB>RX9jNWinOh:3Q8J9RHN0LFAKEei]O861OWaiLEi=Be1DEU=AEUmQ
HfQXIf=PGf9VJF]`MgE/HEiXLgE`K71eLfm`LG=gNWUiOXJ>TYBAPW=`NHJ@T92E
Vj>[[:jf^[^j/JNQY[Fk]JnZYZJXZJRY[k>_ZJ>LUIBHUi>ASi2IXZ2ERHJ8Si:>
Rhf=R8N:SiB?RhR7RhnBUibIT8V9Q7n2R92JWIZBR7mjM6eYJW1bLG5aLgIcJfAH
CTiEGfM^L71bLG9bKFQVJ6MSHfU_LgAaLWn:QgifLFebOh5dHUIHHfY^LWMnPWa_
J6MXK6aTH5]GEf1^LViZKgMfLG1bMg]oPX62PH:8RhMlM7R0QX^<R8J8SHj=TYbQ
W9FDV9RBSi>FUHf7Ri>LXZJYYjBVZ:VYY9fMXjjc[:NW[[Vm]JZQWIbMXZV//KVi
/ZZUXj2MW9F<RHV>UiNCT8b4OG^1QhR9QhF1NG1YJ6mbLgMoR8Z6PhB:SXYoLg1e
Lf][LgQhM71_K6MVI6=WIF5XLgYoPh9nPHB0NW=]JVagPhB0OWn0OWQjP860Oh28
R7acKVedQIRMV9VHTY6DU8j3MW=jOWj3Ri:ARhAmMF]TIFeaKG5jO7anNgMdKfa^
L79cLgEgM7EkN75bMWanNWf6S8^3MV]YL7MmRifVY9nITi:=Q7n1Ogn8V:6SYIb<
OWA/J6UXJ6a^L7AdLFYSJ79dKf]VHV1PJgEfMgEcMGQgNX:4P7Q^J6aaLgEcL75i
PXJ:SY2ATI27Ng=`LgQjNWb2PWIaMgalM71_KWJ3RiBMXZBW[k>^YIjKVi^GT9:J
WinJThb=UINBQWYfLfe[Jg1bMXNHXJBRXYfFSXJ1OGUhN7nBYJbTUXZ4Q8V<RXV>
TY>EU92;R8IkKfeaMW]lN6QFD59ACTmDF5iRH5M@CU1@BD=4ATmLHfegOXF8QhAl
N7n:U9VFU9n_]:RJV9ZHThj7PX:2Q8J7PGUiNgagK6A[MgaeKG1eNWmoOhFBWj:R
Y:JXZ:JUYZJTYJNYYjB^_<C6`[bg[ZBMWIbET8n=RhnBSHB1Ng1_N7YdL75lSIbO
UY:HWj:PWYjQXInHTiNMYk>i/jRZ/JfNS7ebL7AcKFQYLgj1NFeWI6=QFUUNIFMN
E5AIGVEWHUYHHW5lN6eUIgEoNG=gNGYlNgE^KfmXGUE>BU5NHemMI6a^IUQADDe5
@3hl?T]LH61THf9YKW9iQI6GVY^KYK:i]k:/YZJZ[k6a];>]Z:>NW:2WY9VATYNF
TX^0PHF4PX20Ph^GWYnKUYFGU8b2OhREWIjNX:N_/[2]ZZV/[[2^ZZfb]K>^ZZ>J
UI27QHB1OGEYH65YM7n5R8R2NW=/I69SIFIWKGEiOXV@SXf>SXYnLg1_LWEaK6UT
GU]IEeQHE55>CeEEDE9FEUEHG5aKFeiQI6IXK6iZHf9^NWikMWIoPgU`LGQlOGaj
OHB9RhjATHYnM71cMW9/K6e`M7AcM7EaKfe]L79fQ9BQZJ^^/[Ba/;Bd/[Fma/W3
^K6/ZJNY/;>a[Zna/:bUWIVDSXf8PhZGVi><RHV:QX61PXB3PH61OG^0QXV;S8fA
TY:?RhnEUi>BU9>AT9:>Q7imN6iVHFE/LGIiMFi^LG=cKfMPGUiQIg5iN7EhOh=l
MgMhNgQaM7YlNGAdNG]iMWUoPH9nMW9eO7igLg=^IFM_L6aXJgAeM7QnQ8F0Mf]T
J79nQhb<Q7n4RHZ4OhNGWYNATiNESX^8PX:4Q8>3QXV8RXAiKVQVHf9XKG=jOGem
O7aoOWYkPXV9PgioR96ATI>@RHJ8RXV8Rhj<PgMYH6IcNG]kOH65QhR8OgEdNWij
Lfe[KG1bLg5cNgn0OGf3QhJ4R8jBSHV?Thn<SHn<PgYfN7n7SYBJXJ:OXJ6JTi6A
T96DUIJIWIZCUZ6UXIjIU9:BUIbMWYnMW9fQYjBRZ:f^[k6`ZJ>LUi^MUXf:RXf@
S8Z9QhB3Q8F1NgZ5T8f3OGUeMGAaKFe^KVY[LGEfM6UQGeePIfQUHfQ[J6IWJFEL
Ee9;AdYJK6mYIFIYKFi]KfeYJ6YZIfYbMWAaKVY]NX=oNWQeM7IgMgMkO7MbKVUW
KWQlN79aMX26QH>1PH>5QXZ:QhV=T92ATY:ASh^:S92IWYVDUYRDT92DUiF>QXB6
SIVSYjVXZJbYXinLWjFXYJ6SYj^]Z9jGW:R/ZJ:JUibNViF>QhN8QhZ:QhV?TY6>
S8V7R8R3P7igLgEeMGMhNgekMG5cN7anOGj1Ph9lLfm`L6aXJVa/KVm`LW5/HEME
FfE_N7Q]GUAHIVe]IUaFF5mOFUaTJFYZIV=XKgElNgMeN7ekMGIoRY2<OW=dNWj1
PhJ;T96@Si2>SXn>RXN9Si6BTYFLY:JVXIRGViVGVIbOWiVIViVIWJ6OW9^MXZ^_
ZjBQXYbARhR:S8b9QHN=Shb9QGn0Qhb>S8AkOHF4OWenOX>3O7=]KWR2QHF4PGag
Lg9bL6i[JFISJWF0R8V5PhB0NGAaLG9`JfIQHVI/LG9dMWIbL6aVHV=WIUiGF5]M
FeEEFfAVHV5TIV=LF5aRJ6mdN7anOWn0NVi/LgQdJVI]O8N9RXjAUIbOV8f:Ti^L
VYVEUj:YYj6MVIBBTiNLWjBWXIbKW9jNVYRFVJ2WYinJX:BPViJ@TYRJUYJIVYF@
RH>7Si:BT8f7R9>HUYRLWY^CRH5jMWEfN7QeNhR?Shn>RX=mNgeoOh65PgijMg^6
SXf8QXJ3OGIfNWekMFmXIFIVIVIZKVi`MGQkNgYmPXB3PH1oPHB8Si:BTi>ATHn@
VJ:UWiB=SXj7PhN=T8n<Qh=oOX23OWEaL6YUKGV0QX^<S8jAUINBQ7MeNGYhLW5j
PhV>TI:DT8b>S8N4Q8^AShMoNgYmP7moOWYeJf=PHfUYHUYEDD]7ADM=De]WKFa/
KgEgMFm[M7j0Oh21Og]hMG9`LGInQHR7R8Z=S8J1O7UhLVYUJ6meMWEbM7MjOGim
NgI`Kg=eM7MmQhf?SHjCVYjNWZ:TXIjMVIRGVZ:TYJJPVYVFU9NLWI^GU9NPYjJO
X:FXZJVUWiZKXJJUX9fPY[2i^;2[ZJBRYJ6LVYNGVIVGTX^5OgQaK6Y`NGYgLFUS
HF=UHEM:@d92@3`k?T=<E59FHFQ/LGIkOGaiNX67QGikNgUgMWAcMGf3Pge`I61S
JFURFeECEEA>CeQMG5]KFE=?DEAIH69RJ6m[HV1UJg9cKVaaO8B6QhfHWIJ?S8^:
SI>HUi67PX>7RHZ=T9:?RXR=U9ZIUYNKWIVGVYbJVIfU[:nd^;Ne/K2a/k>a/;2`
];Rj_L73_:nXZJbZ[:fYY9jITiBFTXj<Rh^;SY2;R8R6QHJ8S9BIW9bIV9RHVINA
RXJ0NWMlOgf0QH^@S8V8Q7eeKfIMG5aIF5QLHV=PGfEVGeMCF5iSIVU[K6mfMFi/
Kg5dNh>3PH:4QXV9QX9oNGZ0QXN6R8f?RhEnOH23PWioOgf0QHR8QXR8QhN6QhV=
TYBATINKWInPX:6OV9>FV9FFVYJBTY2<R8B5QX5mNgakO7amNg=[IfU_LVeZK6i_
LWEfLfeYJFU^MWUjO7j1OgamOh1nOX63QXR6RXn<Q862PX1mN7EiOh:0NgEbLW9a
LgUkNh23OGI_K6i_KW5dLFUSHV5VL7MlOWelO7alNgA^KF]YI6E`MgajLfi/K6e/
J6I]N826R8J8SHj<RXfBTXn?TiFEUI>@T9:GVYNARh^AU96<QhN<TiB;Ph66SI6?
T9:>RX^:PWUhQ96BQgakPhnHVIB<RH^<RhR8Ri6FUiBBShf=SXj7OgelNWYlP8F6
Ph1mNWE^IfU^M7MdL71aL6m^KVi`M7A]I5aIGF9TIFMUHfQaN7]lOh9oNGQiNh24
RH^5P865R8R9SI:DTXn>Si6CU9BGV9VNWiVDTiFHVIJASY2EVIbLX:JWXYRDU8b6
S9FFShF0PhN9RHV9QX61QHN9SiJHV9NDTHnAV9^GUYNGUIBCSHN5QXJ4OWIdNGen
OWUbKg1^KW1`KVi]K79hNGYgM71]JFMVIfMWIFAYKg=iNG1`N7j4RXZ6QHR:QH1o
PhF1NG5aMg]mOGioOWn5QG]hNg]mQ8AnOH>>UIB=RXnFU8f:S8n=Qh:2Ph>7TING
THnGWj2JTXf=SXb7QHV<RXZ=T96;Ph>4PGinOgmoPhR:RXN5Ri6DUHf6PWejNWao
QHjCTY:ASi2HWYfDRhB1PHB5PX1oOh20OGQgNWamOh:3PXF;SHnDUIJJW9NCT8^7
RHb;QH62PhB7Ri2@SXZ2NWEaJf]ZIVU_Lg9bNXF6PGYdL6]UH5YDE5QJFUiSIVU[
KW=eMFmZJ6aaMgimMgEhNg]kO7]nPh1kP8N7PWilO7j0PhB4QHJ2O7j3OWMcM7Mo
R8V2NWMhO81jM7AkPhF3Q8N8R8R5Ph:6RXb>Shf:Ri>JVi^KVi^JUYFDTi:ATi>>
QhB:UIVARXN2OGUhMgEfN7b0PGmoPX>6R8J3Q8N5PWa_IVQ_LfeSGf1WLGImPh5i
L6]]LG5eOHB7QH:4QX9nOhB7R8F2PHJ9RXf<R8N9RHV9RXnFVI^PXZ>UY::NV9VP
YJ2ET9:BTY>BUIJARH>3RY6GUi2:R8^?TY6?TYVMW9J=Ri2ETHZ8SY6;QXR9RhZ8
S92BRX22S8j9PWYjOGinNFmXI61LF5QGDeAIF5ULH65KEeYKF5IKH69UI5mMHV]e
MWAaKfi_K6IQHfeaKg1`K6icL6]WGeMHH6ATH5aMHF=WKW5dOGmkOH>3P7YbJfMZ
KW9hOX:2Qi>KVIRJUY:EVIZLX::UYJR[[;Bh[ZBNW9nPWYjNViNGVYfOWYbHW:6S
XIJCU9ZNWJ:UYJVZX9F@SHnBRhJ6Qh5oPXZ:PX:0OH24PX61Ph5nN75[L7f3PWei
OH60Q8AjM71eP8F=RXF9TYZLVIRMWijFUIN>UjBNUI2<RHJ;TX^6RhZ1NWf9S8^8
R8^9SIJHTI>GShnETXb;SHn:R8Z<SHjFVYF>TifMUI28PGn2QX9iNGefLGMjNGIg
M6aXJW5hMG5dL6IQGUmOHF=QIVMVJVIUJ6IYKFa`KVY/LGEfNg]gN7YfMWUhMgQm
PWM]LGEdL71]IV5SJ6][LGb7R8Z;PWimM7Z3OgM]MXJ6QhN0OWj5PWMnRXZ@RXF;
QgenPHB8R8IjNh9oOGijNGahOH>5SH=kR8b;RX1jOWn6Shn?TJ:USX>6SHb:T8Mi
NWf3PGUiQ85oOW]lNgQiO7j3RHV2PhZ=T9>CShn=S8N8TIJBTYRTZZRUUhfJWjRZ
UYfMTYVJQH:CXYR=U:2UWI:>W:BMSX:3QHMkLGIbKgUkNh9mM7b2P8B9RGejPW]f
NXZBQY6?QXB:TH5_LgAjRhZ6OWYkLVQ[K6=WIFA_L75]K6MZJ4mIF5=FCEU]FE5K
EEAEBTI>EU]TJVEaOH5iMX2=Sh:0OHFCU8IfMGMhPHAnNWb3TiNETXN8SHMeKhFB
RIRLTIRIVYZLUHjLWHB4THb>RWj=Vi6=R85fN7IZTJR2SHf<[8b;Uem[d;1/Rif[
Y7=`JfZ5TI^IUJ:AI8NUMFnAQWElNGb9R5m_P8EjM8B5QfA:GhJ2JE<lAgN3HEmd
LfmQDTiQIU1FEWEgJWR;QgbNWYFOX9::VK6kZ9:FU:2VXjJ?Oi2LYYVFZj6]ajBF
UZ:h]k6aWX^O/;6SMX>WYjjXNHO4^IB7TJBNWJfk`K>HYkVb/kBb[9VU[:B?MXNA
P8n9O7ifOH]hJfI<EgAiJEMIKh5cHF1[HeI593EDG5/k=d8dCdhk@3XhB55AGeEC
GEANFcI9HfamO6]LJ8R2HeYWP8AgN71KLXnMQfamOX:WW75cLiF]VHn>Vk>/U96A
U9VJTGQ`Ph>?UWn1W9><VimnN9>OZYVQZ85jRi^cWXjPZ7IfXiQfTJ2;MXJSTIFd
_9M]HGV3OHacC6^G/:BHVYVTSGj^[GYnS8j;TYR<SXnFV91mOYZ[Z9FAZKK0_Kna
YL:VT9NDYIV:Th=cSkNSOGYiUZMlHg1dH5QGHF5>CWUhDf=fQWeKOHUJIWE[I5A2
CVQNF5U:HV9DHem:JXn6R9=`BejFV6E/Q81fLh^IO5mTOiVJOf]`RI2@RGiLB6U]
De1LL7ebO8YVI79^QXEaHEI/SX9fP7UVL9bQR8UmKF^=U4]DSgaJRZ1aT[JKP9R^
ZYVNThZCRX5eRYfEV8M_KWMfK92QNV5/Ri:<X::@Qj:TUYJ@TIVe_9afM92ERj6]
[9V4KG1fLh2:QWIkSH5RDDe5@UMDGFM8>cdn?dQ;<cAGFSXlA1h[IWe[IGVAVIRW
XYZTUIROTZ;0b[nha]_9ZJFb/L;>W8c0elZUR8EiRZG5b9n1SIjHY;^^Ui^Z[;fh
ShQmQJFZVY:9UYnCWK[7Z9JdcLFfZl[4/[JIR9B_V9W5Y8NNXi6<VJNSQfYPGVYU
HFeUIgZ>MFISKgaGAdmOHW5TAEa[F5EMGFijJe]KF5e_LE=;FVmeHf]ZKg=VI6eb
KU<oI9>JSWACCEMFHgR1RWQeQ89dMWQeR9R6Lh2BP6N0QFISF5E^KVaGFE9QU8ED
?eATKW]kNWihOhjS[kV/WkODdKZiZZ6VZYn2MWj4KfQXF5EOH51MJ40VDfE9DDU2
BT0i=B@U?Cm4CDM<IX6>MVZ9Yk>iZYb]/jbY[jj^/kW:b;[Cgn?`e;:c/j2`e=O0
U7JBZ:fYN51RMG9LDEiLGfmhOWERF6]nPGaPD5ElQX2CRgNC/jFW_Z1dV;f^XIjE
WjRNSif`/[2/[[W0_kZ[X:6bZY25NFYlPgEnPGalOXV0O862R8NO[I^7S8Z1Q8>0
LfalRH9dLfaXVkJTVHmhMh=`IfI_LF]GGGM`I6inI5j9RVYgThb@ZHmLK8UfIf=D
E7B6Jf=_C45OK75fKEeEFWj>S8=KB61iTH9OMGUeQY>QYiZH]KN[RF=UMGagIE9@
GFM`KfmdIV1BGG5^N7MKCUQFFThl>c`g=TE2<dUbPgn2Ti2KYhR4XI^J^;Vd`L^g
ZL[PgN;N_[;=kO7E]:;1a:FRZYUnKVE`RIV4K6V7ShV;OG9LD69^IFAXLW5ZHEeF
FVedR9NO^[j_]]3VcJZY_m[D`[::PIBLWXagIfB4VXMeIeacQgU[FeA:CEiFCD<m
DUE:H6m]KG1^If1D?S]^SgURHei`Ph1lPZ:h[I^BTZ:UTX]nKXNLRG]]KX67RY2B
UYV<OgUbIWZDQ6eKHGR0UZ>DQgMbPY^VViRARj:l`JJ<S8f8R9FRU7MeSI>>Sh^@
XIjEVjFf/:JMSIRPRgImOg9TCC8e=c]BCBhM:d12@dX^9T9ADDU1?49?F5IEH6E]
R9B7OWnD]=?Jc;NZ^l37d;fUWJVh^Zn]]:jTW9BFVIN;Q8nGSXAkNX=nL5IEGTA9
KG]gOX^8O7UjPIRUSHFQXI>JWZ>od<6`YifK/LKAbk:LX[^n[J:HQinaYk;0Xgf2
VJJUYYZ5QHV4R9F<OW]nMFaZGF5fQWi`KFEXOY:ISXJ4PHF1OgijJfj:Shb8OWF0
Rh=gLFEDGgb5KVEWGFaeEU1GA3Q@LF]FFf9RKWALEV5>C6USAdI@A3<jAEMZH3dl
B5AOETe<EUeOHg5]KX5kLH23N7Z:TiF/akR?QWiXNHY^CUETIf]RD4aFD450ATA;
FUQ@B3`dATi5C5A;@4ePJGR;OhFa`k:bfNWKkO3AcM_Ad>kdek6V]m;KcLo>^kK2
al6h/9bDX9MoNfmHHW1YKg=dMG65Sh:?WYnU^;6GV:BPU9VR[[2RVZoCe<c8]jVe
alC1`;2/]jnRUiBBPh22P8MoHeIQIeE=DDM3EEiIH5/m=dUEEeELHg:9RXV6MFi_
NI6WX8n1O8>;SgUYNgn6TY:@QX:;UI9lL6mlT8QnMFEWLGQhNXRAT8f<PXFNV7n:
WJJ_WXN0RY>ESXnMVjR_V9^WWIFDV9NCUY1gJgnFYiYjM8JFTHJ?TINY`m_2ZJ^U
Wi:;OfI;?T98DT<k<QlZ>30J2PLLA5AKAbHK7cI5AS`e>55dP85hKW21Vk;2`[Ve
]KJobLFeZJFPWjjWT8jCVYVAQX:<U8n<PFiZL6QDEe]ECT]>E6IVETeKNGa]LHB7
QXZ3PiV/_lBgZ[;4bl71cm?Gc[R[^;fd[ZJPWInQYIN0MW1dNgY^H5eVIV]cJ5M>
EV]gMfIGHfQVK6]JEgfV]kffXijX/[BZYIbGWIN@ThYnP8=nLg1kRhj3Lf]bN79U
JWEcJV=[KWAfIf9YKfYQFVMeKVa]If=TKfmOGFY_KVUGD6IoNV9MH5YYOGYdNHJA
SgmhN7]gJFn0T9FO];^^/[nhZ9J3KFAUESlg9a/R:BHP7BLjBeUJE5eZLg=cMVeQ
HVYYJViPHGfGX:bh];_@i>k^hMcZlngKb[nk]JjNSI>SYHieLXbIShR:PWb0O7Eh
NFm_M7EbJf=MFf^2U8n4Vk[0^;Vh`M;?alS8aL??fL>ZXZF/[JRUZjJFPgf0NW9[
KgMfLFeUIVEKFVAYHF=YL7A^LGamNXROYibFTY>Q/jbIQWMnQh^=SHnBSHZ@SH5j
LgN;Rg]fN7^2NVY[MWf2Q7imPX=iMhB8RXf>OFI`QHV;QGj5Qg=RJG9iNWYkM71X
FeEQMX1jKUmMJfmXIFIODU=/JDe>DUATI5eC@TINPZ>]Z;72a<2n]jbNR7A/JV=@
>b/Y8AD@30/C6b8i@SQ2G6QMBd13EUiIEeeYK7V=T9NTXJ:_^<3AfLoAiN[Qg=O;
a/K8`jfGVjjbYjFPTXj?TiVITHN2NgEbMGIkPgiiP8R:T9n^^<G7`Kni^lC>d/>d
/kRc[K6c/K:XVibQUXB8W9^AUXYgNX>9TXIVGgMnKfY/J5m_QXJ3OgUhMWAfLfe]
LgMgO7MRH6abOH=jKGB2QHN7OFmeOWUbKFQPJGIbMX9dEdM>Ee15C59=E5URHU=:
EF1UIf1LGVI`LWAmO7^2MVMaN71/Ohn7Ogi_IW5gMWf2O7f@VI:;QXR?Th^>UiBD
Z;>^/[Jh^[ZaZ:ZUUHR0Nh22JdE1EEI;AdUKM7YgNX:1O8J@RhF5OWf0Qi>ITH9o
SJ6`/jZQWJZg]:VQVibRXIR;Ri2CUH^0PHR8Q8:<UiZHSiFQWI>8MVUfQ8B7QGAa
R9ZLX9J2Q9RGQ8:8SiN=M71oNVAQJFM^OgihQ8^5P7YgR9R@RHn@QHNGWi9oMFmb
K6IaNGYbIf]lP824QWmlPh^6NGAiPWmjOh63QHAiIVU]J75nRI2BQGj>TX=kQ7ee
R8b0NG9_Oi2=R8V0MWAkPGn6SX^6OgMlPGYiR9:8Ng9VG5m^OhImMGn;R85jNh>9
R8V5M6ETJVUPFE9BE5QOJWj=TH^3R8AbJgJ=W9Z?QXbHSgIYGE5@DEITF4A3B4a7
ATDk>TA>Df5cM6IDDV1dQXn@RhVDWj:TYJ6QX:2W[jbVXYnMYZRGSINW[Z2FV:2^
^;BZW8b>VJNna[Zb[:JQWJ>WYjbY]<g<`Knj[ZVb^;J]XYbKWZ^h/jRYZ91dL7j;
UifDQgmkM6adNgIkOg]jMg^1PXJ9Ri6;N7ImL69WL7QoQXIiN81hPHmnK6aZKG]n
M6ifNgIaJfAVIemLGf1TJVUUFDY8E6AUGUaRKWb9PFm_Mh>0IeYNIW1hO823QXEj
LWIhN7QiQhj9QX>2PWYfO861Q8j<PXfHRWUdNHF9QHV8PGekP89cLh66S92<RhR9
QH:7QhjESXJ4RYNS[JbPUi::SiVJXJ>ESH5`K6iVGEIBE5QUJfEQGf5WHemTKW1a
O8RDYJfOTIFLVXb1PHZGVY2:QX9kLG1VEE1BFf=THf9ZMGb7U8inNgYfPI>PY:R[
Yj:NV9:BTi:@QWf6THn8RHfHWiB=Ui^MWi^HVi^DSH5dIfj0R8j=PWj<WYnLX9jA
R8B5RXZ3PHNFVi:9QGf3SXMoOXF>TYJFTi:DT8^7O7V1QhEnO7moOWekNh:0MFaY
KgV5PGI]K7j>QgahNGUgN7=bN7]mO7QjO75ZM7]hMg9_Kg1hO7mgHUUMFeiIC4aO
KW1aKfIUKg9_M8:<T8n@T9FPVhaoLgIiJV9XKg5^L7AhMfa_O7ekOWinP8F7PhR@
TY>JVI67OXNLZ9j>T9fRYJZVWY^OXjN[XIBLZ:BMW:>SUI2FWZBZZZZX[[VeW8=j
OXJ?THbCViB;QWinPGadKg9fLW5cNX^ESGeeMX6AV922PhN9T8eoO7n5SiB?QXB1
NW1]MX1mNWYnP7MWGfMaNH:5OgYkOWekMG5aLGEmOh:7OgAbLganM6i]KWj:Si27
PhB4OFaSLH>:RX9hNWegL79`IfIXJG5fM79cMX2;T8j;Shn7RHYmKf=WLG9ZIW1k
NgMaIF9/Kfi`M7inN7elOHB1LF5OKhFFXj>CRH^>RWihOHB<TI>9OXJBUXaoQI2?
RXV6QXAmOGQdNGQ`IUeMIG=kMg=`LWf3PGikNWj0P7YgPXF1RXj:QWehN7AiPGI^
NHRBU8QlMG=hPWm^IfidNh:4R7i_K7IiLgJ2SiJMW9NBRXR8SIRGSXb@VIZ?R8F5
Rhb8SXn<ShR9VIZBSXnCT96EUYFCS8J7PGUjNg^4Ti>8QX^GWYbKW:2Z]l73^:jV
Vi>@T9FBR8N<TY69RHQoNGUoQXF2QXR8QGehJfE]Jf5SJg5cMH>=Q7]jPH^@SXjD
V9JARWaiPHB5Pg]eKF=SKGMjOHB1NgYdLW9WGF5`NGQgNG5/MWn0MW5kPGeoQhbB
T8fBU9:=QhJ9TiZBRY6IW9F<R8>1PGioPGn0QhZ6Og]oQ8EoOXR<RXR7RHnKZZVI
TY^X/:NJUIRSZ:2?Q8RBTHn:OgIaL7^8RhV4PG]dNhB2NFmWLHB9PGIgN7UiIU1A
HF]aL6e/KW9kQX=/HfY/L7EhNGQdM7j8Qh5oMfi]K6MSH69TIFQRD4iJH5mKEE9M
KgV2S8f9SY6@T8Z3O8>FWinKW:2NXJ6ITI>LZ[Bg^K:ZYj:ISHB7S8UoM7Z6PG9]
Kg9cKf]UHfYfRI6;RHR3Q8Z=TiRETINPWiR>SI>Q[:FHUIfLUIF:Ng^4QhEnM6md
NW=^MWMbMG^0PXV?SXZ:SXn6P8B9R8=nOX1kLgMiKV1IFf=ZL7=dLgAlOgakOGn2
Ph63NFIPIFIPGEM;AD95DEQDFFikPHZ@S8:2Q8F3MgF4R7ibJV][GeMIG5mSIF=Y
NX>3PW]fNWYfMgEeNhB@UHZ3Q7edKVabNh>1R9NDTI:=Rhb>UYN?TIRS[Jn_ZJ>Y
/[F/VY>KYJRRW9NBV:BWX922Qhn;RhZ;S8AjMgb4PgM^L7]nL6U_NhJ;TIZOUX^:
U9ZDT8^<UIRBRXJ2NWV2RHZ8QHV:R8j9OGUhOH1hMG9XIg5kNg5ZJ6ESHF9XJFEZ
L6m_NHVEWJBVZ:NPVINHWj>LUibUZ9f7NgeoNGR3Rhb<SYFIVIN>Pgj3TZ:SV9:B
UYVCRhR6OG9^KV]]LWAiP89oNGInRY2>RhjHYk>cZ:6Y^<?3^K6_[:VVY::SX968
Q7alOW9WJWAgM7Z5SY>ATY:4O7n0Qh^5PGegN7enMFQWIfA]Mgb5QGEYJfiXIVmh
OXRASWmfLf]VI5iOGeaRJEmBCU5CC4Q@DTY3A4aBCd]6@diPKg=aMWj7RH>1OWZ4
TI27NgV4QWeaJFITHV=XM85oMgAbLGAiNWQlQi6DRhB;TIFJSGenRIJKUIBNY:>P
XijASiRQWiJGWIjISHFBWIZHSgmgO8:1OGejMGAaKgUmNg]eJFMdOG^1TINERGMf
PXR6P7]iPi:ETX^0Ng=WJFm]JFITKg^5Shb4OGIlQ7miMWb:RhB7QX=oNWikLW=h
PXb<SI:>SI:CUY^MWJ6W[:^UWIJDThn;TY:6P7mhM75/KgV4RXN0NWMlPhV@TY>J
X:2UYYfIWjbe^;bn^K6Y/;FTUiREQgIdP8=oLfEYLgIiMG=jR9:<OG^4SI6;QHJ;
S8R2NWAeMgAdOH9mMG1`K6QUFEAOJFieMg5VJ7MnOGM^KFMQJ6i/Kfi]LG9iNfME
CdmFFf1YKg1_LFmWJW5ePHZ:RH^>Si2CShB4Rh^6Qh^>Shj?UIZJThQlNH:7PGA[
LGf1Q8F4QhN:ShV2Q8J<THn?T9:ETH^5QI6HWk2n`kFOUYFGVY^LW9VIUiRNWI:9
S9JITHMnOHB;SXMnPXJ2Oh:0P8B:TiVKVi^HSX^EVI:>ShMnOWmmP8f@Rhj?SHIn
NgUhMg5/If9VJfIPF4e;FF9HBDQDI6idP8^3NGUmRHj<U9^PYJ2>OWEfNg]lNgE/
H5mXKF]/KF]/L75^KfaWIVIVJg1`MGf0Q8J4P7n6RXR;Si:FXJNMTHf:SY2:RiJP
[lC<a;>XXYfLWJ2WYYZBU9NGRGQdJfESGUeUKg9_KVm]JVUZKg1gQH^<RhjARh5i
MWj7QX1jLF]ZJ6UVHF=[LW5XHf9QHV=TJ71hM6i`L6a_KF]fO7ajM79^K7AiLVEH
F5mQHF=WL7UhL6MPHFEXL8:?T8Z0NWj8Ti>6NgUkOWefLgEeMgE^J6YcN7AcMg^6
T8j8Ri6FUiRKXJZ]YIB6QXf@RX66T9FDRgidKg5kPX:6SiBATI6?SiFIWZF/];Vf
/[>f/ZBHU9:EWZ>XZZ^_[jn_ZZNTXJ>Z][jdYIjLXJNYYYbEU9VMV9FJX9jIV9B=
RHN3NgEjRYBBTI68PGYbLh6=Ti6;R8bHX9ZARhfBSXN4Oh20OX21OGalNG1WIFEO
GVA[KfiZI5]EEUQFDDeCFeiNIFmgO7afMGIcMgj2SINFS7]bNH:7R8>0OGb1OWQg
NGn7RHZ;RXJ4RXn?TiZKU8b:RGi^I6=WIUiJFUYOIVMUHf=^MWIeM7IeMh23P821
Q8J<Ti>@Rh1kOH:9R8B1MfiZH5==DUYKFE]QJFm^K6AKH6eeNhBAUXb6PhF>THYo
LVY^NX>1MgAjQ8Z8Ph::UI^NXjNZ/[B_/KVbY9jNY:V[XiJ=S9FLUhaoNGUkP85n
P8N>U9:@UYjRXjJ_^;o2_KNd/KJn^jnVY:6GTYNKVY>=SHn?RGmjMWR3S9:KY:RT
Uhn>Si6BRGYbLWMgKVETIfMNDE1EFF5SHfYeN7A^Hf9[K6MQGV5KBd4l=cLl?3Xk
?d98CDY8CUALJG1^JVabLg9]JFabL6i]LgMeKFAOGE]GEeeOI71bLGZ0PHB4OgUh
Q8j>SH^1MVeKDEILF4m7@dE?FeUFG61ZLG1hPXZ>TYfV[Kk7`L38dMC<`;^i^[Vb
ZjJSZJ^VXYnNXZ2GTYROX:Vc[jbe^k>VYZj`];F_/KVe[JbYWHj8S92EV9^SY9nM
VYB=RXZ8Ri:@RXbBV9ZAQX66TiZJU8R7Si:=Q867Rh^8RXf@T8^3PhN6Sj2UXYbE
SH9hM6mXIFIRFeUMEdm?CD]?Cd]>EemTIV9OI71eLg=jPXR;Qh60OWinMfUNF5eQ
FV1PFEYSKfm/Kg=kPhVDWZ2RYJf^YInJWZBJQgEVG5M>@38b>cln?3lk?4I=DUUP
JgEmQhV?WJ2MThnDUiNKVi>>Shf2N7AbN7UgNH:BXJZ/[KBob]OTkNgXgmKCdm38
`[ZZV8f7P7ahL6]SF55DEDe8ATA:G6EVJG9oRHZ9S9BNW9BBVJ:UY:FY/;Bd]K:^
[:NX/:nZYjBVYZ>TZ:ZZXINCTHZ0NGAZI6ITETi>DE=FFemUK6mcNGQbLGR2QHN<
TYjRUY6DV9^GTHj<RHJ2OW]jOgehOHJ?Thn@TY>LWYZHUiB9O7IaJV5A@cHW6`l8
0`00000000023QHJ7RHbAe]WMHNIY:ZWVIBETi:=R8=nOGUdLFUNFEiVJgB2S9VT
[;[;fN;RhnK^m_Sck^SMeLo3/:6KTXb;Qg]gMVeTGUMACTmBFfATI6aiOgn5T9ZR
Zk>i^;Bf_;bo`;J`[ZRW[:n]Z:BRY[2j`<?4aL_;a/6m_;V`YIN9OWE/I5mEB3`e
@4Y2?3Xe=3LnBeUSJW5dN8>8Qh9mNgaiKfAVL75_KG5iP8B1P8NCV9bPWYjQUhf:
Q8>6PgMUDdTn<2@H2@00000?51<A4AXX<C4Y;Sa=I79bM86;R8>6RXbGWINJWi:3
P81oPXB7S9JUZJf^XZ2V/<7CgMoTjN7He];>c<K0_;:YYZJSX9V8O7UiMFm]JfUY
J6MXIfAXMH::ShnAW:>UZjfSX:^`[:^^/kF^Xj6PWj:OUiFKX::UZ:NUXIF:RHb4
NGUjN71UGeaHEeQMIFU_Lg=fNWE_KVmdLW1bM7IfLg1[HemQI6]cLW1aMg]gOIBP
Xj:HTIFMWYbFUIbQY:2ISWIOEeIECd8e<30a;2LX92Te<RP]?U1VNX^ARHR?Vj:N
U9>KXZ6FQgUdL6EMH69PGV1YNXjO[kFf_l_GhNS/k_KooookkN;Fb[nbYjRZX923
NFiRFUQIFUMADUULGUiKEeAFGVU_LgQgLWF0S9BHVIZIV9BATY:CTI6BU9>DW:FV
Y:BUZk6^Z:R[Yi^=PWMZH5Q@BdiJGeYDDeEKIg5cM7ImQX^8QHR<QXB:Ri6GThj<
SHfAV9VARXnDUijLXJNMT8EoNG1TFe5;CDU1>c0W:34i>Sm:CU1EE59GFEiZO8fC
T8nBU9fUYJFSY:nf/:FNVY>>SXQmMg=cLWIgMGb4RHnDVIjY/ZnZ[[Ji^KFa]Ko2
^JnSUHb9PWQbJfMXJVAGCda>F61LDTe9@CdoADY;BDY?Ef1XL7Z1PhRAU9bX/;>`
ZZNQWJ2VZZVPVIFAShb<SY:GUY:ATYBBSH9hNGUjO7]`Ge=?CTiCGFIYI5mOHVmi
PhZ>U9j__lcHe]3=cM79_Kjm]jfSW9:2LEa9@dA4@34R9c<c;RTX9RPe@4M9@dA?
G6UeN7MmRiBKViFGXk6g]kFc[ZJLVJ2ZZIjHUiFETXj9OGEfOhV;Q7ekOh>4SIRQ
Y:>OVI26Phb@SXb?U9JETiVNVY:>R85oPGmfJeiEDE9DCdI7CUIKHVU/JVa_KgEo
Qi:RZJJUY::V[K6c];>b/kNk_Kjm_Ko3`lC5`lC3_;Rj]j^SZ[:[UhAbHUeOGEYJ
GVAVI65VLGMnPh9oPhF3SYVRZJRX/K^l^[N[Th5hJf1HB3Pe>S`b7aHG6b<_=2lY
:S0mCEUHE5URK75]IfacNh66PgUjRIBJWZBZZJBY^<6k]kB]YJ6PWiVBU9fSXY^E
T8nEW9nMVYZNX9jHRgigLFUNDT]8Be1@Cdi?D4aBGfU_M7QiO8N@TI2BTi29RI:N
YJBOWZ2RY:>W[Jj^[Zna];6^ZJ>PWYZFThn@T8^5P8:6S9>BSY:HUhj8QX1kN7Qj
NWEdNWYdL7AjPXjFUY2=SXZ:SX^8QGabKVY/KFMLB3/oA4<l<S8n@d4k;RDW=3lo
>S@`<SY0@dU?DeQSL7N0QhN;Uj>Y[:ZVXInJV9NCT8j=Si:DTY2=TZ6^];6^/;:d
^KRb[jjXZK>j_;ZbYjJWVhf;Ti>;QhN2O7YhMGMeKF5ECe=NIfYXI6A]MgYhNX26
RhnBVZFZZ:BVZZNRWj>//kB]Z:RY[:VOV9VKW9bFS85iLgAkOWalO7j8TIFFVIVG
V9>8PX20OGIcLFUQIG1eOh^8QHB2R8jAUYB@Ti^OWiB3M6ELETXn:aXF6adG30<4
3Q/X;S4h?dYHHVIYKW1]KGJ0PhF6PhJ@THnBTiBKXZRWY:V[/[Zo`[nma=3JhN7F
c<W<d<Nh/K6/Y9jKVIJAQgU`KfmXHF5VL7j5QX:2RiBMY:>RXIbFTXQiJf=RHfAV
IfefNgIaLGEoSIVPYZZ[Yj:NVYJ?OgAbLFe[If=RHf=QGUiXM7YkPHZAUI>BU9FJ
YJ^YYInIU8n=Rh^<R8=kKVUZJfmaJf1CCU5LJVi[JF]`MGUkNgYhMW=]Jf]SDdM5
AD<l=C0];C0h@TE9DUaVKgAfNhVO/KRd[Zje_Kjh[J:NWinKT7maKVe/L7MlOGn4
RiFPY:^f`<S?dm;=cM3=b/W7`KJc]kR`XI:3NWE`JV9MGfU`LGAiNGAcM7AjPH5n
P8B5OFiMDU1?DU9@DUABE5UKH6YdOXZBV9jV[;>k`;fh[Z6ERXB4PgadKFa]KW5d
MGMjO867Rhf:Q8B5Q8F7QXF4P7akOHJ>TIRIUiJDUI2;TiNBT8V6RiBHUi:?SY>M
VXf3O7^2Qgm_H5M<@3H`:R8K61DB51LK82H_>TEBG6YhQYRW[J^XZ[:e[J:ITHf?
U9JDUIJJWjBVZJb`]KNf]KJl`;fg/k:e^KFZXZ2LUY6<QGihL6a]K6MQFeACDe9@
C4Y6@D97BDaBFVA^M7Z4SYNOXI^ETI:DTi>CSXR6RHR2OgekOX>:U9bOXjJSX:>T
XYnLW:2QViBAU9bPWi^EUIfSYZNUXIfKWjNYYZ6MWZ2KUYRJXJFMUI>DV9ZITXZ7
R8AlLfaZIemFBT0l?3m3?STl@TI6ATI7BDLo?D14BD]9AD=8CUAKH61RJG9jPhfF
X:^d]:^SYJf`[ZRPV969PGalNgYgM7=fNGb2QHF6Q8NDWj:QXJBXZ::DSY:HW9fM
ViFBT8Z4OgE[I6ATHEmNGF1THf=UJ75mQhnJXZFUZk>e][6/[;:e]:fUX9bFT8j;
QH63RHfAVZ:X[[Fi]k_4akne[ZVTWI>;Rhj;OfeTIFQYIf5JG65TJW9hOhJ;TYRG
UiVS/[F_Z:>QWYB>QG]cJfUYI61KDdm?DUEDDdi<DemSGeI@CTY=DD`o<Bhb=SLd
;bhd?TE8Be5JIgEoQhfAUj:`_<;1_;Rh^KF]ZZRUXj>UZ:Z[ZZRSWYnOW9jTZ:RV
Z:JRXZJWYZ>NUHj@THb4O7MeLF]VH5UFFEmTIF9MFU]MHVahOh:7Tj6XZ:V_]KF`
Z9^BSHZ2O7afKFUWI6=UJ6a`LWAkPhZAUIFDUYFDTi>BSXj>S8Z;SXj;QGijNWUh
NWelNgaoPX5lN7AdMGEgNG]jLfe/Jfa/J5mIFEUGDTY0?D14@clj=ca7C4];BTeJ
Jg9`K6UZMHB5OGYmPHJ7Q8F6QXN8QhJ6R8bEVY^NXjJVZ:b`[jf[Zj^Z[K2^ZjNX
/;Vl^[Rk`<K<dMOLfmWDc/Nn]:RLTXMoNWA^JF5JEDi;CTm;BDY8ATaFFU]OHF5U
JVifOX>7SI6DVjF//;2XYJfe]kBa[Z^WXIN<Q7edK6QQF5UOH5YCD59GG5mOG5IB
FEiNHFM^MWYmNWZ6TI>DShb@UZ6UWiZHUIZRYZZWY:J[/[6TVI69Q7Y]IfMXIUmI
Dde:ATE5B4a=CDa=EUmQH5ePJWF3T9BGWZ>Y[k6a/[S0`l:k/:NRW9J?QX>1OWYf
Lfm/L7IfNGn5RXfEXJR//K6]ZZVXYZR/ZjFPViZMW9NBShj@T8^8RHV5OWUeLW=c
L6aVGUMEE5==@cXf=Sa1ADM8B4U>EeiSKWb5RhfBVj6W[kBd/[Bh^KNc/k:[XYnN
VYFBSHJ2PGinNg5WIFU^Mgn2PH21PhF6QXR9Rhj?SXnCUI2;SHZ4R96GV9FFW:BZ
[:RSXZJ/[:FPWIVAQ7=RDT]7?38Z9B8P820U;C<f=SM1CUUMFe]MIgEjOh^DUYbT
YZ>SXZ:SY:BRYJNWYjFNUHn=SH^;S8b=RXJ4PH1lNWb0PhB5QX^<QWinPX:2PX20
PX5mNWanNgUkOX21PXJ9S8Z8RXZ8RXb8PGimOWmnO7UeLgIkPHF9S8n?RhJ7SiRI
V9VKWJ:RWY^IUiJHUi6AUijVZJJV[;:aZJ2JVIVGUY24O7MaKF]YJ6U/L79aKFac
NWUfMWZ1QX^@T8nAUYVGSXV:RHN5OgQdMg]lMFUOGV1SI5iGDeA@BTaACdY8AD93
ADE7CE5ADE=BDeYRIVY^Kg1bM7QoQHR<TYVNXj^^ZJFVZZf]ZZJVZjfZY9fIVY^E
T92CUYVJUYBFVI^MWj2PWijLV9:<RHR4Og]hLfe^LG1_LG=cN8:5PHNAU9BEUI:D
Vi^ETHn;R8N4O7QhMG9bK6IUJg=eLg1_MWn3PX21QhnEV9VKWZ6QWIRGVYfQXijE
Rh:2PX5nNGUjN7MdKVYZJ6QZJfYYJFicLg5`Kfm/J6MTHVESGEUHEe9;BDmFF5IE
EeaUKW5aKfidO85mMF]WIF=VIEmNH61PH6AXKWN3S92BUYVMY:ji_[Zi_L2o^kBb
];Jh_Kni/k6^[K2f_L71a<G4alS7a/Bo_;RcZ9jMWIR=Q7]bKF]YJVYSFe]NGf1P
GEaPJW1`LWIjOh:7TYZNXjNYYj>PVIJFUIBCShZ8QhF5QGecK6UZJFESI6Q]LWQl
NGEhNWUhMG5]K71fM6]UIV]aMgj3QXN>UI>?Shf9RXb>UIJ>QH>1NWMfMW=cMWf1
OgI`LgMiNgaiN7Z1QH=nN7MhNG]gKFY/KW5_J61KFEYRKFeXJFibNGegLWIlOh63
PhJ;SHb@THf;Si:BTHj9QHB6RY2@RXR=T9:GWJ6QWijS[kNi^;Rh^;Zk]k6a[jJK
T89hN7YfK5mEDE5CE5=@DEIKFe]LFeeOHVQ[If=VJ6UVHEmQIFEVJF]]L75`LGIm
P8:5QHVAU9:?SH^<SHb;SI:HWYjJUI2=SX^6R8R8SYBGV9ZIUINKV9B@TYNLWZ6S
XZ2SZjfWXj6MV9^NWYN<R8V5OGIdLgEdL6]VHV9RH61PHV=SHVAWIEiHEDm:C4m?
CTmAE5MJFf1WJfaaLg9cMgf7T8j6PX64SYB@SHnBTi>ASHZ9RXj@SH^>T8j<SHj=
SHnBThj;U9fOXZJVYJ:LU8j>UYfMUXj;RhN1OWUaJf]YI61MGF9XKG1cMGMiO7]f
MGj8Ri2HWJ6RYZVVXjBXZ:>OV9FJVIB?RH^BUY>@UijRY:JSXYfESY2FUYJHUiZM
ViF?RXJ4Ph:4QXN3OWelOH66QhAoNg^0Q8V>Si2ASHN3P865QH:1PX1kNWijKV=L
Fe]HDT]4@T93?cDb?DA4B4mDEeMOIVQRGVE^L6aXHeaKH6=QFe]SJ6QZKWElPX>2
PhB9TiNEUJ2Z[:f/Z:JVYZ:KVIbT[K6^Zj^/[J^WXYREVZ6SXJ2LV9bRXj:OW9^M
WI^IUi28PWmjM7=aKVQTI65PIFaaMWIiOhB5R8fCW:2PXjFSWiR@R8B4Ph>2P7eo
QXN1MFaZJF]aNhB6R8nEU8b7S8n=S8b<RXV:RhR0NGMhMW9`MGf0OWj3PGf6QX21
QHZ<RXF3QH=lN7alMWAbKFMLD4Q3@dE4?cTe=ce3@cm0AdeGHVM/M7j4RHb7P8ND
UHj9RXnBThb3P7n0QHR;SH^=UIZLW:6//kFh^k^m`lJo^k^e/K:e]K6^[:VUXYfH
U9BIWIbIUIRMVI:>RhjCUYB=S9:BR7efKFY]J65SJVYYJFYYJ6Y^KF]/LGZ1QXF0
OgmoQ8V7QhjFVYZJUXn=RXAoNG9aLW9aKfiXHfM_LW1]KG1bMGIdMGEfO7aeLWIi
MWAeMWIhOhF4P825QX:4QXN;TYJBT9>IW9ZES8R9Q8:5PgahN7akLVYWJVmcM6mW
JFi`LFi/LgYgLW5dM7IkOWQeMWQiNWMgNWYjNW]oPHB8Q861PhN9Qh9mNW^1Qh^;
R8RBVY^KVIZOXZ2HTY>GVi^KW9^GUIJIUi>?TIBEU9>BShV2N6iZJV][IfIVJV]Y
JFMUJ6aZK75`M7EcM7IhN7=^M7AdNGUfN7j3QH>0Oh:6QX60Q8R8R89lP89oO7an
PH:2PXZCUiJFUiJFVIJDUi^NWYjOX9nNXZ6QYZRTXJ:QWj2QX9jPVY:>T96?ShR0
OWUeMW9ZHUmQGeUGEe=>CeMOHEeLGEmNH69UJFa_L6aWJFmbLG5bM7AbLGEjOX:6
RHV=SHV7R8^:QXZAUIBBUYBDX:>LV9ZLWj:OX:FWY:2LVYRDRX:0PhV=Qh60Q8R;
QWmmP81kMFiYJf][J5iGEeaRI65PGEiWLG=gPhElL7F<Ti:R/:JL[;j]SiZhX9:R
WIZRY:2KT8JDWI2;S8ZKVHR8TinERH^BUHnQVhbFWIJ6QGYeSI^ARXR7SHF2Rgj6
V9V<Ph:6Ti^DPh6<ThV7R8ZAPg9fL5iLJV]CDV1VGV5VEd];FFUdP8b7NG=^IE]H
Ff1YKW1gMWEnOgUeN860N7QoPWmoMVEUKg9_KVeaNGekMgQgMFa`PhnNYZ:GTXb=
SIFRYZV`/Zf`[j6HThb5SINQYZFPX9nAQhJ<QgM`KVaYKVm]K69NI5iEEf1VIEiP
J6U^LG9^KGIkMGR3TIbGU8aoP8Z:RXj?SXMmNGajLg9_LWEeKVihNGE`KW9gLW1e
MgIcMWQ`MH62NGEhOHJBVYF3NXV;RY6GWijKUi:4Phb8Ph>1OgamP7alLfihM5eE
E5YKDe=HF4i:DeIHFeUQK75kRY6?TIVOXjbd];>`[kVl][:b[k6`Yj:IVYnRYinG
WJ>NV:2^][Jg_Kno_LOGc;nlaLVg/;2][:j/[k6ZZJb[Z:FTY::FR8IkKFU[P:Fn
a/c2XHElKUmQIfMVJ6a`MW9/KVa/Mgj7RXV;RGmhNgj1Oh^BVjRSUi:=QhV3MWV0
O7E_NGibKG5bKVIZJUY<BU1FE4iBG5]FEEMJJ6]UG5ABDe=CEeeVM7YgOgYcMWQ_
JFedNWn0MG=fMG1XJF5IFeQIGU=7?c/m?3/k@4=5C59JH5Q;BTi8C5YPIF]aOhAg
LgQhOX=nM75fNH5oLFibMGQjN7]lNh1oOh>0OWioP86=UiBEV96<S8EnPH61Qhb;
QhR8P8>8QWifNX:1QiF7NWahM7^3NgElRHJ1RXV5QH5hMWn=TiJGW:^d]:ZNWY^I
V9jWZ:VTViRCSiFQYJ2QWj2/Z9^DW:FZ/K6a][Zf/k>f]k2Y[[JbZjZd_KVb/K>f
^KNe/kS1_KF`[J^TWYfQZkc:a<;9^ZNPUY2;Ri2@SHf>V9bCPgajOWebO8J9RHN:
RXR2OXNCUH^6Ri2:OGQfKfabM75bLG5`K6YUHEmPJVebOhF=V9ZCU9fNUY>EUYB;
QHf<PX65PGUfNh9oNgj7RX=jMgE/I6AYJVIUIEmRHV9SI6U/KfaVIVaaLGAcL75b
Kg1_K6UYKFY/KFM[Kg=cLWMjMg=fLVYaMFaZIUmEATM;DU]SJF]YJ6ITGEADEEIB
DEYUJVeUH6=VHeA=DUEMJ71eO7]hMWAhN7YlO8F=SH=nOWEUFU1;D51=DEMBDDmC
DTe5>SDe?TA9B4aEF5aSH5eUJ6edNX>6RHb9RHB0R8N8RH>2O7EfNgahMgb0OX>8
S9:?TiVLWIZCUijOWibEUIVHU9>HUiB@RX^@TY:BUInTXJ>QWYnRY:6LUI:BTiB>
R8Z8Qh^=QGf2QHJ8Ph20PhJ1PX^DVibPXYnRX9ZMViNNWi:@V9ZIU8nDVj:MTiVU
ZZj/Z:RSW9B>TiB=SIBETiBARhJ5Qh9jN7MgO8F<TI>HXJNZZ:2NYjf]/[^o_KVl
`Kbe/k6YXZ2LVijKThj;RH=mO7n7SIJIVI^OYZV/Zj6NY[:ZXYnJWYjERhj?QH:4
QXR;TiRLXjVa^KZf^;o3`lO=a[nm^k^j^;F[YZ:OVIBGWJBX[Zn^[kFj]:^Z[JVS
XZ>OWj:QWi^JW::MUi^KV9>?RX=jM6m]JfUZL7IhLFeaLF]TIf]VHF9SG59?CDQ6
B4I:DUEAB3`e=SU0B5EPJg1`LgAaKfi]J65RHeeGEe18AT0g<cDd>Ce0@d11BU9A
DeEADUaVIVI[LGA^If5MGemMFU=?DDm8A48n?3dn>cLf>SLc=S]2CE9>BTY7ADaA
Bd<m>3Y0?chn?3i0?S`k>STmAd]CHf]YJFaXIVYbN7QgNWaiMW5_KVeXHf=SI6Q[
KVm^L71aLfmYIFU_L6aZJ6MSH6=WIF=TIFYWG5ACEUUIFUmMFEiSJFmcNG]mQHfF
WZBWXibKVI6BU9>CTY6?SXj=SI2ATI>IX:N]^<2n]kJj_;g0`Kfg^KVf];:_Z:BW
YjFUY::SZZf//KRm`LK9cM?Ce=CAc];Fe]CBe=CBd<c8aL:o_Kfk][>a/[:`[Zj^
Zj^`];:^[k:_[JVQWJ2LV9ZKViVIVIFAT96=RHbAU9NNY:FX[k2/ZZj_/;>^Yj>R
Xj2IUibNW9ZLX9fIW:6RYZVXZZnc/:jb]kVc[ZbZZJJSYZFOWIbIUYBFV9VJViNE
VIZHVYVASiBKX::OViRKXZBPWIjPW966QHR6PX62OgamNWA_LWQkNg]nQXb>SXb;
RhV8RHV5OWUeMG9/IfEUH5iQHV1SJf]WJG1aMGaoOGb3Rhf;QhJ5Q860O7MeLg5`
K6EOG5iQH5]DCdi?CdU3@453@cdf<cDc<2h_=cPa:2LW9b//9bDY<SLi?412ADaD
EeQLGE]JFUYLGV5RHf9RIVY[JVMPGEiNG5aRJ6a^KW1iPh^;QX>8TYRGThj9QH20
PhF6QX9iMWMkOGYiMGEhM75cMgb1PWn0Ph>2PhF6QGihNG]fL6e]Kg5bKf]VJ6ie
N7IhNgn6S8n>Si:ETHf=T9::P7YmPh5hM7AbKFUZJf]ZJfibMWYmPXZ=SXf>T9FH
Ui29QhN8QhF2P7n0QHB0OgelP8J3NWAeNX63OWYmPXB5QXF0O7M^If5NH5iJF5YN
GfE/KFi`MWalOH23Ri2@TIJLWYjMWZ6PXZ>QW9NCU9BDTY>BT9>HW:2QWYjQYjj]
ZZfc]KJi^KRf];Nk_;Zj]k:d^Kbl^kZe/kBbZjNYYZ6NWIVBTIFJUXn;QH:2P7Yd
LW5_KF][K6e_LWAcMG]oO7^1RXf8QHB5RXf>RhR8RXb6OWQfMWEcKFMZM7IeMWAc
MgYkO8>9S8j<R8^BUYRETYBGW9jPXZ:PXJFVXYnMWjN_];:b^;jl/jZWZjbUVHb1
NgUgMG5[If5LF5EEEeUKF5AGFf1UHf9TJg=dLgIiNG]kNGYhMGIkOgYdM7MkOWae
LW=dMWYmNWUlPH:2PhB5RXf<RX^@T8Z6QH>1PH5nNW]mO7n5Q8B6Q81mNgQdMgal
NWQeL6YWIF5OHF=PFeIDF5eKFE]QIF=SJ6icNX>6Q85oQ8^AShf?T8f8PgmmNGQh
MG9cN7f1Q8N;SiBGVIZKWIjLWJ6TYjV[ZZRYYjFQVYNFUI>EV9VJWJ2PXZFW[;6e
^;Ve[k:f][>`[JVWY:2MVifMUhb2NWIbKVIQIVY/KVi/KVm_KFa_MGQcKVm`LGAg
M6m]KFmcNGeoPX>4Q8:5RH^@TY6FVYbMW9B;S96EU9:BT8n?RhN;TYJFUYJGWZN[
[:ZZZjZ][JRRWj6RWi^ETHn;R8J1OGYkNgQdKVmeNGIbLW=gO7emOh:6RH^:RH^:
QH1oPH:0NgE_KgAcKFa^L6mZIFAXJVU]LGEdLGAkOX22QHR9RhjCUHj7Q89oOGeo
PH:2Ogf1QhR7PgmlO7n2Q8F3OgYdL6i/JFEPFeICE5A?BTM4@d0m>CTj=S8^;C8h
>CTd<Bh_<c8`=Sdo?3Xj>c`j>C/l?D14B4U<D5=CCde>CU=IEUAHGF1RHV5TJ6ed
NgioOh:8Rhb=S96HW:6VZZf[Z:RYYZBRXjBSXYnJUiBBSH^:QGijNg]iNG]iMgUn
QHb;PWj3SYJIUY:@TI>DTi:CTi6?RhN8S8f<RHEnNWUjNgf0QXb@TiBCTY6?TYNJ
VYZNX9nOXZFXYjBRX9fMWj>TYJRYZ:FQWj2QY:BTY:6OWIRDTYJLWIZFUYZMW9ZG
UifPVXb0OhJ<Shf8QHF5Q89lMgMkOGajNW]kOX5oOh>8S96GVYbMX:>WZJRUYJFS
XJ>WZ:JRX::SY:2JU9:EVIbNWjBWYZJX[K:f^;Rk_;Zk_lG4`;fm`<6n]Zn][Zj[
YIbETi:@S8J5R8N1O7McLgEbKf]/Kg5]IV9XL71/K6e^L75^KG5cM7AcKFIUIVAR
I6IYK6m`Kf]ZJFQ]LgIhOGn0P8>5QHF2O7UoQHN8R8F3Ph5nO7YiN7b1QHB3PH:6
QX9nOX>;T8n8QX^>Shn@T8n@T8^5PhB6QhF2PH5nMg9`KVeZI61QHf5NG5UCCTY6
@d=2@D=6BDe?DE9EFE]KG5eOHVM[JVQZL7AfMgMeLVm]KFYWJFYXIF=TJFmcLgAe
MWIdLW5`LG=cLG9fNW]lOG]jNgj1PH21PX:0NWV0QHF1Oh:8SY6=R8>0OG]hMG=d
MgMeM7IiN7AaKfa/K6a]LGIgMWMhNG]nP8B9Si:DUi^NXJJ^/kBc];Nk_Ko3aL>o
_Kjm^[Ng^Kbm_KZf/Zn^ZjRWYZFTXYnOXZBVZJVVXZ6NViVJWJ2PWZ2RYJR[[:ZW
YjRXYJ>UYJFTWiB:QXN8PgeiN7QeKVQSGUUEE59AEUeSIFATJFmcMGEeLVm_Kg5c
M7MhN7QjOX:2P7ilNWYgLg1aM7EeLFi_LWIkOWmnOX22Ph>0OWn0P822PhF:SXn>
SY6FVIZHUI>BT8n?TIFJW9ZDTIBDTHf9QH5lNGQfLVeZJ6ISHF1RI6IYKG1`Kg1`
L7=eMGEeMgYkNgemOH25RXj>RhV;SHf>T96ATY>@SY:EThn8PgijN7MbJV5JEU5;
AdM:BdU9B4U>DeEDE5INIFMTH6A^N7YhLfmZIVAQGEYIFUaKE4a5@T91?Ca0ATU5
?c/k?d=4@d93B4i@D51@EUaOGU]LGfI/KFY[LGMjNGb0PH>8SHn<RXfAUYRGUYFG
VibLVYZKWj>VZJf`/K2^[[6f^;Jc]KVj]kFb/K:c/Jj_/:^YYjFPViRIVINEUINJ
W9bJVYbPYJNSX9nNWIZHUYNHVIF=QhN:S8V5Q8N8QH:3QXV;SY:FVj2SYZV//;2_
[ZbZYjBVYjFRWibKVI>;QHB6QXEoNg]mOgimOhF?UiZNXZBVYZ:KUI:DUiRFUIJI
WZ>TXYnKVYVHVIbPYJRYYjFRXJ6PViFDUiZGSXF3Ph9oO7amOGinOWn1PhF8RHN5
Qh^@TY6?SHj@T8b9R8R:RhN0OX>8RXZ;SY6AT8^6QXR;S8^<SiBGUiNIVifLUi:?
RhV7QH9mNGE`JfU/LG=dLfm[IfIYKFmaLgMmPGmkNW]jMFeVI6ARGEQHFEaOGUYI
G65SHfAWJ6QYJFa_LG9fNgikNgioOGQeLV]VHf=WJfi_KVi^L7AjOGakNWanOWn1
PGmmO7]jN7IdLVmZJF]/JFESHF9TIfY/KFmaM7IhNWeoOgekOH66R89kNGj3Q7id
JfITHV1OHfESGEQDCde=CDe<C4mAD4i<CDe;BTa?D4m?DUMHFEUHF5ICDeQQJVe_
LWMoQ8J8R8V=T92>SHnEVIZHUYNHUi>@Si2BTiBCTi>EUiRETYBIW9VETi>CTY6>
RHR;T9BHVYRGV9ZJVYZLWInMVIJFV9ZKW9bNXJBWZ:JTXj6NWYnPXJ:SXJ2PXZBT
XYjLWjFYZJJTYZ^_[j^XZJf`/:n]ZjZYYZ>QXZBVYJ2JUYJIViRCT96BTY2?Si2A
ShR2PX>3PX21QXjDUI>@S8b@U9NFU9BEUYB=Q7ehMFm/Jf]]KFYWHf5RH5aHEEIH
GVAVIFI/LW=`KVmdNGUgM7AgNWalNWb1QXR5PGn1QHZ?TY:@SXf>TI>GVj2QXZFW
YZ>NV9FFUYJDTi>EV9ZFT8^8QH:1PXF:Si:@SHf@U9BEUI>BUYZKViVCSH^7P7]k
OWikMFiYJfeYHU]FE5AEE5AHGV5PFUIGFUeMF59?DUMIEe5=C4a=CDa>E5IEDe1>
DEIGDTe=D5AIFeYIFUaLFUYJFEMGEeQKHFM[JF5KFE]OHf=RH5mPIFU[J6MXJfe`
Kfe^LgQjN7EcLFm]K6ebNGemNGA`KVe/JFU/KFm`Lg^5RXZ7Q8F8Rhf?Shj?TiFD
THn@Shj@TYFFUiZMWYjPY:Z^[k2a/kNi^KRi^k^h]K6^ZJFRXZBXZjbZZ:Z[ZJRV
YJFWZZfa]KRl`;ji][Bb[Z^Z[K2a[JFJTXf9R8R5PX63QhV5P7j1QhR7R8bBVIZH
U96BU9FDTY>FVYjQXZ:RXZ>SXInNX:FXZJRXZ:JRX9nQYZb`[jVUXj2LVINFUiVK
W9fLVINETXb6Q8R@Ti:CU9FGV9NFUYJEU9>DUYRHUI6<R8V:R8B2PhB2NgEaKVa[
J6=RHVAUHUmMGV=YKFaWHf1MFUUJG5mOGf1RHV5MF5A@CDmADU1=C55FF5QIG5iO
HVM_MWb1PGahMgQiN7IdMWf3Q8F5PgmlNgUhNGf0Oh22Q8J7PgedKVa^LG=cLVm^
KFYVHfEZJVQUI6EWJ6MTGemPHfAVJ6QZJVMTHEiOHVAUHV5VKFmZIVQ^M7E`K6UY
KG1bLWAiP8F5PGn0Ph>0N79_KVm^JFEVJVe^KFYZKg=dLVm]Kg5`Kfi]LWQiMW9b
MGMdKFMVIfERHfM]LgQgMWMgNG]lO7YkOh>6QX9nO7alNWQiOH:6QhN7QhR8Q7ej
Nh25QH>2QX^=R7mhMgb1Q8N9Ri6GVYVIVj2UZZb//;W1a/O5a/[?dM3>blW9b<K3
_kjm^kVh^[bo`;bg][Bc/[2/Zjfa];Bb/;2a]KFb[k:f]kB_Zjb`/k>c/:j`/k:/
YZBUYZ>LUiJGV9JARhV=SXV2OG]lOh:1NgIgNGQfLgAhOXB8Rh^<RhN5PgmnOWil
MgAdMWMdKVY[K6YTH69WJV][J6IVIVMXIF5PI6Y/JFERGUUGF5]OHVI/LG=dM7Ih
NgioPHF:Shn=S8Z8QH>3Q8B3PGimPH9nMVaUIfeaLgIhNgj0OWYhNGUiNW]nPhR9
Qh9lN7IeLfm/K6i^K6]ZJfaZIV=SJ6i`Kfe/KG9gNGQfMWMiNGMdLG5bKfQRHF=T
HV1OH6=XK6i_LWIiNgYgLg9cLVeYJF]]KfeYI61NGEeKFUaPI6MWJF]]KFa/KVe/
KW5bKf]YIfMXJ6Y]Kg5aL75eMgIdLgIlPXN<TIBCTiNKVYRGV9ZKVIRIVIVFU9FD
TYBFUY>BT92?T96@TI>CTIBIW9ZGV9ZJV9JCTYJIVY^KUiNJViZDSXf?U9RIVIZO
Z;2d]KVl`LBo^KVj^[Zg/Zn_/[2[Y:2MVYJDU9BEUYNHV9B@T96?SHb>TiJFThj9
R8Z:QhF4QXV;RhN2OWUgMGAfNWn4QHF4PhB3OgamPXZ>Si2CU9:?SH^8QhN6QhR>
Uj2TXYjKW9^KW9jMWj6RXZ2NWIjPXZ6OX:6OVI:<RHN7QH:0PHF9S8f9QH>2P7]f
M7IiNGIbL71^JFESIFQZJFQVIFQ[KFaWHV5RI6ASIVacMWA_K6Y[JVAPGf1TIfAO
G5aMGEUEE5QMHFAVIfU/KW1_JfITIFAQGf9WJfa[K6i`L6iWH5eNGeeFD4mCF5aL
FEYNHfEQFEMMIFUXI69RIVQVHUmOHfQ[JFIWJVe]JFIVJW1jPhZAUYNETH^8QhN6
QX>0P8:1OWYgN7YjO823Q8F7QX=oOGimNWQjOX62P7ekO823Q8J:SI2DV9bMWj2Q
XJ2OXZFWY9^ETi6>RHF3PXB5Q8:2QHF3P7j0QH^=RXB1PH1lMgEcM7EeM7=dMgYm
Oh24RY:HVIVHUYBEU96>RhZ8QH9oOG]fLg1_LGEjOh:6RXnEVYfOXJ>UZ:^ZZJ^_
/JfWY:BUYZFTY:J[/;6/Y::VZJ^[ZZb_[Z^XY:2NX:2MVYVKWIjNW9ZKWIbJW:6X
[kFj`LO8`k^h]k:a/;2a[Zf[YinFT8b9RHV9R8R7R8J2NgEbL71]J6MXJfeYHUiL
GEiRIVUZKG5cM7EgNh21OWn3RXj=RhV7Q8=oO7n3QXV8Q85nOGj0PH:6RHZ9QX9o
NgIaKFa[JVQWIF1LGEmNFUUNIfe_LWEgNG]lNgYiNGQeLFi]Kg9bLFe/KW5cMWYn
PhJ7QhJ7Ri:HV9JDU9JBSHb>Sh^4OgYiOH62OgUdLG5aL71_L79bLVeUHF9RGU]M
H69QGU]LGUmOFeMGFUaLG5YIFeeLGEeLGV5XK6UVJG1cLW9_Jfa^KVi]L71]Kg9d
MGQmPXR:Rh^6Ng=^L7IhMgA]JFMUHU]BCdmADU1@EEYOHEiGE5MKG5eLG61UIVES
GeiPI6Q^Mh6=TiNNXjFWZJ^/[k:f_/6n^[Fd^Kbk^K[0a<K7aLC6b/[5`L32`l;1
_[Vd[JJOViVHUiFEUiVKWYfKVYVIWJBXYZ>SYJNTWYNATiRHTi6BUiVHUI:BU9VL
W9ZLWZ6QWifJU8n>SY6BTI6AT8b9R8N6QHF7R8N8R8N5Ph5oO7UfM7EgMgMeLg9c
Lg=bLgUoPh>1PH>4PWikO821Ogn0PX1oOWf2R8^>T8n>Si2AT8n;RHZ>U9RJX:FY
Yi^@S8V8QGmoOGalMVmWG5QIFf1VKG5bLFm^KfeXIFARH61QHfATHf1NFeUHFUmZ
MGalO7f2QhZ;S8Z;TYFAS8V6PGilO7j1QHZ<T9>EUYJCTHj:QX=oOG]jNGI^I5eK
FeQBCTi@DU=AC4M4AT]>DeMJHFMVI69QHfM[KW9dMWQkP89lNGQfNGenOX:6QXB2
PGmmP8>1OX>8QX:0OWenOgikO8:4PX5oMW9dMGEdM7EeNWilN7QkOhB9TIJGUiVI
VIVHUI:ATHn>SXj<RHR3OgekOHB9RX^<RXV9RXR4OW]nOWinOWj3QGmnP8>8RHnF
VY^HUHn8PGYfLg5`K6]ZIVARGUaKGVEWIVQ]LWAcL6i]JF=PHFM^LgIhN7UkOH25
SIFJWZ6UZZna/:bYZJZWYJBQWYfNWifLViZMXZBTXZ:VZZb[YjFWZ:RWYZJUXj:P
Wi^FU9BDUYJHW:2TYj^][[2d^;Rg^;Zi][Bb];Nh]k>`[jj^[:b/[Zn^[:NUYJBS
XZ2NW9VFTiBDU9:=RHF1OWafLW1aLW9]IV5PH5iKF5IFEUIFEUMIFEUIFEYKG5mQ
IVQYJFU/KFe]KW5cLVm/KW1`KFUWJF]^Kfe[K6i^JFMVHf5PHF=SHV=SHf5RI69V
IfQ/KWAkPXfBSXV5Q8J4PX1oPGehLfm`KfaVHF1PHfQYJfe]K6YXJVe/IfEXKW9b
L6i[JVaaMG^6S8nCV9RGUiZMViRDT8b;SXn;R8N<Si>DT96EUY:>SXj>SX^4Ogem
OGUcKFMRH5iMGf9QGEiQHFAWJfiaM7AdMWE`K6a`LFm`LG=cM7EdM7QnPXF6QHJ8
SI:ETi:ATY6?RXN7QXB1O7UkOG]hN7UlPH>5QHB5QHB6QhN5QHN7QhN9S92BThn<
TINKWIjOX:>WZ:^^[Zj][Jn`/:n_/:n^[Jj`/[>c/Zj/ZZNQVIRJWIbGThnATHn>
SiBFUYRGUYNFUIBFUiFCTI>HV9^MX:JZZ9fCSHb9Ph9oOG]dLG9bKfUTHVAWJFUX
JFa]KFi^JVMUHV9WKG5`Kg=hNGUjNGYmQ8b@T96CU9:@Si:CShZ7Q85oO7UhMgMf
M71^KW5dM75_L71^K6UXJ6U[KVi/JVY^LgIeMWQlOh22R8f>Si:FUYFDTi:BTiBE
UI:AT8j<RXV;S8f>SXZ6QhZ<RhJ2PH>5Q8:0OWmoOG]kNganP8:5Ph60P7ehM75a
LW1[IfEWJ6EQH69SHf1LGF9TI6=RHV1OGemPHF9PGUiOHf=OH69VJfYZKGAiNGQa
LG5]L75_KfmbLg5^Kg1_LW=bM7QeMWQgO7j1Q8>1QHZ@VInSX9ZETi2<RHF6QX5o
OWilLfe/KFmbM79`LG=fN7MjOWmnNg]nPhJ5PhJ9RX^<SiJJWZ>WZjf[Zjf`/K:c
/kBe];>/YjJSX9nLVi^HV9VGTi:?Si6>RXV9QhF4PH20OgioOWn7SI2@TiFIWIfM
W9^MX9nNWIjNVYB<QhF7RHZ9R8Z:QX>1P81oOgilO7]kOGimNWMeLg5_KVi_LWQj
N7MiOH>6R8b@TI2?RhZ<SXn=Rhb?U9JGV9VJVIZKViZFUIFDTY6AT9:FUYFEVIjP
XJ2PXJ>SXj6PWijNWIZFT8b9QH>3P7enOX1nN7QdM7UhN7IfN7UhM79aLW=`Kfmb
MgYgMWUjO7QcM7EdMG1ZIfASHf1NFeEBDeAHFeeQHF5RHfAVIfIUHf9RHV5PH65U
JF]^Lg^2QHF6QhbATi:@Si6AShb8QH5lMg5_KVaXHV1VK6a/JfY]KfmbM7EgNGQi
OGmoP8:5RHV4PH:6S8f=Si>GVY^JVYVLWYbHU96@Shj<SH^;SY2>S8f=SY2>R89l
NWUiNGMfN7]mOGeoPGmmOG]iN7UiN7UkOh1lNGMdLFe[K6]XIVEUI65RHf5PHF=U
J6QWIV9PI6IXJV]]KW9fMGEgMWIiNWIdMWYnP8:6Q862PX60Q8J1PH>4QhJ4PX64
QXN7Ph5oOh>2OW]mPH66R8Z>TiNETi6CVI^KVIRIVI^NXJBTXj:OWj2RYJBPW9ZI
V9RGV9VJW9fOWifKW:2TYJNWYZFTXj:PWIjQXZ>SXZBXZZJPWIbMWIbLViNDTY2>
S8^;Rh^9R8^@Ti>?S8Z:RXR7RHf@Ti>AT8n=RhV7QhV;S8b<SHf=SH^9R8N5QhR7
R8R6PW]eLFi]JVIUIVISH5]HEeQIGF1RI6EYKFm/JFUZJfYWJ6]aMWMfMWUmOWah
M7AfNWajNGYmOW]fM7EiO7akNGQjOX1kNGb1QXb?S8^>TI:BShb9QXN8QhR9RHV7
Pgn0PH62P7j0OWimNgeoP81oOgioOWelMg9`LGIiMW=cM7MiMG5`LgIiN7EfNGak
MW9_K6a/If5NG5]IEe=@DUIHF5ULHFQ]Kfm`LgIkO7YhN7f4QHB3OgioOG]kNWUk
OGeoP821PX1mOh60P7ijNGQcL71aLg=cLgMnPhR9QhB5QXR;Si2AU9VPYJRZZjVX
ZZb/Zjja/:j/Z:NYYj>QW9fOViFBSXb;RHN8R8J3PX1mNg]mP8:0P8>7S96DTXn=
SHn>RhZ;SXj;R8J7RHV8RHbAU9FDTHf:RXZ6P7inO7YiN7QjNgUeLVm`M7YnPH1o
P861Ogn0QHZ=Si6BTi>@RXJ5QH>0OWn1QHJ3PX:2Q8F5QHN<TiNEU9>BTY>DTiFF
V9bPWiZFTi>DTY2=SHjAUIRIVIVFTi:ATYBEUI>BTHf7PX1oP7mnNg]mOgmlNWUh
NGUhNGYlOX22QXV:RHV;SHj?Si:ASXZ8QXF3PH21PXB3P7]fN7j3Ph1mOX20O7Ib
L6m^KFe^LG=dMWMdLW=eMgIcLgEhNWakNGMfMgYkO7j0OW]eL71^JVMWJ6UYJFQY
JFQVI69PGeeKGEiPH5mOGEaMGf=SHfIZKg5aKVi`M7MhN7QhMgQlOWn2PhB4Q8B3
PX:2PXB7RHN2P81oOh:5QhN5PWmhMWYnOGQdLGAkOh>4Q8B1OG]gLVe/K6Y[L79a
LW1`Kg9fMgUhNW]kNgYjO7]kNWYlOh23QXN8QXB5PgiiMG9aLFm_LG1]K6]^LgMh
NG]oQHZ8Ph20PhN7Q8:2PhJ8QhN8R8^?SX^7QXZ>SXb<T9BHVY^MViRHVifKVibN
WifJVIRGV9JCUIVKWZ6SYZRZZZRSXjVa][Jd/K2b/k>b/:nc]kNe/:j^[:VWYZFU
YZNYZZRXYjFSXZ:PWifMWifLW9fMW9^JV9BASi6EUiJBTI>DTXn:R8Z?TY6?SY2A
THj:RHV9Qh5jMG=cLViZIF9QI6ITHF1QHV1NGEaJF5ULGf1QHVEXJVa^LgQiMG5_
KFYXIFASHV5OGf9VIfIVJ6ieNGYiN7QhNGYmOW]gMWQjNWYkNWYjNGMfMWMgMGAd
MW]oPhF9SY:CTY>EV9ZHU92?SXb7Ph21Q8F6QX=oOX22PX1mOGn0O7MbL71aKV]Y
IVI]MGIbL71aLFm/Jf]/K6YZKFmbMWUkOH66RHR8RH^<S8b:QhN6QXJ4Ph>4QHB1
PXB5QH=oO7YfM7AcLWAgNG]lNgj0OGYfLG9cLFm/K6iaM7MkOG]lOX63PX60Ogmm
Ng]mP860PHB7QhN3OWanPHB3OgemOG]gLg=fNgmoOX67SY6?SHb>T9:BTi:BU9NI
VYZKWInOWijKVYZKW9^IVINCT8nAU9NFU9BGVYZIUYFCTi>@RHB4QXN6Ph>7Rhb<
RhR6RHf?Shb6PX1nOGalNWQgMWAeMgUkO7alOGimNgIeMGAeMGEeMGIgMg]oPhN9
Qh:0PH>3PH62QHN9R8R8RHZ:RHV:RXZ9QhN8S92AT8j<S8j@TI2?SXf<Rh^;S8j@
TI2<Rhb=SXb:RHf@TXn>T9>EUiVMXZBUY:2KVY^MWIN@RXV;S8Z4P7inOWikN7Um
OW]hMg]mO7QfMGMkOGemOWmoP820Oh21OWYgNGn2Ph1lNWf0Ph9oNgQiNWUhMG=c
M79`KF]]L79^JVU/Kfi[J6ETIFQYJ6ETHf1OGUiPHF5PGUiRIVMXJ6QYK6a/JVUW
IVISGUiNGV5TI6IYKW=gMW9aM7QjN7EbLGAfMGMjOh:3PX:3Q8F7RHb?T8j;RHV;
RhV7QXV<RhN5Q8B7R8R8QhN8R8V9RXb?TI2?SHZ:S8n?RhR9SY:BSX^;Si>FU92?
TI:AShj?TI:@SHV8Rhf>SHf>TI6@SXb;RXR5PGikNGUjNWYkOX21PH1nOX62PH64
R8V7R8^=TIBFUiRGUiJEUI:?SXj>Si6BTi:ATiJIWIfKVINGUiRIVYRETi:CU9BC
U9JJW9ZFU9JIVINEUIFGUiNDTiJKWYjNW9bLWZ2OWj2RXInMW9^KWIjMViVHUYBA
Shj=RhV8QhJ6QHB1O7MfMG9`KFa[Jf]ZJfiaMGIdLg=cLg5`Kfm`LG9bLFm^KFi`
LW=dMGEdM7EfMG9_K6]ZJfYYJ6U[K6]WI6=UIVATJ6icLg1]JfYXIF=PGEiRHf9R
HVAUIVU[K6e_LWIkOWn0P81oO7UhNWelNWQhMgIfMGIjOX:4QHN8R8J3PX:3QHB4
QHR:Rhb=SHf>Si6ATY>CU9>ASXf>Shj>SH^9RHR8QXB2PH5oNg]oQX^=Si6DUIFD
THn@T96?S8V9RXV7QXN;Si:DTi:BU9BDThj8Ph:1P7ikN7QiNGUgM7=`KVaZJFQU
I69PH5iNHFAVJFYZJfYYJV]]KFi_Kfm^K6a]Kg5bM7MgMG9bLg9`Kg5cMGQiNWan
P820P860OG]kOH25RHV8R8V9RXjDV9VJW9jNW9ZKWj6SXj6RXjBUXZ>VYjRYYJ2O
X::QX:6SY:6OXJ:RXJ2PX:6SYJBPW9^KV9>?SXj>SXnAT8n?SXb:R8F3PH5oOG]j
OH20OWioOWelO7ioOWejMW=bLG9cLG9cMWQgMWIgNGakNWUhNGakNWYjNgn0O7Qe
M7IgN7YlOh61OWYgMGMiN7IeMWQiN7EeNX65QXF8RhjBUYJGVYfNW9NCTiNLViRI
VibHTXj=RhR:SYBIW9fKUiBBT8j:QhB4QHJ7QX9nOGj0PH1oP8>5QXJ2OWj1PGei
Nh:8Rh^:R8R7QH:0P8:3PX5nNgYjNWYjOGmoOWimNGEcLVm]JfQVIF=QH69UIF=O
GEYHEE9ADeMKGUmOHF=UIfQYJg5gNWUjNWUgMW=aL79cLG1_Kfe[K6eZIVIZKW1`
Kfi`M7MfMGMiOGn0OgikN7IdLW=fNGUgM7AeMWAbLWAeMgUhN7QiNgn2PhJ:T9FG
VI^LWI^FTHj>TI>CU9FGVIZHUiNIVifOXJBX[:f/ZJNUXYnOWYnOWj6RXJ2MVYZI
UiFDUYRGU92>SHb<SHj?Si6CTHj>T92=RHJ5QXJ4PX:4RHb;R8R:S8f:Qh>3Q8J7
PWenOWemOG]kO7]jNGQfLg=cLg1_LGEhNGQgNGaoPX>3Q8F7RXb=SY6@SXb<SI:G
VY^IV9RGUiFBUIRIUiJFUiVMXInLVibLVYNCT9:DTi2@TI6@SHZ:RHR:RHJ4QHR:
R8J3P7imOh:4QHR<SHj?Si6CT8b8QXJ4P7ekO7akNWMfMgMgMG=cLg=cLFeZJ6MR
FeMEE5ADEUMHFUaJG5eMGUmQIFQYJf]/L75_KG9iOGejN7UlNgEdMGEgMg=]K71f
NGMeLg=dMgE`KVe^LG1`L71_KFm^L75bM7IfN7EcOX9oOH:4PXF5RH^8R8b=Rh^=
SHf?RXB5RHn=Q8B>Rh>6Ph>6S8N2Q862PhF6QH1oPHV=SY2>UY^GV9><SI2>SXj>
Si:ASh^8RX^6P821Ng]jKViaKVi`LFm[KFe^M7=/IfMZJ65RJVm_LG=fNgMcMg]k
Mgj;RhV9PhF7QHImMWMhM71fNWIkPhN4OGAcN7QjOWilNX1nMgYnP8:2Q8R?TXj:
SHV9TI6ATYBEVJ2UXIjPXJJZZjZRX:FVYZNXZ:Z_/:fXYJNSWj2RY::OW9B@TiZP
W9RIViVIVijHU9bNV9BKWinNWIZGVIVIWYZJWibLViNFUYVASi:=SXb:QH:0OhN8
QH1lOWQbMW1VHfAPH6MYKfa/LFmQH6YZJVi]J6MTH61JF5iVJf][KG1cM7MhLg=i
MgEhMW5fMgYnPGmnPWn2NGEoQgikO7N1Q81oOX9jMh62O8:8QhZBR8B?RhB:SY6O
WYNESi:KUYRIWjFITinXWi>6Qhf6P8>>VIbMVI2BU8Z;Vi=nOh:6PX25O826QX5l
PXb3MgAeMFUgNgQcNH>0QHR8QX5mPh9`LWi/Gf:0QVEVN7U_Mf]GEV=YIV9WEDYH
FUALJ5QFGeYDGEmJGF9C@UEREU=7D65HFea:Ae]MEE]/N6YYM6I^MFYbLf1CIGE]
Jg=fIF:0QGA]N8IfN8V4K6B1PhVBTY>BVJBPUJ6EMX>DRhREUhb7QHjR/JjGT9fJ
ZLG5/jJ^[KBg/::Z`lB_/;f[X[6f`[R/ZjVVZkJXWiVM[Jbl/I6BWJ^k]Z:b/JRS
TH^<Ti:AShj>Shj8T9>CTYVUVWf2WiimMhUoKH2FQh1lLG=gT7MCLG5`KUaGCeU5
=iJnJ5J<]jI@EfeBIGEYJgilOH1QLgUbPEM2R;B1CW^FL6><M71oJg]lMFf;]Yi`
MHVEOGUaEW:KRWY]B4IaVY]WIiB>U;Z^QHRFWKK;/Z>TSjg9^jf:X:bO[lBHN96C
PGeiM8iZDVQiTI=gI6MZT9Y^F5aZQhIiJeYjPG=nRWi]FfRATGMeQ85_MIB8Lgal
JHF[Qf9aXYmdKXIlGcaPRf12AE1<HHmH84QkK7YgBEYbNH9[EfYTKH=gOVa:Dfeb
L8j7IUQTM65NPY5_F7:=ThZ0RI1mS;2IO828PjB_SgIMJhBDR7aK?h2nYVeaRWn3
T9:;SHVDYI1[N:2QShj>TIE_JfmTKYb:EgZ2Ife`RWYRI8:CSZBLNWZW^ijBWJJE
SZ2OUXIVJhR7MGIKI8EVHFIVN6A]M4iQP9j3L7mcQHa/GFmnP8=Y@FZ@T7mcT8fW
/HFA/<70XIf/]9]nPHfJSFZ0V8^HZHf7RGUbS91TJhadHhB7LgN>T7e^PiNLZIB0
_NFaQ8g1`:g>`h^</Z2FWij``K2VX:2W_lRa[kcLh/bCSLkE]ZFYYHnA[81^UIIY
F6Q_M71VL7n2Rhf:OgBKXj2EQiR=PfmlYjZTX9>5Si:ASWm/MYBBKdmLKF65Wh5S
Adm`MEQ3HGYVGhR>DcYFKFE9GUU3Ce=KHdi:GUmVKDeBOGUgKFY_Lg]gKV1QIFia
DDaL@dMIH5U1DWf4LEMQK8Jg]XMlVIF5SXZ2SHVAXj:^W9BIQYVi]:REWYJLX8b@
Y:^MPgNV_:JHZZJHU9FFRhNLWif<Cdj4QfMGK7ebN7^5KVUXM9fGVX]lQ8IfOh1a
NHRMXh5RCV>4KE=4=SEBKWmeCD][K5YZHEI]LVm]JgEiKfEZIGF9OF9GHh64FDMI
J6iZJU]9BUAWEee/M89oNH1kJVMTM8b<P7]lMF>5Wh]nKV=gUYj?Jf5bKY2BMhMm
KWNZ_I1^JiJNPG=jRHZ2R9jEMfnEZ9Z__LBaY[2m]K73d;nVa>?H]9nS/;kIelS8
_Kg=cJj;SJS5_IR3KX>YUiFOSHN@XjJES8nR[ZZKWjNAT[G4^9QmQinKPVb5/k:R
Uhf;[L>eZJnN[;JJSI:AKg27U8EeHVE_M75THE=LIUAPJF5IF6M_K4a<JG5EB61l
L6IRCeeUHVa`Ef5mPFQBFeUACTU>GU]=DFMYHEIJLW=WIX6VXIFLUi:9N8V7KWIh
QH1RDE9QNIZPRGUkRhMdKG6N_[:FPX1lJf9kR7U`OGm`JFE`Pfe[QI=fO::OTjBW
UhjISWR4QhfUYYNNXYnBPIR_a<N_Ui66PY=mFVJ6OXV?LVITFFB1S85mSi9kNg]j
NfacRH9[JEa>EeMLGe18DEaIHGQbGeYUM8:5QIFBQ7YnKfY/IEmIFUeDDeEUGeMT
DV5fKWN7Ri>3NIRHUj>KT85cPYR<NYBIRIbISi25Q8UmJF^5T8QoTIN@SHEkPX65
UYbEXk^cZIjBV9jHZ9QaL7b9Q7YdQJFFNHNHV9>BWIbP[ZNHSGf8UY^HNWb9Lf=c
PGEjQHmlLWQcO7U/RJbJV9b8T9ZGX:VVX[2m^;BXUY^VYhYdMG=VGfM_O79MIhR?
S8aiLWIlUInASX=fPI:?Mg1hK6I[LGR2N6nC]jB7TiFN/:^OZkjn`;6KSYBX/:FC
Y:fMWYF1NGjC/JAhN8N5QX1iMWMkOI6@Q826SGalPh1mOHF?QG1XMHEnJEiRJFUi
PfYIH6abNg][MH2>[[JZYjFWZ[G2Z8F<Sge^Dd]BFEiJFemVL6UEFGF3QGajOX>D
WHagHd13GE8oATY2CeM1?Ta:EFakMG=kJW66S8^9Ph:<PfaZNgY_NY6@SJc6a[FO
UY2=S8Z6QFISTHMaM7^0LG1hMhjVWIbWWH]oRi:?T7UQGUiWNG1OKGQeLg=_KGN1
MgN?TXVN[ZBJOfQnWYQeEe]QHWmlGE=DIViaJUa^NG62XYf5RXn1Qh]oP8Z=Mf9J
IG1hNg9lQhIgI65QHGJ8Q7]dMhB;PV]GCei[IUmOKWj=SgQbP7mbM7I]LWN2NVYX
GV=fM75hJV=hQHR4RYVGV:BOTXf2OWeaJ65[QHB:UHYbKWemMFiZK8>GW9j<LWB>
XiUoQIVR/[Fb[;;:cKFOSXjS[Z>?TJ:XY:NdZInQXZ6R^/>f/l38^Zfg_k6NSXjH
T96S[:RW/[^UTZ>a^lFl`<_0];2YX96I/;>e^JjMUXbAZ;2^/;FbXYfMOUePLGEX
Ig5iNWI[HFE/O8IfIFIgMFejOg1ID59AEEA8A4Q7@dE9BdiIFT]?I7IiMX>8OX2A
VI:0Lf]JB4mEBE5RKG5WH6=OEeM/QGaePX60RXZ2O7QcJfi`F69gIEYRLh1iMWn1
MW1/MX62QhV<TiFMTgn8SGmgPHnP//?Ee<Zn/kJdZJZbYHj8Ti^=MfmjQH66SH25
YKV`X9jX/KJNOWihIf1NH5mVKV1DDeIMIeQ7E5mRK7j9Q8R;OgZ2OGA`K5iIIfIP
J65=E61UIf5MEei`M6e_LgF1PW=dOXB3LfibKgV1PI2JTXZ9O6aZJV=/OhN<R821
NFi`Nh5hMGZ5Uib7M8JTZ:2IRWEfPGf1T8j5P7ikOXEiL7V2QH^JVhfL/;:lc;nQ
Thb1OH>4Q8:6PgYbIfA^LV1LLGf3Q8N?TXn=TifHSI2@Rh^JY[BeY9B8Qhn=OWIo
RH9nTInIUY6<S8j9Qi2CT9>N[:jIPW]hNg]eJ5m_RY22LG:1PH2@SgmmRijUWiN?
TifSZJN?R9BEUHj5P8bLUH^<Si:7Lf=JIW=TD5afN6YNG6A[MhZBS7IXPYVFS8Io
M71dNg]fMGI^KWb6OFmVLi6JT9FHVYbOYYbBWkF`V8E_G5MRKfY/Oi:BPgakOhN>
TiVMWJJVXYbGYZVISHV<TH=eP8AmNX2=UHagJ7>4QH1lMW1eQI2:OG5ZL7MmM5aO
N9:W[::FS8jCThf2PXb=P7emN7I[HUYKKh>3N7=oRh^BV9R=Ng9SDeAEB4MADU9@
C5IFB3da=D=AIWAfKF^0RWmfLFYYL7j2MWAdJfmfMG1XKh:=RH1oQXV8QhR;PWZ2
RHQnK6E^Nh20QYJPWYn@P8:?ViZ=QXnMXiJ4N6ejT81ZJgV5P7IjOhJ:T9^FQG]g
N7f1PWMaO8V;OViVJ6U^Mh:8Ogn7SZ2`/JZJRXB7OgUnQi6APgf2P7E^JVUfNWZ0
MVYbMWMoQ8MoNGYmO7N2VZZUW9J;PX64PWEnU9RDQh29T8QnNh6@VinGTjJg]K>e
[ZRVW96?UIVKXZ:RXYB<TI6BV:JZXYnNUINQXZJTZ[:^XIJKZ;:e/jbTY:R/ZZ:T
ZZ6<MgB3S8=eKVajRhR1RY:>S8bFUXf7Ph:3QhfGU8AlN79aM6m[Kg5VHg5jO7ic
KGEkPi:SWXR0OW=_Ie=@H6YTFUeQF4a4Ae][KVURKh:7Og9dMf]YNG]_I5mOHFM/
L79^JFebMfiQGfQfOWIaMgAYKW=`LVULHFejPhjS/:JFQH2@WIJ;TIN>RHEbHf=R
HF]lR8fBS8NJYZg0c<:WUiB>Q864QG][L85lKfALG6A_O7ejQXb:RHJ2OWR0ShZ1
PHN8QXInM7IlOH:2PXVDWHioP8J5OGIkR9BFQ7j3OGZ0PhB>WIf?R8N1PHAmOH=l
MgUgL75kOG=VGeaRJVITJg=jPX=fKGAiMGQiLg5dOgaYIFmiM61DF6A^KFEVLH2B
WZ2IUifGSXZ8RHV0LfYWJfe/JFIUKVmbN7EeLFY/N8:9Pgb3R8V?UIB@S8b<SYF?
S9NTYZ6OXJ:SVHjDVY>5O8>8SiZPWJ6WYZb]YIbIW9VGY:j]ZJ6MUY2@RhF@WZNc
/:BPWYZBTi^UYYjESXEmQYVPU8N3Q8^EThEgM7b1NFePEUADEUYIHG=gK6AXMGn4
RHMkIUYYOXB6O6ihQH9fJV5MIg]oMG9hMW9fNG^3RXAoOW=VI6YWKG^2O7ElOVmQ
HgN8S8bBV9N@TiNDSXV6PXB>UiFJXZ:OU8b>S8N;RhF5QhZ4NGN6T9BDRW]dNhR4
O85oN8>LZIb@T92EViZIXJne/:bUWYnCN6IZNX>4QgUXKWf;UIFBTiFDQg]gL6ib
LW9fL6MRH69EAdUDHfaWGf1VJVmfMfaVJg:0Q7QYIFieM71SEV1hPX1nR8amM6UN
GV5OFE9FI6MODU5SMH:7Rhj4MWf6S9^OW:6WXYB1LfAQL7IgN7MkPXV=RGmmP8J8
PWioPXB;ShIeLGf7RhQjMGIhNgf4QH>3Ph^JYZJQVINO[[fhZjJMU9JFShZ0P8^G
Y9nCQg]lPh=jLWF3S8V3PH64RiB?OWEhQY>GU8^7U:VbY8b3RXn;PX20N7V6SY>K
WYnMUY2>U9jSZ[2a][JZWI>7P868R7]aJ6amQ8>2OX><TifNUXn6SZ>a[jFOWIZJ
VXb1PXbHV92?SX^5M6MRHFI]KVY[LGYkOhR4NG1_LG1cNgj0RI2CTi29MfQSI71k
NG=^J6YiR8f<R85oRHj4MGF3RHjCRga`K7=fJf=/Nh5kN7]iMWYhL6icN7E`LWZ5
TiNFTXR1NgQaK7J1PX63P7eiLVa[KFmZI69TKG^5PG^6THalK69MIGb9PgUjRIR@
L5YMHUaHHg1_JVQ^OHbGVI65P8>7R8N1Mg=iN6iTH69QG5eKFEeLFEmWJfe[If9R
I6I[M7V7V9R9NWMfLGAiLg>7YK:WVYNOXIVBSi6DUI:9OGZ9Ui26T:>/Y9>:Ri>K
VIbZ]KJ[WiZAPW1QIWIoPh:1PhJ@W:>IPWN0TifNViF@UYfISWmjPX5hMGQkNG=b
MgYlPHN=THn8NfibQI:ARHB0MfiQE59IJGV2QhJ2OgQ^Kg9eNGE[IFAZLgQcJfY]
L6iWIFAUL7n:SY6IWYN:OW=_KfaZMHJ>SXjAUY^MUX^6SYj[]l;4a<>j/JRKVIjO
XZZa/:>CT9^TXIZLZ:n[YZBLVZJe^kN[X9ZKXZBNTXZAX:JTX9bHShN0NW5^L7R1
QiBLUH=hOHZ:Q7efNX62QHZ>Ui^CR7moP7YfM6iWHfE[L7=cKf]REU5FHfeaMg]k
N7EcJf5UKG5aKfaZJViaKFMQFe]LFf=^LVmaOXV7Q81nPGidJF=SJ6miPH>0MVi_
L79cKVi`MhFFXYf=QX^;PGAbNhNBWZZaZinPY9n?P8>@UY69P7UnSYbLUiZHSHN?
ViVATY2=TXj2NG5ZJg1cLW5bL6UUHf5QHF1MGfA/M7MeMGYoNgAcLg9fP8b:P829
SXMkNX22OgYbIEM?DeQFGFaeM6iZJV]bNGUiOXV?S8Z>SHAiKFAMG69SI6mdL6mj
Q7mgLVa/MGf1PGacKWEnPGiaI6MdMFYVKgIeLg=`KgB2RXAnOhN?SHbFX9fERhF2
P864RYJQYJ6GU9JIVY>:Rhn?Si2BUYfXZj:FShnASHZ<UIjV/kVb[k2/Xi^FU9FL
Y::NVIBGVI>AWJne[Zfg`<S>d/o4]jfVXInLWInMViF8O7Z1S9ZW[:RPWZ2TZZj_
/JjSVYNETHb;SHZ6R92IUXN1QhMkL6YUHVQ_LGEkNg=VGUiOHVIXJVa]KW9fNgj0
P7QdNGagKfU/LWA/IVMWHf5THUaLJ7IjO7Y^I6IbO7EVH6UcLV]_MWUfM7EdKfaY
JVmcOhj@Si:ATi>>RHZ<SXb<SXZ6PgimNW5YJWAlPX>6S96EVZ6NTH9gMGUnOGb0
Q8VATXf4P8>3P821PHB3Q8F1P8:6R8J6R81dLgMjOH5nMFiZHeiNGUmRJ75cKF9L
FUMEF5YHEUEHH6U]JFIUHf1OGEaKHG:5R7ecMh5oLFeaM7MdKFAIDeYRIVM]LVaS
I6adMgUoQhnIWIZCSXj>Qh1lMgZ3S92ATIFGUiNHVI^LW9fOWIRBSXb:S9FMVXf8
U:2JTI:BTiJGUY28QXbASXZAVYRFTHZ9RhN6RY:GV9^OXZR[YIjKVIVGTXZ6QXB4
QXB1OgifJFAXKG1_K75jPHN;QW]bLgA/HfA]OHF4OFiPGF5SHFQgOhB<TiVKVING
UiNET8f=U9ZES8AkNh24QH^CV9NJVYNFWJ6PXJ2IThZ2QHV:SiZPViRMXYbBS8Z@
UiVET8jCVYR<Q8>3Oh25Ri6FVZ2PWJ2WZ:BW[k>]YZ2IUYB?RH=mNGQgMG1^LG^3
QhJ6R8N8SH^3PhB5QX>3Qh=jMgUjN7QhKfMTI6I/M7^1QHAoNg]fM7IhOX>4PX>8
RH9gJEiIFEYNIVefPHfCSH9jNG]hLg5fNgn2PG]hOH><SXR5QXAmNX27QX1iMWYk
OGmkNhB<SHV4Ph5nOWYeMG=`M7^2RHj=Qge`I69TGeULIg1gNGQiP85nO7QcLWR5
RhR7Rhf;P7EeMgI`KgEjN79/K75`K6YYK7=iO7YjPHN?UiVHUYBASHZ9Qh1fL79g
NgahLg9cMWYmOGUiO7n2Og]jOXB5Ng1]L7IfLWAjNGEbLG9aL6m]KVi]M7UgNh5n
LVAPIF]bMWMkOh62PXB7Q7igLWAiOGinOGUgNgeeIeiMHf]^KW=jPXfDT8R6RH^:
PgioPXRAV9^IUXn1NWf6SHjBX:ba/kJi][6^Zj^^/;6_[:VUX9VASY2CUIVIVjFf
_l2m^;Nh]:nXXI^FVJFXXj6RZ:fZY:6OWYfJW9jMVIJIW9RDT8R4Ph5mNgYjMg^1
P7inPhN4PhfIVI:9Ph:2OWI[Hf1MFEMDDUQRJg1/J6YZJVYWGUUNKWMgMG5]JVQV
IV=NFUQIFV5ZJfMWIVQ]KVUQH6E[LWb4RHR1O7enMFQSJ7J1QH^AU9ZQXijCR8>2
QXR5QXN5QXV7PX27UIbLV9BMYJJSWiJBUYVDSHj@SXn>S92DTX^6PhF8RXF0PXR@
VInJT8Z6Ph5mMG5dNgmoOGIYI6Q^KVa/K6]]N8:4P7UgNWelMFm_KV]^L75eNGM^
I61NFU==DUeUJg5eNGn3PGejN7QhMVmYIVE[MWeiLVi_LWEeLg5_LG=gO7emNgIc
NGihKWB<W9jKUiFEU9B@Qh60PXB1P8F8PWI[JFa_LG1cOXR@UijQX9jLVYbNWibL
ViREUI>@SHR3O79/LWj9SXn=RXZ?THf7P7n:UIZETYFGU96:OWIgN7MfOHJ6PX68
Uj6TWYJCUinRWYbPYZRPUY2<RHEoN7AhOhB8SiNOXIV?RXZ7OgMcM7MkOhF6PhF=
ShN0Q8f@SX^<T9>BS8EmNW]gL6a`MWYnOginPh^=RhbBV9ZKWYnLV9FCRh1fKfUU
HfM`MWYiNH6=Ti6=RHV<T9>@SiNJUhj7Rhn?Rh9hMGJ0RXZ7Q89mN7UnO7QhNh:=
V9jQX:6PUhEgMGMdKW=lPhR<Shn=SY:CSHN4R8nCTY6>RHR7RXb7QHR<Shn@UYRD
ShV5Ph:2N6YWL7UnNgIcLgAdMG9]K79hNh65P7UfMGAbKfUSHF=VJ6YUHV9QGUeN
HVMYK6eZJg5gN6aMF5QED4eAFF1SHVAXJFUUGU]NH5iJFUmXM7eoOW]jOX63S9BA
R7ejOX:1OgakOX61PGmmOhJ;SHZ8RHj@SXEhL7B1R8=oPhV<RXR<TI6>RXAmP8^C
U9:@Sh^3OGQkPh=nP8V?UI^MWIfIUI>CUIB>QhN>Ti6;PWEZJ6e`KFefQ8b<QGeh
Lg9gLfMSK7^2PH:4QhZ9P7EcOH^>S8fAUYJCTI2@S8N5PhB9T9ROXifDS8R5PX63
QH^EVYVJW9ZKXJ>JTI6FV9NJW9RBSiFLV96>TYJGV9jTXj6NX:2PXj:LV9NGShAo
OX>;SXb5Oh::TYBAUJ2UXj6UZ:FOViVGTXZ0Mg9eNgYfM7R1QhZ7OgYjPH^8NWAd
M7IeLg=]JVY[KW1eNg]dJFI[J5iECe9KHVI/LGMmOgajNgM]IFM^LGAgNh64QXN4
O7EeNGI`JfifP8=gJF5TLGUlN7ImS9BFUI2=S8^;Q7YkPHJ7RHj?QGU`L7MlO7Yf
MGV2RX^9Qh5lO7imNgaoP8>2NW=/I6AYKFYUJWImPXJ8SXj=SXj:Pgj0PX>7RXR:
Rh^=SXb>THb5QHEoMW1_MgaiN7MfNH:<T8^7R8V8RH^<Qh1nOhF:R8F0NgQiOh5m
OGinOGYjMg9fQYBFShfATi:?S8R2Oh62OG]mP7YfMgE/Hf9YLWUnPhB3QXb?SX^=
Shf:Ri2EU96FViR=Og9[J6Y_LW1/L7MlO7QaJfQZKW9_K7=mOWQeM71^L7MhO8F@
U8j;TIRGTi2?Ti^UZ:NX/KRh];6^ZjFPW9NASHnGX:>OVINFShf?RX23T9ZMUi6>
QhJ>UYVESXfAUI^NVI>ATY:=S8n@S8J2PX9jLWJ2SI6=QX5lO8V:QHR9RhZ3NWMe
MGYmOGAWJVa]K6ifNGIfN7QiP8>5PGf2RHeoMg]oOGI/I6QaMWUlN7AcLFi/HUM@
BDUEHV]^KFmbLWEbLgUjOWaiNWimO824QhR8R8F4QHb?R8VCVYR>QH61PXNAUYJB
U9jUXifJUY:CUiB:QhjLXijHUYF>QhZEV96<RHR;Si6>Pgn0OG]iN7n5QHR:QWY`
KG9aJf]WI6ahP860PH9mMW1[JVQTIFERHVM/L79cLg=bLG=cL6e/K6MOGVM/IEeQ
JFicN7QdM7f5Pg]`If=TJ6mcM7=dMWEeMWIaKg1_KFUWJG9gNh>;Rh5iNWanPX>6
RY2DTXV1OH21O79XIV]_M7QkOH:3Ph>3RHZ4PXR>S8J7U9nSXZ2ITH^8QhZ;R8J8
SY>CTHb5PGmiMGV3SI6BTY:ASH^<S9:MY::QZK>bZZBRXIjAQ823SIRNXIfJW9jN
WinKUY2=Si:EVIbITY6EUHf2P8J?VYjLUi6>TI>ASHZ;S8V5PH:2PhbCUINGTHIn
OhF6PgikO7ilNWQbKVm`KFmfOhN<Si6@RX9mPh^:QXF5RHn?RX5gLgIkNgQgMg^3
SY6;Ph24QhAoNgUhMgYoQ8Z<Qh5nOGafKFAQGeYFFV9YL7IgMg]oQHZ=TIBCS8Z=
T92=Rhb<SXb5O7MhOH>8Qh9oOGb0PgilPi>NWIZHUiFBTYNET92ASXfBV9R@Qgml
NgQfM7AiPXR6PGaiMG1_LWEcL7AmQHJ3PWmlNWE]HeiPHVEZLGZ5S8f9P7M`KgEk
NWA_Kg=gNgYeLg9dLg9eNGQcKVYZIEQ<BE5PJfi]LGV0QH^@TiFARH:2Ph20PX:3
QXV;Qh9nOh:1OWf0Qi:MX9^ETiJIUhn:SY>FUY>>RHV9Pg]hNGUgMG=dM7MmPX60
Oh21P7n2QHJ9SY>EUi^OWiN<Ph:4Ph1jMWMkP7ihLF]YJVi`KfidO860NWEbKfa[
JFEWKgYnOGf1QHN6PgigJf9QIgF4SXf8QhZ?T8b8QXJ6R8b?RhN8QX9oOGQcMW]m
OhB;T96BTi>CTXj:SHn=RHF7QhV?TXj7Q8N8Ph66S8j;RXj@ShZ6Q8B6QhN7Ri2B
ShV7RXn=Rhb?TYVPXJ2MW9VCSX^;Qh>1Ph^FX:BNUi:CUiRCQgimOH26SHf9S96B
R7iiM6mYIVMXJVmdMWMeM7EfN7f3QHF9SXn=RhV7QHN5PX21Q8J8RHN2O7YjNWUh
O7n0PX:5RXj=QH1nP8:3PhF:Si>DSh^;Rh^9RXb=S8V6Qhb@Rh1gLg=eMWAdNX:7
RXb:RhjAShb9Q7ijNGQeN829SHZ3O7EaL79fMgMfMGQiNgj1P7inPXN7Q820PX:1
P7YaIf1OI6Y]JfQ[M7j3Ph61PGiiMW9bNH:8SHj<RXV5OgUdLG=iOX63QHAmMG5b
MWQeM7IiO7j0OWQdLg1ZIFATI6IXIfIWIfMWJ6IQGf5WJF]^L7AmPX>5QXB3Q8B8
SXf6OWUhMW9^IEiMH65RI6Y^Kg=fMWAbM7IgNh68SIBKX9nLW:6VXYR?RXR8R8V>
UifKUYFHWj>QWijPY:NWY:6RY:NVX9VDU9FETY2AUinUYJ:KUiRJVIRHUiBDV9RJ
WZ:SWYVIV9FDU9BEU9BCSHR3OG]oQhZ8QHF6QH1kO8:7R8R;SiJPYJBNUY6>RXJ4
PWekNgn2P7emOWinOWimNG=^KgImPH1kMgQkNG1TGF1UIV9NGF1SI6=RIFYcNX65
R8b?TY:?RhN7RHV6PhB6QHB0NGAeMgA^KG5gNgimO7]oQ8B3PhF7RH^=SHfAU9JE
TXf8RI>LWYRDU9BASXf>Shj;QH:2Ph1jNWj2QHR;S8^:RhZ6PWmkN7YnPhN9RXR0
MgEiOH22Ph>1PH60OgemOh64QXN8QhB0P85lM6]VHf5PHfMZK6m`L79dLg5bLg5/
JFY]LgIeLg5`M7QiMW9aM7QmPHB8RXV4OWYiNWamOgikN7QmPh9iLgEfLfeYJ6a`
L6i_LG1[IfI[LgUhMG9cMGMhNgf0QH^@TiFGVYbNW9F<PgimO7akNgf1QHR9Qh=m
NgamOWakO866R8R7RHjBT8fAUI:;QXJ:SI2BTY:GWIjKVIRIVYZKVYZJVY^JUHj9
R8^>Shb<SHb<SHb=Shn;R8B1P7iiN7UiMgAbKg9mQ8>0PhR=Shn?TI6@SHN0O7Uh
NGn7RGm^I6=THV9WKWMmOgeoQ8J5PhB7R8AoO7eoOginOgj0PhJ8R8J3PhJ7QhR9
RXnEUY:@Shn?RhF5QhR6PWegM7AaLGAlPhJ8RHZ:RHV;RHJ8SY2=R8R<TYJCSXZ6
Q8N9QhJ9SY>GUiB>R8J:SXf9QhV>TYRKV9BBTY2<QhVAV9NBSHZ7QH5mO7enN6mX
J71fMWEiOX:7Rhf<RhjATH^4P7aiNWejLFa/KVm^KVicMG9^JVIRGeeMHfieMWUm
PHF5OWA]K6a/JfQTH5iPIFY[If9RJG9fMG9_KgAhNGUjNWj1PGilO7UgN7]oQ8V<
RXF4Q8F5Q8R@UIBBU9JHVi^GTY6ATY>ARhV;Shj8OGAcM7EdLgAhO7elOGimOH21
PHB:TINLWYjNWIN?QG]gMgMdLG=iPHJ6Q85nOhB8RHZ<SXb=SY2@S8Z=THj7PhB5
QhAoOX64PWagNH26QhJ;U9RFUYRHV9JCSXZ8S9:DTHb8PWalOX22QXV:RXZ7Q8F5
Ph>1OWYmP864QXV;Rh^=T92<SHj?SX^:R8N8RX^8Q81kM75cMWUmOh25Ri6DUiZO
Xj>QViJDTi>@SXj=RhZ:RhZ;Rh^9RX^?TY>AS8Z:R8N3OWanOgYdLW=cKfUQG5eQ
IFM^NXB8PgemOWmoOgn0PH:1P820PGmmNGA/IVEWK79iOH63P7UbKVa]LGEfMWYm
OWn1P7ahMgUlO7UhNh25QhB0OG]jMW1_M7IdL6e/KW9dMGEgNh65PWimP8>3PWij
MW9_KFa]KgAiOH23QhZ;RhN0OX22PhF;TYJFUYBBSXV6QhV:RXV7QHF8R8J:S8V3
OgioPH1oOh:5QHJ3PH63Q8B5QhR<T9FMXInHThj9QhV>TiJGVI^JV9B?RXZ<SX^6
QHN9Rh^7PWikMW1/K6maLG5eNWYdJfESHfEWJW1hP8N;Si6>RhR5P7YgM79dMgMe
Lg9bLW9`KVibN7YiN7MgN7]oP7mnOh20NgAbMgn4Q81lNWUfMGV0Qhb<S8nGWZ2M
VYRHVY^HUINMXZ>QWIRDU9FCTY:CTi:@S8V8R8N4PX20PXB5QHV@UiZJVYbLVIFC
THj=SY2DUiNCS8N5P7Q^J6U`N7enP8>8RhR8R8J4PhB6QhJ4PX:2OGIbLG1aLgMj
NgamOWn0P7ikNGb0Ph>0PHB4P7YdK6IRGU]KHFU/K6a^KVeZIfM/M7]nOgekNWYk
NWUiNWj0OgaiNGb2Q89oNgYjNWUhMgUoPhJ;T9>AT96BTHf;SI2CTi>DUYJCT8f;
RHJ4Q8V>T8j;RHV?UIVJW:2RXInMW9fQYJJSVi66OW]jNGUkP8N:RHF2OW]kO7io
P863RI>HUi6<S8j<R8J5Q8B4Ph1lNGIdM7IeKfa[KG=jOWahMWIeL6UTIFU[KG9g
NGYjNGMeLVm]KW=iOX1nO7alO7f0PhB6RhnCTXj=SHf8OgE^Jfa/JVUZKFm_L7=c
L6]WIfaaMGIhO8:7RX^8QhF3Ph5kMWEhOhB5Ph>6RXf@TI6@T96@TI>GVifKVYbN
ViFBTY:ATIBHV9>=RXV:Rhb>TYNHUiNIW:2SYJBRXZ:SXYjLWJ6TXi^ARhR:SY6B
T8f=SX^4OW]jO7ajNGUmP820QHb?S8J2PH61PH22Qh^;R8B0O7QfMGAaL6m_LgYm
O7UhNWYiMG=fN7QiNgajMG5_Kfm]JV]_M7MhNGQhMgAbLG1aLWAfN7UiNWYiNGUf
LFa[Jf][KW=gMW9aLWAfMgIgO8>8R8AoNgUiNGYjNWYlOGajNWf1Q89mN7MgN7]o
PH:4QhV9RX^>Shf:S8n?Si6CTi>AShf;Qh5lO7ioO7YkP85oNGEeMgQhMWEhOXF:
RXZ<SHZ4O7McLG9eNWeoOh:5Q81lNWYgLVmaMgj2Og]kP8B3P821Q8F5QXV:Qh5n
OWejMW5_Kg1aL6i_MGamNGAaLgMiNganPhZ>TI6=RXN5QHF3PXB8S92CTHj:QXF6
RHfBUYVLXZNWXIbHUI:=RhfBUYVLViVGThj<SHj;Q7moPhZ@Ti>CTiBCT8f9QXJ:
SHf;Rhb;R8B1Oh22QXN3P823QXN8R8R6Ph64RHV5PXB8S8b:QhF1O7YlOWejNG^1
QXJ3OgelOhB7RXnATY:@SH^8QXF7QXB2P7imO7QaK6]/L7AfMWIgMWIhOH:4Q8J;
Shf7PhB6QhV<SXj<RHN2O7McLG5bM7EcKfidO7egM7IlPXF7QXR>TY6@TI6<QX>6
RHV;SY6CU9FBSHN3PhJ8RXb?TYBDTXf:R8F2OgajNgn2Ph5mMgAcLWAfNgakNgb3
R8R4PH20PXF6QXJ7RXj@SHR3Og]iMFm]L7IlP8>3PXB6QhF2P8:4QhZ<RhN3P7ml
MFi[KG9eMWQjNWQgMgUjNGEcM7QnPH62QHN8RXb;R8F3PGmlNWUiNWUjNGQgN7Yj
N7AaL75cMW]oPX:0Oh:4Q8:1Q8R:RXZ8Q81mNgYgLg5dNGYjNgamOWmnNgMgNWn1
PH:7S9:DT8f;RHAoOX64Q8B7RXb;R8F3Ph>4QXZ>TiNHV9JCSXZ7QXB1OWj2R8^;
R89nO7]iMWIhMgAbLgUnOGQcLgAdLgEgMgQjO7moO7IbLgAfN7]nP7mmOGakO7em
OGenPX>1OWn4QXF2PH:1Og]hN7UlOX20Oh21QX^=RhV:SI6DUiJFUIFDTi:ATiFF
U96?T9:BT8^7QH>2Q8J7QhR8RXf?TYFGUY>?Si6CTHjAUi^LVYVIVIB>RhZ9RHV9
RX^<S8^8PgilOGj1QHZ?TiBDTXj8QXR=T9:DUYRET8^9R8=kMG=eMgMgMgYoPX>2
OgioP7mmNGQiNg]iMg5[J6AQGUiOI6]^K6UXJVe^JVETIVY_LgMiO7elNg]jMW1_
Kfi]K6eaM7MiNWanO7YhMWEhO7aiMgUmOGYdKfe/K6idNGanOgilNGIfN7aoOGUh
N7^1Q8J8RhnCUiF?RHJ7Ri6FV9RHUiNESh^9QhJ5Q8F8RXZ:RHR6Ph64RY6EUiVL
WI^GTHR2O7MgNWj0P8:4QXN8R8N3Ogj3RHZ:S92EUiF@SHb8RHb;QhF7R8J1NgMf
M79bLW=fNWf1Qh^;R8N7Rhj>S8V6QHF5R8^<RHF6QXB5PGYfN7eoOW]iO7mlMW9b
MGYmOWimOGakO7akNgj1OgekO7n1OWf1Q8J7QhV:RXZ=Si6CTiFFU92@T96BSXZ:
SI6ASXb<RhJ5Ri6CTi:EW:6SXI^DT96CTXj9QhR9S8f;QXB3PGmjMGAdMgf2QhZ=
Shn?Shj>SHjAUIRGUIBCT8j7P7mkMgUlOgafMGAdLfm[JFISIg1fMGAeNX60NG5[
KW=iOg]mPh1mOh1jMG=dN7Q_K71aLG9fNGI`L79bM7UjNWioOGQcKfa]LF]UIVY`
MWUkOGinN7EjNgMeLgR1QhV;SI2DU8j8PGehM7EjOX63PHJ=T96BShb<T9>DUI>?
T9BDTHn;QGn2RXf;QhB9T9BEU9>EUYBAT8j;RXZ;SY2AT96@Shn;QXB;Shf:R8F0
PHR4Oh65R89nOh:2PX5lOH>4QXZ0M7V8RhbDUhf5QH=kLF]ZJfaYI65VJfmhTJfQ
Ide4@DY:AD14AD];?DaLB4ENIUA6Ae=JH6iaJ6UdM71nUI^HW[C?dLFl^/_PkOKo
oocZ/hVEYZVZ/JIdHWR;Uij=KUmJC4IgT8Z>MXBBO7F1VI5[IH64L7E`DTecPe`n
DEY;B3/]:C<[<3lm=C4f>c4Q7B`b<4IHIG=fNfiJGVYmUIR2NhfGTYjPX/W`onW8
ZkCGlncIcMc^gMCLjN[Cal[3a]CPg];8`loCd/Va];^`][flc/Bk`;:`/9nMY[>c
X9fUWi:5P7n7PW=eOH:8Qh1mOh1nPG]jNVE9Ce5BBS@S8RX^?D11AT0^<CPk?4=0
?3Xd<C@m?BlV<Cm=G6A[LgU^Fe93=38h=Bhg>2dR71DD6ALB5BTg=RdYB5e<B4iD
H6a/HEMMM7M_M7f>UiZQXjJ]_LG5b<30a<:k^lW7a<O2a<gBcl6i^k_8fn3Md<:k
^K^f];_2`l[Li]kNlOknooobhmKBg^7NinCGeLg5hoonl^SUfMGDen7Thn?MeM;G
i>KBa/O7_[Fa]k>RXijHTHj?O75iOgQ]JFYSDEQYJ61SHE]JCdY@D4=3BD0_;Si1
>c4^:R@D1P0000/G6aPJ7QX5000000802@P520H<1000000000PH6`X00000004K
8BD^>3lj=cDg<RX`=38i>C]8Ce9HH61RLFeNF61ZIV9[MFeJEeQOLh6BSg9`Q9NU
XiFFUI6KVINLUij_]lC:b/G4c=W[oooojo?jmOooooWSk?ooooo[hNgoooomnoSU
d=chlMWEgNO_l^cWlOook<k=h_7`iNGUdL79d=3Bc/W6`/[Ec[fjb<neVjVf/9^I
/:1kS:NKTXbAVIBCUIZ?O7MmM6QgQ6iJH6USE59OGE1AF5aMFUeODdYCEe=7@D4c
:bhnC48_<3Hn?cY1B4A7DfAXFe19?T59@CTj>S/_:Sa=EUEADU9<DTm1?c/b;cm?
@SPn?CeAJ6a/HVAdJ69PFfIgMVYVJg5fOWMkUIbBTi>EWZVg^K2PUIVLVYjLW9NA
V9JCSHNLZZ2JWj>Z/[W0`K>QVYjUXij@PXjJXKBg/kB//Knj[Z:HY[Zn/jR/YjB_
[K6f/JjZY:^/X9N?U:6APhfLWHV9TI2=PGEfN79ZIV=RLX5nKVY]KgYZGVQVE4]T
M6==@3di=Si=E559>B@R>THo>34iC4/f=4Q3<b`h?2`R8cI;De=BDda7G6YUEdMC
H5EBBCPk@C/h?4aSLgATI6MIEUUHFVMbLgAcJVMaNWZ=Vi^LY:JHV:2S[JnU]<S5
_/G5`L?4`;Zma/_7^J:Q^;JLZ/?2]JBQ/;bc[;B`/;JaZZ>__lWBfo;nlmo:/j>[
`M;Ie<c3bmgQd/71aL?4blW4`L?7b/o:]K>aZK>ka<c4a:^=WjN[]J^NUHamL7jJ
[JN@O7V0OgAZKgYlN7MdN7=PGVU[IfYQFfY`KEi<BDiNIV1BDVIZHE9AFEeMHF9A
@DQJHe]=CeQGEe]JF4e5=SI;EU9@HFaQF4a7Ff]VCTeRJf]/LGQbFeE/K65UI5]=
AdQ?EeeVIUmIJH>4P7]^LWA_NHfFVj6NWibLZ;2cYIJGT9>S]K>QZ[c0/Y6@/[fb
Zjnk`:^MXjBZ^[Z/X::]_lVcWIRATiJFTXN9TI>GW8mmPhV;W:2QX9J@UYB=VZ>L
V9>FUXf@Y[6MRHb=RY2>V:^CN826RY2BWjbWXYfO/:^KV9B>R8Z<O6YdP8J:Pgao
Pg=QGV9WKg5[K75_HemQEUYKF5aHDTE0ADM1;cEBH54j:Re9DDDk=Sm:C4Tm>3`a
;CXi=d0m?D8mB4e0?C@]=cm2B4]CH6EaJEaQIg1WFVMeNGEPB4I/RXMkLW9nQWU]
OH5[EeI[R9fRVX5dRZBWXiN9V;>gYj6OTinf^J68PH>;Q7n6SijEOGUnQHnDTHb3
OGaiNXF3OHF?UY^CPXVJTHAkR964R9ZOSgmoPh^HV9:GWIVQYiR>QX>6N7bGVhAh
S:>PUYRTY8n4TJ:_/ZFRZZVHS9FOXZ6LWJBNU8n:Qi>PYjNHTZ2Y/;faVinYY9^K
WJBc/j:LX9ZHZkFKOh2EWYVHX:JKVj>LT9>IUIbOUXb2QYf]WXfEWY^CTJ>_V8:9
TiFHUXb3RHEjPXF0PG]hQ9:DS8fEU8bBVi68RYRQW9ZDQ8>AVi5jJ6b6S8R>UibB
QGE[N8F5Lf=WLWYhMgb3PgE^M7agN8IoMH:CUXV0MFikT9J<SINIUi^DPHZOZjRE
S9V/[jf/ZZRWYj2NXZ6WY9JH[Jb5N9>XZj>@Oh:=RgmmO7EiRiZ<MgF2S8V0NG^:
VYJ7TJ2JSH9mOGN5WI>3RY6>TiF5MVeWJGJ2O6]^OX5jMW=XJGMeIf=WGTI1Ef]X
FTE1CeYSE4aBAd97AT92BDe8ATA7D5E>?T=CDdiHGeUGFEI>BU9ECTI7BT]:BeAK
FUQIFe=>F5iNHEmQJVUIC51?Cd]6ATU7@DaEEeEFH5eAD69gNGMhM75[J6mbJFAV
J71iNGIeMWMiOWEdQhMmMFedPHbBThn3Nh>GWYbNWYR=SifGRi:KXJjZVY29RhR7
Si>IViFIVYRJUY6ASHN:Uj:TZ:BGVIbETXZ;S8ZBWYfBTHj8RXjCSi2GUI^LTiBJ
TX:0NG1cNXF;R85nOX66PWmlMGAhOX:2RY2?ShnCVI20R9bMRWMaNi2ER7]iP8B:
SHF5TiB8QHnJXINATXVDXHn9TiJIViRDUY^LUiNARHJ1PHnLX:BPXJ>FSi2FWjNX
ViBRXiF?UIVHWJF/[K2bY9RMYZZ]Zjfg/inEUibOVYjWYJRTUi6GZ;:f^;:WYZV_
];:VThbDWjBXY9VJVHj7SI><QG^1UI63NgV0R9FIS8B3OgIdMgYjO7]fLgMjNgac
K6UUGeUQI6I]JV=VKg1YHf5OH61PHemRJVANIg1_LW1UJG=lPW]fMgUkMVaVGUeX
IEULH6MdLVeeL5eFGF]bJV=LGgB0OGY_J6edM7IlMgAfNh5kMWQjNG9]Kg5cNh:5
QH5mPGmiMfaVL7b5QhF4Q8AlMWZ2RXb1NX27SHj;PW^1TYR@RHVBThfBThb:RH^F
UhZ8S8Z7PXB?UYJBTHf=TYBCTiNOVhZ1Phb<Ogn2NWAeNGUfK6MaOWiiP8Z?ShnE
V9RCSY:KWI^GUIZIU96@TXn7Ph22Q7ioRHMoPXbIWIZDTINNV9VQZ:^TV8n7QHZ@
T8f<SiZUWHR7TiRFShnEUY2:QX64S8f:QH>=THb@Ui^MViRGU8f5Ng9`Lgb3QHV9
PhV=PGZ1PWilOX5nMg=fMW^4PgM_L7J4QWY`KgEdK6QYK71gMfUSK71`KfY_LFQW
IFAXIVASIFiaK6MPHg=mLFEYL75[Kg=XIF]YIfE[NgabLG9cL6aYHUeLFUaQHV5O
G5ePJGN0Og]hM7EoQXN7OgAeNGQeM7MgM7EgLFaZIfa`J6EYLg]dLgM]H6YmOWIi
NGb6Pgj5SXf7Q85nPH1mQ8b:RXb5O7IgP8B2PXB0OhB8S9BHT8N5Ogb4SYFGVINA
RhZ2MGAlQ8=lOHF>T8b8QhjCSi2DUI6<T92;SX^1P8N9RH^;RHB3Ri>DTY6:O7^2
PX1kMGEjNG1gQ89dKFeaNGI^M7MgPHB1Ph^9Ogj4QH1mPHV=RHN1N7ElR8EiNH20
OX22OGZ3RHV5PHV@Rhf<PGQhPXnFUYFNYIfCTiFAUYbHVj6OW9bOY:VSV9JDTY6E
W9fQZjbWXYbHUIBEUiNHWInTZJ2HW9bFTY>?SI2?SI>KW9J>Si^PVYJETI:EUiJA
SXf>R865Ri2JWIZKWJ6NUXn>S8J5Ph:9SY:CT8j>RXB3P7UhNgn6RHf?SXj8P8B8
Qhb>RH>1P865OW1cPHB3Q8N4O7QgMGMmOWE^LWUhM7IhM6maLfiZJVIRHfIZK6Y/
K6ibLg=dM7=`KW9dLG=hMfaTIfY/KVe_Lg5]L71`KVQWJVe^KW5hO7Q_KG9bLG=c
LGAiMG9fMg9^KW1[IW1nPGYbM7UkOGmnO7QhOGn4T9B@R8EoNh:8QXJ7R8fDThn=
RHN2N7IkPHZ=QhN=RXF:SH^5P8>=TXf:Ri2ETi2:Ph63QXR4PH:3RHn@SHZ:R8B2
QHV>T92AUIJ>RXN2P8:6QX>0P8bFTHR8QX>6Si:?S8Z7RHN4R8J0P8>6RHbAT8f=
S8j=RhR6RH^<RhZ;S8f@THf8QX^AUiN>R8V?Ti>GV9:<QhF9RX>0PX=mMWEbM7f3
Q8V@Ti:@SXj?UIbJTHb<Si:BSXV9R8=lLfm_LG5`MgemNWEfOH67S8Z;T92=Si6<
PgmoP820PHB8S8j;QhR:R89nO7^2R8Z9QHB5Ph>1Ng9aN863P7n4R8QoO7igKVa/
KFm^KW1eN7A`LG9dL6UXKVi/Kg5aKV][JfENG5mQI6Q/JVIWJ6UUH61RHf=SI6ER
HVMZIf9MG5]FEeaLH6IXJFY[K6ibMWUlMfm/Jg9lOWakNWYjN7IjPH5lNGYlNgE/
K79fM6m`M71]M7]oPhB4QHF8R8J6Q8>8SXn>SX^:SI6<PWn3QX>2Q8R7Q8R?SHN6
Qh=nOXB:SHf8Q8F:TI6<RHN:T8]oPHZ<RXZ<SX^4OgamPXR;S8n@T8j:QXR>UYfQ
XZ>TY:6KUYFEU8n;RHN8QXB8RHR8S92CU9NJVi^GTYBJWI^GV9RIViF<Ri2EUXn?
UIVKUhn;SYBCT9>FU8j7PX:4QX5kOHF:SHj;RHZ9RHb>S8R:SY6ASh^9R8V:Rhf=
QH62PH62PX>7SY2@SX^5Q8B0OWajMgQnPh1mPHN?UYB?Si2>SI2BTXn9PginPXF4
QHR6PX:6QX9nNgemNWEbMGZ2R8V8Qh9lNGZ0QXN3PHF5O7=`LGEhNgYgM7=dNGaf
LgEjNgQdLFeXJ6a`LWMkNWYjNG]mOGUeLg5_L75^KW9cKfe]JfEUKgV0PWagNGn2
Ph>4QhZ;R8EnNWamOGUdM7^2PGYeMgMcLgQkOX22Qh^;QhF6RXb=SXf=Shj=SXj:
QX>4QXN9S8n?SXf<SY2?SHjAUY^MWZ2PX9nKVIJ>QhF4QHAnO866QH>3Q8B1PhZ@
SX^<TIBEUiRARHF5Ph60PhR8Ph61PX5oOWYfN7YkOh62QhZ7PWenPH:2OGYmPXJ7
QX:2PGejNgajOHB5PX>9SHn>S8V5Ph>5R8Z;S8V9Rhb<R8>2QHN5Q8F3P7moP85o
Ng]lO7j3S8n?RhR:SY2?SXj>S8^<RhJ7RX^9R8J2P8:3PX>6QhJ4PGn1PX64QXF3
P7ahMWMkOGioP8:3PX21PX9oOWimOX:5PX1nNgUkOX:7Rh^7Q8>5QhV6Og]jNW]h
LVe/LGQjMW5cM75/LGb4QH:0OX68Rhf>S8V6OgUhNGQdKVQVIfQUGUULHVATHf9U
Jfm]JFQYJfa^L71aM7IdKVMSHF1PHVAYL79aKVibLfmYIV=TJG1hOX1nNWEbLG1`
LWEfMgQgLW5cN7aoPH60NgEbLgQnPHB6Q7mlOGmoOh>8S8n?SHb<RXEoO7j4SiJC
SHfBUIB?S8b?Shb9R8V:R8B2PX:2Ph>4Ri6@SHj>RXF5Rhn>RX^<R8F6RXb?T8j=
Si>EUIFEU9>EUI6<QhB5Q8>6S8n<QHB9RhZ=U9bRWiZJViZGTXn=S8f=SYBJWIZB
SXj>T8n;R8F1PXF8S9:EVIbMUi6>Shn>ShnBV9bLVIFASXj:QXB6Ri2@T92=Q7ai
NGj4QhZ=SiFKWIZFTi6>RX^=SX^6OgioNgIbL75dMWIfMgUnPXN8QXB5R8Z;SY2C
UYB?Rh^<S8b:QGmmOh5oNWUkO7ejMW9`LG=dN7alMfm/KgAgN7UnPH1nOGj0Ogaj
NGMgN7UgLVi`LW9_JFU^LgIdLg9aLFiYI61LG5iOHVMYJVYWIVQZJfeaMGMeM7=b
LgQlO7UgN7QgMWMhN7QjNgMbKFY[K6]_MWUkO7n3QXN5PX22QHZ?TY6ASh^9Qh>2
Ph:3Q8B5RHb=SHf=RXJ8RhjCVYfOWifNX:2MV9BEV9jSXYjKVIJBRhF1PHB7S8j@
UIZIUY2;RhjAU9>BTI2BTi6BTi:AShb:RHR8R8F0P85nNgYiOH:2PH65Ri6ASH^<
S8Z6QHR:RhnCTXf5PH:1OgalO7]kOhF;Shn;QhV<Si2ATYBDTXj<S8V5Ph60Ogil
OGj1Ph>7S9:EUIJCT8n>SH^:RHR5Q8F9S8nAShZ4PGilNg]kOhF9QhF2P864QH>0
OWf0PX5kMWQoPgieK6U]LG=dNX::T8j8QHB3PH:2PH65R8V9R8N6QH=nNGMiOX20
OW]fLVaVI6EUIfY^L79bLG9cM79`LgZ1QHJ4Ph:2P7YfMGAbKV]XJ6a`LG=eMG=a
Kfi[J6QVIfMTHV9QGU]JG5mQHfATIVU[K6a[K6m_K6YXIF=TIfeaLFm`M7IeM7Ac
M7IiO7ilN7MhNGMeMWUhMG9bLW5_L7QoQ8N;SY:GVibIUI:BU9NLXJ>RWiZET8V5
RHj?T9>GVIVHUiRKW9ZJW:2UYjBMVIVKUXn:RhjBTi:?SY2AShb:RXZ;SI2DUIBD
U92=Rh^8Q85mNg]nQXb@THf8Ph1nNWA_Lg]oOWakOGn1P7ioPXF7QhB6SIBCSHIo
Ngf2Q8F7RXnCTXf:RXZ9R8R8QhAoOH25QX9nOGn1PX>5QhR9RXV8QHJ8QhAoOh:4
PGinPXJ:SHb<SYBIVYVIVIRGUiJBS8R6Q8>4Qh^;S8f@Shf?TI>CTHb9RHb?SXf?
TIBEU9:BTY:CTi6=RHN8Rhb:RH^>SXf=SHn=RHF2P862Ph>5R8N5PWmmP8B8Qh5l
Mg9/If=QHFAZLWQjNgn0Oh63QXR8QXJ7QhJ4PWmiLFaXI65NGF1RH5eKFeaMGf5S
IFQYJVidMWIiOGijLfeYJ6QYJ6U/L71]JFMVIVQ/LWEfMgE`K6YYJ6QXJVa[JV]a
NH25RHN1OGalNgMcLG=fNGYhNWj0OgioP820Oh63Ph>6RHV3OWn3Ph61QH^=SHf>
SXjBUYJEUIJGVijMViNDUIFDU9:@SXb:R8J3PX>2OW]mPhR8QX>6RhnBUIVKW9nN
VYB>RHN7QhN9SHn=RX^?Ti6<RX^>TYJJWj2KUYBATI>DU9>BTiBDU9>DUI>@SXb9
QH>3Ph>7S92?SHf?TI:?SHfAU9FEUifSYZFQWYfJUY>@SXb<RXR7QH>1OW]kP8>4
QHF2PXN>THj:QhF1P8:9T96>RX9lNg]jMWIjOh1nNWMiO7enPXB9SY2<R8J6QhR7
PGYdLgAcLFm^L75dN7anOh64Q85lN7EcLW9bLgAbLG1aLgQlOWmoOWYhMgEbKfa^
LWEiNW]lOG]eKfa]L75]JVQUHUmNHVIZKFaXIFIZK6][K6i`LG=eMWIfMgIfMWIg
MgIeMGEeLg1/J6MXJVYZJVYXIVIWIfIWJficNX65QHB6R8N5QHJ6Ph:1PH23R8^<
Rhb<Rh^;S8b<SHn>SHf<RH>1PhN8Q7mnPHF8Ri2BTi>ARhJ4QHJ7QhN9RhZ8QH61
PX:0O7^0QhV8R8b?THn;R8J6R8V6PX:4PgeiN7MfMgYnPXJ8RX^>T9BHVibMVYFA
TYJJVibKV9JETi2;QH>5QhN7RY6IW9ZHV9VIUi6<RhjBU9BBT8j?ShZ4Q8R=T96D
UINHVYbMW9^HUI6<RXZ;SI2CU9RKW9ZFTi:BSh^7QHB4Ph>3PGilOH22PX>1Ogem
OG]kNWUiO8:5QXJ4PGemO7]jNGYlOGemOGn1P7ikN7UnQXV4OWYkNgUiOH61P81m
MW1^L75_K6QUIf]^Kg9hOGmnO7]kNg]nPXB3OWUeLW9eNgelNGIfMWUkNWMhNg]h
MG=`LG9cMWMhN7IeM7=dMWIeLG1`Kf][KVm]KG5aKfe^LWMkO7YgMg]nOG]mPH>7
Rh^7PgmnO7QaKW1aL71aLW=eN7YmPXJ9RhjBUiNETi>CTXn=RhV;Shn<RHN5PhB1
O7n3PH>:Shb<SH^<SiBGUIBDTXj<T8n:Q8B5Ph61P81oP8F8QH>3Qhb:QH1nO7Uj
Ng]mPH>4QHB4QHR>T8f7P7inO7QiOX62OgamOX20OGMhOWemOh>9RhZ7QHR7Q8B6
R8^<RhV7R8fASH^AUibRXYjHUifOX9jGTiBDUINJVIVJVINBSh^8QX>2Qh^;SY2?
TIRMW9^GU96?SXnBTHj>Thn6QHF4Q8B7Rhj@T8b;RXR8Rh^:S8Z8RH^;R8:2QX=l
O7n0PhJ7QhEoNgYiMWIjNW]iNW]iN7QhNGUkQ8R8PX>6QXj?S8V5OGanO7MeMFa[
L71bL75dMWeoOWn1Ph61Q8J6R8B0OXB6PX22QXEnO7moOgagM7=gLfaZJ6ecLg5/
KgMgLg9kN6U[L6e[KVQOJ71aMWYlNWIiNW=bMW9^LG5^MGA[IF=ZKFedNGIgO7am
OGUgNWYkO7b0P7akO8:2P85oOWinOh1mNgf1PXB7QXF5QX9hNHN3MWn@SHR7PH24
QhV9RH^7PhR:QHB6P7IgP8J9S8V9RH=jMWYmNgMgNGaoOGMhOhF8Rhj>S8R5QHJ5
Ph1oOWalPH=oOX1oPXN3OWUeM7QnO7n4P7elNWamOgmjNGj4QHJ8S9:BSi>?QhF3
PX:5P7YkOH69S8R3OXR?RXV@THfCW:2OVi:;SHb9Ph63QH63RHZ6QhMnOhF9SXjB
UHj=TI6>TIFGVIjOW9ZLWj2HSXnBU92AUY:?TiJEU9BDTiBHW9VBShb9SIBEThn=
SXn=RXV8RHn@Sh^9SI6?RXJ6QXJ5OhB:RX^4P8:3Q85nOhF4OgUfNWn3PX63Og]j
NgQcLG1eNViSJg1`KgIiN7afL71aL6eTGV=ZK6icMgZ0OWI_JfUYJ6YeO7YhO7mo
P85jMW]oO7]hLg9cLVm/If=QFemXIVMdOGalN7QmNWQcL6UQLWikOH1gLGMcK6]/
M7j3PX>5Rhn:QhR7RXN4Ph5mP8B7Rhb=RXZHXj>MV9BFVIFCTi>DVYbKX:BPUhb;
T96@SXnDV9bLUINPWY>:PGejNWUgMgMkPH5dKgMlPHJ6PH>:RH5oPhN5R8f8QhAn
OhF5RHJ1QH^FXJBKWJBZZI^:PY^LPgj;SXB7Ogj7QGijNGIjNW=iQX^@Ui>CW9jA
RY6BShR5PG^1QHZ<SHEiNgn2QXbCUZ2QSXR7QXR0NWYiN6mVHF9OHg=cKFYYJ6en
PWinOXB6QX:6R8F6PWE_MGanOgj9S862LfMfNW]iMgf0PH:6R85mPH>7RX^5OGE/
KFifNW1bOHJ:OWZ0QHf4PH=mP8R8PgeeMGMbKfe]KWElOGUgNGMnR8N7R8R:PWI_
KVeYHUYYMFmZIVUeSI>8Q8F7Q8bEUh]nQXV9QX=oOWifL6m`Kg:1OhbOWIVBRGj2
RX=cJVebO7]iP7f1Q7mdLg]lQ8Z;SIJMU8MlNXJGY:6JUYNT[jj[XiR>R89mP8F4
QhZ5Og]lPWi]K7I^KG^2QhN4R8jDR7U_KWMoPgf4SX>3TXY`K7QlMfeUG69/K6eb
OhV6PH^KXYZ@SHf3NgYnPHR>P7EgNgQ/H6=RG6IbOhV8PGn:Rh9hMW1UIfeYIG=j
OGMcKfU^MGA]LX6:TYR;LVUXK7IiM7=nQY2?Og^1PWmnP8^?UI^S/;:`Yi9mMGAm
QI2OVIJR[ZRKTi2>P7Q`L7f=TI:FV9V>TYR8OX21R8^8PX63R8^2OH6BW9RLYK:e
/[B`ZZJPV8f8SI6DRW]dLW1bLGJ0N6]eQHbFVYfOVYNIUYJPU8F0O7ehNGahMWQi
Oh:2RHf;QX5dO8j>S8fEWZ2MX9nEShj3Mgn9RXR7QHfARGmeK6AXJfMiRX^?T7mg
O7AWI6E[LgEaLgb1QX1[FEYWKWZ5R7inPX:1LFMOFEaMH6AePh>4PhAmO7f2PGUm
RIZNWibAQgecIVA[KfYXMHVIYZJJUi20M7^1OX1mOgYaKWV6PWYkOg]nO7IkQhbA
T8=nOWikP8N5QHb@SHf6PhR@TXb5PH5jOh>5OgMnQ7Q[Jfe^JfabN7]jNGAfN7Qh
MgYlP7IUG61UIg=oQXAjP89hKFIZLg1YKgj@VinLTiNRXI>6PX25TIfUX9FBU8n<
QWMeMgYnRiRDV:6SUhb=SiBBShf6RH^<ShMkMW]lOXF2OWj4T9RHTi69Ng=fNWf5
S9BDOFITLgemNWb3S9RQYZ^bZib@R81hMh:?W:BJTiFKUXR1PH9oPXEoNX2;SH>2
SI:?RHfAU9>=Ph1lL7AeM7YoNG1fOhB6RHb>T96?TY>>QHR@SXMgKfm_JfIVJW9f
MGAjMfmcNWilO7YgNh>3NFeUFe9CHG5`LG9eLFa/JF]TIG=mPH22PhB5R8f8OgMf
MgZ0QHZ:RXn<QhR9OFmYJgMmNgf?WY^:MFY_MW=[JFmiNGN1QhV4NWA/JG9fOXZB
UY>@T8^1OhB2NWV0QHZ;R8MlM7R5ShR5RHnHY:^XWhn1O7j1Ph>2OXJCVI^JThV4
OhF?QH26TiB9MV][LgA`MGf9SXZ2OW]fM7V1Q8F3P7enP7n2R8Z7R8ZAShfAU9FA
V:6MSWn3SiNBRH5mPXN1NG5[KWb9QhN:QH:;THb7Q7U/JGB8SX=oRINERgQTHFag
NX23Oh>:SY2BTI:HW9B8RiROX:6GTI68NWJ0OWQkQ85iOhN@T8InOhZ?RhEnPhb=
RH9eHUYPJGJ5QW]dMGAfOXInMW^1QhV3O7j6PgESD4M9DU]TKWQmQ8f?Shb;Rh^:
PgelOX:8TIJGSX:1PWahR9B;Ogf1PhR3N7n?T8R6QXR@UXf7QgeaLGEgNGQfNGin
NX26PX>7SIBDRGn3SI>GTX=mPGmiN7moOh9mLg1eNWn3R8^=UIN@R8F3OGEcLg1]
LX6:PgEfOX9jKVYdQiFKX9fFS8J1PXJ3P8bLX9jMV9RHTiBNZ:2@SiBDSXb>U9VH
THEjNH64QXj?RH:2OgUoQH9nPh=kNX>5P7mnNWUnP7YdMhFFU8EhN81lKfATKG9g
MWEiOhJ8R8R1N79dO7moNGQnO7MmSY23O8>;RXF3P7aoPWiiMGI_If]`MWn7RXZ6
QH>6RHR2OhJ>Rh61PG]iPHB2Ph:6RXb7QHnJWYnOW9nUXi^IUY>BTHf8PWanQXnD
Si2BSWebOXj9OWj5QXF2O7f6RX9gLFm_L7J0QhR6Q8F4P7f1T9bLUHj>TIFGVIJ9
PhV;OgQoPX1hLfmeO7]dL7N9ThYoOh20QX9eJ6=RH6M]KW=kNg1SHVY[IfE/N865
QH:4R85dIUaBCDiAE5MNIgAhMgEgOX65QH1lP7adNH61Ngn7PWMaKFaaMgIeO89n
M79kQh^6PgilP8^ARhV7OW]oO79aN7UgNWakNGQiPXn@QGilOX>7Rhn@SHZ?U967
OWn1QXN0Ngn9TI>>S8n?Ri2FQgR1SXR1Q8:1QH1fNHR=QH60Ph^CTHfDW:6TWHen
MGIoSYNIXJNNShV?UY^ITYJPWIJBRXJ<UI68PgYcMhB7Qhb@SHN3N6mbOH63Rhb6
PH:7Q7MaMgM_L7R0QXb9PHbGSWaaJFIePWijOWahOhV6NWMiOH:2O7n6Q867U9RE
TiFJWj2GT8N9TINGU8n2O8:5OGYoQ8fIWIbMXib?SY2:Q8^ATHj;R8J6PWj4R8R0
LfilRhnBVYnV/K6UWIF6PHnGRX5oN7J2R8V?RgQXKgeoOWj1Qhb6NWAhMWIjO7U]
I69[Lg=aL7=kPGM[K71_MhRASXj?RhJ7RHR<QgYfPXb;QGY`LWUhMGMiNh:<SHR0
Lg:0Q7ETFU]QIV9MIfiRG6=VI69OFEe^NgamOGUhPhQjIeYACE5ABdmMJfeZJ6a`
KW=mP7UfMgUkP8>7SXUlNGn2PGedL7b;SXb<Q7f2RHJ2PGn2SIRGT96@Qh64SI:;
P82?VYJBSY2IWIR?S8R3QiJPXYnKVInXZ9^@SXV5QhnFUiFDV9ZFTY2:QHB6Rh^5
PH>:SHImMG=lPX23QX60Qhb7Ph1kQ9JFPgMfL6idP8jGUhf:TY^KViZGUinUYj6@
PX>>Thn7PX>9RhJ4RYFJTh^;SXZ5R8n@TYFARHB5QHN8PGQgOH>9S8^>TIJIUhYg
Kg9cLWEgMGn>RWaiNG9/KgImPWYaNXV>S8f;RHZ;RXZ=Qh68UIZCRG]_L7IbJfmf
NGQoRY2?T9BBQW]iNW^0Ph63RX=cL79`KFURGF1YLW^2QHbFV96:PGZ0R8N0Ogme
KVmcO85iKF]]KFieNgj1PGmnN6]RK7MdKVe[JFi/IFMhPWahNgiiMW=cOHV<Qh>0
OX69TY:7OGf1PWmnNGAgMgIlPX63RHZ7QhV6R8f5NgYiLfibMWQiMG5cN7UfM75^
L7EiOGmnPhZ=S8f8NfiXGE=OLWUlP81mP8N8RHnASi6CT8b?V9jMUHZ;TiRGTHj@
U9RJVIJCUIJBShf5QYFLUY6EUhf5P7amQH=lOXF:SI>DShb:Q7]cL7IlPXN9RHR;
S8IoPhZ8QHF3PHF9RH^>RHF6Q7agNGQiNWMfNGagLW=aJVM[LWZ0P825RXEiLgb:
T8V2OgajNWakO7ahNHNATI>GUYFIW9bKViF9Q8R>U9JETHV1OX:8SIBFSXF8SY6E
UY6;RXR7QhJ6Q7efMWYkNgn4Q8B<TYJJUhj6PgibL7Z3Q89nO7eiKfIUKWEhN7Uj
Ngf2QXR<T8n;R8>2RI>DShElNg]fKFabN7f1PH>>VYbFTHZ1NgIeNH>;SX^8QhEn
LVa/JVUYJFeeOXB<VIjERhN8RHb8PhB6PWQbLgIhN7MfL6UWKGMkOh>1OgagKfe`
M7IkPh=kKfQYKWR6SHZ5PWinQi2=QGikNG^5SiBJViJBSh^:R8AoOGalPhZ<TYVF
S8Z?T92=RhV;SHR5R8N1OGj1R8b3O7ioP8F9QhF4PWn7TY>@UIN>Og1XIVagOWei
N7AaM7YnP862PXF<Sh^:Rhb>T92:QXR8R8R9Rhj>RHV9QX5nOh:4RXj>SHZ2NWIb
KfmbMWanP8F:R8R:PgQbL6Y[Lg=_MH:7QH9nNG^4S92CThf:SiROWifGSHJ4P7eo
PX>3QHN4Og]eLgEfMGIiOHJ?TXUmOH23QXV9QhJ3OWalN79/KWEmQXnDU9FFV9RK
WIJ>S8R2PhjDTHf9P7QmQXR8QWabMX:>U9F?QX5nOH23P7U`K6iaLgIeLg9aL7Io
Q8F7S8b2NGAbN824OGA/I61SJFUZL7AbKfi[JFiiQHR:RH5mP8N:RXf>Qg]aJ6=V
K71fOGagMWYnQ8Z;QGefL75iP8B7RHZ7OgEZIfa^JV]_L6i_MGb1PhF9RXR6QHZ>
SHEnPH>1OgakOhF4OGQhNW^1R8V5P7YfM7ImPhB4Q7ecKg5eP8bATHn?T9>GViVC
QWf1S9FHVijQYJFPVinNUhn;RXbAVJ>[ZjFNVYZIUYFDTXf:SI6BTI6ASh^4Ogak
NgYkPH^@S8F0OGanQ8bAShR0O7amOGUjO7ekN7IiOhJ9QGmmOh20PGmlNWaoPXZ@
SXZ:SHj=R8J6RHZ5PhJ:RXZ?UIF?Qh60OgenOWeoPhF8SY:AT96@S8N3P7]dLgYo
PX9oNGAeNGf4SHj;RX^<SXfAVIN>QgmnQHZ:QhAoNgQiNWM_JFU[K71eN7YiN7Qh
MWAeO8:1OgYdMWMeLFaWIFIYKgZ1PXB:SHf@THUoOX65RXn?QG]lQ8Z9QX5iMWMk
O8:AWYnHSHF4QXB1OW]hLg1aMGinMViZKGAlPHJ;T8n;QWegMWQjMFaSH61PHfU/
K6i_JfY[J6M_OH>8SXb7R8Z:S8f8OgQeMG9dOXR?THZ6PWn2QhZ;S8f6OG^2RiBK
VI:<R8Z7OgYlOgn1QXR8Rh^:S8nATI>DUYRJWIfETI:AT8j=TINHUi28RI2@Si6>
QX1mOXB:S8MoNWIfO7inQXZ;SHb<T9RNV8b1NgaoQ8F7Rhb;S8n@SY2BSHAmOH>:
T9>ASi6ETHR3QH=jMW=bN7YmOh:7PGI^J6QYKWAfMGV0OgI_JFY^L7IkNWIgN7Qk
O7=]JFQ[JFU`MGIgNgYfLFeZL7QfKFY_Mgn4RX^9Rhb:RHN5Q8B7S8b;T9BEUY>>
QX1kM7EmPH63R8f?TYRPXIBAWY:0S8QhOh66Rh9fK6a`NXB9Si6@SXjAUi^FSXjC
TXf9S9JFShR5QHB6QGejNgYmOWakPWiiOX:1OGilP8>2QH5mNfidOG1YJfi_KWJ4
PGf4Qhf>OgUgNH>4PH>6QWaeNgn3QGmfLFi`OHF6SHf?SH9nOX24QhIjM7IbLGYm
N79/KgUjMh2?UY6<R8AoOh1kLfaVIf]SGVM]LGEeLfMVJFIZKG62SHZ8Q8>5QHN<
S8IhL7R7U9NGUYB@Ph27QXF8QhV?RhR9SYZOWiN;Q8>6PGj4PWj1OW^1QhAoOX:8
TYVCTibHS8R5QXJ3P7f1SHn<UYJGVY^LWYfHTY:FU96?THj0M7=iOhZ;Nh><PHZD
UiJMX96:TXEoSiVAP8J7MWF1PH5mNGf5Shn6S9RHUXV5ShnFU8j@SHMlMgn9RWYh
RY>;OgYiO81kOH65RhV6NgElNGImNg1ZL7f:Qh:7PWQ`MgejLfmaN85oLfUXK7=i
NWA^LgehNhf?SI:BS8F2T8n0P861S96<T8f1MgUcJVQWLG]hMHB<R8V;UIZCS8V5
RY><RhN6S89iLFEPIFafN7ImOhB@Sh^<Pgf9TYBIYZZIUIJ:QXJ3RHb7P7meLX24
QXUgGfj4RhR0Qhf4PWQhPX9nMgUkLfYVJWEjMg9dOG]eM79/IGB2RXIhO8=oO7Un
QhZ6O7AjRi:<PGb1P7anPhn>OW]oPhEnMG^;TWmbKV]bNXB=RH:4R8f9PhR:PGn0
Ng]kN7QiNgUdNGU_JV]`MH::RHMnMWV2Rh^=QgmZHG=mOX:IWfaXUIAoKemK@8KU
YW^<^[R@Nh5iM7Z7SX^DRg=OQi5SH6iiQIJAKVn<M7EfKgBAOXZQO65_VZ2;NVen
YI]jQHenShI^Q99iNX1lQI1mMi6OUi:;Q9BZZYRMZ9RFVIbQV:2PW9jBOfN0VHR1
TIUmNXfLZHf3R9:SX99mNH62O8F7SHYUMYN5NX^AOfM_OW9aNW]jL6UfQF]AJ8Ig
JgIhM861UIinM7U`L8:=U8ARHG1nMVQNI7=jMV1JI79VHW=kMGYoMW^<R7UfP8>7
UX^1QW9MM8J2KWN6RINJQ7mmNX>;SI^dVgn=WiJOXi6HQ7R7TY:6PH27OGF2N7Yo
T9ahMgakRHIbRiMbJX>0L7AXG7JHR7AVJXN3KfEOF6imLXVPRgn9QGR2NFMdP7Ik
RH>4L5ibMgagHf1eQGUfNgUXKIbIOWAgRIBFS8EfLhnRQfn5ZiF5OhfSVIJ5QIVD
SifQSg=bU:J?QX9mTk2^YHQcTkK2Yh9mRZRZUI>=R8NGTYJDOWaUIWj8Sh6@]m7?
aKnSPWbBSHNLY9BPW7n>XI]nJh2<WZ1cK9j]WX9nXj>Q[IVHYINAUXV7OFe^Jg6>
S75DBDdnEgeT@3e<FF9LAD]`TgQUM7Q`PGieNgefKFi_M7Z4P7QhM79[LGMgRIZI
PW^1MVb7TH>5RH9/L96GQG5PGWUbFTm;FgV2JemdShn2OXRBS8:>Qg9aMWIeO7]b
NX5hIeYWMgeoPG1ZOHF9Q7e`NhV3Ri2>OW^8PHB>RiFAQh=gP9RERI2Y[HQhUJRD
Q7aoPW9eSh><ZYQoPiF2L6MfVJRCQh=cIg^CNg5jNWAdMWj>UhnKXZ:HPGI`Mh^S
WY26QWiiPWm`Kg]aM6iID3i3IF=GJFUWKfmgQXn:MeAMNGYfHfN1OFU]N6QLL8>8
SX:3SHUnMFeiQH2EXXf;UjJVX:FAP8J@Ui2;Vi^KWZ6ESi2FXI23QY2SZ:2XZZRo
bL35bKB[ZIBEY<35^JjNXJRVYifGVYjNZKVXVY^X[InCSI6WYi:G[9b7Tj:/VgAl
TIBLWHN=SXj[YhRAWWaUHgF@S7M^MifPPhR6OGMWJWJ7NfAdS8n7L6E]JFYlQh9g
JVYaLGEfK6EWMgYVHW>0PW=bJf5RJF5MJf59?eI]FT0f>E9ME5=EBDQ7?UQOHf=B
D5]MEV9lPV][K6eoP7=YHFMbNFmCGHFCQWn3PFi/Q8UhM6QLKH1lLG1kLfb8PVMQ
FEaTFeQPGf1ZNHV;Ng>0T9fLRGATKh:>RG9SJGInQHAeIVQVKH6EVHEfIf]kQ8Z2
JFJ1R7mlNhB@V:6FQ7eoRinOUj2MVj:KT8EmN7EnSHUgLG^7SiVFOWUoPXn9O8VS
YZ>SUXfDVHMZJHFARH9gPYVb]:6GX:^b/:2TZ[>g^Lc4XI^VY:n]WXV1W;:VUIN0
KhFJVHEeMhRGUIb[X8J1RhV?U9ZSXZRV[[b/Yj^Y^<2_WZ2W[k>/ZZJTZZRYYIFF
V9FV`LVfXYfN/l>fVHAkNXRQWhQkMXFQ/Ib:VIjKV9bRT8N?U91lQjVSR8B;U8M]
JG=lNhB6PGYlPHZLRfYYQ8mmL79^GeYZMVM@B5EQLH1hJVE/NGU]GTTjAEaQCShl
?e1PI6AE?CPl>cY3C4iBEUMFB38f@d=7@d=AAcTnDEa>A55BA4U=Ce5IIVebLViM
Ff=]LFAHDUIIDdM9B3hi@f9R@C8oAe9[MW1KBDmQL79aNWahQI2ES7ilOW]hPHJ8
SY>>W:nWY:6PXZ2LVINFVj2UWYBBRY6OW9F:Mh6;R926Kg6=VhilPHV8UZ:VZ9V;
V;2dZ9NHWijPYK>aX:6Y//C7]jJX]L37_:^NZK>a_;k2`;Nd][fm/j^i`l35c<Zo
/JVc]jnMSI>LWYJAWInDTHjCT8B5Qh^:R8V;T:>VT8f>Ph:<SWaePHEnR9FUZ9F=
TIbRWi2;UYfIU:2PS8B0P8AmOhZ;RGmdLG=_KGAbJVMWGE]ZKF9THE]TGeQOH69S
JW9kPgihP8MlMG5bR9B9OGEcO8:8SHQiJW=cKWj7PH>3OH>3OH9iIUeGGfANFE1=
BTeJHVY/IfMVGF5UJfePG6AYGeMHIfeIDUeVJfMPE4eIIg9nN6e[L7V1RhQlN7M]
HfANGfMTI5iDHGImOWAZLWYeJEE<EVASFEYLEf1XGf5VJ6]OEU]OIG5lNgIgN7Qn
Q7afLfmhPXF0M7=mPX:1QH^9SY:CWJ2LY[Bc[:>ASj>ZYJNSTHF9SI2CSX^>UiR@
T9BKYZ:CTIfUZZFU[:NgcmKHd/K1`l?8a/?=eM[>aM?OgmgDalJo[kG0`;F^/K>k
]:>LVinSYinARHB4QXIoOH22OgQbOXIjOHR1OhR<T8UmL7B<UY24OhJ?RX62PhB4
Q8F0NG^8TXf2NgEcN7alLV=WLW5gNGMeMGYjPWe^IfQSHEmBFFQYJfm^IeiJI6eX
GE9IJ6ELH6UWI6QXIFATHV5RCT9HLWM[HU]OLh60MVYWKG5gPGacLGEbHeiTK7V0
M6AHGVYTGEIDFE=CFdm3BUEFEeUHEUYUIUiSLWamOh:4PGUjQ8UoNH6;T96?RHN>
TXV5QGinQiJSW8fBWjRVW9:9R8bAT8IaJ7=lNfm]MWb1Ph=nOGf3SIJITI6?QHF8
PW^2SiF>Q8N@ThQjNGn7SXjAT8VAVZ2OShZ=RXZ7NgAfPhjBVI:;UJNe^k>ISiNV
[:>QX9bQWiZ@T9ZLW9F@U9nYYjBGTYfXZ:RXY:2KWj>UYJ>SWYNCTIJIVYJ9R9BQ
XjBSX:FPVjJ/Y9NEWj6PWiJ6Ng^1Rhn9O7b8RH1fL6meNgQaMW]hMgUnRHJ4RhZ5
PXN?TI2;QHfKWIZFUYJEVIZ?PX5mO8b>PWA^NH9kLW1dNGYfL6=LHFQ_JeeDFFIX
HEiCCeEJI6icKUiAE5eVHeAGGemRHF=ZH55<D5mWI69KEU]RIF9RI5a?FFMOFf5X
LWQfLFihNWMiLFMRHVecLG5cMGE^L75UG5QMJVi[K6]ZJfmgLfYZKGMnNgYiNgYh
MgMcLWYkOGn5RhJ7RhZ=TYFDRWmoSY^KUIRJUYbDQXF4Ogn2Ph1kNG5ZK6MSI6=V
JFIZMXF2MH2@Ti>CU9RIVj6UYIfOZj^OUY6EYJVWXi^LYJjc]K[2^kK2c/o9`Kfb
[KJj^[6SYK:f^[fe[Zf^Z::YZjZ/YinNX9nITY:DRhR;SHn?TYB>Pg]nRiJFTH^:
TiRQY9R9P7UeLg1/JW>0QHJ7RXZ<TH^2PWimS9><Q860OG]mMFeYGf=aNgmlM6aR
HW1lPgY^Kg9bO8R8OW5]L75`KFU^LWQnN7IoPXB4PhF3QXZ=Ti25P821O6eOG5iW
LgIiNFmUGe]MH61GDEAEEUeWK6UNG61NGU]TM7UgMgn5O71]LH6?S8B0OhJ<S8Ai
NGn2Q7i[HFn3U95nK6UbN7E`JFI[K6]VGUeTI5]BD5AHHfYUGf9YL6aRHF5RI6Uh
OgIdNgUaK71fO81jL7AiO8N;P6iVJWAnQXZ5PXRFYZnVU8R6RY6IUiFNYZJPW:2U
XibBRX9oQHfEVYNGViN<PGf2SIZQXZ^h_;BWV9NT[[2ZXifO[K_3alNo/J^[[kFf
^<3@e<Bf/[Jh]JjSV9ZQYJFKSHN6QH=mKf5WMGMgOXF:R7aaLgj:RHR;RXZBWJ>L
RGn2SiRJUXZ3S9FBSXf=TI>CU9>BU9n]YiF8PXJ<R85kM7EoS8b1NgI`KVmaM75Z
HVIfO7alLEiFEe]QJg=aK6URHFIWHV5WK6]]M79dOhN8NF1EFVE_JEUFJ82<OfaN
FfQcNgigKVU`NGIbMWI]Ge58ATiKHfQZIFEWHUeMGemKG6A^MGEfN79ZJfMSIfQX
IF9/NXN:OW=cNhNEUHQmOY2PWXIZIFU/LWEaLG^6QWedJ6=WJ6AOETmCH6YWIFIU
I6ATIfUXKh2=TY2BTXZ6R8jGW9RCSi2DUI:>S8V4Q8bASX^>UijPWIB>U9NCTXn9
Q8RFVHYeIfI_NGilNX6=UiVETY:CUiNGV9JGWj>KTiFOY::MU9ZX[k:f^;Rh^KRc
/KBd/k>[Z;2nblc3/YnKW9^U/Jn[[[Fm`kj[WYjNVYVBQhB;UibISh9jMWAcMGnA
WZBUVh^6RY:CS8R4QXb>S8nGWYnKUXj7R8N5RHZ:TIZIShV8Q8B8PW]jO7ahL6MN
FUA=CTi9AdI?EeUHE5AJG5]JFEUOJ6idMGEbLGEcMWMdMWajKVQVJg1^JVUcOX>4
O75aN7ahK65KF5]QJ6]WIVUYHEUHFEiTI5YHHF9QHf1JFEUDDUYPGEeQIVYVH61W
JV]]LWIfN7b4RHAlNWamNFeSHg1nP7YdM7f1NgIgOHJ?TX^6T9ZKU8MhLG9gN7^1
PH>;S8V9S8b7OgUkQ92CU9JDUINFTi2>RXF6SI:HVYZSZZZVXj2OYJb^/KRi]K>]
YInMXjZa];6][:f^ZJ:OVYRGTi2>SI6@SHj>Shj>SXb@VZ:`^K6//;6d][FZXZJ/
[JZSV9VPXIbHUiRJWj>SWYJGWJ2LV9>;R8V?TXn6NFaRH5iMGfA]MWQ`JVQZKFi_
L7=cKfYTHVA[L6a[Kg1bLWAhO8:5RXN1NWAhOWefJVI^MW]nNWA`LG1XI6EZMWj1
QXV<RXV:QX5lNGQiN7QgMGA`JfUWIFAPHfQ`MGAdMWIkPh9kMg=^J6YaLgMkOX62
PGieL71aN7emOGIfOH22NFaZL7EeLFUSHFEUGe==CDe<BdQ7C59DEeYKH5eDCU1M
IFQZJ6QaMWYmNG]oP7ebJfa^Kfm^N8>8RXJ8TIBDTX^:R8J0MgEjRI>CRgigNH:;
S8F1QXJ3QHR7PGenO7^3Qh9lN7^2R8^8R8b?UIVAR8ZCWj^^ZjBRWYVMWj2SYJV^
/:^SWZ2Y]KZg];:e_lS9a<;5a<6m/ZV//[:c]KJd]KNf^;F]Y9nKUijSX:2UZZjb
]:nVWi^DUIjNW9^LVibSXYR?S8nIXIb@QhVAU929QXV=RhN3P8>2Og]fNW]gKV=K
Ee9ADe=ADeEBE5QJGfMZIfUbM7IlO7MaKFUVJfYXIUaHG6QbM7A_JW5jNG1XIFYf
O7M/If]_MWU^GEAFFU]JDTmII6YXGeIDFV1RIVQQFUMHG5]KH6IVIFASIg1hOGn4
QX5kMgIkNgYkO7]jO8>9QWmiLg9gNGMgNGZ2RhnDTXfAVj:NTX^7RI>FS8B1OG]h
NGQhNgajN7V0QhV7QX^AShMlMGEnQXJ3PXJ5PXV?QWalQH^<S8Z8SYVNW9RCShnC
UI:=OgEhOX1kL6UZKFaXIFAVIfI[L75aLWIhMW9bNh>8SY6DVJ:TWYfLVINAS92L
YJf_ZZb_[kBj_;BXXjVd][6a]K>`/:n^[k:c/k:]YjFXZZRQUi6=Rh^:Ri:KViNE
TiBDTiNNWijLUYFKXIjGTI2BSi2@SI6IWYV=Pgj1P7QdNhZDU8j5OhFDV9NERhB3
R8f8P7n4QhN5Og]kNGEbJfQYIfIRGf5VK75eMG=cLG5cLVi[JVa/K6aZJ6Q^LG1b
LW1aLg=eMW=gP7mhLg9dNW]`I6MbMg5TEDiAEUUGDDQ1@450?45:Ce5BDUESKW1a
KVUXJfa[J6Y[K6a`M7=_KGN1QXMnM7EjOh:1Oh67RI2?Q7amPGmfKVYZL7MhLVUU
Jfm^IV9YLWQgM71/LG9ZJFe^KgIkOHF?VIV>QhZ9PGeoP861P8NDUhf3P7n1OWUg
MGV6TIVKUY2AVIbGU9NOYZVUWYjSZ:BGRh=nO8B=TYZJTi:FW9^IWjBVXj2QXZ:R
Yj^XYJ>TYjJQY:jg]k:^[;2i_KN/ZK2i`/2bZJZ`/ZnYX9RET8f:OWQmQ8R2NWUj
N7=`LG5`L6iXIVYbNGj5TIVJVIJDSXEnOX>:S8b>TYRHUIFAT9VJTHR3Qi>LVI29
Ph65RhZ5Ph>5QhJ1MVi_KfQSH5iOGf5/Lfm/KVm]J6I[LGIlP7mmNWQeL75aJfQU
JGEnR8^7P79PFUiSH5UJHVegNWMbKfi_LVmZK7=iNg]gN7YjNW=ZIV5MFeaTK7=d
K5iFFV=ZJ6I[Lg^1Ogj0OgUcKfm_KFMVJg5fMGIhNgikLfmdOHN<S8InNgf2QH9j
MWMhMgAaLVmYJ6UWH5UHFEYOJG=gM71`MG]mOh62P7n0OGamOh:4Q8>6RHjDVY^I
Ui:;RI2HW9bKW9jSYJ2KV9VKViF>SiNNWYRDTHb<TIFCSXn@Si2GWinJUYFFUIbT
ZJj_/;Nk^K6ZYZ:NWZF[ZjNVZJZSUhnAV9ZEShnHXjRYYYnGTiBGV9^PYZVX[:n[
XYZGTHEnO7]jNX>?Ti:;R8b:R8R1O7j3RXf<S8f9PgimPH5mNWQoRiJFSHJ0OGem
Ngf3QhjDT8J3R8V2Mfm^K6UVI6IXIfIZJFAKDdi5@dY?D4]:CU5DF65YJfY[LGAb
KF]/KFm^K6a/K6mcMgakM6e/M7]lNGMiP8F6P7EbLg9^KWAgLFUUIF9NG65RGEUJ
GEaJGF=WJVQUJW=hO7YgN7YkN7=/JFa_KVY_NGmoPHR9Q7adKFU[L79dM7V1RI2@
RGidMGn5RHb:RhnCU8n:Rhn<Qh>3P7]mOh20OgejMG1bNX:8RHV>V9bITHb>SHZ6
Q8F8SiRLWIfLVI6>UZ2QXZZc^;Rd[ZVXZZb[Zk2f^;Jc/kF`ZJJUXIZBRhF5S9:H
VYRHV9VMX:BWYJ:PWinNXJBRWIbOX9bGW:N[YY^FUYRNXZ:NW:6VYJ6NWIR?SI2@
RhJ1P7ilNWUhNX20OGQeMGAdKVicLVeXIfa`Lg^1OgenOgaiMgEeMGQkOG]hLVYY
K6aXHV9WJVUVIfifNG9WH69/N7elOhF=SXJ1OWQ`Jfa[JVQVHfAXKgMgLVeWHEeN
I6ecLg5cLFeYHf9RHF9YK6YZKWIlNgAXGeeRJWElOWalOh1nN79`MGQgLVa[KFi[
IfIXKW1YFTm<Bde?D5EIEeECE5UPJ6e`LWQnPXF3P7egLG1aLWAfNG]mP8B8RHV<
TIRHTXf?UIRESHV=TI:AS8F2PhF5QH>2QHZ9Q81oOGalOH:7T9NHUI2;TI^MVIJH
W9ZFUijTYJN^[jZVYJNVY:6KUIFLXZNYZjja/[>e];:c][_1a<6l^KJd/:b[[ZnZ
Y::QXJ:PWYRCTHn>SHf?UYjRX9bMViRFThn<RhjEUY6>SHf=S8b8Q8J=U9NFTi:D
V9RARHJ8RXV8RXj?T92?Rh=mNG9XHEiMFeQIG65WKG9bK6IVJ6Y]L7=cLG=gNGI_
KG9gN7UgMWIfNGinNgUiOGiiM7QoQHN3P7emNgE^If9PHVQ^L71_Kfm/If=RH5iN
H6AWJ6UXIFAWJfi[J6U/LGIgMWIeL6a/KFYRGf9WJfe/KG1fO7U_JFY^LG9dMGAh
P8R>TI2=RhV3NWEhOH21P7]iNWYhMgMfM7=dMGIhNWajMW=_KFa_LgAdMgj3Ph60
PX1oPH1lO864QXN7R8^@TiB>QhJ7RXn@TI:@T96ATXj8PgikMViZJFU[K6icMGMk
O7j3SINHUIROY:FWYj:IUYFEUYBDV9jTYjNRWZ://ZfZZk2c/Jn]ZJFTX9bKWIjN
W9jSXYfLWIjMVI>AT8nCV9jRX9^IUiBASX^7RHb;RhnEVIVBSHb=S8N4QHJ9RX=l
NW]mP81kN7IiOWioPXJ9SHn>S8Z6Q8:1PXB4Q89oOW]dKf]XIFIVJ6a]K6ibMGIb
KVa[KFmbLW9eMgEbKVYYJFY^LgEeMgf1PH>1N7AcLg1_Kg5eMgf1Q8V<T8j3NG=]
JFIRGUiMG5iMGfI[Kg5^L75YIfYaLfmhPg]aMGQiM79eMgUfOXR<QGYhO8:7R8:1
PhN;SI6;MFYfNGAaK6a^MX2:Q7=TJ7eoLVQXHV9^MWmmJVIdN7AhMV]YLgn<V9Em
N89oQX^0KfEWKWb;QG=gQHAmP8EbHVYjRiF7OXfHTX^IY8n>WiF@WI^EVj6CSj2K
PhB:PI2VYJ2TWX^?YInBUXn:U9nNX:bWUJ6aXYbPU9FNVifZ[:2JZ:RFVJ:PX9fI
VIjVXZ>/Wi6GXJ6KV9>7QHMhN85dIfMcNG9eMg5eN7R4SXN4SIbBQ8b=Q8J;T9B:
OGb9THR9T8V4RY2HUhb5QX^=SHb0LgIlO8>5PWimQXF3OWIkO7IeM79]KGV6QGio
OGA/JWIjMW1ZM7akOXB3OWQmQ7edLG=dNGmmN71XJ6]aM6]UKG9hP8:0P81hN862
MW1dOhR=S8J4OWIlOGEXGUmPJGAhNW=WIFYbM6eWIVQ/MH21N71`MG=]If=UJW5h
Ng]iNX>8PWQbKfa[LgemNgakOX>9SXj5MVmcN7IbL6m]IfMYIfUXIfmeN7UiNW]m
PX1oP7]lQhf?T9FGS96ISY6DR8RBVYN@SIBMXj6OX9R?Ti^IShb=RXbEUI:FUI>G
WIV>RhnBU9FHV9>BUi^ITXn?SXnCW:BSX9jLX::JUibKUI6DU8nAWJNQViF=SHf5
PH5mPHbDUYBET8nATY6EX:>SYYjHViB9RXZ6RHf@SHF7S8j<QH=nN7]nOgUeN7^7
SHj;QHJ9RXR4O7MfLgf5QXB7QWj7PFm`Lg=jPXN=T8^=TXn9Qh5jNgigLFi[KFUT
HUiECDY?EUiTHf9VKGEgKFY]IVA[L79`KVmbM71VGf5TKGAeLfiaMGEgLVmXGf1Z
JfYTGVA[Kg9kOgA_MG=eLfm/K6UUJgAiLg1aL6m`M6mXK7EgN7UcLWAfM79_JW1h
OhF3OGQcLViYHfM`MgN1T8R4Ph:1QXb;S8Z6QHb?UIbOX9jKVIF<QX:2PGejOHJ:
Q8:3MG5jO7b2QHJ;SiBASXR2OX22Oh>7Q8B9UYnNWIfQX9bDT8f<UIfXZj^][:jb
][>^ZJnf/jjZXYR@SI:>Qh>3RI2GW9jLW9^OWj>XY:>SXIZLY:BMViRAT8j9R8N5
QhF<Ti:ATIB>R8Z=RHF3OH29S8V:S8Z=SHZ:QGmoRYNMWi:<S8^>ShAfL6U/M7n9
T8N7UXb2OW5`P8N7QhN2PH1lP7E]LgMhLW=gN7UmPX9iK6YcLG9gMGMiOhF7Q8J8
PHJ3OgijNfm]NGj4Q7UeO7efMgE`KgEiNG9/M7f5N6m/HfISI6UZJ6UaMgYhMGYl
NGUbMGekNWYcJVebLFaZIfM^KfYRJ75aKf]THVIUHUYCG5eFGU]IJ6USGf=YJgAb
JFilQHAkLFifNG=fM7EnOGj1OWb0QX9oOgUeLW1fOhN2NGj2RHIiO7QcMWEhOhB3
O869R8^?RX1mPXJ>R8:<U9B@R8ZBSXZBV9bV/K6d_;RZXYfFTIFQYZNVZ[2`ZjBJ
V9nOYJNNZ[Fc/kZi[j^b]KFf^;bg^l:n/YbEUiJCQh:;RXB3Ph25UI>5O82;QWib
JG>0RXQiN867TY62O862OGQkOX::Rh^=TIB?RH>4TY>5NWb:Rh>6R8R5MFe^LGMe
Lg1gO7]fI61[LWAaK7=fMGYkOXV;NW1aMWQ^IVUYKH:7P7I^KVa[K6i]LWUkMWN7
Sh1dLg9kP821PXjLVi24PHN5OhF0NgefKfidNGQcL6]SJVYXMGalM7b6Q8nCQX20
NWYjKemLI6m]IfMPFeeSIUiHFE]QK75kPGijMWIfMGAcNWimOg]iO8^?OG=bKF]c
N7emO7miNh>6SXZ6QgiiOGUeOhZ@RgalPHB2NWajO8>2OH>8R8N8PWinPHR9RH=o
Qhj>RXR9PgYoPGUiNgioNG5cN7IfOhnFUiRHXJVQYJNOXj:HTi2@U9NGSXR7RhZ<
UijJShF3RI:LW9NQXYnPV9BEUI65MgMmRhf2RI^GU9:0OXRASH>;Ti>FTXf;QX22
Q8R=SY^WWYbPViZLWY^EUi6:T8jDVHb5RHQoNW^2PX:<TI:AU9nNUi^PWYN7P8RA
WZ2BRY2CRHEiJW1iNW=aM75[Lg9/L75]I5iUJFIWJg=nPWeiMh28NgIjNh61MVib
MWYnNG1gPgiiNGenPGicLG1_Kfm_J6ISGemNJ7MjNWYaL75bNGEWJVm`Kfa/K6QZ
KFQWHV1SHf9YLG5WIFYhNVeSIg=aJ6Q[J6IXK79kPhF3QX9nOgilP8^BShZ2OhB;
R7eoQ8f7OWf1QhR3P7QjPWaeMWZ0QHN6Q8Z9PWj1Ph:7RHN=RhV5OGYbMXB;QXJ8
SiVIX:^WYJFTY:JXZZb][jj/Y9^JW9jQXIf?SIFPY9bETH^:Q7j4RHR5Qh^@TiFF
THfDViZFUifSXiZASHj:QH>9Shf:Ph:<THn5PhN?U92AUZ2OUHf8Ph61Ng1dO7Ye
LWAnPh:3Q8R?Rh>6PhN?T8QkNHR@SH^:R8^@UI>?RhJ;SX^0O820PG]`KgImO7A_
LGIlPX9lNh:1P85kM7B1Rh9mOgQfMg=_LFm`L6m_Kg:2S8f9QXZ:R8ImNh>8Og=Z
K79^IeaEF65XKfa[LWIeLW1gN7=lQ8B8RhbDW:2GR860O7agK69TIEiMGUiPHV=X
JVe`JfAVIEmLGU]KHFI/LWA`J6YfNh9nMgAbN7]bMGMeNgmnQXf8PgimQH^<QG^0
QhIoNWMcKW1_KVYVHF5[MG]eLgEbLWIgNH27R8ElNGQkPh1gLWYoO7MeOHJ8PGYi
Nh65SHnCUXn7QHV=SY>GUIbX/:bVWiVLZ:ZTXjBWXiJ@QH2<Si2?TIVJWZJXZ[:d
/:fRVi^MY:JVYJ6KViVIUX^5Ph>;RXB1QhnCT8f>Rhb:S9BEUibJW:Zf]jVMVifS
YZ6JUYVOUhfAUI24Ngb4S96=SI6CTI:?RXV:Rhf>SHf9QhV?UIR>P7AePHVARh66
QH21Q8J6RI:=P8:8RHInMGMiMG9YIFQZJfQRGUaQJ6m`KfYXJfe_JfIQG5]PHV=W
IVMPFUiMGf9UJVa^LW9/JFYaNgahM71bMg9WJgAfLV9CD5=IGfATG5mXJFY_MWIa
JF=JF5MEFEm]NWenNGEkOgYfMW^3RHj<P7IgN7QnPX5nN7QjPXZ=S8^8Q8N9R8F<
UINHWJ6SXI^LW9^ITXf<SYFGRgegMWEhPXN2O7]lNG=bL6ecQ8j7OWMeMh:<SXnC
VJ2RViFCTHf=Si2<QXbCUi^KUh^0QY6EUiRGVYnSXiZCUI^LV9BFU8f=RhV7R8j:
R8^ATHZ4QXjGWIVCSXN5S9BBQgeoQHF5Ph:9SYJLVIB@R823Ri6=T9ZGUi^IT8N4
RIBQYj:BRi:NYjFJS8J4Pgn0PgelPXB3R8j:P7b0QXjCUY6;Rhj<QH1lNGQeMgI]
KGIoOgMfMgEdNG]mP8N9QXR=UIJASX^=SXV5RXn:QhV@TXV;RWY_JFAWK6ibJV=W
M7moNgA`Lh2:QX5nNg]mO7imMFe[KFaQEeIIG6E]Kfa^LW=bLg9^JVedNgmlLF5H
FEiOGUaLFEUQJFYWJVi[IFAXIF5TI6ASIfm]JW5fMGEeL6QUK7V1OGAYJW5_K6QT
HEaRLGEcMWIcLG5fOH1jMWV5T9>ARHF:RhZ:QX1lPXnDSXJ8TI^MUY:GWJ:Y];Ja
/;6/Z:j_ZZ>KU96DV9NBSXj@UIbPX9VDW:JUXJNc^[^o`/72`[be[JRUWiJ?SiBJ
V9:<QXF4OgYeMWMbKg5eO7]eMgYmP8N<T92?Ti>AS8B1PWanPH63QXJ4QhbBUIFA
RXJ:SXf<S8Z:QWadM7]gKg=iLFMWIVYaN7IZHf=PH6MaLfe[KFmaM6iRGF9[LVmX
I6=RIF]bLG5eLg9hO7enO8::SHb7Q8V;QGmiN7MiNgamQI:FTXZ4Q8F4QHJ7RXN2
QXZ;S8b;Q861QHJ3PHB9S8j;Q7YgO7ioPX1hM7=_JF]lPgYdL6m_MhB:RX^5PXVB
Thj;TY>:QHF1OhR<SHj9PW]fMW9_Kfe_KfmgOWifL75jOWioOGn5QXZ<Qh>0PX9l
MWQiMWIiNGMdMGQmQHZ;TYbLTHZ?V9ZKViBBTY29Q8B6Qh^>S8nAUYZKVYNCR7em
PX:8TYB;PGn1PXN<RhZ@VIZLWYZCSi>EU9FHVifITXV5QH61QHZ6Og]jO8>;Shf;
RHN:T9>ARGmjMG=eN7]kNGb2Q8:3PX:6SI6>RHF1PHZ;Q7YeLg9fPXN0O7f3QHJ2
Mfm]L7EkPh>2R8b<SXj;S92AUibLTXEoQHf@SXN3Q8J5PGYeKFi`KG1_JfQWKgMf
LV]XLH2:T9:BSHB2RHb:QGY`JFAVJ6MZK6mdN7UlPX^?RhJ7Rhb9Q8B3PXF6Ph1j
MWQgLg1]M7eoNgA`K6Y/KgIkOWYbLW5_L7AbKFa/JG5eMWYlOWeeL6aVIVaeO8=o
MGInNGEkQH^>Si:DWJ2FQgj1QhZ5Ogb3RXQmO7alOG]hMgIjOh1oOWeoQHJ2OGYn
PhJ9R8F0NgIiNgenNGIiNg]jNh63QiBTZj^VY:6OYJ^][JNSZ:RQTXJ8T9:>Qh5m
O824P7emQX^:RH^FWZ>TXZ2NTHV:T9ZMUI29Q8R9Rhb8PH25SiB=RHJ1QY>FT8V8
SiFKW9>>THYoNgn4PgmmOh>9RHAjLVebNGUjOh60NW=]KG5_K71gNgn0Ng=`M7Mc
M7UjNgf0PGYiP7mlNg]iN7QgLg5bMG5_MWf1OWUmQHR5OWf2P7ahM7V3QX1kNGj2
QhfFWIfCQhJ7SYF>PG]iOGafMGUhNGenOX:2OWf0R8jBU8n=T92BT8jBV9ZMW9VF
ShN3P8>;RH9dJFAVKGA/IVIPFeECF5]OIfa[JV][JVe`MWQcKVabMgMbKVATJVm`
L7Z4PWf0Ph61PXF=THn;R8Z?TY6;R8b7OWelOH>:RX=hM7YjMgMiNh23PXB:Rh=i
MWb4R8InMWV2RhjAShN7SY:EUijUZ:VWWiR>P7f2RY:IVI68R8nDTY:CV9ZHVIZL
X:6MXZFTX9JDWYnIU96?SX^<S89hKf]/L7IjMg5`L7J1PWeaK75hNW]mOGmmNgak
O866QhAoOh>:SXj>TIBBT9JJUYNMXInHTHR2OgaoP7]mOginO7]nPh^BShV:S8N3
PhEoNgn1O7YiN7IgNginNW=]KWEoQHAnOXF8QhR:S8V9RhEmP8>2RI:ET8R3OG=c
NWn6PgYcJVU`LF]/K6i^KG1dN7f:Ti:;R89mOGmnOG]eLgMmPGidJfQ_N7]iMWIj
OGimN71ZJfibNGn4QGmiMWEfLFmfNWelNGIaKgIoQ8F5QXJ4PX>1OWeoOWj6SXj>
UY^CS8R3O7UkOh>6QhB2PXF6RXjFVinSXj2JU8n=T9BFTX^<SXj?SHV6Q7ijNWek
NG]jNGaoPX9oP8J?UYfNViB>SHV9SXn:QHJ7PWf0PX:4PG]kP8N<T9RJU8n<RXN9
SYBARXN8Pg]fLFi]LWAdN7YbIV9TI6AWJfaXIVY^LG=eN7IeM75fO7akNgamOX27
RH^:PGUgMGAgNGj5S8n;QH:2PX:1P868TYJBRX>3R8V9QWeeMWb3R8b:OgUiNG9^
M7UlP8B6Qh>0OGb0QXR4OW]nNGAbKfifOX64QhbCW9nIU9BEV9^IVibOX9VAS8V:
R860P7]jO7YiOH5nNgaoPX1nOGj1RHn>RXF0O7f0PH:0OG]kNWQgMWIgN7IgM6i]
Lg^1Qhb>SX^=U9JFU8j9RHb@U9F@RhN5QH9lNh25R8b=QgmkNWaoP7agLFe]M7Yj
NWMdLgEeMGQjNG^0PhJ6PgmlNWMdM71`MGMeMWUmOh21PXB2OWj1Qhn@SHnBTi:=
RHR<TY:>RXZ<TI>GV9B=QGYfO8>6Q8:1PH>8S8f;RXjDV9^LW9N@S8V7RXjCV9B<
QhB7SIBHU8j:RHjAShb7QXB1P824RH=mOWenNGIhNgYlOGemN7AeOHB5QXJ4PXN=
R8=nNGamOH>2OGYgNGYlPhJ3S9:>Qh:0NgMhO7]iN7QjNWYgLWMkOGahKVU/LGAi
MW=eLW5bLFi]KViaN7YhN7YkNgj1PXJ4QXjBT8j:QhB1Ogj1PgagLgEnOW]mOX:;
S8bBSHjDShfBW:2GSHV=SXj;QhF6QH:3QXZ7OW]hMG=bMGf4Q8R8QXB0OGf1PhB0
MW9fNgUmPhF6QXJ8S8^7QhN<TY6=RY:BS8Z=TIFGVYJ<QXV1PhEnNgAbN7MhNgUo
Q824Qh>2QH>0PXV7PG]fOhJ7RHV4OgQdLgElPH22R8J4Q8F>Rh:3QXZ@ThZ8Q8N?
SY2<Q7iiN7j1OgUcMgYhLVi^Kfm^K6]fOGf1P865PWahMGaoO7j4RY:CSH=iMGAj
P7elN7QgMGUjM6i]KWAeMH><RHJ2PX^>S8b7RI2>R81hMWQfNGf1R8V8Qh63RHZ<
TiN=PhB;TiF?SXb7RXj?RhB0PXJ@ViF8RHZ:T96=RXR7RXV<V9jKVI>?T8AhNGn0
PWebKgAfMgahLFUXK6ebO860Q8N9QH65Qh=lLW=hMWEdKfIWO6eNM7]nRhN4Si6G
VIF@QhJ:RHR8R8B2Q865QhB4QXN5PGefM7E^K75eMG1dNhN>O7QiLWQhK6Y]K75d
NX:5QX>1R8j?R8>1P81oNgUkPHV;R8N1O7b5Rhb=S8nBTi2:R8^;QhF5Q8J4PhZ=
SH^9PgaeL79jO7imLG5gNWUeMWEfNGQhMWEhNh25Qh5hOHZ>T9>CSXN7Shj<SXj<
RhbBV9:<SI:GVYNGVYREUYJAR8J9R8N:TiVJTHV:SHjATHj>R8N<R8bBShf8QhN4
P7UjO7A_JfAMHW63W[:k_[NXV8=hOWn2S8Z>THj:PGn6R8R9RXnARHYnJg1cKFia
KFigPX=jLVmdMg5eMW=eLViUH6E/KFM^L6IXJFIZK6UWJ6mgLFefO7AcN7YaK79f
O7j1OgQjOX:0OXB0OWI^N85fJhJ=O81nMhVCPhF=OgZ?TH^BW:FSS8ZESi2DP7V?
VYJNT8R:SIVJVYfmdkbUTH1aHeYQJG61Rhb5Ri2GWYF=S9>IV9FQWHf>THj;SHn>
VJNPV9R@SY^RVY>KYjVOUi:8Oh6;Si6CSHnBRXV4N6MNJFeYJ6maJViiO7UoMfi_
Jf=SIV5GDeINH5mHD4QHJfAFEe9XM6AgPGmmLVQ`MW=kMgb4Mg][KFMTM7EbNhIo
Lf]YP7acQX:7PXZKVYjUViNCQ7mcJGZ;RhjBRXb3Pi>8QI2=RINGS8B4OGQhNWV1
RX67RXJ1P7EbM6Y[NG1_QW]fQWb0U89`QXR8PXVSW829U8=fOI>HU8b5NW=gOX9^
JWajMX21PXAoQ85hLgIhMgb7PH:;Q8R<V9F@SXN@WJZUVIFSXJ6`Zj2R[[Fd`<g7
_kjoaL?7akZ]Xj:WYIjS[KFb[KFg/K2aYIBEVIfLSh^@TXMiPhb1Q8Z4OGYgNHEn
JVY^M7IYJ7IhNWAZHUmTFU57A4YFFUEOJfm^KVmaLUm?DeYMFE9FHE]>CDi1@TU@
GF5QF5A@CDTo@DU3@4aDFV5PEdeDF5=@BDE=EU9AC4YDF51AGF5LHFaiQ8>1Pgig
M7IeM79UIG5oRXQoMWn8QHB0R8f>TI6FW9ZFSX28TY:JWInLTXnJVXj@SYR<PHjL
[:nSWY^OYJBYYijW[jn][kRcYZ>OWIVEWjR^[J2IXZJLVIfJT8:0RhnFXZfaX9JI
YK>VX:>S[:RNW9ZESXN?WiF:Qh>CYZ>HU8n>Q7b0PhNFWIBHXZ2MU8bBVIF=S8V<
S8nGVIZSZJJOV9>KXIbLVJ2RTI:IShZ=QgahTJBGTINPWYbQYJ^XXZBRXjNVXYjH
UI:7OhB;Oh20M7QmO7YlOWYoR8^7OGAbK6]gO7A_KW5fLgIkP81_FEYNFFAVKWeh
LVYKGfALEUEMIVEWKGAcHe9IK75UEDaEI6=TIVI^J5A9DV=_LFUIGVm/If]YKVaL
CTY6ADi7A4eBF5]=@T56Be1DFEYIIg=fKE]EDE1CEEmVH5mFCf9YGUA9BUURFem]
MGEiPGQePhAdKGV5SXB4WZVMRWmhMgj6QGn2SiZHUYZMUhf=S8fAUIF?RHfDX:NT
Y:JWY:BUUHJ6SiBHY;Bk[jBV];Zk_KVg/jfWYZV[ZZNQWj6[]JZMWZji[iZGY:VU
XZBOSH><ShZ6Qhn@S9FMUhf7Q8VEV9J;Q8Z=TYJ<OHB7PhN6OgefLh2>UXmmMGYn
OXJ?U9BJVXn=Shf<R8:0PgmgLWUnOWUbLgQgKUmCH7aoM6aWJ6]/LG5[KG=]IV]`
MWQ_K65EFV1TKVeSJ7F6T8N4RXEjLFYcNgQdM7Z2Qhb9OgYbJfATLh1fJFaaLFYP
H6ASHfEUJ7>5QgQdPHN<S89oNFeWKVmZK71bKW:0QXJ7RHV=TYNTX969Rj6]YIfJ
U9:HVIBAVZ>TY:>YZZBRY:NZYJFZY:N^[Jbc]:n_[k:c/k>_[k>ZXZJYZk6l`Kjo
_;o9al6o`<:k^L76`KRe[J:NWjVYWI^FVJ>RWYF?UYZIXZZWX9R?RH^<S8V<U8f6
TijJRWijLW1fNWA]JFIXJFEWJV]/JfUTH6I/JVQVIVQZJf1FFEeIG6Q_LVmXJFAU
LWQaIf5UKFi]Jf1IDTaIJ79bJfQ/L79eKfMUIEmNJ6i]KFIMGfIaMFeTHF=XL75c
Lf=GEUUHFEiOGE]PJVaZJfAMFeEFGVM[I5QACTiGGEQ<@4E@De5BCd]8B4A3CUA=
@d56DEmUFU1=BdmHGEMDD4@k?4==F5A;C4Y3Ae5NI61SIfYaMF]PG5aJFU]LEE5E
FfM]KGR1NG1YJ7AmPXB1PXR=RHF9RhIoOX25TIZFTiFMYZRTWi^FUINQ/KNf];:a
]KZl]k:f][Ng^/G:`;Ri^ko6b<?0`/?0_/G7a;be^<33bLc3]jj//K6a/jjW[[Jd
/[Ji]ZjYYjR]/:bWXZNf`;nj^[NaZjbb]K:^[JbZZ:VYZZ^YXiZLYjNOWYnLWZ:O
Uhn>T8^6R8^BThZ8RhZDX9nJTXj?T8n@Shf>S8J4QH^9PX:9TI>@SHb;SiJFU9FB
SH^8Qhb<QhN=UijNUHJ0QHZ5Ng5^LFeUIFQ_MgMfLg5gMW1`LG5bLW9`KG1`JVQV
HfETHFEVHF]hMVm]J6=SHV5TKWAdLW5`M7McL6YTHV=XKVi[J61KGfASHEmJEEAH
GFE[JVedN7YhLW1aKfYPG61QGUaGFV1WLG1[KW9gNGUnPgefNGUdMW]lNGQjPHN>
T8V1PHV=QH22PGn4S8n>S8^6PHN>T8n8Rhj=RhF2S9FBS8B6TiZFUINJWYJ?TiZN
WYRDTINWYiZDU9JDTiVLV9>FVI^KVIJCTHb9R8ZBUIBEUibOWj:OVYVFUiFDUY67
Q8J;Shb4Oh67QWaoQX1hMG=iQ8V9P7YkMFaYJFQ/KgInPHV=RX=nOWafMgmoM6i`
MGajKf1JGFAYKW9dLFUXLGYkKf5PHF5YL79fNGUgLg=fLf]TIFa[HF9UHUiJFeiR
I6IOGVEREe=PJV9IFEYJGV1NFEEHG5QFGVEQGEaQIf9HD4e;BdiBFf5KCDQ=F69T
I6UYHUiOH5mFCTm?DeUJFE]QIfERIVMWKG5eOGagN7MjNg5XIVYaLFa]K6MZLWb0
OgimMgN2QW]cN8B;QGalOgYjOhZFV926Pi2OY9bDVZ>QVYFDVZ2RWYbSZZ^Y[Kk=
bKVd^;Ri]JbWZK2h^Ko9b/S8al_BeLo6a/W;cLo9`L;1_l?2^;>lbLk;a/G7aL:j
];S3b/W2_/79c/c>cLG2a<S9`[bm_[fk^KJb/KFd[J^]/;:]XifHUibJUIBARH1j
OXN:SXn;QH62QXN3PX63QH5lN79bO8B4P7ejMG=eN7YlNG=dLfi]LWUjMW=^KGAj
N7IfNWajLFMUK79_J61MH6AQG5ABGFAVIVMVHEUHFe]LG5MEEeUPI61HEUYNGEUI
FUaQHUmMGUaGCTYFI6QRGF9YJFEQHfUXHf9OGUeMG5YMHfANFEQKGemLGVIbMW5_
KFi^Jf]`LFYQG5eQI6MWIVY`MgamP8J4Oh::RhF0P8F9QhN9RX^7QX^@V9nNVIJG
UYJKXjFSWiVIWIjNW9fV/[JbZZV[Yj:LTY6HWInOYK2d/[Fl_kNXXZJ]/k>^ZZVZ
[Jf[ZZZ[ZJNXZ:>QY:FTYJRXY9jGTI6FUY:>SiJKV9FIVijMViZARXZ8PGn1QHR6
QXV3O7YiO7emOgikOWmkN7=_Jf9NHfQ[Kg9cMWZ0P7UhO7YbKVi_KfmbN7UfM7Ah
MgMlOG]kOG]dKVmaMW]kNGEhOH:5RX^4PX>2OGEgOGQaLG=fMGIkOGenOG]eKG1f
LV]]L79aKVi[IFE]M7A`K6e`KfUQF5IGEUAFFf9THV5TJV]UFE9IHF1LG5mTHEUG
EUABCDQ7B4mEEEUOHFIUH61LFV5RH5mKFUiQIF5BC5=GFUYIGF5SIVa`M7A_JFEW
K6eXIFY_KfYZLWMiN7^5SXj5NgQmOWn2Q8>1PXJ;SHn@TIFGV9B@TYRKWIbHV9FB
TiRPYjBOX:BZ[jfXYJN_]KB`[Jb][JRUY::OWj:UYJ6PYjf_[Zfa[jNPXJN^/:^W
ZK2f]kNg^;^m_;Re/k:_[:VZ[:Z[[:JSYJNWY:>UY9^@S8j>RhZ;SI2AS8jCUIFA
RX>0P8>3Ogf2QhZ9Q862Q8B0Oh>7QGYcN8:8Q7Q_L7=hOX>5QXN<TYBBRH>1Oh24
Q8>1NgUgM7=aKg1`KFibMganOWY`IUeIG6AZKFeYJVi`L6eWHF1NH5iGEUaSJF]Y
IfMWHeeMIFa_KFiaKVUWKGEfKV=MGF5QGEQIHVYXIFQ_MGIaKFa]LG5ZIFIZLGMk
OG]eK6IXK6e^KViaN7f3S9:=QH:6RHN6QHJ9RXbCVi^EShZ8S8n<S9BKWI^IV9VI
VibKWYjMViVMYJBQWY^JVYVHU8nBV9ZMWijMWJB^/[6/YZBTYjRUXZ>WYZ:SYjRS
WJ:VY:>RWifKVifPXZ2MViZLWibIW9nNVi^SZZ^ZYYnKUi>?RXbAU9NIVijMV9F@
R8^AT8^:SXj7Q8N;R7miNh63PXB3Q8R8QXJ9RXN3Q8F7Rhb;Rh^9QhJ4P7ekNWj3
OgYlPXV;SHf8Q8B7Rh^8RX^5Ph>1PX1oP7moQ8F4PgmnOWn2PGUeM7IiNGIeM7=d
L6]/L75_Kg1`KFMUIVEOF5YPGEQHHFMUGU]LHFETGeYHFU]LGUeGDDY6ADA7BDY>
DE9EEeQKFU9>CU1FF5QHGF9PEeAGEe==B4]DGF5THUeIEU]RIfQPFEeUJFISHVIX
IFAUJFa^KFQWJVYXJFaaMGMlOh>5PX21PhB1P8>6R8b@TI6?S8^6QX^?TI:FVIRG
VinUYJ2MWZ6SYJR][jbVXj:UY:6PXJBTXZ:TYjVXXj:UY:2IUZ6/[:ZVYZVYYZFX
[K2]Z:>V/;:^[Zf][j^QViVJVYNFUI:>Rhb=S8Z9RXj@SHAnOGeoOGMaKVi]KgEi
Ngj5QX5kMgIfMWIgNWYiNgQbLGEeLF]YK71eN7b1QhR6PX1nN7EiOX>5Q8:0NgUk
O7]lNgUhNginNgQgNG]gKfe_Kg5dM7AeLFi`MgQbJf]]KFYTI6Q[Jfe`LG9cLG9m
QXImM7=dLg5]Jfi`KV]YKW=]IFI[KFe[KWAiO7]hNG]iM6eZKg9_KW5dM71/Kg9b
Lg1[JVaaMWb4R8B0PXZ@SX^=TY:<QhN9RXV2O8:>TXn=TYNHUiFCUINETi>MZ:NP
VYRHUiBCUI:>Rh^>U9^MVYbPWiRDUI^OWIZLXJBUYJ>RXj2MWZN^Zj2JVj6TXIfK
VibOXj>TYJ6KWZ>QVIFHVY^KVI^QY::OW9jQWYNBShn?SXnCUiB>QhB5R8N4Q8R:
QhF5QhZ8OWE`L7MlN7=dNh:6RHN0OX25R8N5QHN8QH>5QX>1NW=eOH:3PhB7R8F0
OhB9R8J2P861PHJ8QhF2PhJ7QX>1Q8N7QH:4R8V4P7n2R8V3P8:5QXF2OgejMWIm
PWmhLg9aJf=NHVihOX5oNg]jNGMeLg1/JFQZJfEQI6ESHEiOHF9RI6U_KfUXJfm`
K6UZK6m_JfY[KFeZIVYcMG1^LW=_K6]/KFi/JVedN7EdMgenN6mZKW1_LGAhNgM^
JVe_KViaMGYmOh24QhV:QH62Ph1nOX:7R8F6RX^8QXN9RXV8RH^=S8Z9SINLV9FE
U9BEUYJGVIVBSI2BSXZ<Si2=R8R<U9^RXinKV9>?Si:DU9JKVYZJVYbNXZJXZ:VW
YZV][JVQW9VFTXj=Si>GVYbKV9JDT8^:Rhb7QHN5PH1nNGEeMW=bN7n3R8b=RhIo
NgYgMGMhMg]mNWEbMW]lOX:3QXF3QHJ8RXZ;SHZ7RHR8QhF9S8b:R8J5Q8B4Ph>4
QXR4OgemNgIdN7]lNgYjNWYgK6AUJ6YVI6Q^KVQSIVa`Lg5[K7=gMWAdM7=`K6IW
JFUVH61UIfEVI6=TJ6a]JVIVJV]ZJFMSH5iNGemQIVU[JFQ/K6MSGE]JF5YMI6]/
JfmcM75`Mh23P7amOG]kOG]iNGMdLgIlOX22R9:FTXb9RHj?RhR7RHf:QHJ:S8^7
Q8F8RXV9Rhj?T92ATXj7Q8J8RXnGWJ2RXInMWIVBSi6EU9>EV9NASI6GUYJETiBK
XJ6KV9RIVIJBU9FEVZ2UZ:VWY9nNWibHUiJFUiRHV9RFU9BCTXn:Ri>JVY:<Rh^9
QX>0Oh23Q8:3PWn0QHb>SHjBUI>;QhN6QHJ6QXV8PgimQHjASX^9QhB1OWj3R8R8
RHZ:QX64RXb;SHn>SHb<SHj=RH9nOh>6Q8:4QhZ<S8Z:Rh^9QXN4O7MfMW=bLgEe
KfQXKG5eN7MiOh>0Mg5`LgAcKV]VGe]JFUmSHEiQIVY[KWEgLFINGF5TIVQ/LGEe
L6YXKW9aLG9cLg9`KF]/K6YXJ6MWIf]eNgn3Q8N4O7UiN7]lN7AdMGA_K6e^LWIh
O7mnOh:7SI:@RhZ9Q7mmPHN8QXB4R8jASXZ8RX^9RHfCVIZKWijLW:2QWijNWIbM
X9nHU9BGVINCU9RJVifMWInPX9nMViNCT8nCVIjPX:2RXj>TYjZ][Zn_/:fZZ:JQ
WIZIV9JFUi^OXZ2NWIfKU8n>S8Z6Ph1nOGagLW5eNGUjP8F5PWioOg]iMW=cMGMj
NgUhM6iZK7=fM7AhO820NgUiMgEbLG9dMGUmOh:4Ph5oOh1kMgMjNgUgO8:0NgMf
MgQjNgYiNWIaK6UXIFEZKViXHfIZJfUUHF1TJF][LGUkMg=`KfYSH61RI6EVJF]/
KVm`LWAbL6m]JFQYK71cLfm]KW5_KFeaMGAbLG5^JVISHVM]KVQTJ71dMgf3QH9n
P8B3P7aiO862P823RHZ3OGb1QXZ?UIVKW9RDU96;QXF;TI2>Si6@SHZ;SHb;Rh^?
Ti>?RHV;RXR5Q8F9SiBGVifLUiBDUI29RY2DTHb>U9>AT8f?TY2;QhR=TY2:R8b@
SXZ8RHf@T96FV9RETiBCSHN6QhR9Qh>0PXN;SHf=SXb9QhN4OW]kO7UfMGEgNWaj
NGamN7EfO862PH>7QhJ4PX21PhF6RXb8PX27TYB?RHJ3PX>2PH:8SI2@TIBDTI2D
UYFCT92BTi6?SXn?Shf?TY>DUiZLW9^JVI^OX9bFTY2;QH>6Qh9mOhF7Q8:3RHf@
T8n?SHInNWf2PgehMG=cLVi[K6maLW5cMWIcLW9`K6QWJVi`K6U/L7=`JFMZK6a[
K6e[IfASIFUVHEmRIFERHfYcMgEgNgYeLFi/JFMUHVAZJfQSHF=VJFa]K6i`LGIk
OgmkMWAeMW=dMGAeN7UiNgeiLW1bN7YgNH28SHf=Si2@TI2@T92=Rh^=SH^:SI:C
SXb@TiBCU9RMXIfEU9RIUXn:SY:DUYRJWInQXZBX[:j^[k:aZZBQX:6TYJFZ/K>_
ZjZ[ZZBPX:6NVYZKVINETXb5OgalP8N:RXb?Ti>=R8J4Q89nNWQjOX64QhF2OGam
Oh22QHF5Ph5oPHF7Q8:4Rhj8PX65R8N6QHJ:RXN8RXf?SHf@T8^6QHN:RhV3Oh24
Q7afM71/JVabMWIjOgiiLVm]Jfe`LFm]L79aL71`KVYUHfEVI69RIfa]JfeaLFeZ
JVYYIVEUJFmaKf]/KV]SH6E/KFMSI6U[J65LG61QGf5WJViaLgUkMg9aLW5_KVi`
M7QhMWAeN7MeMWYoQ8N7QhN9RXZ9RHZ;SHj>RXF5QXR9QhF6RHV4P824QhJ5QXJ4
PH:5R8V9RHZ<Shj:RXf@SHJ1PhR8RHb?T8b7Q8F:RhR7Ri2AS8N5QHJ:Si>EUIFF
V9ZJUiFDUYVIV9RKWj2KU96BTi>CUiZIUYFEU9:<QhJ7RHR3OgeoPXB7RXR3O7Un
Ph>2PX>5QHB3PX:5R8b@Ti:<QXF5Ph:1PH>2PH>7Rhf=SHf<RXB1PhR;SHb9R8^=
SH^<SHf:RhjCThn>TINIUi:=SI6CShf<RXN3OX23Q8B5QHF6QXB2PX5oOWilO7Qe
MGIdLFi]L7=dKfUTIVa_Kfm_KVe_LW=aKFQXJV][JVY/KVe[Jfm`JfISIFUZJFIU
IfQTHF9UJ6Y]M7UjN7MgN7QeLFiaM7AbKVe_L71`KV][KG1bMW]oP7inPH:0PH>4
PGekNGMfMgQjNgUgMg]oPH1oP8J:S8^:S9:DTXn@THf;SI2BT8Z:SY2@TIJLWI^G
U9>@S8V7RHj@TI>DU9BFV9VKWIfMW9fRY:BWZjn^[:ZXZZf/Zjfa]KJd[j^XYZFT
Xj2LVYVJW9ZDS8^<RhZ9RH^;RX^>Sh^5PhF9RXN2P81oP7moOWajNWamO7alOGem
OGelOGalO7enOWioOW]iN7QhNgeoP7n0PhN9R8R8QhJ4Q8N9R89lNgemNgYgMWId
LW=dLg5aLG9eM75^K6YYJ6Q]LG=`KFa/K6]YIfAQGeiQIfe_KVi_L7=eMG9bKfe/
K6maLFm/K6a[JVQVIVEUIfeaKfYWJ6QZKFmbM79aLgQhN7UiMgEeMg]nPH5oOGj0
PGmkNG^0Q8B4Qhb?Shf@TiBBT8n>SH^7QXJ5Ph:1PXF7RHZ<RhN4Q8J8QhB2Q8V;
QhF5QHR:Rhf=Rh^<SH^7QhR:SHf9QHB4QXF3QHN8RHR8RXf>SHb=T9:@SXb=Si6F
V9RIV9JEUiRFTiBHVYJDU9RJV9FBSXZ8QhN:Si2<RHR7Q861PH1nOH22PWekO827
RHJ1P8:6RX^=SXf;RHN4Q8J7QXF8RhZ9RH^<S8j?Shf;QhB7RHR8RXf=SHf@UIJE
U9FFU96ATI>HUi6=Si6@SH^<SHb:Rhj>RXZ:S8j>S8V7QXF1OGj1PWmlN7MgNGQf
MGEeLg9bLg9`LG=fNGYgLVi^L71`LG9`KVa]KVi[JVY[JFITIFY]Jf]ZJ6ESHfMY
J6EWKG1^KVm_Kg5aL6i]KFQSHVMZJFAQHF9SIfY]LGEfMGIhMgEdMGIfLVaZK6e[
JFQZK6i`Kg5bLG9dMgMdLFe]Lg]nOh23QXR8R8Z:QX:2PX61PhJ8RHZ9QHF7QX>3
QHV<SXnATY6BTi>BU9JDTYBGVYfPXJ6QX:6TYjVYZZb][:RVYZJVYZJXZ:JSX9nR
Xj2LV9JFUI>BTI2=SI2@SHb=T9:BSXV4PhR<RhZ;SXn=RX^:Rhf>SHj@Sh^7QhZ<
SXn?SXb9R8Z>T8n=S8nDV9VJW9jMVYNEU9>AT9:CTI6BTI6@SHf>SHN3PhB3PH63
QHJ5P7UgNGalO7amO7QeMGMhMgE`K6YYJ6U]Kfm_L79eN7McLWIhMgAdMG9]JV]]
KFYWJ6Y]KF]/L79_JFETJ6]/K6e/JFIXJVe_KW1bMGIeLG1bLg1^L7AfM75bMGUk
O7enPXB5Qh^>SXf;R8N5PWikO7akNGYnP7mmOGn0OGUiOGmmMgAiOh61OWn2Ph:1
PhF1OGamOWemOGn2PhB2PX:1OGamP8B5Q8:3QHN6QHN:RhR6QhZ<T9FIVYbKV9JF
UIFEU9BFUI>BTI6@TIBFUI>@SY6EUiB?S8Z6Ph62Ph1nOh60OWeoPhJ9RHF2PhJ5
Q8N<Shj;RX^:R8J4QXZ;RXR7QhR;SXn=RhR5PhF9RXV9S8j<RX^@TY2=Si6ASX^;
S8j@TI6AT8n>SHj>RXJ7RX^9QhR>TY>@RHF5QH>1Oh20OgajN7AcLg=cLg9`KFi`
L6i_LgQiMW5^Kg1_KFe`Lg5/J6Y/K6UYK6m`KfiaM7AaK6UZJfYYJfm_KG1dMGAb
LWAdMGMeLg=bKVUWJFmbKVYZKW5dMWMkOWilNg]jN7MgNGalNgQeM7EdLgAfN7Qh
NG]iMGEgNgahM7IlPH>5QhV:RXV:S8R1P8:4QH>3Q8F6RXZ7QXJ5Ph:5RXnATI2?
Shn>SHf>Shn@TI>GVinRYJNWYZFTXj:RXjFUXj:RXj>SYJNXZJNUYJBSXYfIUiBB
T92AT8^:S8b9QH>4QhZ9QH:3QHJ4PH63QHB3Ph9oOGemOX1oO7]mP861PH:3Q8>1
PH>4Ph>4QXV9RHb>SHZ9RHZ=SH^:RHV:Rhb=SHZ8R8Z8Q861P7mmOGioP81lN7Ql
O7UfMGQjNGMcLG5`KVYWJ6QXJVa[JVa_MGUkNgUhN7MfM79bLFm]KW9dLg9bMGUj
NGMgMgQeLgAeMG=cMgQiNGQiNWYjNWYlOh:1OWinOGYkOX22PX20PH:3PhB9SY2?
T8n?Shn@T92?RhN4Q8B2P864QHB4QXB1OWj0PX9nNgYmP862Q8J7QH>4Q81mOGem
O7YiNG^1Ph5oOh1oO7anP8:2PGmoOWelO825R8R6QHJ8Rhj@TiBDTXn>Shj=SHj>
SH^;S8f>SXn@TI6?SXj@Shj=S8V5PX:3PH20P7mkMgMjOX>5Ph:3Q8>1Oh24RHZ9
QH5oP862QHV8QXF5QXJ6QhR:RXV7QXF6QHB6RXn@T96BTi6>S8jATY2>SHjATiFG
V9JDUIRGTi6@T9:BTY:ATiJFTi>CTXn:R8V<SH^:Qh>1P7imOWinOgmoOG]iNGao
OgaiN7UjN7MgN7MeMGMfLfm]KgAhNGUiN7QhMgEdLFm_LgEeM75`L71`KfiaLgAa
L71aKf]YJF]]KFe^Kg9dLg9cLgAcLG1`L6m`LWAdLFm_LG9_KFe_L71_KVe/Jf]]
L71_K6]]Kg1aMG]oOginOGYhMgMgMgMeMGQlOgmmO7alNWQiO7n1PX:3QHB0Oh64
QXN7R8R:SHnATiFGV9NEU9BCUIZMViRHV9RIVI^NXJ>RXJ6RXIjMWY^FTi:BT8j<
S8Z8QhN6RHb>SH^:RXV8R8V<SH^7Q8:4QHF5QXN8R8N7RHb?Shn?T92>SHb<RXR:
SY6@SHj@TI6@TIFIViZGUYFFUYNHUi>?Si6CTi6?SH^:RHV9Rhb:QhN8R8F1Oh25
R8N1O7YiNGQiN7QfMG=cM7IeMGIiNgajNWYgLW1bLg9bM7IgMG9bMGYkNGQgMgMf
MGQhM71aMGUjN7MgMgMfM7EiOGekNWYlNgQeMganO7UiOH61Ogn3QhN6QHJ8RX^<
SHj>RHF4QHJ4PH:5QXF3PH60OgemP8:0OG]mOgmoPXB1OWemOGakNgamOG]hMgb1
Ph9oOG]jN7EeNGamO7]kO7YjO823Ph:0PH>4Q8J9Rhf<Rh^<RXF3QHR9R8J6QXJ5
PhF8RXV8R8V:R8F5QhN5PWikNGQhMgIfMW=bMGYnO7UhNginNgYkNgakN7IfMgQi
NgioOginPHB2PX>5QhJ5Ph5oOWn2QHN7RH^=SHZ9RhnATI:CUIFDU9NJViZHV9ZK
VYNEUIJETi6BUYRGUYNHUiB?SI2DUY>>S8b<RHJ6QhN6QHB4Q85oOX64Q8>2PX5o
O7amO7YiN7UiMG9cMgb1PGmmOG]hNG]jN7MfMWIeLVi]LGAdLg9eMgMfMGMhN7Mg
MgQgMG=fNGUfM7AfN7UgMGIeLW1bN7emNWUjO7QbKg1cMGIfN7UgM7=fNWalNgYl
OWioP862Ph:2PH62PhB6QH9oP8B8RHN3PX:2OgioPXB6QhV;S8b;S8f>SXf=Si6A
T92CUiRHUiNGU96BUYVJV9JGVIVGUIFGVY^LW9fMVIJFUiNDShZ7QXB3Q8B3P7io
PXB5PgmnP8:1Ogj0P7ijNGUiN7MiNWamO7eoP862PhB5Ph1oP85oO7anP81oOh65
QHB3QHV<SXf<SHb:R8Z;RXV9Rhf>S8R5QHB0OG]lOh1nNg]lNgQgN7anO7QdM7=b
Lg9bLG1_Kfm`L6i^LWMhMWAcM79_KW1bLW5bMWUiMG1_LGEhN7UjNg]iNGYjNGQi
NW]hM7=dMWEdM7MjO7akO7n1PH20PH:2PX>5QXF3PhB6R8R8RHZ9R8V<T9:AShn@
SXV5QXR9RHR8RXZ9QhN8R8N5Q8J8R8J6R8Z8QHF5QXN6QhV9Qh>0PHB9RHB1PH60
Ogn1QHN6PhB4Ph:0P8:5R8Z9QhF5QXV<SXj>SXn@T92ATi>CTY6>RXJ4QX^AU9:?
SXj>Si6CShV3PXJ:R8AnNgUiN7MfMWQjO7j1PX1kN7YnP7mmNGUkOH63Ph9oOGj2
QhV7QXN7QhJ5QHB2PXF7RHZ;SY:DU9:>S8f@TYBFUYBBTYBFUY>CUINHUYFEUI>@
SHf?TI6@T9>FUI6=SI2BTi:@SHZ6Ph20PX:1OgimNgUhNWj0OGYjNWMdLW1aLG1_
KVi]JVUZK75dM7EeMGAcLg5^K6][K6a[JFIUIfQYJ6U/Kfm_LWEeM75`LG=dLgAf
N7UgLg=eMWIfN7YjN7QjO7ekNWYkNWMfMGEfMgMgNGUhMgIgNG]kNWamNgYlOWej
NWanOWn0PGmoOWaiNWf2Q8:1PH60OG]jO7n2PhF5QH:0PXF7QhF4QHN8R8V;SY2A
TiFDTXn?U9VMW9VFTY2@U9NHVI^MX:BUXinKV9JGUiFBShj;RX^;Qh5nOh:3Ph:3
PWijNW]mOGYgMgUmOWimOGemOh>:SXb9QhR;RhR7QhJ5Q8B6RH^<SY6DUIJETY:E
V9VJVi^IV9VJVYZJW9jPX9jKVIRETXf;Rh^;S8f=RXN3PHB7QhB3PX>2P7ilN7Eb
LG5`KVa/KW5cLg=cLg9aLG5bLg5^KW1`Kfe/KFm`Kg1aLgAcLW9aLFm_L75_K6UY
K6i]JFU]L75aLG9cM7=aLG5`L75cMGEcLg=dMGMjO7imOGemOWn0PXF7R8F1P863
QHF6QhN7QhB3QXR7QXJ6QXB3Q8J:RXV9RX^;RXV:RXR6QHN8QhF4QXV:QXB4QHR9
RX^<SHb<SHf>SHf=SXn@Shf>TIBHVYbNWYbJVYVIUiJEUIFETi6ATY>CTi>@S8^>
TY>AS8J2PH1oO7YgMgIdMGQkO7amO7YgMGAfNWelNGUjNWYkO7j1PhB5QHB1P8>7
RHN3OgenPHB5Ph1mOX:7Rhf;RHZ<SXj=SHf=SY2ATHn>SY6CTY2?Si2@Sh^:S8n@
SXf<S8b<SHj>S8Z:Rhf=RXAnO7enOgikNGMfMgQiNGUjNg]jNGIcLW9aLG1_KVe]
L79cLgAgN7EcLgAcLVm/JFQWI6=TIFETHfEXJf][Jfa^Kfi]KVmaLFm_Kfm]KVm`
Lg=aL7=fM79aLgEfM7AdLg=cLg=cLW5`L79cM7AeMWIgN7YkNWYkOGemO7aoPhJ7
QXB4QXJ6R8^;R8N8Rhn?S8b@UIRGU96>SY2BU9BBShf@UYZITXZ7Ri6FVIVFTI2A
TiFDTY2?U9VHU9:ATIFIVIJBT9BHWJ6PW9NFUiNFUIBDU9>DUYJETY:CTi>AT96E
VIbLVYRFTi6AU9NHVIVJW9ZFUiVKV9>@TI>FUYBASHZ9RhnBTXn=S8f@T8n<RHN8
RX^<RhV9RHb?T8j9QHF4Ph60PH1mNGMfMgQgMgQhN7MeMGAbKVa[JVUZJFMUHUmP
HfIXJFUYJVYZJFQVIVIUIVU/JfY/K6a/K6i_L71_LG=cM7AbL75cLg5bLFi_L7=g
N7QfM7IiNWUiNGMfN7YkNWUeM7IiOGinO7elO7j0Q8J4QXR9Rhf?TI6>QgijO7n0
P7ijMWIjPHAoMfiZJg5hO7]hMWAbLG5`JF9MH6YcMG5/K6i_L6m[IfAUKGEjNG=^
KG5iP8B7QhB3QX^@TI2?SXnBTiBFVj6UYZFRWibKWJBZ[JZWYjV^/[>c/K2]ZZ^/
[:ZVXZ2NVYRGVIbMWIbLWYfKWY^MWIFCRXF6QXR<SX^:RHZ9RHV;RhV8Q8:3QHJ3
OgajNGYhMgQjNWQhNGYkO7emOG]fM7IgN7QhNG]mOWejNW]jMgEhNgajNGaoOh1o
OgmoOh22QhN4PH1nOWn0OWelNW]mOh62Q8>3PH61PH21PhB5R8^<SI2BTI2<RHR:
SXn?SHZ8QhN8RXR3NWAfNWmnOGakNWUkO7]eKfUXK6m`LG5_KVm]J6ASHF5VK6m]
JVEUJFieMG=`Kg9gNWakN7MfMWYkNWUiNWf1Q89oO7eoQ8Z;R8>5RhnCTi6>RHJ7
SYJHUYFDTY2?SXj@TI6CU96ATI>FV9REU9FFV9RHUI>AT9:CTY2>SY2ATY>CT8j@
TI>DTXf:S8jCUI:?S8nCUiVGUY>BSXZ7QhJ2OW]lOGn0OWemNgQgLW1dMgMhMG1^
JfUZJfY[Kg5aKVa_KVmaKfm]KG1`LG9cL6i_LWR2QhAnN75bMganNG9YKGAoR8B1
MVUSIW1hOgebIfI/LGAaJfAOH69WJVUZJVUZJVINEU=HH6Q^K6EPH6I_MGEeN7b2
QXb=Qh>1PH>5QhB5RY6LYJRRWinJWZV_[k2`ZZZa];Fc/:VWZJNZ/kVg];2_/:fZ
Y9fPYJNX[:j[YjJQW9bPX9nRXIfRYZ2KVINBTIBHVYbIUI>?RH=oP7akO7amOX20
NgIeLfm`MWUiMW=_KWAeLFeYIfY_LW=dMGEcKFQZK6EPHfQZK6aZJVYYIVEYKG=d
LGAdMW]mPH5nO7alOhF7RH^;RhR9SX^7OgMgNX:9SH^7PWinOG]jMG1]KgIlNWI/
HeiLFUQGE59EFUmMF5EBE5aOH5iLFeYLGfEWIVUZKW5aLg1]KFeaMWIcLWIjNgb1
QhJ8S8nEV9RIVINFVIRFUiZOYZVVY:FTYjNPXJ>NXJ>SZ:VZ[Zj^[ZVTXZB_/j^U
Y:NTWYRGViZGV9RGUYRIVYNCTYJATINCUYVJUHj=RXf@RHV=RHJ9SiBAU9F?RHJ6
P7AaLWIiOgigNGmlNWYmP8>6QXB2OgegLW5dOWmmP8:2P862NWEfKFAXLgYjMFa]
LW1]Jfi`IUYBEfE/JfUUHfQWHEmHBDA1@deBEUUQIF=XJFATJVMTKFmVIVQVJG9l
NW5dPX^AThn<RH:7T8b;T9^IU9^SZ[6`Z9jHW:6UZkJg[YnkdL2^YYjAVgj7f/>1
T;?MfIB=YiN9ULC6XYf[T72DYHZAQ6bAXiJ?X[RRLgB<UG=XY:5mP7:=[9=]O7aW
GEITL5mEHV9GHXIlKfQHKG]DD69YJfiaNGU`RXASJh:1SiAkK76;QG^CVI2ASh2>
VHYZLW9?HGaiHTMJMVE<BGVEN6MLKH9gL6aTDce0DETn828^ADdoBG:;OX60PH60
GTAOIUUSQ825TI6/aYIgX:FVZJBN];j_ZJRUZ9b3YLJi][f__mJhX;VVRi2dckZT
ZZ=fLiZILf5jSYNSV8>;Xi^AV92@SY>WWiFEVZRJQ8bKVHnI/jn[VH2?THn3Pi22
O8NAQh=lPHAiR8YbNh52?dhf?gFdcm3>eM:hRUd^4``08Dn0U81RA4UJGDU?JGEn
PhIkJC`000004Ae0G65eP85jKfQQJFaKC44mDFAFCe9IKhBASY^iX:2Z[;>aZZ2@
QWijQXb<Sij/`=;@a]70[9MnV[neVXfFVX28[JFL/JNH_>?6V:S2^Z>OWY1kOGA[
Oi6OUHb]UW=jS96DSGbBUF]SNWY^I7=gOINC[:f@OhBGNVEhPVUORJ21P8N7W9bM
VYF<M8=TE8IoAb4gGV5TUlkPm?ooh[^GVg0j=d1?HFMbPFmHHVADDU9]NfYWF58j
91@000001ahT9DYhUZf[S7YeHEA[NWf7P8B2G6>8M7:BT:Bk`MS[j=ZYQXn9NGET
IGn0R9BV_[k5bk>`aK6EViJ@Qg5UEe=BFGjYU6n?/:ffdlZkZYVGSGmhR8BCXZ^^
XJ:ZU9>TWIfJXKFWRfe`R7ihR6QXSXbCOgAiOhb5KW=gLX6;JV^:SgIYJ5EMKW9U
EffN^kgDk?oog=SHWGUYF65ZK7R;M6:8I2XeB4i<@DaKEEeEASDE3R/^:a`74S]L
KXR=Th9ZFU1eQX9aKGMgLW9oNgMeQYn__L_^m=:^[9j?XIAiQgiOLW1QKH6JTF9V
VImoGVJ0MV1LLX5ZJIJNTi^SZKG0]:BIXkC1_IbEXimhIfieOgIaRIN<P7N5UHZ2
SJ2GRHEoQHV:T7iIIIZMNF^=SWb=RhFCRgVYZINUXZ:IUj:FWlgOin_Edn?L]7QI
JG]>?Ui[K6Y34APg>S8S=5IG=SmGG658@48`8AdP>3/eEgn7SWmWOWe]PhEeQi>K
SW:5//6/Y;2da<2NXkJm_;NYVj2JQGYdM6QGGV]eNFIOLXZHVXf9V9ZIV9>CWY:1
V[BANY6JYl2]Z/[:`[>/`LRgUWj7TIZDPhfHW[Zf/[VQ[<:_[:J@P8F>SV/kBU9J
JE54D6j4Tin8T:6GUiJ]b<>oe>cig;Zb/9ikOh5]K6=IJ7QjISPG:3e;ESXC8c4b
=2LS7`h230P430T;:deLKgMjO79fNXJ>PfaKNj:^W7Q^PJW=bkZmb<:k^/72/jRD
PX1`H4<]=Bl`@U1CCU9dSh2:QVE_LWUkHf5RJW9WHgF0Lg^D]mO?bl6lb[2OXjB/
WijQVi^9OW9YOjBaZjB=P8V;PFm/LWMWDTToHh9iIeaSI6eoS9BF_ngooooooooh
iL6d`JV2Jea_N75]D3<mHGMlL5E@GeeMHU]B@B0H3P0E8Q4cFfV:ShR=QX>7U:R/
VX:6Tifb[Y:>W:Vl]:Z`[KS<b<[Og<:YTHN?S89_Bd]HATiB?TA=B5aeMgAbOY:K
Xj^OU9J=PhF9RH^7O8nb^:NAPi>^[if=PWefM7UjN8:2HeYeQY:DQX:=[[6AQXb=
QW]lPX9mMWR9U961RJS2i_coonKGg=6iYYAgGDm@EDaMD2HW;d=MHV5@AE5ECU5>
?bhR6PdB6bDd@D]GJ7f8QHfGVK3:`ZVNUi^QQgajLGj7PH^@QXRFX[?6cmgC]K2T
UY>6MfQNIFm]Mgm]GEmKD5UXLGjAUhb<THamL7=dMH>7PhV0L7V5RHjBU928T95o
N7agJF1PHfMULGf0V[:YX[6g^KZZXjjbZIF4QHMhKG>;Wj6R[[B[[K6LS9>6KfQW
Kg5RD3TY;Rl^>DA<FF5PIgIdLEi6?d5;A3@e<dI/O7]cLh66T;7<a;Bf`mC?aLBi
[:BOXifFXIR4SjNjcm>nZZVYXJ:c^jnRWY>2M7^9QGMOF6IYKW5FC4e7FF5MGeaV
MG]mP8F6QXN9SHj:SHJ0TI^8PYJJX:bYWYbOWYnRVXAgLFmmSY>:Nfi`R9^FShb5
U:Zfcn3A/9^QZiR0MVQJDD=4DD`m<SM=E5QTH5MRJF=XMh5kIeIAEEI2:bPa?3i0
DUMLJf][N86>Vi><W;Fk/JZKR8IjLGj=Th^6RYFcb;J[_lV`VjF^[Ib2PXJ0O7Z1
RWIWNX>7Qg9XNhj;Mg5kPH9gKFa^L75kQHbGTGn3WjFQXj>`^K^oa/NlXX^BZ[:_
Z:2EUj6SWXj4SI6>W:Z_ZIFF]M7RhLo6`;BQQ6MH?A/@9TYD>adB9SPoCUEDBCY0
GH6EPF9EDDe5<bTa?d4oB5ISJ61AHX:5KF5dS9FIUHZ>ShV5PgmmLfmeOYJ/Z:Vo
d=CCb/;3]J>N[Zn?OWMaNFM=?cE4CdE7Cf>1TiFJVHj3NGn7TIZ;M7F1Og1ZIV=V
LH>@U9BEW[O:cl>RVZR_]:NPYY^AW:V^[9f?TkC6_[F_`>;]hmSCb;BGQ8>0KUYA
FVmiKeMCDTiIGE59?2`Z>dU2>BPA1PT=1@0>8BX[@EQRHV1jTZ2ZX:>g_/kQi=oF
`[^k^[jcWhAfPXjAU9bPXijDVYnEQGUgO8RFS7QYF4H/8Bla<ST`:dASK6mfOXVC
TI2FXjb_];bo_[Z]W9N>O7f9TibIU9NRYIjIShIdK7j6Qi6ASHfBVI^GTYFR]L?O
oooooo7WgmJoWGm`K6eaJUa>B4I7EEeFBBlT>4mLHEaJGEmMEE1>DUeSGeIAEf5V
JWMhN7n1TZN_^<7>gnOSh^C>^KNZSWn2QHjNWI::PHF<RGajRIVFUjVWTGiXGEI5
<2<R;34Y8bTlCUEHFUiQIG64Si:@PhFDVYfOWY^HU8fGZ:b_^;^_Z[Bn]YnCQV]N
HVIZJEiEFE=9EFegOI6/^kjo`lSAd;nWSGMiQXEmMVm]KFMMEU19>R//@EUE@d51
@4=2ADLi9bLd@E1DEeMGGF=/MWQeM7QmR9ZWZkC<fMK:]kK>gn7Ph^?OeLW2c=6m
[k:b[j^TZ;6XTH9jJUQBAS4N5R0^<cDoBdi?HG^?VY^P[JbU/<?<akZ_XY>AS7ih
NWj4QHN<UijHSi6@S8f:Sj:a/JJRWYbV/kk8d<[4aL?2/YR?RX1YEUYTHE0m;b/^
;blX8BP`=d1>G69NEeIJEdm?DDiACD51BU9EFFA^MG]nR9ZTZ[6c/k:a[jjh`kZW
X9jMXjNVWINFTYNLWZNUV9R[][FaZ9nBPF]@ADM>DT`d9BPb@Te6?D1=Gg9lOH67
S9>QY9NAUYN@T9VHS8N?X[>dZ:F^][Nf[J2V[j^RW9Z?RYNJW[6j/kW5a[naYIbA
R75KHW5gKU]:?cHa;blc=C8f@4M@GFE]NG1PGf9YKViTEUUUJV]]JVihP8b@TI6?
VZFXZZZRXZbj`:nNU8fFXJJWY9bATYVDS8J4QHR@UiBAU9NAOFADE69UFTe5AU5I
F5aSHFAaNh6@W9^FUYfPW9NFU8UjKfITK7MhLFmhP7elNG^5Sj6[Xj2V[[[1^[Jj
_L7:h?G^gn?Ug=SC`JJCTIBDR6mVKfQ@@TYFFUYBC4a?GW9iMgAYEDM6Bd8a<S/i
>4UGEUIOK7V1RI2CUIn^^ko5f>;MeLk4^[6XZ[>[W8n4P7U^JfITK6]TI6Y`M7E/
H65TH5]>A411@CP];34l@dA;EEION8VAVI^R/KZf][:RWJBXXI>;PgelN7A`KFIW
LgUkNG=dMgV0R8nETIJaa<_Df]OGiN[Oe]KC^YJ2PXElIE13<BXd>c/a:2X/;cU2
AT<n@4E4?T=FETM6Ad10B5AOI6AZN8F<TIVS/L?EioGej^GQfMWNg]?6`Kji/JZY
[JbVVhYiKg9hN7anP8J2O7I]K6YYIeaBCe5ADeYOHV9OHFU]MXRDWJ^`[kJm_kno
a<S8a<2m^k>RThn<Qgi^HeaJGV1UJfa[LGMfN7j=VjNh^KFj`;fbZYb5O7YhMViT
G5QDCdiEETeBG5UFEUENHeiLFTm5@TA3>Sa6BTi@EE]BBe=ULFiaOY:VZZJRYJjb
^lK3`L[Bclg?clc3^kF^XIZOXifARi>JUI67N6eYKVmXFdm=D4a8BdXl=3Hd=Cm=
De5EH6ikPXVGXjFZ^;joa/[5^:>GV9^IThEjNh:>UYFEUi^LVI^U[ZbU[lCAgM[:
aKfZWINEQVQDC4Q9AC@V9R@T:b`]<CHmA4eIGVQgNGb3O7Z3Qh=oNGUiL6]_MG9U
Ff1cQY6BS8bBUZ6]/KJi^[Rj^KBeZj>RW9>6NgIdJf1MGf=XK6a]L75`JfY_L6aU
IWN4PWeeKFISJVeWHeeKHfagRiNJXZJQWZ2[/ZfUXjV/Y9>4PH:7SY:FUinZ[JZV
Zk:b][k3`/?;fNO/h]O@blRn[YnFTHf0Lg5[G55>CTTn;1lQ8BHg?D=?EeiOGF9[
KWEmNGIdL7J0PGY`JFeeMWYhM7MgNGmnQ9:FU9RPYjJY/kFi`Knf[Ij?Ri2BRgeV
EUaWJUmACdi5AE1GEUA@E5mVLG5WJFYTGUUIHVe/JG=iMgb6TYR>RhV6U9jMUhMi
NHFAU96BT8f=TIBEUYJMZkBg_lO5_L79d=;8`L31a<:l[Y>4PGEZHTi6?S4_:R4M
6QXS<3Li>T9CHVEUI6=VIfITHf=/MX2=VibBSYNU/Kg6`[o9eMC?c<O2_[N_Z:BL
U9>@QX61OWaoPgmfMWE^KWAbJ6M/M7QfLgA_IFEaP8N8R8N3OhB>SXF0RY:EVIfS
[:^WXY^JWJ2TXIVIVi>:Ri:ARG]`KVi`KFQYJ6U^KVeaMWQoSIVX/k?1d]KHf=KA
aKbbY9^AQ7MXF4a9?blX9AhG6bdg>D9<CDQ0?TQHG5ECE59DFUaFDEUUJ71oQhZ;
RY:S[[:e^<78b/W5`/32aLO9a;V`[K>j]ZRCP7MbKFUTH6EYJFEMF5IDDUEHDTM:
EeI@D5=JFU9?EV=[K79lQY>JTXZ<VJJ[[:jYX9ZHUYJFU9NJVIfPWIVKV9RIUIJI
VIJBT9RKUY^RXZ2MU96BTY6:Nfi]M7Q]HUe>?d=9AD51@Clm?3a1D5eSJ6mfNGaj
NX:=UiVHUIFFUIB?RHF5R8^>S8IoPhR7S96?T9VMViZQ[[F/X9Z?Q8B8Si>=Q7QW
FeeRIfEPGEIEH6UYJ6igNgehL75jQ8N8SI2@U9ZIUi^LVI^SZJRUVhj:SXb8RH^;
RY:MWYJ?QhRCVifLVYn/]K^l^KNkaLo?b<2l]k6b/ZjWUhZ5QXIkL6YNEf1UGU=9
Ad]?C4U6@S/f>c/c<CLg=Se5BE1FFVA^MGQfMgj2QHAmPHEmOXZ>RhJ5SYRKVibN
X:2QYjne^l;3_K>TW9V?Qh=gIeYEEE5=D559@C/oCeUEDEEHGVI[K6U]NGioQH^?
THb9S96KYJ^_/[Be]:n^[JbZZZb/ZZBRYZZ[Z:JYYIVCUYNIX:b`YYfLX:6PYjRN
Ui>EV928P75RCSm4AD12?ci6BdU6ATY@EEQMIgB2R8bCUYVJUI29OWMfNGQcM7Uh
NWj4QX>4SI>EUijRWj6[]L77alBm^l;;b[je[Yn?RH9dIf9OEe19?c]0AD]>CTe;
DeYNJ7Z:TYJLXJ2JTXV:S8F0OgmmO7akLfa_M7MhNWelNh:BX:JXYIfIVYbNVY>B
T8QlP92EU96>TIBO[J^UZ:fc/JJRWiJ<OWI^H5MABCd`:RTX:2dd<bd/=D9@FF5T
Ig1lQ8AkMWEbMgf5S8Z4PhR9PGioN6maOX^DWJR`];:`][^i^l;2^kNk_;6WX9R=
O6iVHf5KD4Dn?Clm=cDmATaEGV=VIfimR8jCUIVNXJRYY:BUXZJ[YYjHT8R9SXn<
S9>GUijRWIVKWijHShJ6S8f?TiBATIJHU9FNWi^ESi6BTifPV9NERWa_J6AKE4e9
CDY5ATY<B4E8CeYOHFASIfiaM7=]K6m`L7=fNh28TI69P866RY2HW9J=Sj2a^kfm
^kNmbLZm^;jo_KV`Z9nBR8>0MfIKEe5;D5IGEUQKGF1PFeQLGEeXMWYlR8j>SHV9
TIFCUYjRXInSZ:VVWI:@TiJLYZb[Yj2MViZLWIbJVIfSYJN_^;VeZZ6OWIfOWIN@
SY:BR7iaHUaRK6MGC4M9DUMGEUI=@415ATA4@T13BU9IFE=@EUeOHVMWHfE]Kg1f
OXF9Q824SYNMXZNXZk6b/KNn_[N_ZJJSVi28PW]`J5mA@SXj>Ce3A495CE=HG5]M
HfEXL7MiNGIlRI2BUibKW:2VZjfb^[bg/ZbRW9fU[ZjWW9JMZJb][JRUYjVUYJJV
YZ>MViRBTI>HV96<QWijN75]KVi[JW1eM6]RGV1QHF9UJ6MWJ6ebLfmaMFm]MXF8
PWmnO7QfNGIcMWQkOWQcN8VCTiBFSX^CV9:BW:N[[kRh[jb_/[Ne[JVVXIB<RhAk
NWQ]H5I;?cTl?Cdm?3m7CUIIFF5XJFmjQ8V=UIbNWifITHZ4NW=bMGb1OWQcL79c
MgYlPXfEUIVV/kNi_lG9b<C5b<6ma<S5]:BKT8^8NVmTEE9FGEi=@S`f?DE6C4iB
EeMIGVA/K6a`KfeZIf1JGV1OHf]cNWemNGMgNH:<TI:FWJ:TZJj]/;:^[Jj`]KRj
]k2/ZjFLThR6QXB4QH1jMgMaJFITHF=UI61GEEeUJfQQH5mNIG9mQ92PYjFWZ:RS
X:>SXYnJUI>DUYNGU9FLWijPWIbV[Jj_/[:/Z[>e[Z^SViVHUXj0Ng]mOg9VGeMC
DDm<@3Ll>S@h@4=1A4I4BDiCGfifMWIkPXV?SXN3Oh25RXnDUiVKVI>;QXR8RHjC
VJ2SYJJVXijNX9jNXJ>QVI>BSi>KWIVARXJ0NWb1P7YcKVm`M79ZH5MBC4mIGf=[
LgZ0QXV7QhjDVIVIWIjERhF0NWMjN7EhO823Q8VDVibKW9^HV:>d_/74a/K4^k2X
YJFLTYBFU924N6]LD4A2A410?38b<cDh>D14@DE>FVIYI65SJVi]IemNGf5WKG9_
JVa^L7=gNWn2Q8R;S8nCVZBWYjNSWIbTZjVPVIJGUY>?S8^8QhR7PWacJVMVI69R
HfMXGeMFEeQIGVMZKgEfNhF<Shn>Si>FVYnQX9fMXjVZZZ^XZJZUXJ6W[K2a[jbb
^ko2bm?HdlS3`/2n`L:l[jBNUHn9NfYIDU1?CDDk>SHY8bH_<c@h>d5CH6U`Lg=b
MG^3SI2:R8jGW:2PVYNGUY:;QXJ9S8b9QhJ7SI:HVYBAUIZKVYbGShnIViZKUhf1
NW]jMgEaL7AfM79`JV5KGV9SI6M_N7moNG9_M7YmPHF5PXF=Ti>:P7YfMGIhOX9o
OH65PGYiN7EeOXR;SiRX]l34`;Ng_/76bL[8aLG1^[R^WXejL6UQGUI;@S8/;2@R
8bH[:BX_=TMGFe]MHVM[LgIhNWMhPi2DU9JES8N6Q8:8SXnCV9RFVijJV9^KV9NK
WYjOX:BWZZf_[ZVRVY69QHF3Ng5YI5mFC4Y?Cda?Ef9ZLGQnQ8V9RI2JWIZCSY6E
Thf:R8N5QHR<S8Z;RX^<S8nAS8fFV9JIXJ^a]KZo`LC6bLkCe]2o/ZVMUi20KeiD
CdE4?BXL4a4C4QXW;cY3B4mCEEQLI6Y^LFi^N7mmNWaoQ8Z@TiFEUYfRY:N]/k>_
ZjVWZJf^[k2[YJ>NW9^MX9fGThj;SHb8PgadL75/IEaHEeYRJfaXJ6igOX>6R8fA
Thn;SiBIUi2?T8^3OgmnOH24Q862QhR6PWeiNgalP8F2OH68S8jDVifOXJJ]];c7
clVn^K:ZZZFEQW]cJVAPDdI4?cH`;C4e>3Lc<SHh?dY>BTM4@DEBEeMOJ6mgP8F7
RHN2Q8jDUIZNUiJNXj2NX::OV9FCTY>EVInQViRGThn;QGn0QH=oNgE/IEmEB491
@Chh>dIAFV5VKW=hPHZGY:RX[[Rl^;Bd][>_[jjYXIVBT96?Shj8PX>7RHJ6T9RK
Xjfe`LkEf=cIemoUgm34_kNf^:fFPWEYGU=6?CTd;R`/;S@j@DA4ATI9EVQeMW9d
NH:5Q8B3OGMeNGamNgMhOH25SI:AU9nWYjR][k2`[Z^UXZBXZ9nGUiN@RXV;RHJ3
OW=/K6i[HEYGEUQMHV9RIVQWJg5bM7f9TYVHTi2CU8^5Q8F4QX^>Rh9kNWb2PWag
M7=gOX>6Q8>2PXF6QhV9TZ2YZjfe_L;6a/2j]k>d]:jSTX=eJV=JCD<i<BdZ;C0a
<c4^<3<lBD]2?D9:DEMPJ6YXKGZ7RXR;SXjBV9bQYZb`/:^TWYZKW9bLWZ2RZ:ZY
Z[2i^K6WY:N[[JbTUHR3OW9SEda3?chm>SHf>Si2B4iCF5iYMG^0RI>HV9VNY:NZ
[kRl]Jn^[:RWZ:BKUI:ASX^9R8^;RXV;T9RS[k6_/k>c]kF_Z:FUXZ>RTWmbHUA:
AdI2?CPd<cHj?T=5?c/nAE=QIf5PIfmgPHN4OGj8TI:>RhnFV9VJV9FGWj:OWj6Q
XZJ/[Jf[YjJZZZV^/[>b/:f/Z:>OVi22NW]iLVm]K6UWIVIRGemNHFATIfacNhB5
P8>8S8^9SYFFUIZTYIfCT8n9PWegLW=eN7UiNGb1Q8J6R8^@WZje]K:e^[Vi^KJ`
ZZNZZZ:IS7Y^IfERFe98?3@c;b`]<C4[928W<3Li=cHmBEAOJF]]M7f1OGEcMWUj
OXJ>TYFJVi^LViRHW9jNWI^NXZ:OWj>WYj>PWYjRYjJNUXn6NW1UGUQABdI2?Ce1
@D16CU9GG6EbOhV@UIbRYJRZYj6R[[Nd/[>b/[2/ZZFKUIJFTXnAUi^KVIJFVJ6W
ZZRY/[g2`/?4_K:a/Z^WXYJ4M6aTFeQCAS`d;c8d=CU0@d=6D5QMHfESI6MZKWZ3
PX66RHN6QXF3PhV@T8Z:TYVLW9ZJW9nNViFATiZOXjJZ[Zj^[jn]ZZRXXIB7OGA/
IVERGU]DC4E3ADU;Ce=FFV1WLGYoOWYlP7mnQXj=SYVPWIVKVY:;S96>R8N7Ph1o
OWamOWalPHRCWjVa]K[5b/O8b/:e];Ve[JNQU81cJUiGDTPl<c@f=SLi?44o>CLg
=SHh>3Y3BDmNJFMTK7UoQHb=S8jAUIRGUI^PWYZJX:J[[k2_[k6f^[Rc/kVm_/2n
^;Be][>/X964Ng9XH5YDCdM1@490?Cdk>ci1B5=PIf]aNH22QXnFUiVOZK>d/:bY
YJBUYZ2HUY>=S96EV9JAShj>TYVOYZ^^/Jn/[k>c[JVZYIfHT8AgK6ANGEmKCT0g
=CDd=ce2@S`k@4M@FEeNH65VL7f5QXN@VIjPWYZIVYVJVIJJXZ>NVifMViZGT8bA
V9^KW:2UZk2`[JZY[;:b[:NQVIJARX1iMFmVGe]LHEmIEeADEeYNI6a`MGb2Q8R@
UY^OX:>TXIfJUI6@T8j9QH:1PH60P81mNGMgNGb3SIZV[K:b/KFi^KFd^;Zg/jjR
T89gJf9NED@f;RPU:2TW:RXU8bDY<STl?Cm4BDiEEeIIH6I/MGUkOhJ<TIFIWInP
WIRHWj>SWifNXZNXXj2RYZZ]/KBd];Rn_[FXW966Ng9WGUYGD4Q5ADE5ADQ;CeAK
HVafO825QH>4R8b>SiFNYjnf^;Jb/;>c[:BPWYVDU9RIUi25OW]jPhjFWJFZZjZa
^l6k/:j^Yj6PWYF8OG=^L6iUFDa8BT]=DEACCdY6Ae5IEe=CEeaOI6Y/KWEnQHV=
TY>EVj6SXInRXYfHV9JBTI2=R8R=THn@U9ZNX::RX9jPY:ZZY9fESHImLVi^JV5I
DDe>Cda:Bda>DeIIGfEYK75fNgj2QXjGWZJZ[K6b[jj`/:NLUiNDS8B1P7ahN7Qd
MGf7TYbRXj>TZ;:k^[Fe^KZj]jnQTXEhJfMSF4e6@Cdj>CLb<BlZ;30d?TM;CE5E
FV5ZKFeaMgb1Qh^;SI:EUYBBU9NGU9>IWj:UYZJWZ:VXZJb`/KBk`/C5a/O5`[jf
Zj6LU8MnNGE/HEQCBd@n>STi>3Pi?dM:CeQQI6IZKg5dOHN@W:N_/:bZZjfZXj2O
WY^EShj?Shf8QhJ2PhR?UY^LVYZNXZFXYjFTXZ>VYYb<O7=^KVmXF4Y3?cTg>cdj
>cXh>cdoB51CEEURJW=mQ8^AU9NKVibQZJZWXj:W[:f/ZjVVYJ6ITHZ2Ogn2Ph:0
PHN@UYNHWjJYZZ^YY9fDSX^7PGafKf]]JfMVI5eHF5MJHFU_LgEeM7AfN7YmPHR@
V:6UYj^`][Ng^;Vf[ZNPVY:=S8IlNGQgN7^0RHnCUIVMYk6j_[fm_;Ne]:fQTXR1
N75YG518@3Pd<S8_<2TO7R4U:2`];2hb=d5<E5]SK6maNH>=UYRDU9BBU9JIVYZM
XInLVYVEUijRXZ>V[;Bj_[jj][:]YYjGShAlO7ilNG=/JFUXIV9QHEeKG5iUKW5a
Kf]XIVEWKGAiNgn5RXjAUiVIVijSYjZ/ZjVXYZ>QWYVDTY2AUY^NX:2OW9JCTIFO
YZBNWZ6PWinLV969Pgn1PWYbKf]XI5mKEe1<BDQ7ADI6@SdoADYDH6U]KW5iPHN=
TiBDUIJHW:6UYZBRWifMViJCTYBGUI>DUYJFVY^KVYNFUiJ@RHF5QhIoN7MfLW1a
KVUSGEMEEEAFFEMEE59?D5QTKgIjNgalPHfIXjZ_/:j][Zj]ZZNVZ:VWXibARhR6
QH>1OG]nPXJ;TIJGVZ://k:a];Nl_[V]XYZAR89kKei@AST`;c8f=S4[:BTY:c<k
@TQAFF9/LgEfN7^1RHj?T96CTi:DV9JCTY2<R8N9S96GW:F/[k2d^Kbm`LC5`kji
]K2]YibCSHN2OWUeKVIRGeYIFUMGE51?D51?CU1CEUaSIFIVIfacNh:8SI2BUIZL
Wj>TXIjMWIbJVYVIUi>=RHR7QHB5RHb>RhZ<RX^BVIZETY6CVInNW9^HShN3Ng9_
K6AOG5QABD8m?T93ATY7@T98EVEdO7aoQXR=UI^NY:^][[2_ZZJUYjVYYJ6NVYRI
VYZHTHV5Q81jMgIdMWQjOXJ<TIFIWjBVY::OWIbNW9:7OG=[HUaHEeABDe5BDeMP
K7=fNGanPHJ:T9NOYJR^/[Ff];2_/:n/ZjVTVi>>RXN2N75bN7YjO7n4RHfDWjZa
/Jf^[:Z]ZZ6FRh9kLFUPD4<h<2d[:BXY9AdG5QPO:Rlb=ci6CeMKFE]TJgAmPX>4
QhfEWJ2QYJVZZjj^ZZNTYJZ_[JJOW9fMVIJFU9FIWJ6RWINARhV;SY2?RH>2P7Ub
LFm/Jfe]JFMVJg=hNWUfLW1`Kfi^L7EmPXB9Si>FW::WZJZZ[:bXYjb`/Jj[YjJW
YZ2KVYVDT8n>Si6?SHj=RXZ<QGn0PhB9S8f9P7inO7ioOWmlLVYTHf=UI5iGD4U7
BDU9Bde?DUIIEUEGFfA^MGn8SYBJXZJWZJVZ[[2/Y9^HV9NFTXn=R8B6RHR8R8B0
PhZBUYNBSXj<R8V=S8R:S8V4PH>5QhR7QH5iLg=aK6YZJfe`LgEfM7=iPHJ9Rhb;
SI:IW9fKVYfPX9nITHn@S8R4P820PH1lNgenP8:4QHV<RHR6Qh^8PH64QHV?ShQm
N7QiO7mnNWQfMG1[If5OG5A=BTQ4@D=7B4]>DeeSIVY_MGYnPhZ@TXf9QhR>TY:D
VIfRYjVXYZFTXj2KUiBBTY2;PWE/JVYYJFa]KFi_MX6;TYBBT8f7PgmlO7]hLfm_
L6eVI6MZKW=fMgEdN828SHb:RXjEUYNJWZ2PX:6QXJ:TYZRXYIfCS8F0OgagLW1`
Kg1bLW^5S9>GV9FDWZ^b]KNbZjRZZJ>OWYN@S8ImLfMMFUQCD55BDDi>DUMKFeEB
E5QFDE9EEeaTJfmdNG]jNganPhVBUiZJVIVHV9ZMX:BWZJf_/;2/ZJZ][Zj/ZZFO
VYB@Shf8Ph:2QHV;RX^AV9ZKWIjMVIBBTHj8PX63Ph5nO7QbKg1aLWAcL75eNGan
Ogn1Q8B5QhF5QX5jN7UjNg]jMg1VGUYLGV=WJFMVI6=YLGImPhF;UYZARhb>TiVL
ViB:PWn3Q7eeKfQUGeA:A492@413@dE9CU9DEEMMH61QJ75gOXB7QhJ7QhJ6RHb?
T8j=SI>IWInQX9jLW9jNWIfMW9jPX9fJVijNViJHViZGV9^OX9bGU9NKW9fLWIjO
Wj2OViNFU96>Rhf>S8V6QH9oO7QcKg1fNgn0Oh20OginPXF8T9NJVibKVIZKVIF@
SHj=QWehMW=bLG1`LW9cN7j5QhF5RHf<R8R8QhN9QhJ5OgalOX21PGihLg5^IemG
DDe:B4U:BDQ:D5ELHVIYKWR1RY6EU9>CTiJGThf8R8V8QhV:SI:EU96ASX^=U9RI
UiFEVIRBRXJ3PhF7R8R9S8nCUIFCT8^5PhB4P7ekN7AcL6i]Kg=eLfeVI6M]Mh27
R8J5QXN6QhZ<S8Z;Si2>S8b>T92@T96ATIBGV9NCShb8P7I^K6iaLg9`LG=eNG]k
OX66S8^=T92=RXZ;QhB3OGAcM7EhM71/JFQUHV9PGeeEBT4k>Sm4A451ATa@DUAG
FEYOJG1bMGUoPhF6QhR8RHZ;SYBGVYjOWj>VYZBTZ:^ZYZ2MWIbIV9F@SiBFV9^M
WJ2SXYnOWYbMXZNYZ:JSXJ6SYjNPV9BAShj:RHN5Ph:3PWekOX62PX5nOX23Q8B3
PH22QXN5Q8:0P7mnOh60P8:4QH>2PX62PhB5QhR;TYRJViZJW:6VZZf]ZZJSWY^I
UY>BTi6>RhJ4QHF3OWI_JfUZJVa[J6QYJFYXHUaKG5mPGeaLGVAYJfmbM7EdL6i^
Kg1dNWmoO7QfMWQiNGI_JVY/L7EjOH24QXAnO868S8n@Shf9QH>2P7aiNGanOh63
QXN6QhR6Ph1mO7enP8:1PX:2PGikNWb2RXj>SHb:RHN5PWmmO7YjOWn1PhB6QhJ6
RI6GUYBCT8Z6QXJ4PGehMgUiNWYgLFi^L75cMWZ0PX1nO7enOX23QHJ7QhJ4PhB6
R8Z>TiJGU8j=S8J1NWA`JfUWIFASH61NFeI@Ce5EGFEZKgEhN7V0QhV;SHf>S8^;
S8b=Shn?S8J1P8B9SI2CU9BCTXn<RhjDVifOXJ6RXZ6RY:NVXI^ET8b6R8b8PWmo
OWalPHV?TiBFVIjV[[:c/ZfUWINDT8b<SY2?SXf>Si6@TY>CTi>CUiRBShj>RhF3
Q85nOGanPGmoPhJ6QHF6Q8:0Oh1oNgQgMgMfMGAhNWYnPh9nNWQiO866R8Z:RHJ2
P8:7RXV7Q89nNWA`KVYVI6AUIVETHemKF5QGEE=CF5iVKg9cM7IjOX:6QhV?U9NH
Ui>?S8^:RXV8Q860P8>:SY2?RXEmOH:7RXf@SHAmNg]mOG]iMgUjMgAbLWEeLfm[
J6Q[JfYWJ6aaM7MkNW]lO7f0P7moP864Qhb@RX60OgilNGQiNW]lPHB7Rhj@SHV5
Og]iNgj0QHR3OgejNWmoNgUjOX65Rhf=SH^7PgmkNh67QXB1Oh:5R8EnMW1_M7Ie
MGAeLF]]LgEdL6a]K6a`LG9bLgMhM6m]MX66QHF8S92GX:JX[[2[YjR/[:NRYZf^
ZZVZZ:6QYJVYYJ2NWYfJUI6=SY2>R8>2PXR:RXZ9SXnATi2<QhB6SHf:RHAmOhB6
QX5kNG^0PXB1OGYhNG]kOhB=U9NAQXbASHn?R8B1NGIiNg]kNGMgMWMkNgUjO7Mc
LG5aLG9fNgajOX1mQ8V9RhjGWIjQXZ:VYZ6ITXUkLfm_MGaoOG]fL6QQG5iTL7]m
NgA^KG5eL6QSGU]NJ71aLG5aLFaTHfQZJ6UYK6iaMWQjOGajOX>8S92ATiJGV9ZI
U8^0NWIaJ61OH6=/MGIeN7IeO8B;Si>EVZJc_lK4_[bj]ZfVY:N[ZZBPWY^FT8b>
SXAjN7n4OgYlNGMhM6YPFUUGE5UTJ6MWIfISHfU/Jfe`L6]YKW5bLgEfLFibOhZ=
T8f=TIBKXZ>QXYjFSHV6Ng5fOWeoOgUeLWAeLW9aKW=jOH20NWIjOWeiN7AjPgmh
NX64PWn4RXAkL6Y/K6]/KVi[IfY^LgUjNWn8SXn<QhN7OWUnRI5oNhb0MWYiMgUo
PWejQ8nCVJ2XZj^_];W0a/S8b<[9`;Ne/:^YYZ6OVi:;Ogn9R7mjNH28S9:GUI6<
RXZ5Q8J4RHj?TY>ATHf7Q7n3SI>FVIVJWiV@Shb?U9>BVJ:WX9VGTHZ8SHb6PgQb
MgQbKfm]JfIKD4]>EEQNIfU[LWYhN7YgMgMcKVUYKG9dLFaZIfEPFe]GEe]KFEQR
LW^1PX5nNWf0P7]iOG]kNWQeLGAgM7MkNg]kPHR;S8b<SXnATHn?Shj<SY2;S8jC
UXZ7TY>>UInOViZGRgibK6]XIfIRGeiOH5U@FVUZJW5iPH>7T9>CUY:AUYROZ:JJ
S8N:Q7f0S9B7Phn@PhB?T8b1N79_LgAUHFIXLg1PFUMPIfEbN7QiLFQ[Lg9ZK7Il
PhZ7OGYeM7IgPXJ8RhJ2QXZ5NFmRHVi_K6mkP7M`Ie]GEUYNEDeDHV]]LW=fPH:C
^=35YYV:Oh28RH=nN79cMWn4O7n4Q7eeKfaoTifb_;R^Yk2[WZ:j^ZVdb;:UanO@
UIO8iMW<e^g`aZZ`_nWom;f/b=jkNUmZQJO1dM:oWI2GYI=cS=;KY7:0UgI8:2YJ
QGe:4`09>UYKCS`U3P/H;SPY6QheBU0n;CU7AdUDF5EMNWmdFU=WLg=oQWIkPh5d
L8:GT8ZIYZ2;SY^LVJBc]:^UWiZZ^jbAVkRk][6AP9VYW9>OY:R^/:>JVjFOWJ>P
[:BMUWeoUY1nQi6>SjF^W9NQ/ZjLVJFYSVaSIV=OHEU4=TEBE5EPJW5hQXV;W9nD
QgiiJEYTKE]7A4Q9DDU8Ef9dPWmhOWidKFQ`Hdi>?c=1CTM7BUI_KfYXJF5_Pg]V
Gg^4MW9gLF1>?2XY<c/oA4aJGFAcLFicS9JDW:6PW:J^Z:R[V92HXK;0`lc<^K2j
`lO2_;BUVY2?V9n[/ZRKVZ^l^;:ocMoWi>S_l>_Pd=3:^KNg]L;6aN;ah]WEd<G7
`kRk`l[2^L78^[Zk][k0Z9RZ^k6GRX^<PgIYJgAlLVe[GeiMEUEFEVATG5eICe5I
F4a2>cPd;R<L8b@N61D?0P00000000000000000000000000000000L=30lN;S]8
CE1JE4e@D4U;Ef=/JfI]MVQAG79gMFIQM8F=TIZIS8F8SI:BSIRUYZJRVIJQ[[o6
_;2TZkBg_Kk5bLBk^<C7a/[Hh=;:dn?]m_kil>GOgn_aiMK>dmGUknkWiOChk>[Y
g=cMdm[SfmWE_l3JmOgdj=oCbLO2_[>MWJVga;^TUYJRZI^HX:ZRVinPWiJ8OGV4
W:>HTI6GVYVCShn?TI>;Ogb7T8f4Q7QLEF5/Kfm]L6mUKhF0HUMRLG5IATaQJf9F
D4Dk>SXf?DQ1<c90BU14;BT`>S`kCU18Ce]FCE5PHe]KFeU=?S<gBEIFDUYGA3/l
@4A;CcPX92P`;SQ7D4Pi>Ce9CT8c>SDT7Q`W=3P`7aPX@TQ8BEUSJGQjLWJ9Ti6?
RhVAUHR9VjJW[:FHRGanOgUhNg^2R8=lP8R7OXREXJZX]<K:eN__el?0_JnV[KS5
b]CQfLg6f?CigLO@e]_Lfmk;]kFg_LO2]J6<QhJ6PXAhIVEMFfb5V9V8PYZb]JVP
W:6[[JZVZk2c]KBVU8f@T8f4LVM@=cDj>cD/9b0Y<b`L5Q/>0PTL=e5GDUY]O7a^
IVmhOFiTKGV1O7=_KVY[MFi^NG9RGFeeKVmbKFU^PhZ5RXjEWij=LVAYLWMUD5ii
PWaeMH^HUj^i^LG?c<o?b=;Mg]G@fn3Bblg1Z::YZJ:HTiFIVifWZJ>SZJb[^LO7
f_;cmooooooZfLc7aKg6ak6QRgegLg5[K7>3QWaoRIRRVibIVj^c^<37bMGNakJ]
WYN<KeUJGF=YLGMgMGJ0RhR3SifJUYRDUZ2MW9bERWYWFeeTJETn:A8:5AXH6R4Z
=e5YJgjHVHb9S8j=RX5`KViIB4Y?CD@f<3UBFe4m:B4^@dY=CEUdPhF6TJJb^;F_
ZYZAUiAoI5=EC2dE208000001P00000@62`oC59DGeeMIfIMEU9:Ce91@F1kM5mC
DEUNGVIcPYBS]/;3d>;Re/o:_l;A`ZZXUgYgMF9OJf9>D5UVMGj0Q9FNYJ^VY[2l
`<2gX9RMX9^BTi>AU:2XVYbYWiFDVjVXXj2SZ[:aZK>j][Nk_[[3enOWh>SUdKf`
[:VQUIVPUh1[KW1M@C@h=Si>B4ILJFEZN7b3PWEbLF]UGf9gUIIjIUaHGF=SHfU/
NXZ3Q96GV8IgOX9cJViTEUeUIfISGEE9>C0^;bLZAUM=?DUOKWamOGQ`KFM^P8R7
Q8B3OW5aQ8^5OWf2Ogn3Pi>UWY>CUZ:/Y9^Q]/gLgmcQm_oooooooogko?obe;b/
YJ2CU9^=PG]]IFIgQGf9VYRKY9f<ShM]H61XFT5;HV1ADVYaK7=iR9RM]M;Hfm;2
b]K;^ZfRViFBTHMiKfYZJ65JG6I[KgQiLg1`L7=dNWUWGfQ]KVi/MGn5RHJ<V9jT
ZK2i]jJHTiBDTY6CVI=nM7EjOWaoR8Z8RXjJ//2^ViF<PW1LFeQ9<ahI7Q<65aXI
;Ce4ADUIKHFCTX^9Q7]cK6QPEDe5?dI>FfibPY^QXif;SibV];6YXiF?WJJIPWMb
KVMUKVmdR9VQX9ZHV9ZMW9NDRWf5V9R5Og]dO8nKViNJWZZd]K:XXiN;S8Z2P8R?
RG]gN7AiOH2?W:F[]L:n^KZicoOoooooongC`:F6IEaRGEa/Kf5HEeiYJUQ7Be]S
IF1TIE50=CE3A3H`?4EBJXBR^<6o^kg1b<Vl];F/Wi^ESWmeNWU/HF1QFU1@E4a9
C4e6>S8R3P8000001aLN71hZ@4Dh>DYJGVA_OXQnIf1MDDM9BTA0A55JIG9dMFiT
JW1`LfiVJFETJV]lVkS:c<>f^;BLR8=eG5QDFF]bL6UUGTe7BTUJJVQ_MG5[IfIN
EeeOFU99B5AcV[Fk^K2UXjN_/jNDQGn>WYfFV:JUV9NNZko=a;:Y]l[;`[6PWi9e
J7N5Qi2JXZBZ][Vk_[Fb_;fcY:>Z/[bo]jj^][:PXK6k_;6^_;nh]:VMWZ6UZk2`
[Zjgdo7ooooooo?LajjFSGi[I6QbKVU[L7]mLF5PJ6e^IEiQHV9OCCTeATmAFUUK
LIB^[Zb_[ZJRW8aiKfiWI6M^OXb@UYVJV9FCShZ=Ti1nI5I;@cdk?3HlBEIUNHZ?
ThaoNh1kKVa/K7EoOG^7U9bPUX1fOhB5P7EfM6YVHUICFf1ZMGYdKF]SJWnA[m;W
gl>YUhYmJ4lk;20H8DejPh=oMWYoNgA/HU=9AD52A3lg>dUGHViiQYJW];F]YiN1
K5]GG69ZM7]dM8ZKWZ>WYJFRT7MTHFY[GTHe;R`fBU]VKWAgOXB6RHYnJfEYJFI]
Q9JS]<C9a<[Kgm?4_KZc[:jc]k^f[JVZ/ko2`L33b<>h[iN4T9bmm_oon]S5^KRX
RFeBCEebTJR[[:FQY9^9KVR0PgMcLg]kLFAGIWj>W9N>RY>`_[>VVX]gHUeWM7j2
QX>=X:F`_[RRU8j4NGQhMGInPG]gL6=WM7McJ5mQJFi]JV9FCe5OJfm]I6Z1S8^3
O7ioOgemNG9iPh^FVZ6[[Zf/XY^OXIZ?QgaWGVIbRkOPkMJ^PVQUHDlX1`0001M2
FfEYHEYA=AHA8CHh:b`lBDU:Fg21R8F8R7ejQ8b3L69EAS8L7CI=FVI]IV5XKgEb
JEm?@chn@455Ce]TKG1/LX2<SXF0QhZ:RhEnOGinQ8b?U::ZYZ>UY:>GOViaMWA[
IFekPXfMX9F;T9JFWjf`ZJ^_ZjFX[J^oh_ooooooglo8`K2>LV5JH6f:[;Zh[9R8
NV5=DFQgLEm<Ae9JIGR@Y:RUY:2PYJjbYXenOh20QI:S]LC6`/6n]:BCSHYmKVQ]
M7A]JFeZIVU]LWZ2QGmjL69LGF1PGfMiQXfLYZJQWI^JU8QoOX1nMgMmNWR2TYNE
UYJARhbCTHEcJfe`LVm^KGJ@XK?Gm^g0VH5`KfQ37aXV>EEeTZ2PV8UlLF99>daM
HV5GF6M/KWb?W:BQSWn0PGmkKEDj=498CUQOK86=R7ebHeEABSlg;BPcCf9XM8:7
Pg]dKg1_JFUTGEiSJ721UZJXZJf/ZZBKUH]hIfA`OXF=W::LUYRT[j^YZjJLVinU
[Zj`^l2j^L_NgM7MkNGZoooogJV6PY^NNFI[KG1eQ9JAQWYXGU@o;2TfAeMSIfel
PXJFXJJ/Yi^ATIb[/JVNWjV]XYVMZ[S5bKbRSXAoNW=YJ6i^LWQhM6eXG5ACEEe^
NGIeNWf2S9JR[:^UXZFYZ:f`ZIfHUi6>SXf;S9:IViNEU8]oN71TFEEDHgf?VIFB
WjFBQX^5OX6D^mkhm;nCR8jPT65;Ad]@EG6:SY>3L6eKA2/N:SM5ACU0C5ERLhZL
UXIoOWf2RXR3NgB4V9VGVZBd_;BUTX9eJfMTGU]PI6U]J61SJV=JF4i0>ce2BUAG
E5]YM7j2PhRBW9bDT8j<QhB1PhR<S8b:Q825Q7ejMWMgMGMmO7=eQiRFQGn;VYjJ
ThnMZKKOooooeKR]_<j]Nfi[HFMcP8nDT7IQJVYIASiAHUm==B`^<CU5FG:4RhR9
RXV7P6mFB5QdOHFEY[c:`j^DRHAoMVUQJ6mYH65ZKFIPI6meKEeJHfY`JfI/L7F0
RY2IXJFWYj>QXjBUZZRSXj>MVJNc/J^QV9VOViJET8EkN7Z1QXF2Q8N6R81bIf]l
O8c8m_?1THF7UheG@di=FVIhV:2QTgYdI4hk;3I?H5@oBE]NGfM^LWYoNGIlPhN9
Q6]DH7j;S8fBYl;<_jNITXUlKVigM6]ZKG5jPXN;SX^7QH1oOgU^IFMcNWf5T9jY
[:JNVXn7PWE]K7N1Q8N:TIZGS8B1N6eYHf9WIVYbN7f0T:6MVIfHTXamOHF4U;7H
nMn]S7bCXhQG=d1;EV5[PHN1KEQD@c0L4R@oEU=2>ca8FVIcRIF@R8N@VIVHSGei
QiZOUY2FZ;NdX8mnIEM@AT=8D5AHGEaEBCloAU5HFeUGIG1/IF=]NXZGY;S8dmSI
f/jlZj2QY[2g_/_EfmG=bkn[VXj9SX^1P7]mRi:HWYjS[jVGT7aWKXJO]McoooK@
a/kF_HYeMgInQYFW[knjZ:2@OF=?BdiGEDPn@DiFFUe]QIBHUY>BT8Z4N6eaP8jF
VJ:ec]c>/ZJMTHEgKV]dOgaeMX27Qh9oOgI^IEUGG5UBEeiRK7EiQINW[[Bj/ZNU
YJBUZ:jd][Rn`/S>b[nl^JjWXJ6RTH=nO7IePhUjKWUjJfa/IUe?Dg6HZY^0MGZ9
T6@^9bdjBTiIJ7^<OFU[ITle;3DoA3TR6R4/?E1KIVieNgaiJeI5=BP^@eQTHV5e
Uj^UTH=fIeY=BE=RKgImO7IeMGIlP7YfMVm`OXF1NWE`LG]oNgf2SINESX^8OGIe
NHJFXJV`/:f`/JVJTI>DU9:CWJF]/[>f][2YYjJJUiB9SiRPY[CQnnK5YZ6dZgYI
HVM[OG]hRIBDRH1mMfI?BEQ]NGA]K6a`Oi:U^lC0_;bdZ::HPf]MH6egNWb9YKfi
XiF?Of]KEeYLH5aDEeiQFeaVK6YYKFQUKgMeM79[KGZ2RI2DV9J@S8nGVIF?R8ZG
WYZHVYB:R8R5O71bNGYiM7IdL7MkPXb:QXjJW9bJT9JR[K_5h_SJ]:Jdb;1eE5QQ
JV=GI7N:RW=bMfU58Ad[=C4U:3@i>ci5EEmSJgMnO7McM6aIC51NIFEWMiFSUXB2
R8IiIemNHF9NGEeOGeUJIFmaMWagKFMXKW9bLWV2QXjM/;fk[j:JUiNFTHnDW9nT
[Jn[YZ>UWY>=QgikOWimPH5oPHZ5NGj2Ngj6OWAfP9Zfbn?SbJ^Y`/B`Rf]]L7Z7
PI2QXin>Rhn3MFY/LW9UF5]PHf]cNHF=SYNRX9R<OWMfLgAnQHJ5Rij_[j:ASHZ3
OgAaOHnQZJf/YYnHW:>RVYJCRhV<R8B3OGEjPhbHY:bb^;ZfZIR;Qh>5TYbMVj:X
ZjjXVXaoNGb2Q81gM7UoP8>:S8V=TiJFU8]mOhVEWZO0b;6Z_LReNdiEGV5_I5me
RIZLVInIShJ1NFYQGEmTIf]]JVYZJg9oOFaODd]7@3TjA4a;CU]]N7IXGUeFBd0h
?TmKEU5FFEYLGEY@ADA:CDi>BdY<DEQUMH20Ngj1PG]gNgehLVmaM7QjNGYgMWMa
MX5oOXRBUiF<P7QgOX26Ui^KWinPXYbASI68PIBfakNIWKFfUfYMI6QbJ5]TL8:<
QhV5NFeXJfmfOX:3PhR@V::XZk>oa/:j[jJOTH60RI>KWjFa^;^dYibDRW]/JFmg
P8V=Si>JXjFOThnLYJ:NWZ2LUiVS[K6[XZ:TZ[6c[jBKVYjQY:BQXJ6PVY>ASHAm
Oh>4PgmnPH>4OWIaMWQkQY2LVYFIWJfb[kBm`JZ?TjRZRV5=E61^MFQWKWIbH5]A
C51BFfI[IEM=B4mGFE]OIGB3S9BJUH^0JeEBH6]`MWb8UIVETIBCS89`GEQLG5QF
D4Y:C51AD59BCTI4B4Y;B4E7CUQOJ7R2QX1jNWU`IV=XLWUhMWMgN7MeNGYdMGb1
Q8bATYNJRW=_OX1eOXb:SiFFVZF_Zk?=bYj6X;2OP5E8FVj2RXR9TjBWU85kMFaT
H5]LH5]GHFicKFQYJW5nQ8J:R8F8QWekP7mmPHRCX:RUVIVPY9f?R8^BTh]oMgfA
Wj6W]L71^:jTX9N6N7=jPHNAVjR_];VeY92;SXn<S8^<TIFQ/kV]WiZKVHn<SXfC
TXnCVJ2OVYRIUi>GVibEPHVVZkOIh/ZX[<BkW6e8Bee[IEAPNiJTSWaeHUM7?4IA
EeAFIWQkKFIXJ71lPhN7QX=lLfEPIfAPGfAeOW]_IfmkQ8J7SXn;QH60OGYmOGYl
Q8Z>V::RXYN3MFUUJ6QWJ6miO7j2QhMoLfIQGe]IFf5RH6=SIFaZIVIVJ6e^KW5c
MWV3RGmiOH9hJW9hLWbM_/g0YYNK^]2XITA6EF=SFVJ5XKB^WY=nK65DDUA=?C8g
CW27SI2DVi^@SY2;R8=gJV=VKG9nSY^NVI1oMGV3PgI_KG1cKFYTHFEVH5mXM7f8
UJ6//jfUX9jNY:NUY:Va]KB`];o0^JjYZj^UXIjSZ:FOW9fSXYVCU9J@R8R3OXJ<
RiJ[`/6/Zj2B[loFe/fcX:K9i]JVMg1gNGYREVUjRGmXJFi^JV5RH4lo=SM2EV=[
MGUmQXfDTHInO7QZHfQXJVa`OHV=SXEoO7EYG5IHHFmfM6mYJFMPFeICFemOG5iX
L71/JfeaM7^6RhbAShV:RiBRYZRXYJBW[:NNWj:NW9jLVYVFT8MkMWAbNH1mOh5f
MGikMWMjTJjbXWeXRJj_SeDcAeiWIdi7Gfi^J5iNJVQKFEaMEchd@U5KHf1OJWAl
QXf@ShEjLVa]JfMYJ7:5UjN/Z:2MWiV?R85nNg1[KWEoRHf>TI2<S8V5QhN2MfUU
KgYlOXRBUI>=R8V>SHF1Q8V7Qhb<R8N<RXJ;TIVKWZ>SZ:NRW9ZUXiNLX:Vj]jVT
YJjld^?N`k?1a[VLJUEYNWYYDUYeSiV8Oh1kKEeIFf1KC4M=FFIXJGF4Uj6NV8n7
PGM/JFe/Jg1ePH^BUi27QHF5O6mXIF=TIVU/KVm]L7V3SI6BTHUmMWEdLVaWKGN2
R8bEVY^HShR5Ph25R8F4PgmoPX:3PGmkOHN7PGmoOGYlPH^GY[6ja<G4_[W0b=kc
lMNlb^7I]7YUJ6]hIe1JMYVNQWEbNg9GDEAAASD[:3<m>Se:EfEeQHf:Q7eaGda5
AT0n?TYFH75iO8>8Pg9[JfQYJfQRF55CEeaSJWB0Rhb:Rhb;R8J3OWUhP8ZFYkBd
[:ba[JJPVIJAS8^5O7UgL6meOH:;U9NLUhZ4Ph60OG5cPX:3Qh2D/;2nbL>fWk7B
a:1mJFU_MfmNHgNCWi2=T96@OG9_JFEOF5ENGeMHGg:9UjJZXIZERWU`O85kNg^0
QXfIViVMUhb6Q8>6QWY`KVYWHV5RIVeeQYRNWYZCRX=lLFabN86<T9BJWYjOXZ2G
SXZ7QXR9QX=jKFUZKWJ2S8b<TYbOVIJIV9>HWjBWYJNZ/KVgaLjgYk7:cZR<P7Z3
OfiJADaXOWa`MGn1MF]`MgYiJfE]LgMkPhZ>UYVLWIVMX9R=Qh=cIFMWHfAUIfQ[
KV]]KV]ZJVENH5]@BD0g=SQ0C5UUIfM`NhJ8Q7ehMG9/IVQbNH:=Ti^LVj6VYZ2H
T8ElMW=dMgUmPhbCVj>PXJ:NVY:<Ri2FTX^CZK:hclbe[;6j[I1hK6eYHeE4BUEX
LeYCHV]bKF9SJfYMCdM6@CTi?D5ELH>@UIZUX8YlMgE]If]^KFU/L7AoRHV1Ngj1
PWmfM75/K6MSI6AZM867RH^?VZ6TWY:?TiFCTIJLVifNVIJGUYRNVHn8OgYjNgYi
Oh5oR9>JXJFUYJZ`ZjFQYZZOWinDW[[Ck??Nbm7A`JR4JfEYKf=BG7F7THMeMH22
OgQ_Kg5aLfm[Kg1]LW9eQXjCXJNWYib@Si:>SHn<RHB3Ph65RXR4PXF;U9NBS85g
KFEPGF9YLG^4S9:DUi:<R8>2QX^>S8^;RXV=SXZ3PXB8SHn?RX=nMFaVGUE>D5YP
HfQWJWJ1RY2GW9RDT8Z7Ogf8U9fCRIBIXjJFQgMaKfEKEE]WJfAHF5mOGEYIGf5O
GUeHEUAACe1FH6E[N8B<RgmfMGQhM6eYI5iJFemTIfEPHVaeNW^1Rhj:Q7]bK6aY
HV9WL7f;VZ2RXIZHVIRFU8n7PXF=UYVETiBHW9fRXY^FTX^6QH:1QhZ<T96BTiJK
X:FY[jn^[:FTX:Ff^;bhYj^d/k2PU8f3P7QZI6QbN7=/LGYmO7YjOGigLW1_LFeT
GeaMJG=eOXF7R8B2QX5eJfIUI5eLGfQ_KVa[K75fMgQkOgihLg9cLVm/K6eaMWb4
SiRKW9jU[:f[Y9jMWIfQY:NYZZVUX:2TYZ:HTHn=RHB4RHR5QH>5RXjEW::MUIZK
TXnCWInMYZRRU9:SYIV6MVmQGEY=CDiEHUaEE5MSHU]LHFMRGE]IEe1>EUeSK71c
MW^3Ph60PX5lNgf0OgYkNgIdM7IlPXV<RHAjLg1UG5UOH5eNI6U[K75jQi6BT8nB
V9^ITH^=S8V;SiBKWYRDUibJU8n<RXF1Oh5oNWf3RHf?TiVNW9RFUijSWiZJVYZL
Z;Fh]Jf/[jRISHV4OX5oLFihRY:>RXV<SHAlOGagLg9aKVQTHV9VKGb8T9JMVi:=
S8j<PGIfOGihLWN1Rh^0NGb1PX:3PhF1OWaiMW9cNH:7QXJ3P8>8R7ilPXF6RHZ=
ShZ5Q8F8Rhj=RXfEVijLV9BAT8b<SiFIWjBWYYjLXJJUX9nW[jj`/k:e/ZfYXYfL
WZ2LTH=lOH1nLVQWJFe/K75bKVURFEEFEE5:A4Q=D55AEe]JFUM=@S`mA4mFEU=A
E5]OGUM?BTY:BTU<EUiPHFM[JVU]LGAiOXB8SI2@U9VHTi2@UIZIT8fNYY^HV9JD
T8V0Ngf1QXN3P81oNgEdMGAhO7amP7inPX:2OganPXZ@UIFGVYbLUYBFX:JY[[:b
[jj][JJFRhV>UIJHVINDSX^:QgicKgAkO7]lP8:1OgM`LGEgMGEjPXZ9Ph:1P7mh
LG1aL71gOh5jLFQXKGIkO7j3QhJ4PX>2OgeoQ8F9T9VQX9J>RXN3PH:5Rhf:RHj@
Rh5fLgEiOGj1R8nCU92>TYBARhR:RhbATi>BTY2@UY^JUYFEVZ:XZj^/YjFWZJ^X
XibIWjFVXIZETXb6Ph>2OGEbMG]oPhN:RX9gL75eKV5IEEEMGeYEDe5=BT]?EEE=
B4Y;CTa8ATaHGUeNHV=PH6=WJFINGFE_M7=`Kg5dL6e`MW^1R9:IVI::RH^:Qh:3
QXR=UIVIUY2>U9VCRhZ=TYZLViZESXEmNg^1RHnCUYJDT8f<RhV6PGj5T9NKUHN3
QHR8PWenQ8Z;Si2<QH:1OgilO8:=V9jQXIZETi>AT96?RHF5RHfBSX1gM71/Jfaa
MGIfMGQlPXb@TXn<S8jCU96>SHMoNgMfMWIeMW^1QXJ7RhjBU9>>QWmiN7aoPHB7
RHb=SY2@RhV>TXn6PH65SI>ASiFNYJV][JZYZZVXZj^XZ:V_]KJ]YIjES8N5PhF7
R8b@T8^4NW5_L6m/JFY]M7^1P7]bJFEWJFESJ7=kNg5VIFITHEmLFEYKGfIZIeY?
CeQPHfEVIfU_LG5`IeaDDeaYKf]^NX>4PG]eMGb5QXB1PH5nO7YiNGYfMWf3Q8>4
QXV<RX=jLg=lQ8R9RHV>U9NJWYnNWZ6SY::QY:N]]kfj[J:PYj^TUhZ1P81oOX::
TinVYIfHTHR1OWeiMG9dNh>5Ph5oNgA_LGIjNGMkPXR9Q7eiN7YkNWMdMWb4Ri:H
VIJCTY2=RXJ2Oh64QhV9QhB2PX:2Og]gN7j3PWegLF]XJ6]bM7IjOhF7QhEoM6QS
JG=fLFYYKgEhNgajN7IeMgj6SI6DVYfMWYnLVY^LVYJDTI6GUhj2N7AfO7iiMgUl
OWemO7Q_IVE]MWb2QH=mN7AdMgE^IF5PHV9NFU]PI6=PG5]PI6IYKWAhNgeoQ8J6
QXZ>S8EoOGejMgV1S9JIVInVYYfBTYRLUX^3PX^EVYZHUi67OX24Q8>4QHJ7Q7ih
N7]oPh9mN7b2QhZ;RXJ0OhF;SHZ6PhB9T9>?RXN8SiJJVIJ?R8REYZbVWiVGUYBB
T96@TYNJV96<SI6DU8j7PGn0PX5iLg=^IEiPHUiMH6IZK6YXJF]_KV][KG1aLWAh
O7aiMW9^JFAUJ6Q[L7EiOX63PXF:SiFET8b;Rh^;Rh^;S8R1OGYiN7MgNH28Rh^<
SY2DUiVLW9^IW:6VZZna/[2YX9N>RhnDUI6>RXR:TYbLT89kOH>6R8bBUIBCTi:;
QHB7RHR4OWb0QXEoLVMTIVMVIfUWIFEYLG=YGE]SL7YmN6iXJFicMgIdLgAfNWn1
P7j1QXJ1NG=cMgf5S96EVIfPYJNRVIBCUIJFTi>DTi:?RX9jLg=iOgmiLgEjOh:1
OGalO7anOWUeMWYnPH62PhJ8RXZ8QhV<Shj;RHZ;QgmiNWeoOgn0O7EaLWMkNgUf
Lg1aMWQdKfe_LG1^K6a`N7f2Q85nOhF?VYnLVIZIUXn6OWioNgIgOH>5QhZ=RhEo
NG9[JFaaMWQjNgYeLG1cMWYnPXB5QXZ<RH=kMG=fN7]oP822R8jAU9BCU9ZNWIZG
UiRGTXb9RHjFWJ:WZjf`];Rf[jBJU96@TIBIWj6NWInSXYfHUYJET8MmNh22Ng1Y
IVAQHfMVGUIBDU=BDEAMI6IWJ6UYIEiKGfAXJVUYKG1/J6MZLWUkNW]jN7QlQ8N3
OWj3RHf@TY>CTiFFU8n;RHJ5QXN7PGajO7ahM7AgNh28TYJFUYRJViVGV9VGT8Z8
RHjFWJBYZJV//;Fj^:jSWI^LX:>RX9nPXj>LThb;SHb7Ph>4PWmiLF]XJ6U/LWZ1
QhV7P7MaL71^K75jO7QeMgYjMW1ZHeiMGUeLGfI[JF=QI6Y_LFmZIf]aM79]JFU[
LGQmP8>5QXR:RHN8Qh5kNWUiNgeoOgeiMWEdLgMlP7mkMG5`LWEcLFm^K6]]L71`
KVe[Jg5iPHJ2NgUnPGn2RY:GVYZKX::LTh^5QhjCT8f<S8b;RHJ1NWEdLW1aM7Ek
Q8Z7PGakOX1nOX20NgEeO8:2NW1/KFe[KGAlP860Ogn1Ph:3Q89kM7=dMgYnQ8Z>
SHb?Ti25NgIiOH>8RXV7R8jGW9bGTHb;T9BDT8j?T9>GW:6UYjZ/[:^YYJ6OWIZI
V9^RYjRWYjNUYJFUY:>SYZ^][:f`[jNNUiNHUI6;QhN8QX5oPhJ9QhB2P7n0PXF4
P7akOWelO821Og]gLfmYHEeMGUeIDTa:C4i>CDmDFf1RHV=TI69SI6ESH65UJVe^
L79bKfYWIVU^LGAjQY>JWZ2RXj>PVY:=RhZ9RXfCU9:@SHZ8RX^<S8b:S8nBUIVI
UYJKXJFUXIfJVY^LWifGTiFKWYbDR7]eMgf2P7YdMGQnQX^:RHR7PW]eLW=eMGIh
NWaoPH>1OWUdLG1bN7]gLVmcN7enOWelNG=^L7IkOGaiM79bLW5^JVISHV1OH6E/
LGIjNgM_J6M/L71`LWEgNG]mOgmnOWn3QhR7QHF7RHf?SHImMWAjPXZ=SX^9RHb?
T96@SH^;S8nCV9jRYZJSWinQXj6HSHV<TiVOYZZ][JVVXj6OW9ZGThn;SI6FUY>?
RXR7QHF4P7]dKFIRHV5MFEUJFeaMGUmOGEUGFEmTJFe^KVmaMW]mOGalOX64QXR8
R8J4Ph5nNWYnPhJ8RHV9R8Z@TXn9QHN:RHF0O7]nPhN9RXZ:RHR7QHB6S9BJVibO
XZFYZjZQU8R4QXV9RHV7QHB6QhAoNW^5T9>?RhbCVIRFTXn;R8N9RXR7QH9mMg=a
Kfi_LGAfMG=eNGaiKfIRHF=RGUUBCU1HGEeIE5=EF5UIEeEDF65YKg=hO7n1Q8N9
RXZ;SiFIVIF@S8V6Q8>2PH:6SIFJVi^MVi:8P7inOWn2QhZ:QhJ6R8R4OWf0Q8F4
PX>4QXZ>TYBGWJF`]k^l_;fm^:jTX:B/[jbWY:BTY:JYZJFOW9^IUi6=RHEmN7Ih
O7ahM75^IUmMHFQ[JFQ[KVeXI6AWIf9LG69YKW5eMG1[JVa_LW9`KFa[JVQVJ6Y[
KG5fNWf0PhF8R8=lMgIhO7inOGanPXV@TXb2O7j6RXV6Q8B4QXJ4Og]fLg=dLg5/
JFiiPXJ5Q8J;SHb6OWMfNhB<TY:AUIbQXj6LV9JGV9ZPY:BPVYJ@RH>1Q8V;RhZ7
QHB3PX5nNgMdLgAbKFUYK6aWHV1RIVQ[LGMkNgYkOh>4PGinP8:2OgYeLgAgOXB6
Ph1nOWimNGEdMWQiNG]oPhB5QhZ<SY2BUYZOXJ6NW9REU9JGUiNEU9:ATI>CTHb7
QHJ;U9bRYjZ[Zj^[ZjZVXj:UYZJUXYfIV9JCShMoO7n8TiZKUY6<QWmhMGEeM75_
Kg5_KFe^KFYTGe]IEU=DG6AVIVEXKW1`Kfi^KVi^Kg9bLG5dN7QgLg9dN7]lOGem
NgYlOh:4QXR;RhZ7QHF7RX^:R8N7QhJ6Ph5mMg9bN7j5R8N7RXb<RHF1P8F<TI6>
SI:JWYnOWifKVINETi2>TIFHVINCTY>GV9F@RXF2OWYgMWQnPXF6Q81iM7=eMgQd
LW=eN7YlNgM^IF1OHF=TIVadO7n0OGYjNgamNG=^Kg=eMG9cMgYhM6m]KFmaM7Mh
MWEeNGemMgAeNh:8RhZ7QHJ5Q7ifKVUXJ6ITI6AUJW9iOX63QHN9RhZ9RH^?U9VK
WYnOWj2QXZBTX9nSZJf][Jf^[jbWXYjMW9VFUYNIVIRIVYVGU9:>R85kMG9dNGio
O7McLW9aKVe]JfYZJFUXJF]_LW=`K6UWIV=OGf9UJ6YYJ6U_NGilMFiYI61OH6=U
If]`N7n4R8^>Shj=SHj@TI2ATI:ATI6@SHZ7QXR9R8R8QhJ7R8R7RHbCUiNGVIbM
W9ZIVINARXF5RXnBTiFGVIbOX9^DTI:CU9FEU92<RHV7PgmoOgikMg=`L7=eMG5^
KVi`LgAeMGIhO862P7ekO823PWaeLFm^K6][KWAlP81nNWEcMW^2QHB5R8Z:S8f=
SHf?SXQoNGIgNWinNgQhNh:7R8Z<S8f=RhR4PH64R8fDVIRDTHn?Si2?Si6CTi2<
Rh^>Shn=RXR6Ph62Ph:0OG]kNganQ8bDUY6:QX>2PGimOWmnNgUiNGEcMg]oPh>1
Ogj0PGmoP860O7YiMgMgMgQfMGIeM75bMGMdL6i_Kfm_L71bM7EdM7MiNgalN7=_
KW5eN7MaJfETJ6]/Jfa]JfY[KW9hOh5oP8>3PhR@UYJDUIVKWYnNWj2SYJ>QX:2O
WY^JVibNWYbJUi>@SiFMXZ6MUHn;S92DU8n5OGYmQXnEVIRFU9BEUIBDUi^OWijO
WIZFTXj:RHZ:RHN7QhF2OgelNWUgMGIhNW]jMVeUHEmQJG5cL6i]Kg1bLW9_JF=S
IFIWJ6UXIFAPGfAUI69TIg1gOhR<SXf:PWUdLgMlP865R8N5PX:6Rh^;R8R:S8f<
SXj=RHJ6Rhn@SH^<SHb:QGiiNGYgLFe^L75aLWMjO7n2QXJ1NWIiOH:7S8j<RXZA
UYRLViNCU9BBTi>EUYFGUINHV9^KWIjLVINHWIbHThf;QX1oOgYeLFi^Kg1bLW5/
JVMWJF]aMGMfLVi/K6][K6i^KVmeOXN=TY:?RXR:S8f=RhJ4PGejNWioP81lNg]n
Qi6?RHj5NXb;QY2=Q8=lMX23P7]eMWAfO7n1PhB1P8F6QX^>Shn?TI2;QhJ0O7IZ
JVi`MgIjNVmYJVmgNGanPHF4Q8J4QHR:ShZ4QH^DUIFFSXN4P7j1Q8F0OH28RX1j
N7AcM7A`JfMRIFYZHUaMHfa`L75`JVIWJg9eLfm`Nh64R8b:QHF=VZBXZjn^ZZ6G
V9VKW9J?RHZBVYjMWI^ETI2<SYB@Qh1jNGYnPhZ?S8N5R8bBUiVKVYJJWj6VWHj3
L69PKGIcLhFPZjVTVIFESX]lLW1bNGj0PX=mMg^7Vi^FUI>ESX^5N7aoM7R0RY:F
W9jJV8j;Si6>RXF1OG1WH5aCASTg?CU5De9EFe]IF5]UIEmRIFU/K6IRI6eWG6MZ
JgB6RhVATHj;UInJUi6OYYfGW:JLUYVMUhN0Ph^GWIZLUHn@Ri28OWUhLfM[NH>0
P8MlLW9dNWalOX>3OGZ6OFY_MF]GAT]KJ71aLW]nQHnCTI>DVjNXY9jOYJfd/Zbc
c=_SjMoNhM[DcLRn]K6GQX^>UXf1P7V0O6idMFY/I5MKETmDCd95BCln@TIDEU1D
JG=aNHB4P8:9SiF9TYNFX9nHUI>?U:6SXJ^/[Jb^X:6SUXQlP8J2NgMlO7IgMW5X
GemTIeUFH6I`J5QII69KGVaZJVU^MWQmPX5kNX9lOgi^J6icM75bMWAhQINHShb5
TJ6KVj>QVHF4UiVQ_LG6iMcBg=cQel6_ZheYHUAAC4E?BdE@E5A?ACHgAT4l?4AC
<bdm;BDW7B4h>D=VM7R1Vk:_XZB/XjFa/:^NUIVESIfUWk70`l6h_]WWd[FYZIjA
VYf2PX60Ogf9LVAbMGj:Og=dO7IeSIV1PiF;XZZR/kBTWZRRWYJASi6EP79iLVQQ
GF5PEemkP7B5QgJ>SX:;QY>HTJV[[L>e[;k2a[j/];JAPY=jGEUIDeYPD4U7@dQ>
BT<j;BLj@bLU;b<K6Q`[?C8i?d=EIFQRJgA]QjZ/Y[B]YKRg^<;1/ZZ/XY^@S9FL
X92BUhn:LXFARHV3PX5fIVEZNGA^OW1eShND/jR@W:RX[jFL[;B_[KNj/:^QThfG
YZJMXI68S8=fKVIZH4AJP6UjQGjPYH1gOhNQWi2>XZN]bm3@cM7AcnOS_[[C`[RY
XX]ZLXA`A6Z6BE^?ODdi?CXe<blfHe`d8B8D3S@X7CI7Hg9KI9b7NhjHVWakRHf=
N5mZIF=[K8N?QHMjQYVVRg20V961LVYoW99YJWUKE59MOGMVHEQOMh^8NXFGTX>R
akZaWZ2PQj6LOIBGMW5hSi:1KeUSQgeAFG]nL7V>R4`mGVIMGX6RN8NXZInIX:2c
^[35d[g4em[C/jK3ZXNHZYn1Mh1fOX=XI6QOCeehN7=SJ7ajBSaGEEAKASe<B3]A
QFmPRX1NT;Vb];Jh`l74^9N=S9>Y_[F3K9NSW79CNiF7NYbYQHfTS7j;Ph23EVV9
LWJLXX^[aH5n[jJP[9Z1U9V;MWbVY9>NS6ilUk2bQXVKRYZCKUmfRXAkNFmlQ6en
SXVRVfEi[WMTU:JGQ7jCX9>IZjZFPW9fY;JMRHRNZhYZPIR=QG]kASU^IC/[?3U2
;Q]3F5]ZGDQIHVMlNg=iL7=XIEm1FGM?=dIRKGF<PG^DYkBjQ6ZASI>@IUaZNhbJ
MGFGLf:F]YUmTJBO[[n^Qh://H>0YZ:FRWnBRXbFKVb;VYenHGZ<PWJ:YGQ=GfMf
Q7i^M7^2RhI^HGZ1QYFHUWimRWm_Q:V:JWU/K8b>K69ZKif?I7^1JhJKMViaMhbI
V9N=QW]hS9MkJ8F7RjFXS7n9RWUEHHM_G7V9RW]XJGfIUXVY^8]kP9f/SHbCN5m/
DT1IHU9RO6=NOIZ;P92CQh^SW9BTThbAJVVAXJBDRZ>UXZ^?Nhf>Rj:TTYJMT8n^
UfZ;SgJ?TH^ISINTWIUhHGnGPGJ3RH=`O[6OMXf8MXN1R:^ZUYNLSZ6XL51IRZMn
KG>7ViMeH6mJHH]jIEiLMH26SWaSEFA]MWYUHGB1QH=bJgj6Nfi;CW=SGgUdOX=X
MYJGQH>S/8aeSY64KUi^S:VFNUi[UHecJVATKUY7I7ieHVn6MgYjP8ejOHYdGfR@
UViYP8N>UFmSMgQ_GeeNHgYoIfV@SHB=Si25Mg63Y9MdPZZFMh:8V922VK3EeJJJ
WkVcS9FN/Jj8LGYnUJbDM6A^PgmnTX^QXGN2X9nIKdMDOj>6G6Z2OGa[JInHMJ:c
XIJ?V9^[a:b9N7V2UjFS_LFOOZC7UF]iR9nNZJn_aK^SXJ:RX8I]IG9gNWU`GEb<
V7Y]L8:5IUETMVI;EVmZLXAP?5elHdU>EEADIH62L5ILMGQbOVd`<G2:ID5CIeiS
N9FAM623];6MU8=fQYfQUGm]JW=nP7abGUefO7YeH4iaXIn7UImmMX5lQ8elHEUm
WY1kG4Z1ZY^gc9]_PjRVXZjjW7^:W8n1RYFJW8n>QWYdTL?;^k6WXkFgZXa^J8F4
Lh>STf9^PgnDVgEFKj>hVgioS:2KO7^6O961IGnLSG=cQ7MKKhV7LGB4MgElPYF4
Nhj7GDaiQGQbMGMQPZ6@R9NNRfifTI65MWn<OfM`N7Z7SGEDGh><P7=mWZYnGh:G
NgEhIU1XU7UFGVYTKFUSHEMFIHBEQ7^8QY6`]J20IGIfL6]VP8EbL6UkU7]jWJf_
XjW:_9b]_jVNPUe/RJ2=IVmcR;:l/IfM]jjR]JJEPVn>W8JBTfi[MXJ1Ee]eMGR3
TYZ7MGn6P7E`NFEQOhR0I5UWMWf6RhMdLiJ^ZKFkVYj]WINGRFe8DF]fRGQRJ7Z=
MgN>LgZUW8EoN7ijQ95QAFUM@VAnOG=FEWB3OW9[MWMTHVUjMV5HF5]IJV54EVmY
G69ePXB9RgamS9RMVIN3Qi=jHVYaFUYKIg]aKgQhP7n7Zk2QYIbJXJ>XUGinNF9G
EFAYGg:3OWeoTZ:OVIB1MHVLUgaaL6miLV]nLVn2KG^da[VSRJ2k[J^VX:N<RYEl
O8J2MVb1T7ilUjR/WHVL]jf@QIB>PG]cJGV8IE]bNX6:S89nOFmoZ[VDOGYmUZZM
NGMeJh9lLhAnRYN3QZFXXiAoUJbQWjJi_:6VVHJ=Nh2FRH:4NWB5Y[N<G7ZOXZ2I
QWmjQJ>ENhV4GdQ7IGIYJVebLWRUZXYjM7ibHFQWCTaYLUi@EfecMVaUMWegOiNO
T7YeRZZZVXA/MXAeJFaVHEI9I8B7NV9PNh27WYN?T8jNWgAgSH6=S7I[KXVGUYf9
PijHT9jPVX]lNH:9R8n6Ke9AKGMjNgMlRYFEVIVLWYRd`9f<SHFBX8YTHWb6P6a[
NG9bR8b8QHnERhbN[:FDSYZPSGUkLUYcRgI`JVm]IXfLThQjQXf7OWAgL75_J6A=
DV5WN8^?PGj6U8mmN7^1KUEUNH>6KV1[NWihIf5RFW^=PgaaSJ2MXZ:@PhAgNh^7
O6eXMXAkGeMUK6YgR8b6R9^SXYV2M6efQFeIDdAAEUmmQ7UeMW=oW/32]KJZ/KFW
/[JOSH1mPh:7RhJ?W8jAU9>/YiVVX8^ZblVaW9^COX>UW8]nNh:1QY>QXIF>V9BG
WH]^KH>=LU9<CEeJBTmDIH^KTX5lR9BQW8YmJE5RMW9mHe5^Lg20P7j9MFQ[MhYk
Ni6AOWn8QHIfMXIlOh=hPHnIUH5dKgV4Tib8LWB5R7AFFg1WETi@HfmPC5J1SGQa
MG^<VifGRi20I7N;Th1CEgQdJfecLg>GXY>;RjB`WI6HU8B6SXJ9OF]aK71oRh]Z
DFIcO9BJRgj1S9BCS865U8YiNG]nPG9ZOY6BS8JFZj2?T9VQZHibM8:=MGBEU7Y^
KWnAW:2XW8Z?TJ6PS7mcMhR7PWQiTYNAQXNCUIjIPWn>UIZO[;ZaZI]iPIJ:NVUO
J7j<P8RHRGYeNhfMTHB<VZRZVhZ<T8elLhJ2Nhb3Mhb8Phn:SXAlS9:1N8N@NFY/
GeYCE6E[GfQgM7IhOg]`LGEnLf9/MGAgQgeSIVY[JeY<EgEjMGIeNX21T8n9VHmf
L7V2O75ZGU=TJ51KHUeVJGF;THf>TYNGXi=OGH2=PgZ4U8InXJ>7QHjEUIJQ];ZZ
/;:UTIFNU9:7O8:8NgR2RX^8Q7n8Vj6QWX^7Th9/NY9lEe]TJGQ^CTiPIg1nKfmn
W;:CR9BJUh^?SG5NC5E/K6ehN6MaQHVDThnDTIfPW8]oSXV3QXR8OgIdM82:RWab
P92CSh]lMY2GQ7QhPGadKV]cKV1ZOHB6SGmkVjnXX9^BQGenPXn0FT]QOGmfLF=Q
LhNAU8B2VJNd[Zj[Qh>CT8YiIF9/OWUZKVaWJg1aR8f7UIj[]JbBMg::PGI_Ifa/
LWaiMhF3OINYYk2YY:FY[JN[ZJ:JQGEhRGmoSibHRHnFVJ:]]K2BQXN9S85gM7Mf
Mgf0L6A/MY2@LG>9Si^HPh6;P6iVKgQhMFERLWUhMFQYLFUXMH:;SYRJTHn2K6]k
R8UbHUeZRY=oMGb3PGYiPY:JTH^PX7m]L7>4PfUEIWmgKgV7QhIkLgbDZJ>3N8ZD
SWa`MfmNI7QlG4aCF7B;NWMkP9FZ[IZ=T96<Ti^7Kf1PJF9JF6ekLVeXGfZ1RhB6
V;2WOFI^UZRIN6YZIf9WQIZENgF8Rhn@U9VMUHenNHjBQXR2Ohn7Ph:5QXF3OXJI
XIZIV8j9QgijOgEXJG^9OG1QHgV1PGU^N92HXjf/]ZEoNWmgNXF9OgmnMHB>RYFB
NXJQ/k6__LJjXXb<THImPh9bJ6QcMVm`LfUXNXF2Phb:QhR<RhQoLVQZIUiLG5eU
LW=`MXV>Oh:=SYFOVH1]JWN8SXAaGTLgBEYRMGATIgR;Thn9S8n?QG5[MWamIf9X
H69PI6mSF5m/Lh2:V920PX25QGiiLW1iM75^M7YfO7j1U8moT[6j][Jo]IB<SHjB
RhZDSXN?UibCUInSXIfSWi^TZJRNQGEkOF]OJVMNGUQYNVaUMX6EWYZFSYZVW8j<
T8alNWISHVihO8>:QhJ8QH^GVY:P^:jRPWV@VZ:KRh^5KfMmPHJ>PHF:T92@V9NW
VgmfO81gHEi^Ng=PGfmgNGZ5QhRBTi6<RHV4OWIkMG5[IVeXHf]fLg5_M7^5TjNY
UiZXYiN8MVQ_N7QaIFAdN7V2OFM`OHnJTIJNXj^RTXb;QHJ0O7ilL6QeOWidKgZ;
UIFRZjFOWjRQV9J<Ng9eMGZ1MW5mR9VVWHf<VIV8QY^PSWimR8n=SX]hKG=bM7]h
LGb<VYb;RHjJUi6=QW]_LWIeLFiUJG5bM7AYIg1bN8:1QY:FS7]gMgenOGb3RX]o
KXNEQGMjMX2DUI>ATi><Pg]`K6=OIVQRGf5bQHB3R8VCTXfFW9RCRhZ:R89hK6mf
LWEYH61JGf1_PHZ6OgMhU:RFP7]oN79YH6aVCDEMIV5LJGAePGj3RH24TXj0O7^5
T9FGQW]gL6aaLFecOXJ=X:2CRiNNVYRBQh1mRHb5QWM/M8V>RHF8RXZCRXVBTHf2
OX^5LW6:TH1[GfQ[IWF:T8VBWYZMZkjnX8f8PX64T8E/KH>?T8b?TH^:V:Z_/;W0
^ZnWWY2>RWQbLWIoM6]fPXEjNHR8P8:6R8nGUhn?T8E[FUiRDdA4AeMRJGYjMX28
RWmnQhN4Ph=lNHN=PWYbJ5UBFFM`MhVAT8n=TZB]YIF3O862NW1UJg1PGVEXH5m/
J6^2ShN9Ti>8Oh62MgJ1T8f2PgmhJFYfOWAdRZ6VYjjb/[2[WY29Ogj9U9nCPHF8
QX^8RhjEXZFPVYnVUX1oPgIXGF9bIfM^JFecPhf3Q96ASIRRWi>5PX9cL7mjHEYW
LFiVK7IkMgV>X:JTXIjMXYf<T9^@Q85mOH=kNHZ@QH:9T9>DUI6EVZBPTH^1L6a/
K6mbL6ATKWZ0OgE_PXijHfalPgmhNgIdO81fM6iOG6ASJH:7OWj8SYJRZJ::NGMg
NGaiLW=hNX1mNFmPH6QiRhn4PIROUY:?ShQkN7MaMh:0O7A^OH9eKVn4Vj:OVinY
ZifGV8UgNhJ7OgAePH5jR8]nQYRITHnBSXF2QI6DUIR<NgQeMgEXJGMlOhRCVY2B
WI:=PFicOWenLeaNIfMVJW1SF5m^NhJGWHR3Uj2CRI6?PWZ2S8j<Ph>0MWf4MVM/
QiFGWiZBTiN<N75[LG=/MWYgOWeiP8N=R823QY>RWIFCTINFShYkK6]`M6eXLWj7
PW=bQ96@SHnDSXF<TI20Mg9QFUaQIUmGFf=QFVUoQh5lPHbIViB<TYJERhJ8OG=h
N6mYK71cQY6FY:RMXJBGShf5P827QWQgO79_NhV;Ph:5T9jKUiZ>OH6JVhIkNH6>
QgA]Jf]]N8B2OhfOZJZUYjZGNWN0RHQkNX29T8b0MW9kQHF>W9bT];Fh]JZTSWMe
OH9lMg]jMWQoPGE[LH69SI6FUHj9R8N1L65NHfYVGEaNJh24NW=`MX:0LWElO7]o
Ogj:Rg]]I69ZJUiKJGZ3Ri^UXJ:WYinEUYB?RHF5OW5ZMGM]GUQNI6YaKFYeOGam
Ph63RhE`J7J4S8]nMWIfNGUhM7F@[K2/[;2d[InCSiB;QYBGRhfCV9^FUH]nPhjD
VI>DV9ZMT7ifNh1kL6mhOG5PH6YhPhJ7RHN:SiRFPh2@TGe]K6]]MWM^Gem`Lfe_
Mh69RHV:Si:?SGmjQXb7O7QoPGYkPX5fJfYlTZN]Xj2TYj^KNf]]KfILH6U^Kf]Y
KW=[HFA/KVUYKFeYL8:9P71/MhF:RGiUGF=YMGY`Lgn6RY>HTXjATI2?TI67Oh61
PH:3R89cMHZFUIVKWjV/Z9R9R9>KUXR7ShZ0N71UG61ZKG5gN7^0Q8>3Ri26NFYS
K7IeLW5bL7N2OWb0QXf:P7b1Q8F>VYR?RX9kNWQSEFEiPGegOhZCUi2HY9^?RX61
Ph20NWI_JVe[JVm`JfihQYJJWj:JSH63T8f0OhB9RhjAS8=lNWaaI6Z3W:ja[Zj_
ZjRVWYNARh^EWiREXZ^VSh69RHF:RXnEThj4MfiUIVQTIVIWIfU]LGN0P7j5R8fG
WijBSY:DSX9eJEmBD5]NE5ANHVI_O8VHZZVOX:>MU9:GUXn6MgAaIVYeMgA]LH:>
Uj:XZ:Va^;6XWYF?SI>ES8N1O7b4SY6<RXV;T8jAUY26PX>=SH>1PX20OgQcNHbM
WifOWjNa_lc7/ZBIU9jOUhMcKFQTI65NDd50CU][MGj;SiBOXIfIW:6OXj:LV9RC
R7ecGdY6C555=c]0>3@a<CPe:B`jAUAMHEeLJ7YnLV]XJ6AXL79fM6e`N7anNG9b
M7=bOY>IV:6VXZ>Z];Zn_;:YZ:NOW9^FSgmcKVQXIVAXJFI^Nh21RIRRYJna/;Nj
`<W>bKjh/jZJRWM[LG]gJVEYIf5OE4M8EE]OJgf@UY2?X;2aZj2DS8bFXInITWaY
JgAcHUQRHf5TIVafOXJ8RY:JVibRY9fCQh>?Rg=VIEeADeeOHVabMGn?XkFf[JRZ
[jfTVHV0NViQG5I6>30`=3<j?Se9F5iSL8>@S8J9S9RV/Kg5`k^k`/[GgLnf[JjU
UIFNSWaeMGA[FTU7Cdi9Ce58@dMADe]XKgJ1SiRAR7YaMh61LF9LH6MVJ6Y[KVec
OhbIWYjW_MCQg<g7`;[1b/NiZZ6IR7igIUUDFfITIG5jNgAkSiF9QiBV[Z^Z[:VU
YJ6FRXZBTI:LX9J9QH>2QhZ2M79fP7mgPiRW[ZfY[KG5eM7:akfh]:n]Y9B2MFMJ
CCXZ8QlU:Bdg;ADB8S@j<2`a>TACJ71YHEmSIFALC4E>HG=mRIVNViN@SXV7RhjI
[[bj[:>/]K:bXXMnPXR9QXV8Ng5cMfmSHV=OHFenP6m_Oh^;R862PX>=T8j9QXf>
S96CQWIhP8jGVYbDU:>^/k:kd]gIg>3Mh]oA`[joZi5dGEMFDSlW5PX95AhS<Cm6
BDYCGF]kOgn;W:V/YZFTWj:TY9jETiFESGabLW9eMgMjOhREUiRNXjbb/[Nh]kfn
`<6cYIV;O6UIDT/o<RTO71dO9BP`AUECEVInTINDQG^2RI6JWIN@THn:Qh=mOHJD
Y:ne^L76am3Li^[Re]kZlo_/eL[=bk6@NVIEBT@f6`800000004?628^<cDlBUAG
JGn8T92@Wk;3cL:d[jn/ZJFRViJASHjAUIZNX:FZZJ6PYJJXYI^=QHB3NFMJC3/h
>cTf<S0h@4YIJGV5TJ>Z[KVm^[Zi_Kbe[Z6=NW=/I5iHEUUTL7=fO8NFVYbX`=S/
oooahN3/k=Fm[Z:LSWUXF48b70L000000000000?8RL`@f1_LG^@XK2l_kRZXJVd
]J^LUHf2O7eoOWagNhjNZkJk^l7;eM?4^kJc/ZjWW8QdHeaFBd0h<2HX=Cm4@3m5
E6YhOGn6TifTZ:NTXj2RY:>QWZ6WZ:NVWIF@SI^UZ:fTWInP/<[JfLc9dmgTglfn
]K:XUGiUE4Xn>C8N1`002A4L;T9@E5ATPIJESY6IXJFPU8Z3NgMgKF9SIfUXJW>1
TJ>[[;>l`/?0a<S5a/>cWhn8OVmMCdY4>c<^;C8`9b8N82di@4aEH6Q]Mh27U9ZT
ZJN^/k2a/k2/ZJJQXZ>MVIbJUi>CVifFUIncb=_/l^cVj>_[g<>]XYb?P6iE?2/Q
60d000001A0M>5=MF5a^R9ZMY[S9c/g3^[B[XjBUW8f7RXn;QX9mNg]mPXVFVYF>
SI>GVYJ<QH1gLg1/J6AOEDLo?chl>Ci4B51EEUi/OXbGX:R`^[o3aK^YVi:?Q7an
PH5iLg9`MgYgOXNCXZ6OXJ>]^L;9`;:YY[G2]9R0M7A^GD`n<BXZ<2hW8adH5ADP
;cQ1BE=VNH:0N7b7TjNh^[:a_]CMfL^h/k6//;Fj_;Rf];W5bL;0a<S8_kRdZIZ9
NVQA?BTJ40d;0P000P/A6BTmC5iiSYf[]L7=emcHc/[;c/bo/Z^VW8n;RHN8RhjE
WIjETY69OWb4SiRSZZZRXJnj^Z>BU9NCQWeiLF9CC4Xo9Q@C7B8H72m3BTE@J7f7
SIfa^lG=d<c3_l:j[JROUHf9RXZ;PWMhOH:3PG]fMgUkNWI[HEeIE4]1=bXX<CY2
CUMPJVmbOY:IT8bBWJRXWIZOWI64PGmiN7n7RHJ0PI2Q[;6d]kNh`<K:dM7?cL?4
cmWUj^KLc]7KgM2bTX>1LeDc5@H00000000000044ba4Ef=`R9nb^KRob<G0aLFl
[YjFVIR9OhB=T9FLXJN[YYnJTXf<R8F6RHEhJf9KCdYAE4i:ADA=Ff5NFeE?DEiZ
JVY^LWIgNXFAVZ>`_<;6b<_CfMK@bLFn/Z>DR7e`GeIGFUYIGFI/KgV9UjJZYYnJ
ZK2LNf9JED`j9b0N61DL92T^>TaJIVmhQHf9Q8ZGWYN?TIRLVYBFUX^7TYfOWIfN
X:BWZkJl_;Zj_[jdZZJTX9fKUIBLWi:6PhB5N6EIE4]0?Cdk=blX:c8lBUe_OhfH
ZK_:dmKIgn?Of]SEakVaXI:=R8N;SYBJWJ>]];Nj^k:da<kDdL>dZjFJPfQCBe17
=BHJ5aDI8R@K3P`E71dU>eIXIfAeRY::O82AW:2SZjn/Z:Z]YYF3NWUjMVaQFUYH
E5AGH6ITGf1]OX^BTHn=QX1lMVaREDPn=C@i>STi>dE?EV1dRIJQ[;c<dM7>d]_K
dl_4_[R`ZJ6JV9BATXn:QhRAV9^MWj:Y/;[:f^KUfmCIh]_:^k:b[9^9OgMYG5UL
ET<]81lO72@e@D50A4iJH6=[NXN=TIFEUijZ/kFc[:FRYZ^^/[:c/jnXXJ6PVI><
Qh=iK6Q[J5eBBClg=3Hn@Slj>cdn@DUEGf1NH6UiRiNLYK:l_[k2`l2fZj>LU8Un
MFeRE4];BTM8BTmHGV1VM7eoRYnldm[Mj?;dhlVg[jNGQGAQDD@o?cXZ6adV;C<m
CfEcM7F1SiF@RXfHWj2NV92:R8fCV9J>Rh^@UI^MVifMViVMY:V][Jf`[JFOWInM
V9JHV9:7PhB3Ng9YHV1QG5ICE5QIG6E^LWElQHV9S9BJWYnQYjBITYJKUi:DVYfH
TiJPYjV/ZjVYYJB]^lFn/Znh_kFPT8V7Nf]PETe2>Si4?C0Z:RPO7BXnCeADFF5U
HUiMHFQ^LG9bL7AmPG]cL75gOXF>VIZDTiFGUXj4PXV?Shb4OGYjNGIcL6UOFE]R
If]`MGIdNXVIX9nPYZjb/k6`Zj6ITHR6R8=kMFmVH5eLGV1OHVM]MH6=Ti:EWZFW
ZK?3c]KSk?7akno[f<>i^;Z/UX9YE4E0@c`V5QLJ6Q/X@5=GEU]]OXV>UIfPXjR[
Z9n@Q8B;S85fMG9]J6j0SHj=SI2EV9^T[[Fe/ZjWXYnKU8^2NgE`KFY/MGQdKFMU
H5YAASln?d53ATU<Ce=IGV9VJg5mRiJOYJJQWYfMVXn6QhjDU96AUiJBVZbl`L76
`[Vl`/6dWi2@S7U/IfMSFEMMHF5TJg5`KWfBXZFMVIF8N71`LfmUGEI;?cXk@TY>
DeUQJGN:VZ>UYZRZZJJWZZ^[[K:c/JnZZjbTWZ>UWHj0N7A[G4Ti;bX/;Rd]<CQ4
EfYnTJ:ca<gAemcIclBm]JVISHJ0Lf=KFUUKHfabLGAmR9:MZKK5d=WJd<oHg]O0
[J^^Y9B=QWi/G5M?@BlV8aL:2adY:2<S;CDb<3M3C59JIgJ0Q8fMZJ^VYJJSX:6Z
/:bSVYFGWj:TYJ>TZ[2a[JVUWi:3NgUcJVQXJ6=IE5ELHfYaLgAjPhbFVIF>SY:G
W9jQYjNMUI6ATiBEV9R?Q7mnO7UfLg5/JW1hOhN=VZbncMKGfMkOeLBf];R]UhUm
Kea;@3<M20<930<26cY9BTiQMWmlOi6MW9fRXifARY:MW9FDVIVIXkG4bL6g]KRg
/ZfYX9>9PgacIe]FD48g=CLi>d19DUMGEUQKFUUFEEMKGV=YKg5aLWAiOGn5SIFK
WYnMVYB?Si2<QhJ8S96HViVEU9^/_L_DgNckooooooooilVd[Ij3Kee9<ad@3P/3
00470`<F=U5MFf1`OH21R96CUIfRXYbHWZV_[:RXZjbYZk:d[9nHVI^ITi:DTi2=
SiBEShZ;RhR6PW]eLW1]IUeCCTm@C4M0>ca3CUaRHVAZKgEkPXZDWJ6TYZJPW9jR
YJJX[kBh_/S=blS5`l2n^kVf/k>d[J6IUi9oI517@3@/:b/Y8R0T:2TZ:R`Z92Pl
CeI@DEmXHf1YO8fEVj:Z[:fb]KNdZj2JU8^7Ri2=Pgb0S9bY/[Rob<oCem_IdL>c
X8emLFEJC3`a;Rla=Ca5BDY>Ef5XLh23PHF:SI2ATiRNXZ>SXYnOXZBSXJ6UZZf]
];^k^[fo_;Ja[[6h_;fo^[Fk`;BQThf>QgIUFe=5<bh]8a440000008L;Bl^>4eO
I6QkSiRGV9^ITHZ<TY>@T9NMWinT[:jYXijKUXn>T96@SXf<QWikNGIdLfiWJFm^
JVILD4Dm=S<d<c8g@4YEHFQ^MG^3SYVU/;Jj`/_?dMCDd<S0^[>ZXifKViVFU9>G
WZ6RZK:f_lc?cmKKd[j[XIZ>NFIJEE9<BU1ABT4nA4I1A5EUIU]DE5IABTmOK6]W
KGEiP8jP[Jn//[g5al_De]38`Kjk]jjXYZBOW9VHUY>>Qh1hKF=OG5E?B4<o>S4V
7alS9RhkAe=OIVakS9NQ[K:b/KBf]:^PUH^2MfYTHf1KFUiNFeaSK7MoRINPYJfh
`lO7c=7Cb[JWYZ^UT7mgKEa<ADI0<2<R:B`[=4IGG5YPKGEeMh2?VinQZK2^YjR_
/ZnYZJj`ZZ>X/:ZKTi:BTHb9SYFEShf@Sh^:SHf7Ng=fN7AaLW1ZIVAQH61PGeeK
GVQbMWEfNWimNG^2R8bAUifTZJRWZJRUXInOWijLVifPW9RJYK6i`<kOiN7NiNWO
bkVYWHmfGTdh9182000000032P/K>eYaOHRHXJ>PY:ncZj2HSWi^J6QXGU18BeAH
FEmYKfm^LGMmPH1nO7YkOG]iNgj1P7ajOHF<TYZPWiR@S8MkL6e[HUM@D5EED5=O
JW9nSYb]`<kDemWKgn7JcKj`X8j3O7AZIF=QHVI_NhNCWZo9g]oJf=gRe;b]YZ6A
Ng1UFDi4ADPl;RXc?ci1FWEnN6ibOG]bKgV5QhB4QhV5PXZHV8j;TYbPXZF[/K>b
/kJg/:^^/[:a/:jYYJ2JT8EhKVYXIF=ME4Y1>cTf<Bd]<cDf?d]@DeYWM7j7RXbE
WZ6RYJFSXZ2LVIJAT8n8OWEZHEiQHfEWIEiJH6f1U9bOYkJn]jja^[ffZIb>PWIZ
If5>>c<b;RP`@eEMFeYPIfihQIFPXj6MViVHW9nMUHUoOh>3P867SiZX/kZl_/?8
b<S8aKjbXiVES7UWFU17A4M:CUAHFeeRIV]cMgIgMgEdM7EdM7UnOh>;UIjTZJb]
[k:a[ZVRXZ>NThZ7Q8:3QHR=T8nBW[76fnc_lOWmm>;Abl^nXhMaGdT]60H00000
0000000C82PhD6=YKGnGWiVBShn@TiVOVhn7R92EUY^PXJ6QX9bFShN1OGemNgf3
R8N:SXf;SHj=SXf7Qhj@RhAlMW1]JFQXHeaGDU1CFV5VJF]_MWb2RY:EUiRKViZK
XZVZYZ:MVIZOYk2d]KNma<gHi^cVhN3OeKfYXj>HOVIHDdi6@Chc9AhS;C0b>3i3
@d57Ef=XKgj>Ui^PYjbYXjJWVhYoP8N6OWYoQHR<TIVPXZB/^lWBemSFe=38_kV^
XIN?Q7EUEd`n;bHP71XG4Q<G61PN:3<oCEaVKWJ1SYZOWIfQYjVZZZ^][k:d]K6Y
Z:NRVYB<PGEZJ7:2SibSY:Zja/O5a<W?b;^_YYf;Ng1MAC8V81H92Q4L81TJ:3Lm
?TYNJVa_MgYcL7R4RH5gMWj4PX6:UIbRZk:i_l;7cM;Ff]cIe<c4_[FXW9J<OWId
LFaYIEmIEeMLHF=PGEeLFEYOIFY`M7R1SYZTZJNVYJ6NXJFVYJ6KU92>S8b<RXbC
UiRKXJ^ld=_HeMOMh=>o]K6^Wh]jJEM4<BDK20000000000=5ADG:TACEe]/Q9:J
XZZ/YjBZ/JbNTI6JVY:CWjNVVhf6QHB2QhjATI:CTiVQYJNYYZ:SYJBUXYV@RH=h
JF1MFEEBCe9HFeYIFf5ZKVeaN7aoPhB2PX1lNg]gLG1aLG9gOhF8S9>LY:Za^/GA
g>G/jnGWjN;B`kVg/9n@PG5VF4i9@3H_;2hX8BD^=SPf?4QBEeYUMX>=V:6UYJF[
[ZZTWijQX9ZARXR8R8EoOX:7RhjGYK6e/Zb[[k2/XiJ8O7=YGeQ@@c8S6aXK7B<Y
;C0e?TI<E65`OHJ;U9nY[k2a/kFh^kZf/jnZYJFY[JbUViJET8N6S9>EW:V`/Jj]
]KbfZZB[]:^LTHR0LV=QGe94?T51<bXaA55<Ae5MHV1QKh28Rh^8PWamP7ecJ69Q
HVI[MGn3QHV=TYVS[K:e_LSBdL_9bLO3^k6YYInBPWM/HeY;>S0^;2HN71hQ92`j
AU5OKWZ4SYjfcmgRj>gYgmODdl^m[jFLTXZ5Q8>0NgEdMWZ2S9f]]KJf^/:lZIZG
W9N2KemAACH]<2PG41PR7aPO;d9<CU=PJFYYLhB<SXn?TIBIY;6d[ZV[/[Ng^Ko5
`;:UWibIVYnQX9jMUi2?UIjQW9B?SX^5OWM_IUYCD4e8ATI1?D56AdY@DUUXMX>C
Wj^i`Kng][Nh]jjOThUjKFMTH5]KG65VK7AkQIBS/lGIi^c/kNo^i=31_knaVGeT
DdDi=2dP3`H82PH64B@c=ce:G6MXKGjEXjN[/;Ni^Ko3_;>_];g4aL2k]K2YXIZD
SHN3OWj2Q7aaKg=bJV=OGf1NFUMDD4M0?3Tg=SPl?CdoA4iGGV9WLX2:TiVQZJb_
/kBe^Kfo_[^g];2[YZ>MUXj7QXb>TIFEU9ZX^/K9b<oMg/jo]kNcYI1iIeQ5=SH]
6`l<51TG72/mBDU>HGV4Ogj<VY^DSXj<QX:0O7I^JVidMWEhPXfDVZ:[][bo`<C:
dM;;a;jf[jNIS8J3OG=YH5YCB3hj>CTi=C<e>3/l?3i3CeeYM7n<W:fla<G6bm3B
dm3=bLJjZ9bGU8j6OgUfMGAfOXVAW:FXZ:fi`KVZWYbLSGIYG4m3<b`W7A8;41XF
5BU5GFI]OH^DVYfW^<6k[jRSVYJHUXanN7]nPhR<Si2@TIFMXZ6V[ZnYZ[2b/:b/
[:ZSVY2=SHV1O7YgLVYRFUEBCda;CU=GFUYLH6AZLWV4TIFAVZ6QXjNWYZ6FSHb>
S8J0O7QhN7V0Ri>EV:2[^/?5bLoDelnm[ZRXXi1oKUU;?C@c9Q<71Pd:00DF:34b
>DQHHVMdS9bOWYfPY:JXYjBJS8Z@Ti2<SYBFTY6BUIRMX::VZj^XYJ6NVYF@RX=k
M6mYFdi:BDDm=2d]<SDiB5]ZLWEmRifZ[kO1a/W;b/W8a[nf[ZJNVIJCT8Z4Oh21
OGMeMg]lOXF@XK6h^l7?gn7Ec]GPflRj[jFMRWU_GD8Y8B8H2`TB82HP9CU;CdeF
JWf;TYNMViJCTXn6Ogn0OGMcN7n4R8Z<T9FKXZnmb<g<a/2m_;N/WiJ4M6YSFTa6
@cXa;c8j@dQ7Ae5NHF=WK79hOX24RHb>SY2GW9REUiVIV9NDTY>BTI2?RhN3PHB7
R8nO/;o3_/7;e<nn/K2e[YN2M6QIA3Hc:AL<3ADF51XZ?dY=F6j1SY:L//;9bLBo
][6c/:JHSXj;OgMdMWYlNWYkNgf2R92KZ[Ff]K6/[k:aZjBRXIfMVXj5OWM^H5IC
DeACDE9EFE]MIG5gNgj4SibZ[ZVWY::OVIFETXf7Ph>3Ogj1QXZ=SHnEXJ^ea];E
e]GNin39]:VXWHMmLVINCD8j:QhG5QL>1PhK8A`C7353AdE=GfikPhV8Oh6:TiB<
QHJ>T8^7R8Z9RXV6QHZEW:Ja^[bdZ:BVZZRPUX^1MfeUGE=9?c4V8R@V:S4h@DM<
Dei[NXbLZ[NoaLkDfMSAbL>o]:NTYj:IShR8R7iiO7n2PXB5RIJV];bg/KO9fM;0
^;_0`;>XX9F<NfiWET]?DThl:B`j@C/d>dmIEE9ONX^CV9N@SY:LWI>5Q8R:RXR:
SY:@RhZ<TIVSZJja][o3_kbk_;VaYYfCRh9dJF1HC3hf<C0e>chn@TA4ATmJHfmj
PH21T9NEX9^@S92DTHb>THf6PGn5QX62RiBMXI^GWZZia/g<aLC=dLNdZk2aWX1X
EdPg9bDR50hF7Q/D5B0`?T95F79mP8VHZkFm`l:j/[>k_;Jb[:FQVXj<THj2NgU^
HV5YLGIoPXB2P7n5U9nPX9VEUY68PgYdJea?C51FEDi=DE9DFE]MIgJ4SIJPYJBW
Zjf_/KFi]:BCSHMkNh65Qh^AUZ2XZ:JTYKC3cMGEd=?LflR`YZR/X8mnJV=EAT=3
<AlU9bT_7Rlk:bTO<C/l@TQEH79oO7M`KX:ATXj5RIFHShV<V9fQWIB=R8j<T9jU
[k6`[:FXXj:XW8]nOWMLAT=4?c<M30dL:B/d@D50AU9VPIROZkS:fNC[koCah]?<
b;na[[:VUhb0OWaeO7n0Q8J8RYF[][Ri_<cJeLJl]kfgX9^IQWa^HEQ4<2Pc?blM
8B/c:B4^@da:CU]ZNhbDUiRFWJJ/ZYb9S9RBQ8BBW9jGUY^PXJ6MYKg4_l38dm?>
bKfd[YjJVI24Oh1cG5EDCTY6ADQ>FVM]K6I]Nh62RIBHU9NNWiJIWIjHR7amOGAd
O7abKGZ2Q8bEX:FVYk30bmKMfmWIckng/JVGPG5D?cX^9ad900033@447c8h=SaG
Kg]nPiVa][JmblZi]KV`YZRXZYn>Q824QGe_K6U/JVE[KG5bLgQlOh:7RXZ=QgUf
M71^KfMED4Hh;b``:bP/:BXa=CY:HgjCY;>eZjBWY9fHTHb9QXJ8O7=eLFe]LGUj
MX6<Si:MYZfb/[c:dmK4[J2IWI=kKVINF4e4>RPV;2l[6Q4G:CPa:c]<DE1>IH>?
T8^<TiFP[kFcY9RJXZFPVibNVj2XZ:^b];:e`/_AfmcCcLg?aKB/XiJ;NfUMETdm
=cTd=CXk@dmJGeeMK8FO/kk3b]?LjnkWiNKYh=KDc/cAcl2`Yj2KV9BBTiRDRXZL
/KVe/kW5e]c?^k>l`K:SUHUlJ5YABT8m@3hk>C<e@4I5AdiEFV=cQ8bBVYZGShjC
VIN>TY>=RXN5SY^QX9bNXjNZ/;[2`[g1aLG8b<Bo]jRIRgiaJemAAd0j<C4g>CXi
?4=9DEUOI765S8f@U9VKUi>@T9F@PGf6RH1hMG5[JFUZKgZ9SHV<Uj6WZ[:g/[2a
ZIB5Q8F6Nf=<>S0Z718800000000000;40hE9c`o@eekQ8B:SY6EVIbRYIjEU9RE
Q7MhOGefK6I]LVicNGf0P8F<SXZ<U9ZDR7imNVYIDe5<A3@V9BHW;SXo?3m2B5IU
M8J=Ri>KX:Zf/:>PXjBOV9:=RXN6QXF:SY2DUYBHXjbY[Ko?eM?EgMkD`[Jb][:O
SWedIeMDET`l;c8n?34]<Si2>T=GIfUWMi>UZZV]/kBf^/?5^[Jo`kj^YJZZXZ>X
Zk2g][S4cMCHfMG:`l[Cckj]X9N>PFeNFD`e:bdf?D15Ad]AEUYQLXFCXkS3`/[@
d]OLfm?LhmG6am3?`[>][:ZWWYJEVj>WXinR/lG7a/_GinOA^[K4bkZQSXMjIE11
=RhY828S6APS>T<i>DMRKfU/OhnKX9JATi>FV8mnNWimNG=`LgaoOhB>Uj2Z/;C2
c<gDeLg4_[R`ZjFJShEjJEeHDdD_924Q9Rd^;C0d>3e1BEMWKgF0SINNYjFNWZ:Q
VYBCU9JHT8V8QH63Rhf;TIBIWIfV]lBo/Jji^jVEQH>7NfI??C<S3PP;20<00000
00HB7RD^>4YIFV5gRYBKW9^IUY^RXIN:QHZ:Q7inQX^0NH:6Qi2HXZ^f_;Vh^kVg
/JFDR7idKf9??RlZ9b<R92@T;3@k@4YDG69WM86;S8R>VInLUYNCSHV3O7MjOGf2
Qhj<PGf1QXZCVIRGWJRldMC8b=WOc[nmb=;7/Z:=P7=NC3d]60/60000010K5Q<Q
=49;E6j<V9ZNYj^XYJZ]ZIZ=T9NJUiRQZ:FV[kW1aLO<d=OKem36^:n/XI:6NfmR
FDdm=2dX9bT/<CLoC5AGF5iYLWf7UInLV9bTZk6d^;o1`/C2`/;1`[ZaZjR[ZZBT
X9ZQ/;Rj`<kHh>CXmOSUclO=d/F]VXehGdLf9a@:2@T60@LE9SM0BUecOgf2V[6j
]:fXWiJEUY63LVmeMgA`MhB5PXB>VZ:Z]L?=dmWKfmSGeM3:`;F^ZZFMTX=eIUM>
AC/f=34/:RX]=3Lj@4YHHVYcPY:IWJ6UZJf`[:V[[:ZZ[:JQYJNSX9nOYK2f]KBg
_lC1_Kfo]j:;PhJ7Mf5?@3<Q4aHF4@/<4@T12b0^<S8g?d]CF6R1T9:@TiJEUifS
YZ6KW9nQViNNXj2JVJ6XZZfe_lcCemWGeLg5`[^`Y9R;NFQHBShc9adJ6AhY<3Q0
BU5GIgN4SIJMY:NZ/K>_ZYfAShf5NG5aLFmbNGakNGf6SIBHWZNdaM?MhN?XloW/
dlO;eM?2/9b;NF9@?b/M4``000000a0?4B8kB4]DK8VKX9jNY:^^[j^TViVNVhn8
SIJMWYjPZ;Bj^[k;eMG@b[fb/[:YUGmdKfAFB3lg<BTQ7b0T:c<k@DM>E5UPKGb8
SY:DU9JIVibJV9^PWY^JVYbNWIZEUYNDTI6BUZ2[/KFnc=OJfn7Yj=S1/[>dXHMf
JEU6=2`S5P/:4Pl82AL]>Se4DV=^LGR7TYNFTXZ3P7mhJemGF5QED4mFH6I[Lgn7
SYFJXZfe_<71_[bj]k:XW9:@RGabJF5GBSld;Rlc<RdZ;Bl];38nC5IKIWB1SIFI
X:JXZ:BOVYRFTHf9PgajOH:5QhV<SiNR[Kk<c/O5d=G4[J6OWH]bHDhm<24D1P00
00D=2`dL<S`i?eIWJFI/OXnFVIVETHjBV9^IU9RQXi^EVZ>ZZZFTYjV[[K6e][Ng
];2b^Kbg[JFSYJ>IRWe`IUa@Ad=3A4I9BdaBGFMbPI>S[;:i_/;5a/6h/jn[YIjI
UHn9PgahMgQmQi:GWJBa_lkPkO;`koWoo>SFdMKA_JfQTXAbHEI7=2T[;b@I82hg
>3<jBUIHEfR4UIVMY:Z[[K>i_;J^[[>aZZR[[JZTWYjTZ:R/]Ko6blg7`/2n^JfK
SH=jL69GCTDm<bXU92Pa>3a1AdaDFf=^OHZDW:B]/[>^ZJNWZ:ZXXj2PXZ:QWIRF
UIJEU9FFVI^OZ[S4al;5cmG=_;:b]JjIQWQZGDm5?B`K51XR8B8/>TA7BEQ^OX>8
U:>[[k6/XIF<QH1iKVMWIV1IFFA^LWElPhR@W:Rc_<71_KVk_l:n/jBDS8^8Pgea
Gdi2>SHe>3Te<S8b<S@h?d]FGF9]NXRDVj2TZ:V]/JnXXj2HTY6>S8Z8RHZ@VZ2R
Yk70b/k<c=WTfl6[Y:JNQFiOE4Pd81@3000000000A<R9bD/@E5ACe]`OX>5Ph63
Q8>2PH69Uj:TXInTYjJSXJ2MVi^IW:BWYj:KV9RIVI6:QX5iLVaVH5I;@CTb;S8g
>CXnA4Q>FFEeRIVRYjjh_L31`;Z/W967P7]cJ5mJETm<D5USKGb:U:2a`m7Ig>3/
m_3IaL33`:ZCR7ieJ5E9?BhS7A`E3Q8M8ahG72`f=SI4HGInPHJ?Ui^OWY^HUiZL
VI:@U9F@RhjEVIfPXjZg_l?3`lG7aKjdZ:6JSGe/GeQ=?c4U71HE6ahR:cE1Be9L
JWZ6Ri6IXJZ`/[2_ZZ:KV9RKWIjOX9nNWIfPXZJ/[jn^]L;>f]WAd=[QeKbf_L2g
Whj5NW1ODDTi:RDW:BDU<TEBE59OMX22R9^b_[nk]kNaZJBMThN2Q85jLVmdMWIf
N7n;UZ>^^LG9bL_:b<c<b;nd[jbSU8R4PG]`I5]ECda:B4Q8B4]?DEAKHfQZLWf6
S8nBVj6RWYRDUIJFU96=RXZ9QhN;TiRJVj:``m?JfMOOk>gJ`[Vk^JF6K5Y=@c8R
4`@00000000772HT:3Y?EeMLKhNCU8n<TYRHT8IoO8:;TI6?UI^JUY6AUINJWJ6V
[[>c/:b`][Rc[:VVX9R<PGYcJEa>A3dl?d0o?T95BE1LJg^:U9fW/kg4a/C3_[J]
XYJ?S8AhKFISHF1TJg5eOHJBXK32d=GBdmo^jM;0^lC1ZY>5NWAUETm3=c4`<2HN
9SM4AChoC5ABDEa^NgilNX69Ti^ITXZ7S8j;QhN@U8n:Ri:EV9jU[;>k`<?3b<kA
clFj]K6WUX5cJUm@?BdQ6QPH5aDJ8bdf@U1QL7UmPhbHXjVYZ:VZZZBMUiJIVYJC
TI:DU9RNWinTZZnd_<OCem;?en7I`;>g`;ZQRW]bKV9FCCd^9RLW7aXQ;SPi>dUL
If]bQ9^Z/kJf]kJh^;>[XZ2OUXUoOH21OWUeMGV3SIRW];Zg/K2g_kni[ZBNV9:8
P7YaJF1IE4m>DU9<ADA9CU9FFf1TIFQ`O8J9QH:2QhjBTi2>SHf<RHF2OWalOH23
RiNQZJnibm[MgNKclmo<bM3?^Yb4LfA@>bhN200000000000000773=0AE5WN821
P8F:T9::OWA`MGQbJFQcPHZ<SI6FVYnUZJf`/:fVXJ>VYinDSX^5Ng5^KVeYH5I=
BTe?Cdm=C4a=DU]WMX26SYBIXJZ`/kFi_;R`ZJJRW9>8OGEcLG9dLg5bMXBEYKO1
a<SCh=g9_[k2_:F@Q7YbHDm7?2lT8BHS7R@_>3dk@eMSI5mXOHZ<RHF7R8Z>T8j8
QX^<Qh66T9F?RX^<SY2CVjF/[[2e]kc4bLW0]kFe/jbSW9>8Og=WGEA<Aclh<c@h
>SXnB5MWLWb7T9FGUYVPYJFSWYZGUY>?T9:@SHjBVj6V[[>g_/KBh^SRh>O]h/:^
[kB`UGQYGeeCAdDm<2PW;2/Y<T9;CDU<GF]bMGfAX:NYZ;2h_/?0^[Ba/ZjWWING
UiB>QhJ:SY2CUYVMXJJXZ:nd]JfRViJ?PgE]IemCASdh=cPl?3/m@DQ?FFE_MgUk
PX^AUIJFUYFDShMoOGn2OWMcM7IhNh69T9FIWjBY/K_3`/7>gmo>_[g9cKbWVYB=
O6YNCcld;RXI20PA6a/D62Pc<c4mEfU`Kfe^LGInQ8F1OX60NW9bO8F5Og]nQHbF
X:Z`/kJg^;Zo`KfbYYfERWe`If1IE4i9@d54B4Q6B4mHGV=ZMH:<U9fW[[Fi^kk1
a<C1^[Fb[jZTWYJ=R8N8RHR;T9JLXJ^i`lG2aMGMc;>V[KbaUGicKfUID4Pi;28R
8QPB72dj>ce<GFEUJ7Z@Vi^ETiBDV9RARHF9Shn7PhR@UIFFV9JFVYnUZk2`/:j/
[kBf/J^YZ:FNTXV6RHMnLfa[Jf][J6EUHf5PHFQbNGYjO8:8S8f>TYNFT8EmNGUh
M71^KW1cMg^1QHbFX[:nbMCIe]WWl>?:_;fo/I5eI5Q;=bLL40T61PH31Q@T<c]3
EFQaMGb>XZZZYJBX[kFg/ZZUZ:^WX9bRZZZSWI^LVi^MX:6PW9RFU9BDSX=iNWin
NG5/J6AQGUYGE59@CDQ3ADQ:C51JJ7=kPHN?U9FEUIVQYZFOUY>ASHV4OWUbKVib
N7j4Ri>LYkK4b/_?g>KH_Zf]]kBJPgE_KF1AA3H]9R@U7adW=3dn>T9BGEmOJWf7
QWacLG=hN71VH65THUYDF69ZKW1dNhF=TYNOZ:j_[Z^_][Vf[:BOUhemKF9KE4Pi
:b<S9RLW:Bhc=ci=GVilQHnIXk2l`[ni^KVg];6f_;ZcZjJQWYbMWj:SXJ2RZ:nh
_kni^LOHe[jYYJjaWXEfKFIF@3<X8AlO81T@4b4]<c8hB5EJGVf8WZFSWj2U[:n[
Y9fLW9RARh^BThn8Qh^AUifW/[Zk^KVi^[fn^k:VWIRAQGI/IfISFe9?DE=EEeiW
KW9eNhB?V9fPXjFXZZVTWiZFTH^4P8:2OW]hMGAeM7ImQ8V=TIVT/lG=blSCj?3Q
bl76cL6VT81hL5e;>2<E3@T400033A<C5bPnCEEMKXFGXJJZ/;Jk^K>`];g1_[J`
/[Bd];>d]kVl_lK>dLc3^;:`/[:/XYV@QWARF5EFDdY1>cPj?Chl?D54ATYBGfig
O8:9TYVLX:>X/;6/YZ:TY9bCRhR7QH1mOGinOWn4S9NU[k:c`]SReKjf_LFlXXUm
N71MBCX_9alK5Q0@72hh>Sa8F61QIWJ9TI2<Rhf@Thn4Mg1`L6UQGVE]KFUWJG9j
PXR>UIbOWIZLXZNUWiVIVYN<OW=]JVQQEd]4@3hl>CTl?chm@4QDHFafOXF<TYVR
[;Bh^[Rd/kBd];:^ZjRSX:>[/kJg_<SFgn;Pg^?^m>K?a/S?bJb?NfiVDc`Z60d:
2PP200LG82<T<TUGG65`RI^RXZ6UZk>e[ZBOXJFRVHn>UIF>QXF9S8b?UYjTYZFT
XZJ/[ZZSWIbITH=eJfESH5UBD59DD4Y;DUaQHVE^NhN=TiZNXZ>RWinRYJBLThf:
Qh9lO7ioOgemP862R8fEX:Zb^kbl`loC`jnY/kjaUWmaKfQD@S<U6aDB30401@dA
3PXC8c4jAE]aOhJ;TYfW[jjYYZJ//:jXYJZ_[JVWZZne_LC<dmSKgM[FeM??aKVc
[J>CP71QEDXl<B`Z:2PZ;2hb=ca1B59OJWAmQXjBU9FEVZ6WZJJSY:NUWYREU9:?
S8b>SY2CUYZQZ;2e]KFodM[;]Jbe`;JNRX5nMV9>?BhS6A<=1PH=6R@V9c=5DEEJ
JWf:SHZ<TYRMVY67P7ilMFeXJg=gMWEiOhJ?V::[/K:`[k6e]k>YWYNCSH=dJF5J
DdTm=C4`<2`Y:Bhc=3HkAE1IH6QbNWn2QH^DVinOWijNX::RWYZHUiFCUINLXZN^
_<cGgnCUjoKoo>_Og=kJaZjLShMeFT8`91dF40X61`dD6QlZ?DeEG6Z0T9VMX:N]
/kJb[J^ZZjNPVYZOXIfIVYfMVifRZ:b][Zn^[k6a[JJPWYfGRgabKFUSFeEEEEED
DeEIH6AXKgN1SYVNXj^c^;Rd/K:d/k2YX9RCS89hM7QmOgn0PhVAV9fW]<38bl_>
f^WWdkff_l:bVXMjLEi7=BHH3PT700000`X=30lI9Rhe@EIZMWb2S9VV[k6]Zjje
^;:WXZNZZ:BRXjFX[K>kaLgAdLg;c<o=aKfh/JJGRX1fJea<@3Pc<cDe<cDk?Si0
B5MWKg=jQY:JW9^KWj6QXZ:SY:>PVYBCU9JETI2ATiBCTiZRZ:ZWXZJha;ZVW:2]
ZiN6NGAaH4dl;BDO6A88218M9BDT<4ACFV1`QY>JVYZNXZJUWYF>Shj4MVMQIFMT
HFA^MWYnQY:NYjf^[:b`];6YX9ZDR7Q[HEYBBClf<2d/;2XY;38d<c<h@dmDEU]U
KgIjP8J;TYVOWijPXj6NWZ2PWijNWinQXjR]]/7=f=cHfNWimnKGe=gKa:^GS8Ia
FD4Y5PP410000`hH6QTU?59NHVaoSi^OXJZb^;Vc[Zb_/ZjVWIfTYjRWYjV[ZjZY
Zk6e/jbUXjJXXiZBShb5NW1/JFIOEe=BE5ICCTaBFf5RI6YgPhV?Uj:/[jn_];k5
al:l^;B]YIjHTHV2OWj0QXbATi>GXk:o`[o7fN7F`kZn`k^TSh5mNFUD?b`N5Q4;
0`052PX61a4R:bha?4eJHVQ/Lgb6SHf?U9bPWYRGWJBXYZ:QYJ^_/;:f_L?6alO8
b/W3^K6^Zj>GQWM/IUa;?SPd;2<Q9Rhf>d16CUUYMhF?UYfSYZR[/;Jg/jn][:VS
WijLVI>?SY2BU9ZNWZ2W[kBd/;K7d/^fYjVb[YV2Lfm[FdXk;bLQ7QXA3Q@P:bl^
<d5=E5a]QIJKV9VR[;Bd[JJSXj2IShJ5QX9jLgAmQHR8RY6JWj6SYZR[[JZVXJ2M
U8AdJfQSFDe3?3Pc<30e>S`k>cm7DeiUJFecNWn1PhR=T96?SHb=Shj9QHJ:SH^9
Ri6IWj:X]LKCeM7Bgo7bh<c4bm73ZYB7PgMOBCDV6a<=1P064b0V9RTgAe=KIWfE
YJZXZkG2blNk/k:h^[>WWj:VXYbKWZ>VYjVYZZZ[ZJBOWYnPW9JCU9>;OG5/K6YR
F51=C4e<BDQ<DeQJGFEcP8F:TinY[[2c^/78bl[4_kfh/ZZTX9jJThj;S9:GWJ:Z
]Ko6a/CAh^OG_;6e^k:IPG1[IE8l:QdC3Pd80@8<61/I6B0^=CY1CUeXKFi_M7n;
ShR1PhjFTXV5RY2@RhJ7SiJKWjB[/[Nh^;Zoa/W5_KVh/jVKSXJ1NVYEASdh<RPO
6AXO8bD[=D=AG6IcPY2KXJF/][k0_;Ne/jnYXYjLViVFTi2CVInNVj2Z]Kbh]Kk>
e<:WW::^ZI=nKfe]HE0o<RdY9AlG5A`X;b/X;ce7CEAQM8>=T9:JYJnd/:ZZ[k>^
XYVIWYfCR862R8f@TYFJViVGUifW[ZjXXj:SWiF9P7YdJU]>BDU9AT0k>d99CDmB
FV=XKGAlPXF6QHB7SI2<Q821PGmmO7alOGamP8F=TiVMXk2obm3=c]o/im?1`m7B
_J:@RhMgHTdj;RHQ6`l71`hF5QDJ9cQ3BeEVNHN?UZ2^^l?1^k_0aL:h[:R]/JbO
UiRPYZJVYZNVYJ6OXZR/Z9nIV9^ISGmgMGA^HeUGF5IABdI6BTi@DEANJgImPXVD
WJ:TZ[Bm`;be/[Fg]:jVXZ2PWIRDUINGTi>HXJfc][Bd`m3:]jV]_/2/TWmjNV]D
?bhU7aXC1`033QTK6Ah[>D56DF9aNGMeNH6:SXZ3P8F=S8AmP8Z@Rh5mPXfDUIJH
WjN]/;:e_<2l/jj^/:bQThV4PGU[GUIBCT@i<c8d<blZ:cA1C59HGfUbN7n8UJ2V
YjBT[;>d[jVYZjf/ZZ^^/;2^[k>la/kAbl[EhMo;^;Fo`k:HQ7ioMEe6<b`Z:28H
4A<M9bTV9c90ATYDIg^5QXB9U:>_/JbWZJnb[:BSZJfXWYJHX:FRViRKWj2OWZ2V
ZJJOVYfSY9^>Q860NfiPF5IBBd8m@4I9AdE7Ce]TJ6]aNGinOX:9SXn;QH63R8N1
N7=eNG]lOhF<TI>EVjJc_Kjg^L[KfL:][;Rm/9Z;QhR1LF5AASli<B@I5ahS7Q<?
5B0X;CI5EF5VIfaiRibSXJ6W/KNc[Jjc][6WXZBY[Jj[Zjnb];Be^/34`[^d/[2Z
WHj2O7QaI5Q@CD]7@Sm2BDm@DEQTKgMlPhbFWZ6RY:V_/[:`/KFi^KJb/KBe/k2^
[k6a/K2`/kVk]Zf/_Lo;/ifKZ[:UT8:0Pga[FTe4@3X`91TJ8RTV7ATP:c<h@U9S
KG1aMX6AW9fFTIBKWIN?S92@RX>0QXnGVIRJX:R^[Zfc_L;0^K:_[:FHRWigM6mS
Edi<BdM0>S/n@D92A4YAEEEFFfE^LG5bMgf0P8:7SI:CTY:EVI^NXJ>SYZZ^/;Fm
b=7Abl_IjN[D_k[5cKnUSXB2NfM?>RdU7Q@90P<<5AHB4Q/Z=Se8FFakPHB8TIfV
ZJFTZK:f/:NQXjJTWYVJWjBVYJFWZ:JQViRIW9fIShV6QGmaIV9SHUaBBdY<BdI0
?T54ATE6C5IPI6EYL7UnOWn4RXj>RhZ<T92=RHJ6RHb<S8fAU9BDVZFa^K^i]l;D
f/bh/;O0]Yj8P8B2LUe;@3Xf<2PS8b`d<bdZ<T1:CE1IIW5cLWEkQ8V:Q7j1RiBC
S8Z@VIbHUYbW/KFd]l39cL_8algDe]7:aL6j[YjBRhInLF5EDE1>BT=0@D=5A4QC
GfU^Lg^4SiRMXZN^][Rh]kZn`;fg][Vm_KVe];Fj_[jm_/G<cLBob=C@]inJZ;2P
Q6aUJ69B@3<[9B4J4@lD82TW8B0X>DI>F6EcOH62QHjJX9bBSY>KWIF:QHV=RhB0
Q8jGViZIWjN/ZJBTZ[6c[JJSXj6GR7eiNGE[H5MCDU5;A456BTU7ATYDGfEUIfab
MGEdN828RhJ0P8F9RHJ6RHnCU9JJXJV]/;Bla]7Fd/oHj_7Na[g8eLffVXb>RWUQ
B3Xa:R<G414G7ahI6B<c?dE:EVMgNgUjPXnHUi2<Tj2VXibHWJFWXj2T[[Nj^;Ro
a/O0^[Zo`l2f[:BOVi1oKfESHEM9?Se0?cPc<SLk?3/oAe5IGF1UKGMoPhB9TIRI
UY>FV9N@RXR9S8Z4PX:6RHV:SIJQZ:ZW[;k?d;ZTY;C1]Y^5OhN3LUe:A40i;b4K
82/e=C0b?4Q>D5ETM7ekM7=iPH1gKFY`N7M_IVE]MgUfMX2>Vj6SZKG2b<K3a<[?
d<_4`L2n]ZRKU9>?Q7I/JV]UFeEEF5]GDe=IHfY]KG5jQHb=SYFPZJ^WYZ^a/ZjX
YjZ][JVWZ:Z][Zf`^lWDe<g;f>[^f/6h`lg0XXAfN79OA2PK50l800023aXJ5a`/
@DiEH7>6THn<SiRSYYjARHbDUHf3P8J>SXR4R96IW9ZKX:JXXYbMXjVWWiVGV9R@
QGekOG]bIUmNGEUABDQ;BdQ5ATiGFe]MHV]cMWIiP8Z@T8b:RXb:PgekO7elN7Ii
P8J:SYJT]LC=d=KVmo[Xc<;>fm:fV8Z<QW5G?cD`:24J5Q/V<34];3I5CDiBH75i
M6i_MGj4PW]fNXJ@TXf:T9^OWIbS[kRj^KVm`<;0_[fn`/6k]K>c/JNGRXF2NfiP
E4e6?C8X8R<V9bDT;3Q4Be1HJ7N1QXZCWJFYZJRYZZNQVIBBTXn:QhV>TY:CUj:`
^kjj]kkBh=RmYZRl_ZV:LgQoMF17?3hn>RlV:CI3AT0nA51HEUAOLX20MFe^Mh1n
MF]YLGUgKfU^MWMaJfijQHf@UJ2//K6a^<KAdlg9b/k?aKJXX:2LTXIlMgE`IeeI
GF9RGeiSKG=dM7V1R8Z9Ri>MXj2JUIJJW9ZHV9ZMW9VIWZR_/;2ga=;If=7>e^K_
hlRd]LK7/I5hMW]]DcHW:BPP4PH73aLI5a/X>D=5BEQ^P8F2PXZDWYjESX^@UiJ@
QhF:SHZ4PXN?U9BDVZ:XYj>RYjn`ZInHV9VDQWEZJ6UTFe9?DE9?BTQ;DUQJG69/
M7IcM7Z4RXR5Q8V@Ti2<RHV:QgmgMW^1PWimP8B6QHRBXK2j^kVlc>7Vd[J[^<O1
ZY26RHAcFdY4?cP`:B/c?D4m>Sa7DUEDF6MhPGacL7AlOg]eLWIoQHJ4Q8R=T9:G
XZng_<36cmKEc/O8cM3=a;Zb[JFHR7]eLVaQDdU5A3he;B``<Bl/<3a:D55CF69/
LWIlQXnEUI:AUYbNViNGVIZHUiZNXJ:QXZJ[/kZn_KNhaM3>^J:LZ:jRRFmYKVQH
AC`o?CH/9bdg?T94BU=MHF5PIG5lPGabKW1eMW5ZIVIYJfYWIVY^L71cN7n6Ri:J
Xjb`/;2b^;bm^KBb[jfSUHV3PX9mM6]YJfaYIFEZK6YXJgAmPGmmOX:6QhF5RY>H
VIJEVIjPWYfPY:JVZ:b`];Nj_L32b=7If]GCfnKWe;Z[[kbiYHUgMG9VCchh=S0T
6APO:BXV8RDa?413B5IVLWIcM7V1QhV9Ri:IW9ZEUI^RYZFUZJjd][Jg^;Ve[jZX
ZJRTW9>;QX5hKVIRHV=NF55@EEUHE5AJHFEUIVY`M7AbLWMmPXB6RHjBU9:?Si6A
SXZ6Q8B3PX5oOWeoP8:5RYBOYZRX[KW2_jnNV::YXhmiL6mYFDHj>clk<BTZ=T=7
ATA6CUAIG65/MgimMg9aMGYkNGUnQX^;RXbEX:NXYjVa^l73a<S<cLW1^kVj^KB]
YInHSX=jM75^IeiGDe=CDDe:AdM5@T53BE1DDe=GGfYcN7f4SIFIW:2VZZ^YYZJX
ZZVVYJNZ[:VVYJV`]kbm^;Bc][bhZ9N<Rhb4MV]UIem;>S@mAd@k>3m=EE=BF6A^
L6i_MX68RHEnNGIeLg5_L7AgMW=bMG]oP866SYJJW9nW[k6^Yj:QXjBSXj>RWIN>
Qh>1OWYdL6i/K6YYIfIUHEaJFf9WJfa/KW5aLG1cNh:7S92GWZ>VZ:^^/;2a/kFf
]kRg]KBc/kBi`LW<b<?5c]KA_ZbVZZbPS7ikO71H@ca2AS/[8RPf?3Te>D==D4e=
EF=_Lg5^L7ImOGQeNH:9RHJ5S9NOX9jPZK>h]k:b][Vf[J>MVI>:P7YhN7I`JFEV
J6UVIFM]LgEcL71bLW1ZIVMYJVQVJ6eaLW9cMWYlOX:9T9>@RhR8RHV7QHB3PX5o
P8>5QhR;T9VQY:FV[KVn^[6[[k:/Vh^5QGm^F4U6B4@j<S4h@4=5B4iFFeYHEeUN
HF=RGeiOGeiMH6UeOX62QHfGWJ2QYk2h^kZi_<31_;Nc/:bVX9^HV9NDSXV5Q8F4
PX1oP85oO7]lOGahLVi/JfYYJFY/KFmbMGZ0R8jBUYVNXZ>PViVHUY28Q8B5Pgek
OH:6Ri6HWJ6PX:6SY::MUi:?RhAmN7E`J5]BD5=EEEEEEUQJG5mSJg=iNWIaL75b
LFi/JfYUH5iQIFQ[K6a`MWf3Qh^@UY^LViVJVYZGTHb8QH>3Ph>6RHb>SXjAUYbP
XJ6OWIVCSHN3PGmkMW5^KW1aLWAgNgj0Q8^BUIJGVY^KVIZMX:2MVYNEUIJGV9VK
XJVa^;^l^kZj_L31_;>YWiF:PGYdKfUQFEEGFemRIFMXJVicMgYmOh1nNGA`LG9`
KF][KFmaM7QnPhJ9RXbAUYRIV9RHUiBASHN1O7UeLVm^Kg1aLWQoQX^=SHj@Ti>A
Shn@T8j;R8F3P7agLg=dMWUlOgmmNGMeLg9aLG=eM75/IfARHV5OH6=YKW9fNGb0
QHbEX:JYZ:FTY:>PVYB?RHAmMFiXHeiHDU1CFfE/KVe]L79aL71dNW]fKVQVI61I
E55CEe]NHFM_MGMgNX28SY:DU9>ASHV4PH63Ph:2Q8R8QH1oQHbAUINIW:2RXInL
ViVFTXj=SXb8PWmnOG]hNGj5R8J5QhfBTHb7QHF6PgmoPhZ@UIVHUi69PGYjP8N>
T9>JXZZ/YIfHUI>=QX:3QhR5OgYjNgelNWUjOH66SIFNXj6JU96>RhEmN7AaKfUT
H61QHF1PHfU`M7MjOX61Ogn1PhB2OW]lOX1oNg^0Qhf@T96FW:2RXJ2QXJ6NViRG
UI>?S8f>SX^7QhN6Q8:0PXB5QHB4Q8F6QH:0PHB7RH^=Si2?SHR3OWQcKVmcNX68
T9FJViRDSXZ8RHZ8QXF7RHZ;Rhb;RXR8S8nAShV3P7ioOWakO7ajMFiXI65OGf1Q
HV5OGf1TJ6U[JVY^LWEdLFm`LG1]K6mdMWEdLgEgNgj0PX>4Qh^?TiNHV9NGUiNG
UY>BTI2?Shn@SXV4OGQdL6]VHf9SJ6ebMGUoPGmkNWj2PgmiMGAdM7IiOGmmNgYh
MWMhNGYiNh24QhR;SXn>SHjAUIRGTXj<Si6@S8R8R8J3OgamOgn0PXJ:SHj<S8b<
RHAjL6a/KFe^LGIjNgYgMGAcL6aWHfAXKWAiOX>7RHb>SXf<RhV8R8N7RHZ9QH:2
PhF6QXJ4PH1nNgYjNgamOWeiN7]mOG]lPHN<T96AShZ3NgUjMg5[If=PH65QHVIZ
LGV0QhjGWj6PWinRY:BSXJ6QXJ>VYZNVXYfGUIFDUiZLWj2OX::SYJFTWiVEUYRG
U92=SY2?SH^7QH>0OGYjO7n0PH5nO7UhNGUiNgj0Q8J6QhN4OWQdKfe/KFi]K6a^
Kfm^KFa^Lg^1QXb@UYbOWYbLW9bIUYBBShb8QXF3P7ejNGQfMWIgMgUkOGamP8J<
T96@SXf>Shb4OGMfNGj2QHV<SXb8Og9VIfe^KG5jPXR:SHj9PWilO7akOX:7S96B
Shb7PG]fLFe/KG=gNH27Ri6DU9B@RXN0Ngf0QXnCUYFBShR1O7I_J6EVIFM/KFi^
KViZIV=PHF=TIVY^Kg5aL6eUGU]KFe]LG5aOHfEVJ6QZJfa^Kg5eNgn1PhB2PXF8
Rhj?TI:CUIRIUiFEUYJFUIFHW:2QXjFSWifNXZVc/j^UYj^WVhV0PXB5Ph1oOGYf
KfIQG5UKHFQaOHZCV9fQX9jKVINGVYfLVi^LWj:PW9NCShj;RXj?T96BThn9QhF3
Ph5mPXZ;RHJ6Q81iLfi[JVQWIfEUHUaKGV1QHFI]L7EiNWQbKfQ[LWEfMGEeN7eo
P8>4Ph>3P7YhMGEiNWYkNgUiO7j3QXJ3Q8F6QhN5QhR:SHf>SHjASXj<RHf=RhV9
S9:GVYbJUiJHUi:>RXV<Rhb>RhR6R8EkM7EiOH:9Uj6RXZ6HTi>AT8jAUI>GWYbG
T8N0NW9ZIfUWK6mZIFMVH5UCDe9BEe]PKGf;UIbJVI^FTiVITI>NX9bKVYRIUi>@
RhZ:Rh^=TYBDShF0OWYdK6ARIFEQGeiPGf5SHV9RHf9NFV1LDeMJGF5SJ6mfP8R;
SI:JW9VNWYZNXIbGVInRWIN?QhJ9QH:5P7j8SHf?U92DWj2LU9BGV9RMTWi^Gf5W
LGj3S96:PGEXH61WLgf7T96<QGmbJfmcNh66SY6<SYFESh^=UYVMX9ZY^KB[X9NA
Shn>UJ:XXYbJU8V2OgioOgMdN7MdJf1LE55;@dA9D5AJGEaLFeUGGVQdNgn;VZ>M
S8V=RH>0QY2;QhR4QHAgJ6QbNh:;SXZ8S9:DSh9mPGejNgU_IemSIEIHIFU[KVaU
J6eYIVAWJfQTJW9gLVaXHVE_MGimP8^4QI2FUY6AWY^J[JjMUI^SVI>LXj6X/kS0
`kV[ZkFc/k6YXjR/YZFFSY6>S8F:U9:=QhR>TXnBSi2DUI65Qhn6PXfBSgmhR9BN
Y9jBQhbFTXAoR8n9R9:0KGn8SY:BTXZ<UiR:OWmlM6mYGEYOHfASI6EPEF5aKfI`
OhV4LfU]KF9KHFUgSi:8UZ6PW9^d/:B][[>cVYRNTiNFQ7A_If]_I6EOA3e=HW>4
Si62LGMZFDiEF6UgNXAnKW9lOi6IV8f<UYJ?VJNTVjBOXYf@UX^4QHfDTGn9TX=m
Ng=YNYNLXJ2?PWilO7A]KgR;UhZ2R8F2Og9RCe]bKGJ6R7mJ@3dZ9BP/;R0S>451
@S@U<DM@HFEPGeYHDdm7?3a;EVn0NWaoSinDWZ^V[ZBX/;2h[Y^SYYJHVJ6]`L6h
b]>k/lC0^[Fg`[BUYJJTQ8:JR7MlIe1dSXN=PWn0IW:0M7I^LXJ1LgE`J61cVI6C
Z:Z]]L?;`[>UWk>[TJBEQ9JGOWZAUXVN/jB]^jRTXiZCOXNIS8RIY:JNT9nd]JZT
Y8m/KVm?C5m>AeiKEEaB=Bm1D6IlLUQIGDe0>AlD;TQ1=cTfDfePH5e7GfEQQ8^B
W9ZUX7Y3?V1SE7B=UjBEPGf<T9JUY:BSWinQUh:2OVeLKY:IW9bXXY:<NX2>RifH
RH=/PH=KE4U:LhU`KY2d]i6?X9ZKV929MWjIVhEjM7=eKW:?YJ6IYkVg][VeZIVM
Vj2/T7J=^[bJZ;RO]ngR_/SGdM:k^<WGk_7F]8n?UINHPfY`RY:0I6ijHVIUA3Dg
BVUbFdTl<24H50dI<3Pk?T10EVULGfYJGX:SZXn1U:25PYnBPX^IUYnl^JfUZl75
XGfD]:>?SXRHRVE/R7QeS8ERI7EHB3i3E4U0?T/k7RXfCG5N>TUGFFacPXf7U:6L
WZb`Y9^T/:BNVZ;2/J2MTY6E[K2CQh=gQ9:1SXQWIWAiNgV:V8B:Uj6PRGR2SZ6j
]kC?fLVgTgMiSHAYJ6MYMV5:H7Z2ITi_P8FIWHUhG4I6CDY7>SM7Gf9B@CaCL7eT
G7RGWhbIXXAjLEY2A5m^KWjCVh]/JGB3X[:CNi:TV9jWVX>2NW^:S8fS/:J_bM7?
_If<NG2BSUEBJVUdM5@nA6MkQ9:>U8f0UJjMT8:1U:>RRi:KVJO5`;W8`;BW]mO=
`k>WX861TibLW:j^/l?@bKBnb/Jk/[_Zon_2]:>:I5EE>RPm@T5MNgEWGeEUKThh
D6EgO6Y<:Q`3014H9C`jBFU_MVekSgUlQ92bWhbARHJ@UYB:V/SNeMG@cMC>dLZc
UXF7PW5OFU8h=b`M93A1F69WLWR2HdIMIT/Y7R@Y=DaDCTY@FVM[KXVNZk79e;NC
Ri^ISXamMHRGVjR`^;jZW:J/ZJjlZ8UmKg=[CcPmCUagQfYCIVYNJGInYLkMh/RW
UWIMGD/k<24Z?4MGJVMPHGN8PXZ5M9FfZY5VCTmHH5ICCe5aVYb;Ri6IY9nCTXao
O8=nMGYoLG1lPH>:TiNO^M[SdLc8]Jfj^YF2QGinMF9UIVEbR9bZ]:BE[kRYWX^2
SIR@OXF=M7JET9>ZZ9^WaMO5YYN;SY>2P8]eIFioQH^@QGf>WYZOVhR?VWmWIVIQ
H79ZFW^1M8VIWYfS_>7ooooD][O2[8n=NVI`LF]`MG=SFf1FEVE^Jf9ICRl:0000
000000`<:F=bHf^2Q7N2UZN^XXn5PH1fNWMNK96TZkJo_lCEhnSVc;>h_:ImIV]L
D4db;D=PP8R5QX5lQYBJSWeI?E=PDU9@@DMGJ7>;[JjIXkbbZjjNPgQmOGA/IFQf
OgZ5WIV>Vj2@SYfFSIbQV9NJWY>C^Lc0/ZBU`=kdmOOig<c6ZiVANe@gB6=SJ6UD
ADQFKFQYOHNDThAUFEU:Ad@V3218F5aQHGBLZYbJYZVX]Kk2a[2BP7QiQ9^/ZJZf
^:nYZ[2`ZZNCP71ABDHJ00003PhP>TACHV]]HgJ>S8n:PWj4RWelNG63Y:jNWjbd
_l_AcL;2akfWWYjMYiI_H6mlOHN0JfUXF5m[H5IBD3hmBd9:IFMQEeehU;;2e?Cj
i/fjcN7D^YQaIFeREea?>Sa?J71^IfA`NG5HCe=D@c8l?cA2DUEVPYjSXJNT/lC<
dLNcVX1mLU5CGVenMFM[QIn^/Z^HSI:NYI=hJf9A@C4c>cPkCFQmR8bAUZ6b/YjM
]KZc/k6a[9f9T[2_];fd/kRo_Z^PTWEXIVISAc@oB4iAAd9@HW20S92EW9B;R8:?
UI2HT8ZNZjffa/cAo_ooh=gYj=g9ZIVKU7YKBdiHHVERI5mOKGnARgEL@34b<c4V
5aDM:d9AEeQBI7nJ[Z:IX[JnX7mfM8:=O7^:RWn5UI6FZ:JNWinGTY>AQgAOEeaN
EU9LKGb2OVi]OgecO8Z?TXmdHW1aKh65P866SXjEYJ^/YHn1Ph^BRGaaKfmcPGYY
FeAOMGj1PgM^MgU_K6QUKFmVJ6eOL::hZk?Sooohe<GKhmJlV7IJDDHa=Sh^6QHR
<cI1G6miJTTh?DI0:aX>52Tf?e1QMh^BUjNjcMWSj^3>_KJo`kBXY8emPXRAU9FK
U8j8Q8Z=TXadEd=2BdTk>Te[PhEoN7f@VZJ`Z:k0a;Z[Z:Ze_kFVZ:^dbMOOfmK?
_:BFTi:9Ng1TJ79RCT]FJHNDQh67TYVFS7n6Thn7OFYZM75`K6Z2X<7/oooeh=K@
a[FKR6iED55AEU=1<3I7EF9YMHnKSgmYCD=?EUMJED]<DE9MM8^@TInRX[Bk/9jH
TX5fIU=AE4a7BU=JE5=EEEiXJVedO7=UF4Y=DDa5@d]HK7YmQinhb=3Cc<_?a;g3
b/NiXi23N7AgQ8^5Qi:NZJ^VVi:@QGM_Edi>>cE3CTa8BDeAHGEeM7EdMW^:ShV=
RWenOh6CYJ:[bo3omnG=`LS6[hAPEV5`M6eQEd]AIW=nQhjBSH1]EeAJF5Q8=CY4
CUUTMXNEWjJ__L[De<_5_:ZGPgYgN8NDRh5mLViePY2JWijMViF?SHIeHEQMHfU[
HFAmUJ6SWZ:^^/G5`L6k/:JEQhF3MVmbJeeGGfedLG5jOGQfL6IPEdi8?c`mATmF
I6idNGn8SI:JViFEV9ZQYZ>MV9VES8fBVZk4enKQd<K<d;ZEME]3=2TQ92/_<SE0
Achh@EelPW]]H69THf=IBdY@EeIIJg^6TIJP/lK?b/>iYiNDS7edKfUPHf]YIF9U
LWUmOG^5Shb7PgISFEUDBDYMLh>9R8J?X[Jb[;BaZ:b]YZ2LVYNGUHZ6QX:7SHjC
U8Z5R8V7PWaiN6eQI6aYKGZ5TiZLVYBFWIB=SI2AQGamOW]dKG60Qh5lQ96[c=W>
_KJl`KJNPFA<Ade4>CH_<3i@HgMnOH2<WjfUWJJ[YIbASXQhKFikRI:S]Kk5c]GK
fM38^::FSX=eLVeVIEmCBT54FVUXIfieNXB3K5A9CUUOHV1PIG>8UjBa^;o5_K>/
/[k0_[Va[j6?RX^>Ti27Og]lPXb7Mg^1NWM^IfAEBdmIIFeaKFUdP862PGanQh^;
SXn@V9nKT85hNGj2PX61Sj>b`[ZFQHjMX9B2J55=BDE;BD=3AU5MHF1MIg^8RWeg
O7=XJ6Y[K6UPG6MlSYNAR860R8QhJfUVI69EA3e0ATY;AdU=DV9cOh:5RhnCU96?
R7M/K75jOG^5XKVl]Zn^_<6h/K2f^:j/[JJIPg=VG5eTJG1bKg64Thf;SHN:Ti2:
R7]^MH><T8j9RX^;T8j9UJF][:f[XZF][:NIR8>9SHV6Ri2EXk;1a[JSU9FWZ9R>
RXAfJ65TJFIKEf1ZM7MhOXRHWI>3JeQKIVYUGEYPJG1dMGIkNh:CXZndZ9^LYJ2=
P71XJV5KFE5DI6YZKG5fMGQhLWEaKVYHCTi@E5i^MWAbLGb?TiVUZ:b^ZJZ[Z9nG
RWakO8>CTh:4W:j/Y9fBSHR1OX>8QhF9SHj:NFETLGamLW9hOHZ:QhjCT8EnOX6<
T8V=T8nEWinQYJFT[/CGfL^n`lRnZH][D4<m=SU0?C<[<TYOLH>>V9V:OG]iM7Ui
FdiGFEUIEUENL7n<WZZnclZn/:BKRGAVH69UHf9TJgMkOWeaKWF2TIRBQh1hK6a`
KW=kOWj;VYNHXk77eM74_knn_KJMQXRFX9MoLG9nPGQ]IF=_MGEdKV]XI6QPFfIV
HfIUKGAcMWQnQH^KWYNHTHV:SI6=S96?RhF0M6UUHfIcRINQ[kNncLj[S8R<RX9_
EdE0>cLj;R8V9bdf@4eFIgAlRXQjM6e]MgM]GEMQKH2<QHB>Ti>@U9ZHUiJ<QhR2
MFIIF6Q_HUIBFVQgNF]RIV]dNFaVI61TJG1jPYJV[[:]/KRj_;Jd^KFe_knl^:jT
Uhb9S9ZTVhf4Q8^ASWmdN7n0NgEeMWUgLgIjNgIbNXZDTh=gMhFIVXj;SHf=Qh1j
O7mdLgakN7E^L7b:SXV=S8jP/K^n/JFWZjRHRH9hMG5WJg^5OWIfOh^CSX5lQIFL
Sh23TYbMQfQHH7V:Q7M_Lh>>TiREShnARh1oPgmmOX>7Pgi^FfAlRHn@SiBLY:b^
ZjNVY9VFVIF?TIF@RXjEVIfOWJ>VVYJQXIZFRWYhOh9gIV1VK7=eLG5hOh62PG]d
I5MMJG9fM6e]NhN0MW1/LgMfOhR2MWEkNWR1PGE^K71fNGamNgMiPhf>RXZ?U9n/
[jn^Z9fCSHAgKei6=S<h?D=6>BTU<4YMGf1WLWMfMW5_LW1_L6mdO7E^NHV=QhnL
Wj:XZZjZVXj;S8R7Si:;RHQoOhF2O7YnPh>4Q8>1NgIeL6i`If1VKF]UIfUXLhJB
V9>?WJRZZZNWXI^U[ZVLT8Z4Oh5jLh2?THZ1P8R=QW]kQHMoOhRDV8f1NGN2TY^L
UY>DV9nRZ:na/[:_Z:6NVi6=V:J]ZYjDUibLW:>OTYFPYjZa/j69OW]gJeQ=CeAF
FemGDE9IIVmeNh:;TYN@PGE`MGifJ6EYK6AHEUeVKg=_JVU_Lg9lQXR7Og]lNgYe
LFUICE9MIVAMHVihOgmiLg1cOGehPHf9P7n4S8n:RIJVZZFHQX>>UiJARh:0P7Yf
MVmVJG1]GeMNKX26OgQcLWj9T96;S92@UifLWIZ@SHfAUYRDRXFBWYnERhfAShnB
Sh^:SY>ASHMkLG1dO7]gP8R>VIbU];^hXY2=SIB;MW=aKVaQH6IYI5]OJFYWIFag
NW=[JVa/KW1YIfefOhJ7RH^8QXV:S9FV/kRe/JNGRXB7RGmZFeULG5]OHFI/JVYZ
IfU`O8VBUiJASHR;U9JFUXb3R9VSYJZb/jZPWJ2MU8nCThb=Ti69QX^:QhfDVjJ]
ZYZ6O7n<ThQeK75kO7E^JF][If=OIG1gOGn3SI2:PGn8S8V9RXR;TIB7MWEkNgUm
OG]iM7=dK6A[OHN:S8J0PX9nOG]cJ5U<ADeHE55FFF5eP7ajQi:BT8]mLG>6VIR<
QH1oOX66PGj5QhN=VjFMShJ5PgQdMFmYJG1dK6I[KVYXKgV3RhfBW:2NVYB@SI2G
TXQoN7^1NW9gPHB2OViTIfmoU9bOVi:@TYbLR7b2QXB6SY:@TYFCShbBV9:>TIZO
UXV:TI2;R8J9SiRT[JbZXHf0Pi>MUhYnNgikMgQkO7b0R8IoNgQnQHbHVI6>TifT
[;_7blJh[jVXZJFOTGe`IUiJE4i2>3i>FEePJ79lPh:5QhB7QWYYHW20Og9XLGn2
PX20R9:MVXR0QHnGTiFISh9iMgE]J69KG65WKFMRIVU[KG1aKW9kPhN1MgAgNWIc
OHZATHjFWj>UWiB;SYFARH>3R8IjK6=VJVa]IE]IHGB1QHZ7NfiXLGEaLFiWIVah
PX20QHnBSHV3Oh>8SY6=SI>GU8f;SiNRZ:NSXJ6MUi25Q8V5N6]/MGf2P7n3OGUj
NgY`JVmcMW=]JF9RJFEQJ7J2OgMjO7YmPXR5PXZ@R7M^LWA/J6ijP7ajO7n7Shn@
U9RES85oQ8Z9OgI^I65ZMHB>UI^JVIRIZ;Nn`l2fZj:RXYZCSHb@RhbDTH^;TIVI
UiRJX:JYYIF2OH20NGIkOWaoQhnDTi>BRhF5QH5lMFm]LGE^I61MHF=RHf=XMgn0
OGeoNWEfLFUUH6=WIVabLG=iOgn1RY2CUiNKWIRDW:VWUHfFYk[1]:BRZ:bUSgY/
J65=?3Xj=Bh`?4YJH5YHGF5ZMh68S9BEQ7IeM7MmP7eeNHVCUY^TZj^WXYbMWYbI
Sh5hMWE/IFEXJW5dLG1dN7elMgEoSYFBS8R9S8^7QHR>TI6<PhBBVibMY:n`Yj6M
W9^@QH>3PgieJVUgPGn1QXN3OhF=RH1mPH5lMW=eOHB7R8bAVIV?QXF=UiRCSY2C
SXR7Q8F5PhR;QXZCVYfHTXakKg9dKVASIfE[NXB;U9jMTHbBV9jPVYB<Pg]gNgYa
K6ebN7j6RHZ?U9B@QGQcOXN1LFERGUeLE4m?DEE?CEINI6YdP81hN7f1P7Q_IfAX
KVaTHVaeN7IfNh:2PXR<SYBGThb4NW=fO825R8V8QWeeMH:CVI24PhZ=SI2@S8j>
SHj:QXF:T92>S8F6SYNMX:6PVIFKXZ:HSHbDWZ:PVY:>U9RDRGj0Rhn;R8^?Shf7
PH>7Qh=nOGioPH>1OWmlNGUaKG9mR8R4R96BRXFAVHmmJf5PGEEBE5AADEEEEf1Y
KWAoR8Z?UIFASI6HU8^6QHfHVibMWj2RYZFMUY^OViB:Ph64QGabLV]QH5mIEEaX
LGR3PWYiQ9BFSi6IXjV[[:fXXYjOY:BQViJIW9nPWJ6WZJR[[[2[Y:2LUi27Pgif
LW9`KFUUIfibMWZ1Q864QhN3MF]^MGn4OgUcM7eoNG5^LWMlN6eUK7^5PgYhNWYf
LFiZIfITJW=aJfmiPHF4PXNEVi25QXZ7OFeLEU=@BdU<CDeDGVIZJ6]/L7^1OG=[
JVe_KVENHFU[I5]EEEmXJW>1QhV?U9JDUijRZ:ZVXYfGTY6@RXAmMW=cKf]/LgMf
N82:SX^6Q8R8OgE/L7n8RXnEUY>@TI2?TI:EWZVa[jJLUI6=RXN0NX27RXR1NW=d
NgemP866SY>?RX^=Si29PH23OW=^LGQmOX::Ti^KW9bIV9VHWJ:PViNHVHn2NWQi
O8:;Si2BWJnm`kbYWjBVY9Z?QH21Q7mfJf1JFUaQJFeZJFabN7ajN7n7QWe_JW1f
Ngn2OW5WK7N3RhMoNWIfMgMiN7EaKVeTEe=FGF=SIVU[Kg9eNWYiOHBAVinOWjB]
/kNh/ZNMW9fDR89nO7j1QhV6PGQcMWf0PGmoPH:3Ri6?PG5/KVa[K71gPHR9QhB4
QXV>THn=Ti^SYYjDRhR;S8V7RHV5PX:6RXnASHN3PGegNGn6S8j8QHZ?S8J3Q8J<
TXb7RY6FTi>CQ7A/IEeIFeaMHV=SJgEhNGMhNWYmO7f3QhR:S8^0MWIlPhF1PHbI
WYF;RY2HVY:;R8V:QX>4RY6CShN3PX1nNgQeKVEQIg=jN7AeN7QhMW9dOHF<TiF?
Pgn4QXR4OXJFXJ6OXZJYZZBLVYVCSHR2O7IfNGj5Qh5eJF=SIfmfLVQXLWn9Si27
O7QgMWAbLWV4RHF0O7E_KFe`LgQmPhb@RGieM7QjNGYgM7N2U:6RVY>FW9J;Pgei
MG=cMGM`I6=_N7anNWMgN7b2S9>>RXb<QGU]IfU_M75]JV]dP8N5NG9cMgb2Q8>0
PHV@UY62NWb0PGafMGIiN7=dMG9`Kg5gOh:1Ph^AUIbOV96=Si:ASHZ:SI>ET8R3
OW]nQ8AnMG=kRIFHThf;SI6@Rh9iNX:9RhR:TifRWi^HUiZKUi>@S8V:RHJ3O7=/
JFU]NX=oNWf8UIbOWj2QWijNX:>RWYnW[:ZXZ::CS96FV9>;RXj;P7AaM7MfKVEV
LWf2OWUiOH5nM6UYLg]gLGAlPX1eJfacNh21O7=`M7Z1RH^5PH1kKV9JE5=HFe]K
G5aJFe]HF5]SKG1`MGb4Ri6DT8V7RHfEVIZKX:FUXYjFTY6<Rhb:Q7n0Ph>8TIJH
U8b8Pgf1QH=lMgAdNW]^HEeLGEmMGfQhQ8N7QH>9TIBDTHjAV:6VX9J?SI6ARX=m
OX>2Og]iP8F7RHV8QWmhMgUlN7=eMgMgMWEfN7IcLgA`JfY/Lg]nNFmYJ6YaMgYi
Mgf9RXF0NgMgNWQbKFa]MhB;T96>SY2@Rh9kO869T9:?RhR7RHjCU9:<RXjDV9bO
X:6SXYZAS8R6Ri:IW9N>QXNBVYJ:O7MjP8R5OGf2RY:>P7=bOHN9QH:6TIJARXJ8
S8j@TI6AShb9RHjCThf4P862PhF4PWijNWenNgE]IfAUI6=XK71fNgmmO8>:SXn<
Ri6GWInMViJ@TIBARGihMgQkN6eREdm>Ef5OEE5AEEeUJViaLgV5Si:@SXf=RhV8
S9:DU9VLVIF>QhR?UYVFUYRMY:>EQgmlPH=mLfiaMWMjNWIcLG5aLWV4SYNKW9bH
TY2AUIB>S8Z;SHj;RY:MXYnHTXf=Si:EV9^HT8N0Ng]lNG9YI6EYKViZIfEXKgAe
LgEoQHZ?TIRNW9^KUY2?T9:FUi67PhJ>U9NHU8n=RXR7QhN6QhV<Shj8PGagLg1`
LWAbL71bMWIaK6MUIfU[K6ebMgUiMWN2R8R0NGf6SY2:PWmmOGemOg]dK6QYJfi`
KVY[KW=eNH67Q7ahNGanOWUaKVi/JFISI6M/LG=dMg^4RhV1NGMlQXf<QhZCVj6P
VIBAShf9PWelOGYjOGeiM79dN82:TI2?Shn?TIBFUi>=Qh>5SI6?RHN9R8AnOGn0
O7I_Jf]_LW9_K6a`N7aiMWMjP8J7QXJ6R8b>Si2GViRFUYJBShf>TI:?S8^8Q7af
MgamNGAcM7A`K6MVJVmbLFmaNXF=T8b7QXZ@Ti:=RXb@TiBATIBDT8^;U9jTY9fD
QgaeLG9hNWIbJfMXKWAeLW1aMW^2Ri:CTXn;RXnFUY6=T9BHVIB>SYBJW9^KWJ6S
XZ:NVifOX:6PXJBVYZ2CRXJ:T8f5OginOWn0OgYdL71fOXF4O7UlOWj1QXR5PX>5
QHJ2NgIcLg=cLg9^K71gO7eiNGn1OGMaL7^9SXIhLWAkPhB0O7YlOWegL6]SGf=X
KWAfN7]kO8:9RXV8QXF6QhJ6Q7edJfITHfI]LG1/K6a]LGEfMWQiOH62PGihM7R0
QX=hKVabN7YjMG=eMgMfMWIbL7AiOH21OWj0Ph9mN7Z1RHb=SHb=SXj<RH=kM7=i
PhN4O7EdN7anP821RI2FV9:;RHbCUiJFUibPWYbLW9jQXj2HTHb:S92@RXF6SIBI
ViVCSHnDThf<S8^8QXV=Si6?RXN7Rhn>QX22QhR4OWIbMWUiM6i^LWUmOGYiNX66
QhJ4PXF;SXZ4P7inP8J<Rh5fLG9iPH=oN7AfN7YoPhJ2NgIdM7MiMg=`M7UiM75c
MGEgNW]oPhB5Q8=oOH:8Rhj=SI6GWJ6QWYVET8IlNGQkPHN7Ph64R8J0Ngj5S8n?
SHf@TI2@ShZ4OgYfMWb2QXJ3OG]nOWn1OWMeNX>;RX=mOHRDW:2NViZHVYbKVIVJ
VINFU92=RX=kNX27RHEoOH67S8n;OgIgOH21P7emP7miLV]UHV9SI6MWH5]MHVMX
IF9TIVIUJ6YYK79dN7b1QXR9SIBGTHN1OWn5Rhf9PWeoQHN8S8f:RXb9Q8>4Q7mf
JV=VKGAiMg9aM7UkMg=bMGf3QHV>T92?TYNIW9bJVijT[K2]ZZFNVYRDS8B1Ogen
P81lMgIhNGIcLg=cMGAbLWIoRHj9OgE`L7IhLfm^KVi`KfaYJFY/L79cMgUjNWId
NXF<SHZ9RXb?U9^QWibKV9>ATI6>RhR8SIBGTX^9RHZ>THn8P7YkPHN:R89kMG5/
J6EUIf][JFMTHFA[KVa/KW5dMg=`LWV1RY2@S8^=S8^8QXV>SX^>UYZGT8N2PhN:
RHF1Oh>9SY2:PGaoPX1mNgeoP7ejNGQfNGj1PH5oPXR?TiBCTHn@Shb;RhV;T9>D
UifRY:6IU96<QX:0OGUhNWYjO7n4QHF6RI2EUI>CUZ2XZZBFR8:2QHN4OgYlQHR4
OgQ_JFQ[Kg9cLgZ4R8V<SHj=RXJ5RXnBTi>BTY>ASXb:QH1nPHN;RHB2PH:5R8N2
Ng=/KGF0Rhn;QXJ7PWUaK6]_M7AaK6EQIF]`Kfi`MGUhLFa]LWYoP81mNWQkPhR8
QX9nOGioOGYgM7AfNWekN7V1R8V:S8V2OGYjOH64QXJ3PH1nNgYlOh62PH25S8f9
Ph:6SYFDShZ7R92GVYRETY6@SHR4P7]eM7UmO7QcLgMkOG]eKVMUIf]aMWUmQ8V;
RHF2PH1lNGMfM7IjO7ajLfeZJFabMgUjP8N9RXV9SHn=RX^@VJ>[ZZBMU8b8R8F4
QHN;SHnATi6=RhjDV9NARHF7SIFKViF@Si2?SHZ3PHB9S8^6P7YeL6m`LFiZJVQX
KGB1SI6?R8B4QHJ9S8j?T9>DTXn=RhV9R8N8QGimQ8jCTi6;P7QdMWb1PX:5R8^;
RHAoOWmmO7]iMgQjOX62P824QhAmN7QnQ8J4QHZ<SHf:QX9nNG5/Jfi`Kfa]L7Ei
NWYjN7IhOXRAUI:>SHf>T9:BTY:CTi2>T9:BSHN2OGUeLg=dMgj7SY2>RXN7RHV:
SI:DTi6=R8B0NG5]K6e^K6]]L7AhNWUgNG]mPH:1PH:4RI2DUI:>RhR7QX:1Ph5k
Lg9bLW9eMWEbJF5OGemOHFM/L71`LWQmPhR8QHB7Rhb;QhB2PGmmO7alO7aoQ8ZA
UY>8OGMjPXV:QhJ8RHN2NgIcMGV0RHb8PWioQ8Z=SXn;R8V=TiVQZ:ZZYj6LVIB>
R8J4PWmjMWIgNGYkOGmoO7UkOX:8S8f<R8F4Q85mNGMeM7=_JFMXK75dLg1`LWIk
PhR8QXF5QhR3NgMhNW]mP8J<T8n<RhV7QH1lNWYhMgEcMGYlO7alNGUmPhN6Ph:8
Ti^MViB<QhJ5Q8:2Q8F3OGMcLgIhMFaTHFA[LgIfMgUgLg=eNGYhMg^3RHV8QH61
QHR:Qh>4S9BHVIbNX:BUXYjHTi2BUYVKV929Q81mO7]kP8F7QXB1PXJ;TI6;PGUe
LW5bLgMkOGenOgn1QXZ;S8f?Si2BU9:<QXF<TiB?S8Z8RY2HWIV=QHN?UiJ?QGim
OgmjLfmbNhB8QX>0P8>9Si2@TiRMWIRASHf?SXb<S8b<SHb8Q7mlO7eoOgiiLg=g
NGanOWYhNX26R8N8TI^QXYfDSHR5PWiiMGIiNgUgMWMjOGn1PWefLgIjO7U`IV5Q
I6U/K6mgP8F5Ph60PH61PH1mN7AbLW9cMWQiNWQeMGMiO8:;T8n:QXF2OWUcL7Em
PH:1P7imOX22OWA_LWYnOW]gN7eoP81mN7MhNgj1PX:2Q8J8Rhf;RXfAU9BASHR6
Qh^=RhAmNgf1PX1lNg]jN75[J6QZK6i/JFY^LWQkO867RXZ7PgikOhR>TI>BUY^N
WIVETY:DUIFDT8IoOh:7R8=mNgf0PhJ7QhV<SY:FUY6;QH:0OgafLgEgN7UiNWaj
MGAeMgUnPhN9Qh5mOH21P825SiRMWY^CSHbAUY^LVYRFTHf?Shf:R8R8RXZ:RHV9
RXnBShf;R8F1O7EaLG=cLg5_L79cMGQeL6]UHVA/LG=eMGAeN7MeMGUnPH>3QHZ;
QX1mO7emNg]nPH:6RH^=SHb<SHj@U9RIV9RGUY>=PGE_Kg9hO7]iN7MeMWQmPhV=
T9FGThj:RXb@Ti6>S8Z7Q7mnPXJ5Q8F8RXf=Rh^<Qh5nO7]kOX>7RHN2P7moPXN:
R8F3P7mmNWEaKVmdN7UiNWYhMW=`LG=bL6i]KW1aL75hP8R?THn;RhfATY6>R81h
MW]oP7ilNW]kNGQkOX:7RXZ9RHR3O7IdM7AcLW=fNWn6R8EmMgEfNGf0QXZ=SXj@
T8f6OGIdN7f0P7n0P7mmOGj2QXF1PHJ:Rh^9RXZ6P7moP861PH:3QHN;RhF0O7Ui
O7j0PhJ8QX:2QXb?SXV6QXV=TI>CU9FEUIBCTi>CTI:DUiRGShV7QhB1OWajNW]l
OgmoPXR<Si6@SXb;RHZ=SHV4OGIcLgIiO7elNGEaLGAjOWmnOGn0O7E^K6ibMW]o
PX:1OWemOX21PH>6R8N5QXV:Rh^:RhR5PhB7RHR7QHN9RHR4OgakNgUhMgEeN7n7
RXEnMW1/Jfa^LGEiNWUgN7QgMWQlQ8bAU9FDT8Z2O7anOGUeN828RHF3PX1mNgao
P864RHnBTi69P7UeMGMkOX22QHR8QXB5RHf@TiFGV9VIVY^LWIbHUIFFUiNETi:D
Thn;RhjDUI29QXJ7QH61QHZ=T9>BT8n?T92ATY>AS8V7PgmlNW]oPH1nOGamOX20
O7IcMWYiM6eZK6maM7V0QHJ1Oh>8RHEnN7IfM75^KFe^KViaLW5_LGN0R8f@T8f:
QX5mNgalNWQiO7n2Q89lM6eWIFMZKG5gOX>3P7]eL6i_LWAgN7UjNWQhNGUiNWeo
OWakOH:5Q8:0OgmoPH:2PX>3Ph>3P7ejNGUiN7IeMWUmPH>3Ph:1OWalO7]mOWin
O7UjOH21PX>7S96EV9ZLV969Q8B2O7MgNGaoP8B:SHb=TiZOWibJVinQWiVBSHZ8
QXB1Ogn0P7imOGeoPHJ9RXZ:RHN3OWf2R8^>T92@Shj<S8b:RHZ=TYRHU8j;Rhf=
RXR8Rhj@T92@T9:BT8nATHn:RHR8QX9mOH:6QhF0N71ZIfQZJfibMg]jMG5_L7Ah
OH>7QhF4Q8B3OgQcLWAeMGIiOGijMWAeMWIgNX26RHN7QhAoNgUhN7E`KFecNh66
QhF1OGYjOhB5PX:6RX^:QX>1P7mlMg5^KW1dNGenO7YkOh>4PWelOGeoPhR9RXfA
UIJETY:CU9NIUi6=S8^:Qh>0P7ikMgIeLg1/JfYZJf]]KFeYIfU_N7enOh>:T9:C
Ti:AT96DV9NBSHZ;SHb;Rh^:RH^>TYBCT8b9RHZ9QH61PH62PH20PH>4QH9lMW9b
N7enPHN:RXR3P7n1Ph61PX:2PhB8RXV6Ph>7Rhb>Si6CTHf7PGimOG]iNWamOGen
PHB6QHB4Ph:1P822Qh^>RhR5Ph>2Ph>2PhJ7QHB4Q8F7QhF5QXR9RHJ6QhJ0N71^
LGIhNGb0PH5oOh66RHV9RHZ;SY6EUYFASXj?SHZ8QHF7R8R6PGYeLg9bLg=aL75c
M75]K71dLg5_L7AhNW]nPhR>U9NJW9^IUYBASXb<S8^8Q8:4QXF5QHF7RXj>S8^;
SHn?SXj<RH=lMW1[IV5PHVAYKg9cLFm^L7R0QXR7QXV=T9BETi2>SXnBU9>ASX^8
Q7efM7AdLG1aLG5_JfYZK6e/JV]^LgAeNX66R8F2P7imNWYmPHF9SHj=RhV8QhJ3
P7eiN7YnPHF7QXAoO7f1Qh^=Si2@SHb>TIBBSX^<T9BFV9VIV9JBSHb>TI:@RXF2
OgYbJfMTHfEUHf5PHVAUIfY^LWQnPhF8SI:BS8N5QhZ;RXZ;Rh^:RXf?SXf>Si2@
SHZ7QXN8R8R9Rhb9QXF9SHn=R8B2PhJ7Pg]dLWIhNGYkOX63PWmmOh>6QH:0PH>2
PX>6RHb>Si6BUYVHU92<R8J4Ph>4Ph5nNg]kN7EeMgIdLgIlPH:1OgekNgYgLg1`
MGaoOW]kOGelOG]jOH65Q85oPH>1OgmmNgQeN7b1QXN5Ph20PH62PX60PHB9SHb7
Ph5oOGakNWYjOH22Q8F3OgYiNWYjOGn0PH>4Q8B4QHF3Q8N8Q7mnOh23QhV9RHZ>
TI2?RhR9RXb>T8j;S8^8Q863Q8B5QHJ8Rh^:RHV;SHf9Q860PX>1OGYgMGMiNWUh
NWeoOgj0QHZ?Shf<QhF5QhZ?TYBCT96BTHn:Q81nOGelNgYfKVQVIFQZJfYZK6ma
LgAhOXB5P8>9RXb=RHF5RXj=S8V6QHJ4PGmmOgegLg1bMGIeMWUjO7inPhV=T92=
S8b:QX>3QhR5PgmlOH64Q820PH61OWj3RHZ:Qh1kNW]jN7QhN7IdMGQiNGYjNGYn
Ph^>RHF9Si6DUIFHUY>AShn@SX^6PH60Oh1nO7QaL6m/KgEhNgakOH21OGf5QhB7
S8jAU9BDShN0OhJ:RXfATI2?SXf9RHR5QHF7S8nEVYnUY:2OWYbIUY>>RXJ2Q8J3
PGijMgQiNGQdLgMmPHJ8R8V;RX^<RhZ8Qhb>RhV:SH^7Q8:1P861OGaoQ8J4QHF6
R8F1RHb7RH^7QHJ8SXZ2P7aiM75gOH5oN7AcMG^2Q8>0NgYjNh1oO7enOGUjOX5o
OWE_N7EjOWQhNG]lNG=bLVe[KGMkNgf0QXV:QX20Q8B4QXJ8Qh9nN7EcKg1cMGIi
OhB3PXB7RX^8PhJ;RHN6PWimP8=nNW=/Jf][JfY^Kg9eMg^3Ri2:QHZ>TiNCSi>E
UI><QXJ8Qh9nNgYiMgAdLG1^JFU^LW5]KFmbMg]mP7ejNGf3Q8F6QXV;R8R>SH^9
QhZ=SXV8RHB4QX5jMgUhNH25QhV8QH62QhN6Q8=nO7amPX>2Qh^:Ph67T9REShj<
SIBHRXJ?V9N8QX5lOG]iMgYlNWn4Ph>2Og]gO8:1P8:1OX20Q8^7Ng]iMWMfOHB4
P7f4OWEjM75eNh1kKg1oRXV4Ph^?TY:>RHN@U9JGTXj>S8>0Ph1lMWN2QhJ8S8b5
OhF9QgmlP8B7SI6?TYF@THn8QhF5RXn@RgagOh:6Q7ifKg=dMgagNH:6RXF2Qh>1
QhN4QXV>THb;Rhb?SH>1QX>3QHF;RXZ8Q8Z4P7ihM7AiOGUbKgIhNH29Rh1iNGZ3
RH^@SH9hN8>:R96>OX62Q8F7S92FVYJCRH67RXJ5OgMhNGj2OG^0OWQfMg]lO7n5
QXB<RWYhOG]jOGinPXJ<S8f5OG]oPH65Q8J6RHj;S8R1P8N;RXJ;SHF;UIN?RhZ;
Shf8R8QmNGUcLG=hOgYgPXZ7PG]oQ8>5Si6?Sh^5OGR7UHIoQ8B2OW^0PgadKf]]
M7MgMWA`Lg^1Q862RIFHY/;6Wh=mM7A`KFaXIEmIHEeIJW9RCTU>E5=AFV=SK7io
OG^4U8enNhVP/kF_/KW5c][Uck:e];>iZiV@SZ71fM6UOg9iPH:0PWedLFmWIFU]
NHF?THQ_>A/gEEiFF7ZLU6e9?cT`:AdF6RPlBdLn=B/W7Q<B51D@4aTN93<o@dUK
M7ieKVegRYfTSWb;Zk_8cm3;b=O/i/o=e^3[k^oWhMOIh^7Sh>?joooB/nco[W;=
o^7;ZiRXZhRJ_[RW[jbeYgj8XXb3V9ZTVXVPXG]UP9fDWIFK[:nDQj:NPg5kRGaX
JVaXF5E6:b=4JeMCIU]7EEPl=SPn?Rl_?3TZ;Ce6@TA;?cQ;GEIKHEeKFDle=TeC
EC/a;R/X8RDT;CA;D40iDE<h:390Ce9AEe=NGE5EGeIHIfe`PHb:QhN;UjJMU9VN
V9FFUIRS/kRa]/gFd=38bMCLgm_@b/kDd<>l`;c4b/75d=[IeN7RgnKI^l7Nf]?9
^<;Lj=gWo?oooooon?3Vi>W_im[:^[W4f=FjYZfg/;2i[iV]_;BUU9NJUI25O8J5
NWYcIUmcOVeSHF=JFE9>DeQ?AC@U8R<[;AhD8C4W4Qd[9B0[90H02ATH2`006B0^
:aXF6AdP70/D7Q<D7bHR820Z<BT]9Ce@?3a0D5EBBDY:=cM<CclnCUISFeMKD59/
NF]TJg5mQhR3Q85iIF=fSIb:IfAiW;JVTI^Z]kNi`<Bm]k[?i]k9aLg:f?3jl^__
k_?ooooooO_knoCfooobiN[moooQino`oN?4alB[^mGGbK:/Zl7=W8fGT9:PYib]
`;^eZZb`YjZUV9nYXYV>PGIVLWYbPhmeHVERI6]YH5A@DD=@HeU>CUE?@chg=S]0
@3Xg<2HT:c4/;3@]7aDQ;BP];A`K9BTZ9bd_<TIDEU9BDdE0ATiUJemQGEUPJFaS
CD=8E5I>BDaAC48kAUUYK5M6@TE@FfEXG5]BCemZKW5[M7Q^N863PXF;UJNi]InF
Z;ji^[nd/KFl_;Bg`kVhd<>V//o@alGDdKjm`M3RhLo5bM?EeM?5`/O<d/Zf]L?6
`LK;^k2b_<W;_KJncmgCcLk6cmgLg^;OdmGKfMgKb;k>d<6e`]OG`JfZ/ko0^k2U
XIZEWZ6BSi^HRX5jP8b:R8Z4KFU_LG9XDdQ6?3PlA44j?DY=?STg<S4]<dM?DE56
>4QNCc4Z<3e9AdU=D5EKIfI=<2`];CM4DDdh9bDY=S4Q6b4Z:34]8b0L;C@Q9CM0
>C91ACDeAEedHUUjRhR2MW5nR8nFVIR:NW=bNi6QUgakPgMQIXBIVibEQH6=VI::
RI>MTXYnPX>7XJFEQXJI/J^OTH^IW9fY_<:fYYRDXZo0aJjW/;Jh_<O?cKJWX9f`
^:n/]L:n_kJNR8:JYhQ]N8jX/:6MWI2=VZN_[91ePYFOVXf7P7ImPgi]IWM_I6I]
MG]bIh>FOVa_Lg60R8V0N8N0P8j;R7YaP8AkM6i/Kf=JIFYNFFIZHEEFIgATEUaL
Dd]6B5IPGVALATA>D5=NI6AA?e5]LWIkLeY8Bdm@F5aMHF=RJW^2N6iWMhf2K6ab
O8fOXI:4OXfV[j^JUYVO/l;:^JJf]:Rh_:Zb`KnYSiBES8^?U9RRY:BSV9nc`/Jb
/[o0Zj:TWjFY]LO9/ibMXjJe^JZRWiRX_[fl^:jZ[kk:ck^/ZZ^_Yjff[:b`/K2S
RHf[/Zn^[Z>OX:2MQhZDP7^AYZJQV8fQ/9fKYjBHV9^DUj:TXZFKTiN8Qhb3QGQZ
IVMUG6AcMfaLEE5IJWA^FeQOGEMKG5]H@c4jDf1=@E1JAS8i@3e?GE5:C4e5?T99
Ace2CTPn@4U?DUQRJVQLFF=[J6IZIf1YNH1oO7j8P6mXN8fNZ9B0Phf@TXZ5RhN5
QY2JShF;U9F8R8n?UIR0MXREVJ>h_:^JPWN7XK:XSH^FUh]iMhRLXjBGP7MfQIjO
WZbUQ7NK/Z>KUY2=Ri2KXIIkJgF4OW1dOWeiMGF1PgQiQY>6NH69QGQgOXV?RhUi
I6a^I61LGfQWGe]EDTmCI658@deDF55=BTA8CeICBDeNJUa:D5==CE9IGU=1@4mR
FTU?FEA<D51;BTQAE5=QH5UUJUe@Efi^JVMDDV5UH5QEEUaIBTaHIWIfLg5`LG1a
KVE^PHZ5MgB4RWaaKh2BQW5eT9RBU9ZQYK?1^jRLXZJMTHnAVjZYYk6`/;Jf/jnk
akna/;Zn/JNZZZBOYK_5_knm_Ko1a;bja/Rk_LW4/Zn[WJ2TX9nX]KRf[J>X]KVj
/inS_/g?c<S6`lS?bL6k/ZbY/Kbf[:N`/jfVXZBRYIJ9TYVGTHR;X:B@SIRSXI67
PhJ5Q8InO7moOX26Q7YaMH::SI:@S8MhJ65YKViaMGn0NgAgP7]YGVQbLgIcK7F3
P7mkHVIkO7QeKfmdLg5bN6m/N7n5Ri25JfQoQ75_LEeJJ7AdLgQmP7IdNgekLgV;
QGYgNHR;S9:HW929RhAnNWajNGijOX5fOXn5N7^;UY>AS7]bN8>FWYF<QX1iN7n2
O6icQHf7L5]PN860Q8>2U9f6Mg]kP8AgNXRAVYbGUYBJWin>MH:KWXYdM7j0Lfib
LWQnO7a_KGf1NgI`GUEOKgA_KgN1MEiLHfEXGde:DeiWGUQUHUQGFUeJFeUFIWA^
KWYjKfYSG69THf]^GTe;DUYODdiMGeYPIf9MFEMTK6UTFEMDDUeLDeMLEdi7DfYa
K6UUJFARL7QeLFe_LG1ZGf=dM6][K6MVLgUfM75dMfmZL79^KW9mPWM]M7aiMX>?
TXZ4SIRKUiBIW9:CTXf?RX1mP8J=Ti62Nh66R8>3UZR[YjBLVIbNZ;2_[K2d/:JT
[:VKVZ^c[jjZWY:<TYbOUY>KY:6OXibIVZ6WYZ>PW9R;PhfCT89cPYJES8Z<RhfI
YJ>JUi29R8^:PWn7RY6QXIJ?U9REUI>@TI:GVIJ>Qh>0RY>>O6mhO79/JFikRXf5
QH1fMWYiLfUYMWEaL6Y`O7MUHF]iOgemR9RGQh>9RXB7SHF3SIBLU7mnP863PGik
MWMmPXb:OGj0QiFEQHBDTXZ<SiZTWi>@UIJDUY>6OhF=S8J4RHIjMGfDW9nTX9VB
S92BU9bFRHZ@TIZSVi6>S8bFXJBRWZ6SVi6DU8J5TYRHV9BCVibBU:NZYJBKUIfN
UY>BT9:EU9:>Qh>3RXIoOX6CVHEoP7j4QhfIW9:6PHF4R8Z7QgmkPG]]JVmbK5eK
JgE`KW9bMh>3LfeiOW9YJ6e^JFY^MWI]HUmVJVmdMgM_Jg9jLFagNW=XFeMPJVe]
I5UPKG1^KV]QFeePGeiQIV]YJG1iNgYgMWYfK6YcOGidLWUiKfU^Mh1oNGAcLfm`
Lg1_JV5ZOhV4PhZ9PhB8SXn:TIfTZ:JPWj>QX:JUXIjGRHNFV9:>T8f8S9BIWZ2K
ViVCWIjETYRNViZGShnFVYjEO79kRYJCTi^NVYR@SIFIV9:6QHV8S8b7RH^;R8B;
THn@T8Z8RHN7Q7ejOX9oMgIjNW=^N8:3R8MnLfY^MW5]LgQjOWUcM7EbL7AiMgAf
N7UoOGIbL75`LWAhOWimN7EgMWIeL6]YK71ZHfIXJfUJD55DG5iPI6=XK6YUHfU]
JFUYGe]JFF9VHf1OHV1IEeYJG5YCEV1THFM]J6moNVm[KGEiMgQoRHV5PWj7SHfA
T8^;SX^9RHJ8Ph6:TiZMUI:CTiNJW9J:SINGTY2DVY=oMGb6Q7alNgYlPHbFThj@
S8N3PXV?UYRGUYNHUXb9TiNAQWf0QXF9SHb7OWf3QhF0P7j1Q8>2Q89lNgn2QXb=
QgQ_M7b0Oh68SHZ3RIJDT96DVYJ@Ri2FUYZERHJ7S9>AT9JJThV9Ri2BSI6DQ7Uo
QXB0QHJ5QX>5RHjDUIFDSHB1QHZ=RWiiOX1hKfibLG5hNg^5SHV2QH^9RYFITi>O
Y9jJU9:FVYJ;R8n@SH^AVI63NGYmNGQiPXZ2PHfHViNIViF>Pgj6RHN8S8f?ShIm
OX>8RhEjPXfAVI>9Q81oPH5nQH^6Ph^CUI6@TiBHUHnBVifGTi>HW9F<QXF=Thn5
Q8IoPhb8O7EaMX23OWEfOX9oOGiiMWYhMWf6QXJ6QHJ9RH=nPHjETY2>QXB9Qh=o
OX>9R7mjNgakO7ekMgR0QXJ2OGf1QH5kNWf1Q8AnLW1iOWikMg=bLVmXHVI/KW5j
Ph5nPh>3QhF0OWijNWemOh63OWAbLgIjO7enO7emO7mnMFm^LGAhMG1fO7n2OWUi
MgIcLWEjPhJ4PX5nN7EdLfm[K6i^LWV2QGijNGYjN7IgO8JAUiV@R8^>U9NDU9>>
SI2DU92:R8J3PXN=RhJ4PWn0Q8B4PgegMgf4Q8>5QHRATHb>ShnAUIJBU9JCU9J@
R8Z<Qh>7U9F:PXZDTHn?S8b?Ti^NUhj;Qh9mNg]kP8J6QXJ7R8J7RXN1PHB5PGaf
MWIgMW9`If9XL75cMGAhNgZ0Q7efMWZ0Q8F6RHR4QHAlNWQcKFadO7alP7mgKVUV
I65PIfi^LGAcL75dLW5bLg5_L75fN7QgMGAbKF=QJW5dLFa^MGUgNW]fLg5[JFi]
JF]bNG]gM7AcLgUoO7MgO7eiOX5lO7UdM7EfNWinO7f2QhAnO7j0PH>4QHN7R8R7
QHN8QHB7Rhf=TINFTYBKVYBATiNHUiVJViVFVZ6PWInPWYbGTH^8Si>9PGejOH67
RhIoPX>0NgQiOH21P8:6PWenP7ecJfY^M7UgMGEfMWIfMgMdLgZ0P7ioQ8N4PH1o
OgYiPXV;Qh:4QhB2PGimNWYoPhJ>THj;S8j8P864PgikPHR<R8B8RHAlNGanOh24
QhZ=RXF6RHJ1OhF<TINJVIZPYjFLU8j>UY^LXJ>KUIRGTI6DT8^9QXR@TY:ASHV6
QXR7QX:0QHV6QHN8SY26O7^1Qhj@SHfBV9nQViJFVY^GTY:BT92@Shj>SHf;R8J7
Rhb8PGemNgUhN7MjPX>1PWmiN7anP8>1NgUmNg^2Ph21P7ahN7b3QhV9QXJ5PWek
O7n3Q85oPXB4Q8B5PWmnNg]jNH2:SHEmOGeeJVadM7=gNgf1Q8>2PGYcLWIhNGYk
PHB2PH5oOgQ^J6eeMW=aLWQlNWMfMWQgM71aMWb0QHR8QH>4Ph:3RHnATI>CUIJA
SHZ3O7j5QH:3RHZ5OGEcLW9bLG5`LGAjO7UkOgmlNg]kOhB6QXB6Ri6ASi6AT96F
UI2>SXj<RXV5P863PX21Q8F2PGmkO7]gMGEcL79bLW=dM7=cLW=gMg=aM7UiM79g
NgMeNX27S8b9RH^>TI>CTi>EUY:?SXb<SHZ6PhB4PhB9TIBCT8j=RHF3Ph>4QhbA
U9FETXf:S8Z5Q8F6R8V:Rhj@T8jASXJ1P868SHb7Ph:2PX5nOH22PHN=Si2>SHn@
T8Z4PhJ:S8Z9QhB3Q8:2PgmgM7IgMgQiMFiWHf9RHF5QI6U^LgIgNWYjNGUiN7Mg
MgUmOgilOGaiNWakMg9aMW]kN7IfNWemNWYmNgYoPGmnO7MhOX1oOgilNWIcMGMg
Lfi_LViXHf9SI6QZJfe_KFecN7aoPX9lNGQlP821PXB7R8N5QXV9QH>1OGYlP8N=
RhZ;RHJ4PWmoP8B8RX^:Rhj?T8n=SI:GVIRBSXf=SYBETH^8QX5lNWj3QHF4QXR5
PX:6RhnATYFGUYVHTHZ8RhjATiJFUiZJUiNESHJ5QXV8QhZ<T92<Qh9mNgemNgEa
LWMjO7f0PH60PH:1P822PhJ9Rhb<RHJ6QhJ4PhJ9SI6EU92>TYJETHn>SXj<SHf;
QhF6R8V9R8F2OWb0P7UeNh>7QGijNG]mO7]lP8>1OgehMgUkOX1nOH67R8R;Shn;
R8B2QHJ3OgalNgalOX62QXZ9QX9nP8F8R8V?U9BDU96:Q7moQ8R5PH62PhJ8QX5l
NWamOWekOH23QXAnNWMdM7IjO7enPHB5QXEoO7ioPHF7QhR:RhZ<SHR2P862PH20
PH61P7moO7YiNWQeLg=aLWEhNWIaLG9aKfYXJVicMgQhNgj0OgekNWYlNgUiNGUh
MWAcLg9bMGQkOGakNgUfMW^0Og]gMWEeM75aM7=^Jfa^KFUUHfAVIfQ/LGEhNWYl
PX>2P7f0QHV=Si6ATI2>SI6CTXn>TI:CU9BFVYfMWIVFUYVGTi6@T8n=S8f<RHZ:
RH^@UIZJV9BCV9nRWYRDU9BCSHV;SHb9QXN8QhJ6R8b@TY:AT8j<R8B3Q8N8R8Z?
TI:BT92BTY2AUibNWj2LVINBSHb;QWmlO7YgLg5aKfmcN7b1P7ejN7UjO7j1Ph5o
OGUeM7IfMGEdMGUnP862PX63Q8F7RXb:R8V<S8N2PH1nOGYgMWIeMWQhMGEgN7Mf
M71]KVm]KFi`L6aVHfAXJVebMWQiOH:7RX^7PGmnOh63PGejN7QhNWamPHB2Oh22
PWioQHfBSXJ1PH:3QHJ3P824QhJ7R8V:S8j@TYBEU9:@TiNGU9:?SHb9Q8:3QHN9
RXR6QXJ4PhB5Q8>2PH:3QXJ7R8J3OgelN7IgN7MdL6mbMGA`KW1eN7QfM7=eNWio
Oh23PgeeLG9dMWMhN7UkO7akNGEbLg=dMGMlOWinNgMhNgj1Q8J4Q8J8R8J7QhF5
QXJ5Ph:3QXJ2NWAcM75^K6a_LG5_Kg9eMG=cM7AeMWMhNWamOX23QXV8QH62Qhb?
T92ATY:CUiVKVi^KViVDTI:DUI>@S8J1P8>8RHN6R8Z;RXZ9R8Z=SXf=SXb8QHF4
Q8B3QXb@THn@U9RKWYnMVIJFUYFBShb9QXN8QhF5QHJ6R8N4Q8V?U9JDTHf<S8Z7
Q8:0Oh64QXN5PX63QhfBUYNFTY2AT8n>SXf;QX1kNgioO7QeMGIiOX>6RHj@SXb:
RHV;T9:CTi2:Q81nOWimNGQjOh:2P7ajNWYiMg=bLg=aKfi/JVYYIVASI6U]LG=d
MWYlO7alOGejMgEhNGMfMGIgNG]lOGmoOgn0PXF6QXJ8RXMoNGIdLgEfMG9aLW=b
KfaYJfmaLgMjO824PgeiN7UkO7j0PH62Q8N9RHF1OgioPhR=T8b4OWenP820PH:0
O7QhNW]lOWejNGYlO7j2Q8>3QXV9RXb:RHZ?Ti:@Shn?SXf<S8fAU9BBTYBEUI>>
Rh^:R8V:RhZ:RXV8RHZ9QhN8RHZ<SH^7Q8:1PH61PXB4PX61Og]gMWIgMgIcLgEh
NWYjO7moNgQhNgj3QXJ3P7n1Q8F4Og]jNgn2Q8>3QXN7RHb>Si>HVINETi2>SH^:
R8=lMW=cM7QiN7IeMWQiNWUhN7YlOH25QhF5QHB3Ogf0Q8V<SiBHVINDT8f>TI>C
TY>EUI:<QX>1PH20P8:5QXR:RXV9QhJ7QhV9QXB1OgekN7MgMgMgNGeoOGf0QHV;
RXV:S8f<RHN8QhF3P7mnOG]jNWf1PhN=Shb<T9>GVYfMW9^HU92=RXR4P7ioPHF7
R8R7Q85oOGj0P7eiMW=bKfaYI5iKF5QJGF9WJV]^LgAdMGAaKVi^KW1bM7AdLFi/
KW9dMWMiOH22Q8=oOGinOGQgN7IfMGIfMG9^KFidN7QgN7YlOh>6R8J4Ph1nOh:3
Ph>4QHJ8R8F2OgmnPXV>TI6?SHb;R8N8R8J4QXZ9R8R9RHR:R8B4Q8J8RXj>RhJ2
PXR:RHN6QXR:RhV9S8j;QhN:S8n?SXn>S8b=S8^:R8Z;S8f<RhZ:RX^;SHf=Si:B
TI2=RXZ8QhR:R8F4Ph>1P7eiMWMhNX5mL7EfN7QeLG1]Kfm`L6mbM7AhN7MkNgel
NWaoP7mlOh:2Ph>2Q8:0PhF7SHj?TYBDTi2>S8f?RHF6Q8R8RHZ9QWmoPH9nNgUi
NX25P7alPGifMWIbLgImPHB9Rhf?TYFDUY^IV9^KViNGVIRGU92:QHF8S92ATY>D
UiB?RHN9Q8>7RH^<SI2>RhV7Q8:3Qh^=TIRLVi^GShbAUYFBTHj<S8b>Shb9R8F5
R8Z8QhR9R8F6QXF5PgmlNGQfNGimOWikMg=eM75aLG1_L6aZJfa^JVQUIF9JEeMK
Gf1OFUYNHfQ^L75aMGEaLFm^KG9fMgYhN7]mNWUgMgUkO7f4RXZ9S8b8PGaiMWQm
Oh>4Ph5oOGUfM7MhNGQhNWYmOgekMg=bKfm_LWEhOH20P863QHN9SI6FVYbJUI>C
Thn;QGemPX>7S8f?Shb8Q7mmOGn0Q8R9Rh^5P7n2PGagMWIfNWYnPH>5QH1jNWb3
Ri2ETi>DTI:CU92>SHb9QhJ5QHbEVIJBT8f9RXnCU9:DUIFEUYJEUYF<R8F1Oh24
P7QnPWigM7EcLW9cKg1cLg1aN7]nQHR:QH1mNWIdNWYgMg^0P8B4PX>4QHJ:TIJF
VZ>WXiZFT8N4PgegNG^1Rhb:SHn=RXV4P7n2QHb:QhZ5PgmoOgYhOXZ?TI:@SHR8
RXZ<T9NNXInLViVDT8Z:QWekNh67S92@U9JETXR5Qh^7QHN5RHf<RHB1P7]cK6Y/
LG=cMWYhNGUfLWImPXZ<RhV<Shb6Ph9mOH20Oh24Ph9oO7emOH60NgYfO8:0OWj0
OW]jMG5aKfMYL7=eLg9/JFU[KFY_L6]WIF=NHV1LG5YQKWYlOh9mNgUgL6]]MW]o
P822QX=hLWEeMh69Si>ASXb>RX5lMgQjNWYhNX5oOH63PWadLW=dLW5`LGYlOWee
KficLW5fOhF3QH=oPGilNGEjR9>GWIjJTHZ8PgYgO8:9TiNIUIFARhR1NWb4Ri2F
V9BCT8^7QHJ4Ph>0Oh5lLgAhMW=gMgMlOX21RYFLXJ2JTiBEU9>@VInKVY>CUIFF
UI2:S9:DUIfOVIVNX9VAShb?Ti6>SHn>QhF4PG]mPhJ:QGYaJVARI6M[LWMcM7j5
PX25QH9nNWMeMgQhOHB5Q8B1NWb0PX5mR9>MXIZEUYJCTX^1PXfBTIFERh9oRHf;
RHN8Ri>GTi67O7IfNWA`LGZ2QHN4OgahM7AiNgj4RiJSXY:=SY2?RhElNgUfN7n8
RXf>PgaiNgUdM7V6Ti>7PWeiP8MoLgAhNhF9QWI_LWMfK65OIG=jNGj5R8J9SXj8
QHJ7RHZ?T8j9P7j2QhJ4OWR0RHN0Qi:GV9NFUiJASHb?RhV6PGYfOH9nO7]jPHAl
M6]PGfQYHF5SJ6afOWMYIF]hO7UaJVmdMgQkNW=aLWAdLW9fPH^BTXb6PX23QhN8
QHB;Ti>3NWYjNGMhOH:3NWIfO8:2OW=THfU/LGEdN821NG5]Jg=jOGb1RXb>VZ:Q
ViFBT8j9Ph24R8R=U969Q8:5QXB2P8>;U9bQVXb4Ogf2Q85mQHn<QhN7RhImNWb2
PGn1PXJ=UiRBSY2FW9fDS8bDWJ>LTXjDW9^EU92:RiFIShZ=UibKV9BGV96;RHV:
S8V4P822PHB9Shn>RgicKF]_MgUaLWUjMFm^KW=fMWb3QhN6OWEeNh60OGM`LW^3
PhB1P8B2OGQjPH:3Q8F1OH69RX=jLg=eMG1]L7AdLW=cKf]VH6=VJViiP862OW=V
H5aHGVEXKgj=Thf5PhR<Q7j2RH^;SH^8SYFESXIoNh1oOh:5RHnDTXZ9SHZ3P8F6
PWmmOGUeM7EgMW=aLWAcLgInQXZ8QhR=THj;SI:JXJ6JUIB@U9VJUI6CShMoOXF@
UiFBTiJFU8j3OWj1P8:3OGj3QXV<S8N3OgI]Jg9cLgUgLg1aMWYhLFa`MWIdMgj4
QX9lO7eoP7]hLfmcO8F7R8R8Rh^6OGb3RHV>UYZIThR1PH1mOX65RH^<PGMfN7]h
KF5KGfUcNWQfNGQ]HEmMFeeTK6ieP8R:QX62Ri2=Qh>0PHF;T9FHU8n?SXN3Ph>7
Si:ATiFES8F6QGmmPXV8P7MbMWj2OgI`LGIlOWinP8R=TY>BU9BDUY^QXjJSWj6X
[J^]/JfVWi^IUiFEUj2UYZFWZZRXXi^HUYFHWYjKWIbJVj2NUI2:OW9dNgilN7Un
P7Y^J6IYK6aZK7J1QX=iLW9fN7QeL6e/KG1dMgenMVa]MGUjOX5mNGf3Q7icJfeb
MG9aLG9dM75^Kfm/J6ESHV=UJgEjMgEfL69LGEmMG61ZNH62P7moQH^;RHN:SI:D
Ti6CUIJIV9>=RHZ8RXnASX^<TiB@Si:>Pgn2QXZ8PGYlPX9kLV]YJViaLFmbNX63
Q8=oOhB=T92GW9N?T9NOXj6OWI^EShR2Q8jFV9VNXjBSVi2:QhF3Q8N5Q8N6QHV<
RG]]J6U/LGMjLf]ZJfaZIEmOI6]_KVi]KgAiOGekN75_LgMhMGAhNgYlOGQ`KWAl
OGYiO8>9S8Z4OWn1OW]lPHB5QX=mNGQcL71_KFibL71gO7QcL6aWI6IXIEeJH6ag
O7UdLg^4RHZ9RHR:SHnBUiZLWIfLVYVETHnAVZ:QUXj@UINETi:EW:2LUI6CUiVC
RhF2P862Ph>1P8>;T9:ETHJ5SYRKWj2JUYj[/k>[XIbNWi^FTiBKXjFTXj2OX9fI
U92:QHV>SHb<SHb;RHZ;Q7elOWimP7egMg]iLfaVHF5WKWEiNgf0Q85kM79eNG]k
NgMdNX1lMWA`JV]gPHJ6PWf0QXV8P7IcN7n3QhR1NgeoOGekMgAeMW=eMgMfMW^3
QgmbKFe/JfURGfE]Kg5eNGf0P7alPH>5RHf?Shn?TIJGV9>8PHF;RHN6PWf1RHb8
Pg]hOXJ8QXB3QXV9Pg]dKFY[K6iaLVi^LgEeMGA`JViiQ8N3PXB7Rhj>RHN9R8B1
OgelOWn0Qhf@TI69OGMhO7moOgikNgj4PgimNg9YKGQoPWmgKVmfMg9/J6Q]LGEj
NWQgNGYlPH>3PH1lNGj2P7inP85nNGEiP8N;RHJ7T9JEShZ5QHN9S8n@SXjAShZ9
RhR6RH^=S8b?TY6>SXb6PX:1OG]gKf]^LgAjOgn1Q8R8R8V7RH^@TiJFUYZHTY>H
Uhn=UIbPX9fIU96>S8R6Ri:@S8b>RhN6QHB3OganP7imPH:0PhN9QXB3Ph>4R8f>
RhbCVInTXi^GV9RETHn=S8n@TI>CShj@T8f@TI2=Qh>5RhZ5Q8N8RXV2OGn5QhF0
OGn3Q8:1P7]hMG=dNGj0Q8B0P8F9QhJ8Qh:1QHJ4Ph5oNgEcMgj2Q81hMW^0OWek
N7IgMgUlOgahMgEfNGYgLFe]MGelMWAhNgn3PGYeLFiZJ6QZJF=OHfU[Jg1aKfe]
LWV0PX60O7b4RhN2Q8J4PhF8RHV5PX22QHB0Ngj4Q821Q8>3Q8=oNgI`KW9eMWUj
N7E`KG5eLVaYIf]dO7ejOXF5Q8>4Q8J7QhZ=SH^8QHB7RXb>T8f:RXV8S8b3O7am
O7f0P860OG]nPXB1NgIfN7IcMWUhMgIdLgUoPXF6Q8>:TYNGTi2ATi:@TI:BTHj8
Qhf?S8^>TIBCT8n?T8n<SXn>Si6BU9JDTXj<SY2<QhZBU92AUIJETHV3Q8V9PGUf
NWiiLg5`KFibL6e]KfmcNGeoQ8Z:QH1nPXN9Rhf>SY6BSXb<QgegN7b0QHR8S92B
U9>=QhJ9RXV3O7UiO8:6Q7mlNG=aMWf1Ph>2QHjGVINEU9>BTY:CTI2@TY:CU96@
TiNFUIZPWiRCT8f:R8J5Q8:0O7QjO7agM7MhNGUhN7IeM7IfLFUTIVabMgQfLgEj
OWelOh1nOX61OGQeLWAmPh5kMGAhOGikMgEfN7UiNGUhMWQhMgQlO7IaKg5fNgen
Oh62PWmlO7agL6i`LG5cLg1_L79aKVQRH6I]M7YmO7UhN7YnPX>0OH29TYFETH^9
SY2=QX>3Q8J6Q8>6Ri6EThb5OW]mP81oPX>0O7YgLViZIFIZKg9cM7QnOgn0PH61
Q8J6RHb>Shn:QHN<Si6CTXj@UiVGU9>?R8>2QHN7Q7igNHF>SHR5PhB8RhZ8QXF5
QXF3PGmnOWn0PhR<SHnBUIRIUI2@TI:@RhV;T92<R8>2QXj@SXb;Rhf>SHj@TI:E
UI6<RhR3P8:3PH63RI2EV9J?R8N9QhB4QH>0OgagMWIfMgUgLg9cMgaoPHJ;RXJ6
QXN:RhV7S9>HV9JEUiRFTi28PH23QXV=T9:CTXf7PGj2RXf8Q8:1PHF9RHAkLg1c
NGakMWAjQ8V9RXV5QHV;SHn?SHj>S8^=S8Z7QHJ>U9BBT8n=RhIoNWQhMgAcLgAc
LW1^JfU[KW1`L75`KfeZIUmIEeMGF5iTJ6]_M7AbLW=eNWmnN7=bMganPHB1NWMg
MWEcLG5fOX:1OWalNWMjOGafL6e/KG1eMWQmQ8J5PWihM7AgN7IdM7EcLG5bLFm[
If9RIg1gNWanP7ijNWj3QHF5QhnIXZFQViREU9BDT8b<SY6CTi6AU9:?S8Z:RX^A
VInOViNFUYB@QGYhNgelO7anP8>4Q8B3Q8R:SI6EUiJETi:BTi>@S8R8S92ATiFF
Thn9QHN:RhR4PH62PhJ9RXN4PhB7S8b7Ph:1OWelN75^LWQlOGanPHB7R8F3Qhb>
S8^:R8R;T9BBS8R6QXN:S8^9RXb;RXb@TY2>S8Z2NWQkOhB8QX>4RHjAT8b6P7el
P8B4PWikMgAaKg1bL6m`LFi^M7^4RXZ6P7]kOh60Ph^?TIBGUI2<RXV9RHV6PWn2
RI2?RhN2O7UlOh63R8n@SXb:RXZ;QgeiO8:4P7YdLWMlPXJ5OWQhOHF<SHZ8QhJ:
TY6;QH:3R8b=RhN5QhJ1Ng]mNgYjNWMdLW1_LG=dLg1_Lgb1P7ehLV]XJFIPG5iQ
HVAYK6e^Kfi/KG9gNW]kNWYjNgn4Q81lNGIdLVi]L7=jQ8V6PGn2RHn?RH5kNgmn
OH24Ph61Ph>1Og]hN7]mOGYfMWYmO7YfLg1aLgEdMGYnP820OWenPhR8QhfGWZ6R
Xj6NVIJEUYNFU96>SHj@TY2:QhR:RXR:SiBIWIbJVY^ITXf<RhZ9R8J3PH61PhF6
QhR4Oh68Si:DThf:S8n?S8V6Q8B5R8V6QHN8QH>4QXF4Q8:0Ogj0PX>4Q8F6QhV;
Si2?S8Z9QWmhLg1cNGenO7alNGMjOh1mNgUhNgn3QHJ8RXb;PgioOWn1QHN7QhJ8
S96EU9:=RHR6QhZ<RhR8RX^;RXV8QhR7QHF6QH>2P7ehMG=aKfibMGAaLG=fN7Ui
NWenNWIeNX26RhnATi>@RH9oOhF<SXZ6QH:2QHN6PGemOGj2R8b>SXn@TI:CSHF1
PXN9QhB1OWemP8B7Qh>0P864QXV<S8^=Shj8PGinPHJ7Ph64R8IoNWQjO7emNWMf
MgQfLW1`Kg1`LgEfN7j2P7aiMG1/JfUSGEUIGFA/LW9^K6icMgMdLGAiOWmoO7Uf
N7UeKVQVIVQ]MWeoOGakO8:7R8F4QXF2OgelO7j2QXR7QXB2PXB7RXZ7Q8:0OG]m
OGUeLFi^LGIjNgYgMGAeNWimO826SYBIWIZFU9BDTi2>SY>HVYZJV9FCTi>>RHF4
R8nFV9FFWJ>TXIZDTI2DUYJBSXf=S8V7QhN4P8:7RXfCV9VIVYRDT92BTi:ASXZ9
S8n?RhJ5RHb?Shj<RXN5QXJ4PH63PX:4QhN4QHR>T8j7OGQiOGahN7]nPGmlMWAf
NWejM79eO822Ph>2OgekN7AcMg]oPh:0O7]nPhR<SHV3PH:5QH=oOWmoPH5oNWMh
O8:7QH61PX1mO7YeL6i^Kg5aL6e/LWEaKFa^L7=eMWAcMWf5RXf>SHZ5Ph60Ogn3
QhV:Rhb<RXR6PGakOH23QHF4QXV=THj:QXF8RXb>SX^6PX61Og]fMg]jNWanO7Qk
PXV<RhJ1PHR?TI2>Shj=RhN2P8F;SXj=RhN4PX20OW]gMGIiNW]mOh62P7QdM7Ae
MGMcJfM[LWEdL6e/K6a]LWEfMGIlQ8=nOGn0O7YkNGMhMgYoPhAoNWj7RhR8QhJ6
QXJ7Q862PH22Q8B3PWn0Qhf?T8f7Q8F7QhB1OWmmNWUjNg]kNGA_KFmcMWUkNgj7
Si>EUIB@T96?SHbAUIJHWJ6NVYJBTYFBRhN9SY2AT9>HVYRFThf=TYNIVYZHU9>>
S92AS8=oP8>5Q8N>TY2<Rhb<RhZAVi65QhZ>ShZ8QhR<Si2CTY6BS8N6Og]mO7Uh
OXB5PH63QhZ=Rh9lOWijN7YnPH1mOGQaJfUZIf]^L79bLWQnQ8J3Q8B4Q7mkOGj2
QXB0OGf1QH^CT8R7Q8>4PX64Q8:0Ph=nNGQmNgamOh=oNgYoO7IgLg=bM7EaLgEd
KfQTHf9TIfMTI6MXL7UkN7]oNGEgM71fNgalPH>0Phb>PgUjO7IdNWYnO7QmPX>0
Ogb1QhN:Rh^>Si>ET8j7QHJ3OgalP8>4P7YkPHF2PH:4Q8^@RXN8RXnDSgmkNWn=
SXnFThj8QXR3OWahLgElOGUmQhJ3OG5eMgMhMWQiMgUiNGUcLGIeM7ElNg9YL824
PhZ?QGj:Shb8PhB9TI>;RhV=VY^QXiVBS8fBShZ;QX:7QGn1PXJ3PX=nPhf2N8>1
MX1lM7QjPHQdKhBFTGmMLHMaU7AaTGE`Ph1gVYZ/[hZ/NBi[RFJ2ZH=mV9RBTH61
SXa`HHFY/9F5Phn>IemaNYBBTIn9RZFVUXbLWHf:MXN^YWMhOgB`]HEbMH:FYj>L
V829VIFFWIRDQ7N;TJBdT6YiVKBSMG9lKg5nQWaVJfYdTHYnQXMoOW1LKH=gEEEc
MDm/N5mTKfiJEG28H669QH^CWj5mNXB5Ti9jMJJoV82EW9^?RYF8SiZ=PVn9WIN=
M7EeUI]kM5aPNI6>JFJ2Rf9:LhieBfJ4P7=VJgMZHW=gLW9JJhb0RH=aKgJ0Mf9S
MHAoLFIiQ8j9MX6>WiYNEgR1TX1hOXR=RFi`TI6AWi:@O7fb^;2ST8fR/I5dM8j?
PImkG8:FUG=CJHR?NFJ<UVabR7YRP6]EIHbSLF]cPJFHIeZ6QgRCWWaJJZ6]RT]3
Rij>NFALJ7^9UfaGMGidK7Z8SGeFBUiZN79oWGI[UJVKRIFHMgR^VgQkP9>/]9><
U8VX/YN;RX^W`Ij7MG9mW;VKJGNRVh23TXfBRfMNMY24MG]fM8JRTh9cN926QX>3
NX:IRFfHZi^FK6b4ViU_Mh:6U:2JO9J^VX6`XVZ@Wi^0JhZEW85VOXR7L7VMN73;
hXY^[/:IQIn`VIV=M6]nQWmbFdERSZ:6HfigLi2TV85RGH5_D6YbEDA^T9>=Jf]c
NgI]OW1=L85`NfY^LE1;JV=YRX]6>eYFIH]WI8RO[IjMNTm?JEQINHJ3MW>8S75n
QfN0MgVTYHVUZ8QnSL6aR8:RZIQlRIn:R7QiWhMLN[JZR7MeNVfBVXAUGXB8NWIY
PYZEUZRPLfV7S6mVL6UQRI9GNIYoTXZ:O6ZHNEjET6ekNFZJY7McSYbYRFB<ZYEk
NH=mNGeL>6>6QIflVW^CZ:ba^8YbV[2VMEafV9MgLiMk?DQgRW]NG7J9U8R4JUA`
VYUSIg1jS8ZGPGBFM4n2PW>7Pgi2>IBiP6mjGeB5]j1QB6IfUJZGHe65/[BRSX9o
IeA_R7AVNI>_V75hLX2]/Jb?OG^Bi<b2SHnD`KfRT8jR^;^[V:FVMF^1UINHX9j@
R7ahM9BhV8VcZ8RHX9>@Yk2MQXAiLV]YRiUnJH9^J96;M6QkMeY:Dg:ETgf7R7N5
UYjCM8NKLdQPPg5THVf6Lee_OWbOXgagT8>Bc/6NWJR]XYZAI6RJWh1MBWB5G40h
AGN<Ng1PLIbGKV]dHE1IHfIAG81aJ7ESAE9fSgaRDd5?CEimGd5ADfYdCf=TFWE^
MWUNJfmcR81[MhbELTaVNX65OG:1OF1bN6=dQhZ0Uk^@KXnbbKnXXKVcQZ6kZjJ=
PJbiTHb<RW1lYI^UXZNMM8^SZJ=fR99jR:2DQgm`TiaoRHa/LGY[P9:LNfidDgJG
YIEZKW=ZJGn5Hen6S89fFgVASh>@XgEh/ifI[XEZHgRKYWm>LZnZY;RcTJBaZZn]
][:XZH5YU:NLU8AlN8n_TGEdW:VMUIVUUGV2Z:JHOXBLUY^GW9n<TY6<V8f=QWF9
VijARH^3LhMeK8F2KVfVZGm[DeIgSjUgBG9mIV9hPUQAQH5=EViPJgb3PXRWV79i
R8=kQ:BMLgJ4KfZN^JJ=S9EjHX:IX8j@T7F3V8aQLgB0Uh5UFW^9J665QEAXU8aQ
EfmFCWb7M6=8DgZ1DSE1G6MD@eI<D6R1P4A3Kh]VCf=]IGMnKeA;IGmUCUE>Q9Io
PGU?CWbc`hAjX8ecRi22M71XK9FBOH9U?DN:XV55J9FFOX6FWW=VNh=nNfiZNVZE
Td]9K8FHR8:GOf1YQI>:LVY[K7J;QedmIij@JVieIfb;]jm]FgN6M5maOWIkWY9H
CG64QYZGOX6^cZ2>[iRPin2kYK_MeK>GWk?Ab;6PY:JV]KJaWkW^gk[0Y9Bf`/^W
RY>M]<ZkXXMoVK>oWHA`IYJdVY><K62?[HUSR[RVRY26LHJMT7QnT:JKR6]QW[2H
P7^KX8nDT6ahPGn>UhemRiZ3U;JSVI>J_<:SUIVQUWj8SFU?JYB2G6B1KFQhPW5`
OYVRPEmVWIUhSHm/MXbDRGAaOfe_LWihCE64X6e@J7QaLhAXFFYiRh]kI65VLG1M
H7AZEdYEDDANHBlcBB0Y@SdiC6mdGeEmR79/K6QSIGVCTFm?EfUkLW:3MEmRLWAe
OGN7N6F6NFY_OGQkT81ZMiIkKHbNS8=mKGZ7QEa5Gg>BXgMXCDn5VW=KFU=_O8J=
MV9QGX^TNfMmKUmgViQ]LH=hJ6QnLVeiP8V5SiB1JH6a[J>WQXZPYK>POXNGW[V]
KU]aOYRNRFaPN9F]^J5oVjZRZYbJX9^K_L>@MhbKW9FJVKBYNiZUThRM_Hm^N:>f
PFn6X;2TW9^<LHkRcGN8_Zj3MIZEQHn:PHV1O8A/M:JYWi5dU[V_X9ZL^kZc`l>F
Tk:UQHfeYHZ3TY61QhVUWHBL[Ij<T8F5ShAgOXUgOWifOhfBOVeiQWU^He9KVImK
=4eYGXN>DT]UM7ifGVQfGDaeUVi[NdXWF8n6MW9_MVQ@GWAaJ5]SCTQhQVI5EWAi
KfagQ9=nO8]iLfUUH5AEJ5mHH6QaMEe=F72:MF]^K5egWHZ<RgM[Ri^4L75aJGR1
RI1eKXR7LXVPKU^;Y8N:Ui:BTI29M6IaUYZ4PgESJ8>5LHMkEE5fNEECF456P8]f
QIQeH86MSIVGPXR^`J6@KWBa/Y:FT7ZG[ibOZYb8SIMeT/VOM8V_^hEQWkR4TLFn
T8Rjaf]FX:Z3O9nYY:BPRX6DRY6ONEn>ZZnNOWIePJ34VE]]PY>FUI68RI>OOWN5
PXbFUhf;VjJGSYjVWZ^LSjNfYY>V]In?VI>NZ8YOMI>BUWIJOXb6PhV7KhNURFJ3
QhJAOgmgLgUTLWaZMXQkRXeeL5mkRWAlFTQTKfajShAfGeYkPXB2T91eQ8M[CGFA
GdmWIV1BA5=WJfMmMf]IFgE]LY>OP7bCUIJHPgEaLG5gPWAdOga]KGadP8U/KYRa
R5IFKX:6MV]XLViNK7=iJEEJK7YTHfE/JV]SGV1;DVQeIVecNGU]L5MHLGNBRgEW
J7QhHWj9JXJPTGYVMhf4IUQoUiJ6KWF1Ri^JNW^=ZkR^];BNS9J@RiB4Q8V1OiZC
OiR8SYj;Si2AVXmkY:bM[:VAQibeZh=iSib@XKBUThFGYYnMR7F<_Zb7W;R/SiVM
VYjSYi><XJ:LWIjQQhbGUWeWLFaZLH:0MGf<Q8>2S:JDP8nR/:>N`Z9`TZ6DRHV9
QhjDXZb^[IIeLYBYYY^JT6mcXZ>5UhmhPiBOWjNFIen4Wh1VJ6amUHR8PV1cP7Q]
LgATFE][OGUeLF]dMGAaIEAeR7APLhA]LXAfE5I/N7bFSVYTIWN;ThR0Ng:7VHEe
R:VLPHJEMfEoGeY^N7APGUU=LH1_L5eDL81/P7i9GXR:EcYOGUAJIg5ODU^1QV9T
P6iAFVETGf1iK69KG7inG4]]NG6CWg5MLg]]KVE9IFUHH6IjQGabM6aFGgf0Ig>L
XY>CW:2NTHF4SIB@PWAlTIj_ZX9kQYBIU:BgX7f@TXJI[jj<N8NPYhQfUZJPVYRL
UHEoUHmmP9FCP8AnKgZIRWF2MgbAV8]kShj?VH]oNhB>UI^KWIBERhJa]Hj>Th^=
UIZKSIFWW9>D[;:/WZk?_;BkUY6YWiFCU8bIWZRdZJNESY22TIUnN9naVHbHShfO
XX9^OhfCWIQlMJZkTGR0LVN0S:FQSF]IMY2DQGYlLWB7Q7meQ85eOX=fGUIPE51K
FTe<FeE>FVA??F9]JFYdThYaLI>ZNVI]EeelNV9aPiRMSHM`KhZ3P9F=Jg6ATXIg
OH21ShJ0PgmdNXeiOhITBEb0RhicGF]cJFYiHe5WIf=LFV9NHf]dPG5EGVUFIh=d
JW9fOhAkGd]PLgA_N7]gP8AlLgR6UiV=Q6YcTYj_X9:PUGA_Q8n?RHj>MVN2Pfa`
OI>CUGaMNYNLUY5fIGj<Ph1dDf5fMWF=YI5nNY:BNfIYR7e`R85[OHf<SgmoO6mo
V:BPX91cM6m^L71lN7Z5Rh]oOW]bRib2IGjf^IbT/J^e^[O4]YBB[ZjCXl:fZZV_
_[JL/kBN^/BmV8Va_K>mZ8R;ShF7SZBbTI2PTiRKS7^5/j^5Nh>FTiFLOW9kPY6:
OHBHXi]jMHIcKWR2QHN6RgMLNIb@PH:6OWb0MGJ1OFj6VhmnQ7j3RX6DUXB6X8UO
GG9bIg::S5U?K8nSS7=[Kg=dKfM^P9J6JfAgRWYTE69gN7>6PH29P6UiSWebI6j1
T7eOGf]hQXA`GE=XK5==IgieFe9DATUBBT4j>44n;CE6DEDj?da<EEQTLhJDQ6U/
Mg9TH5IEK7UhNGJ0S8b4Ph:1TY5nO8j?O8b_X8:3Qhf:PXF2SYfAP8:4Og]iP8F8
W8mgLHBVV865PGQ]JWeoO8>4RWIfSXecKH>@RY2DPHR6L8NSVX1kQ9JQYZR=OYRc
[Yj:UZJPVZNc]KBZ/j^=X/:]UHVV`IV0RJ^oZIfUW9fIUjNNZKf`ThNBTH:1PXFD
THB=V9JAV;VkQgZJX8R;Xj>5Lj:aW9B;RH:8XJfTS8nGT8=[KWegLHJ:KfAWOHaj
N7A[M7UlLgN7VjJUVgedS9N6N7AdK8ZOQV]dT8F1S7iaN9VIP8J@UY>3Q7meOX1]
GFe`K7^:Rg1OGgZ4MgU[FU5TQ7eLKF]XJV5ZL6QmP7M]FF:0M5M>Hg1UGeYFH6M[
NWQgIU]TGembLEUPL6ihLVaPFFj8SGmeKFihNG9/MWmfM7MjQHB9PhV?THM[KfUa
R965PXf1MFihQH20SGmeQXnJRFMoTgMjQ7V1R8=eOi6CQXjAHVZET7Q]PYB6MhB<
R7]YG5eYMGi_EE5XKW5XG7b7Kf]jS8j?XkNNOFYfQGn0QXZ1OX>CYYb?Uk>eZZRX
W8Z/c:bL/K6^YZbkY8nNZJNSX:j^WZBRWIVOUINPWJF/XHjIZYAnO8bIUHZ;T9>=
TJJKR8j>SY6EWXAlRHb5PhZAT8AnU:ZGPh^?V:n]U8JGY[2XWI5eOZg5^Y=eQ8j>
T8^7PgjCVhn6Q8=iKH6DV9R?PVIOKgAVGE1FL6U]P7EZGf^CRgY^F7MjJWQcK6eT
KWm[EeUWPiJ6Kf=aLEQLO81XI61QGUYQFVEdK6e_I5aAGfQSMGUcN7aeJEm[KfeZ
I7=]E6J3PF]YK5YRMWebNh1^Mh:;Qg=^KF5[PWEVH6MhNHj?K6=TK828P7AJBg63
P85ZJFU_OWmgJVIcQY66IeiZLVAAGFUQKG5bO8F;OVemPWb9OVIaP9BEPh=oL7RQ
Y9:4MY2YXiZDUiZ>Ti^RXYfGVjRRWiZ=R9>[/i=gOI2PVH^<T9>DV:R[UhnKXi2;
[k:PQgnL/ZVDPi2/]:RBRj2/YIbQZ:BVX9NK[;>[VXZ9RiVNP6efNh:7R7MbNHJ9
SIb]^Y^CW9>>Qgn5QH9iOhn6OH:2UibLVYJQUiF:RYNUYIjMYJVGP7F1R9BLQGJA
Wi69OWAbPXb2KVZ2R86AUGISMH5jJEUEJH>>R7AZLG=]K79^HVU/C5EoOE=<I6]S
NY5fAdIaQgYnRWj3OfmgOH22PI6HQ7V5TI26Qh9/L8j;J6F6R7UmNgN1MGQlLX^?
KUa@DFMoMe]>D65[Kh1YFfikOfiXGfU[LhA_K6Q4E8FDQgQgNg1XMgi]IVijMf9d
OUYAEeMXL7]jIF1VM868MFMZPifYRVelSZ69JfIhSiF7LWEiLgjFV8j:QhnGTjNX
UijPU8]mLX68QhJBY8QiTY^SWINIPg9bQi=nMG1lV::EQ7QcPYZb/9f>W9j=QiRB
MgF6QX23Ri=nR:>WWHR1QHbCUXfK/Z>Z/iRAXjZg[9N>VJ^FWkj`S8jLZ[N]VhnK
Z;K1ZJBS[;2CNhBMTHBSYHf7Z;>5KWRDXYj7M6MdXJJ<T7=HOZ>NRWN1RGjAZ9ej
FgNDMfR2Sg9RLXVJR71FA4]NJe]KHTM<LG1KKhehGVQoS8QXIWAQHWIZIFQPFem^
OGZ9TGYhNg5jPhb;PYFHTI2IUVaLNiZKQf9QMGf1NgA/FE9VNWEOFVm/Ef=hMfmX
IUa>EG1fLg=eKf=YLeaJK6A]K5E?CUAUI7B9NEE5FgUfN8n5LXFNVg5TPHb<MgjH
U8aoPZ:[WYN=QH:3RI61RZJ]SX>>TH^>UHV:TiFAN7UlNX1fM6U]OF]JNiFBOhZA
P6n3UXImMHB5QiVLQh6IThJ?Thf3Q8>;[K:=KVb2Rh:7TXIfVIfHXJB/[Ib?S9F^
/YbC[[BERIFITIFTThBBVYN2Oij/[:BMVYFU/k^bX:jdZ89hUZRLRH^:VIRHZZb@
P9RGOWMlOX><TYV=KFM_S:68P8jOX8f>Q6ieO6]_NW9VFVf0MWF4S7YRJVmSM7eh
P7ekP7YaIgF6N7MdJW5mMFiiPhAoLgaiKWZ0NWb>VYV?Ph>2OW=QIGb7Si:7OW9a
NhAkM7alJFU_MGAgOgenMfeaKVAbOgIlO71ZJG5`JFQSEUa_NF]MHVM]LF16A4=B
F5APIW1gIfEeOfUNJfecOhMbHEmXP7MYJEeYOGIeOXN7P8^OUi:=PhbCUJ>KS8f=
VI^;OX69S9BAPWUkQXb<Ng9gQhf5NGn=Ri:6MH5oO7Z1RY>FUX9oRX5`Jg=ZKX9g
HeaWRYB5O7mfNHR?U9fGTi2N/InKVH><XIfLW9NIVjZi/JbXXk>_Y9fP/K^_/jn^
^::BVj2LYZjcYi2MUXjEPg^AW9nGQh21RZjmX7ikU8n;Vhf3R8f;V[:WSGf3QI:K
TheeLYJUV7i^Mh1oJV5/KhRWZYJ?UI5iNi>=Ni:NQgb5QXMlMGQaMgE]Kf9WMg=e
RI2>RgmmP7f5S962NXN3OgU_KGMgJ6EcM7=nNVj2S7=MD5]dLg=`KGImMVaiO71R
NXMgOVeMCEARHUU8BeAHH5eBD5MBBV1/HF1ZKg=`Jg9cL6M/N7aeLVYeNfI/NX1o
O7IgMWYdL7f0S9j?SIJ;P7n4MVAYPhj=T8ijGVN7ThAbL75fP7]cOhMhM75iO7B4
T8b=RGV0SHJ1MfUcPHJ7P7iYHGbASgmbJ6=TKGb0NH:OYYnER8V@QWnHV9>APXBA
T8N0NGEaPY67QhNBZZNX[9VFZjZO/[ZVX[O5/jZgYY^KWJZZVi64Rk2XVZNPV9BJ
WXVD[jRKW:>W/;2RXJ>IV:2IU8b4Ti:>Rh>7RGIbNWf5NGN0PXYoNI:OShZBVhf1
T8j;QH::PX:;QY2OTh2@WYB0Phj0RJB<MhnNSG]gS8U]LWj0QWQPFF=fL6a^I5eL
KWE^HVAaNXMjJVMTKh:1NfYGJWQnR8AcH6AdKW9cJUeGKG]cM6=<BUEXMhEkK6Mc
PXB3KFUdMWMoQW]`IWB=OfiQEei]MFaMIVYWLW=lO79fNXV?Ng>0RiJIRgajMgQe
L7]^Hg=fNh25RG=YKVeTJFidN8J?OhZLRh:;SH9jOGilO81nLVeXIFYbLfETGfQe
LfmVK75gQ8^6M6QaPXN0RI>7PHRMX8f:TiNARH^DWYf<S9N^XINOWYjHWZFGTZ:W
WHR0SINVZYF;R9N[YJBCPY6FUifDUXn5UZ6IX[6SSXnU[j^PSi6GWjfPS96RUYNZ
XXifKG=lRZ2?NWUjPYBYVGV:Xj>CR9>BQH^@T85fN7^7Q7ImRHIhQ8nGXYF8QhVF
Si>LT8bAYjVGUhV=UX]fLXfIVHAdOWZ9MeEZLFe]NH69PGR8OhR>N7UhNHAoR8IY
L85eKeaRMF5ZLEM:CF9`JfMaIVF4P6]VL7mbMH9nSY1lIfn9PWQoQg]iPHZ5N7ei
NhIfKXJ=MUeYQhj9PW5gKemYLFYVGf1QEF1eH59QIVQXLfI7Eg>0Mg5cLVm_KFM^
NVIaPhR?M7B1K7J3Nh5fE69iM7I[N75PR9UoNH67S8B1PHN<QHN5PXJ@SX5oOX1n
N8V=Q8j3Pi>KUXN0S9^VYJJVT9JXVinRSX:5QH><YZFBU9V>ViR?SH5oO8NIT7n@
WjFNUZ2LS8FBW9MoPIbUWh9ZPXV1O8BCSHUmLXZEUYRCNGjGU8:2RHB:Z:bETIJ<
SibMY:B>QHfEYj^VZ9nIZJVQW9jMUYZRZZ2NWi28Ri1nPhV=RH2:RWieMXN<MF]j
OWMmQXAhQi63Phj8OGaeLgb4P8N0IFn2NgAoOg9WHFemPWmiLUiHM8UoI5ISP85]
K861LFMTM7UQEEeMGFUoOEYDKWafMGAgP7UdJFimPHf9N7AnQHEhLFm_OGmbM7I[
KFm_LF9RMWIeP6mZQIb:NH62KWJ3MG=eNGihMWM[JVIYNgYXG6U^I5i[MG^4OW1]
L7^0OgUdLW^:Sgi]MH:3QhV8T8V3UIZ<SINFTiZDPHjVVi>@TiV>T8n5SIVOSg]o
RhMoPG]fM75hOVi[MfYdPh9fL7]kQHImKFIdPXf9SX^7V9B<OhJJUHj;OFmgQHVD
Vhb6SHj=T9VPUXZ=UiJO/J:EV9nXVi2HUYbPX:2QYYnCSJBbW8R7TijX[jNHVZjg
[IZEV9NSYI6<Si^UZ:NITY22O8V=Q822QHB4UIAoNhR;NWJ2Qh1oPhQkKfe`NWIc
Gf=dIei/O7ESL7]_M7aoJem_R9B8MV5PPHn8Q81jIW6;QWmlMWMdN7f7O7AmQIZO
Pgn4Q8R2QGikKg1gP7miL6M]MGU_HEQHIW9ZF5QMHVMYKfeKH6eVLWaXEVIoQh1i
LVY`Q7a[K71jNG1bOWUfLFUaNfmTKGUmPHAfOY2:RXJ8PW5eMgEcN7ieKVidMViZ
J6i^J6]cNGeeQ8j7RX>0NgZ:RWR2TiZBP7ikNXF9PFiaPhf3PHZFW9VASIVPV8b:
RhnPZj>IS8R:RHb9SXajN7n9THYhLWj7U8AaMH^OWI2@VinUW9>>QY:NYIfHU9>V
[:FJUjFRTI>JWjRc]ZJP[[6h^J^[[k6b[ZNY[Y^:SiVJVXejQY>=PgZ2OX6CSiBB
QhN8PGN;TXR2MH6JWXUjNWmhMG]iLWR9OFmiMX:2LGj3QgYNIgV8U8MnPG]iQXen
OhAlR8j1Ng]nQHZ2JV=]NgY_Ohf<T965QX>@U8b4Mgn6QXV;Q7ejMg1/Ngm/Eem]
HfA`Lgn4LV1XPhE/G6EbLh:2JeeVMG=_Hee=DUaKJ6e]HEeVFD]DHFMVJViRKH5m
KFYVIG=gN7]mOGAXJWIdNHEmKFe`MWamRI6?TYJAOgf=SXj;MfYcNGZ0OgikLVaT
H5Y[PgQ^IGIjHV=WMHF1OgU]LH6CSGQmUI>6PXZOT7V1S8nBTi6ISgemS8QjR9:8
QHR4SYFBUi:<TYN6M8^PUhn1NXV=PhJ0Mh1iNhMfM92;Qi>?UIRBW:NWUYb/[ZBO
[:bNWY:=U9ZJVHimQiJDRiBW/9fK]:ZJUJ2c/JJPUhjIW:BZU8RHZY^6RhnKXYZD
OX6;Qh5jQI:CShb@Si:JVhQoSXYgPH^;WJZJRXZ?Rgn3Qhb4NXNKXYNJUHB:RH^H
V9YoLGn6V9F2NGmmMF=UMWEcK6UXJFUVIVAZK6IXHEMDIGAcO8N3JUaOJFIMIV1J
K6UKFEMSIF1NF59FJ79_K79kLfm]KhEgIVegOh^0K7IcKfn2SG]bHeIQKVIVIV5]
PXR7NgIjPY^NPXBFVIRCUi:9PX27NViWKW]eMW=UIGR;QWUnNWF4QhB8PH^7Nh>9
QgUbKV9SKfmSKh9oN6i]Lg9cNWI/L820PhV<TH^<UiRGS7j=WZFRWI^?PhZET8Z<
QWQeRjV[U8ZFWJ>PSi^]XI6FW9BHX9IlMhF5N7^6Q81jMW]oOXN7Q8JAR829V:2>
TYbLZZJ:P8NDShVIY9EkPYfSVXR1PHR5Oh5jQ8jDX8j5V9bR[9j=Qi:NWiJ6OH>>
R8J6PVaPJ6acN7EcL7=eOHQoMGnBTHF8R8J8QYRWVhUlLGb;RH=hJW5lPHN3PHN2
R92CThJ8TIBJWiZ3P81mPWeiNG1WJGV1LfUVHF=_LfIDFfY_N7MfN7]mOWmjLFMa
O869R8IhJWj9T99iK75dO8Z;Ri6;RiJDR8VGXYVCSh^8S96?PgIeKg1/HEUNLW=a
KfaVJ7AmNWEdKF][K7=^KX>?NF=QKgmnJUYQJ7EcJfmaNgAZJ61SMW]kLVanP7b2
PWYgRIN>OWYnSijESi69PXRATH5cJfU`M7Z1OHJASXf6RhjDWI>;SiJIUi67OGF4
T8J4PW1hTi:4LWN<V9J?U9NHTIRUYJj`Wi6CUY^OVi:BWIVBUIbPTXfKXiN3NX2<
WjFLPg5jPXVJWhYmR92:SiNBTYFITi:HUiB?ShV3T9bLVi6AX:Z/Ug^7VY^LTHN1
R9ZDOGV2MVYbOG=QJ7MiLFAIFG>6QX5hN7MmQHF5Si20NGQnNgMfMGAaN8:2KW65
PW5[L6QNI6mkQG][IF]`N8J4J5mgQWmiPGUcM6a_LWIaF5I[Jf9KH79eLW5cLgQm
PXR4RY2@UHUkMgf=QW^4N6=]LgQeKFiYGVE`Mgj9Q7elOHJ4QX9mPhnCRX=kOHZG
UH=hMhFBS7aWI71ZJWf6LV5WMG^2N6UeR9:3KVUdRXeoNg=jRHB9RhZ4Q92=RXJ:
UiZHVJ2NU9ZLVZ2YYZ>HR8J2ShmlJFUeOH=oMW5^MG1eNFmaNG]jOGQgPX62TYJ0
MhB2MgB5W:NEMFinS96@ShInN7nBUYjJR8B<TIJIThZ?VIbGUYfHT9j[Y96@UH9d
Q8R4Q89mN8F=U9bBS9RX[k2c^kR[XJVbZj:PWIFLUXb=SY6?QWQiOh24TY^@Ri>I
UXZ:TibLThB2QHJ=Uha]KH28OW]hLWZ5PWEYIG9kNg9]KFmdO7]dNGYcN7YhPX1h
NWEbMWIkPH=kLgMmPX9nRYj[WH9kPiBSXiZ6PHn<RY6<OVQZN7UiM6aQIFEPHEmR
H6E]M6eaNgM[H71mLfQNFF1[NWaWEEEGHG^6NW5XKgQdNWAbLg9iOGM_KgF4PGf5
OGIcLG]jJFMaM79UG6]nQg1DEUQIHfACDVEgKfYhOhVAT8R2Q8J4NWF1PGakMfiW
KgQ[GF=aLgb:SHVAThR:UijHRgb8UIZOUHRFVI:FT8n>T9ZBQXN2OXbFRHJ@VIR;
QXfAU9:9S9BJViRCTiVGUiZ;OH^OXY>7SiFPYZ>TY:J`[:o7bkBY[jNOZJ><TZ6X
WHJ;TYBBPhF<S8Z6PX69Rhj:PhQmKW=nQ8IhMX:4OWZ9Rh5iO7miPGa[M7]kP79d
OgEcO85kOHN1OHZ>QhJ9PX:9W9n4KGF8R7f1QgaiMg9bMXJ4OhZ;RHbDSHnM[Z^>
RiR?SXZ0QXZ<P79dNGefLW1WKfeSJgj3Oh2;PG1cOH:0Oh2:RgimRH9hMWYcN8V4
NgQlPWEWKFY^MG9YG5mYJW9dJWElLVmbPH]iM7]jLFabMWUkNgQgL6YZKGF1Rgme
R8j7RHf6RXMdKWAnOgUeL6a_LG5SG6EOF5=EIWR7QfaOJVmdMgYjKVQ/O89mPGYk
QHAoM7F2Rhf8QXN3SHQeNhV8QHJ1OH>4OXVASHF8ShZ4QXZ<Og^7OgV<TX9cNXJ5
PH5oNGakQIBPX9RHX:JOXJJSXk2gZZ6IX9n<Q8=kOXZ<Q7IoSYJLVY6:RY>SYj6K
WYjCU:Ba]:29Tin@Q8V9Q7f:T8b;PG=eP81mOh:6PXf?Mg5kPGUnQhZ8PGn:RHjE
RWf1RHN3PgejRIbJUIRIY:>QYj>MWj6MRH>KWiZKShN5QhV6PH2:QgUjPX9jMgih
L6YYMWQaLG=`LGEmOgEZKW^0LVYaOH5fJFi_HF9^Lg5^Kg=[HfYiOGj5QGIbOXV4
MfmgNfUPJg=gM6USHFERGf1[LGAkPXVBU8b0NHZERg]hNGj7Rh5fKWAlMfa/K6AQ
JWAeMgUgL7EiOX=nM7UmQHf6OG]oSiF4P81kOHF<T9FGQgejM7AnRHIcKh6>R7j2
RXR;VIB3R9>GSXF9Rhn4MG]jL7V0QXF1Pi2GTiZKW:RXYJBLUi2:UJJYWINDS8J6
R8>2RY:7OhF=T8f@S8EoQi66QY6?QH26PgYoQ7igO8>2Qi2APh6FUhN4P7eoPH5k
NG]kPHV@T89hNgN0RHAiMGYkOgicLWUiP7e^LFYLJgUnNg]nNGJ9TY2AS8f<SYFI
WYjEQgmjNGaiMVQSKgYiO85gMGMkPhR9QWimPXJ9Ri2<PH6>Ti24M6e`PY:4KVeh
Kf]hNW5^NG]iNWUkN7^9QgYhQH=oO7V5TYNARhJ1PHJ3PGYbO7inP7^4Si>DT8nA
TiBCQgR4ThYgMX20MW^5QH5oKf=_PhMeKgAfMW=[J7=iLg9_K79lMW=eM7Z0LVE[
Lg5hRHIkM79iNFU/O7QdMgUmO8J<Q8>;TXf8PXJCV9JEU8UnN7QfPXAgLWB2QHB<
PgYoT:6XZj6BRY2S[:>FTY6>UHj3Ph1mOXF6PX:3O7j6RHj?RXR;R9>MVibKTH^B
UHj=SY6FSHfBQHFAS8f8MFmhQGmdLG1kP861OHB?TXZ<U9nWXYREW9B3PhZ<NVa`
NH69QGZ:U9JIRHbHWYfFU9FBV9nPUI6AQ8:5P7MhQ8J1MWIfNGagM7EiNh62QhR2
OhQiK7Z:PGb4ShQhMh>HVY^GP7EmNG=dL75kMFU/LGUiOHEmMh5oMW]jN8:4O7Ua
IF=_MGE]IU]FGFUWHFAWKG9bOHElO8:;Qh66S8N4NFmfOH1eKg1ZH6I/I6YiPhj9
MWInQYVLR8F=SXfCThb:QhV3PXf@Q81mQ9:8MgEmNWUkN7=bOh5iLfmgO7IeNgYg
OH:3PXR9RHMiO8VCRGehMh2JWH^=Rh:=YJVWYJ2KUIbUXIJATI2MU8R9Qh60T8Um
QHZ5P7anP822O7E`NXb@RWm_KGN8OVifPh1dNWadMX5lKFMcOgV0T8YgLXJ;QWQl
TXV1Qh1eP96IThF0PGn3TXAeMhB7OHF4NhJ=R8R7RhnFVYNCVYNASI24PiBIUH61
RHV6QX9bKW1]LgmoNW]jLFmjOgf6THYgJgF9Rh>5Q7UfPXn=QHjIVX=hNVihQ7eb
N8f4K6M`NWUnOWimO8>5SY2;QHJ5QHEnNWanNGIeN7UgM7YmPH>7U9>GVHZ:Ri:I
QWioPW]lQh>1Qhj5MWN4RH=gN8B>Sg9/OHIkMG9/K75eLfe_OX:<Qh6;SXZ?WYZ2
OHZ8N6mlRHEiJ6j3SX]jLG>3RX=nO86;S7idNGajLVecMVaVK7IhMGahMGMjQXB4
SI6EY:jGPhbBVYV;PGQkSHYlPH^9PHB3Mh6?RG]nRXjFS7^:TXf;T9:5Ri2@S8R=
T8f5PXf0MWM[JFmkP7]`JG1mN6iZKGMhNGn6UI^FSY:GUY^MThb<R8VAUXIfNXN=
ShEoUIjHW:6W[ZVMVinSWY^IUIJETYJDRhn:Ogf:R7EcMgifMGU_J75iL6YZMg]^
L7=hNG=[KWb=RGejOh9^JGQiLW5dLg1iOgUaJ7F?S8>7PH:7QXZ?RXB1NW]gN8N2
Mg1^MfmXOGU_MhJ4MgMkRIB>NHF=Ph9dM862N7AkP7YhOge`IVYcNG9eO7=iQHZ0
NhFBS8NEU8J5RhjDVY::Qh65PhN9N7EmNG]eMXR;M65/O7YfKWJ:TIB7P7n6V9N:
R85oO7MlO7YlM7V3NgR4R89kP8j;PXB?Uhj3QX^CTY2BSXZJV8Z:Ti23O7fBSgf3
TXb6UiZ6PhZ>UIN8NgQfNXN5PXJ6S9>?RhJ2Shj0N7V0P7f4R8V;NVE]OX67OWR2
QH^;Qh^7NFmZOh9fOX9lNXJ2Lg=jNg]fLWV4S9:KX::HSXjDTHV;PgmkOH=kM7ej
LWEiOWUeLGR;UXMhQHV7QXJ;QHF9Ogj7TXf5QXB6Q8VCVhYdLFakRh1bN8AiKgn2
O71aQh=jPXenMX>>SXN6Q81mO7j6Sh=[Jg]nO7UiOh69SXj=SHF6S8nMU8InP8fC
QGMlPhAoPXV9P7MdN7b6RX9kKW9mNg5dLW1eLfe_LFY^OXImPHV3OWj8T8F2PhN9
PX66PGj2OWI`JgZ0MGMjQGaaOHb;OWegMGf1QGmfMGb7OgEoQW]kQhN0QY6FVHj4
Q8j:Oh>8T8n8Ph68Qi2>N7B5SGQ/KgQnP8j=NG1gPHb<SXZ7Pgn7UIbISG^1RH^6
QH9mR8b3OGYoQH=kLgQiKWAlN825QH9oQ8jOTGQkN75kQXB7RX61QHN6PXR4NH>E
WhmlQ9JLWj>FUYJGXZb]WZ2MV9fLV9ZLRX>1O8J=RH5oP8B;PG1_Ph9aKFifQhjA
T8F9Shb3PXnAP7=gPX=iJF]dMWejMVmZL7f5QgMcO7IeOXf<OWF2MfZ1Sh=VHg1i
L5mHIGMhLVihP8F7R8=oQ8^7Nh:?OgAlOH:6PH=oLf]bOGmdMgmnOgaoOWmkOhV4
NWelO7n2Q8F9R8jCR7j5THYlO8AkMGb1QX>3Q7YcLg^8PgEkPX60QYFDRH:6Rhb?
SH9aJWEiK6mfMGb1Ogn9SXVDXYnFUYbNVI6FWY>6S92@SH^AUhb6THimMH6<SHb2
QX^3OGV2PWajJg9jMh1nNGb1NFmhPGmoNWb;Q7YkP7aeMG9bMW=gQ89nPHZ4P8^G
Uhj5PhJ6S8IkOGQjO7IbL7IcM7j7SHN3T9ZGSi^JQ8V8P8F=TXj8QHbGSXNBTGmg
Nh:1P8J9Ri:=Ph>7T8b4Q7n0SHn9SXb2NgZ2T9J<RXb:PginNG9eMWAfO81gMH27
P89nN7^0QHJ4Q8=gLgA]MhJ0JFMeM75^J79nNG]mNGQlQ8UnO8>3RHJ5OWYnQ8Z0
Phb=S8B2PhF7PhR;QX9lNXN<OGEnNg9hNFiZLh>9QHJ4OHJ?RXAlN7f5PWUiR9B8
QY2=Ph22RY2FUYFARHV5RhZ2PXF6Ng^3PHR>QGf1PGn8P7QlOgYjQXj8NWb:QGUb
LXF?RH=jQ8n8QHjENg1jW:9[Ij>VMHJ>L8RIMh2>L6>0OV1VTJFINWR?P7N1KfIf
KF]bFdmcN61RNWAPJWa`J7i`CF65OgFBY81aNX^DSiF6JgZ<PX2DSHRGX9F<U9>K
TYVa][NJTIfNZZjXXY>CXJ>HVZ>a]IF>S8N;P8:APgInR8emLW=[IVidOX>9RHR:
ShInP89hIfEZKGQaKW9jOWQ[FU5LKWa`I7N3RgmhQY2IRW5aNGUZJ79eK7R9NGN1
OhF5MgmnPga^MGfET7B6UIFGX9^?T9FCTI:@Ti2CTIRLWib8S8n5QHZ:QXR6SYfH
RH>;UY5mO9>EQHJAQYF=TIMaN8V>IEYcNFe_LFITIFEaGEQfNWAYJfe[IfQ/IFAN
Cf20OG=XM7Q]Jf]XI5URJVmkLFZ2R7N5ViB>SX=iMXJ<NX26RH5eKV]^N7elP8F1
NUmCGeiOLH66S8R8PXRQXI22Mgn7Oh6?QX9oQXAUFVeaJWF;THN:Si^SV9FDXJNJ
Y[6STXbQ_lW>`:NDQ8:7Qh]nMWj;THnMUi^XWk2mZij[^JfRYjf]XjFVVj>k]Z:T
Y9jHS7QkT8jEWiVO/:nLQXRQYiVHZIn3RXZ6QWa_JVY]L7b:R8AoNHR@SHEkQ99g
Gf=YJgQlJF]_HdULMVYHFFmnLgIkMFUUJUUJKW9_N7ikMGM_L7b1NV5QIGNETY:I
UGeXJgUiKFAVKG=bMWANBDiFDTa@D5ANHg=lLg5bKW1gLfQ]J5eTJg5VIgMTDEmX
FE1VKfeeGUUWE5mhKUiAEVMaLfUhP7=^JVj0PhR;P7j4Oh68QhR9QijOSInXY:F]
WHnPZYfDTYb_^;>VXZRQYJnXVj2OU9je^IjEWJ:LW:^[Y:ZZYkJo/j^XZj:EThN0
TYZ5QH^0OHJ:SI:0K76AWIjNU8b=VJRXU7j7Y[>/S8FIYJ2ISh>0Q7QjQX^[]:BX
Z9RKZJ6?Ri:S]K2LT9VXZYMoKfAgO7B3QWifMhZ5O8=bHFIVKh1kM6e]PH5iNVAR
I5]jQfQTLh65PhQoLgAmOGIdKF5XL7=ZF6MmNG1eLFM`N6m]JFE/IU]EDEY?Cf5A
C5QAE65DF5iHH69KJ6A=FgIYFVicJV1GFEYMJfAFEE=DGTi5HW5gMg9UJ6i`KV9b
OhN0LWMYI868N6QIGh2ESWa/Ni68QX1^I7f?P86=PFiVIG5aKFA/QhB5V95lQ8b6
RHAhJ6eiOhN?VIB6S9RFThn:UibBW9nFWZf`ZZRYYijIX::SXJ>VXYZ<SZJXPF]j
W;Ba[::AU;FkZZ6EWJ:CSiNNViFETj2NP7b9Ri^VXj:MV9NRYIFP[:N//Jnd/:6X
_;VQUjRg][Rg][Fnb;2M/;6b_kff];>faM38/9nS[Ko2X8>0TJN_[L7Ph<bkYiN=
T9NIZkZ[X9ZLYI:3SiVAR9RTUXYiIVA_NgYaLh^BRH5eIf=KBdYEFUUMH5]LIF5S
IVUQDCe5FDa6?cU<L7AMDE=ADDi4?41BGe]LGD/nBEQFCC/i@DaMFE9HF4m?E4iL
JUY<EUmRH556BTi:DEMBE5]HDeYNH6AOEEE9CF9RHEiDDE]ZKVEXL6acLf=ZKemF
BdaKFFMbIF1`MVQWOHN2NfYKK85hKFUYKG9bJVA^L6i]KWMnPX20NG9`JgR8PGV4
T9:?SXJ:ThMmQXjEVi1nPXn=Q7mjPY>@R8><Y[>YWif@R9RVWI6BPg9^MHjCPhJ>
UJ:`/Z>BQgb2THn>SGQbQX^7QH6:Ti^SYj^RWZBUXZNST96R]/70^[RbYjN]]JfT
YJZk`;2V[[S9emC9b/Nk^/3;dLFe/K?0d<B_ZZnd/K2/W9fUWifKTI>DUYfQYjVN
TiZPVI6?PgN;WYNCThZBWijDRY6EU9JGSXjJUi6AV9ZGTHJ3T:F^YibFTiZMT8J5
S9VHRhN<RH5mPhV<TiFGW9jKSh60Q81mL6n2TI5nL7EbJG9dL7V2PHJ3PXJ4PG1S
K7^5QGmcLGn=RGedIFQ_JFIF@TeNI6ENE4e<De]JEU5>FFA`LE]>DUIIGEmLDTa:
Be]ZHe95BeMQIfMJEEiOEeMGDE1CF6MjN6aTJgE_K6m[GeAEGE=3C5IIHEiJI6=U
LGYiJEaGDUi/J6INCTaJKWe]DU5OIF]`MgQ/I6QbN6ePDDmTLWMjMGR2PhN:OG5f
Oh5iOHB0Qi:@QhAlOXnCSI6HSX>4RI:LW9J>TjN^ZZ^TUHbCXIbOZJ>LX:N`^;:Q
VIfBPhJCUYJIV9F;SIF8PiB>QHnKWYV@S92=SH^4N79gMWf6RXQmLgEkOX21P8>2
Q8AlP85iOGecNXB3Q8^ASXJ2Ph>0QH5gLgZ9UYB:Ng>3UibNXijGUifRVXZ6RXb7
P7mmO7YnPXN7R8QfLginNg]cMX64QhN7QXF7SHb8PWQiP7j3OVi[KWMmO7=ZJf]^
LWIkNg9]N8F3N79/JVagQXF2R8J4QH=kKf]]LgZ1OX:6O7f7QWekNGEnRi2?TI:<
RHR9SX^2NWZ2RhN3RHb>TiB4N82AWYnOVIFGT8b<Rh^5PGahRiZAQGmlPH^FSWn3
RHN<UXYmOXF<S8b@U9JCRHnNW9BATibSXj:OWZV/WibRYZVUYk2d/:RW][fk]jRR
Z[Nm^kZk^;>ncL[7aLC<c<C5aKV`ZZVSXjj/YZR]]K>YWY6?U9FKX:2RWIFLWI6?
THf>TXn:Ri:?RHV0N7b4RH=oPgiiMgZ1Oh1nOhB2PXN7PgI]KWAcJFQ/KVYUIFQZ
Jfe]IemZMgMnP7UgMG9/JViYIFe`KgAgLFeYGeaVK6IOFU]SJVmeKfY/I6IcKFY`
NX1eKV]TJg9/He]FDUUWIE=<E59?EeMEFeiKG69VHEmE@D1;E5m/JU]HGUeIE4i@
FVIXI5aHG65NFf5SGE]QJ6aTG69ZKFaVHUeHF5]PIEmAAdQCGF=OE5UNHFa`HeA?
DE=DFEQ=C5QUIf1JFEAFGUMCGVY[IFAZIUUAE5iZKVUZJfY]Kg1dNWE]MhR@SXAk
OHZDT8AoPXJ=V:JZWYRHV:6OT8N9TifW/K2_/[6^/:jUZ;:e_LJm[Jbc/ZVSWY^Q
ZJfa]JjOTXbBW:N/YJFZZZVVWibOUXnHVI:CUHj=VYjERXF8QhB5S8V1QHb@TXIg
MhF@SXnCTYB@Rhf<QWalRi6:R8f<RHj?QWmmPXB9Ti>CV9bJViNBU9BHWj2JRh23
QHJ5PH5oOH>9QhV<S96DUIVGTiNLUhn@Shj?T8^8S8j=SY>GU8Z5O7AeNhB=SXZ7
QhZ:Rga_M7^0R8^<T8f6QGm`HfUcLWB0RX^<RGmlPG]_Kg^3R8f<QXNBT8J4OgEb
M7UlOh1nPHV:Ph61P866T9R?QhAnN7IkOgeeLWV6R8Z=PGQlO7QlNGAfP8b=Q7I`
MWQjNgAgOh5nNgn7RH1hO8F;QH21P8ZGWZBQV9NMXZ>MThf>V9nJUIJIXjV//KFi
/[2c/k:d^;bk_;be][JZXInIU9ZGSY:P[JVGQ8B@V9jERhfFWYbFU92>T9FFTHN8
T8f6QhF5R8AoNgUoQH=mNGj3PGajOHJ;QhF2OGUfOhIlL6UbPXB3PWI]L7IeKVQZ
LgIgNh:6PgijNWIfOWebLgYmNFaWK6i/L7I[GFQlOGIgLFiiPGmhKg1gOH21NFm^
JVU[JV=NFUURK6UVIUmBCeMLEeQHEf1/JUeBC4eJJ6MIC4YCFU]GCdeDFf5VI5mL
F5eUJV]VHUmQK75XHEmLGVU_KfUSJW=jOWYXGVQbL6m]HU]RL7YhK6Q]L75eMFmW
IVa/J6U`Lg1]MGioO7Q_KgUnNFmWJgV8SHN1PH:2QXN3NWV6TiNHThJ4SYNKViJF
UYRLXZBQUXZ<V9bGTYBIWjJ//[:[YZZ][[2c/Znd^K:VW9JIXJ6LUYNQZ:^]ZZ>J
SX^CV9NIVYVNZJNLVi^@Ri>ERX61Ogj3OWIdMg]nOG]kNWj2P81oM6=KIGAgKVQ^
NX1oO7afK6eeN7UjL6=SL7QfKfQRJ7UlNX69R8N<RXB5Qh9lO81nM6idO81nN7A_
KGEkNG9_Mg]nRY:<PWinPHF4P7eiMWZ6SX^1O867Pg]eL6a`Nh=oOhF7QH5lNWI_
KW9lQ8>0OWj0OWYbJfU^Nh>6S8f2OhbCS8EoMW5mSI27N71aMGV0QHF5QH>3QH>3
QH9gL7F0Qh5lQiNHR7imN7EoQX1lQI:HU8b5PX9oNgj0OWeoPXB5P7]mP7n1PX24
QgmhOXJ7Q8B4OhFAT8V8T9JFV9RCUZBVWYnPUi:GViJ<S9JOYJV]]kZd]l;2^l37
`;Jk`;o2a;^]ZJb[ZjVUYJ^`[JBKVJ6Z[JJGUZ:WXIbOYZVVXijHUYVJUi:ATI2B
TXj=TIBDThj7PH65OFm_OHJ6OgYiOXB8QgY]KgUoQ89iMWUiM6]RGEiZN8B;RXR5
OGAfNg]mNVaVLG]dIUiOHVEZJ5YJJgZ4PWQ^KWAeL6e/JFikPWmjMg=ZHfM^MGAX
HFMZIVmfJEeQIFQaKf1OK75[I5aBDEiVIEiLGf5RHEaJGVQ^Kg1dN7YiMWYjL6eZ
H69^NG]eKfeaOhZ6OGIbMH6?SH>3RHEnNWEeN7EcM7EdNWifLWUlN7UeL7EjOGae
L75dNX1oMgAkQhn?R7ejPHJ3PH1oOGn2QHJ6RXV6RXjAThn=SHjGWI^GUiVGUIVG
T9FKThZ;UJB][:ZXWiZS[:b/[ZbZ[Jne^K2UXInMVYZLWj6KVZ2TWY::R8bEWIbG
VJ6WY9bHSh^@SHV<RH>2RHn9PH5lMh29QgmkOWn2RXAbHeUJJgEbLWE_KWb7OFmZ
JFmdKFISI6]aL6aYJFijPH>4QHJ6R8j@SXQnNG^2QGmcLG]mPXV8PGIdNWamPGY^
LGUoQX^8OWn8QX65PWE^M829QWUbM7EgNWMZHfIaOGiiN7EcNGYbI5aLI71eL6EL
FEMEFEYNJGIiMWUlLfIXL6m]JV=UKG=eL6IQGf9ZJ65WLWEfNGilMG5_JfISIVa/
IVMZJ6YdN6mYJFabLVa[KG9dKV9IFV=^Lg=cMG^2OG5ZJ6afP89oO7UdKgEmNWIb
L7=kR8n=SI:@SY2<R8bCUYJIVIBDVY^GSXF;VjV]ZJBPXk:o^k>`[Jjb^LC:cLg6
_k^k][>d/J^VYZRTW9BCVjVc/ZbXYjRUXZ6PX:>UXIREVj2SXinMVI:?Uj:XYIjF
SH^AU8elL7J6TiF>Pg]jPhb;Q7aiP8F7Q7mmOWigKFUZLGj8RHR;S8R2OWeoPhJ0
O869QgihMGEiOX1mMWEhOHJ:QH5mMgEkPHF4QHV9RHZ7Pg]aKWB1QhEnMWIoPGQ]
IFQdOX5lNX66Qh5cI5UGGF=UIFIWIfMWIVEWKW5`LWUmNgUcJFIZLG5ZIfaaMWUe
LWAeM7AeMgf6Shn;RX^7OWE]KG5cLg=dNH>8QgeeMGMiMW1]K71jOWYbJV]bN7al
OHB;Rh=jN86:RGieMWUiNg]gN7j6RXV9Rh^>T92ATiFBT8n>S92HVYB=S8j<RHV=
Uj6VXi^IWjBUYJ6OXZbh`<2j][Ni]JZQWj:VYJ:UZjnYW9:=TIbSXjBXZjb[Y9^C
TIBDTI6=SINPWYNBSX^:R8B1PhJ6QXR8QWmaIVI_MgYkMgAjPhN6OgAZJFmaKVQV
J6idLVUVK7IlOWenP7mmNg]kO7ilNWj3PX5mOH23QXImLFUVK7IkOGikNGMhN7=d
NGakOGn0PX5lNGUjNGM`J6U`MgYgLVi`MGQfLgIjOWidI5aQJFaYIF5PGf5SHf5S
JFieO7agM75_Kfm/J6=OG5ePIVU/L79_KG1cN7n0OgYcKg1cLVe[KW1aM79bMgIf
N7UhMWIeLg9cMGAfNgAZIVagOh:0PH:0O7IcLWIjM6i`L71aM7IdLWEfLgEiO865
R8b@THb5P7j1R8V7QHB6S9:BSXV8S92EU96DVZ6VYZ>PXjZd]kFd][g1^k:[YZ2L
ViZIVifLVIZPYZNRWYjMVYFDUIFDUYNGVYbESi6DTi:CTHj=Si:AT92=SHf<RhMn
NGj4RHV3PXB4QH=kMWIjOWiiM6m_MWajMG1cNWn0Ogn1PH22Ph:4QXF5Q8:3Q85n
OH23PWn1PWmoPhF1OWn0PH65S92BSh^:RHR8Q7ahNgenP7imOWekOX60OWeoPH62
PWmnO7I/IF9SIFASIVa]K6][JficMWUoPhF3O7IaKFUVHfEVIfegOH22OgUdLgAe
Mgf2QHN7RXf<PWMaKW5eM7EjOGmnNWIcL75]IVI[LG=dLVi^M7QjNWYkNgEcMWYj
MgAaLG9cM7EeMWMjPHJ9RHN3PXN9QH:3PhJ:S92FUY>>RHR<U9J>QXB6SiJEU9JH
VifOX:6W[k:e]KB`[ZfYXYfMXJBRX::TY::RWibPXIjNWYjRY:BSWifMW9ZJVINF
VIfMWZ2MU8R2Q8Z=T92;QhN;RhJ0NgYnPXJ6QHB3Ph9oNGEdMWQjNgYlP7ihLVe]
Lg^1QHZ:RHR5PH>5Q8>2PhF;UIZGUYNDSh^5OGb4Rh^<Si>BSHV;SY6BT8V6R8f<
QXB4QHF3P7eoQhnASHInNgf1QXV6PH:7RXEjKfMTIfQYK6a[L7AgOH20OW]jMgIh
MgAeMW1XIFATIVY[JFQ[KFa[K71`Kg5aKV]ZK6]YJFYYIfQZJf]ZJ6UYIF1JF5UJ
FeePHfARGUUJHFMWHf9UJ6a]IeiJFUeQI6EVIVQ[Kg9aK6QUIFEYL79aLgQjMgIh
NGQiNgamO868QGegM7AjPXN9SI:FVYfPXJ:TYZR[Zj^ZZjj^[:ZYZ:BMWJ>TYJRV
Xj:SXj2LW9fOXIfHV9bPY:JTWYVMX:6SXI^ETiFFU8n>SXj@UinOV92:QHJ8QX9n
NgaoPHB6Q89nNWUhNGf3R8R3Oh25R8R8QhB3QHF5QhJ3PhJ8QhJ6Q8:4QXB3PGmk
MgQlPXB7RHZ<Shj9QHJ:RhF2Q8F5QXF3PX1nOGinOGekNWb2QhN6Pg]fM7AbKFEM
G61SIFY]KFaZJF]_LW5`LG=cMGYjMgE`JVAUJfa]Kg1_L71aLFm^K6a]Kg9fN7f3
Q8:1OWUfM7AdMgUkO7YfLViXHVAYJVYXJW5gNW]jNGMdM7EeMGAaLGAfMWMhMG1`
Mg^1R8b:QH>2PX62PX20QXf?T9BFUIBBU9BBU9B?RXN9SIBIVibKVI^RY:>UZ:ZY
ZZb/[[6`[ZbYZ:NWY:6QYJFSXInNWinMVijOWIjNUi>IXJ6PX9jKVIVHU8n<RHB2
QhbAT8n@SXV;Shj8PG]hNgmnNG=bM7MgM7=dLfm]Kg=gNgelMW1^KG5dLgIkOGin
OGeoP85oP7mnPhR8QXF6Q8:3Ph1nOh63QX^;Q821PHB8SY:>R8N:RXJ2OgioP8:3
QHZ@TXj;RHf@SXV1OGn1PX>1NWEcLg9aLgAeMgIdMWj3QHJ3Ogj2PWmlNW]hMg]k
NGYjNWE_KW5eNWalNgUjOh60P7moOh1oOWn0OWakNgakMg1YJFicMWMfLg5bMGUh
MGIiMG5`LG9dM75ZIFEVIfQWIFUaMG=`KFQVJFUUIfaaLgEgNGj2PWmjMWMlOWem
PX=nNGEdMWZ2QhZ<SHf?S8Z?U9BBU9VKUiNKWYjJUiFDTi>DUibOW9>:QHJ7RHZ:
SI>FUI>CTHn@THf9R8V9QhR;S8b>T8j9Qh^@U9RJViVCRhB1PX>3P7akO821Oh1o
Oh64QH9oOh:6QH>0O7QeMgUoQHZ;R8N7QXJ5PGn3QhV8RHb>SHn?RXB2Q8N9S8j=
T9JMWYVEUI>=S8n?Shf;RHR;T9FHV9FBT8b:S8b9QhZ=RhJ2P85nMfm/JfebM7Ad
MgUjMg=`KVmaM7Z0PX:1P7aeLW=aLGEiN7MjNWEaL75^JV]bN7YmPXJ8Qh=oNgUg
MG=bLg5^JfQXJ6UXJ6MTH5mTK79dLViZJ6QXIfQXJ6UYK6m^KF][KW5bL71bLFa^
LW=eMgEbL7AiNWanP8B3Ph>1P863QHN6PgiiNX27RX^=Si6CTi>EUIFEUiRHVYfS
YJ>TY9nKVIJEUiVIU92ATI>GUiJEUi^JVYbJUYJGUiVIUi>?SXj;RH^=SXj?TI>C
TiBFUYB>Qh5oPH1nOG]jNgaiN7^0PhB4Q85nOX1oNgQiN7^0Q8J:S8^8Ph:2PH62
PXF;TI2?TI6=RXR7QHJ9RhjBUYNFUYJFThj9QXJ6RHfBTi29Ph>7RX^=SI6GVYRD
TiFETi6?RH9lOGn1QHR6PWmkN7MhO7anOgemP8:2PXB7QX>2P7]fM7EhNWioO7Mb
JfMXKG5`L7AhNgakNgj3PgefLg9cMgMeLg5^JVETIf]^L75`KVi_KFQUI6ATHUmN
HFM]KVa[JFITI6AVJfi/IfIVI6EWIfEWK6m_L79bL6mbMWIdMGIiNg]jNgj0NgAb
MGf5S8f=SXn=Rh^>T9>HWIbJW:6VYZ:PWYbKV9NHW:2PWIRDTI>CTI2BUYVJW9bG
TiBETi:DUI:ATI2>T9>DT8nEVIbNWIbLWYjISXJ1P8:5QHJ8RhZ6QXJ4PX>7RXV6
QXR8QXB0OX21Ogj1QXN6Q861QHV:R8J5PhB8RXV:RhZ8QXR<T9BEThj:RX^9QhZ;
SHf=RhN6QH60Q8V=Si6AT92@SX^9QX:0PXB3P7aiNW]kNGEaLWEgMgQkO7]hMG9`
KfmbN7j0P8B6Q81mNWAcMGAdMWMgM71^KFmaLgAfN7]nQ8Z=RhR3OGQdMGEeMGIf
M7AfMG5`L79bLW9aKVa[J6Y]KFa/Kg5aM7IeLg5`LG=fMgAdN7]lNgUfLW=fNGYl
P8F6QHB3Ogj0PX>4QHF6RX^9QhF3P822PhJ:RhV6Qhf@TY>BTYFIWJ2PX:6MUi>B
TI6CU9:AShn@TI2=S8jBTI6DUY>?SXj;R8N3OWYjOH23Q8B4QHR9R8N6Q863QhEn
MW9aLGAfN7QgLVaZJfa`MGUkO7]jN7IfMWIcL6i^Lgb3QXJ4Ph:0OWQbLgV0QHZ<
S8^8Q81oPXJ7RXf@TI:BShR2P7imOX21PXF:SHf;R8N7R8V9SI6DTi6BTi>CU9:>
QX:2QXb>RhR5Ph1lNgelNWYkOGn1PhF9SY2?SHZ8QhR8QX:1PGmjM71`LGAhN7Mg
N7^0Q8J6RXn=QX5lNGMgMgMhO7alOGemO7akNWMcLW=cM7EdLW5aKf][KW5cM7=a
Kfm^K6e^K6YZJf]ZJVe`M7UkOWmnOWimOG]gMGIiOH:6QXB5RXj=RXJ2PHF;S8fA
TY6@TYBFVI^LW9^LX::TXZ6OWYjKV9NIV9JCTY>DUiVFU9>BTiFET8^8RHR7QXF3
PX>7RX^=SH^:RXf>TIBDTY2ATiBCT8b6PWijN7YmP8>4Ph:2QHV7PGajNh23Ph1k
NWalOGenOWinOh23Q85oOGamPHJ9RHZ;Rhb;RX^>T96=RHV:RhZ8QhF5QhV8QHJ9
Rhb=SHj?ShnAUINDT8b9QhN8Rhf<RXR8R8J3OgeoOgmmNgUgMWUjMgAdMWf4QhV9
Rhf>SHZ7Q81mNGIgN7QgMGMjO7enOX22Q8>1PXB6QXJ2NgIeMWQjNGIdLg=cLVm]
KFi_Kfi^KF]YIfMYJ6MZKVm_KVeZJFMTHF5SIVQ/LGAeMGAcM7AcM7=_KFiaLW5^
KFidNGn3Ph:2Q8F3Og]hMgMhO862P7enPhB3PhN<T9>CTI6DV9VFTXj9QXN;SXn@
TYJGUY:?SXnBTHj:R8R9Rhf?T8n<RHJ3OgioP863R8f?THj8QXJ6QXF3P822PX61
PX9oNgQgN7UjOH:5QhN5PhF6Q7mmOh21QHV<RhZ9RHN4OGMfO8>8RX^<SI2ATHn:
QhJ9S8f=Si>DTH^6PX22QXR7R8b@TY6?Shf8QHF:SXj?Shn?Si2ATI2=RhV:Rhj>
RhV8Q7mkNGUiNWYjOH63PhJ=U9FCT8j=S8R2OGQfLg9cLFi^LWMiMgAdMWQkOWmm
OX64Ph5nNgMeLW9cM7EfNGakMWAeMG=aKg1cMGIeMWQhM6m]K6][JFIUIFETIFIU
HfAXK6maLW5aKfe]KVi^K6a^LW=aKg9hOhB4P7j1QhZ8QXJ7QhF2P863QXV=TY>A
TYNKWZ2NViVIVYVFU9BCTYFHW9nNViRFU92>Shn?TYFGUiFCU9FBRXB3QXV;Rhj?
Shf;Rh^:RhZ:S92FVYZDSH^;RhJ0OWj0PH>4PX64R8V6PGn0Q8V<RhV8QhF3PGik
NW]lOWmnO7YlOh20PH>5RHjDUYB?RhV9RXN4Q8R<SH^8Q8B7RX^9QhR;SY6@SXn>
RXR8RHV9R8R7QXR9RXR5P7eoPhJ4OgYgM75_K6abN7YjNWaoQHb@Shb:RHV6QHJ7
Q85oOWmnNWMhNginOWioP8>5Q8:0Oh64PWilOH21P7ijM6m^LWEeMGIfMgIcLG5e
NgimNgQdLG1^K6i`KfaYJFU[L7=dLgAhNGQgMWQlOgeiMWEcLgEhNgakNganPhN8
R8N8Rhj=Qh5mNWQhNG]oPhJ;Shn>SXj>SHV4Q8bFW9bIUHn<S8b:RXZ:S8nATY:C
Thn:R8N7QhN9Rhf=RXN6Q85nO7anOX22PGmnOG]jNWYiN7IfN7]mO7YhM6m[JFa^
KVmcNWn0OWYiNgn1OgemOh60O7YjO7aiM75]KG=kP862PhF5QhZ<S8^7QHF6Ph1o
PH60OGYlOh:3Ph>4Qhb>Shj;S8b;RX^<RhR5R8fBU9FDU9BCTY6@Shb7Q85oPHB5
PX63QXR:RXV:SY:CU9BEV9RETHf:R8F1P860Ogn1PX1mNWYmPH>3PGinPHN=Shj=
RHB0OG]jMgEeMgUjNgamOGemOX22Ph:1P7ekNGIbL6m/JFU[Jfa^L71_KVi`LG=d
Lg5bM7IgM6iXIVU^LG1aN827RXV7Q861Q8B1OWn0PXB6RXb8Q8B6QXN8SI:FUiJD
U9BCTI6?S8Z;S8b;Rhb;RHV7QHB4Q8>5RHZ9R8N6QXN5PGinOWmoPXJ7QH5oP8>6
QhJ6RHnCThn<RhV6PGajO7elNgUiNGb0PhF5Q8B8Si6AT8f7Q8:1OgakNGUiNGQg
NGf0PXB7RHZ<SY2BU9:?SHf;R8:0PXB7QhJ5QXZ>TY>ATIBGUYFCTi>CTI6AShf<
Si>EUiVITh^6PX:4QH>3PGmlNgQfMGUnP81oO7b1R8b>Shj<RXZ:RHN6QHB4Q8B1
O7YlOh5nNg]mPH>3Ph:4RHj?RhJ1P7mlNGIaK6U[Kg9dM7AdMGEdMGMgMgEeLg1^
JfQVIVUWIF9PHFAXJVY^LgQiMg=`Kfm_KVa[KFiaMWanO7UfMGIiO7emOGn4R8N3
P7imO7YkOGimOH23Q8N:RXZ9Q822R8nDUiNDTI2>S8V8R8R:Rhb=Si2?RhR7QhN6
QXJ9T9FDShf>SHMoO7j1Q8F5Q8:2QHN7Q8:2PhB6RX^8Ph20OGQdLG1aMGUnPhN8
QXJ9SHj<RhV7QhJ4P823Q8F3OWanQ8V:RHZ<SiBGUiJEU9>BShf<RHAoOgn1Q8J8
RXf?T8n;RHV<SY2?T8n>SY6BT8b<Si>DTY2ATi>BShb;RXV8QXF6RHR5QHR:Rh^8
Ph>8SHj>RhZ<Si6?RXV:RhV5PWiiMgEdMGEeMWMhNG]nPH>4QhR9R8N3OGEaLW=`
Jf]]L79cLW=eMGAbLWEiOWmoNgEaKFMTHV9SIVUZJVa^KF]ZJ6ETIVIUIFQ^LW=b
Lg=bKVaZJF]_LgMjNgenOWemO7YhN7aoP823QhN2Ogn1PhF8S92CTi6ATI6BTi>A
SXn@Shj<Rhb=S8R4PH:5R8V9R8Z:RXV9RHZ9QXB4PWmlNgalNg]kO7n3QhZ:RXb=
SXb;RhV3OgenOGQcLG=hOH:5R8R7QXR<Shn>S8Z6Ph60OWaiN7UiMW=dMg^0QXb?
T96AT8j=SHb:RHZ8QH61QHR9R8J6QXN:S8b:RXZ<SXn@THj:RhjATi:@SXj>SHf?
Shb7Q8>2Ph>4QHB3Ph>3QHJ5PWmnOH67S8nATY:BUINGU92>SHb<S8^7PX1oPXJ8
RHZ<Si>FTi6@T8n@T92ATHj9QX9lN7MfMGMiOH65R8V8QH5mOGakN7IeLg9dMgUi
MgA_KFmaLW=dMWMjNgUgN7UjNGQkOX63PX1mNgYhMgQiNWenOX23QXJ3P7moOgen
P821PX:1P7elOGn0OWj2QhV:Rhf?TY:@S8N2Ogn0P7moPGmkNWj2Ph>2PH63QhN3
OgemOWegLF]ZJfi`LGAiO7aiMWEhO7emOGYeL6e]Kg5_KFa[Jfe`M7UkNgf2QXN5
Ph1nOgmjM79dMWUkNWYnPhJ7QhR9RXZ:RXV;S8^9RHZ;S8V4PX>5QHB2P864QXF2
PH>9SXn=S8^;SI:EU9:?Shn>RhZ<T92=Rhb<S8b;RXZ<SXb9QhN8RHN4PX>7RXf?
TIFIW9^FShZ9RHR5Ph>6QhN4PGimOWmoP8:5R8V;SHn?SHZ5OgYhMgMgMWUmPHB4
PXB8R8AnNWYoQ8J4PH:3PGmkN7EdMWQhN7MfM79aLWAcLg5`LgZ1PX1lNWYmOGUb
KVmdNGenOWeoPXB4PWmnPHN:RXZ:RXV7Ph63QHN8RhnBTHn<SY:FVINBShn@Shb7
Ph1oOW]hM7AhOH62P7elOh:2PWmjMW9bM7AaKF][KgIlP820P8>6QhJ6QhJ7R8N4
P7emOG]fLgAfN7]oQHZ=SXn@SHZ6Ph:1PXB3P7aiNWamO7]kNWb0PhB2PX>5QhV<
SXj<RhZ8QhJ4PX:1P7n0PXF6QH>2PhJ;SY2CUIBCU9FEThn;RX^<RXJ4Q8>2Q8F5
QHF5QHB3PWmmNWQhN7UlOh:3Ph>3Q8J8RHV8QhJ8RX^:QhF4Ph>2PX>5RHjBUIJD
THj<Rh^;RXb=S8Z8QhN4PWmlNgakNgn7RhR3OGYiNgemNgYjNWYiN7EaKfe[JFQW
JFieNgmoOgekNWUjNganPXJ8Q7ihM7=eMgYnP862PhB4Ph>3QXN6Ph1nP8>5PWij
NGUkOX>7QhJ6R8N7QhN8S8j>S8EnNWYkOGikMgIjPXV>SH^9R8N7QXB3PH:4Q8:0
OGenP85oOGj2QX^>SH^9QH>2PGmlN7IhNWYhMGAdMWZ0QHN7QHJ8QhB0OGf1Ph>0
Ogn0P7inOGn3QHJ7R8V8RH^=S8Z:S8f>Si2>RhF0OWelNgYiNWeoOgimOX22PhF9
S8n?S8R3OW]hNW]lOX67SHj<R8=oOGeoPHB4Q8B3QHN6PGahMGMjOGj1QHZ>THj9
QH>4PWeiN7]nPX>2PX60OWenOgmoOgn3QhV:RHN5QhN7QH5nOH25R8R6Q8>3Q8:2
PhF7RHZ9RHV9R8F3P7ejN7MgMWIeMWMjO7eoOginOWn1P7ilO7inO7]iN7UjNGIe
MGUmPXJ8R8N8RHV9QhF3Q8J8QhF4Ph>;Si6FTXn@TYZOX9jKVi^KViNBT8f=SXn@
T96AT96?S8f>Si:CU9:@SHR6Q8>1P7ioPXN9RH^<Si6ATHf<S8^:R8B0O7]mOX1n
O7]lO7eoPH>4Q8:0OginOGeoOW]gMGAdMGAcL6eZJFUYK71bM7MiN7MgMgMhN7Qg
MG9_K6MSH5iOHfAVJVe_LWEhNGQhMW=dMGEeMgMhN7MfKfi`LGEeLg9bM7MkOWik
NWQfMG9`LWIkPHF6PWmoPHF:S8V4PH63QhV8R8R8R8Z;Rhf?TI:DU96=RHV@UiZI
UiZLVYZIUiNESh^8QH1lOHF=TY6?SHb=S8Z7Q8:2Q8J3OWMcLG9cLW1/K75hOH22
OgemP8:3Ph60PhN;RXF0OGaoPXF5QXR;T9BFUYRFU9FEUiJ@S8jATY6ASXf@UYbO
X:6OWinNW9fNX:FWYZ:MVIVJViRDTHf?UIZKViVHUiNFThn<S8^9RHN8QX62PXB4
PhB1OX1oOgmmNgIaL75bLg5^JVMXJV]/KVaZJVQTHfIYKFeYJVUXIfMVIFIVIFET
IVMWJ6UYJFUYKgMlNgYlOWimNgE_K6a/JVQVI6EWKW=bKV][KgEjO7aoPXB4Q85i
LgAjOX1nNgf4RX^;R8N7QXF7Rhb<SI2FW:2NUH^4R96DU9:?SY2EV9RBRhJ6S92B
TY6ATI2?SHZ5PGmnOh>6Q8>3Qh^<RXN1OX64Q8=nOX23OgYmPhF7QhR8R8Z:Rh^<
Si2BU96=SHj@SHR4P7n0Q8Z:RX^=Rh^?TI2?RXJ6RHf=RhJ6RXN2OWf0QHZ<RXR;
T9:CThj8QXJ8R8Z:RH^>SHR6S8n<R8J7RHZ9RHV:SI2ARh>0OgalNgUhMGAbLG=e
Lg5`Kf]XJFY^LWMjNG=]Jf][J6MWJ6Y^LgIeLG1`Kg1dMWMmP7emOgmlNgelNWak
OhN:RhV5Og]mPh^AU9FCT8b8RXV0NWMjP8J=Si6ET8j?SiB>QY6BS8^;SXMlNGUm
NWYoOgejNGf2Q8N2OGn3PXV@RXB0OGaeLgE`IfAXLgYiL6meLgAdNWR0R8:0NgQj
MWAgO8:0OX>7Rhj@TIBARhZ?VZFUXI^MX9RBTYFCTY^Y/:bUZ:RYZ:BOVifTYj>K
VI>9QH>9SHj7O8B=UIN?S8n9QHF7R8J4P7ioMfiYJ6MUIEiHFfA/K6igLg=lKfM`
LW=ZH6]/J6EUJFAPIVQTJG1dLgEcKVQRKGQgNGIbLG5aJfYXHfEZKFmgMW9hO7Eh
NWMcLg9hO7IfNG5[N85jLH>AS8V;RgijQ8N3O7QiMG^<THZ3LF]`KG^6NW=cMgmo
R8UgIVQlR89eLfQWPXUfN7I[J6YaM7MbLWR0SI:@THnCUY>DT8N6PhB8QXN=UYNN
[JNHUJB/ZJn_];V_Z:BQXYV5S:BVXjNTY9nR/Zn[ZZ:O[KfjZkNh[[:i[Z2U/:ZO
WIV_YH^SZ9bQX8J:XLO3LjOC[9mmJi6HRiF9VYZ7RIF9KXfIPVMaMGRCR8J4OW1W
KV]kLFmiGCM9NGj3KU5IL71WGFAfJE1ZKUI[KF5NJFelMfj=SGb0U9Z8MgfNS8FE
QWAdOG5ZL6efLEaFNhA[IFM/GU9nL5e@C6ACC6AfCE5JBFaH;3IBG69PE6UYF6UO
Ce=RCCiSPeE0LYNML61^O9]hKY9iPYE_MiR1UK:AP7ZH`9ZD/YREVi>[/9NEVIfU
[JR3WLSA/8^hb;JIV;BeWH62PYFg[:RDPj2[/kN]YHafR;ZgPfmoQ9:bYG^O]8NZ
Z8S3YV^N[JMmIgNBRgETFgn2SjE_JZ63Jfj=V7UfPF=?L6]XMg9VIH9hGfiH@VQS
@7ZAIVMeRGY<HYj9H8]gJ8Z2L6mWI79JHY24KiInL7aHEH=mGemaO7=[N7=ADVIQ
JGn7QGMmH6QeM7mcKfQeMg:2P6eNKh5TLGI`Mf9WNeil/WaTUgj1Z8^FXG9/RHFd
Z8:cXH2a[7b>ZlG__j2n^YZL[[>ZTHJbdJJ?YjN`dlROTjS8YY?@`;2CQZfTOZ>/
UJFCNVZ5UifPP82GRX:@PXNHPh=gDEmkV8Y_JWmkK6n5TVeGJ:jKFXBjPFB4LEi`
P9NCJW^2GFijLF]THUE?P9m_GGf<TVe6D5]QEeEQ@4ePB4i6LhPh>g=IP;JGMViT
IeARJTe[IcY;HT=;E65oR7Y7@e9CGgf9ICi6GEifR8IiDBleMI=><hRLJ85mEgj[
Z:REJW6;Ohg3_Y5XLk3?W9>UUjf`]L:fbJUdT92<[j^9S:C2bJFCQ:2m[jBPPiG=
iN>gUZ:/WIn_/WUY]m6SO726`:1STk6FW[NQIH?D`7a/QZbb]/R?KYN5NieUGX68
X8V2QGb`fIanGT1WPGn4OG=PHHJMS8F`c<JHPJ>lTFMRMF]DGVQA@7F/WFeECW6R
SUi5?4m]MG1MFF1ZKGAMCEicMgA[FVIZGgB:P7mK@DiGH6n4TWmCDGf^U6MFEEUE
BFMjI7J8O75gMfZ7WHEfM6J1Uf1LVjYmFG6S[<7?XI^lc/c8_jmoUKVLTWj2YXi`
QjRZWg]hQEU_UH26TIR7N9NZRFAJK9B7Gf=gU:NCJE]hSZFVQX2<TX:;/jjHRHB7
RX:0NhJ?MXRISHJ5P9bDRJkGh/Jlf]>5DTYHDU1[Lgn<OhRJQUeNIDaWRUa@LFI2
82DI000A9cI>HUHnBUEDHDXcA6>FU5mJR9EmFe]WEV]gR[^WTZ^^VhJR^GIQVin?
[i]gMY:i_;n[Q:cCc;FQUWmlT:26OH5TLXnBUI2?S9:RZZZYVhZ8PGegNHJBUijK
Z<K>/jcAg;BKUWibPi2FSGR1P8J@PG=^Lik3YH:A[ZF=Ngj1IeIPM8f9MG1fTi9h
QgQZKV9_RHn8V[oRo>gHfL^dRU=MGca@RjZJLh>CKEQ@J9Z=DE1DBE]:<0h000lC
8A/J9CY]X9RETf]FCdUHHVEOHVm[LWmlLX>JS8jBX/O3_lW:/hU/L8bLN5=XPXVO
[jVbTV5jVWaTL7=gNWJ1P7QcOhigIWF2S92;T9ZSY7iKLi6QV7nB[[O1]J>LOXRT
MF^3Jg2AVi=jMgj4Uhb9WY:3Ui:1R7eTE4e;Cg:<LVafM7iaL8B<S8JJ/[WVoool
kMG1QeARLgQWEh:DNfMPJW9^N8j9KVAnU7m4=S``>D8m=CLi>Ta/SK>oUVj0X9V>
KE]gQ7I]N7b8Pg>6WJ2LUjcUo>74cMJl][n]WIn=OHnb[Z2LMVV?X8ekLG]bEVR3
LTHlBe=NDCM4GVemTjFVY9B>UIFQUh=kKgMjKW=iQ9V:Oif>MInhWYF@RhU`K96W
PeYEDVF?WY^JVYB@W9F=V7iAC7>HU86?Z/Kcoooof;:;Qj5mEV9KE6E^IEHj:TYn
TW5OK6=nYXUO>B4R4P<6000064UaR8aoMhNN]Jf1MHbKXj6QYJ6BPiJXTXZHXL?S
i^C>/kN/Rh62RGQULG1]PFiHKGYXFVAYFfFBYj:5Ff5iPI2CO69QOiJFU9nSS82I
UgUWHG69RWYnOfEUJWV:OWf6R92BQH1mP::VRXYnNHI`HgA_F5acTi9`JiBWPVR6
^/KCoooW^;ZdR7=eJ514EF1ILGiOKX5RH6Y;>d]NHe0l;BTW60X74AHE;TMVWKbW
OhFUamO5]Z6DUXjW`IAPDdU@JXJKV9bjg^cC[Zbd^<gA]YUoNGmfKFYTG5QgZ;bT
QiZaXJBk/YUlJGN=S6QPL6ehTjNj^[2e`]7JkOcI[JnhYiV9O8N4NINSU8bB[KNc
dm:SSYVb]IV1MWYhNHfFSg5JMiJ;PIg=oooWg=_8Z8McId<I5@/05c4900005S]<
CdY>GVUkODPF2P@000L<7bHWAEaOJgYnRYBMZJJMT8ZCVIEnI54k@6=lMVUaNWJ7
XInJV9^//Z6ISfmMGUQEGFQ/Ge1TPH1[EfZAYJRSV969OX>9Q79QKHRETiZHV[2l
]JB[/JR`ZYVLXI:<Th5[LhbLV9NL[[f_YJNT]M7=^9nOc/^FU:N/];c3d>kniLcD
e[FGTXEbLWEaNGM[EblfEUYBDem[KVARM85aG5I9<Ra0F4HX;dEDE65_If5YQJRT
RXB;QY>i_IZ5QhR4KVQnQg9aPhJ>UGi]Q9VJT8=kOX^BOF5ZNg1LEVadEEEhQXB7
S9VOU96KYJBNViZ=OWf4PGEfPWn=Z9f3OHZNYiR6RijOWZ^QTI:?RHUlLWj8QY>O
W9J9Rj^h/jfRWjFkfnkS`jblbkZob:V3PHMgKVaQCS/lD5mB>Rdc>cPm@TLm:C0l
<BT`;B/e@5E`MF9HKWn9Sh1jPXVMZJJc^ZVDTjRbWXJ6X[NRTI^DU:jcXi>0Rjf]
WXn0M6YdL5M3>TACDde=GW=aJF]`KV5JJgYgMFQEHWZ0Qi22NG]iPinURXJGW9N5
PHR4MVajS85hP8N=TYZY/9jCVIN@UYZRYY:A^>3il]C?i>C6[ZVQVI^AN7F2OEdh
=D93?cU4CTA7D4iMIUQG@bdj@c`iCfMPDem`LfmbRj6Z^/:g^MOZj=k;_<72]k>`
Xj2c_[g1^[:i`<77eM[E`jR=Ng^6PgIYGUUFD4DnB5aRKWY[IGV1NGj0NGE[Jg=d
M7AkOG1[NXV4NXJGT826VIF8Q7]dMFAGIG9aMgYQFfmnSHIcNX^HViN[bMOOh=K8
_Kfn/::KRF]MIW5eI44b>c/fADY7A2hU;CU6?bd[:b<N3@003B4Y<ce6Ad]QNYRb
/JBU/ko4`l32_ZbQUY6EShN:SYBR/;S1`K^o_ZZHU9NGTXE`IV]K@3m@C3L`=TEO
KVmWJ7n7O8:=S8f>RHnMYZ^/[[>dZiZBUJBc/JNY[Jbe^KF_YZ6CR8^?W:RVYjf[
XifP[kBb^m7Tj^[Nf>WafL?3/H9[MgU]J61CB414B3hg>Shk<c4mDU51?Chb:R0<
0PdQ9R8X>4mOGF1`Q9f][;32c=7Kf<Vo]JjYVhj9QHRIYjJLUINSZk6j`KZSUinH
OVmdOGAJ@d16?c8];d9FCdE;E69iQi6IUI:P/kJZZ;6`ZZNZ[:6DU9NGTHj9SIN;
O8:8OWIfNh:4OG5cR:FUSY2PZKBg`mcSeM3Qjmc;akbQT8IkN824M5Y7@deBBT=6
CeA=CeI4<cDk>34X6aTM5aPN9Bdc>dI?DEQcT9ZPYJR_^;bm`LBhYj2TZjBCR8Am
OXV>SI>@T:6TVY><TZ2JQgE`MgAUG5=4>SDc:B4X;S90C5ATLgQjRYVBUk2cYjRY
YJRYZJNETYB;PG5ULh>5P7b5RhR<TY^VYJNf_;6VZ;S:go3^hM[Kel[=eLZeYi^:
R9NBMF5KH6=JCDA7CEENHEeCBU1JDDE2ADUHHUYDFF=ZJVa[JG>0S9bX/[g0b=GI
gMW:b]WLg>7D_kNh];2i/YjHVYZ@S9><Qi>ITX9aK7IiL6MHB4Q:BdHg?T@f=D=?
FEmQJGZ3QY^`[Y^<TYjCOWEeNWI/J6]XJ6]ZJEmEFf5[OHJ=VIbEUIbNXjFT[[[:
fL^o`kng^/2VNf]YJ6edKU]BDe5CCcloBT/n>T93AdM9Dddn>ce7B3@Y>TY5?D1@
G6=UHfMaNXRHX:R[YJNb_<?2^k>_Y96@XZj]Y9fOYj2BSi:JWHj2OhRHVI6:PGel
MfePEeICDeUPGE]QIVmcJ6=bSZJWXZk6dL>c];VcZijIWYbHThn@SXMnO8NCWjVV
XJVaZjNcalZo`<_HiN[QfnS]fm3?`jjIRGaeKeU1@TLl;c4m>RTL7bH[<BlZ;cHg
>chk?4UDCDQAEDY3CUULHfabN7]iKFj7V9fZ]L35`;Vg`LNo/JR]]K2RXjZUVX^4
Q7Y`Lg=`MgegJF1SIfAJEUaNDdYDEU5IG5iXL7AhNX29TY69T9ZKVi^KVIJCRhF7
RHb;P7R0V:NRViVMWYjMVY^MWZ:UYJZlcMKBb<2eZk;2`JnQWj2IRgYaKF5EC44k
Ad`k:RTc@48l>S/k=cQ6B4=2AE9NG5=<D5mTI65SM8B7QY>]`L>k[:>//K2c^[fg
[jZVX9jSYjFHRWifQ9B=QHN<T8n5M6AMG5aQHF5TH5MCCTQ;Ce5FFEYUOHjBTIFV
]kBTW:2]]kZ`WIRHSXJ2PXF4RiJ@QhF:T9VRYJFZ/kNc];W2c]GLgM[Sh/o1_;^^
V8j7PWQXGeeC?S0g@3/d>3`m@TiEEf5/IUE8@daGF5AAE5YTKVUKD4mFEUIUN8RK
Z[>e]l35c]GAblcIh=G?eMW<`<2hZ9^?QH>1Oh>8Q7]dJ5UMKFaMFUiGC4aBEEEE
CDI3?d17CDmFI6ieOh9kNhFAVYbGUYZCQH>=U9fLRh>4MVMWKW=hOXJ<SXj<SXj>
UI^U];o7d=GEdl_5akfRTYJCQH1jIdm2?d14?2TN828Z>DE7ADI6Ae=NGUMFGVM^
K6M[MWATHg1eMWUkP8V:QX^FX::SZZVV//C4^[g0^KJi_L;1^;2YYY^;OG1aNWf1
Qh=fIEaRJfYPGV=XKG5eNgn0OGf1QHbATI>KYk2/YZZ`ZYfOZ:b][jn]ZYn>R8nL
WY:=S8Z;TYJGW9fMY:ZUXjnka<[:b<_>cLBfZj2ERgeaIemHC3d[92lh=Bl`:QXI
9R`d?c/f>3Hc=Se1A4Y5@DQ?DEMQHfUdMgMhQ9BEU9f[];c:clJn_Kbo`;bm_[Ne
_KJOTY2;P7E_Jfa`KFITIFQ]KVUYKfi/KfmWGUaTJFQTED]@E5UQHV5WLW1/N8fN
ZJjZXZ2SW9NQZJ>NXJ2IUYfITI6>QXRAV9^HUj:b][O1cL[5c=CGe]SEa;>[Z:NN
RWQWFEIBBd4b:BDQ8B<T81hZ>D92@DI@FEmQHfMWI65RHUmOIFaWHfQ/KW5lSYBB
TYBGWZVja/G6cLc6`kni/JJPViF>R89fK6YVHF1QGEMLIFacMFm/L7IhN7IgNGYn
Ng5VHFA[Kfm[JW=jP8N;R8bMY:>TZK:dZjR_/kNi][Bh^;2ZXYbJW:2MWZ:QY;?2
a/;3a/C6b/W6_k6QVifFQ75SETXo=S8]9b0H6RD`<c0hA4Q9CEMNK7f6Rhn?S8J5
RHN6SiZKUYF@SIFIUiJDUYnY]<7;dLo;cM3?cLc=a[J/YIfCR7mgKFAEBDQ@EDm4
>SU1ATM<Ee]HEUMGEeUIEU5@BdQ@EE5;CUIGG6M[K7:0S96HWYbIVI^IV9^LX::N
WInOV9BEV9ZIVYjOZ[Zk];G1al6l_kf[W9^KW9B8MfIMEde3>c@Z8b0L7bdd=STk
@DE:DeeVKFmcNWelOgmkMG9dM6i_M7=_KgEoQhR:UZ6X/;Fk`lS@dm?Ig]O=aKbb
[jfVW9JIUHV1O7]gL6aXIVeeMWAdMGMkO7]fL6]XJFQXKGEjNgMeNhB:SYNKUYVR
ZK2d]K[0`KZ^[KFh][6ZZ:VVWHn4PGijNX>=TIVOXJJXYZbd^K2NVIV?Qgi`HUiI
BC<U6a8;20H531TQ:cHmAd]>FF=WJg60TI>=SHZ6Q7]bMGIaKFMYMhB9QGUgPi2I
WjRc^l39c/c8alc@c/>f[JJSVi6>R7][FTY5@cli=cTnAe5DCdQ8DUeMFeeSK6iZ
JVidM7Z6QGn4S9:EU9NLYJja/;6i`Kni]KFl_[Vf/JJPXZRZXYRFWJFVYjZY/<;5
_;Rg]K:YXJJ_ZInCQGacJ6APE4<i=cDc<C0c>d51>SDiAe9?CUEMIf]ZIfARI6]^
Jf9RJFMTIfe_M7f6QXR?UI^JUYFN[;6`/:fXZJj`/:nUV96<QH:2O75ZJ6EPG5QC
C4I2AdmBEeQDEe]JF5QTMGn1Q8N>UY^OYZZXZ:b_/;>g^KRh]JfSW9FBTI>FV9JA
SHZ:SiFMY:Za];Fla<2i]kRl_KZe[:6CQWibJEm@BD8e<cHh?417Bde@CeQUJg9n
Ph1lOX62Q8F3QXJ3QXb<Q7j2OWMlQHbCU9RSZ:VZZZjc];Bc/KFl`LC1]J>DRHJ7
PgEXIEmKFEE@A3`k>Sho?TQ?CTY8C4a9CeMJFeYHF5]TL7UkNW^3SHnCVijIV:N^
YIfGUYnUY:2JUiJDUiVMXInHUIf^_<C2^[^n_LC9aKfe/kBb[In>Qge`IUU?CE5>
?c8/:BHZ=C`i>Sm0ATi@D59GHFY/Jfa`Lg5dOGYeN7UjOX:5QhF5RI>QY::X[[O2
aLG8cLo9`Kbna<O4^jnRThZ7PGM_J6=RGUQNIfAIEUUED5EMH6I[K6][KW5gOH:;
UIJIYJj_ZJN[Yj2LV9ZJTXb;SI:ARhF0Q8V4P866Si:CVJ:YZZVa^;B[Xj>XZjjZ
WYV>OWI/HUaEC3ld;BDO8R`g?417Bde@DeUTK6iaNGeoQhYnN7n5QH5mOH:6R8Z;
S8R8Si:GWInW[kJn`<31_;>][;>i^;>_ZJ>UYiV1L6QQFE17BE5BCTe<ACm5DEQG
EUYSKG1aN7YcLWj7RXfFVinV[:nb]KVg[ZZa][:YY:RYXIbIUiJIViVCSY6HVYNI
Y[Fi_/G0]K2^[K2^XIRJVHb2OgERCcha9R<S8R8Q8B<W;c0W8b4R;CHf?4]EDU5F
EUIRL7A`KW1_KV]XJfYUHfAWKgZ7S8^BWZ>TY:F]^<75aLG1_;bj]:RHS8J4OgYi
MFUSH5E;BU1EEemRGEYLGf=RI6miPHB<VYnOXJ:UZ:^`[Z6KX:FYZZJSXZ6NVIJD
UibNWZ2PXJ:NWZN`^LC:aKk0a<K=bl6k^;Ji_;RZVY6:N6MMEDm=CTLm?T52A4A1
A4iGFEeVJFUaNWUhO7j3RHb=SXf3Ngn2Ogj4S9BKV9BJXj:NVYNEV:2UYZJVY:B[
[JBIT8^4OgioPGm]FE=@BTE0?3m2?3<b=3U0A4E6Be=LIgJ4QhJ<VZV_[Z^ZZjf^
/:bUY:6ETYZLThR0O7]jN7YmMW5jRYVOXjJWYj^f_kfg^/;4_kNd^kVTS7UYG55:
Ad<l=C@f=STf<30d>ci4DU]LG5]PJfe/L75cMGIfLG9oPGEaN7elOH::TYFJXjRZ
Zjbc_<74alW8a;jm_l6n]:bXXj>QThEmMViUIF][HeUFEU=@B4A=De9AE5e/NGem
P8:0P8F<TibOWZ2RYJNRUi6@SH^9QhN1MG9hNWA[Ig24TXn9Sij^]kZl^Jn[/k_1
alFl][:WV8YjJf9KEUI@AC`e=3Dd<S@d;C0lA4Q>EEeUL7MiNGAcO8B5QXF2PHJ=
Shj?T9:GVi^JV9NFW:^e]K>e][W0`;bg[JFVZJZXYj>KUHf0M6i]KFYUI6AOFeaQ
GeE>Bd]AG6EZKgMmQHnFV9^SZk>g]JfZ[k2_[:FHS8R4P7]iOX5iM7MmPhF5R8f@
UJ2//kJc/;K5clo@d/Zk/JNGRXAjJUiKETa1=bXP6QD@4QPG6R@_=3Hh=CU7Ce5D
FV5TIfY]KV]SFUQMIFa_L7IoQXF4R8Z:T9^UZjVVZKG0_[:YZZj`/KJg/:RWZjRM
THJ1OgafJV1LF5=<Ad]CE5EJHVacMgUkQHf>TIFKXjNZ/;6XWYZIVINBS8f@SXf=
QX63QHJ7Rhn@U9^W^<G7`ko2b<kGg^;Md<W=bKBNTHQoMf]KDDe:AT0m?CTd=STh
>dA<DeUMGF9[Kfm`L6e`MGIhOhB8T9NFUI^OViVET8nBUYZS[:VSYJba]KFbZZBW
Zjfa]:jPUI6>QWYbL6i/JEmDDE18>c<_;c0c<cU4BU5KIFi_KG1hQI2IXk6m_KVf
[ZJNThJ2QXR8R8=lMWIeM7V0OgaoQiFR[K6]/[o2_lSEeLg2^[JaXY>=RGibIe]C
C4Dn<bXU81hX=C@`<SDh@dY6BEQQHVQ_LWAeKfEUJVQWKgMjNgaoQHR3OX>>UIJG
VZ:_^Kg0a;b]Zk>e]kVj^;Ni]JbWYJ2BQ7efM7=/IUiFDe1<BDI7BDiCEUYQIfY_
MGYoQI6MY:^a/JjUVIFDTI:=Ph67QWikNgf2R8Z:RXjBUj:a/:>T[J^]^/;3`Kbh
/ZZRVi:9Q7edK6AJDDTo>3<]9BL`=ce2ATmGH6UcOGahO864R8j?S92IVYJHWZ:T
YZJUXYnNXjVYZ:V//KJe]KBVUiNQZZ^/[Jb[ZJBMUiFBRhF4Q85hJV=ODT<n?3Tj
?D9:E5UIFUePHVAXLXBIYJV]]KVf/k:^Yj>RXZ:QX9jGSXj@QgmmOGMbMWb8UIZM
XJR]YJNh_kfo`KZb][JYWIN;NVYOF4e1=BHP8AXB51PB3Q8F72La<c]7Bd]?DE9I
GeUEHVaWJWMoPHF4OWYkMg=iPhV>UY^LXZ^a];6/ZZjd^/?=b/G3`;bg/ZRMV9:;
QGilMFYSHEmJDe=GFemSHV9WJVY^LgMmPhN=UIbJUYRNXYnMViB@Shn>RhN5QhbC
VIbIUINJXJZb][Jd]K[3b<g?cLVn[ZV^ZJ>QWYJ7O7]kLfIJDDM0?Si3B4=0@49;
DU1?F65RHfijPXJ8S9BLWIRMZJjZY9nIUIFCUIVIUY2<RXR:S8R8QGmmP8J=TH^5
RHZ7QhbAU9>?RGigMG5SEDm7?C`i>3Xh=CTl?Ci2BEANIG61S9VVZJBRXjBSW9JG
UYFFThb9QhAnNgUfNGYhO8J@Uj:[ZjNU[KVn`<O9a<;1_;Ne[j6GS7a`Iee?AT0f
:b8M6APN8R4T;3<lAe1JIFEMGFM[J6U[KW=lPX:4RXZ5P825SI>JXZ^`[jRY/;Bf
/jfXY:>V[[Rm_kng/k:a/[6`[JRTXj:LThZ3OWAWGemOFUUKFEIDDe9ADUAEFEmQ
IFY]LgMiOhF6QHN;SHjAU9RLWZ2RXYjGSXZ9SY>DUijWZjjja<C4alS8alS8bl[6
`;R^Y9AnKfMMDT@e;c0`<3@h=2l_<3<jADeCGVEYKG9lQH^AUY^NXZ^`[JNSXIjK
ViRHV960LWF3RXN2PHB4PhVCVYfNViVNXZBUZ:bXWIFDTHIkM7=fLFMTIfUXIV5M
FeQEEe]PJ71fOhV<RX^>TY:@TYNMXJ:NV9RKVYF<QXF8R8=mOHB>UI>@ShjDWjRa
][6^/KJj^[RaZjVQVINERg]YH5mGBC/^9B4N6a`M61<F6b0T8QdO:c8a>DUHHf]d
NX25Q8B7RHR9SI>HWjBTXIZDUIbRX9ZIUiNLXjJZ[JVUYZZ][:Z_][Zf/k>`[J^T
WI63N75`Jf9JDDY4@3di>Ci3A4YJI6U]LW^2Qhf@TYJJW9^PYjfb]kbo_KBZXj2T
ZjbUX9jJVZB_][Rd/[2^]l?7a/gJf]OId/>fZ9fAP7IYFeA:@3/j=B/Z:B8Q9bHW
<Ce0@dmHGFAXJW5iOhB?V9ZMXjBSXZ6OViJ@S8f>RhF2P7Q`KVe^LgMhOH>8SI>F
V9^ITi:FTh^6QhV8PgikMFaVHUeIEeA?CUIOIFU[JFARIFU^L79eMGAhP8F9S8j@
T9:EUYRJU8b;TIRHUIFCRX5oQ8jJXZBUYjf_ZJRa];6`];Jf/ZVRXIb?P7E_JV5G
De5AD4Ln?Cdb8A`K5aHJ82Pb>d58DEIKIFicNH2:UJ2[];Zi/JVY[[6`[JNLUYRG
V:6RViBBUY^QXjB[[J^^/K:`[k6a[JVTXj>TXYbDSXZ4NVaNF5=>CDi@Cde@DeQL
Gf=WJW1oS9:HXJJY[K:d/:JKTY6FWIjIUI:>RhR9SY6ATI>HWJ2V[[>f^K^m`<?0
^;Vl^[2VWi^ES7mbKFYQDdQ1>C@e=38a<2ha=c/oAD]BGfY]KWAiNgeoPhZATXf:
SYFIUiNHUi66Oh26QX>3QHF6QHN>THf6QH^@TY2BVJ2RXjNWY9nITXb8Q7mlNgaj
M6m/IUeGFEmQHV=QHF9TIfMUIV]eP8F6RiFMWYZJWj>RWIZESXV6QHR9QWmkNWUi
OH:4QHV=Tj6[ZZR//ZnZZJFLUi>=QHB5OFeSG4/j<R`R6Q@=2`h?3a4@3Q@N9BL/
=D9BHVmkS9^PX::X[K:h_;^g[jRXZjNRWI^JVINDU9RMXZ^d^KRd/K:f^;Vj^KFc
/k>b/JnYX9N=Q7]jNgUeKVYWIF5OG5E@E5mXKgAgNWn6SYZSY:>PWYfNXJFWY9fF
Shb=T92;QXF6R8bCWjR][Zn`/kFd^/73`/C7aL:o]jjZZJJNTh^3NWIcJem@ATE6
@c/h=BhZ<3Li?3dl?45:DUURIfIZLWQmPhR5Ph9nOXNBUI2;Qh>2Ph>3OWI_K6ec
MWEhO7n2PhF8SI6ATYJMYZ^ZZZb[Y9jHT8QoNG9ZHeaECT]:AdI9BD]>DEIOJWN1
QXR=TY:FVY^LVibNY:^_[jZUXIZ@RXJ3PhB5RHf;QH64Rhb<TYVLWZ:UYJfe/:JP
V8YoN71TF5A@B3lj>3D`;RXX:RTX;SY3BUAMIVe_KgAkPHNAVj:X[:f_];Zg/:n_
[JVVY::TZZb/[:>IUibRZ:b/Z:V][Zb/[:fYXIfKW9fLWI^DSXV2O7MeL6MQGEQG
Fe]FDe9@Ce5FEe5=DU]SK7=hOX62PhF:SH^:SYFLWYnSYjNUYJNVXY^HWZJ[[:VU
YJJNUiZRZ:fa/;2b/kFi]:ROVIJDT8^5MVQQFE19?bhO5a<B628W9bL]=3e4BDaA
EeeUKWEnQhf>SHj>S8^=SXf;RHV;RHJ6QhJ3P8>6RH^7Q8bIYJfa/[Bh_L;7a[nl
_;Rb[JJKTHb6OWEZH5aKF5IGGVEUHF1PHVAWJg1bM7MlP8F7QH5nO7UhNh24QXR:
Si29PGakNgUhN7UlPXV>SiNSY:2SZZRRYJNUY:FUX9^HThQnO7IZHUeDDEADD5AL
GeeJE4a9BTeEGEeGF5iPH6AVIVYbMg^6Si>JXZBQWY^GUY^OX:2OWInSXi^EU9>?
SHnBTYBJWj2OWj2LV9ZMV9FDTiJKWI^GTi2=RX^<Q7I/J6APGeiLEe9@DeMJH6EY
LGb3RI6IX:R//K>b/[Jj_[nn^kJ^Yj2GSh^@VYbIW:6OW:FYWiVNXZ:V/;Ba/kBa
/;:[WY::PgYfMFaOET`o=c8U6APE2`P>4aPR:bda>3Th?deGFf9YKG5hNWUoPgmo
PhN:S8b7R96HWJ2TXinOXZ6LUiNNY:NXZJVTWYVFU9BCSXZ9QXF:SXn;PWYgMG5b
MGIfM7=dMWMeL6]XI5iKGf=TIFY_MGYkO7n4Ri2FVj6VZ:NSXJBUXYbIU8f;RhN4
QhfBTXjAV9F@UIbMWZ>UYJfa[Jjd]JfQW9jKV9ZFS8N1LVEPED8i>3@a;b`/<3Dh
?DI>DUEJHFYePHN;TIFBS8Z;SI>EUIVITi>JVYBBThn:RHZ9R8N5QHV;R89oOWj2
RYFJVYVFTi>EV9NARhJ3OgUgMgIeMgMdM7MfM79aLgAcLgEgNWenOWj0Ph9nO8B@
VZ:XZJBQXZ:NViZGTXb9S8j=RXF4QhJ6RHJ7UIbMZkRg[J^]ZJR[Z:BOV9><Pgmm
M6i/HE==BTI5AChi>c/h=S@c<S@c<CI0AdQ<EF5^N7n6SI2DVZ2SXZB//:f/[:NO
VYVJVIB;QHJ:RX^@Ti>>RHB1PHF8QhN;S8V7RHj?TI:ATYFIWIjKUI6>S8R3OGM`
JfQVHV5PGUmQIF]/KW1dNGb0Qhb?TiNGUI2=S8ElMGMlO7]nQ8V8Qhb?Shj9QhbC
W:2TYj6MWYnQX::WYjR][ZZVWYJ?RX^7OWQbK6U[JEiFDT]3@Clo@494B4eADeUQ
IfY]LgIbLg^3QhZAUijPViJEUYFGWjJYY9^DT8j>SH^7Q89oOhB:SY2EW9fIV9ZK
VYbRYjNVY:6OWj6SXZ2MVI>=RXf@SHV5OG=ZJ6YXI69SHfEXKgMkNgYnQX^<Rhb:
RHfEVIJ?RH=nN7UnO7IgNWMbMG]lNWUiNgioPXB7QhB8T9:BUI^MW9jOVYJGU8b9
Rhb5O7AXGeaKFUQDCDU;CDa;Ce=@BdY<CU5BE5MHG69XKW5aM7MiOXF;SiFJUi2=
RhR5Q81kN7UlP8:0PHN;S92CUIFJXJ2JVIfSY:FZZjRVXinMW9^IUY:?SXb7OgUe
LW5`Kg1`LG=eMGEgOHJ>UYZJUYJLYjj`/JjVW9B@SXb6Ph:0OWn3PG]lPhF3QHZ<
RhjHXJ>PW9fPVI2AUIJHX:JUXjJXXIZIVYB8P85oMfmWHEeECDM2>cU0Ada@CdY5
@dA8B4Q7BDY:CE9DEUeTJfmbMWalNh:<TiBEUI>CU9FDShb:Rhj?TI>DUYRHUY:B
UiVGUYRHUY>BTi:?RXF3QX^;RXR5Q8F9SHf;RHV9RHZ;R89mNGEeN7MeMgYmPH60
Q8R9QhN:RhR3OginOX1oOh64QhN8RXZ<S8b=T9BJVYJIX:JWZ:VWZJVUXZ>UY::Q
XZ:QX:6PWIN?R8=nNWMeM71ZHUYEDU5>C4]:BT]?DDe8Ad]=C4a8A4A<F5iQIFab
M7QnQHb?TINMXjVXXIZFU9:=QhB4Q8>0Oh64QHJ9RH>0PHF:RhR1Ng^0Qh^<RhV5
Ph>4PgmnOWn0OgmoO7IcMgeoOWj0PXN;RhZ<SY2CV9J@SXnATY:BU9BCUIRKWYjK
VY^KVYNCTiFBT92<QH>8SHnDUY>BTXn>TI>CU9FFVIVGVIjNVINCSXb6OGUhMW1/
JVMSHf=PFEAFFeYJG61QGeaIFE]NI6Y/KW5cM7AdMGMhMG5aMGMjOWmoPHF8Rh^9
QhJ5RI2DU9BDSXJ1OWQdLVeVH5iPIFMXJFieNh66S9:IWjBRWIjQWYRIVIBASXR5
QXZ:RX^<SY6EV9VJW9fJUYJETHn>RhJ1PHF8RH^8Ph:3QHN8RHV9Pg]jNWYgMWb0
QXjBTi2?TiFFUXn8QHR=SHR5QhN5PWikNWf2QX^@TiB@RH=nNgQdKf][JV9HEEEE
F5YKFEIHHFYaMWA`LW^4QXF6R8V8QhN:TIFHUXn<SXf:R8R8R8N6Q81mNgf0OGMe
MGAbL6iaNGn1P8>=UiZIUIBETi:BTY:@RhN7Qh9nOGakOGn3S8j8P7MbMG]nQ8N3
OGQdLgMlOhJ:RX^=T9BCTHj>Shb7QHB5R8R7Q8B5Qhb?T9FGVYnPXJFZZJBRXZ:U
YJBSXj2HShZ7QX>0OgafLgAeLF]VHV1RHemOH5iIEE=ACdm@E5IEE5IIFEMBD51B
E5EEEUUNHF=/NhJ:RXZ<RXfCTi:CUIRDS8EoNgaoPhR?U9NIWZ>Y[:b^[Zb/[KFl
^K>ZXj6MVIVMWIR@RXN4QHV=SXj<R8N6PGQcLgEhNWQeM7MlNWMkNgQhNG]mOX22
PX64SI:BShR3Q8J6QhV>TI2@TiNFTiB@RHR<TIJEUIF=R8N8S8f>SXR5QH:0P81l
Lf]XIfEPFeaMG5UFEE9@EEMFEUMIFEIEF5UHFEMBDeYRJg5cM7QoQHjDUiZJUHn>
RhEnNWMbLGAhOhB4PH22QhnBUYnUY:6OViNFVIVHUY6BUI6=RhV7RHV5PhB8RhN6
RX^8QX5mOGn2R8R5T9RFV9NCT9JJVYjRYJBMUibPVYVKUY>BT96EVYjNVYFFVYfP
XjFSWiZFU9FBS8J3QHR:RHJ5Q7iiN7MfLVYWHemQHEeDCDY:BTY<CD]<DeQDC4M:
CE5HF5QPHemMG5eOHFEUHf]cNhJ@Ti:BTYNEShj@T8Z2OGUaJFa_KFidNXFBV9fT
ZJb_/:bWYJ>QWY^ERhN2Ng^2RX^;R8J;SH^6PHF8P82;SY:ASY>DUYbNXJ:PXJ>S
ZK6`Z:>TYZJSWj:XZZZVY:>RXjV][:j[YZ>VZ:FRXZ6OV8f6PX20PX9kMGAdKFQ/
L6MUIVI[I5aIEE5BEeUGDT]1>SLd<Bl_;2d`<CHj?413A492@dUBFFA`M7=gOX26
Si6@T96ASh^9PgigL6m_LWIfMGj<UY^JWZ2RY:fl`[jm_Kjk[Z6IThj:R8>1QXEl
M79^KgIlOgYfMgYnPXZ<S9:@S92IWInRXZF//:^^]:nYYZN_ZjBVYZBSZ:FMX:FS
WijPWY^IV:>XXj>VYYjFTXf8RH^:R8R:QXB2PGYcMVmWHUQBCdQ4AdmCEUeMFeaI
F65YJFAVKF]^MWMhNgAdMfa/L7ImNVm[K6ecL6YTGUeMFEYHE5AJHfI`MW5aO81n
QHZ:Ri>DRHR>SX5_JfecLg1nR8>0P7eoRHZ6Rhf=SiRSZJRRW9BKXZ:PTHN7SYBM
Y:>PW9RKY:6LZ;>g^L3:blRo]kRk][>_ZZb`/Jn/[JNITHb;Rh1iNgIUFDQ8C40h
<bl]:RPW;3@d:bT[<Se7DU5BFUUSM7UjO8:?Uj6[Y:2UW9FCSX^7QhAmNW1XLGb3
MeiKCTQBGVYdNXJ@SI>PYJ6X[JNKTI:;Q8^EXZ:CRY>FUIjYYYFIZ:BKS8NH[J^O
PEm/VKW4al>bS7J3SGY?Ag:jl>VeN5ABJWfJc?SooookooGH`l?Bg]:n^;NJMF5N
GfUgJTDP40X60000000610000000000000/K71/R=4IDHF]iV;Bna<O4c<g:akNY
XiNFT9Ve]:^GRXfCThEoV]fYGYBc[ZbWY[;5dl;7g<ZfZI:O^l2aZ[c0/J:S];^h
YHf4OfUMF7:GSgn7Y;RNPY6PW96BTY2;NGQkNG][Hg5iP9:UXY^HU9nVXIVV[k6b
YJ6SW8AgPGmcJ5eJFdPd90T93`0000032000000000XB83@i<3M2B4A4Ef5OIVm/
Jfm^J6IYGF5dKf5_LUaMFee/M6QQKW9]LGMkOX6;Vj>LU8jFYKR/Tj6_]K^j]kbf
ZY^=TI^NY[>fa=3;c=7Ig=3=e]OCcm3Pkogkgm_Zl>SSj>W_oooonoOanooomNk_
l_gomnGSjO;]g]7@blFiZ:FWWXZ0Q7QTLhRM[ZBGQgIjOgMfMgmmL7J4RH1^IfMZ
IeI;C4E3=AlI30hK8bd`914>4`h70aPd;b4]?D@l>30b>RXO9RHW;2`];b@J9S0X
<D4d:1/G6ad[;Ca5>SLd<c@mCda9AdiZLW1^K79dK6EZMhV>XKS4dm_Gbl?Bg/S2
fN_Sd][EcL2RR71cJf1[KFQCC5IMGF=[L8BW]iZBY/;BamCUlOommogok^_oooof
h<>TXkbXSHf5P7UiP8VCRGIgOHJKXIZCTi25Nh5mPG=TP9>;NFmlUI^K[kJVZJNV
/KJo/::MRHF5R8R6PW1SHEa>?RLa@bdG7B`[8aD=7b@S?F23SXnDSXF?X9b7OW]g
NWn5NFYODDY2>2lT6RTX4@lI7A/O6c=PL7=eKVMPIGf@S8F4Nf9TLFAMGfMcNh1b
LX28T9BCSY>FRhbQ/KR`YjR^/:JTZ:BSVHZ4PhN3Lfa[MFaQIfehQY6>S9F[_/73
d^GXjnk^i<noaMC?a/2jZj:Y/[Be^<7>c/G=gN3Vl_ooooooooooooofj]JjZ9nF
P6IOH5A8?D1CGEmSK7F;UIBQXjB_]kk0^kfm_kBIU9V>PVU=?Ca1Ae9MEdi>BUEo
VINAT9bMU8B2OWMdHD4b;RPM4a0A3P@=7R<V;2`dCemQK8BIY::CQH61OGEZFd@m
=R8K81@10000000020dC82hdAE=HHVioUJRf/k2h/Z:LX8mZCdiLGU]E@C8I218X
=R`S8bTb>TiUOX>2TXUeJ61TEdI6D4i:Hg1RGfUePhj?UZJjb]SPiNolooolm_CS
bl>nZhUbM7n1MViTHVUaOHR6QiBJ[L?<d=3?f_3fl>;=cMWId]_[j>3KcLK7`L78
c<_Cf=??b<?1^Jf[Zi^?S9NX]L:jZkC>c[B^/In;QH=/EUYHE5=@@S<`:R/mCTY2
CFE`KgIfL71gLf5=AT<o=R/W9bh_9ahE7CAAHEMIMhnCTijTW96:R8^0JUUAF6MZ
HUA9BU5=@dmSJgJ3QWb3S96SZXUVK8B?R8F3Ng5/OhN0QHn?T:2TWY^V];Ni/ZNT
YIbJXk2d[k_6aL_HlOooooooooSYgLneUh5iIEA=CT]=De1FF59OJEmHJX^JU8Mk
O7YlQh9kNWV0Ng^<TY>FTYJ`a<G2aLoPg/2XYjZIQ85mLea;EVMSED]@GfMXJV]a
OWihO8:<U92@RH5lN7f2RY2CV9bZ[j>X/:Z]^Kf/VinWWX=bJEaBDEEOIUiPL7=_
MWMfNGf:Wk>j_;Zh/J>JTX9`I5e6<ce1?3dl@48l<cQ7D5ANH5I>@R`L7AlP9Q`=
4RHjATeHKh6<S7YXHFIcPhZ@Thb8R8V6M61OGf9^MGYlPiV/[::IR6]GD5a]He9F
I6U[LWf5T9N=RI:Q[:b`[j>TZ9Z<QXbMXJJb^[feZZjaZ[;3`kfo_/;6a<>m^[Ze
`<c8`[^d/Z^UW91oIUUDAcdg<SDd;cA1Cdi<EeeOIVEVKVQFA45@FeA:B51OK71i
Q7m`Fe]]MgMWF5aLETm4?CDa?DU8BEE==3M>F5M>B55FEEUMG5UHD4=8Gg=fKgb@
UXj5Oi2ZYY^FRhAmLfi[IFEZK6e_OiB>QXj:PX::V::VYZfl_;>h^LOWo_oooooo
oooQa[R_XiF=QhN7P8J=PG^8R7f1SXUnLFilOgUeL7=lNgV0U:c1c/g>g>[WinCE
c];EeMC=aL;0b=39`Kf_XjNRUY6ARgUhLfmlOWUeMWf4S8R>Y:bUXj:Q[[k4cM2l
ZJ2JWjZ[[K^gYZ:YZjBMViNBTYREQWn5TjB[XI:>T8f;S9VbbmO>_;6c/9n6HDDh
=4=BFV=WIg1^Fe50;38g<RHM7a`;004=6b/Z61HS>UeeJEQHET`h9bPb=3Lo?c]9
JGb9VZ>JQ7AVI6IJE5IKFDHf=dYLGEIHIGR5R8ElMG9/J6=OJgUkOXF;TIBOZZFK
VInKTiJEUifKVI:AVYnTX9RDUIbOZ;Bd^<?3_/GAh_Kebk34bkNCIDa;D65^JgEk
OhZ=RH1cF45BJem=D5IEFfAfSjBTRWj6V;K9^j:LYJ>ITY>ITHjBV:BVVhn=V:FV
UhEhMWIXG5M?B4U8CeQOKWenNhJBUh^4Si:9O7InRHb>VjbVWYjKThZAUXV1NVmc
NGYfJVYeNh60O8B7PhB8O69GGF9RLXJC]=O5WYBIWHm/Cd8o=c0iDfe]LGQbMVe2
9BTm=Q`U:B0W9QhYAUYFE5QPMi:RTGQfNg]^GVAhQh^>THj@XJbY[[B`VWMXJF9@
B4Y?DTLk?d9@If]VGeePHfEICeaWHUIFIgbHYZV//[fo]jbSYJFJTY2CT9N[/Jjb
_L2g^<>cWIR8M7AgMgMoSIjlfoKok/2_/Zf8Cd9;>D5DG7^HYJNS[;:LL55IKF]C
?Cm9BU1PO9>R/:6?TYRWW79HEF=UEDiKM8^L[:fOWjNZZ:fcXGm^OI:JUH^;VJ>Q
XJ^f]kB_Z:bh`;Za]KNbZ:2SYjbf][c2]JZWZZFNWinKVYJDWZnl^kBcYZ2`^[B]
[kNh[j2BRXJ=WjJjjOoof;Fh^JYhASdc<4E4DG=nTYJAXj>8ESa?IW9K@T4o@daN
OI>TZYZCWkG4[9>:O7n6OWb0TkS=bkRWW964LV]^IUE2AEeQEUMJH6EXL7=aNH=f
I6=WIVEUJWR;Ti6CUIVSWI2ATY>>Rh^<RX5fK6UYIfiYGUiOGemPIfYZLGUdK7Uh
GF=eJVUoX<SQfkf?OiJ:CRLf?cI0@4aYNGiZGFAPDSHO8RdW2P002a0X?eM[LVmY
JW1iP6m;<2TlBD=:HX2HYZj]YZ6IRX9mMFePFf]mR8Z0MGZ6PGj=Rh21OG5_KfQR
IgR3SI^QZ[6^[ZJIUiNGV9^LVIJEWjf]]Kfh`<S:c<C7c/W1_lO<cLnm[[Rd/L;9
e^ooooo9^][@QVI`G5Y_LX2D]L^cWIRNWGUCCVmoFCi;DUQ^RIf/`lJaVHZ>UHIX
CTEADTmJFVR<WYfGTi23Je9:De13@415DeeSJG1eL79lPH5lNWamPhEhLGb;VZbg
[j:ISWm`H5AFF5YOFeIMJgUeJ6QXIF1KGf=XJV1LKGejN8NCWJBHR8>6TH^@]]WN
^8Z:V85692DN6ahO;3MAIddnBDXi6Q8T?4@_:C0/<Se:EVV8THf;QHnJT7mgO7ei
MW1cRJRk]jjZWXQdKg=aI5A;AdA?HVIUKGQkL6Q/MGiiL7EoO6mYKGfEYZ^]/KVj
];Jj]jnWWibLWjbf[9ZAUibIUiZPXY^=R9:HWIjDW[Bh/ZRRZJba];SGooo_a/GK
dYE_PWijSI2PZK38]I>9QGiMB5ekRViII69SIfinS:Nh[:NQWZFKQWIfNWAcMW>3
XK>cYIF9PX=oLfeZHe]DEf=eQ85mQhn:Ph>5QX1]HVa]H65YKGN5Si2;SI:@QG=/
MGj3PHBCV9BCUifNXJ>MY;6_[[Be];Ne[Zbe_kblal_1/JRVZ/CIgLjZVjBOKSQ5
Cc<e?dYHHhF7Jf]YHUE:Ef5WFTMBE4e?D61]NYFLVibGUiF9MFIUHUiNEeedQHMn
MWQfLFADE5MABCX]<45>CE9UMGaiM7=kRHV4R92ETHF0SZJc/Jb_/ZZQVhj9QGAS
FUILJFaZKFaYIF1WMWn0N7IiM75fPXJ0TJRITK6fVIjY/=?/m>Zl]M2WGE=MBDQH
G6]mSiMnJFIPDSPU:dADB4E;@TA>E6R;/LO@clK;cKfZVXj7QHB8TYVZb=?7]JFO
Tg]aP8MiKF1BFF]gNGQoRXf;PgYoRHEgL7=iOXVGYkO2aL2i]K>d[jNPUYFKV96E
X:>LV9RERhV:Ph62PgmaJW1gN7N1TI>J/ZRCViV;RjS;d]oRal7?_GeWRF]4CUAO
IhFTPgJ3M6]LC59VKTe0AS4U:34jAF=eO8b@UIN9MfIOETU>DEAYOhN2NWQfLVQA
C5aLDTm>BDU@BdE:Fg5gL6e^MWUdL6][KF]UHg:5SYBGUHZ0Oh28SH1jNVeSIfUX
KGEiN7MjPhfDW9R=RXV4Q92ETIbVZ:>BSHF4U9BN/l;A^J>l]h9LDd`m?TI9Ben6
R6m_KfAD@CmGIEEBFUEDEeQRLi2b`lS9`[ffWXMoMfm[KGQnS:Jd[j>CSXmlJgN0
NWEbKVQYN7mlP8B=VIfT]<71]JJQWI>@UIb/^kfk]k:c/Z^RX9N:RHB6S8V;Qgj1
Q7n0PGeoPhJ:R8J0MGV3RIRb`;^na;>S/[bc_]S]o??Lf=jkN6AO?2`Z>4e=Mhi/
IVIKD3lb<dM6=Ca1?Si1DEa[SZRg^[Zm]:NCQGe`JWInO8ZS/:ZSWi^JP69JFeQB
BTE3Be]FCU9LKgf0OX^IT8J2P7QXIFM]Q9NIVYVCTINFSi:;O7MdLVe/KFAQIFAU
JFadNgioNVmXIfeeMGF2TY>EWI:>S7R9WiZheMgF[K;I]W9NHdToCU1MJhJ[Wh9l
MVU?;Ba8C3Lb=CA2C5IZNXjIXJ^VXZNINVeVG5USLgZ1TYnITXn;SXA[GfinNW9]
JF]dLFIPIWR2Q8J@XZZVWIJBU9NFWJ^g_;bk][>`ZZJYZZNUYjVYXYNBTY6>TYjY
Zjfe/j^WWiVCTY^FTJ:[YjB[]ZZMXkG9g?SngL[Kh:eKAEa?A4@nBF26UGmgOgmX
ACM5H6IIEUAEHVM`NhVMY:JVXZFWUg]]KVi]K71jPhjFTXV3Q8AeH6EgOH1mM75e
NgAXJWR7Si>EX:jXV96=R8J2OhBBVZ6/Z9nQWXn9T9>@RhF1NW1/KgEgMWQlOhJF
WIF>RX9eLWb4Ri2DVY^BPWf6Q8B=RIjm^:FLZZag@3Xg8RP^:2m1Hg1MDeUKB2TK
;4<o<CDf=c`e<Se?IgMoQh^:Qh1cK6IPHfMUHfMmTH]lLfe/IU]PJVYWHEI;CeeN
DdaGJgAiP8VAShInNgUfMFe[M7f9Ti^Y[Z^WWIRDSI:HTXZ:TYBEUinZZZFZZj^_
[Jj^ZZ^^/kJe]L39a/Jn^LO9b=glooodj_KRYh1iJ61THfU]S;>TRX>1Pg=CBUMM
FUaGEEeJF5QGKHRMZZBOWYV=PW]dKFY_L6mhR9RSWiVKUHN2Qh^:QGY/IF]aKVee
Q8j>SI6HVYRES7mjNWE]LGb8UYZEV:2SX9ZFT8f;QH=oOH1jM7AiOGaoRHn@Ti:D
TH^=RX=mQ8f9RhinL7R6TiZP_<boZ:B^V6E<D3XX=C`m@FJ8NFUVHei<=2/d>R`Q
81TJ8b/iAEU^OXZ;QXnDP6]RETe6@TI?EF9_KFaaN7ETGVI`KEi=?cLj?C/kA5MY
LGEoSiVJUXj7QH=jMh25R8n@S92FVIRIVYFCTHb:R8F6RHJ3RY:CW:ZXXIfKViF?
RXF4QXbFYjbY/kJha<[DioSolNSdikV>TY1aJVY_NX^a]YjLXIf7Jf9WL6eUHeaO
I5aKGV]oSYnZ[[Fo^:RMThMoNWIfNhJBTY:GVYN<QY2HUXn6OFiOF596AUIVLWZ1
RY>KX::OVHn5PX67T9fVYJJZ/K_1a/>l]JbWWI6@SHAmNW]kOXJ=U9BARH21NVi]
K6Y/O8aoMH>9RiNU^L_DdlcFdjJ4Pfi@BdY7AE^6SHB5PWa]EdM;EeQBBcdb;S0c
<SeHLX:5RINSX9F:MVAHD4i=EFMeLFacOX1dL79eNgAUFe=>BSha;CE8E5MLJGR5
S8Z6Q7e/GemWM7f4Ri6JWYnX/[BaZjJVZJ>NW9B>Rh^7QYJSZJVVY::MThV:ThjA
ViFGX9bOZjbkdm[Pf>KmgJZHVGaPFDi;Dg29NgJ<ViZ4HeeUI5aIEda>ASe4AUM/
MX6=V:>`/:fZXYJ7Q7ifNHJDUiJMYJ6MWIJBRh9hKVUWI5]CCUISKGV5S96CUiNC
S8AkM7EfMh6;TIVGShnHVY:GXZ2KThV3OG5VHVAUJG=jPi:QYj2JWYnETYfLV9Z:
SYN@Z[k4g>GPemg/cIjGSG=TH5e>CVehKF9SLgIUFEIJFe5=@c8`;2X/<TIJL8:7
SInYY::LTHIbHUYFEf9/KW1fNW9bOHF;RX9lNW=]HeQ>@d0n?4AGIFUgPh>3QX9g
LgEcLW=cL75bKW=oQhJ7T9:;QhN0M6YTHUeFF5aQI6UfOX62PhV:SI6CU8b:SI:S
XJ[<c<34e^?:ZJVWQGYkIeaGLHQ^IFmlPW5XI6A[HV9PCe5:@4<n@DiMJW=mS9ZI
V::TW9JGTXN5SY:;RXZ>ShF;UifOWIfKUYRERhEnNGMdLgJ1SYZTZJja/;2`];6V
XZ2GT9:FV9bOW9nVZ[2^ZZJTWiB;R8J8R8F8TIBHVifNWJ>UXYnHVYJ9SH^:Y[K0
a;30fLnbUYR=NGaYE59SQ7YVL7MnNFQVJ6e]J6=EEeM?CTYAGFUdMgb:THMoPX5d
JVQPGf=OGeUCEeQBC5ARIfIUK7=bL6aUIF=QH5iMG5mRJW9gNWanOGf1QHF9SXjA
THf@S8AoOH:1PHR7RHn:Pg]iMWAiMG9hOGinPh^?TYNHV9ZKWYFEZ:^^_/:o_lgL
a9nOWH5gM6MMHWEiKfa_MWE[K6ieNFm^JVIWFeMKFUiWM7n5RHjDUYVMUhb4PhR4
O7eoOGalNgMgOhJ8QXB9RXF4PgijN7IdMGQkOhJ>UY^LW9fNWIZFTI2ATH^8RXR8
RHR;T9JOXZ:TZJVSWIbCS8b:Q7n0QXF6SI2FVifRX9R?Rhb<TI^V[[:e]/3:/9JL
UhMnLfIPL8R1L6UaOGIZIfeaIf1OFUaLEE=ADUQLIfmhPXB4QH^6O7ejMgI]IfYY
IVU_M79cN7f2PhN<SXf7Q81lOWijMWAcLgAfNGUlO7YnPH:6RXb=Shn<Qh:0Oh1n
OhB8SI:GVY^MVI:ASH^9QHB3RY>EVYnTYZBXXijPWJ6VZZf`];6e^k2EPhAeHUiD
CU=SKF1FEUaWHEUKFf1OGF5KG5]DCTI5@D5:DeiSHf9RIV=NH6AUJfQOGeaKG5YK
FEeVJFUZKgV1QXJ4Q8J8RXZ8PhB7PgijNgenPXJ9RXR=U9BEThJ3R8J0Ogn1RI6D
UYZQY::NV9JHUH^7S92AU9NDUYfRYJRWXZ6U[KJg_lk?c=GKelJe]jjFSXIkM7Z?
SX60QI2>PhN;R89jMg=`L6UZJfESIFaaNGimPH>7RhF1PWmjL6QYJ6AUJ6UUI6U]
LG=gOH67RhZ:Rhf>SHV3OgafMgakNGUnP821PXZFWJ2OV9>EU8n7PhN;R8B8SY6?
Shj;Rh^6PWmnP820OWQjOG^2S8n=Rh^?TY6BVJ2TYjbVUXR9ShN0Ng1[M861MG5h
OWeiNH26PWQbL6YWI6AXIV=OHFEXKVYPFf1YIUeIFf1QFe=AD5EMH69VKGEiMG=f
O860OG]hLg1cM75`L6e[KgEmOh:9SY2;Q8B6QHF6QhV9QXJ8Rhb<SI2EV9ZKWinI
V9VHU92>Si>GVIZIUi^SYZ>OXJ>QY:RXZ:NZ/KNi^KJc/ZjVVhj8SYNIUHf?UYZN
XZVXWYJ>SHZ3O7MgMWE_JfidMW1[Jfi`K6]/Kg1]IF1OFEEJG5aLH65PHfQ/LGMj
N7AcMGb1OgYlOW]iNGIeMG5/JVe_LGMmOX26RX^<SXf<S8j?S8f@Sh^7QhN6RX^7
Q8>8TIJETY6>Si>AT96?SHnCU8j9SI>NYZBOX:BXZjVOUXf9S9:@RXJ9SiFIW9nO
UH^8RXEjMGAfN7AcMGUlMg9cLFeXFU=JGf5SHF1OFeMFFEmQGe]LG5YQK79[H5iM
F5QOI6IWIf9LFE]PIF]`Kfa[JV]bNGanPhF2OG]mO7]iMFm[KgIfLgQkOHB8R8^:
RY2ATHn<SI6CTXn?UIVJX:>RZK6d]kbk]K6b]:fKRH23SiJHVYVMYjZTXIb@Q866
RXN4PhJ:SH^5Q8V<R8N:RXV2MgEnQ81jNGYkP8F7RHZ;R7a`JfMTI6U[KW9eNhB<
RXN6PgihM75`LW9cM7=fOH>4QhZ;SY2BTY:IWYbHU9>BT8n>Shj:R8Z:QX^EU9NL
W9fMWJ6SZJn]ZZZWZJn`/;:g]kB`[kFmakjXWifLWIB7Q8:2Q7YbMWQ_HfA[K6EM
FeePHeiCCU9HEdm>FEeHEEEJHF1OGfAbNG9YJ6QWJFIRHfQ_N81kLW=dLW5]JFMW
IV1JFeiWL7=cL6YUI6]dNWIbLFmbN7YdLgQjN7AfN7A`LWMkNW1PG6UiQHnEUIFD
Sh^7QHN9QhF:SHb@W:Ze]:bQVYjY[JVNTHj@TiBGUY:BTiFHWj>KUIFDU9><QXR4
N6]UJFiaK6MXJfUUI6A[LFe/J6AWJfURGF9]LW1[IVA_OX=kM7AaJfigOH>7PWMd
Mg]mOXB;RhB6S8j?SXR1PXR7PhN<Si2DU8j:Qh:2PWmmOh>7S9BLX::MV9RETI:D
TY>JXZFUYJ:U[;Bk]k:d]kg9bk^/X9NFVInSWiVJVI>CVIbESi>DUIZNWijNUX^1
NGMdK6igP8N8QX1iN7EZIf][HeUEEf1/KfMOFEEDEUMJGV9QGf1MFEUJFf1TJ6mf
P8fFW9bIV9JCTiNKWJ2UYjVZYj6ISXJ3OWeoNWEeNgmoQXj>T9:AShj=RH=oPH5m
NGYnOgj5SI:GV9:9R8jCUY><Pgn5RhN1PHF5OW]jNGYjNGMgNG=ZHeeLFUUJFUaS
JFmeNGQZHFAXKFiVH61SIFQZJ6EOFEeQGf1WKW1`LW1YI69OFUmUIVM[L7R2QX9j
M7=eMWV9VZ6TYjJNUiFEV9^IU96CUiZMWIV@QGejNG^2R8bBV9^IUiNDSHb?TIFK
XJBUZk6b/:ZX[;Nj^KVe/k6^[ZRLUYZPX9fIVibKWIb>PX63QXR4OGEaKVabMGMi
O7UcM7^6SXQjLW9`Kg1]JFafO7MeNh5nM6eZJfY]M7EeMgj2OWMaKG1dN7f2PWik
OX1kMW=dMgA^KG9hOgefN7akN7AaLgIjNgQgP8^>TI>DU9BDU9>CTi2@T92=SI:D
TiNRYj2LXZVXXYfISh^@Ti>DUiRGU96:OgA_LFi/J6=UJVaYHEaIDe5ABTE=FU]G
G6I[JVITHfATI6=SHf5RHV1KDDY<Ef1VJ6=TLWemNWaoOWUgNH26RXZ5Q8N9RHN6
R8bBUIB@SH^8R8^=S8^:Ri2GVI>9PX61P8:9T9BGTi2@TiNIV9JFUYRLXJF[]l2n
/ZZZ/[c0_k^f[ZZ^[ZVVWiR?PgUhNgIeN7UdL6ibNG]hLVi[J6MRGf=/LVeYJg5d
LVe`MgEZHEmRIfeaL6YVIVifOX>0NGEfMgEbL79iQHfAU92<R8J4P7f3SI:FV9nS
XJ6OW9^HThj8QXV>SHf?Shf9PG]lPXF6Rhf<SXj;Q7eiM6i[KG=kQY2EVYfQXInU
/l7<clRl^;k6b<2dZZBQViVIUXn7PhVBUYBAU9>@Rh5hM71ZHf5WKVUNEeQOHfAO
EU9@DeMJG69XIUmFD55BDUMKFU]TLWQgLVi/JF=NGEmSIFIXJ6QWIfU/Kfm`L6e]
K6]bO85nMG5dN7anP8:3PWmkMWEiPHF3OgamPHR@U9JFThf:RhfBVInW[Jn/[kFk
_[^e/;2]YI^EVJ:TWijNW9RDU9:?SHF3QHN5OGYhMG5_KVi_L79cM7MfL6YYJVMS
HfM]Kfi]Jfa^LG=eN7amOh>;TiRIVI^IT8N0OhB:SH^8R8R:SI>OZjn_[jn[ZJJS
XJ>SWiZHVibKW9nMUXj;R8N;SHV5Ph:0OX23QHB2PXRBUIRMYk6e/:NRXJJZ[:RQ
VIRKWIN;P7alO7UdM7EeLfm/Jfa/Kg=aKFQVI6=SGEE@DUACDUAKHfERH65SI69O
FeUKFeUGFV1XKg=bKVUUIFMXIf=NFeYFDe=DF5]JF5QJG5iNH6I_MGIfM7=bM7Mh
MGEmQhf?SXb9QhEoM6a/LgQhMgMkPXN7RHjCU96>TIVPYk2h_;B[Y:>XZJRRWJ2U
ZJJUYj^]YinKVYRFTY2CTH^7QXJ1NFiXIfQUGeiRJg9bL71cLg=dM7EdLG1`MG]k
Ngj6RHF2PXF5PgikP8>3PX>6RXb8PWmnO7QcL71`LG9bMWj2PXB9SY:BTYFFThj:
RHbAUIRKVIB>RHF8S8j?SXf<SiFKXZNZ[[:f/ZVSY[2g^;Ri`<WBg=cBaKfk_;Zd
[JV/[ZVSViFCTY>@SH^9Rhf;QWaeL6]VHUiMFeUDDUEJH65LF5EBCe9FGFE]Mgj1
PH20P7ihJf5PHVAZL7=eN7]jN7MhN7QeKfUXKWEjP8N9R8AlLfi_LG5^KW1aL71a
L6e[If=PGf1SJG9kOg]iNgn0P8B8RHR7QXN9RHV9RX^<RXV<Uj:VXIZCU9ZKUI:B
UI>@T9:BS8F3PWihKfa_LFiXIfQYJ61JG69RFeAAEEYJFE]SJFibMganNgIeMgEd
LgAiOGekNh26QX5lNgemNgMdM7AcL6e^L7J0RI:KXjR[ZJ:HShZ9RhV5PH>9Rh^:
RHV7PgejNgn7Si6?SY:HVibGTI6DVIfNX:BW[:n^ZJRa^l74`/?5bLo?blS:blO5
`;R`YijDS8b>Si>CSXV3OgUaJfIUIFAQGf1WKW1`L79eM7AfMgYkNgQcJfESIFIU
I6EZL7EfM75_KVQNEeEFFV1UIVIVIFEXJfYZKgMmOgn1PWmkN7QiNGYlOhF<SXnA
UIJCTI>CU9BBSHN6QhR5PhN9RXb<SiJLWj6SWiJDVJ>YYI^CUZ2RVHn=TYBBTI:C
S85jMGAdLW9fMg9WHfIXHeM;AT]CEeIGHFecL71eMgI^IVAVK71`Kfm_KFY/L71_
KG1hOgijNWf1PGikOH1oNWMjP8F5P7]iN7UmP81mNGMeMG=aLWIkOhF8RHf@Shb7
QHN>TI:DUYJFVInRXZ6OViZLWj6V[;6/YJJ^][^l]k>`[Jna/JjVXInLVIFDTi6>
R89nN7=^JFENFEIDDeEFEUaTJ6UXJg1eN7EdMGAaKFe^LGAbKfi_LW5/IfIVIfU[
KFa/KgAeM7AdM7EfMgA_KVi_LG9aLG9bLW9cMGIgNWj0Q8V<T9FIV9FDTY2=R8>3
QHR:RXV:S8f?TiBEUIBFV9^OXZR_]KNi_lS=blJo^kZm^[2UX:6NUi:BTY2:Ph63
PgmjMW9/IVAUJ6]YI61SJ6QTIVe_Jf=OI6aaL6]XJ6UUHFAVJg1cLgIlOgahMG9^
Jf]/K6MQH6AYKFe[JVidMGMgN7YlO7]mOgmlNG^2RY2BU9FGW:6VZJNQViNEU9JH
WJ>VZ:NWZ:RUXYnKUY>EW:6UZZj`]Kc0_[J_[:^/[jjZYJ6QWinMUheoMG9fO7em
OgmkMg=`KFYVHf9SIVMWIfU[J6=OG5UFE55AE5QLHF9OGEiPHfEWJfmcMGAdM7Ei
N7A_JfY/KVi_LWEgN7QiNgf0PH1oP822PhF8R8J5Qh^<RXZ:RXb?Sh^7QXJ7QXJ7
QhJ7Rhn<RHZ>T9BIWJ6TY::TZ;6h^K>ZY:BVXibCShj<RXN9S8Z2NG9aLWAdLWAg
NGUhMGAdLW=fN7MdLgMkO7YdLgQlNG9/Jf]XI65RHfAUI6IZKVm`LG1_Kfe/JVIQ
H5mPGEE?D5AHG61UJg=jOX:8Si6AT8n@TYBDUYVHUY6<S8j@T8f:R8R<TIFHV9JF
V9^LWZ6U[;6c/kBg^kk0`lK5`[be/K:e]:fUXJ:PVIFFUI:=R81gKVMVJF][If9P
HV=PGEaMG5MDEU]MFE9?DUQMGf1TIVMXJFYZJVMXKW=gN7b3R8R5Ph>4PGeiMgIf
MG5[J6Y_LgIhNGaoQHN6QXN6Q8N:S8f=SI2CUYVIUiJDT8j=RhV7QXN;Si>HVYRE
TI6CUYRIW:6SXj>W[K6c[jVSWj6TXj2LWjBVYJ>TYZ>PWYjNWIbGU9JIV928Q8=m
LV]WIfMWIVASGUA=C4m@D55BEUICDE1>BdU;D5QLFUYQK79bKVUVI6=VIfMUIFQ]
MGanOh23Q8B3PX>6QXR<SXj<RHR;SY6CTI6?SXf?THn:QhR9S92CU9:ATY>EUi^O
WifOX9nLVi^RYjVXX9VEU9B>Q7n3RHb9RHjATHb7R8^=RhJ5QXN3O7UkOgijN7ao
NW9ZJFa`LWAeM75/IfEUI65NGV9VIfQ/LGAcLWAfM6mWH5aKG5iMFUQHFf1SJG1d
MGR0Qh^=Si>EU9>CTi:@S8^?Ui^IUiJFV9RFU9>EV9VJW9jMWjBTXI^FUINKWZ2Q
XJ:OW9ZKW9V@RhfDVIREUYVJVINIW9ZBRhZAUiJ?RHN7Q7mlO7afKfUWJfmaLWAe
L6QRH69VJFY]L71_JfUZJfUWJ6a^KFaaN7ioNWEbL6]UI6M/L75bLgAfNGQfMWQi
MgEfNGn4QXN:SHf;Rhf@T8nBUIRJVi^KWIfMWInPX9jOXJJ[[Jj][:^WXj6NVYRH
UiFBT8n>T96=QH67RhZ;SiNLUi6:Q89oNWMgN7E`Kg1aKf]WJ6QUH5]MHfISGUiQ
Ge]FEEUMGeeLGf1MF5MJHFATIVUZJVMXKgMjMgEfNWn1PH20Ph9mMWAhOH1oP860
O7IbLWAfN7b1QHF3PGmlNGQhNGf1Q8ZCWJBUXYfHVI^LWZ6X[:b_];Vl_K^g/:NQ
WYnQXj:TYZNVXj>VZ:NUYJNYYj:OWI^GTH^6PgmmNWUjNWQfMWI_IV1PHEiIEUYP
HV5PHVATHf1LFeUGEeUMHfU[JVQTH5iNHFQ_Mh6<UI^JU96DUiF@RhZ=SXb=Si6B
TY2?SX^;Rhj?Si6AT92DVIfMVYVJVi^JV9BATI2?RhN5QXV=SHj=SY2CUIBCT8b:
R8J3PXJ<TY>BU9BCTH^2OG]fKfYYKGEjNWE`KVaYIfIWIF=UJfaWHf5QHV=THEmM
G5iPHfIVI61LF5IDDUAHGFA]MWMhNGA_KfiaMWf6R8B1O7MgNWf3S9:HVYVETHnA
U9BCTXj<RXF3Q8F7SIFIVYZMXJ:PWYZDSHZ7QhV:R8J8RXb?T8n<RhjCUIJHWZ>U
YZRXYj:LUiJHUY6>SHj=S8b=Si6BTYBEUIBDTXn;Qh>0OG]iM71_Kg1cMWIdLG5b
Lg1]Jf]`Lg9`KVaZIVATI6IYKG1cMWE_J6IXJVYWIFM/LGAfO8>4PGioQ8J3PH:5
RHb?TiNGUYRLXJJYZj^[Zj^[Z:FRX9jLVYJCU9VMXJ:PWIbLVYJCTiBCT8j@Ti>B
TY:DU9:@T9:FVIVGTi6>QgmjM6iWHF1UK75dMGMiNGMeM71ZIVARH5]IGF9THf5N
FUQHF5aQIVU]L75aM7EeMWYoOgimP8F8QX9mNGMeLG1aLW9cMGIdLW=eMg^1Qhb>
SXf=RHJ3P7ekNWamOGn1OW]mPXN9RX^=Si2@SHV:T9FGVijKUYFDS8b;QhN5QHZ?
TIBBSi2?RhJ0OW]jNGMdLFm]K6]ZKWEmPhF:Shb7QHF5PgmhKfQUJVe`LgAbL75d
MgUlP862PhJ5Ph>1PX>2P7moOX:6RXb<S96FVYfNWIZDT8j;RHZ;TYNHVYZFTY>E
UI2=RXN8S8b<T92=R8>1PH:4QHR:Ri2CUIZCSINNXj6PYJJSXIfKVifPYJFXZJVZ
YjJUY::ITHb9Rhf>TY>ASXR0OGelNWUkOGUfMWQkP7mjMW=`KVe[J6UZK6eYJ6QY
Jfa/J6M[K6MSHV5SH5]NI6U/JfIOFUYLFEIGFUYIFEYPIVIQGVIYKW1`Mg]gLfm/
J6U[Jfe`L79cMWajMFiUIF=UJfmjO7IlPGn6SI6DV9jJTI:JWIjPX:6PW9RDTY2=
RXZ7QHR8RXV1O864QHbFV9FEThb:S8J3P7amOG]hM7IlOgn2PhJ?UYROYJBRX9nJ
UiVHUYBAT92ATYBFUiJFUIFGUYFASi6ARhV;Si6?RHF2NWIiN7QlNgUlP7ecKVaZ
JVUYJf]aNWimO7j7Si6<S8n9PhJ:RHfATY:@Si:HVijPWYfMViVCSi:DTi6@S8^;
SiBCTY2=S8Z9SHn6OGioOGn1Ogj1PGYgN7YgLg=eMGQoP8:5PHN3Lg5`JV9IDdm?
DUIOIV][JG1fLVe_L6YRIFeaL6YVJVe_LW9cMH23OXB3QXMnMV]VJ6USGEUCCU9A
E5UHH6E[LG1gNgMhNgQmOgaoPH22Ri:GVIbNW:2Y[JZUZZNIXJj^/;2b/ZfYYZ:L
VInUX9VNX9^HVYjMUY>FVifJW9bJVijPViRLXYnJUYJCSXf:RhbDWinKV9NFTi:9
PhAmOH9mMFmTIFYZKW1kPgj5QX>7T96;PhR;PhF3OX23PX63RY>>Q7miN7E_JfQ[
K6e_LgIhNGYgMgemMWAkMg5cKfQMBTeGBUihQGA`LVIZNWf3S9:?NWjNWhJ5RWQK
FWN2MWYnMg5bLgAeJUmMGF1TIfMaPX^6P8ZGTHjFUXj@VIjAR8>:T7][NhJ2Pgam
R8jASY2KUX9kQ8AmNgYdMH22LfMUGUm/LVa[L7^3O6mlSX9fNH9nL7F?VYN?RYNL
[;Rb/;NcZ9fGYK6SSgehPg]oSXMoPXV4Oh^=MgZ9MWV7QhZ<T925QINEY;6fb<W=
e=S>bN7F^k^o[ijFU9>@X9QlMhR3QYnMTInNWH]oQWAE?alD:AL64bDf@3i0CEmR
NHM[EU:HUe=^UVI;ACaOK7f:RGm`SZfaRfj=/:B5ED9lPDdgFfYE?CaBH6MNC41G
G5ENFfAKBE5GIVaQCEf=W9JF[JfP^M_D[::TXl39/<_Qd]G[nOW[d<FTPHZ1Lf=F
FU]aM4iELeELKUIHJfMdQh5]EdXj>3XlBdiCHfQmNWbHY:jRPHn]ZiVGVk2cRG9g
SJbe[;6h`L_IbkC1c<39`j>HPfejO6maIen?UG5/Mh5bC5e_GEIQJgQ`DFnSTXRX
[:Fc_Z6X[ZJh/:k5clG@glbb]KBUTXV5LWNGV7ijOWmnIf18;e=:;Cm2?bTT:BPO
420W<Sdi>ci5HEE:HU]QPhecL7R1U8iPH9NfUWImRifR]kfR]:n9U;2XS8B<OH5n
EU]TDU5GDe5MCdiIHFMgRWYhP8^<XZnJX:k6ZiBUVjFod=cSkn__oooMb=oDZXAf
LgN5KC@RFGa`HTU[V7]WL6efNf9KCcl^6B8i8aLV>4iUIemUWZj1Vm;H]hb0W<>b
L8:`WZ6]W[C4^kg3][_5bkNKVYnDSGATLfmVFc@/E79jJDa:IVa[HF1aS7MTR8=k
S96FSHR2QJ:h[Z2gjOook_3Zjn_Vf[N_/in=PWafMhanIG:4MWRHRFMFKX=M@dQ8
?S4H1Q<Z8BY1@eQhOEafWXRBRGMbNi26LGbJQVmjP9>k[iFY_L?AcKVVXK:iZ7EM
IUi=@d]4Ef]OFEUYPH9TDD9?GfE^IV^3U9MfKYJZZJ:?TJc6bkK2h][GgkbQ]Zem
LVaBF6MQ?ba5@C5EJDa<N7]QCf23JRhZD5H`5QTI4bDf>DUUNXbY/Zjmg?7NalS9
c/B][;2^]:fIQXNW]I^G/KnXUj6UX85XD3/i=chT3ALW<cDiD5iIHeiPP8V3O8:B
SYB5QHN<VY2S[InZa/_Kooobm_oooo_ok/^k]:jEN6e=Cg1KD5M<>T]PG4E?NeLZ
Aee9<1/H6Q`L5@lM=CI>K6I^QIfhXiB]ZijIX[JPMh:LVI2F/;VX/kNnh]:ob/Vj
Z:JLP7AP?TA6;Blf;T=FEeQ;EfM^OGI_Rif9RYV:LVI_MGYlMgN6WZ:hemcXoooZ
n_o^blNoWIF@LUeZMeY<IWMXI7QeJWb9PW]fK5a:<RP/9alM8b/fBEYPOi^QY;Bi
]/Jj^/^nZZjf]jVGViR;SHbEYKZoZjbc^KJZTG1TEeeI>2ln?CI8DTY?FF5YLG]i
Ngn8TZ>]Zk>galfl/K:k`lK<h?Kekn_oooojlNkE]ZRQQFIJ@B@a?1L78b<55BhQ
6B8bD4hb>48m;`T02a4D8bP[?dmACEY^QjF[/;Nj`kk1`;6c]JnWU9FUX9RVZYjJ
WjR[YYB>T8IfIUYCBd4oBD]2?D@m<cmFG5MYN863QHZ@W9n_[Y6HXINNYYnT^L;;
fn?Oi__`en;_j/bXW:2QTfeNK6IIFV9LHG]dEeM^Oh9jIfb4R6e<BUIPFDi:CV=d
NWYkPgikT9VGZ[BPTYJX_;FLRH5gOIFCQX:5RIJPThB4QWaoOfiaKVIfNg=ZIVQ`
KfQKB4m[LWf<NWJ6V:Rb][NhYXj7Si22RIN?S:K4a<33[inc]Z2FO5mYLEm1;cLk
<AlG410V<bPcB51GGEQLNHEZFEMIJ6EYKE]DK8jEQXFBTibcaLS3a/gFjNO=c=_H
b/6_Xj>MUXj6NWV3MVQWHUM8?D1<DE1BB417AT=?E5=<B624Rh>7Q8BJZ:B^][Bf
_/>eXJ^f]lGBf]C>j_GYi_3T`lc1Y:JKOfeWM89_DUACA49AHUmCEV1QI6UYK6e/
KVaSFemSGV1NFf5MI7I^HVj5UibKX:RSVYnV[;:d/:FETIVKT8R1MWn9OgMnNEeL
Idm3E5MFDTYEGeE=F6IUFE5OL7^0Ph>1Qhb>SXf@TH5bMHFJX9NJX:FebmK6^Kng
[[6RUI:EQW5mO5eLJ5m;AUIEDf1RG69QH6mnR89fOGUVHVmhLFUOFfahO81dLHNH
VYVKUi2EVIFCU9:FYZ:<RibZX9RLT7idLgj;R7UeMGEjOgAaPX1^K7=_L75/I729
Vj6SZjj`/Zj``[jVZk:PUi:FYZ^/[k6nd=;<c/o5`l>cYjFRSfYIGeYDCchZ93Tn
>DU7@51^N760QgMXJV97@UQLC4E<B4M>EUiNDU5IE5MWLFa[NXB8TI6FWifLW:2K
UIbHR822QhZ:THmnLg9mRHInNGEeP7mlNGN0Ph:CYZFMShZFXI^>UJ>HOfaYN8bC
SHfCT9FPZ[o=eLg2bM;<_[Jb[IaoNHAiIfEUEe1YNfYQK6U]OHB2PXB7QWehNgmo
LF1RKFiPCT]FEDa@EV9aK6n6RHR:Tj2PV9FLXZJQV9J=U9jKWIZDU92<PWEWIFab
K5I=EEeXMGQhOXR<T92:QhZBV9>:TijHSXEnOGn2MVQaPHNCXJ6P]L>dZ:jZW9ZM
W9jJOfehP7=JG6UJBT=5BeEIC4aHJ7]cJg9aLGEkQHAnOhB7O6]ULGUeMFiVK7Ej
MG1gNW=_LF][LgIhP9RUVi2L[J^KSY2KTWmmO8B;QGMYIfagMW1cNhN9R8j=UYj>
SIjIRXV>RX>2QHb6Q8Z?V9bKW9^Q];N_Yjk0`[B/];B^[:6KWj2LUIZKQGUhJfMe
N7AeNWmnNGAaOXj7LfedKV]dMGIgNGaZFE]VIf1OHF5PJWAgMFIPLgmmP8F5PhF=
VJ:PTHj=PWA/JfMSGV1XJ5eDDe1@F61THeiXOXjAShnATI6=QH>8T9ZLSHJCY:n[
VYfXVi:HX:>UZJRT[K^i[ZJRViJAS96CPgElQX5gNWiaIfU[JV9MHVenPgE]MWej
O8>=TY:BQWj8SXImNGaiKV1IGf=]NWehIf9`NGj3Q7a^KGJ1TZ>OTYVKUHn:SHEh
KfefOGmhM79^M7amNGf?VI>>UJ2TWI:ASGajPHJ8P7EgPXV;QH21PX:0P8B;UIZH
V:B[Y9R<QhF:U9B?S8QoMWYnMfeTG4m8ATQMKFMTJFMTKg]jMGEaMHF<S96IWY5n
Nh66Q7M]KFYQGFI^JFU`MWIjOX6;U9FCTYVVYiF8Ph>?U8QlKf=SJVmcKF]XH6I/
JgV<UI^JW:NUW9RGTXnCUIF<QhjGW9bMXJ:UYibCVI^IX[2_XiVHX:JQV9:BU9:@
VjZ[Y9V@TIfRTGahMgEdMG=WI6aaMW]hMWQjQXZ8TYJNYIZ;NWAhNGUgN7I`JFAV
Jg5_I5M>DE]SIVM^KVinQWe/F5=OKFmXIfacNWenQHV6P7QaKfYUIVaiOWUiNgE`
LWUoN6QTIg9lM6ihOhB<TiRESH^>T9NJUiZJVj2LWZ2JWj^ZYJo6dlRh][Zi/J>L
WiR8O7MdMGb3Pg=PEeYSIfU^LgZ3RHZ5OWUfL6]/LFiVJ75dL6YVIV9JDT]=DU=I
GeeLI6aYJ79iM6UNIWR2Q81nOG]nOG^1Q8F8S8j?UY^FU9RITI2JXInNXZBZ[j^S
WI>8S9:CUYRFTHn>S9Z[ZYj<O7f8SHnBV:2Z/[:_[J:NX::ZZifBT9NSXi^GTHV2
OWE[L7YiNWeeKF]YIFIYK6ADEVUeLfa_LViaMWenMV]YKWImO7UeKfe/JFU^KFIU
JfmeP8Z;RX^7PWecLGj7P7IdOXfARHV?QWMnRH^<PGN2TY^NUXb5PXRCThUmM75j
QXF2QhInNGMmR8Z8R8nJV9BEThj:R8N6PGn8Shj7QXfATi>LWi>9SiVKVY:<RhEm
O7YdKF1FEemXM7YdK6abN7I_JFabLFiZIFacLWQoN6e[KWAjNgf5SY:ATiF;PH1f
JF=MEU9FGVIXIemGEf5[KVi_L7=hNWj6PFiQHVeeLFahRI6CUY^RYJ2NWIVJWJ6W
YZNVYJ:LWJ6NW9^ETYJPZZjZYZfg^:fSXJBVY9nESXnBUIZMUi6<PgaoS9JJVIJE
U9:9OgegKgR1Mg5cM7^3Q7mkNWn9S8F3R8V0NH26PGUeKUmCDEASK6eaK69TKW1^
JfYYHfIbMGZ0NWA_KGR2RHb3OXF9R7mhNhF8PGM`MG]fLW=_M7emO7enOWeoPhF3
PhB5Rhj=SXnDT8AmNX::OVaUIg1lQ7iiOGYfMgEfOX1jMgj:UYnOThR7Q8><U9RK
V9JFVInKThj5P8B7QhR7PGYeMW^5SH9aKG5jOWalS9ZGSi6JWYZ@Pgj0OGAZH5QJ
I6maL6mXFea[N8B?TYBIVIZOYJRVWI2<Tj2UX:>YXHmmN7eiKVeXHfaaLgenMFeR
HFUcMVQQKGIkNWf:ShIlO8JHWIbQXYbHVZ6TVi6GXInDTI6AUYVFTi>DT8f?S8jF
WJ2KV9NAT9FEThenLgEkPXJ:T96DVIJCTXf3O7YiNX64PG]kOga^HV5TH5UIH65K
GVU`J5E8@SL_:RT]=d57BDiDEE9AEf1VKgb7SI>GUIJIVIZKVYZFTibVZkBi/JJR
Z[JeZj>RWiF@THf5Q8^<QhV9OG5_O8V8QX^>TYNMXYZ<SYFAQ7MkRY:LXZ2KS865
Ph>:PgE`MhJEViN?Si:=SYJGT8^>UYZHUHn9RHR5S9FBQh:0OGimMWN4QW=PG61X
KG1dMG1_L71^JV=IDeELIFAGD55IIfmZHeY>CfAkRXn=TIbRWifMVYB>Qh1kNgn4
QXN:QgeiNgb0PWUaN8F<SH=eKf]SIVi^JfadQi6:QXUoL6YZL7UkMWR3QHJ?THV4
Ogf0PHNEW9VJXZ>NWZ>UXI^AQhN@U8aoNWb3RHZ:R7a_KgIlP85mNh:8RX^;Pg]n
OgYmQhnAT9:KXijBTI^PW9::QhB9ThmlKFISH5Q?CU9EF5]MEe5CEUUMHVIXL7Qo
QXjBTHnATHn?ShZ4R9RQWIB@TiFEW::HS8Z<S8nEUHjBX:FQVY>CT8Z=UibGTIFJ
VI^NV8b:UY^GTH^4PHJ=QgmhLW=kPHF7PGn7S8b=Shb5P820OWeoOgf3QgebKVm^
JF9PI6M]M7IbMWafLWZ3O6e[NHF4P8J?TI:IWIJ?RhZ8P7j9RWebK6UZJ6ATH59>
FFEZKW9dOXZ:QHZATiNFSX^@Ti>DTYNLThR2PXEoO8NBTY:CSXZ>QgYeMWIiMgF0
RXAmNWQlNg1`NhJ:SY>DUIVLWYnESYVPVinWXIFDWJ2RXinESXb?T9BFSHfARXB4
P7ahLFe[L7EcLg=aNHB2O7YgNGmoNWQnQ7mfMg]hKfeaMWenMWIkMgAfLVQPFUMA
A3e4CU5BEeU=A4mIFf5VJ6a^M8:9RHjBShZ;SHN4QHJ9SHj>Si:DTiVQXInUZZFK
UifUYIbGV9B<SYJCTiRIVYNBUYfRY:6QVXbAX9jFU9NMW9VNXIjCRX^@TiZKShV:
Ri2JWIR@QhF7RY>GS8J9QWe`JVm`IV1TIf]_KVMRJ6]TGfAXIF9VKg1_LWEeLFa[
JfaaMG=YH69XJVUQEeMLGF9XJ6UdNGIiQ8nCUiJCUYfQYJRUYjbYY:BRXZVUUHV;
UIB>T8^1PhR3NgI`JfQWLgifKGZ4O75[KG9cLVYRJWInQhR3Qhj;RHN9T8f9SiVM
VIBHWiZGVYbKTX^:RY2HVYRBPWQiMFm^KfYWIVEXJ6Q]L6aUIVQSH69VKGMoP7an
Ri:=QWelQXnCT8MmOhN;SHQnNG]kMWEkO7EfN75XJ6miOh>7R8Z?UIbPXZZaZ9nO
WibJUY6>SXb5OgehLgIhNGj4QX>1QHb=R8B4QXV=Shn?RXB4Q8F7QGmoQhfBThfC
WinJUYJKXZjeZiVFX:Z[Zj^QTXjATHEhLfeZJ69MGUiHC491@Sll@DM:BU1HG6A^
L6m_KFa`NhF2MW9fNh60P8:4R8Z9S8Z;T8YoOXB5OW=^Kg1^LWeoM75mS9BJWj:T
YZ6JVI^RZ:ZWWI>?TiRDSX^7OG^1P7MaLG=fNgI^KW5`LGAkQXb7P81nMgImPhJ:
SHEkO8RDWZBVYZ>U[K>bYijV/[BaZZJVYZFUYIfARhElMWIfM6aND4I7BDQ6AdQ:
CE5ACeERJVe`MGZ3RX^8Qhb?RXB:SXZ8RY>LWibIW9N8PH5mNGQ`J6]aLgEgM71b
KF=RKGUnPhb@TYFIW9fOVI2>S8=iLFmgOgiiMFaPG5mRIg1hO7n1PhF<V9bJVibK
WJ>UXj>QVYFDT8jATYJGU9fY/;Ff/Zna^/6n_Kb^Z:^[Z9b@SHMkJeiFCdQ4?SXn
?S@]<3Lf;c4f=ce9DUQLHfagPi:QZ:FQYZnd/jbWYZJWXijJVYZJWIfHTXf=T8b6
QHZ=RXF8SXj=T9BASHf8Og=]K6YXH5QDEEaPHEmKEUIFEUUJI7=gM7^=VIfQYJN/
/kFb[Zb[[K2_YIZ=P7]gL762S8ZAVYVCUJ>_^L;0^l70]K2c[Y^<QGEXGTm0<bl_
;2@O7aPA51lV;30X9C0mA4]LKgUoQHbCVIjV/[[0aL[8`Kno`/W6]:JSX9N=R8b@
TYNHThf:SYBBRH:0OWM^KW5XFDi7@3`g<30b=3]4B4iFGFMdOHF@VYnV[KK1a/[>
c/S3aLC1`L?0^[:[YZ6HT8V9TiZFU9j^[Z:SZJV`/:RWXiVBUijFOFYVGU52=bHN
9B@N6QPH5ah^>3m@F5YQJgEhPi6ASi:@TIJEShnCUIFFU96@TI>GUiVLV9JFUI:F
WIjGTY2:QX9oQXb8Q8J2NgM`IV1KETm4?3Pk>cPnBDmEHF]eOXNCX:Rb_L77cM;H
g]kGbKbg][Je/jnYXIR?RXbCWZFX/L77_kRdZjN`ZiV@SH=_HEeE@C<[8AL?1P0?
71P?30lD5b8`>4YPJgAnRY6EYKO0aLg?d=;Ee<o<bL:fZJBPVIRDRGmoNfiRHVQc
PXJ3R8j?TiJFUiR@R8=kLFYYJVYUGEePGEYPKGV4S9:LZ:^//[Fa[:JOV9>>QhN<
S8EhK6M]Lg9`Lh27Rhb8TJFg_[g5dLfm^K:X/;N/YJRTUHIkJThj<B@H3`400002
0@0000056be2IHJI[L[If=o_m?SoooomnN_Kdlo7^JVHQgeiM6m`M79^IEI=C4U5
AdY9B4a=BTM4@d=7CeADE5YTKgJ0SYFHW::[]kjo`lS:bL[8a/S:aKfj]JNKUi69
PgifJUmOGE=;AdiNLhFBVjS4e<g4`l30b<:aYInDP6mL@2PQ71@A3@402Q/V:2ho
CEY[NhNI/;jj^lS7_<34^kW1a/K2^JbTZZnXViB@QgafK6QYJ6=UJV=LGVIZJFY]
M7YhK5mEBShc:bX^;bTT9bdkCEe/Nh^O]LOEiOKjm?3Zg]?=b<6fZIbCT8n;QXF6
R8V7RYFU[/3Eg^?Thng]e<>o][NfUgUZFDHc91D00000000000045b@U;d1<H7Z;
YL[QiNWbmNoZkNWShm[7]Z6:MVUWGTa5Ad=2Be9FIWf7RI2AQh>9Qh20OgUaI4lm
=C0];c8c=c/mBEa]P9NV[;FoaLO5`lG4_;:WVhj3OGYdLG1^L7IlQI6JW9ZP[:f_
^;_7ho;`l_SlnNKBbKfi]YeoKU]5;QD000000000000000XJ8S=:GG69W;KEj>g_
m?Oaj^WSfm?5/jZRTh=lOGieKV]VIFU/L7V6SHQlMG1[JfUNEEAACE5DCdU=EUmW
KgIlPhjJY:^c]KFk`/2m_;N^[:n/Y9jLViJ9Og]dKFa]LWYlMW5gPhR?Uinab]_W
l>g]kmk?cL2c/j>5MV]LAS@^8aHE40<531<S?5EQH6MfMgR3RHbJZJVMUHn2N7n;
SY2@RhJ5QH1lQI:>RHn>QXB6T9n_]:bNVi^CRh^:QXAoKf9F@cPl?S`m@4I?EEeX
M86=U9RQZJb_/[Bb/:ZMTXb6PH1kM7ImPhB9VJV_/kJg_lG2_[o6e=gEb;jk^:66
M6ETJUHi=C<Z9R<U:2<T9AdJ7R<aBfEcMgb8U9fW/KoEinONem?9_;Ne[9n=NfmV
Fe5=DEYMFeePHVE/Mh:<U9:7P7]`J6IVIfAJEUUJFfA]LGf>VJ>b_/?9bl>j][2Z
XI:0LF9EBSlc:RPY;SHi@4iLIgF8UjF`/[K2al74dn;^ooooooool=[;a[bg[8UX
F48U3`000000000000058ca8DfMmS9f^`=ccmNcVh=?0]K6b]kbfZjBOViVJWIN>
RXR4PgmjNX62MfQOFU9;BDQ;DE9AEEYJG6IcOXVBV:2Y/K_3`[fh];>d/Z^VXIfH
TX^6PgefMgU`IfMWJG1gNWj0OH29T9NNY;?:gNKQf^7PcKZ`Yj:ORVUFC3d`:2T/
:b`[9bP]>4USOHEmOXF4Ph^AUJ6_[If>PWIaMg]iNWahKfQVI65WKFe_MGUhN8::
TIRIU8n=S8b<RhV5PGY_HeUDDDi9BU9GFF1YM7n4QHJ9SiZRYjbZXIVGThZ2Ng5/
KV]UJWAhOiFY/[Re/k_2_[g6c]c]jmO7`lBfUH5nMWIaET91?cD[:BTV9RXU82<[
=DaYNWUfQIJNZ[S0eoOon>k_k^CIc/2bY95mK5mEBdE8ASm0ATQ=EEaXM7f0NGIh
Kf=PHF=SHf9RIfmdNhVK/<GCgNK]lo7Uf]76]ZRFP6]KC3`^7Q4@5Q/P9B/c@4mO
K7J0QhfEVYjSZKG7f>7Xl?3am^G1^LG6`[>@LVAC>Q`00000000000005cA@GfZ7
Y;72en[nooool^KKbK^i]JjWW8]lMWIcKfm[I69UI69PHV=QH5Y<AD@n?D=9D5YV
LWb5SiZPY:jj`<?;dmcSg/^j[jFOWYJ8OGI/IFESGV9ZJfe^J6MXIf]bNHFAT96I
WJ:[^<G?eMKGf^CWd[>RW9RDOeHl>3P_8ATE51`X:RDV<D9HMXjBTYjXZ:fd^<38
c<O2`;^ZW9ZFTHb2KUY@B3de<2PP8B<T92L`>dUGGUmVJVU`OXVAVJ:XZZRRViRG
VjF]ZZRZ[k:/XIZHUI:DT8V9QWIYIF1MH6=WKFmdOhfKZK2g`/_Adlc4_k_2c=CM
gm71_[NNPWMkR9:4IE=>BD4e<38a:b8G4QXV=4QRLWAfOh^K[[c=iO[oo?G/glg3
_K>XVH9ZG5E>BDM6@dA;D55FHFmlQ8F4QhV1Mg9^J69PHVE^N7YkPXbGZKRm_lS=
b<:j[ZVVXYbBPg9SFeQCD5EJG61UIV5RJVe]KFaWIVUVFe9@DE]^QibW[[W;i>gG
`lSEi>K<[Z2IRg=>;1H90`0000001B8mBe9MK7bAZ;_?g^7KclBi[If@S8Z:Q7IZ
IVY`MW]mN7UnOGalO863Ph1jLfmXHV=QH6AZL7j=UIJAS92NZk>k`L74a;NXXinK
ViN>Rhj<RHN3PhR<S8Z3NG9]JFejPXF<Sh^:TYRKZ/;Gio?eko;jjKnWY9jGR68k
:bHL304320hF5`l?83mOOj6a];^m/jf_]L;>d/^n[Yf5KF9PFe=3;QlJ7R4S92LY
<Cm5A4YFIWJ0QHfHXZ>SYZVYZZ^`][>VVI:<S9:MYJFUYZFRVHb8Qh1jM6aTGeM@
DUEEE5MNIfmiR9Z[^l_BeMcPfmGCdLW1_[k3b<Bj/[Fo]I5iN7IlNU]4@c`]7@d6
2a8G3`D64bU5IH>@UZF^/KoCi?KoooofjM_8]JbQSW]VDTY:B4<m?DI>DUMKFeeS
K7InPgmkO7E^Kg5dMWZ2R8^=SY6FWZV]Zjb]ZjZVTX1oOGM`IEQ@B454BTe=E5eT
Jfm`LgZ1R8nBSXb;Ri2FTHF7Si^fc<o=c]O/l=Fg[[>n^iU^Dd<d80T000000000
00hTA6InSj2_^/ODgO3oooOOc<JhXiNFUIN?N6]]M7QhNg]fLWQoPH1nNWMgMFeX
JF5FEUaOHfU_MGUkOHB<UZ>^];Fd]kfl[YjHUi>?RhJ4Q8>1OgmmNWj7SHV3OWj1
R92EUYNIW:Jb[YnKWj[1e=C@d<gBf;b?O7b0RGE481460000000000003b=0J96[
];W1am;Sk_GknnoHa;jaUGadK6=I@R`Q8bT]<Ci;DEMPHf=ZM7n=UI:=TI:6Oh>;
Shb7RY>IV9FFVZ2X[K6f]K6/X8anO7eiLVAEC4Hn>ci3C5MPK7f<VJJc`m?Mh>3O
g]oPg=71][:^/;g1]k2d^k>FMfefR8IN<b8R91hC3@T;5APD5R4bCW:EZ[:lbM3J
j?7noooom>KJaJRCR7edI4ho?456@cm0?d1<EUMHG69VIfEOF5MCC4mHHVeeNhRE
W9jS[;O3b<S6`kjh[in<OG5VG599@c/c;c4g?DA9C51DFfIbNgj4Rh^8RHnHXJFL
UIZLYl;Eg^_cn_ohf<>o`<JjTFE=@S@P3P801P@000046ceQOHV@VjB]^<7?h>WW
gM;?cKjZXjN/ZZ2@Q8B;SHZ8QGadLFiXIFMXIF9JC4A1?3]1ADM;D5U[Nh:9U::_
_<?5b<c=c/o4][6_[:NTWYF9NG1aKfQRGUQEE59@EEaMGUiKFF5`PHfBUYRM[LGI
jNoYhN?_i/J]Xj2TVFe2<c<^7P/30`@;3``B93Q>K8RASY:JVibTZkBl]9b8QXMh
If]jR9:;NGN:VIjNVYF?Rh^9Q8>2OgQ`J5aFFEUFF5YLHVekSZ6TWYjU[KBi^kJ`
ZZ>JSh5cJFEPFE9>BTaEHFagP8jN[[_2aL_?d]KGbkfe[jbZWi2<SHZ=WJjj`KZc
`<^`R7YoRXia@RLT91lC30hD61PG72i9IH6O/[>e_K^f]k_1b<BdX9FBQ6QGFfI]
J5eIH6efN7f9TI6CUY:=RX=nOGIZHeeBBTiMJW5iQiNRYjFSYZba/k6ZW928P7=T
FEIFEU99Ad]<CUINIFigP8bHWZ2RZ:n`ZJ6JUIBJWijMVI6>TInda];Ie]SUhlVb
[:fd/XeI>C8]7`l5000000003B8aBVYhO8RFVj:`_LWJimo>blo4/k6i_KbaUX5n
QXJ0Q8MkKg=lOWilLF]/GdPj=B`U;CY0@DA;EF9_NHFCXJfialo?dMGCc<O1]:JK
THV5NV]TIVEWK6YXK6m]L7MlPHZBTi>GVj6TXYfHTXjAV:2Z/K>f_/NoYI:BUinN
PEe;Acla9R8M6142000>9SiILG=_NhJ:U:>__/oHd<K<d/:[YJRYYiIkK6mcJfAX
K6EJE55DGFQ_NhF0L6aaMgj5QX9mN7EjR9:AT9FMXZZe^;Rl^k6UWibJUXj4OGQb
KW9iOGelO8:=V9nW/KVl_l:n][:][:ZPS7U[GeACEf1/KF9SMhAiJF]oWK2NLeII
I6MOEdi2>C8X8BTjCF9iQ8:6TIjY^LK=e]cDal70^ZZGRhZ:OfI@AdU=Cde9AdM9
DE]RK7Z7TYVCQX:5QhR;RX5gL7>1SHZ1N7InQHbFW9REU8^2P7acJ5Y9@TE2@4UE
F5IDFF=_Oi2OZJnb]l?=cLK3`/6o^;6^YiNDY;Fj^[NibM6hVi^__[nTNf5CBd0Z
60l20000000583YDIW6=]m3KjOcooooooookjL^bXiR<NE`n:R<R8BD^>Clo?STh
@eIVLGIcKVi_L7EmPhN6PXREWjJ]]/?Bg>3Th]WAclFdYijDQFa;<b/V81hR9RT[
;SYAJ7V6T9bX/[[3b/gAclBgZj2IU9:CTiR[_L70b<fmZ:NZYJZQOf1@@2LA1P00
000000000aPgDUi]Qined>WjooooooSailnbWiB8NVA;?Cm8BTYCH6MZLGMjOHRF
Wj2CNfUOEE5FG5iICTUBGf]iRYZ]`<W>fN?YkncNbkZWUh]kJUU9>BdX92<Y<Se;
GG65UJ6/][Vg]kFd/jjQThUoN7AeN8BHZ;>laMCZkMK3a/kCbJR2JEmGAS<S5@T0
000000lW@Ui]NHjR[[c>hO;lnnkNf][=]9jBRX1^ETM:E5YNIW9dKg5gNGUmPhF3
NV]MF5E@CU5FFEIEGVmlPHRAVJ:YZZZ/[JVPUHUnMfiQDdM1@DA4A4mPKgZ3SIJP
[;O0a/[<cLg:`KJ_Z9fDS81jO7b1TZ>`^KNha<JeZ:F[][NIL5M<@SH/91X@3Pd8
21<P=5EgPX6;UIZW/k_5e=gFaKnm/9jASY6FT7m/IFQZJFQXIfITHEiNHVYdN7A[
IfU]L7=iPi2FUIZVZjFQYjnf^;6VW8imN7QdK6MRFe9<CE9LJW5cN7eoQI6GVIjP
VYJHUY6=RhV9RX^;SYNLWIbKXJblblk9al_=`JNAQ7ejJ3lK3P`5000000001`dK
<DY/TZbg_loIeM7Ff]kRhM;1]jnRUi>FWZ>JQFmXKg9bMG9UFE18@Ci1Ae5IF5EL
IFU_NXRGWj:X/kg2`l:n_[fg[9j=OGIdL6QPG5YHEUMRM7elOX>5Q8F6RXj<PWYj
NWA`L6i[KWN0S9j]/KBk_;k=gNG]i/k1alJ`TgaaLFYD=bDS9B@O7b0P9S<lA55Q
L8BMZZnf^kjn_lC7blo9_;Nf/:FJThn=QgEPFEaPI5mCAd=3ADU@E5]YLG=fOHF8
QH:0PhR5OgmkLVYTGeiQIFQYJfmiRibRY:BWZ:BRYJFUYJ:JThb1NgUiNWIbLG5b
MWf4SINLWInRXJ:XZjJQWj:Y[J>ESiRSUgi]JgAnMUQ2?T52?SXj=C0a<2PU:CM;
H71dMHFDVJ>b`]?UkNWWj^WMclJo]ZZJQWI`KVa/JVEJD55FEEe`PI2DT8Z4Ogii
MgQgKf=LF5QNI6A[O8J9TYn/^/oPiNGQgMgHc;f]Xi9eH5I8>c@^9R0R:C0nCe]W
NXfO/;o:cmGIdlW6`kVd^;R`ZZ2IWiMgG51EKGEK?C0^;R/T7QdH4`h300@G;T]X
LWB5VZ[0f_7oooooooooonWGaKJXTgMLC4Do>cm4ATI;CTmIJWN4T8f1NWAYGeeQ
Hf5HC4U<CDaAG6YnSIZ[^lgQj>7LgM[Db[VWTgm]GUA7>34[9RLb@55UNHjN[;k=
fNGXgmKAb;ncWhUkMgYjN7]nR9fUVI2BW:beZIJ9Qh5_GU92=2TJ1P001Q<S>TmK
K7j:V[35f>_gln[Sh=FoYi>:QgQLAC`nAdiCG6]hOH22Q8jKYZf/X8acF4Li;RPV
7A8>4QXU<D9FL8jPZk[>i__ooo[ajnGG`:REQgQYFDXo>CDjAdmGIG1jRIRQ[[c2
`L?4^ZbUWI:8OgUmQi6HUYVWZj2DTYZZ^k6FQX1eI5=2<bLS7@l100LB93iDH6en
SI^]`][`o_ojl>[Pd/S6_k6NQVmSH6AVI6M[K6QPF5EIHg1fLfULDdi:BTiIHF5P
IG1lRiZY^<_LhnO^l_;aj][:_:fLRWIQCcl`9R8R81l/=Sm9EFMhQYBPY:^c];>_
ZjNRW9F@ShnEWjZ^Zjbi`[>LU9>GXI=]Ccd]7AD=1000000000lQ>emjQY>Y]/7A
g>[inN_JcLNoZIJ@THj6NVYOGfEWK7QiLgEeKV]]JVETIUi?@SXd<3<lA4aFHW:2
TJ6a_]3Ph^?Xhm[GdL6bYYF5NFaRFE1>DUUQIFQ_NHF<TYVQZJf[[ZjYXIVHV924
OWenOH2<Wk>n_lCFi>3?aLG5aKRDMVmWED0^8AH=2PH000LG<4eQIW65SY>O[Kk@
fM;:c<g7^:VTZ:VOSh5gL6e[JFm`JF=RHE]HGFIZIUYAD4]3@DM@F5iUL7IlRiNO
ZK>l`;nl^;Rh/jfVVHn5N6eRFEMHEeMKFUMGHg9gOXR?TiJFU9^SWINLW9FASXJ0
Q8fFWZRVWjNd/9b;S9BOWH1NDDe3=BTT7QPG4PX<62HjFG9lQYZ[]KoAhN_dn?7Y
hm[>aKng[jRNThQlLfQTJ6IJEeIBCTiCFV=TFeIJFeQLHfagOhF;TijX[[Jk_L73
`[k0a/Jm/J>ESHMnLfUQG5AADeEHEeUUKg9eOhR?VJ:VZJVUYJBKUI>>QXN?VJ:Q
VIFQ/ZfFS9FOZjfDNG9eM6MGBClo@Sdd;RX_@e]UHVMbNh:;TIb/];Jj^kZe[:RX
^;bZW8n4Mg1^KW5]HeaHEDU9CdiHFE9?CTY8CUELHfQbOHF;RX^HXJ2TYJ>QVIFC
TXn;QhF0N7A`KF]`N7enPXZ>SiBJW9jPY:b^XinRY9f?R8F4QX^8QY>QZ:FQZ;g1
/Z2IXJfQPFUUJ5a9?S8R8RPP7b@V=4]SLgElT9nTZZnlc<o7_[Vg[ZNQVIFDUI:;
PGIgO7amOGUeM7IcJ61RHeYAA3hj=3@oCeMEEfIlSIROZK_;g_?fk>?Sin3>^jbN
RgUWD40i=RlY:c<g>D9>F6AfQhn>UibIY:nd[jNMVinLVj://ZfX[;FYU9:MZJF;
JUYRH4/l>3D`:bTP5aHQ<dAMJfmiQ8ZDXkW:dMOGcm;Lf<g0^;VcY9:5PHF7RXf8
NVUUJ6ITGUEFE4i?De1:C5Y[M7QhO9:W[Jf]];bn`/[8_;2/ZZ:CT8f1NW5TG5UE
CDI9CDmCEUILIVifQIFNX:Nc^[bo_;>e^;6YZJjc/[:ja[jCLGV<UhaYBdiCA2dL
6QdS<cdb9B]2HhBR/kRg];>j`l[Bg=S6]K6ZUhV:Rh5[E44e;BP/<3<b;R/c?D58
BdY@FVESF55BEF9bN7M^L8>@UYRLZ;:nb]7;_kg7a[>WX8aiKfQQFU96?d54B5=O
HVUmT9FO[kc1`lW9bLgDdl_7a<G9b/G1_lOCcK:BQHRBUWmOGFIUEC``;c@n@cXh
?d9=HWB=VZ6//[>g`m;Kd/>l^JnJRH5nO7MaJ5]<D6=/Lg^3OX6=UIjOU8b@Thak
JV1CE5mOF59HIg5eMWV7U9b_`Kfe]Kbn]K6ZWI:7OgQbKf9HF5QHFEYOK7Z2QY>Q
Y:2KV:6UUHJ1NW5dPHR9QWj1TIV7JEaSNHZ0Gd0f>cdb8aTB5AlX:2LY=UAhS8jF
XYfAU9jac=O=^jnYW92<Rh^8Q85oMfaVJ7AjLVmeMWZ7THU^M8V;PHAmI6EgO8NB
P7N6SiJR^=;UiN[fkN3</kVdWIjNUHMiJemTHUeNIVYSJGQfHV9fQY2DTi^PYJRW
_/g8b<cCg>3Xj^7Tk]jhUX>9X9YnH4Y0;ah>000000@91PTG>fEdN8bN[[g0`]OV
hn;Odl>fZ9R?QGUVEe9;BDE5CEE<ATU:CdmHIFQYHEA7A3`b:R/_<Cm3>cPjAE5D
HgN1Rijd^[O0a;Vg][:_WXf2NG1PCDA7BDi>EV=XLW9bR:2b_kRYXZk0a/[9bM_/
j=K8`[RURGaoQXYeEUMEBC/[;CY2@CPc=ci4CfEgPhR>X[O2`<SHio3`jM[@b;:X
YJRUS6YGEf1NBTA@Cd=7E55?GFelSYRCTYbKVIbPXIbEWjbYYYnBU9ZW]:fSYKWB
dknYWYbLXZ6HRh9oQiN@Q89nNhBCWIbGVifU]KF[XZ6UXIjQV96FXKJm/k>eZYV;
SYZIRF]PIUlo8aLB3P40000000/Q=TI:C5YaNhJN/L3@h>;Kc[^[Wj6TVHYbETYB
EDDm>cY3C4e7?d=@IgabJVYUIVYYJVMQHF5WJUiCCe=ZNGUfMWInSIn^ZJ6LVIZN
ZZVGR823QGQOBTYJHEeLIWEjNX::RI>MUIBLWjo4a[Zc_/_9`kFLUIVPXHMUE55M
DCP^9Ra0Bc/V8BU0J8Z;Nh>DUIJO[kk@g=[Hh>OTh=gFd]CEbK>XXYn;Kf1@BDU2
=bh/<3HmA4=:EU9GKWioPi2NZ;C0_[bj[K2k]jfRV8Z9U9REQ6]WNXAfJ6=PHfa^
I6E^JV9QHVMbOXN>WZJW]<_DdMOQkO_ooooooookg/[8akZLMf5JC3/`:2LR72T[
828Y?UEVN7moQXfFX[38f=K;`<C9`K^d]KniYZ6SWIF:OWIeLV=EBc`e>Cm0?S@`
>D=@F65`Oi:S]LO?dMSNg=OCdlfgZJVWUWidLFUWHF1VHVMXIfi[I6YbLW^5Pgaf
NXB6PhJ6PWUaN8>8TIjT[;_5_kJbXIB<NWQkGcLL5A8000060P00008?8SaHK7F7
VY^BTJ6[ZJ>PVHmoKf]THFI/JEY9A4eCD4m?BdM=EU53?Ce2B4e9@T90?T]OL82:
VJ^c^KRc^<KCf<_0_kR[Y9QoIUeJDTa=CeAOIfihPXB3RI2EYZn/[:VSV96CTiNH
ShV:RiBW^LOAeMoXekBT[kRi^9a_FeYE@bHG7bXb9Pl>7SQNQI:;TZNc[jfec>Oc
i]2o/ZRRY9fMYIfARhN;VZZ_ZjFIT9NKS7]`I5E=Acda8QLI9C<g?TiLJW:5W:Re
a]?Hf=3?dlZhYYR4LF]XGE5CCd53Df9XKg9dOi:NX:F^/k2WV8N1Ri:7L6M_P9^[
/[S5gnoQ`kW7gNOJ_JBEQW5QDSP[:RDJ1P0383iDGV9ZMXFCX[OGm?oghM?Bd;nZ
X9bGS7UZHf9YN8VARGimOhJ?VZJVVXEiMfiRFeICDUAGGV]iQ8nO[l3@fNC`mOWd
in?Md/:WUXeoL6YTGEYMHUmPIVikPHnZ_<35b<S@f]gGc/2TUYn[]k^_XJc9ck2C
RHbRYHI/H5E3<RXU6A4=30l71AHaDVMYLh20P8VDYK[0]9f8PH9kLgElMVIJEDi<
EEaWLfmUI65IEf9ZIUM9@CXe:B8T8b@[<SQ5EfEeRinY/kk4d=WHemG3ZYVCQfM1
:RP[;c0c?TM9BEAYMgYnRYVUZZ:JUIRIT8R7QgY_MXRHW9BBYK:NP7EiPXIbFUUL
CSPW8R0M5`X000<E;TAIKgj;ShfFZ;K<h>GPdKNXWiZGTHn0KVIPF5YRK7IjO7em
M6]cQHf7MfMIBT=1ADQ3@T91Ae1DFF5bSYjRXZFd_[nn_l;3_;:XVXAbJV=SK6aK
BTI7Ce]TKg^0R9BQ/Kfk]kk2_[^k^[g5d^3NeM?DaJRLW9^LR6QHDdLh:A/M92T/
:B@W>EQjU9nPY[Fk]:fkf>SZhMK?c<2_[kZjZ964Phb=QXJ>U8j0OHV;QhN?VIfI
RWUfNfmVJ6MUIVU_OH^@U9^/`LgBclc@f>3Ncl2g[ZJQU81cK6mjQ8B1PH63SYFK
YZZ^^;o1aloDdM3FdL>j]l;EgmG3a<biWIFBTIB6J5I>BCdV6QhU8alO7QhX@fJ4
U8jE[[o3`;g9gNGGa;NWTGebLGA/Dcdb:b/g@dUAETa6DfE`NXNAVYVES7ekPhjD
SGidLGV0OgYkOH6:SY2<RY>R[jR@O7EcKF9DBDI2@4I>EE]PH6=aO8>:UZB/[jZX
[ZnY[ZVITi:JZ[Bh_<KEdZn;QHnLV7MA?S]0<a/=20T?5A071QDcDf]aM8VPZ[S5
cMg^l>GHdLBcYinCSXQdHEQHFEYPIf9MGEmWL6m]Jf][GU=?BD94Bdi@Bd=6Df=_
MX28TJ>fa<Bl^;c0_[6NSX9jMfmLBT52@CPc=CY0A4=2ATmGFeaOHfEYKFQRJgZ4
RIBR]l[CfN;Sck^k_/6jVh1eIe8n9Q4:0P000000014dD5aJGfQfSJ2//KNo_[^h
/J:HViZET85_KWAeNhF9PgQ^JFATIfUUHF1GCT]4?3e9EEMJHfioU:6W/Kg5c=3A
c/[6`KjfZ9^BRHB1OgIWG5eTKgZ1QX^CVIn[]kZd]/33`Knh/k>`YJ6W/LOLhMkN
k?CUak2c`/6SMUiCASLR4`T51PP=30hM?fN7VIfY`M;Jh>OfooOVe<Fm]JRKUYF<
MV1DCE1IGVAYHUUHGfIZLgYnPgi_IFIWI6E]M7R0RI2P^<cDf=gMfn3VhmO<b;j/
WX]fK6QOE4Xn>D=@EUMKH6QdO8F?V9bQZZ^RXJJXZJ>JUI>KZKG4e=_QkOKXb[Ji
`LRnWXIiIe0f9AlC1P@70@003c5BJ7=gO8VKYjbkd]gHc/Jo^:jVZ[Ro/j:MX9bF
W:J]ZYZ9OGE_KFaWGUM@AShd9ahO:30g>Si9EfA`OH^IYk2i`LC2`;Z_Z:NOT8El
MFmSFEYRIfY[J6ATJ6MTI65KEU1BDTY:D55@E61^PYRY_=?TkOK[c/K@d/fjUWQW
FD<]7a@;2@T91P@<9T9JL7MhPHR;UJJkal>h[ZbYVX1dNXN?Of5GGFIbPH^DWIF0
NXB3Oh:4P7MVF5E;?T1<F5iRI6YiQhnL[;Bja<O4a<G0`<>l/:BER8N4MVa/JVUa
MGImQ8V>TiZZ^Kjj^;Rk_;Vd/:bVWYV@RiFV]L;9bLgEckV[Z:BVXhANBdDn<20B
3A<I5a0?6C1@J7R0R9ZWY:Nda=;Ie/^m/ZVOVYZHTXE^FDi8CEYRHE]BCe=GFEaV
L79`JEeEDe1@G6]]IV=XMH6:TYJLYZfZYJNWYJ^_YIZIVIFCTHj>TI6>T8n<R81g
L6aZJ6ENFEYIE51>De]PHfQ`MGj:VK77c/O<f]Bo/:VXZj>6LFeUDC/]:B/Y8a`G
6bDdB61dMG=hNgb0QY>W/JZIT9:HVIZPYjZPTXnEW:6TYJFOTh9iMFm/K6][JUi;
@T8o?D50>CLmBUQQHVMiRiBFUifW/[Ro_kB[ZZFKUI>?T968O7YmN71^KFa/JF1L
GemRHUeOIFQaPHN3Q89nPY6Q]<W;`lgLdk^^ZJRb[IF1MFaRFDi0=c4_:bPX9BXo
GGEbIfegP8bK/L_Mfl^n`<O7`Kbk^JZDQGiiM71/KW9WEE9EDU=JJ7AgLfiZJ6MU
IVmnQhIoO827SI>IXJNYZ[>m`LG;blFm/jRQViNHVYNCU96<Qh:1Q8R>UijMWYnK
VJ6]^L6o^:jPV9^OXZBV//?:b<O3/::[^KnkYI2;QW=JAd12@S``8QPM:3U@JWMc
MGZ5UJRmc]_Qe/O2`[b_[:n[XiJ3LV]]Kfe^LfeJE5mVI6=]NXB5M5mBBdaJI65J
EEEQKW1^N8^JZKBd/KW7cM3?`kJ^ZjNOUH^6OWE`K6AKEE9EIG=eNGaiMGV1Qhb=
RXR6P7YhLFMYLGnEXZFKTj>_XXb:UjRdX7i[HUeGC3d/7@d3000000dYAEEAEVUj
RIZ/`mWNe<g:cM7;a<6m]:JJSH5mOWakN6iNDDU3A4eFGEa??3<g=Bd/=41?E59@
Dea]P8^@WK2l_l70`<K9a;bd[::DQWmhLViYHU]KGV9ZL75bMGIkPhF4OgMcMWem
LFIRIFY_N8NN/[o7d=_Ld<W>dmK?]Y^?QGANBS``91L:00001a`iEVAUL8:DYK6k
b][OdlBk]:NHShf?ShEiLg1gQiRW[ZJKVYnNVYNHW9b>LUM2<RXX:Rhc<BX[<Si:
G7F:W:V//;_7dMgUi=gA`KJ/X9F@RXF7QH23R8fCV9VNZ:b[Z::QYJFMU8j4OGUa
JfMXKGnO_M3@a/cLgm70^l3:aJB3LVYPD48b91XC3``@624cCF5THg62RiR[`=CU
iMC9blVm/Jn_Zj2<P862OGUgM6UGB3`c<cY0B4a5>34f@4YBFVIgQhb=SiBN[k^j
]kRi]:bUXJ6SVhYoOh5oN7AbL6i^KVeYHf9WKFUOFUiRIVIPGV=YLWj4PWimOhRH
Yk?7g>CQh>;NdK^YX9^GPee4>c<W6Ph71`lI6@h;42E5HW5^K7EjP8^GZ;W4a<?1
`/2g/[Fm`l6fYiRASHV6Pg]YFeM@AT53C5EHCSdh?4ABHFU`N7YnQhb=T9ROXZFV
Y:2JV9fRXj:OWj:UXYfLV9:ATXj<RX5fKFMUIfQTFUIIGfQ[JFU^MGYlNWIjR9JW
][g0b]WUh/Vd/K:h]YUhJVEKCdQ1=blZ8QLF6B0`@e=JFVE`LgV4VK?6blO3a/g9
a<G5`[ZYVi:8NfaWJf]OBd11BUAKGV1TIfM[L6m/KgfAViRJYJ^_/kFj`lS6`Kfn
_knm]J^TWYbGR7emOWalOGQ`KFi]KVm^M8:@V9fQYJjh_lG;bL?1`;jj][>ibM?>
`lC9^j6ASI2PXX9UGemFACH/9bLZ:1X>41dfDVadLWR2S9RW_]O^nochmNoSf=;<
aKVOP6YJC44f<SD`:bd]:S=7G7>9Thb8S8jATi:FV9:=RhJ1O7aoQ8jCTXj:SYRP
XYnKV9F@RhEoNFeNEeQGDT]4A4aEGFM_Lgj?WZ^c][c8b;ni[J6MV9:EW9^HTi6B
QG5/KW:0PW5UIF=LFEQABD0f:QhI7B`nDfIUIFibNHFF[lSDdLNk][B[Y:6KUHUh
K61CB4=8E5Q<?cXnBUY]OH>1NW9_K6MSIFmjNW5[JFY]MHFEXjVVYJN//kJbZJ>N
UXn5LV5KF55=BdA2ADQ=DeMKIWF0RY2ATiRKWJ>SVI>BTI>FU9JP[[Jh_lS5[i^M
YkFhVgY[IUa8<1`E5A8?0P00010^CV9VMXVFZ;W:h?Oon^cRf<F^X9VHVHYcHUUH
Ff1UJ6UUHVI/KgR8V::PTX9jMW1dOXB4OWQgP8^DVYfT/Kg4`knl_<33_[N`YIB6
OWYkNW=aMWb1Q8F9TifT[[Jf][Nf/jfOTY>ESX9cHe]QLX6AWYjLYK:dYiRDX;2_
UgmdJf=OE4e9?C4Z81PH93ePOhR9TiZMXjNaa=KHc;VTUH^4OWUcIUUFDde:C5MV
L6iSGUmTKWZ3RXj8OWn2P7f1RY>GTi2=Rh^>TYFJWj6NUi6?UY^FSHZ:QWidJVQX
IVQ^KVQSHVMcNgUkQ8Z=SHb:SI6CVYfGS8:2SY^W];^j^;c9cKfXWijRYY1YDU5B
BS`]7a/K50d<3aPV=DUIG6AcMGIkQYje`lBn^kfhZj:QZ;Bg[jBGT92BUY>3KEiG
BSdl@dU;BCh_:2LU:3E7F6EYJVedOXjOZk2b/Jf]/KJj]ZVQWYVDSXAmOX5mMg=]
IfQ/KV]XJgF1QX61Qhb;R8R5P7YgMgZ2T9bV]lK6b=?</jV[/;ZbTGYcKFMNCSlk
>S<_;2TW=4mZP8=nQXf@VJ:Y/KVl^;>`Y9>?TiVQWI:>Qgn0R9:JWYVARh5iNhVI
YZNIRX1jMWR2S8n@Shf<RXZEXj^`/k2_/k:ZZ:ZXXiV>R8F3QH^ATY6ATiFHWIfL
WJ2TXYbHUiVLVXn7RY6CT8^7Q8NDY[[5`L3:b[6JU9VUZ8QJADI9@S8N51HJ7alJ
6Ad_BF=eLgJ7U9jWZjjg`/>j[JFNUiVKVYbHTH^1MgIgNGmnKeeBBD=7CU9FGEeI
EU1;CeUTJfe^LG9dNH>:SYNU[jjXXJ:^]kJb[::GU9>>SXQjM7MfKVMPFf1RGeiO
IFMYJf]aO8F8PgimP8J?W[75dmOAd=6iW9NLX9emF4iACdHg:R<U81<80`@A:T1B
EdY;FfE^Mh:EZ;Fh/[2e][Jl`L6l[9jJUY6@THf2M6=CCDLo?SlnA4U1>d9;DEeX
KgElPXN=TiFJWj2W[:BGSX^?VInIT8V3Ogn0PXAnMWQkM6i[KWIjNGEdMGAeMgIe
NWmoPhb?SHb=UJFgam;Df^OUc;Zf][^gW81bJ5Q1;RH/<bhR61<C8CiIKWIdNh:2
PHJH]]3KeLK0`kni^Kc0_[BXWYJHWZ2OWYB3Ng]gMWf5RX^4NWMgMG1/K71hO7al
PHN=Uj6[/k:ZZJng_/;0^:nXX9VET8V6PX23PGajNGaoOWajOH>9Si:DU8n9RHf>
S8F1S9VW[j^^_mCF_j:GUifOR6]OEDTo=2h_<BhW7Q/M:3iDJ7^6SY:;OWf>YkZk
[j2GTXV1P8:4OWE^IUmPIV]bNGE/J6IQI6ibLW9_IEmLEU=GGVI[JfegPhbEX:Ze
_l?2`/G9c/g5^kF^X960LFe_J69RHUmPHfAVK71eOX>7RhnCVY^JVi^FTHnDWZo0
bL[;dmcI`jZTZJjZRfMGCSh^8AHB3`D000054bi:GfidO8J7Qi6V_M?Jd<K0^k:X
Xj2OWiN=Og=dOHR>QGEWHf=OGF9WJFMMCTQ8A4=6BTmEEUMLIW1iP8VDX:JXZk2c
^;Vd/;2]YinES8b@SHR5OWUkOGQbKF=NHF9KEEEFEUMFFUeKFEiYNi6R[k_5eNSV
d;Rb^/K6YH5aIUiBACTb;RLO6a`U>EE`Q9:HXJ>OXZc1eM_B`;:[YIbBRhV<Rgi/
HF=cQ8j=RHB2Q8F7Tj6VYJ:ISHJ0NgYmNgYjNgj6SHn?U9VOZ:f]/KRm_[^b[J^S
V8f3O7akMG=aKFY[KFi`MWb6U9^KXJRXZJj`/:bVXZ>Z/[S0a<G;cl>VRGeoSHmb
DTU5?cP/81lP6a@:1PdK<T]QLGZ5RhZ<V:c4f>3Pg]cFb[bd];VgYhe^EU1CDT/n
;R4N6a8B7BH`>S`k?dA5Ae1LIg1cM7b;VJ2U[[W2a/C5c=;Ff]K>b/>f[:>FSXQl
LfmVGU]DBdE6C5=OK71bNGamQXjAT92CUin^_L[Efn3YhL>YXjjm]iA`Hf5JBcLY
8R0F20000A@^AUMNHg9kNWf;Xl7FfM39aL2h[JBNWIR=PWAYK7=gMg5UG5eMFUmW
JF]bLF]UG59?DUEHG5aJH6U_LgV3TJB`/;2d^/75`kjl^[:UUhUnMV]SHUmKG5iH
CdiFHgB6ShnCTi6CVinPX9^CSiJQYJZ/ZKFnZH=/KGZ5MU0m?3T_8QPG82LT8QlN
9SQCKhFCXK6f/kS:h_Son^WPfmG:_[J_Yi^;OFaTJ71bKF9DD5MIFUmSJW=eLW1`
KV][KgInQhbCWjVZZk6jbMKIem[Oh=kFb[ni/:>ERX5jLFQSH65PGEiQHF9TJgN3
R8jHYZfZYjNVYZV/]/cIf=cSk_KR^ZJY[Z^=H4e;@S4I2P@10000000894ESLW=n
TinW//;Ll?K_h]SEd<Nn]:VMRW9MCTY?DeAECd4i>ci6CE1DFf9PF5ICD5AEDE=I
FeiUK6ebOHRFYZja^;o3a/O8bLW3^JnRUHb7P7agKV=IDe=HG5]OJ6mcN7b1Ri>C
UinRXj>T/<G>b<?<f=:dU8^IZ9edFEAABSPS6QTJ5Pl:2@lO>UM]LW=oS9>JY;K?
h^?JdLk;a;R_[J^TUX=`J6ebLW1YG5=ABTI;DU]SIF9NG5]HF5UHF5aPHfUcOHB:
TIVV/[Nh^;Vn`/6l]k6]Z9^:PGUaK6UWIV9MG61VJ6YbNGUgM79eNG]hMWA`M7j=
XJj_[[S<d[fQV::c/i=`HUaC@2@@2`X20000000D<4UIHg:4SiV/bN[oooogl>OJ
clFo^JfIPfYHEf9XIV5JF5mTIVeiQ8fBTXj8PGUhOX5oNWIfNGf2PhF=UjFb][[2
c=SQhM[Cbl6i/JBGRGY`KVaSF5=ADeQPJ7>0RiNSZZZ[/[Jf/jfXZ:Z`^lC7bLgC
ckJKUin/ZhmhLfmVE3/[:BXT6@h610lS?5=SKg^5R8bJ]=;/lnkYi=gBblW5_kBQ
SGQSEeIJGeiEBdLn=C@kA4YADTi:@S`oAdeCFV1WKgMnQi6O[Kc6a/2l^l77`[FX
WIJCRWY[HEePIF9LFEMFG6I_Mh27RXR5PHF<T8n>R8>5QXREY[:naLO>d;j][KBk
^Ij4NVeMAB/M6QL=0000000C<4YIHVikQHfK/LkVl>gRf<g1_;^e[jBFRGa/HF9Z
LgI_HeeKFEaUKGIoOWAZH5ICEUICDE1AF61UJW5kQY:LXZJ^/[Fk^kRh][:^YIJ9
P7]lOgmjMG9cMgUiNh:8Qh>1P7j0Q8B4OgM`JFUbOX^CUYVRZif2N7f?Wi5gJVIR
FDU0?Slh;24I5A/]A5][M7b5RHN=X<3MjnGGc/S1_;N`[jfPSGQVGf=]N7ehJf=N
Fem]O8N<RXEnN7EgNh23QHJ4PXJ<T92CVZJe_Kfl_<35a/6n_;BZWi23NWIgN7A/
IVMZJfedQ9BOYJR/];ZnaLS:blBgZInP[l78a;Zl`kBFPGn>VXa[E4e:@C4V8AhG
30@0008E<DeQKWZ9TiNO]=Keooojm?7Zg=3:aKJNQFeJDU5@DDi4>C8_<CM2C5=J
G5UFD4M2A4E7BTi@EEiYMH>>VJNf`l_@eM[NgMOAc<2]V8V0N6aNDdi:BDQ9BTY<
EVIaMgUjPiBOYJRYZ:>KU8nAWJnna/G3c]>lYZB[]kNJNViYHEA6>S8Z5`@00007
7CE;EeaUKg9fQYnkcM?>b<Nn[j^/[k2SSh9iLWAnRYFFRWadK6I[NHF9QgmgKf5F
EUQED4i@EEQIGfUfOhN@U9FJXJVa];6_/:fQUH^5PX1lOXB5P7n0Oh20P8:4PWn0
PX1mNg]kNG=^KFe`NHNIZJj//K^dVhN3S9J9JUYIETdk;Rhd=BlX9RDY>UEaQi>J
XZJPWjJealk:`[bdY9B?TiJAPG5YIV=UJgAmOWUhMg5]Lgb6Si:@SXUnMWIjOGin
O7f2Q8VAVInVZZb_/;6d^/32_kR]XYR>QGigLF]UGeeKG65XKGAmR92FWZZkcMOH
dl^o];:e]kZl^l34_[fgVhF2PhZ;LEQEEeQ@@CHc<bPE1`0042LnDUiQHf]bOIBc
c^?_l_Cfk]oHf=OA_Yb0LV=HDe9FEdi0=S4_=DIKJW=bJFANEUQQI69PG5MGF5YS
Lgj3RiBNZ[2b^LKAe]?:_[:UUHV5Q85jKeiEEeMHFUiUKG5gOhJ<UIjRXYjIThf7
Oh:@W:J^/;K4aJV>RYBVZhi^IF1JD40_:2LJ2P<000hU?eAPIg:2RX^DYkc>e<g8
b;f[X9^LXI^:OWQcLgQlQ8Z3NGIgMgZ0QHR:R85nMfUPH61PGemRJ6YYJg=mPhZA
U9NGUYbVZZBLUI2=QgmnPH60OgeiNh62Q8>0P8F6QXN7QhZ;RhZ:RHN5Q8:7UZFb
^kNb`<NbUhZ5SiAhFE9CCT@c:2X]8QXO92/gB65lSI:GXJFRYK;6emc@a<:l[ZNU
XJ6IQ7UgLV]VIFafM6]UHEYJHVagQ8R7R8=mOH>7Ri6EUI6;RHjGW9bJWZ2QXJ:Z
];Ng]kF`YibARhR3O7EaJVERG5EBE5e[M7Z3RY:O[K[3a/O7bl[4`<C>f]_?al[3
ZHUcL7elHdm8@SXa;30g=RXS8b8T:SQ@JGEgO8B7R9:V_];HeMKKf<g4_kjn]::B
PfmOEeILG4lo=Bh[;3<lB5ELG5YFEUaSK7ImOWagLWJ4TIJGVZ2VZ:Z_]ko3a<Bn
]:NLUI6<PgI]IEeFDDi>Ce1DGVI[LWV0Si^QXj2MWIjNVinW/Kk0][K1_J::PhZG
RfE<AD4o=bdW91X<1PH31Q@[B5aTJgN7TIZZ`=;IeM7Hg]S<alG7aKBOTHIjM7Ag
OGUZFe1=D5=GFeaLF5EBBdA7DE]PGUYIGFIbP8bFXJ^_/;6a];o7bLW4^:^PV9FB
Rh=nN71VH5eOI6ARI6U[JVecNX:9SiNHT8R6QX^GX:Vf^;Fk_K>SThjFVhm^EDe;
BdDj=STh<B/V7b4Z?U]eOh24SYFJY;;1b/O4aLO3^kJg^knfYifERX>1QHf>QGil
MFiYIF]dMWMdKVQRHVYbM6mYIfeeN7^3S9JOYJRZ[:b_]KVl^kNb[j^UWiJ>RHEo
Mg1]K6e]KgAkOh64S9RPXjJ[/;Fe][Rd][k3b<[2_lK5]in8PHF0KUQ>C4Y2=S4g
?3<X8b0U;c]<G6QcOHF7QHVEY[Fi]kVn`;bg]KRi/J6ESXN0NG=dN79XGU9;C4a=
DUIGF5MGG61TJVe[K6iaM7IjPhfEVIRFVIfOXJFWZ:VWYZFQViF=Qh=kLFINFUUI
EeIEEUaTJg1gP8ZEVj6XZjf`/:jd^l32^Zna]k>TSG]kPh1ZDDM6AT0h<RlW6A<D
5QTI7Rm1Be1FGf=UKX:IZJ^Y[kg6a<72a/Ro/jbVWYNAT9FDRGifKfaZIVESH5eM
HF=QGUeQIVIRGeiQIVadNGn6S92DVIjTZk:j`L;1_[Rb[ZRNUHb2NG1YIV9KEE=H
GfEVIf]bNhJ=TYRLX:>UYZR[[K:f/Zf^/JbOSX>5Qge[GEYKFE19BDa=BTU8BDeC
GFQ_LWR3S8Z2PhbHXJ6PY:RWYJJ[[jbVXZ6RXInNWj:SXIjJU8^3P7elNWEbLG1_
Kfm_LG9dMgQgMWQkP8J<TYFCTI:FVYnSY:BTYJ>PW9RGUiJ@RH>0P81mNGUlOgn0
PH:4QhfBUINIVi^KVYZMX:N/ZJJTYZbXW8n:S8YlJV1NH5eGEeMGF5IEEUEEFVA_
MGEhOX:0Ngf9UIRCShn?SH^=T96?RhJ4Ph1lNWb0P7]gMG9]JfeaLg1]Jf]/K6mf
OX:0OWalNWUkP8J;RhR7QXB3QHR<SXf<S8Z9QhJ6QhJ5QH5kMgAcLW1^KVi_KVe^
LGIlQHZ<SY6EW:2RXJ:UZjn/YZ>VYYf>NfmZI5Y=@Shk>3TnA4Q8BTe@DeQRKgQj
NX27RXN5QXZ<QgmlOGinP8F:RhR4QHV:RHJ4Q8>3QXV7PGajNW]jNgj1Q8J6RHf>
Shn@TiJHUiB@SHf;QhAoMg9_KFa^LGAgNGaoOgn3RY2CU9BBTY2=RXV6QHB3P7ej
O824QXR;S8fBUiVIUiFEUiRKVi:9QXJ9RX9jMgEeMG9dNGUgMWQmPH60P862PXF8
RHR8S92>R8B5RXb7PGmnOWinOgmoOGaoPXB4Q8R@Ui^KVifQXjBUYJBQWibGTY2>
RhV5PGeiMgIcL6m_KfiaMGQiNGYkOX:7RHb?TiNIVIZIV9FBT9:EUiJETi>CU96<
R8J7R8EoNgUjOGilN7AaLgEdMGQnPhF5QhZ>TI>GUiB?RHAmNg]iN7IbLG9`KVmb
NX:6QHN:RHN7RXb<QX1hKVEOGEeIDdm?DeEGG6E_NH68S92DV9jTYjFSXZ>OVI:>
RXJ0NgIbKfmbMWUkOGn0PhR<SXj<RhV7Q8:0OGQdLg1/JFU/Lg^3R8R6RY6DUYRH
UY>;PgijLVaYIEiJFEQIG65VJg1cMWQkOX65R8b>S8N3PX:3Q89oO7YlOh23RH^:
RHR9S8b<S8Z6Ph1lNWMbKF]ZIfMXJFebMgj3PhF8SI6FVIZJVifKUXj7Ph9nN7=/
J6Y]Kg=gNWakOH>9SiFIVYRFUI>@SHb>TI2:PWUeN7n5QXB1OgmoOh23QXN7Pgae
LW=eMgIeMGAbLgEhO869T9>EUiZLWJ2TYjVWX9NBSXb<RHN6QX>0OG]nQ8R;RhV6
QXN9SY>GV9JASHf>T9>DTXn?TI6ATYBEUYBCTi:BTXn<RXV6P7aiMG9_KVaZJVY[
K6a]LGMmPhF8RhjATi>ASH^:S8^6PgmlOGimOWemPXJ6Q8>2PH64Q81jLfm]Jfia
KfiaM7MiNW]oQ8V?TXj9QhV<Shf:Qh9nNgIfMgMgNG]kNGUiO8:8SI6@S8Z9QhN6
PX1kMg9]JFeaLgQnPhF6QhZ@UIZMViZJVIZKViRBRhN1NW=^Kg5bLgEeMWIfN7]m
OGf0Q8J7QhB2P8:4QH9nNWQgMgUiNG]nPX>1P862OginNgMcK6ISH61LF5IIGfAW
JfiaMGZ1QXZ=TI>CTi:=RXV:RXV6PX62QHN8QH5oOh:5QhN4PGmmNg]iMG=dMG=_
K6][KG=hNgamPHN=TiRLX:BXZj^YZ:FPViJAS8EnN7=bLG1]Jf]]LGAdLgIjP8B6
Ph20PXJ9Rhb>SHf>SXn>RhR7QhJ2OGQcM7MiM6eYJF]^Kfm^KW5fNWamOX64R8b=
SY6EV9VJVYZHUI>DUYB@S8Z=SXj>SHb<S8f<S8b9QXN7QH=oNg]lO7YiN7IdN867
RX^:Rhf?TY>CTiJMXZ>QWIVGV9RET8^7Q85nNGAbM7UmOWalOX22QHV=Shj;S92C
TXn<RXZ;RX^:QXB7S8j<RHJ5RH^8PgmlN7=`Kfi]Kg9fMgEbLW9eO822Ph>7RhZ;
S8V8QXJ8R8N4PGinP89oO7UjOGn2QHN6QHF6R8R6Q8B5P7QbLG5cMgUiNGMfN7Yk
O7j1QXb>T9BDTXf;S8^9QX:2PX>3Og]fLg9bLW5bLgIhNGQhNG]oPH20OgilNW]o
Q8N7QHN;S8b:QH:3R8V6P7]jNWUfLVm^L79dM71^KFa^Kg5fNh63Q8B4Q8>2PX:1
P7eiNgn1Q8F7QX5oOh22PXB7R8F2OWakNgioOGUcKVa/L7AiO7inOGj1PhB7SI:G
VINDU9JHV9>>RXJ2OGYgLg9cLg9`KfmbMgYkO7eoP865RHZ9RXV6Ph>6RHZ8QXN6
Ph61PhN9RHN1NgIcM7MfM79aLG=aLG=fNGYjNGYkPHV?UIRIVi^JVY^IUiJEUIJF
UI>DU9>BTY6?SH^<SHn@S8J2P7ilMG1`KfeaMGQgM7MjNgaoQH^@UYfSYZJVZ:RU
X9jLUiFDT8f:QH>2PGmnOGaiNGYjO822Ph5oQ8R:RH=oOh22QXF0PXV>T8f:RHZ>
TXb5P7inO7IaKfe`M7AaKfaZJfe`LWAfNGYlPXR;SHn@TI6ATi>ATI>CTi:@T96A
T8j<RXN2NGIgNW]iMgMcKFISIV]bMgIaKfmeNGV1QHR9RHV<SHfBShnCTHj;RH^>
S8b6QHInOGakQ8Z;Shb9QXF5QhN8QhF2NW=bNGiiLg=dMgYeLg=cNgalOH1oNWIc
LG5bKViaLGIfMWEcMWaoO7YnOWb2R8N8RhR5PgemNgMfLW9cKFa[IfYaNWieN860
Q8R;Si:ETXb9R8F5QX>3Q8B4OgMkPGilNWIiNh68RHF6SHb1Nh21QHN0NW5aOWag
OGn4R8V6OXZDTINKW9J@TI:CSi2BS8R8Q7ekNG=aM7ajK6E[MWf1PGahLW5jLW5l
NgalNgn2QhMnOhj:SIJ?U9R@TijKVYVLW9JARi2?QXn=Oh23QhAkNgekPiJCPX:7
SI6?PhB7PXR;QgUgOWUdNXJ9O7^1QYRGUYbCQHZRWYJNVYJ=PXRAT7ekO7ejO8>8
RX>5SI:7OXnCQhJDX9F6U9f8RI67QiVEOgMlTYenLXJISFigSh=]KgEfJUe^LVMa
K6a^KhF7M6ahSib@S96@V9J7T9>1MWV6PWZ7PW]nMX^@LgnNSgj@[jZ4QjBJT92:
PWEkTXmjKWF6Q7E]KGR9RX^?OhB>PGA]Kh5nO7MUKFiHD6AdJff?O5MbOhnJO8nO
Q7UdNh]fLhaZHX6;LeIWNW1gKV9XDVNDNfQdFD=NLUQ2HGiQCfIgO8EhJWf>TYB<
N8BQ[9EiNiF>Oh5jQIb?Jfb6N61jO69WNFiLIg9mN762PGMdQY>KSXbOXJRNY:j:
QYjGOW^4RY=^KHj9UiV0Ng1]RG]kSGZ4QHN9M8>DTHj7Qgn3VJ^9QI^<TJFGT9B;
Wk>^ZJ2HPHjZRWZ8Mgj4HVY_LH9]Gg9fNHA/OIR?RhZGWGYeTXF=TG9XLX:IShEf
KiZRRgZ=TGenSh]kKFMeLDeCKG1fIUa[IfFANVV=Pg:@^[2RZZ>>PhjGQX68NW>3
S7IaSY>3PhIeOIf?QY5^IHfCUgiNJ7AXNI61PI:BTYR=TiF@Xj1mPZBJThYmTIU]
OY^5KWAmO8bIRWF2OFA_JWJ2PGf7PG9_L8:KQFQoOgfKR8BXXh><ZYemOjZMUk>M
M6f3XjYlJG9dKVn2RW1MFWN?V8ieP:2WWY^AX;>WY[2_`;:5TYf8W;:RQ86FQfn2
S8^2G5^;Rg9`F55bQW5AI8b;LVi_KF^<VGamNW>0QH:@S92=OHb7NhZ>TXi_KfeX
IV1EFEQJB3HmCFEPEf9UIG1WLhB0NFi]MgJ>VGEYNX9kMfiiPWMmUijDPW5fM6QQ
KeTkCeAHCCe3@T9QLU5FNW5UQ:^SRKOD]KB]V9:T[jbDQh66V9fKQGR4UY>4Jfb8
THQkNFE/M6]RHVeiRIJ5PhV5Sk33Y::bYY^o^j:aWind]JBVWHb5Nh>PV869WI^:
NW1fQi64QgacRY1oPIV?MfmdSjZ]Wi>DPXnVS8BDWIV=O8ZEPgR=OFI[KFMIGVQD
CfENB5UdId=T/:UUDY?2[gi`QYalIGJ0LUimX9IYGgNOUW=_KWj5OgUjO71fLgYl
DeJ5NEadTY63Kg:@Thj7QinQY9b:X[6HMHni/iF=U9FIVZZRT9N:SXYoK6^6T95e
I7R<NVn6VXR:UHEiTJRZ[ZN[[:NITX^2SYB;T8]oQh63PgmbMi6JRFeNMYJ3L6eT
KGMVFeecMGN>R7R0UXf7T9BYXhnF/[N;PZjbPgB5U9>5OGEXJV]DBf]`FTlk?ei/
HdeRO6mcMW=fP9:4L6n;T5UQSXn6SI>TX8EkNYR>IFYhIU5OJF=JDF=MDg5oM6U[
HgBDOfajNGN8RfECNHALHWYhNHEoM8ZFPG6<UX5iTXURFVIlOW9OFfAML7=]KVV:
Xi^IZJBAV:>_[J6NVIVKTh^4RI:HTH69TiZ8RZJTVhb<UIf?K7j7MFR0UX1_H6E^
HfemOgASI7nPT82@Xk2b]k2[[JV?RJBY]JR4KVmfM7U`LXZ>ShMhPi>OWIbg[h^<
WZj^U8jLX8e`KX6CTHAkNXfGK6=hL6]]NWETFEMLE6M_EdmCGGMnHU1JOHb8RYVF
OY:KTYFAPWjM/J67NGbDVi:@NFajPGUkMfj?REi`Wj6@PG5hSZ24LHjDQHR=OgIj
NI6EMVj3VYjNXJ6PZ;Zm[jni[YB6OW^8R612@DiBDEmQF5i/N8R2LW9gXl^lVi6E
S8^>QXR5Sj>VXXMiOWJ8ZZZ>N7I`OXamJfmnMf9YPH=YEFN>X9UjJ79bLWZCYY=^
IG^AV8QmP9RTTH9mOWMnSY^PTH1dMHbIQW]eN9bbV7AfOWE`OG]TG5MHI61KK75^
MHNRY8j3QXf1OI>LUHUnNVm^HEASKg9RC5ITKgQnShafIf9]RYN4KfaeOGQeJUYL
F5ehOVEOFeYkQhR=MV5cUZ:>Q8R=W:^RWJ6HUJBc[ijCS8B>X9fBRV=FMWe^JfAK
KWQoQVEBJ8VTV9JJSh5hSijQXYJHYjJ=OH25SH^DWhIPFVEfT8mkKW9nRi63P8Z<
U9jXWYRNVX9dQ8MhNG]TGh:SUWEeXJ^OYJ:CO92g`ZJ9PXJNT6=JEf61WiU`IF=Y
NhJ3KFETIWnDQVQTPI:BShMkLfmcO7^@XY9mN7Y_JfMUJVm/GF9SCTmfRhJ6OFUK
GX2HTG]YQI^@Q7ecMgYlRhInO6=WSI21Nh65S8^9TXEmU:jbYjRf[j>//Z:?TI^R
Y:JRRGJ0P7V0RhaiJgJ1OWigMH>=YkFZX8Z8VYjKXjnTRH65TiJ@SXB1R8=lPGil
TZ6PU75MM8^BSW1VPhIgLGEaFem`He=>C4mTKVIQI6]QFUiXNWUdM6UcRIRJSHF>
V9:2Qi^PYKc7]Jji/JjlaKNXXYBCThAgI6AjOg5_O6a:>d5CJWIYGfAYK6UGDU]P
If5UNhN7QhVSXgegOX6;RhR4PhjHUhUjLfidM7Z4KF1]L7F2PX:CY9jKX[6m/ZJW
Z:nlc<Z_X:>PTH9oPgmeN7MMBeaTGEMABD59BTQ2>3e>GEUAE5=?CE5PL7YfJgBB
XIbQ/;nmZJk6_k2X[kjeX92>SXf=QWQcJfYZGfUfM6=YMg5iOGIgNh23OHNRZYV=
V:N_ZIf@TZF_/kRn_kNQSi2BV9^FW9nET960LXB4If1lShIeMWf4RXfFXJR>Jf^7
SW]`NGilN61AAdA5@3L`=3a3@cloAeY/LG9[CDIMMh9kNHVCR7ihMg]lQHV4SJ:M
UZF/X:>e]JZVZ:BGUI^S/;Jd/ZN3JgIoMgMaM864LEQPLWEYLXF3N6mdOhR3Oh>;
T8V6Q8J7RXbBWInESiBMXiZDV8UgOh9cLGEjNGbBYJnXWZFSZKO6e]C2/k:[XJ:U
TGMSFDdh<d15?cPT93Y7BDA4F6MMIg^9Thb0PhN7T8n5Ng^BZZNOXYFE][^UWJNR
VjFVVYBHWJ2QTW]`LG5^HEAMIVEWHUE4>cli=D1;EV9VJ6iXNI^/ZiR;T::c_;Nm
bLJcXijFT92JV7m^JfMOIVeXHV5^NganPh2C//[Kf]cQf/g3alFdYJ:PTh1aHU15
AT</7R8V9aTD8CeBD5ALCdYOI5aKIVmhPh1kOH>=UIBDUYfRViJLZ:FZ_<6o^[6U
XZjk`L>j[:>KVHb3RX=hM71TAS4oF5]EEem_LV9NJ7ZEXIjJWk:m^:bZ[JZ[ZYZ>
UYfJUZ:PRWIhPWeaI6IhQhZ8R9FJUi:FYZ6PX9><TYNARH5jKea2=ci0>cDl@38f
ATmJJ6m[KW1eOXV?RhnNVi2?S7]]KWQoLg60OW=dOHJ<SXf:Q8RGYZ2IY[Rn]kJo
^jF>SIREShN0MfEIBDA:AdI;C4@h9BQ=K71[L7MeLWQoRIRZ/:VV[;>e/JZ]/jn[
Y9ZBShV6TYZOX:BXWYZIXk6f`/c3/:fj^Z2ATi23LFQQC454@D4o?d0f:2/nBEEU
LW9XKGElQ8B2R8b9QhF5TIRFV9VBU9ZESHAkNgYjQY>DSHV5PhF6RhnARHRBV9ZI
UY6;PG=TGf1FDe]MF4e8DEQLHVUaLVmePHfJZKBb[Znc]:6HZ[>UV9:5PY6@OFmY
K6a/LgAjQY:SZZb^/;Vi[jNX[k6TVIB>Qg5KDD]7BD<Z6ATS=T16Cdm:BDeEH6E]
Mgn;S8^CU9:CU9RJVj2RWiVKZJRLWZ2LW::WWYNT[ZVT/;Na/[>]Xj6SYk6XTX9_
Hf]mQ7IQGUI<DE5AFfQbKFITKWn<T8^AWZ:NW:N^ZZFUYjJWWHb8QGUaLWb6RhE^
HG20Pgn3Shj=U9jRWIjRZ:B@QgaaKFIZHUQLGEa@@dUEFUYDCEMXM7imOXV9Oh:0
NWn4QGinQhV8QHF2NgU_IfUbOh:6Rh^?U9B?S92FVIZJW9jNWJF/X8j5PWi`IFMX
JVmZFTiEHV=NEUUTKG9fP8fDV:BZY:Zkb<[1_;Z[W:N`YYV;SIJ=QXb:QH^HXJ:R
ZJNOWJ>a]:JOWibIRWM`KFYSF4ho<SQ0@dQ<E5UAB4iBFfefNFmTL7YiMWf;TiVL
U8QoNH>>R8:7R8>1QhAfM7ioMGZ7SHfBWZJSV9JKYJbSTHJ0QHj7PGijM6YRHVAQ
GemPIFigLgF3QGf1R8EnOHR:Ph^<P7]hN7AZJF]VHFUoQhF:R8>5Qi2HVIfSZ:NM
TiNOXjJORgMcKVISIVQQE4];EUiJDdU2AdU>DeYYNX1kM71iQiBITXN;U9>FV96B
UYFARXfCUIRMV9>MYjJNTi>Q[:VPWIZFW9R5NWZ0PG]jN6iZJfeeMG9eOGabLgMf
LWElOh5oO827UZN]Yi^FV9fOX9jMWIVGUhj6QH1mNFmWJgj3OWn1RXnGW92DYjFM
Ui6CVjRXVHYmOX=kKV1SM7MiNFeSH6AVJ6]]JEiOJgEiNgaeL7EeK6EXK6Y^MG]n
P8:4QhAmQ9FIV9FCShnQ[:jd[Z2DR7]hP8^<PWE_MGQbJVU/K6maLGIoQ8J8Si>?
TYfZ/J^SYZ^XZ;2e[ZNRW9VGUi26QhfDU8Z7RhZ?Ui>EVINLVI^NUYFCS8EoQ8N5
PgQ`MW5[L75/GeECFE]ECD]FGeMBG767TI6:Oh2?WIZ;S9nVXiZ<P7YiLV]YIEiR
Kg=dMG=lRI2;PH>=T9>AQH63PWimO7aiL69HFf]iN6m/MG]gNGikMGEiMW5iR8n<
Q7YgO7I/L7YgMGYmP8>7Ph1nO7QhS9JBQg^0SINRXIbDQhB5PXN<QH60PH1iMW5a
NGEZIV5ZLVQSIVQXL7]gJFQbM7V9THb1P8B9Qh5mPX^3N7QnPXAoNGV3TYVGSi:M
Wj6V[:RSXYf=PGUfNG9YHf9UIfI]M7MnOGE`MGf;THMjPI6GVYbIShjIWibAQhVD
UHj;QW]iOgMWGfIXHf=SIG>3R8Z9SXf6S9>KY:6PX:F[YjR[Yj2AR9FQXj>NTXZ1
N7R0O6YJCdmLIVAOGf1NFEULI6ISGF5_M7AgOhJ4NViZKg^3Q8F6RY2=T9ZQXJBP
THV:Rh9gMWn3MfUME59IIgMgK6]ePXnIVZ>ga/2d/;2f_<34aKn`Z::QWYZDS89k
P8J4OGQhNX2:SHJ4R8jHWiRBU92;Pgj2PWn2P7YmQ92FT8nMZJZUW9VIVI^APGen
Oh1nOgagKfY[K6]ePXB3PGikM6m]LfiSGUUIFf1WKW1^JF]eN7MmR9>JWYnFSY>I
UXioKVa[K71cLVa/LgQgMgYeJ65ZN8N=QgYdNX>7Q81iMGAgO823QHR?SW]]MGmm
O823PWn0QI6HUIBBSHfGVHioNH63P7eiMgMdL6i`MgMdNWYiR8b:RhZ=SiFS[JNI
TYROW9R<Oh:9PWUhNH:4M6Y_LgIfNhB6P7MbM7b2RXMmOhJ7P7M/JW1dNgeeJFAU
KGAcL6UXKg1`MgmoO7n5PGMcMgYmPH:6QhZ<R8N?V9VBPgQgO7YYG5UNIfmcLVYR
J7^0OWUePI:OX9jJUiRHUY6CV9^GV9bQXYnPWIJ?QWeiNH28R89mPGadNhN6Ogan
QXjCV9bJUXj3OWagK6=VLGUmLV=_PXJ6OWR8UYFFSH1oOh24Q7icJ65PIfYXJVa]
KFiePH>1S:2VViFDTYBOYZRSVINGRWelQ8InNGUfM7^1PGYjQXb>TiFJX:J[[JFO
Y:^/Y9J@U9jUXiJ;R8R7QhnAQgaeM7MkMVe`O8>5PhB6Q8B;TI6BUiZLWIREUiNH
VIB:PhB5QHN6QXN0LFYbN7elKfEVJfaWG5ADE5MKEU=GFEaPH6=ZKg=iNgMgOXJC
WYjOWiR@RXJ5R8F1PhF0O7afK6YZJ6MZJf9IEUYSIVE/LW5fO7]iNX65QhJ3P823
S9NESh^9QGU_MH>8R7mdKW1dLG60TIF?P7AdPY2FV9VGTHjCV9bNWiVCTiRNWYfS
ZJna[ZfYWiZS[K6[Z::DT8YlN8BAUXn2O7n4P7b1P7AYIVafOGihMGQlS9:7R8Yo
OH5kOX>2OW]aI65XJFQXIFAQGEiLEeQMHF=QI6ijN6i]LGN4ShQfKFegOG]lPH1l
NG=]Lh>=S85cKVi]L7EjPh^<QX>3QHnGUIFGU9RMVY^MW:2YZZ>JUYVJViF>Shn=
S8J0OX23QHV>RWecKf]`MWE_LGEcJ65TJW5aKFmbMgn4S9NMWI^LX:N][JZb^JnU
Y9nDRWibKWEkNgM]JFUWIFAYNXAmOHR;SI2>RXR@TXj@T8n@RhN:Qh>1NgYjNW^3
SHQjL6eaNH>8PgUbLG=gP8nGU8b3PGikQi25MgIfNH65QXEnMW=fNX>AVIF?RX>3
R8f@S89fKg5`LG=cLVaTGUiQI6ESHVMcNG]lP8jHUX^6SI6BTYNMW9ZOWiF<QH>4
Qhf;P7]nOWM]IfmmQXZAWJBSY:>OXjNRW9RBShn<R89kKfmeL7AfKV][HUUIF5UN
HEeOIVARI6AYMg]fMWj>Uhj6Qh^BUiJBSiBLWinJSHJ9SiNJV9FCSXEkNH27RXEi
K6eeNGUkP7aaJFI[N8>;S8J6RhfEYJn^ZJ>OXJR`][Nc[JVUWYNBSHR7S8Z3NG1^
JF1CBe9QKG5dOXN;SI2BTI2=SY>FVYjLV9>;QH1nPXV4O7n3Og]gMGQhMgUeK6MY
JVebLV]RG5maMVUWJVIZKVUZLWR1Qgi`JfmgP8V;R8>1R9:@R8>2Og9XIfU[Jfe]
JVEQG5A@EE]OIFa^KFa_NhV<Pgf0Qh^<SHfDXZbZXIfNYZf_[ZNQWifNX9V=R8^C
VY^ETI2@S8V=T8n:PG]nQ8EoMgQjN75[KWImQ8V8QhR9S96DU9:=SYNPYJ^XWIRD
TY:@RXB0PXJ;QW]hN7YkNW5XJgV9UINDU9JIVi67QHAlN7UcKG5gMG9_IV5EB4]C
G6IVHFA/L6]YJf]YHf5[LWEkP8B9RHZ7OWf7SiFJW9V?R8N8QWabLWZ5SI2@U9bO
ViNEUiRGTHZ5OG1UIg1eLVMJDU=LIfY[K6UYKWEnQHB2PHJ8PWb1RXb3O7ajMg^3
Q81oPX^KZ[:d[:BUZ[?1b<FjZIjIV:6ZZ9jCSX^5PXB4QXJ1MF]/L7V5RXZ3O8F@
TI:CTHj=TINJWIfIUiF?R7a`KGAmQH1eN7M/IEaABchf@U5LIVmeMG=`Kg9gOH>6
S9FETXf:Qh1gLfiYJg9jOh20OGUhMW=`K6MYMG]jMgEgNWYlO7UdLgEeN7j4QXV>
TI:?S92DUY^OXZR_/[6][:f/[JZRVI:?SY6DTXf5OFmVIVmlP7YbK6eiQHn@RX9l
O864QXR4P7inQHb:Q7mjMWEoS8j:QhJ4OWb0RiRNWIF?U9RJWIfKVifGSH^=QWIZ
IfEMEDe6@TUJHf=SHfATGemXLgb8TiBBTi>BS8F3PWj0Ph62R8jASH5eLG=fM79j
RYJMXIbBS8b@TiNITXR8SI>HVYB>RHN5PGiiN82<T8f=SXb8QHB4OWQfMGMiNGal
NGUiMWEcMWinO7aiMgMiO7QbJV9SKgn?V9RARXZCW:F`[Yf?QhB3Og]jNgU^G4a9
EF=XIVEXKgIjPHN<SHbFXjbe]:ROVIZRY9^:OWQfNGUgLVQVJVeaMGR0RXj;PGYh
NX26QH:2QHV9QWifKVYdNg]gJfEWJgElNgQbKg9fN7f0NWAdN7n0NG9^L7MoQXN2
PhR8QXB2PGemPGYYHVZ0Uj>VYIjGUIVNWY^JWj>RWIB:OgUoQhElLVY[NH^GUi6?
Si6CUiZKUiBIX9fHUiNCRh=lLfaZJ6a]KF]XIF]gOWegLg^:UZ:ZY9^JZ;Vi[jZY
ZjRPVYFASHR4PWacJ61NFE99@4A?F5]KG5U?D5UQIEmIFUaRKgj7Q7ekOHJ:QhR9
RY:IUi29RXb@W::OUXj<Si>CTYBDTHb7PgegO8N?T8Z5Q8R@VIjOW9NASi6DUIJG
VY^NX9jKTh^;TYRGT8Z7Q8AoMgAaLgUjMg5/LWn7RHR5QHN6Q8B4Qhb>SXj:Q8=n
OHF9RhIkNGb4TIJFU8j@UIJBRXF1O7eoOgifL6i/MG]eLV]RH5eOI6AVIEeBAC/i
?DUEGEmNFemWLWYiMGEiOGioP7j0PhB3PX:1O7QjNWYhNGj0OGQaKg9eNh65QhV>
TiFIW9bLVINIW:2PWi^GVjBYZjFJTHnDUY>>RXR;SHZ9SIBESXR0MgEiP8B4Q8>4
PW]fNH>9RhnASXj@T92DVY^ES8F3Q8NAUY>>Rh^9QH1kOWafLFUTHV5VJ7B8TYNH
THnHVYnUYJRTVYRCS8ImN7E/HUYDE5YMFU9:A495@d=6AdY?EF=^Mh62P8B9SXn?
Ti6?TI6CTHf9PWmlN7b3QhR9SiJFVI^LX:BUYJVc^[>[Y9ZEUiZIThIeJVY[IfIY
KF]WIfM/LG5_KW1bM7UlOX:5R8V6Ph9mNWanQ8V;S8V4Ogb2SYRNY:VZ[[Vm_L33
a/Bm_;N[XijIVYZGSX5mNgMlOWn2Phb=R96ASYRHVIR?TiB=UYVBThYoMVMNDdM8
?c8c>3/j=CPm@TiFFUeLHFmmQXF6SH^7PWQbKVeZGEIHE55>CUAFGVYcPHb@UibW
]/3?f=GCdM;Fe]GAbL2dYYV>R81aH596@Clm>SHf>TMKJFicNX64Qh^;Ri6FT8Ej
LfiZJVaVH5iMGEeRJg=jOGn2RI>MY[>j_L;7a/>h/[Bc];J`YiZ;Q8>3QhZ=UjBW
XZ2NXJ^^ZjJOXIfIXIf;NfeQETa3>S@f=C0_;bh`=Sm8DU]TKGZ6SiROX9B7P824
QH1hLgElOGYfLgEkPHF5Qi2IWYfKW9jPY:R_^;Ja[Jj_Z9jESi2ASHJ1Ng5_NhZB
T8j8QHV>SHb8O6iVI6=NGUaGE5=GG5eRJgAnQXR8QXRAThn9P7f1PX5mMVm/KW=b
KW1eNX29TYVNXjFRYjZRW9bT[[>h]JVVXiVHViN>QHN8PX>0LVMRGUMCETm7CUAA
Cdi<BD]ADDU4?cLh>CLb:R/a<ca5B4mHHfmeOXZCX:jl`lC:c<_>d=7AcLBj]ko5
`l2l^;>]Yj6MW9nQXZ>MThb9R89mLfEKDda:Bde<BdiAEEaRJG9kPhfGW9nW/KJe
[ZRWZ:NVY9nFSHbBVY^DSXZ6QhV8R8Z<SHjDVIR@Q7n1Q8B7S9JW^Lk@aLNn]l;3
]Z:IWIVASG]QEU=AC4U6?Sa4AT97D5MNI6=MFeQ=BeAJH6Y^JVATIF5TI61SJW5d
L6acPHV7Q8=kMGUoPhR:R8N>V9REWJRc^knn^KBa[JZ[Zj2@PgegMg9VH5mQHfQb
MG9dMg9bLW9hNG]lN7QkNWYiMWAaKFUUJFi]LGf7SiRMWINFWZJVY:2MWIVDU9N@
QWmdLGAmQY6Vb>7Hc]39a<[DaJ^SWI2>UHmlLG1ZH5eGCdY6@CPe>3L`:B@R9bXV
9bdd?U5UKgN0RYBMWINCVJ2RXJ>Z/:f^/JfXZJja]KbnaM?Kf]OFdLc3]ZZQU8Ih
K5e>@38X8AhQ:S<kA4aCH79mOX25QhR8QXJ5PWmnOWaoPhJ=UIVMXJ>PVINMYZJS
X9bGU96;QHF7QXF2PhR5P7ejOhF7RhN4S9biblG5_JZTZJjSRXR6L6YcMG=cN79I
BdM1A4Q4@494@C/h>C]1?SHf>3iAJh::R8Z;SYBBShf<RhAmNganNWZ2PgmjMWMl
OWj0RY^NUIBCShf4MFi^KfaZLGIbMh63PGn0PXF=SXb>UYF=RHAhKW1gOXJ:S8f=
T9BKXjNZYijDRhF3Qi2DTHj:QGiiNhJ@THn9RHjAUj6//[Jf/k:k`lG@j_ooj>;L
d<o?aZfARGiaNXAdHVE`K5YEEE=BDE1@FF1LEe55?3H/:C4e=ce9EE5?G6E]Mgn6
QhZ@Si6HX:V`]kfh];Voa<Bo_;Rc[ZRUZJRPWIN=QGacKfmfMW5_K6QSHF5KDdm>
DEMCBdQ;DE9FH6EWK6QPHF=TJW=kNgUmP8B8S9:IWj2NUhj<Rhb9Q7miLFMRJgR0
QXb8PX:3RI:N[l7Jjm[5a/Fd[:nSPVmhM69/OW]aLW5KBTiCCDY7?CDc;b4L8B<Z
<Bh/=TQIJX>ASi>PZ:^ZZ:RWY:2MXJ^f]jbX[[:e^/C8`[Na/[Jg/Jb/Y9ZGV9RI
X::FRXZ5NGZ6RhJ5QW]bLFi[LGZ0PhR;R8J7RXb:QXN<T9:ATYNIUi:>Rh=kN7A^
KFe]LGQjNGf8U9RNYJfe^KRh]jjYZ:Z][jbX[[jlXYRCPWUoNUXg=TA2DW=jL6me
JEE>De1:BCha;bhS7R<P82X^:2/fBEmfR8EnPX9hL6edNgYgNhB8Qh^BU9jUYZ:L
UXf8T9:;QhN5Qhf>RX^FViVIV928SHj2OXN8OgMeLfa_NX:4Pg]^IF=UIfY/KfYV
KWV4TiRDTY:EV9RFTHZ5PhJ>ShN0Ng^1RY6IX9jBSYFMWjF/[[:h`<K?hOWooook
g]K;^K:_W7iXJ6=KJW]hMH24N6UWJf9GDTm;A3DU92`b>3ln?D9:EV=]Kf]/LgA`
JfU/KfmcOhbHXjRUWifJTi2BTXf:S96HXZ^a][g7c/Zm/ZVMU8f5NFeWHUaIG65X
LgEaKFQUGeYJFEIGFEYMI6adNGeoOgUcM7A`KFaYIf]aM7AeLg=kQ8J7Rhf8OgIe
NWeoPhEoNX29SiVX^M7^ooocc/:l];Rm[XU]LGQnVK>aXYR7L61XMF]IDdi4@4=7
BeEQGUE8<b<S;SU1A4@o?DA9EVYjQ8ZEYZj_]Ko2_kN^Y9nSZkBh^[o6cMCGe=3<
b/No]:^VXYfFSHF8UZ:RVY28OgIbKfaZHE0l:24X=4=>EUYIF5iWKg5`KfURGeeO
HVYhQY2GVj>//KNn`l?0^kB_[jj/[K2_Z:6PWifMVibX_Lk;/YJ>RXB?VHMYDUAQ
I763N6IIAcLX;Cho?TM>E5UKHfQXHeQ=?C0d@e9LG4lk<SPn@4ICG5A=Df1^MGMg
MWUjNX6=Vj^i`<;7e=kKd<:`WiNOYJBUYZ:QXjFUZkJl]jbRV8n9P75TEd]4@TE@
HGN9T8n=RH=oNgIcL6iXHf9XLgf1OW]jNgn0PH62PGelOX:7S9>LX:B[/;>d];>g
^kFa/[kCjOShfknk^[Bh_KRXUYRVZk:k/YV0IeI@DeM>>bdU8bDV;Se3?cH[81/Q
;d5>D4Y5A4IAHG65U9J?RXfDV9VMXZ>NUY6FWjN_]K:[YJBSWIVPZ;?1aKng/[2a
[jZY[Jn[XIZIUI:?QWASEdXk;RLX;c<c<Bh_=CU0ATI6B4Y@EEiXKFYVIVU[K6md
O8JBWZRb^[k1_K6ZZjb//;Ro`;o4aLBm_LWDgN[ahLBd]JjSWI^ANFE[NHNHWHmh
IUE1=CPk>30];c0a<cY4B40^6`lA6R<[<2lZ8b0/A5a/O8Z=RHfL[kRf]KFh^l3<
g^gflnSNe/o9aLC3_KNc/kFbZj:LUY2:Q8>3PX>2NG=aKVe^JfAIDDe?EeiSIVMU
H5eKGF=ZL7AaL79bLGN0R8nBTY2AV:2U[KBf/ZVQViF@TINIVYbESi>HU96GVYRJ
WjRhd^[ekMBjX8V0MVEQGE58EG63SHn0GSXS7B<`?dI1>3Hh>d1:E552:aH?62i5
FF5NDDE2BUMVMGmnNgn4SYnZYYnQYjN]^/[Jh^3Idlo<alG0^;>`^/K8a/:gZY^9
MVAMFeMDDUIPHf5NF55>CTU2A4]>DUQFEE]MH6Q`LW5_K6Y`NhJ<T9JLWjB]^L;;
clo<aKfi^[RbZj>LW9jLVI^S[K6a[J2EU9:8QIN`aMk^j]6eYIN9P7ihLFe^LH2J
[:jRPePc7A`T;STl=S<c<SM2CE1;>2<L9C=4F6IYJFQUJWZ<UifPVY:AVJ>`_;Z^
X9^NXZfh^kVbZ9jGV9ZGTH^6RHj=SY6BS7e]Fd@d<3@mB51EFF5XKG1/HUQACU5G
GfQbMGIlPHB;UIjQXIbBRXZ@UiRGWZ:PY:nh_;bj]:FGSh^8RY6DTXn;Q865S8j?
TI:BSH^8OWn6P7j@//gHbjF?RhAlMfmXJWJ6U:Fc]j^FM4/b9bXhADQ8C5QOEU9J
HfEODTQ=H71hP8=oOG]mQiba^kZbW8=iMgAbMGAaLgf9UjZl`;fcX8QjNGf1QXR<
TYRPZ[2d]K6ZXiZBSHZ5P8J@Uj6WX9::PW5WIVAOGVEZJFIXKW=dMg5RFUUKHFQ]
KVYTIF]aNH2:UIbMU8MnNgUgNWn3S9BHVY^MVY:8OWEcMgf3Ogf2P7YePYNVa^CS
]i6=PWAbLFIOIg^E[l?@elBYPV1@Be9OJVe_MH21OXJ7OW5G>c4d?4E@ED]7BD=3
DF1WKG1[H5YOJ7AmNgA_JfUbRJFe^;>SUY>@TIJMWinU[[S<gnOUf<F]UXEmOH><
W;6j^;F_XHmmLFMPGeiLGfQdOHF>TXj9QX9kMW1^LWUkN7UlOX:6R8b@THn>Shf7
OgMeMGUoQ8V?UYRCRH9oMG9cLWV1RHn;SIbCNg^CXZ_9l?[H[IFAQgAdLFUeSJRk
aLo?_:5eB38/9RHb>c`oCE=9>2`U60<000016C94Bd]?DDY;FVUdOXJ7PhRBX:^]
Zjfhb=3Gi>k`j^;GaKF^ZjVZ/;Bd^L;7akf^W8=/Ge]JFV5`NXB?Shb7O71RDDM3
@DiSKgR8TY6?RW][I6IZKg9cLFaZJfmeM79dKFEYKFi_KW9gNGn8Tj:c_lG>e]34
^kB`[jbWYk2ob];Mg=?=`JZLSXRG[/kVfk>ERgUXHEM9BU1HKG^2R7UK=0X01Q8]
BeYVK6m`IEE@Dd/o<BL/?U9WNX5lN7=]IVUcNGmoLV=MGV1RI6ASIW9oQi2NZ:BK
U8b6QhN0PXbHY[O:eM?9]jFHS81iMGIkPXZFXZRVW8j2M69FDEISLGb0PHF6Ph5m
M6]WIVUdPXbFVIJFUiFFX:bc]kB[WiJAT92@TIVOXZN[[k2]XI1nJUUBF6UmS9>@
S8j;Q7ikN6aUK8FTbNkggk6DT8j;R8Z<Sib]/[Jb[J>8I48`<Se=GVQYI65NDdI3
A48i:QdL;49AFEYBC4U7AdiLIVY]KW5hOXREW9ZKXjZ`_<_IhMcBa;R_ZJFPX:BX
[;6i`<Bo[YZ9MUi@DeUKIWjFWinMU8MjKV1=ADUAFF5]MGEfNhB1MF]RH6AYK6ia
K65IEeYPLXJCU8n;QG]eMWAbM7b0Oh>:TiVIVINCT92FWJ>Y]Ko3a/G0][>i_<;4
`LO?fN?/kmBLMfaMDEANGV5gRI2JWYJ7JTLW5AHS>5AVLgakOW9RHEmGC3TZ:CI@
KXB9PGIeMFm^MWYhLFUVIVUZKWAbKWF2R8^<T8j9QGmbJfecNh^O[[c4al[6^ZnQ
UY>>R8fIWZ6Y]K^h/JZNTX9_GU9?E5]SJ6ecMgMdLVmXGeUHFEiZNH::T9BLXZBV
YjRVWI6<QG]mQIBOYJje/Zf[XiR=QXB3NWEiOH64QHF0N7A`JVEMEe=HIgB5VJO2
b9j1N6UNGVU/MY6HX;Fh^K>KQ5ho>CI3FF5^LfY^K5U;AD8m>S0Y<ci5DeiQIFMW
HFAgPXjNXYjMW9FAVInIVJJf_L?;c<_4^JZ@Og]aL7j@Xj^b`LFn]:2;OG5SGFA^
LWJ1T9ZKVYN?QW]bIV1RIVU^MGf9TY6?S8AkLg9_JfY/K6eaMGUlOWmnOX60O7]m
PHF8QhR:Si:DW:2OX:2OWYfRZJZ[[Zf`][Fa/k6[ZJNTX:>TXZ>[/l35]i5]J61C
C55MIWB5R8n@PG]YBBD40QHX@5m^L7=cJe]BDTU1=2PU<U1QKGYdJfQWIfY]If1N
DdU<EV5]M7EbMH2<U9FFThj;PW]oQ8fIWjZg_/K<dMG?aKNXWYZJYKFoaLW>dmG>
_;6YW8n7OgQgNWUiOWilO7ahL6EJDda8B4iDGFUfOHF?RX1jM6m`L7MnQX^8RI2K
XZ2QYJ>LUI>ETXR5Pgn3Qhb@TiJ?P7UcLWMeMWZ5WKFob=WM]H^1MVQ/N7jF[kZm
alg0]Z::K4/k?TUHIg9fKfaVCChh<bXS6`dD7bPiATE8D5QNIgMlPY6?Ph:6RHfG
XZJa`<[>c<Jl/jbUWi:8QX^CVIZLY:^^Z:6NSGEYGeA=Be9KHVn6VIbFSX9kNGUc
JfUTEeIULGEhO7UaKG5`Jf]ZJ6Y]JfAVLh:7QH1jNgalNg^0Ri>IWIfNWijMYk>i
_/G9`l34a;nj]JfXY:JQW9nLViBATHB5Vj:V[ZZ@JUeBA51JEfYnQHF8TXj4OFQ6
<Rhc?e=[MW]oP7]cKW5YG5Q:?DIKJ7V<RWYcJUYGH6IUIEi@D5YZLW9gOH>8R8R7
RI6>Q8F8R8nLY:R//:bZ[jjYZkJk^;B^YZ6UZZRNWJRXXYbGTh^3OGYhNh64Q8R@
Ti27PWmjKf=SJFQVIV]_LFi/K6UWJVi`LGAaKWf>UIZNXIf=R8EjN7afKg=iNgj4
QhB5P7I`L79]L7IoRY:HTi^da/W:_9IcIfYaP8jHXKS;`[fo_K6HPFYHCeYVKGEh
Lf1JJ5e9Ad0f=2PK8SM6C59@BeMVJVaaMWQiNGf2Q92MXJ2T[:^SZ[6_[:Z_/jjY
ZZj`Yj2X[:JTZZZXYZ>NUHf9SHn6OhB8Q8F4PX:6Qh5mN75bM6aUIV=KG69THf5R
I69JEEaNFUMGDTa<Ce1CG6Q/IfE^Mgb3S9:CSiVXY:Fa]KBl_KBf_;Vf/jb]/K2/
Z:JRYZjZZJn_/Kc8aJf=NFmZIfanR8f;QhZCThEWCSdP4b0jE6=`OH=nL5a8>3Pg
918F:CiFL8>5MVIQHF1RJW9`JFEVKGZ8Si6<QHJ9QH>;THj;RXVDWZ2W[kFe/kNe
/;Bb[[2/XYZHVYZMViJJWiR>SI>GUXj6PH27RhF1PX1nMFmbKF]`LgI`HEiTK7Im
N6m_LW5fPHJ=TYFIW:F]Zjb^/;:^[:VZZ:2PYJ2KVYbPWYZHUXb8P7E/K7EdMX6:
Tija`[2=Kf9TJWR4TijJT9>MYjVNRVeDA49CJW^0PGe`G515?DUBB3T/;Sa9EUiN
DTI3@TM?FVM]KVaZL7f;TIRPZKBi]K>i_[jj/JNRXjNX[:nXUXZ;QGUeMX26OgEb
LFm/K6e/K6mZHfYaLVeZKg1`LW1bN7j2PhN=Q7QgMWQlMf]XKW9`KVe_LgUkOH62
Ogn6RHR7Q85nNGMoPXN>T8nBTi2AShnEVZ6WZjf^/[Ba]KFa/[Bj^l?@c[J?LFUV
K7f<Vj2HT9>MVHYgH4Dd=4QSO8^9OgMbK65IF5YLFTi6C5ISKgE`IUeMI6]dN7A_
JEmJG6IfOXF9S9NDQHB3P8>5RH^<SibUZJRRW9^OXZ2NXjbd/ZfYY:>UYZ^[ZJf/
ZJNQViNBS8R2NWf1Q8V3Oh:1MVe/JF=QHVY`L79eM6m/LgYfLVe[Kg=bLW=bN823
Q8R=T9BFThn>R8R@S8Z<R9:JU9^QWIfIR7acJVmnPX^PXHMcO8V=VJF]Zi5oPHjD
Rh9dH59CHFeiQh]oJf5IBdI3@TU;@S]3EEaPJ5m??c<e>Cm:DeINI6=ZLg^9UYZG
VYbMVZ:[[k:k`Kfj_/K9`KNa/;6/YjJXZJb`[JBIShIlNG]iLW1/IfQZKgV4Q7Q`
LFYUJVERJFabNgn8Shb;QWihLW=hNgeiM7YmP8=lMFmZL79eOh63OGEiOGj2Q8V@
TIZ[]KZe/KVo^K:b^;FY]<S<dMGJgMk@ZX^0OX>C[<O;XH5lO7e_GT`h91XP=41:
F5@f8BP^:B0O8BPc=ce>GVUhQWeSGWV?TY6FVZRg/jbZ//39^k;5`j=nJ7R7MW9i
RIjKOUHhA72Xc<Ff`<Nn[I^DU9B8Oi:VZI^4Ie5HGfiP7PD<8S]@D34b>AP04Clc
0P<Y?c4Y:CE3?C4lGg=]O9:4Jhg2`ZNMX[gHckRZ/[>fhoobb<W`n]VoeOKdfM?R
e;Rj]jV_/;:iaLk<bkjDJWRO/ko=fLVVTiRS/JnPUINAOFahS8UoJfQfPhZ2QYJI
PW5]Lh>9ShIcHDi;DTe7B4Y@CDMDEEAUJfU[KViXJ6U/OXEeKgUdIf9VGe5@GVaX
L7IdNgUaM7InKeM;?TMACChaAeeDA3/oATmME4]?CCY7FeEGI6iWIfYdNgQhKEiU
JgN=VJVT[;2QVI^YYYbMV92ATIJKUiJSZZjgak^TYZFPV9>EVjRe_<>naM7UlNWa
m^odlN;HbLgVlNO_o_K]mOOTfn?Xe;fd^=7Ld/W;akFWUi2FTHnFS7QcPINOUijR
ViNDTHb?UYB8OGn2Ng]hLgE[DDU8Ade@Bchb;Bd];3Hi=BhS5A8M9RXT:Bl_;2DT
9bTR3P042a0W=T4k=C/g<24<1000000:20T3000000000`/I8AdH7R@W:2HU5a@P
;30_=Cm1@5QfMF]ZKWN2RH1oRiZJV:F^Zj>VX9RCVJ6RY:BZ//GBcm;Wl^KFcLS>
f=SNj>KRk_oooo;ooo?If^[moookmNG^ooOOam3Ke]OKdlNl]lOFb:RQ[K6ebLo;
c/W4cmcKak>/[K2mc<o;a/cHf]W:^kji[kC8f]O>d=CBb[jRX:FRXYfDT8ZAThR>
UYJ>QhF3QGiYEDmBACY;ETm>D4E3ASTa=34^=3HY8BTV<dQ>CTTn:RPe?3`k?E=K
D5IMFUi^LV5IF5I@AT=;FF=OFUI=@U1PF5EHC4M1>CeBMXIjHd/k?D=@G65LD4YC
HV5VJ5U6>ci5EV][H5UBCUM[K5mULgYnP81nQYFKT7]/LX6<TYfSW9bU[KW5b[JW
^l_8_:jX]lOB`Jbb^[g1`[Zh[I6;WZNNWJ2KYKO8eLBTUiJK[[^]WZBl`KFb/ZbR
UiF3K6amTIVBRh>3QW5OHFejNGAbKF5LJgE]KX6<R8>0R8j;TY1oNG]nRi25NG=V
GV=UIfU/JEmBC5YaNGUZFUYJAcM6EeUMIeU4Efm]F453BUAZOG=JCdU<Ffe_JFML
EDiIGe1?FeaLF4Q:Ff=LB4=?CeQ_MgQjM7IjMGElOGEeMWfFWH:2U9fUY9VATJ2^
XIRTY::VWi:DWjJUZJZRThF;WJ6X]Jn^];Vo_Kbl[[C=d]7Bal6n^;bm/Zjoc<_<
aK>Y[;6baL^o`l6VTYRRW9:GVIbY[ZFDQ7MjR8FBYj2?QHB>ViJ:PhfGTI2AS8:4
S7m_O8^BV8ajM6aTJFa[KWR2Q8>3RhZ7S9NOSW]fLWV>YJZNX:BOW9:7Q7Q[KWEd
LV]bOGIQEU1<F61FADM>E5UFEEQIFUI@EUaOJg9WH6aaJ5iSNh]hKG]mN7MjPi>G
Q7^2PH2;X::CShZ1Oi:SWI2F[:n__KR[]knaYInFTIRRZ:fd/[JkYiVGUiJERHN;
Q8FBThB1OW]lLV=CEFEcKEUDI79cKf5UNhF0Oh1^H6b4TXb<Rh>0O7V4RhVKXIJM
Z9n<PXNHVhZ8VIb>RiRPYZ>HWIfEWJZXVhajIVUbPIFAR85mOgehNVeDAd4i?e5K
FE]JABHG7BXl?bh/<R`Q93Y=CT8g=C4[;30e>3a1ADI8@45BEU1BDE5ADUQBBDY?
@Sa@EdY;E5aECUEACEMXIEUPJFebM7AcLWYeKWn>RGaiOX>6RY6BRh^;RHQhL7Af
PY:ARhnFWZZbYYNCTinUZ:nla;Fa][Bl_lO5]KS2aLBm^K^^[;Fc^kZXZl76^jJ=
NH6JZ:NJVJ6/]k:YYZ6OVhb<Vj^f];;6emC<b;VX]<_4][o6`kjm^:jhal6YThEm
Tj>PXInLTXF1R8n5PXf;Pg]cMgb6SXf8Mfe^KGF8RWelQHZ<RH5eKF]VHE]JG5YL
FEYQH6I_Kf=@B4aEEE5CDU=LGUiTIUmOIFMYKgEfLg=oNV=MHF1[LVe_JV5JIW5Z
J69GGVESIV=KEeQNHFE^L71lO6UIHgn?T8j<RXbDYJZJSi:8O824RYFOWYfNTHVF
XZ6OWifHU9>DXkFl]k2d^<?>d]G@a;_3cmo]j^_al^WOjNkUd[noc>3XeKjd/Znd
^[N`WhR4TIFBU9RLY9n;OgUgOXnHQWMnQXR8SI2BS7idLWR1QGecL6MOJh>AUIbJ
SH1bJVEHFVmeMhRGUY2=TiF0LX:BU9:ARh5fM86@WIV1OH=lMgIhM6A?ATmTKV1?
B4E1@TE5ACha;SLg;bX`=3M2B44i?Chf=dE=B3`i<be2BdeHEe=<CemLE5=>B4U?
CD]BIgYjK5]UL6ELFeQHFEeRGV9/JF9TKWE]H5eMEU1GIG5lQX62RXJ3RXenKfQP
EDmXS9nPRGb2Ph^8OgigLFikTInTX9J8PH>4Ph5lOh^CVJ2Z[:6DSHn?PG=lSYJN
Y9jDR8B8QhN7R9FJUYVOU7n5T8b>SX^;Sh]nPi2>Pgj0R96?Si62KVETKGj6R8Ig
NHjCQWYmQhZ9PGaoPH23SY>=RY6:OW]kQ8>7UY^DRXJ9RX9gL6e/JfMUHVI/IfMb
OH:2NW1`JfihNGMfN7UnQXB1Q8V<QWQlR8b3MGImOgUgOh9oOX1oMG9jP7eaLWEg
OWf3QhJAUiVMXjFPWiR8RYJOXjBXZYnIZ:nTTh^8OgAfQiBASi>=Pg9XKgN5R7if
M7n9SY>>QhJ=T8R=X[BbYYnHUInVZ;6g/Jba^KZj]:fWWiREWKFo_KZb/[jl/[:b
/;NgZj>QZ:nZZJNVZJFUY:FW[K6YXj6QX9VATIf`/:2KV9JFS8F1Q96ETH^5Pgmo
OG]mPHEoM7AlR8Z2PHR@SXF9SGmjOgj0QHZ3LW5iQ9NOVI>:Qh9lOGIaLgEfM71_
LFMIFemJEE5BEf=WI6ieNGE[IVI[L7=lPW]eOHN3OXF@TXn7OgYhPHnMZZfSUY29
Q8F0MfeXK7Z;UYZCSHV2O7MbJFIVJFm/L7n1OGYeJEA6ATe@D5MJE5=LJV]WI5mL
EUYWL7eoMVeUKhF?RXZ>Shj<Qh1mS:6XXj2RYZVWXY^HV9VMWYfNWZ6/Zj:KWj:?
OH2;SXZ4PhJ4PXN4NWA_IfEWIEmMHF1JEUMNIF=GD55GGU]IGV=UF4iAEe]LGVE[
JFQZKF]PGF5XKg=cNhR;Q7]hPHbFTH5hKV]cNGUfMWaoMfi[JfaeOX:;RGIeOX=o
NWf3PgaiOhN8P7QgNG5YJg1aL7B0RHZ<RXAkKFQVGUm[NXF:QgEWHV1SJ6mcMgak
MgUoPWinQ81cJG26Ui>7Q8J4QhR2Q8=oO7MfO8B8TI>3M71cNGQhNGEaLgUlO7If
OGQgOWn2PgagN7UhNgaoQi6CUYfNWinHS822TinNUIBGUYRHU92?RXR8Pgn3RI6G
UXn>THj=RXR>Ti>AShf;QhZ=R7efLFmfOX62P7M`KVYZKW1`K65OIVIRHf9MGeiL
H6=ZM7IaL6m_LGEkO7ahNGinRIVGUI^RYIbCT9JOWYNEVJ:Y[kBb/JbVXifIVZJ`
/kJg][S0aKn`VXjAVYbMWj:ZZjBRXYnIT8N0P8F7RiFOXj6@P868RHR8RiBLW9NF
VIJEVIFBV9ZJX:Ve^[Jc/Zn^ZJBSVi>FWJ:QX:>Y];R_YZ2KVIZCRHRAW9ZCTi>E
UY>ETHAnOh>4Q8J9Shn:Rhf;QgiaJFQ^N7YiNgf1OgQbLgIgO7mnMg1aLW5hNgYk
NgimMg5ZK7AiMFmcMg]kNGYfLgUcJFa_MGYbHeiVK6MLFUaKHVQPEU=IGeiKEeYM
DTiKHEaLFUEGGFI_KVicNW]fL6a]KVe[JFQLD5QVJ6afMW9dM75bK61JJ7=bLW=i
Oh60PhAkLVe]Mg]hNgejNWIcM7=`KFidNWQgOH60PX>2OGUiNhF?TiFGUiFFUIFI
W9bGU96>U9nSZ:fXXinKW9RASY2GWYZETY2DV9NEShf;R8EmOHF9SI>@SHb:THf1
NgIhPHB3QHJ1NGMmOgamP7aeKF]`M7E`Jf]`N7n9T9:=QhB4QHB5QXN?VZ>TYJBN
ViJ@RXZ@U9FBTIBJW9NDUIVJUI>FWIjFSH9jPX^=RhJ2P7efKfQSHf5UI6=/LG9f
NWinMW9`K6a[I61SJVe[JVebLFMVJVMPG65/MGQjN7IeLg1`LG1aKfUWJFa_Mh29
S8N8SHZ0N7b3PgmoOGf4R8F4Qh9lO7j3R8N8S8j<RhjCVj6TWibU/[^f[:NTXIfJ
V9BDUI:@THj9Q81nOgn0Qhj@T9BFT8V3Ogj5TYRFT8Z6QHbBTH^5PH2:UYNDV9fJ
ViV@RXV6PXB<T8f;RHAmO7]hOHN=TI>GVIbNV9>CUINETiBGV9^LWZ:PViZKVYBB
Thj:RhV6PG]kP89nMfm[JFITH5iTKG1fO7YfN7IbLFeaMWQmOH26QX>5PG=UFeEE
GVekOWemNgEZHEmPGeeQJfiWGUQFFEYGEe9?DEAJGf1NGemKE59IHFAWJfe]K71i
P81jMWAeNhF6Q8B1Q8B1P8B:Qh>0NWEeNgelOH26RH^<RX^;Qh9oOh><UZ2Z[:FR
XIV@RhJ4Q8B:TIVRYZFPVI>8PHF9R8R;T9BGW9fIThV0NgUjOGehLFmaLGAeMWYm
P85lNG]mP8B4PhF8R8^AUIFCShR5QXB2Q8fCU9FASHb<RXb?TYFEUYB@S8R;TiB;
QH>0PHB0OhF7Q7efN8B@V9RIViNCTXj5O7=/L7YnOH:8Qh=jL6YTGeQBDE9EFf9[
LgMdJV=NEU=CEeeSJG=nRI:BSY2DU9:<QXJ:SI2AT92<QXJ5PGimO7]hMWUmOh1o
O7YmOgejN7QjPHV:R8V7OgIfOH22QHV?TYFLY:VXX9J@TIJJXJNWZ:ZUWYNAShb6
PH1mOXB<TI:AT96>Q7aiMgQlPHZAUIZLWj:MUHf5PX>1OWn0PhR8RHN3PX5kLVi^
LGEeMg]nQHJ4QhZ8QX:1QXZ<SXb9QhJ4PX:4RI2CU9NHVYVFUYJFW:F//[Bc/kJf
/J^UXYfFShZ:SY>IWj6QWY^GThn=QginOhNCVI^NX9^DRhJ3OGQjP8N8RHb<QXB4
OWUhMGEgMGUnNWA_KVi]JfMWIfMYJg1eNGn0NgA`Kg5`Kg1iPXN=TY:@TI6;PX26
RhbAVIbNXZFSXInCS8b7QhjAT8n@ShZ6QX=mMgA`LWMlOGajN7IbKFYUH5aHF5iQ
HV1JEeEBCTQ4A4E:D5EHFf5WJ6EOG5eMGV=TIF]]LG=cLW=cLFeYIVAVJVmgOGml
NGMiP8J8Rhf<Rhf@Sh^6PX1oOWakOGajNGYlO7enOWegKVYZKGEmP7mjNX21Og]f
LFm`L7EnQXV9Pg]gMGEbKVUWJG1gNh:6QGaaJVEPGEmVKgAhNh:9SXf8PGejN7Eg
O865S9BGUi6;R8R9RhnCU9NOXj:SXj6QXJ:PX::UYjNUXjBSX9ZGVIJCTY6AT92B
TI2DUYF?QX1nNWMnQHJ1NGIfN7UjNWYiMG9eNGUmPhR9QX5nOWmnNgUhLW1bMGUm
OWinOGUdLW=fNGj1Ph5oOgmnOgekNG]oP862P7emOG]kP8J5Ph1oP7ikMg1/JV]Z
Jfa^M7^1PH:8U9N9OGn1Q8jJXZ>TY:FXYIbBQGUbL7=lQhj<QH1kMGAdLFe]JfQ/
M7]nP81jKVETIVMZJfa^LgZ0QHV5NW=dMgIeNH28S8f=SXn?Shf8Q8>5RY:GVIZG
TiFLXjVWY:2QYZ^][[:f]KJh][>^ZjRVZ[2e]Jn[ZjNMUiJCTHn=S8Z<T9FGTXZ2
OWemOX61Q8J7RH^<S8n>RhjATHn?U9VJUiB?RHB2Q8>1PXN?UIJEThn8PGinPXF4
Q8J4PhF4OgUfN7enOX25Rhj=SHn>SI2DVIbKVYZGU9BBTiJDSHEnNWYmP8B:S8^<
SHj;PgaeLG5cMgUiNGMfM71/JVMUI6EVJ6icLg9eN7QeLW5`Kfe/K6a]Lgb3R8J3
Ph:0PH61QHV=TI:@SXV4PGahLW1bLW=dM79`LWIhNWanOW]iNWYhNGUfLFUUJ6MS
HfM]LG9fOXB4Og]hLg5_KVmbMGQhMG=bKVYTG5IGG5iOHVQ^LGAhNgj2QHF2PhN<
Si2@SHb:Q863QXV:RHV8QhV7PX1mNWQeLgEkP81nNgE_L7EiNGEbLgMjN7MjO7n4
R8^=TYFBR7mkO81oNWUhN7YjMgA`KFYVHUiKF5IFEEEGFeaMG5]JFUaPIVa`LW=d
NX>=Ui^IUI6?T9:DU9BDUIFDU9FGVINCT8f<SI6CTi>AT9:HWJ2PWI^IUYJIWYnK
UiFFUiRIV9JDTi2=SHn>RhR3OGYkOWeiMGIhM6mZJFUYJfe[JFU[KG1dMgYkO7n6
RXZ:RHN3PHB8RXb;RHN6R8b:QGmkNGYmOgmoP821Og]jO7ioOG]jNh27S8^5P7em
PXJ6QXV<SXj=SH^:Rh^=S8^<RHF6S96@RHF4Ph>9U9fNUHEgL6mcOHN;S8R7R8V;
R8:0O7IdMgn7S8f9PG]gO8:1O7QgNX6:TI6@SHMnNWYoQ8V<SY6EVZ2RWiV@RHZA
VZ6VYjBPVYFDV9bMWYnMUiJJWJ2RXIfGTY>JXJBWYjJUY:N//[Vl_;Vc[Jf]ZjRV
ZJna[jj[ZJJPViVIVYfPXZ2OWinPWiZETHj=S8V8R8V9QhB4PgmiMG5]KG1aKFQQ
G5UHFEYKGf9PFeMEEeUFDTm?DEMPJW5cLg5_KVi`LG9eMWQlP8>4Q8>2P822QhZ9
QX9mN7IcL79aKfi^KFUVI69OF5=BE5MIGF1SJ6YYJ6ISHfATI6AVJVa_LFm[JFUY
K75fMgEeM7EfMG1ZIfU]LGEhNgYhMW=cLg9dNh65R8Z<SXj;RHR5PhN;Rhb>Shn>
RHJ4Q8J9SI6ASH^:R8F1O7MbKVibMWEdMWYoPX:2Q8V=SXnAUI^SZZf/ZZFQWifM
WIbKUi29Q8B4Q8AnNgakNgn3QHR:Rhb@SXN7RXF2PX1nOgmoPH>7RHZ=THn:RH^;
SY6?SXb7Ph5oOX20OgadJfMWIF=RI6MWHf5QHfEWI5iIDdm@DeEHGV1RJVi/JF][
KG9aK75iOXB7PH65PWj0OGYkMgAcMgf3QhJ7RH>1QX>1Q8>3Q8B5QhZ7Qh^:QhN8
QhN7QhJ3PXF8RH^;RhZ4QHZ;SHf8PX:4Ph>6RXZ8R8R7R8V8RX^8RI6FUYJFTiBH
VYfOWYjMVYNMY:>SXY^ET8nBTI6?S8V5PgiiMW5bMGIkPXF8SI2>RXZ;S8j@TY>F
WjFVYjRUXYjIUIFKXjRYZZZWYZFTXjF[[jn^[JbYZ:NVYJ:QWinQXInLV9>>R8>2
PX61P8:3PH1oOWalNgUhMgEeN7UiNGUjO7j1PhJ:RH^=QhF9R8J9Qh63R8j8P8B1
OGmgLGMjN7IhO7moNW5`LFiaKVQYJFY/Kfm[Jf]YIfa`LWEcMWUbKW1]IfM[JfUV
HemNHFASIFAPHf=PIVa^K6icN7]lNGUmP8N:QX>4RX^=TXn<SY6CSXV7QhJ2OGen
P8:3P7]jOgaeM75aLg5_KW9iOGmnN7AcMW^2QhN6QXJ4P7mnOH:4Q8B5Qh^>T9J?
PG]hOX>6Rhj=SHnAT8^3NFmWJ71jP8JBUHj=SXb=Shb7QH>6TZ2W[J^MU8n9QHB6
QH>4QhV<R8V<RX9kO7Q_KgUnOX20O7QjNgajLW1^KgAeN7UmPH:3PX=mMGj8RXZ6
PXR:RHR8QgekOg]iO7]lOXB=THn;R8R6Ph1nOgn4QH66QhF1OWilMfe[JVeaL7=a
JV=UIUiNF59EE5ABF5iOHEMPI5iRI6a`JfibK6UcNgioNgMkOgmnOGalPXR5Q8Mn
NH66Qh60PH22OW^0QXB0P821Ph9lO7n0OXF4OXf>PX:1P7YiPGUdNWabLGEcN7Ub
K6Y^O8AnOXR@TiNNV9FLXj^WXj>UZjn[ZJZZYjFTXjFXYJN^[JjZYZBLUiFIWifD
UI^HW:2JSHR7R8R4QH>2R9:MW9FHW9jIUiJ8PhZ@SHR?UI>BVYREUi:@S8b=SHf?
THj?UYbIVYnNV9NLVI6HW9NMXYnKVj>RW:2VY::OWj2IU8n<R8R6R8J8S8b=SHZ0
PXV:RHZ5NGn7QhN5Q8B9PgajOG=WKW1aM7YnP8B=SHB0O7MhMgQjKfidLVi^KFUZ
LFmWIf]VHF1SHfIaL6UXK75/JW5YJ6aZIV9UK7AjM6MTKGAgN7alL6YQH65VK6]/
MWabKg5_KF]^M7=jPgf1RhbBUY26QHV;QHF?S8F1OW^0Ph=iMWn2OWMgOX67Rhf>
SIB>Ri>DTIBDTYB<Q7f6UXN0PXJ8OXF:Qh>;RWaeN7U]LH1kJfIZI5MSM71UJVUM
H71kOh:3PXbHVHf9RHF4NG5gQ8f:R92FThR3PGenO7ilNWmoMWEeKW9bLGAcLgAl
P7Q[JgIkNG1_L79iOWMaMgigL7EbJfQ/KfIUKFiRFfIZI6U^IF9VJVYjTXM^KGQj
MWEbKg=dK6EaO7YhLgf<TXn?SHf;QHJ6QHJ2PX^HUH1cNGm_GUUNIFI]Lg=nPX9o
O8B1NW^1QGigPXR6SI2@TiJFSi:LY:BRXiVEWJJIRY6KWYZDT9FW/JRSZZ:BSY>T
ZJ^YW:>_[ZNOV9NHSHbOZJ2?UJR_YZ2LVINATH^AV8n6RINMV8^6RhR2PH5oOh:0
OXF2MF]aPhfEViRAUinOXJ:LS85jNX6BWIF=V9V5KVYiOH21M6moSHN7PgahKf]]
MVmID6QnPWe`JG9mNWEgQ8UnM71cP8=iNGEkQXnAQhB4QHR?TXnEVY^LXjJQWj2M
UXb2P8VBUYRKZJ:DT9>HTHn:QhfOZj6MWJ6MV9V>P7b4SYjKR8JCUhYdKFmbMG=]
KWf8S8V;UI62MW=dM7f<TXIeL6mfP7m]GEYKJG=eL6mlQi6=OW^4S8B0O81mNX:9
RH1jN7^5T92=T9>ARX21Q81dLX>AShB4TibER8R5PX1jMgZ6ShUiMgU_JFi/J6Q[
M7IcL6aZKW1UEUAVM825OfiQI7AnNFaYKfm`MWn6NgAdKVANEeIPKGMbM828P71Z
M7]fLWZ:Thj9S96>QWYcMg=VGem_PGm_Ife_JfMSHfM]LgIbKfMPIg=fLg5]KWN2
Qh^:RY2CRG]fOHZ<PGUkP8NAUIZKThR1Q8jASX^>S89gNXF6MVMaOGaaJ760QX5k
PXJ2PWimR8n=QhB6QgmlPXJ7QXZ<RGmdLgj5OGA]K79nQHF4P8>:ShZ4S9^IRH::
ShnAT8n;QXN7PH>=Rh:2SIB9OHB<QGAbQ9BHSGecMgn2PgmmNG=aMWinOGf2PGEW
I6Q^M7MiNWelN7Z1PX>7RY>NXjV]YIfNYJJCQHR:OgYnQH^<RXJ2QHN5O7ElQ8F:
UIjEQ8>=TI6?RhbEW9:6SY^HSX5iOHJ<RhF3R8Z;RXV8Q8:0O7EiPXZ3MGEnOh23
OgmoNW^1PGenR8j<RiVUXIjITHb;SHf9Ri2;R8fFWIZEUiJ<PGb3SHZ1MgJ4Shb6
RI>FU9>@SiZWYIVDWJFTX:2LT8B5SY6:Ph21P8B:QhF<RXInN7n@VI:0NXJ;RH^;
R8V:RX^@V9R?S8b;RHZ<Shn=S9:HWIF6PH:2OGf7U9VFT8V3QHV7P7YhN7IeNh1m
N7AbKVYVJ6e_Kg1cMGEfKfQXJfe_LW9fMgEbKWR4PgeeL7=bLG9]KG9`M7n3QH9k
MWZ0R8nGUheoOhJASWmeM7AeN7E`L7IiN7UnPXJ4PGinOgenPWmgMWanPHF8PGM]
IfIVKWUnOGEdNX5mN7b2OgYjPH^GUHn8PX>4QH:0OgajNWUhNWf2QhJ2OX::SH=g
N8>@UHanLG5jP7ijNWanOgYhOH9lO85lMW]oNWYoO7MaKVUTI6QbMgEePHnFVYJA
U9VHShZ<SHV7QHB3Q8=mLfabO7aeK6I/Mh>:PgQgO7egLVieO7edK6Y^N7]cJFQ_
Lg=_JfUXKWb7PgimNgEfOgihNGaeK75hOH1hKVmgOGeiM7AhOhF>UIBDUiB?SHj:
RHj<QXB9Rhf>SHn@RX5mPHR>R7]cMgf1P7E/K79hMgZ4S92>SH^9RY:IUhn8S9:D
VYR@Rhb9Og^0QXb:PGUoSYF?QhF5R8nDUiJGUYB=QhJ7QhN;RHF:RhJ1NgQmPh5i
Mgj2PWmkPXjDUHf2OHB=RGikP85lNg]jNh1oOgmoP8F4PHF9S9FHTXb:Si>CT8b8
SINJUi:AUIFIUi>CV9VHUXj;Si>GUiJGUiJGUI:FXJZWWYZNXIjJUHZ8SY6;Pgn0
QH=mP8Z>SI6:O7MkO7j3PWemPH61Ph>3PgaaKgIiNG]iMh:?THV5Q8>2R8fAUi^M
W9JDWJBOUHj9PX:8RH5iNX64O7A`LWEiNW1[MH>:PgMdN7anMgAgNWYkNgQfLfi^
LgA_LGMfMGM`JVm`JfY[IFEXIfE`Ngf0Q861QX^;SY6@SXf9Qi:KVYBCT8fBTh^2
P8><UH]kMgaoPWmdL7Z4PgeiN826OfiSHV9SJ6QUIVMZLGIbKG9gMgQkNWn8PWj4
S8n@S8F1R8b5OWeiMgEeMWj6R8N5PH:@V8n8R8N7SHn7PH65RXYnMGUoOWUbJV]l
RH9dKVYZLgI_KgIkOH:1Ng]lNW]jKF=ZMGMgMG=dNG]iMgaoOWYeM7f6QhN:QGen
Q8N7QhJ3P7eiOX9oOH20OhB:QgehNGanN6aVK6i]JVAULH23PhJ4Q8^<P7V0QhR=
TH^5PhF6QWeeMGM`K7=hN827P7b1Q8>5QHB7S8b?V9V?Rhb<SI:AS8R7QXZ>RH62
Q81oPWYbMGj4SY6=Si>BRhN3P8N=Qh60OWj5QgikPX=nOh9lNX66Ph5oOH::QX66
QhB9RH1nQhb:RXV8SI69O7]nOHB>T96IWj2MVIFGWYV=RX^=W:bVVI>BTHj8Ogb4
RH=kLg9hPX=kLVidP89fKWR2QXV9OGEiOWamOX:>VIJCTY6?TI25OH64PGn0QXnI
W9bUYIbMWiR?U9bMW9jJV9nSXZBOVYnSVi6@UibSZ9jEV9bFTHj9R96JUhj6QHb=
PGYmOX28SH=kOWijNGE]J6U]Jf]]KWIoOGf4RhR5Ph1oQ8N:SX^1OGmnNGioNWMe
L79lOWUdM7EhP7mfLgEeN7YdLgUiKf]/JF]gO7=^LG9eMFeWJFebMWMbL7EgMg^1
O7UjMW9eN7EeMW5]M7enOGn3QhV6R8n?RH^@SX^@Ti2<RXZ:RHJ0OX>5QXMnNGan
OGemM6]/KVUXI5mQJVi/KWIlP7a]I6YeOH1nMG5lPGmoOWQeM75^LG9bMgU^JWEn
N7EgMg^5SI2>RhR9RhR8T9:CUYJDV:BUVY6>Rh^:Q85nOX>8SHZ;SHb8PgU`MhJ<
R8J8R8N5PWj1PhB7QX:7TI28QXR1O7moO7]lNWb0OG^0P7IcLg9aLg=aM7A_KWAf
Mh23OWj2Ph>;T9:DUiNHVI>>T96ATiJBS8V:RXIlLW5dLVaaNW]jNgMbLWIlP7mk
N7QeM7UoOGj1PX>8SHb<R81lPHJ1P8B2P822QHV<RXN3OGn9RX:1PX23Rh^1OH>7
Rh^5PXB7RXjCTi:CTH^5OGV2SHb8S8b9R8R4OGakN7IfMg]nNgQeL6YYJV]]LWAf
NGanQHf>RXf@RhR<TiVKW9ZFTi>EU8b5Ph9nP8V6OW^0QHV;QGekNg^3SHZ5Ph=n
NgMhP8N4PX>4PhN;PG^2RhnATHj>TY>EUiF>RhZ3OH63QX^;QXB2Oh2;T8Z4QhZ<
TIFFU9BHVibITXn=SY6BS8J5RHZ8QhF5RXZ5QXN1NWUlN6m/K6a_L7AjOG]kOWan
RY>CTI2>RhjATiRKTXf=SHf>S8=lNWYlNgYmR8f7QXb@T9NMViRFU9NIUi:BUIRO
Y9Z>RHR6Q85mMViWJ79kOGf2QGifLFe]KW5bLgAcLW1[JVmdMG=eMGEhN7QiOH25
R8AmOXB5QXjASXR2P8B6Ph63P7]nOg]fMGEeNWagMWMgNGakNgn3PWn0OWUfMGZ4
R860Q89lMgA`KVaZJ6MWIfUXHfA/Lg=bL6e[KW=jOh60Ogn0Q8nETHj<QX5nPXR;
R85mO7anQ8N2OGj2RI2DT8^7Ph>5Pgn0P7amR8j8OgUkOgejO85oNWUhMGEmPh:0
OGUfM79fNWamOh1nP8B3PH1mMW1/IVEXJVMXKW5`Kg9iOH64QhV7RY6CU9VOWYVE
TXf;SY>CSXEnO7aiO8>6OgMgO824QhV9PgejN7=aMWYmPhJ2NgE/IFI[L7=bK6U/
LWZ1PgmlMG5cO7aiP8Z9Q8J<S8^:R8N4Q8V?T8nAU9FIW9NASXf8Ph1nQHb?S8jC
THZ9Si6>S8N7QXB4PWYdMGQgM7AfLVm^KgAmQ8B2P7j0QXZ<Si:?Si>JXJ>JTI:C
RhJ8RhV;Si2BUIB?SHj>TYJHVijKUYZQYJ:OVYRHThnEVY>8QXJ3PHB4Ph>3QHJ3
PhZATY6CTHf<RXB1PXB4QhV8QXZ=Si:DUIFCShb:QhV?T8V5R8V9SY2<QhF3PH>4
PGaiMgb2Ph23RH^7Q863PgeiOX1hLGEiNWj6R8R:S8b9PgelO7eoPX5lNWQeN7al
Mg=]IV=UJ6igNWIdN7eoOX25R8N3Q8N5QXV6OgUgN7YjMW1`LgQoQ8B3Qh^9PX21
OgUhP8fAS8N4Ogf3RXR4PX:2P7n0QHb>RhR4P7elNgn5RXf>SHf?T8n>Shb5PhB3
Ogj0Q8B1NgQfLg=gNgalNWUiNGMhO7n0PhF4PXJ9R8J5PWehN7YmNgIeNGYkP8>1
OX24QXJ2NgMgNH29SXZ2O7QfNWioOW]iMWQkPHB0NWQhMgEeNGj1Q8B6RXf<RhMm
MG9dN7YkNgUhNG]kMgEfLf]XK6i/JVe`LG1]KFaZKGIlO7b0PgigLFa^LWIgMWA`
JfY[KWEkNgYiMW9aM7UiMgR0RY2?SHf>Shn<RH=mO7n1P868S8Z4Og]hNh65QXF4
QHF4QhZ9Q863PX60OgijM71`L6aXJ6U[JfY]MGf0Q8Z:QH60P865RXjBTXn:QhR=
Shj;S8b7QH^CVI^HUI6<S9>JW9F@TiJIViVGU8n:R8N9RXR4Q8B4PX20P860Ogej
MWAhOh1oP8:5QH1kNGUlP8J:SXn?S8^=SXn?SXb9QHR?Ti>@T9>DTY6EUiRGUIJG
VYbLVYB=RX^;Qh9lNWaoPhJ6QhN5QHR<RhR8RhnBUijRXY^DU9FCShb<SXf6P7am
OGj3QhJ1NgQfMWUoQHV<RhZ;SHnAShj?SXV4PXF5QhJ3OgalP8B5Q8J;SH^8QHB4
Q85lOH22QX^>S8AkMWUoP8>3PH1lNWb4RXR4PX>3P865R8N6QhV6PWmlNWYjNgn3
PWaeKfm`KfmaL6eZJFa`M7UlNWQjPHZ>RhN6RHf?SXb9RXb=SHf>R8B4PWmiM75`
LWEfN7QcMX24QhR6QH^BS81hMgYkNWf4PWj0P7ilO7ioOgYbLGIhN7UjNgn2OWai
MgQlO7YfLgR2Q81lNGaoOWehLFm^KG9gN7QhOH:3PGilMWIiNG]mO7akNWakMgIe
Lg5/Jfe^LgQlQ8J8R8J5QH:3S8n<R8F4PX>5Q8F6Q81hM7UiNgikMWEhO81mMG=i
NWj5Q8:7R89kNgmoP8N;RHF0Oh:1PH:1P7YbLg9hQXR;TIB@QGajO7n1QXf8PH:3
Qhf<TI>9QHJ4RHnCU9:DT8j=Rhb9Ph>8Qh20S9VDRXF1PhV=Q7amNG=`NG]eL6ec
LVi`KfmeO861OX24Q8=nQI1nN8f=RHn>RXf>SX^6QHF3P821NWUnQ8f?S8UoNh67
OX6EVXMeOX^:QXAfLgQnOgUnNgZ5QXF7Qhb6NWQjP85nOhF3OGmkLWZ6N7N3OGYj
M7YlOHR=SXf:Q8>6RY6ETHV9V9N<SHZ5RY:GU9B=QHN>V9>:SXn@U9B@P7^2SYbC
PH=nNh>1LWf>SI6<R8j?SInHT9bFRHf<Phj<QH=mNgUnOgIiPh67UIN=RXV5QY2G
T8^4QHb:RX1nQ8N;UHI`NW]lR8QoO7R4RGiiN7^9PgI_L7=gQ8=hO7I`NXB0NW1h
S85nNWb<R8:9MfagNhREQ7f1PXV8QHJ3QXR4QH1`NXn@R868PhBIRGYiOXfAS9>B
OWb6Sh5gNG^;T8B<R7YnPGA/N8N8PG]eKGjASHN4PGinMXJ;RhZ0SY2CVXYdOh=j
LW>1Shf?UhIfS8VDWhb3MGMkQ8n<SYB?Qgn5RWajRHE]JGj5MWj:RGn5SHMjM867
Q92=O7YkO9JCPHBEQG:9U7][OGf6Rhn9OhR>P6i^IfYiO8R8LW5jMfe_NGAPHgY_
F7RFSgMPGF=_L7EhGDaDLgMcP6mHG6AUJWEfP8QnKfAWL8>1M75KGFImR6YKLhAg
KF=OMgMPN7aeKh:@LFQ[OW56Hh=_Fg26QW>0SGYfOGE/PXN3SHjIS8JS[HihRX5m
YJNBPXBP/:N_/ZNFS;2iYiZEVjJYVZ6LWHn0/JV6V[J@LIBFSIZASFalWIB0TG^0
[IFCShJ7SWfA`ZElNX29V9^MS6R6/YAhJFV9THfU^J9oOIZTRFZ4U8JBT6URMGQk
N822JF1bMVEmPFQ]Mi:5MH2;MfmoN6B0PU0iCEmSNeQCKG^2KU]lJEUaI8B9D4UR
NWZ5Q7ImVYUnSiR=QHbWYYZ:MW:=TH:GRg=gLFAQHG9/CeUbM7bCTgf3Q7M_Kg9k
P9VFNh>3M7bLUXUeOhbAUj>LTJC2^ifj]Y^LTYne[IB=SZJRSjVNPij]RiV_TXR;
UZjLQXf4NX=kMiFVX:>MY[bOTi24VZVMUYF2U:R:IWN=I6>2SF5CJW9/P:fFOXUj
PX^5T9JZXXYlOXQ_HWbDTge/I79bIGFXYHZ9QhehOY=gJ8bKP7AVMXaUE75iKEm:
G8QaI7eQEGE`KFYCKFQPNgekNG9nVX=SIhN1Ih:>MFQPJ7Q_If5FK5m?FUM>CU9E
JWeaLGE^KGElNHF0NGYYLhUjO9>HWXn8SWAVQI^=UiZ7TZbb]jnNUYJHX:NAZLBc
[i]lSI5iSiVHQ7jAN622Z95YHgiiNgahV::<VJb@QX>5OhjSSgR3RgQ^PXIhO75f
NFaTKVQMQj2AQHb9Q8]mKGe]JWU[KeQmTV=_QhaTE7Y`GUa^[Y1XYkAhNh=^MV]o
TX]nLHVJUfA9JHV?NFU]M85cEFZ4O4aHRfY1CWZ4PYJDViV6MVbA]JjNRGf0TX^<
SVEKNGECLh1VFVadK8J?QG9nQGEmSXAQKG]kRh1aN7Z8QGFJX7MfVYf;N8[0ckNS
[[bdW:Bb[[6PXZfUWhR9[:VIN7>EXX9KMh69QUiMPHYoHDe8CgN9Q71mW::JW::G
PV5_V/2aO7:BW868QgE]GUYbN6]eQGEnYIf2MfejSI^_VifXSgJ;XIjHJVAmX9Ue
MGZY`J:KZI:1Ri^XV8J?OI2hXX]jLV9/J5]_JfmlLFA_OGIcGU9[LWQkJeifW928
M7FDO7Z<QGmiRIR4OgihMg^4PH5hJ6=]LWAfMWj4Mf9mS92JRXf@VY^?RXJ>XkRY
QWjBX:BNSHb8UZ2JVI^RXYbNYIVJS8J^]InOTWb9R6A^NfEMJH>5O96:GgN;Kf]h
Mg^?SHVR/iF3TYJNWXa^KhjCUI]oL8RKVI=hIGUQGfe]OfU_S9nBOIN=EDYcTH]S
JH5jOXUoISm2IG9^G5UKJg1lQWAPHVUMHG21OGZ2PgYgR7=;C5e/Ti5NFhFEPhJB
Mea]O79bM761T92@UYV2KGb=QHR>UY^P[i=mOGf1OFEMOh=]Eee]KVmZJVi`SYe`
FVf1OWj0LG5kPhF7P65MPHYeJFZ3PXBCQIRZUXV@Wj6S/ZBIX:^iYi26RIFIWib7
N79dSY^4J721PG]_Lf9;H6aeO7F6T9NOUH5[IWZ7RYFLW9ZKS8BCPWUgF5UZMX=h
LH2@TI>>MfMcSYJIVXMiTk6URg]cKf]ZJgMlLWf@UY2=VXQcPiRRUXF8VJZ_X9B4
NgYaLhB9MWF4R85cHfeVGVY^M6i[M7M`PiBBPG:6W8U/KhjSS8R9VIafKg]cLGAR
Fe=4Ih9bH6A`J5mULG5eOGn>UGekQH5lOGf2PGb8T9JARhEmSiRFZJJ;W[ZRNh:K
WijOVj>KSijDSiZ;PHj9NhBGU8B=TG1ZKfekL767SInJRiBETXnOZIbAVj6I[Kfd
UXZOXhelLVIYMgecJWb>RHR>RH:5Ogj5RHbBUIVKTY26KFMeOWIUIgikL7N?S8>0
Nh>6P7ZBXIFHXYbOYHYkSi>;Pg]mOXj^[9B5Qh1lRHQhNXN8SYJEUhUmR9>CR82:
TYBPYjNMMUeRK71]IVAODTmDGeeIHFYUJW1XHeAEMHQdLWanSXamPXYmLgAeMW1f
QYF>QginPW9`RiJ4R9^HVI:EVYJAPgZ7VhaiPhB2RH9bIgAoKeiTI5M>GVU`KVMd
S968RH9/KHRJUXj7QXf:RY:BPF=@Ih5iL7f9Sh5iUj2AS8:8XJRGTYNJWYnf/hj9
RWUeOH>4Rh^;UYF5MhBRYXamSXf=W:2NWYJ7P7V5SHUmNXZ=Oh>>OG=lMfQRIVMY
JF1LK75ULX^ANVeYM7YiQXN9S7MjRga/KU]6BEINGUaGFUeVHeQOFe=KKWQiP7ac
KGb=OF1/PGQYN8mnJ6n=UGioRY2MV8>2S8fAVj2;R9jJRH67PWM/L8F9NF]aQhUg
KfiRFeeILH9fOW=WNHF5NgQmPgn5UY^U[9R?YKJ/V89cNX9oO7AgMGN5RgIbNVi]
N8N>Rgn0U:>PSi>EOX2=QGUbMH5nLWQiNG]oR8QiNHZBT8j?UJ>MTY66Q8j?RGY^
Nh>4V9N=TXanMhB:QXFAUY:GV9FV/9j>PH6@WJ^ZVY>EX:>KSg]gLg>0N6eWGVAc
LVa`Ng]]HVQZHfmlOX1oRXV9QXRCSH9nPXNCUiFPY9N1NhJ7RXR8QHNV]ZbZX8nD
VIB?UiBBX::UShbPVH^7Pg1OIGAlLFQjRhV>ViF8PXB?VIVHWZfcXYba[Xb6S8jL
Th24TI28QHnAS9>FTGn8YIn=RY6LXIfMZ:fPTHZ3P7j4PGj;ThZ4PXB9OWV8ShN8
T9F>Qhf:QX=eNh1oQh=oNgZ6PGZ1L69aNWITEe9>FVEaNWYeNGUdM7I`LGinOXR@
RhEfI61FDDi9CUACAS`oCEiOD3m8G5YIGV1^LfMRGfYgKF=XJF=KIG]kMgmlP8b5
O7YiOGimPXR@WiZ;QHAkM8>8QXf;Q8ZEUi65MfU/M7=bLW9^MgUjQXMjNX1oNgV6
V9RIXjbRVZ^c[Yn@SXQoRINKSgf1RXj2L7YjJgV=U9>CSX5kRYJ6QHenOHN;PgUk
NViVLGYgNWUmRi29QhV5RIVMS8RETXV0O89gKWF4U9R?PGZ1QXR=RG]`KgEoSiZ@
PginOWn=SHRGSh:>WIb;P8N1KgEcHV]/GEIGEeEPK69JFDe0@UMXI5eVI5i/OWa[
IfehMG1kOhbNUHR<THV6SY:>QhfBTj>d[IfCRhf=Ph::Ti>HWJ:TVYJ@Og1cP7m]
HVeeN8VDP7McKWQmPHB6TZN_[jfISIJSWH^;T9BPYYnHSh:9UI^OShN:RiNJV9^C
TijUXinMVifSViB>QXfDS8N<SIJGUIN?TZ>VViNDVJ:KSHB;THj?TXUmR9NIVX]c
K7R;SXb8LU]JKg]dM71OHgn@RgAXM8J9Og^4T925Q8AlNG5ZJ6UZGeAIK7IdJf1J
FEQNKWM_IVMZMHB7OG9WIFebNGQ_MHB<TY^GR8>>W9^GThnP]kNb[HiiRYF<RhQo
QIF[^J:1NG=`Nh5mMW5^LWf1QW][JW5hNgQhNH:JZ:V[YI^KVIjXXiF>SiBGVYf@
OWIoS8E/Fei`RiZKSh1oQhEiL6U_OHF?UX]`HfebM7E_I5UTOXN2OgEeQH>3QX>4
NgR4PGYiJfQjRX]hIEiRMXV4OgMUHW21QGaaIfAaPi26MGMlNXB@QWEdQYRMUH5]
KGMbIeM>EF1^P7YQDDM?HfUXJ5a<EgEmLfmYG5iXL7MeMG=bMWj1OW5`OHR@QgYj
R9fYZjbTUYBFVIR:O7R7X;BiZXmmP8fAP6ULGfafNGafJfmhM6UVKGEbPJB^WHf5
Q8RAVYJ>R8ZKZj6>QhRAUHZ7SHZ5QHV?TiNFRXJGX9J6LgZDWjJSSWijOX=nMFmV
HgV=Si2>S8jAUYR:Ogj3T9jOWIB>TiRESXElPY:IU8f2N7MhOX1lLVQ[MhR>Qgim
P8>>Ui>7O7N2Uj2DOW>4T8=_GUm]M7QiJVIXHfi^KgY`Gee[OX5fLViVLgeiLFaa
MH>FThZ?Ti2?SiBHVZB[/;F/Y:2NXjZc/9J5W;K3`JnOTi2DSHN;RH5lNgn1NWAb
NhN7NVU]MgjCVIJHTHfIW9V@RI:BTIRBRXb:SXn0N7=WI6ajRXf>THj5NgYlMg1a
OY2FTHAjMgQjMf]VK6Y]O85jNWn1PHNBU8b;SXj=Ph27SI6DSX1fMGn7P7aoOW^2
Qh=gLGMcK75iO8B9Ogf8U962NgAdPi2@TIR>NfUMGV5VK6mcN7=TFUIOMWibIF1T
J6meL6]_Lg=dM7R0P7E`MgE[K7V3RXMmNgQoQhV<RXVAUHb7Q8:2OX6:SibTXIbA
Qh=lNWE]KWAcLWEfKf5SJV5GFVYkPXB8QGmkQ8b7PhR<RX=nPgmlQHR5QXJ5P7]m
PHJ8QH23TIVER8:8RH>2T9^OWY65N6e_LV]WK7MnNGIjNgn8S8MjN863PXZ@V9ZD
SH>0QhjJY9bFTXV3OGb2OgeiKg9jNG5aNh::ShV1PXb;Ng=mS9FJW9N7P8=nLgEf
LFa/L71]KGIoOVmUJFi/Kg]jKVmjNVmbNWIaMW]kOH26RhZ1OXRDW:6WYZ6QWIRK
WjFRVj6XY9jOZ:j/YiV7R9VJPW=jNGAaK6e^JFMZKWEcM7A^Nhf;Q8:6SI:FThfE
X9jFShf<RY:FR7U`MhB1O8RASH^9QG]bMh64P7n9T8^9SXamMGf2OGM]KGQnOW]f
N8FEUhEkPX9nPhZ?SXj<Qhf?QX>7S9:AR8R=SXb8QgieOXF2R96?QhNDW9NCT92B
T92IYJjZW8aiMGakNgmjKVUZJ69VLgUjNGMeJf=[LfiVIg=mQXf=R89iM7QlOH26
RY2CU92:SIBFTX^5Ri6?Shf9QXB2PHVBT8nKX9:3PH61PgidN8:1MfQKFFEeN7Af
N7]nOginOh63S9RESHb9Ph:7RXJ4S9>=OWMlOgaoRX^7SI>@RXR:Shb4Qi2GVY^F
S85kMW1]KF]_MG=dOhAkL7F2PWUgNH6<ShZ2NWIlR9:GWIjEU9F@S8F2RI6CS7ie
M7YnO7]oPHB:RhEkN7MaLWMnQHJ0NGEiNg5ZIeaHG5mRHUmPI6EWKVeRFUeQHFAT
IfebMWI/HEiUL6iYJ6=WM86=TH^7PhB6P828RXbEWIbKWIN>TIRLXJ:W[JnZWHj6
P7n2P7eiKfEPIW1bKf]XJVebMg5ZKgR1SY2;QhJ9S8Z;QgUhOW]gMWEeNXNFUHQj
LgZ8TINHShN;S8N8RHV>SXf:P7I_K7AnP7mlOhF:SiFDTXV3QhZCVXn3Qi:IVI28
QH^CU96;Q8VCU8n>R7McP8R7QhR4Ngf?UY2:Q8JDWZ2JR7j6TINER7ifKFY[JFQX
JVmdNh1gJF=UIVMXHeiZPHb?Sh=fJfYdOX1jMGb;U9NBQH>>UYNCSh^8RiRUYinC
SI6CTYBBS9:RYIfGSX61RiFCQ7A/IFUiQHR2OGekMgUhL6emU9fKTH=nOXNDTh^7
R8jATYR@PhB8SYVISXB4SYJIU8b7S9ZTYYjCSiZOVYJ9N7IoQHF5Q7adMgj6R85j
N7j7RH5eJ6MfQ8fBSXZ:RH^8OgYlQXnDUHYfKWR1PX1mN7Z5SiJDQWagN861NG9]
N8fCTXQcIF9PHfAQFeMPJ6Y`L6UUHEaLGEeGEV=bNgYaHf1YLFeWHeaLJWf9SHZ5
PX:3PgiiNH6<VJBSVYFGVYZDSXfHZ[Nh/J>CS8jBT8YkKW5mPH1mMFmeOGabJVMY
KGAmPX>3QHN6QH^;P7QlPX5oOWamQHfEV8UfKW>2SiJETY>HVHj2Ngf<WZFPUH9g
NH>8PGUgN82:S8b;Q7n3Ri6=Q8J<S8^9R8B2Qh^:QhR=T92@T8j;Pgn0P7j1Pgai
OhB4QHAlO8F;RhZ3LVeoTYfQVXanMG5^JVQVK7j9QGM[JG1eLFAGFFIdOh9oO7Ma
L7=aJ6=XL7MkOGajNgeoPH:7Q7YlR8j?UY^ITHb<QWimPX^AUJ2UVYBGVYN=OfiU
LGmnOH62R8j8NfeUK7V6T8n9PhNCVIB<Rhj;QXR?ShZ:T92=Rh=jNX27RHAoPHF=
UINETHZ2Oh:6R8Z8OG5_N822OGAiRHj8Ph:6Ri6GSgYaNH>3OWn5QXbAS85jOXF8
SiF@PWUmQH1gMWUkPXfASHJ2P7j0P7QZIW1gN82=ThZ1O75VIf]XIfM]L6UUJ6YZ
JVQREU5PKW9dLW1^LG]oMFYQEUISM8>5PHJBThb8QH5oR9BIUI>GWjBOUXj:SiRH
VZB[[J^WXijITXZ8RHZ<Shb9SIBGUI>7MgR2OGAgOh:2S9ZMV8n9R8N4PX:0PHZH
VYJ@QH68SH^6PhZDW:>LRh>3R8b=TiR;PHR@Rh>2Og]kOX:6PgehMgUlPH=mOHF3
OWekP8F5QhZ;Qh65Si6?SXj9PH:6QGmgLGV1OgelOGemPXR:Q7Q`MWb0QXf?SH]o
J5eMG6=/LgUfKFY/Kg5/If1KHV]_LgIaJVM^MVmOE5=II6]/JFMYLGQkOgahOH60
PHB7RH^DW9VAQX69T8n<SiFPZ[:`YIbBQhJ4NgAeN7j5QGmkN6mVIg5lOGQgOXF:
Shj7PXB7R8J4QXV:SY:BSXN8TIB=Q8B;SHbGYJ>HTIJPWYNHUHV5SYJBRXR;S8V7
RHjAShjCUiVJV9:AU9FBRXN<T8n;RXb7PXfMX9F6OgiiM7IeKfYaOhR9Q7U^JW1l
O7E^KWAkO7UkQ8^<SHZ0OG]jOh1hLW5cM79bLFe/K71dM7IhMGEmQHZ6NVmUI6ic
MGb4R8AoPHJ4NgAhPXR7Q8J9SIJFSh^8R8f>SXf:SYJKWi^?R89oPX5mOX:1PHJ=
S8=nNgUdMGQcKFihOW]nRh^0O7eiMWV3Qh5mPhV8PXB8Q7ejNgioQHj=RXN3SIVF
QGYkPHB=Ui:7PhJ;SHIkMG5/J6Y/JfeeOWefM7=cMgYlOWn4S8b:S8j?S8V7QH60
QHV9RXf:QXV:R8J6RHV<ShQmO8B:RhbAT8EkN7IaKG=mNg=bMg]lNWAUG69^N7Yh
M6m_L6eYIfAPGUaPIFMXJfi]JVY/L7AeMWYkNgf0QXV6QhbBUY::RHZ=UJ6^/kBl
^ZbOW9nLTi2CT8j<RhV0MWIlNWEhNgQhPhZ3Nh:@THb9QhF6RHV4PhB7T9VESHAi
Mgj8SHZ5R96IUi2CVIJ=Q8>2PHN=SH^9QH=oN7^5T9BBT92>SI2EU9:DUHn8Q8:2
P8><UYfIT8R3QX^7OWQiPHR:S8Z:RhAgLWAgMWV1PWYeN7f2PhB2PHJ<T8f4PH:1
OginO7AVGf5WJfi/I5mSJg=jO7agKVUXJFUYKG1bNG]fKV]dPXJ2OGMjPXV<RHF3
PhJ;RHF7S92AU9JCTY>AShb6P7j0PhB3QXZ<R7iiO85oOWn0O7MfMGEkQ8^=Q7Me
Nh22PX:1P866RXEnNWUkOX>7PWQeO8ZDU8n:QH60QHV;RXfGXZ2FSXf@THf7PGal
Oh>7RHV:R8>2PH62PX:4RY:HUHf>Ti6<Rh^:Q8:>V9F:PhB9RHZ<R8N8QXN5OGZ1
RXf:QGebK71hNWEbLG=fMGAiM6IQJ6m]Jg1cLWIjM6m]JVITJ6a]IfE_Lg1bMgYh
LWAnPX1oPXJ5QXZ6P866TYJ=PGZ1T9ZOWibMWZ2UYZ:MVIBBTIB?Pgn0OGYiO7ml
Ng]iLg1_LGIlOGanOhB9Pg]nPhB2QXb;PGYhNWeoQ8R4OX29U9N@R8^@Shf:PWn4
T9^PUhR2QHR:SY6?SHj>S8Z<TIBEV9ZCR820QX^@UYZFT8j?T96=R8AnNgn1QHR3
OGQgNgejMgIjOWejNGYfL79kOGYkPHN9Q8>6Qh9cJ6ESGf5XK6QVJVmdMW1]KFma
KVMNGfU`LW=cLG1bMWQgO81oPhN:RXAoOWf0PGn0QH^:R8^=S8b;RHZ<RXZ9R8J5
RHb8R8J5R8Z6P7eoQXZ8PgmkN7f2QHR9R8b=Si:ASHfBU96;Q7n0Ph:3QHB1NgMe
MWb3RHnBT8Z4PXF9S9:DUijQW9FBSXN5QH1nP8=nN7f6QhB4QhAjNHB:RHZ:QhJ3
P821PX:7SI2CU9FEU9>ARhZ>Shn<Q8:8SY2;R8V8QhIkM7MmP8:3QHF3O7MgN7Mf
MG=aKW1bMWI`LG9`LG1[IfQ/Kg9eM6m/KG1dMGAbLgZ4Qh1gLG9dMWakN7]oOh:7
SHn8QXV:Rh^@VjJWXj2KUi><QXAoNgYmPhB0P7ehN7IfNW]gMh1nNX1kM7EcOH=o
Oh21RHn:QX>0Ogj2RXN4QHF>UI26OX:8Q7UlQ8V8R8V4QhV8QHNAU8n:QXF6Q8:9
TXn:QGmiNhB1OhF<SX^6Qh^8QHJ4Ph5lNgn1PgiiN7IkNW5cO7imOh22P7=cOh:8
R8:;UinRV8^9QWagLfm[JVe]KW=iN6iaNGAYHVQ]IF5UIVAWIUeKGfQ/KgMoRHj7
PHB1NgZ0Ri:=QhR@UI6>RHJ=T8V1Pi>JUIBEUiRARX^BU92?RhN:SX^4QhZ6NgUi
MgYeMh:9SXb;U9VERhR<RXN6QH63RhEhMh:4NWZ0PXV<PWj2QH9oPXF4Qhb=TibJ
Thb?U9>9OHF@S8J;TI>JVXf:TYBATY6>UY^?R8bDSH>4RY6>R8ZBVinHT8nDUHn=
TY:7Qh^=RhEoLW=kOWafMW^7RG]eP85bJFmcKFebL6mfOWEWJWMnL6AZLFeSJG1_
MWIVH6I]Kg9bN867Og=jOGUjNh:3Ph=nQY>BRHN?ShMjOX^7RYJOY:VZWXb7S8f2
MWUkNgeiOH9nMg5`Kg1bL6MXOXAlOXJ=P7AjRYFCS8J3RiJBQhV?Shf5PXJ9T8V0
PhZ4NGYoNW=bLWb8RX61QhR8PXB7PWmkNh><TXZ5SYNCQhN9RHV7RHfCU8j:SYJF
ShEeMH20MFeeOWimOXB:OgA`MX>3NW1dPXJ2P8:7S8^:SibOThB2PhB0MgEkP7ag
N7j1NgMiO7YdKFIXLG1TEUMUHUiSJg=gMWEnQH1cLWUoRHj7OX29ShZ7S8Z3PXF=
Sh^:QY2KVhf1PhJ7P7f0QH=mNG^4QGQdMWEdKfUYMGQlPh^ARGagP8b;PWUeNhB8
PWamOWMeNGQgM79cOhZ;Pg]nOXF5MG9jQhf<TYJIUHn?TI2;QGemQX^>SiJJTXnC
V9NDS8:3SI:ASXbATXQnP8R;S8b?UIBAU9VOW8n6PX6?V8j9RHR6R8f?RH1jOhZ>
RGedKW5oP7EcNWefKFeeMgAdNH>7PgmkNGQcJfU_KFAOIW9kN6]PJ7EfKfUZLGEf
MGIlO7j2RHf4O7b6SXV6S92GYZZQW9jIShR7Q7mnOh>;S8EoMg1eOGIZJVi]KG9h
OgmjMG=jPhN1NGb6S8^DXIjDSHnDUY:3OHnPXYV;QX^;OW=iOgikPiFHSh>1S8^4
PWmiOHZ;QY6OWYFEV96<SH^9T9>EVIFHY:VNUYfRUhV4PX66RHV?UYNES81mP7]f
NGYaJgB5TiZ@NWB6Ui^ESXbASXB2QXEmMgemM6m/LWioNgeiJfY[H5IIFE1;CeAE
GVMUIW1gO7M_KgIhN7j<Ti28RHV;TX]oOhN@UiN?RHV<UInSUXZ=TYRMTGn0TIfE
QWf0Rh^1MgMhLWJ6Ti::QHbGU8j=RXV;SX^7SiN?RHb8O7n1O7aoPH:0NgUmNg5_
MGI_Kg5fQ8j<QhV<TI69OWAaLGJ3T8f3PhbKW8YeKGV2OWYoRI:CQgj5SH^;RXMo
MgV7TY69P7QgO7eeKgAeJFYdL6Y[KVaXJW9dM7=bMgMaMGmoM6eYJ6mbKVY]Mgj0
OWYdK6EQIF=GDUY^O7a^I6YhOW9VJ6a/JfM^Oh>5Rhn;P7n4QHB2PHB8SI>GTINW
Zj^a/JBCTifJVZ2QW926QX^9P7UdJfU]KG5jOWQbMgn0PhN4PH64TjBOSXF@XJ6H
Rh:8UIF>UJ2SX962PHB4PHF9QWj0Rhn=Shn<PgUbL7B2S8f:QXF0P8R4O7anPhN<
U9bNVYbSZ:JKSXF4QHF2Ph^BTHf>QX60NWYiLVASMhN;QWadNhJ1NGf9TXn:S9:F
ThfAS7]bNhB2PhB3QXV9QWimNfePGF5UHf5XJ5mQKGIbJfa[IfYbMgekLg=hO8:2
OgQiOX>:Si:AQhF=UYB?TIJGThb5PHbFT8R8SY2>RGeaKW5jRH]oN7^0PXJ5Ogb0
OG=iQXEoOX20OGYjOgmjNX:;S8R5Q8J<S8F4Ph1mPHR3OH6<U9JIW9jBO6eaQHYn
KW24UIRAPG^4QGinQXf;QH>5QXR=Uj6KQWb6UJ2VXiVJVHb:U9ZGShR4PHB<S8N2
NgYoP7I_K6abNgn2PWigLW5bMWEgOH23R96FT8AoQ8^7LV1WMGenNG9ZJVm`KFaZ
J6ITIVQZLH2;Q7UgO7UfM71aN7YeNhV>Rhf@T8n?SHj?T8nCViN?RhR:SHj=RXMn
LW9gNgYbJVY[K79kOW=VJ7F3S8IlPX^@U965P8F7R8fHWIVJW9:4OhRCTXUoP8J:
Rh^9SY63NGn7PgYnQXV7Q8:3RHV7RHZ8S96<RHbAU9FJW9JCThj8QXR?SHR@WI^<
PH>8RXAbIg1nQ85eKFmlQX5mOWj2RY>BTIROXYf;NGAnRh^2Oh60NgZ3QgmeLVQL
G5YGFEQDE5QIFEMFEUMOJ6mhN71ZJg1dNh1oNg=cOHb=PWf1RHj;P7f8U9NBS85m
QXb8PXB7S9><OW9`NX:3OGIeO81mP7mkMW=lQHZ7RHn@S8V3O864PhF9SHV5R8Z:
R8F2PGecL7MoP867RHJ7TJBaZY^EV9^IShJ3RYJJVI66OWj2PH1oPXV?S7eiQIVP
TXEjNXF7RY:EShV6R8j=QhF6Q8B1OWn1Ph>2Qhj?S8^9QhR>UINBQgejMViaNgeh
MGV3Qh5jN7n1MfaYKGIoOgejLG9fM75[J6eeNWI[IgB3S8^2NWf1OWYjNWIbM7Um
P8F8S8n>RhV9SY>EUinTXIbETI2FVIFAS8F4Q861QHImL6ijQXImLWAnQXF0NWQo
QhZ8PGf1R8^6Oh>@W9j@OGb8U9NBQh23RHb>RhJ3P821P8>1O7QcKg=kOWegLG1b
MgUhO7mnQ8V<SXf:S8Z4PHNASH>5T9NIUHb;Shb6OWYmQi6BQg]cKW5gMW1bN7n1
NG=lS9RESHJ0OgilOhR6NgUkNgamP8>2OgQbKfaZJ65PJ6mYGEaPHVIaNWUeLgAc
Kg1hP7Q^LgZ0R8Z8RY2BSXV;SY6FVIRCSHfCUHb5QhjEUi24PXbCSHF2PG]eMGj4
OGAcLg1dO8:4QH=kMGAaKW5gOhR<RXN6QhN;TXf8RHInMgQnRHZ1Ngb3RXf7Q8V>
Sh^9QH6:VJ6LT8F1PWefM7b7T8n3NGb9S8N4PGmoPXR?Ti6>RhN7RY2AT8j:Rhf@
SXV3OX25RXb=RX:2SYJBTIJDRgafOh^:OGN0SIFCShZ7Q8:0NgQkQI2CRh1iNGai
Lfa]MGamMFeaO7mlP8J4P7ekOGinNgIdMGUkO867Q7alOWinP8F=UibLWY^BSiBH
UiJIUhf4Q8fCQgA[LWioO7QaKFi`M7MbKG1jOgYdLgV0QH9kOH>7QGeiNh61P8B6
PG]nQhnESGacLgUnPhB6S8^4PH>8RHB1OGYeLgMjMgZ4S8b=ThejKgJ6TY22OHB@
Ti:ARXF3QHR5O7InT9ZAP7A`M7I_KGF1QX>0OH:9RHb=R81nQXb?TI2<R8N5PX62
QhZ7P7j2PWU`Kfm[JFaZIEiMIVY^MGeiJfE^O8F0L6MZLWYoP7inPhN5OgQdO8fC
RX62RYBFSHV>Ti6<QXJ=U9>ATi23NGQhN7UjNgUfMWb1QHbBTHAmOgilOh61Q8ZB
U92;Rh^<SYBHSGYbMh><RGiiOhJ8R8N3OX6;Shf7Q8ZDUY6;QhF1O7AaNhN<S8Z;
RXN3PXF3OX28Shn@Shb:S8V4QHV>Ti::R8^>S8R2O7UlPH1mO7f4Ri6HVi63O869
RhQnNWf1QHnFT8J4Q7efMGEjOWikMgIeLV]NFVAYI5mNGf1TJg9cKfe`MWEdMGAb
MGYgM7V3RH^6OWb0Q8J;SHVBXJ>NVi^JUYBGWInDQhN<T8b0LVmaLWQoO79_LgMg
M79aMWejLg=kPH1kMWR3RXR4OGUlPhV9RHN4Qhb>T96=RXR2NWAiPhbAS8J6RHV8
RX^:S96>QhB5QhV>UZ6TUhJ3R8f>RhR4PH>:TY28PhF5Q8=oOhVBTHZ7QX5hKfMZ
LWMhNgmoPhV=S8R7QhZ=Si>GUY6@ShR2QHb?ShV3PH>4QhV3OWn1NFe]KfYUIVmk
OGI`KgEiNGUfLW1dNh:4P7f0Ph>0Ngb5RhJ5SI>BSX^:SY:CTi>@Rh^DW:BVXYjJ
UHn;SHR2PWifMGb5R8J2OG]hMgUgMGZ0P7f0QXF0P8F?UI>9OgaoPXF6PWeiO8J>
Rh5kNW]mOgn4T9>=R8R7PgadLW=cLW=eL6]_MgQhNGQcKg1fOX>2PX5oNGZ0QXb>
SXj?TI6<QX:4QH1lPHN6P7j6TYJ>PW]fM7EgMg=`MGf5R8J1Oh22PWYeNh9nNX29
SHV2NgMfM79`KFMUJFicMWIdLFm_MGUhN7UhLg9fNgn0Og]fLgIjOH65SY6?SiJJ
V9FGWjRYXifLWI^IUY69OgUjOGmkN7QkOGYbKG1cLg=eNGUhMgQjOh>7Rh^7PGmn
Oh:3QHR<SXnAT92>RX9jN7Z0RHj=RHV<S8Z8QhV8Q8F8QWigNXB:RHB0PXB5R8Z5
PhF5R8f<QhB6R8EnNWn8RhN3QHV8Pg]cL75fO7mlNWQkPHJ8QGimP8B7RXnEUY:<
QXF6RY2?QGj0PhN;S8j;PGj1PGU_JVmfNGQcLW=_Kg=bKfmdN7f2P7UeN7ajLW1f
OGmlOh>5QhR6PX20QH^<RHB4RHjCU92?T92@SXV6QHF2OGYmPHRAShEoOh20P7mo
P7n1RHb7OWb4SI2=PgakO8>:RhR4OWUjO7aiN7amNWYlPXJ4PhN;SY6@RXF2PHJ<
SXZ4Ph60Q8V:R8V<RHF3QXV:Qh9mNWj;Ti29RHj@TY:?RHB3Q8R;R8J;TYNHUHn;
QhF8QH1lNGUnQXn>QhF5PgejO7imNWQlPXB5PW]dM7MhN75ZIfIWJVe/IfMZK6YW
JF]`LW1]JVUdP81gLG5aL79eMgUiNh67QgmjP8ZBUYNFTi:CTi>DUYB>R8Z:QH63
Ph1mO7]kNGEdNG]lNW=`MG^1QhV7QHF5PhB5QX^?U9RHUiBBUIB>QGelPHZ>S8Z8
QHB:SY2ASXZ>U9:<S9BKW9NDT8V5RHj?TI>BShjATi>FUi:>Si>EU9:@T9:EV9R@
Q7n0Ph>3Q89mNWYlO7]mPhN3OWanPXJ:RHB1PhZ<R8F4Ph60PhR7Q861QX=lNWE_
KFa[JfMVIV=OHVIVHf9TIf]/L7MbKFa/KW1]K6mcNGmnNG9_L7EoQ8>2OGV0RXjA
UYNBS8Z<T96>Rh=iMGIkP863QH9kMgMiNGMhOXB5P7j1QHR:S8b:QhN7QXF6R8J6
QhB0OgejMgAhNgalNWMfNH::SH^6PGeoQhZ:R8EnMgEkP863Qhb;Qh^BTHN1PhR;
SXnAUIRDTI:DThf;Rhb<RH:0QHV<SHZ7Q8>1O7aoOginOh20PH:4Q8>4QX5kOX:3
Q8R=SXf6Og]kOhJ=Rh9jLg5fNW]iMgYiMGIkPH9nN7EdM7AeNWemNW=aMWUiN7Un
PX>1PX^@SY6DU9JIVYZFUIVFT8^:SXb5Q8B4Ph:4PGmnNW]dLGMfMW9ZK71aNX>7
PgYjOh5mP8B8QhF8Si>GU8b6QHB0OGb0QhV2P8:3Q8F9SHJ3PGZ2S8F2PWamOgei
M7EiO7n1Q8J1Ogn0PXB6PH28RXJ5Q8J;RhZ2MW=hOH62OG]iMGMmP7mmOGmmPHZB
TXMlOXB9Rhf?SXb5PXZBTXn;Shn7PX25RHJ9RHF3O7IaJFIWHf=ZJfY^LgEeNGYg
L6UXL79^MG]jOXF7OgAaMGb5RhZ6PX>5R8nDUIJCT8f@UiZFTHnBT8V3PXZ@RhJ9
RH=nOH:6PX20OgelPHZ;QhF4Q8:4QhN7R8R8R81nPH1mO7akO7moO7YiOhF7R8F1
OWn4R8V7PhF:R8F9Shn<QhR:RiBMP7F>RGf3RH:5RXF2R9:CRHJ@V9F9Q8R6RiF?
S9:>RXJ1PgelPH:8RXb<QhZ8Q8n@QhR2P8B6Si:DUhn3M6mjPH65R8=mO7E`LW=i
OgAZJVafOW]bMGI_JfigOGagNWYfN71bOh5hKG1cL79jPXb<QHJ8S8j:Ri:JUhj>
TI2CShV=QgYkP89oN7b1QXZ2LF]/Jg5kPGedMgilMWEkQXZ4PHF@UI:>Q8:9R8J6
RHR0NX26Q7YaOHV2PhMoP8jDTXV<UY:7P8:6P7imNHB9PX61OWb6THn8RXR4Ri6B
UI:>RhV5PH:4RI>9OX5mMgUiNXJ8OWUcN8^AShAiMg9kRhZ8RHEoP8R7PHB7QX9n
NWanPhEoQXYkLfmTH5aJGUMJKV]TK71cLFYXIf=VK6eXI6]lOg=bJ5ePKGajLg1m
P7QlPHV<RXR:UiZ>RiRXYZBRThb=TYF7OhZ:Ph24U9B7P8>7RXb;VIJ8R8N6Pgn5
R8ZBTi6@TYZIV9V?RHAjO7n4Pgn2S9:BTiBASY2HW9N@R8ZDShnCThZ4S8UoOhJ=
SXYoMWR7TY2@SHV<Si6?SI>>R8Z4NhB@S8bBUXikM7emNh1nNgM`MGYgOW]/MGih
Ogi[J7F7SHB4RX=gKg1mPgimNG=aMWYmNgIeKFI]LVm`Kfi^KFiXKGM_K6]^L6EP
KWUdMX1bGF5_N7^0PhF2Q8jBR85oPhj;RIRKS8BGXXMfQ8MmN6UZMWQmS8aiKVe/
LW1VJW1bMGQfOHVAS8b;QY>LUiNNXIZDT96>O82?QWemRIJGUHV6R7mlQi:HViV:
NgZ6ThMlPX1cL7^4OW=ZKX5nLWIiPH=bJWj?TYRAP7AiQXnJUhZ6SYbJQHJBSHb;
RYBHS8F:W:RRUI>BVZZYWj:KTI>T]kg6c;^SUXQeKg9bNGA_O7ihNWj2PhB2PhbB
UiR=Ph5iKVI`O7]gQIfLT8A/Fei[IeYWKg9mSHaiKfQTGV=ZM8bBQX5`IFa[K6QL
JgI`KVQYM6m[Jg1jLFAMHfQ/If9SI6i`L6iQGFUnKd]jVWijRHnEThEiPX]lQZ>M
RHfGRXN9RI:KYI^1QibNZ[6ALWEkL762U:_6d/:^]:McEfadMH:;V:2NUHVBUX9l
Ph^GYjB<NWYiMg=`LWEnNWMhPX5dPH=bLF]WK7IgL79kPWA]KemIIFaVGVAUGf]Y
GVj3T8ehRIN1MgaoNh:CRGamMgf?U9J;PiBFTYbBQhf?SX=lRXnAYZbT[kBVWJRV
Yk:dZjjl_KNd/kNk/J:CTYbLWZ^VUY2EVI2<V:>PU96OYJFTYjNOW:B/];JWXjZW
Z:bRV9FHW9EnNY2JTHJ7S8IiP92JR7V4QXB3Og=[HFEYGV1XGdE7FemIFe1<GFAJ
FUmPGEaPFUUMFE1;D6MZI6=NGE]IFEUHF5MKFU]PEClk>TE:BDm@C4eJGeQ9CF5M
EUQ>DEYDEee5C5aACci1BdQ3AdUAFEI?BUeRGfQGCDi6Eea@E5EHKg5VKW1cL79_
IEiRJFEVL82:QH>1Ohb;P8R6QXj3R8R2SXj2Ogj@Ugj3U9>FU9JXWH^;V::JV9fQ
Z[2]^k^c^ko1`;FU/LO@c/W6_[^l_/71^JjX/;jk^;bma<:i/k6b]KW1e<o0a/oA
dLkCc;g4cLc6`LK7`KNjd<R_ZJ^/[jj/];BXWJ:c]Zn]ZZFNWYnKXZZTXZ:BPGYk
R9:?PWelNgioPWigM6e[LG9_J6QdM7ijJFU[L6m^LWakJUmYN7AfO6aULG=gMVef
P85nOGilPXZ:Qh:1RHAhOhIkL7J4SY>EUhalPHR6Ph9oQHb6OHJERGUdLGMgKgAf
LgU_JG9QD55IGeYPFe=NIfmXH5eIH6UYJFaTHfihOGQ^GE9CGF=JDe=NIF5VKFEH
D4mHD4I>FEYAATeFDeMEFVa/GeU<ADiDFUY@Df]lLeeBDeYKHFadLFa/M81iL6YT
I6QbMFi]N824R85^GUeVN7ekNW=dMW]kLgj8PXB3RHUdM7n2R8Z7QX61OGAcMGao
OX6:S92>OGUlP8R=PFi_RinLTXf=SYJMTXV;QX:4QhB2SiVJWZ:MTi6IVIVBSXf=
UijSXiF6Qh^=SX68TXN7T8^5RXb2OXZ:QHZ=TIBJW9>FXJ2LViJFVYn[/[2XWZ>X
XZ>TWibGT9BO[;6/Zk6`YJ2QX:>^/ZFS[jV/]jVNXj>OVI2<QhjKXIZGWYVLVhf4
RI>MYZ6LV8b=UYNDS89nP8B9RXF7SIFBOfaTIFmiMG5_Jg1fLfYTHfQ]KFieK61Y
LW=hOWm`HV9XLWb7R7amQ8>9TH^7S8f?TYJFRhRIYYjBSHb?VZ6JS8AmP9NUUhnH
WJ6[[:BOX:JYXIN@TjFaYZFXVIJKUI6BV9RFV9RBR8N:RhF1QHjBRWj0SYnQWZBH
PhFHWiB;RY2JXI^@Qh1fOX^9Ng1[L7b<Thf9PWn5NfiZJgEjNX9kL7A`LGadJVMZ
KfmVGFanNgUcIVAUGUIGHVacNGQZHfYbLFQOHF9QIVIZMgUfMgIYHEiDE5aNGUeO
HV5OHFMOEeaNGUaCCDaAG5mPGU]OFUABDUUFBe5JEUIJGf1IFEaKGeeDE5eSI6ET
Hf1QHUQBDTi?FUiNFe5<DemTH5UBDeYPHeI<FfIRHEiHCTM?F5]RI6I/IUUGHFUP
F5YMHFe_KFacP8>2QXN;RXF7R8nGSHRATXQmO824SiNCRHB7Sj2[ZJ2DU9bMTXB;
X:BRY9nJUYJLXZ6JT8Z:Rhj=TIVKVibPXj6FSIJW[Jb/ZZBUZkBg/jfVWinNV9VL
Ui6=RhV9Q7]jPhj;Ogb5TIJ@O6aaMGZ5QGYaNhf>SiRDRHR@THfCW9^FUiZOYj6A
TIjQVIRRXYjQYZfZXYnR[[>YWibNWjVb/kBe/ZnfbL^m/Jjd^KRc/K:a[K>k/InK
XjFRXZNVX:>XYIfIUH^:VJ2OVHn;UJJWVYNJVIJLXIjNX:6NXZJKT92=SIRUZiR1
OXFDWIJ<R92HUI68NGV4Shn7PX61RY2>TY27QHb@S8J8RhbCU9>8Mg9fP92HW9nI
UYjWYYZCTiF?SiBEUiBAUIbNU8V5Ogn7QhN5OX::SHYiKgImQ8=mMVeaO7j3RWa_
KgIlMWAeKfe^L7b4OVeTKW=`Kg1_KW=kPWihOH64QGEQEU9HI6aXF5=DDEQRGeE:
DV1YKVMIDU9JHUmKEe1?CU5FFUaOHV5HCU1FGV9MFEQKF59FGfARI6YZI65[NG=V
HfM]JfIUH5YJI7AgLVe[LH:9PgMcNGUjOWQ^Jg1kPG]fKfM[KG1^IfAQIfMJEE]L
G6Q]IV5SI5mUL75dNWM/JFU]M7]lM75aLg]mL6U_Lg1RF5QBEE]MGeiLG5eQG4i4
@4YJDTE3@T]CDU=JFeMOLGQ/J6meNWUjOH24OgYoQ8>7RhJ0PHB6Q8J:QX>4RI:A
RXF5SI6BVYnPWinTXIRHWJB^YiF?U:>YZ:RLTY>ATi^KUiZ/]Z6@Ti^QWiREV9fI
SiNRX9VLWIZHThjCWZJRXJJQVI>@UYnPWYZJWYRDUYVSY:6FSIZTW9F<SYbNWYV=
QXN?VYjJUiVPWiB?TIbWZ:>ERH^=SYROWYbPXj6RXZ>VZj^WYJFTZ:^[YibIXJJX
Xj6RXZJWZ:VQX:FPUi69TIfOWI65Ri6?SXf;Qh^?Q7aiN828SH^2QhR1PhV7OWj5
R8AnOhB7QhV>SXAoPh1mNgQhNWmmMW=_LgQeLW=eNg]hN6aSIVQ[KfUSI6MVJFma
LWQjMg9/LGEfNW]lQ85iOX5lOH>6PWimP8>4Q7mlNgYjNgU`JVicNH:;S8B3Rhf>
TXZ7SXb9QX68Si6ARGiiOh:9UIF8R8b4O7]nQ8F3OGUlPh9oPX>4QhR3NgUjO867
SHn>RhR<TIF@Qh1nQXAkNG=bOH:4Og=_Kfm_H5MNIVMTGEQKHVEYKfeYL7amMW1d
NgUjNWV1Q7YcNX:6S9:?S8n?Shn=RXRBWJ6LV9NBShf<TibPW9:?UInYY9bNWiZC
SXj?TiVGU9>@R867T8j?UIB@R7n2RHf<PWQlP7j1QHF1PXN7Ph60PXB3PhJ7Q81n
OgadL7EnPGifKG1jOGj1OWemP8N3NgekMgUmNgZ1R8F3PG]jOG]fM7EhO861O7Yk
MgAiPXJ6SYB@SHj8Q8V=RhN8QhJ=SXInNgj0OX:3Oh>:RXf;QHF2PgmcKW5fNGI`
L75/I6E^LgMfKfIQHfY[K6i]KG=eLg5]KVeZLh1mLV]YJfmgNW9^K6iaKFANG61T
IVAIEV5[KfeVJFiaLVEEDE=FFU]HEEMFD59FEeaRJfULFEiOH65PHVMWI6IXJg1g
OGahM75eN7EbL75bLWIjMWAcMGZ1RXV0P864T9:<S8J4RhV5PGn3RHV6PX:3R8n@
Si2ATHf7Qh^BV9B<R8j@Si2BT8jATHZ2PXZHXj:JTHnCW:FTWIJBUI>=SHZ9SHZ<
THf;RXV>RWijNWalO7alOgmkNginP8B;Sh^6Ph:;THb7R8^;S8j?T9JPX9bJU8jC
WJBUYZJSZ:jWW9JLYjb^[:BPXZRa[ZJUY:FYXYREV9nUYjJQUhj;TIFFVYbRWY>@
T9>KW9>?U9VHU9:>S92FUI:CS8R=UIJ?RhR9TYJARHN9RHR:Q7j1PHRCTXj>UIjK
TXb5OXF?THR4RHjCUY28QXbCTi6@SiFKThR6RH^:RhV6QHR>THn8Qi2CSXZ9QH27
TIB@Qh:8SIBDRhJ5RYFFThf3P8R:PWUcMgn5Q7ijM71cN7UdLGEfLg5[KGEiM75e
MgAcLfiYK71/IfEPGfQcMGAhMgIkO7Q_IfAUJ6aWI69NH6EYK6]XK6m/I5]IH6IV
H5mLEU]VJFATKGAdLVaTJGIjN7MfLW1bMWMiOh>8S8V1P8:4QHF2Oh>9RXZ8Q7n0
RHj<Qh62RXf=R8:2RHMnMW=fOXN8QH>1P8B:SHf<SXn@UHn:SHb9SYNFT92DThn>
SXbAUYRKVYJCU9ZHTi6DVYbGShB2Q8:2OWIhOGinOWYjOh5nMg5_LWIiO7YgMWIc
KVeeOh5oOGUhNgQbL6m]K6mcKf]`MG^3QX=oOXB;TiRGUIBCT8j@SXbAUiVLVY^J
VJ6VWiNIV9>BTYBKXIZARh5gMgj1PXJ:QH21OGEeNG]nPh9lOH>4PHF8QXN9Qh1m
Oh24QhB0PXJ8QX1kM7IkNWinMgEjPHR;RhV6QH=oNGIkO7b0P824QH9mNGn6RXf<
QhB5Qh>0PHF5Q89kM7EiOhJ9QWmkO7j0OgekOhB5PGihMGQjNWemOWn0QhZ5Ogej
MW9`JfaeN7QjMgEeMgQdLGIhMgMdKfecMgMgMG9dN79YIfQZLWUhK6=VKWIjMW=b
Lg=_Kfm[K6m]LG5/JV]aMWEcM7IfLF]WIVQXIfUUHV5RIVQYKgQlOWafKFacMG5^
Kg9eN7MeMGIiOHF6OGYlOhJ:SHf=T96AU9B@Shf@U96<RhfCU8j8R8f@T8n8R8j>
SHMoOXB=ShIoPh^DVI>8PhR;RHN;Si>EThj<SYBMYjNLU9BGVINBShjBVIZIUXb4
P7f3QX5iLgEkOgilOh1kMg9^LgYmOgeiMgEeM6i_Mgf4RXIjM7MlOh1mNWYnOgYg
N7^0R8ImNGf6SiFGUI>FUYNLVIRLW9bQXj>SXjJYZjRUY:>WZZBRZ:^][:FLUYNL
WIZIVibMW9F>T9FFUIBCTYNKWIZGU9:GWibDSi6FW9fJUiVLV9BCTY6?SYBKVIJG
W:6RWYNFUiRHU8b8RH^=Si:CTI6?QhF:Si:FUHb5Qh^8QXR8QhN7Ph22PXB9RhN5
QH>3Qh^<SY:AT9BAQWeiNX66PW]hOXB7Q7ikN7QjMFm`M7YoO7A`LgYhKFQ[LWUh
L6a^LgEaKFa]L6iYHf9SIV]^JV9LG69XKG5bLgAbLW9_JfIMF5aOGU]GFVE`M7Aa
L7AdKf]ZJVe^JF=OI6iaKVmaM7aoNG5_Lg9bM79`LgUiM7IoQ8J6PgeiNWeoOh1n
OX21R8f:R8F3QXb<R8B1PhJ4PH>6RHb<RhV8QX>4QhJ3PhF1OH22QhV7PgimOGUg
NWj0PH60Oh:3PXR@Ti:=RXV<TI>>SHn>RhIoMg=cMGMgM79bMWMdLW5aMWUeK6EU
Jg1_JVMXJVIMG69XL7A`JFUaMgEbLG9dMGA^K7=iOX:1O7UjOhB:TIBDTXn@TY2=
RHB4RY6BTYJMYZbZXYZGVY^GUYFEV9VFTi6CVYZDShb=TiRERhB6RXjAU9RJVI>;
RHV9QhF3PGj0PXB:SXj=RhbAT8f:Q81oPHJ8QH66T9NHUYJIW9ZBRX9nPHN;RXR9
RhV7Q8:6T9NDSHN0OH25RX^8Ph1nOgn3RXj?RhN7R8^?TI:?S8b<SXj:Q7j0QXR7
QH62Q89oOWn2PGYeMGYmO7b0Og]hM71_LWEjOh9oO7ekMgMiN7=aLG9eMgQhNGYg
L6e^LGMmOgioPhF6QGmhM75`L79cLG=kOgikMgZ1PGahMgIdLFi/K71aJfIUJ79m
OgUdLW5aLG5_KFi`KFY[KG1dNGmlN7UjOh:0O7QcM7MjO7]iMG=gOX5lMGQoPh9m
OHB<SHIoOWn3R8b<S8n=QGmnOX:9RhEoOWn1Qhf@Si2ARX>0P8>8Si2;QX62SIJD
SXb>Shj=R85mO7n6SHf5P862QHR6Q8N8QH:1OWj3R8EmMgEeMG5_M7j6Q7eiN7an
OWinP8F6PX23QXJ8S8Z5PXJ?VJ2OVYRMWijJUY>>SI2FWIjLXJZ]YYbFV9nQWYZG
U9BJWINCUiZIUiBDV9nRWIB?T9>EV9NEUi^MWYfIU96FWI^ESXV<SH^8QXV?U9FB
RhR9RH^AThf9S9>FUYBCUIVJV9F>RHbATXf:RXf@SHJ3Qhj@RGmhNGYjOX:1P7ih
LgAhNWb2QHB2Ogj1QhZ8Ph64RXn=QGaiO821NW=cMWQeLW1bNGekMW9_KgElN6aV
IFAQH65RIfmaK6YZIfEUIfIXKFe[J6QWIfU[JFQUHF1TJg9fMFm/KVm^IeiHF5mW
JVUXJfe]JfUZKW9dLVi[Jfe/IEmNHFASGe]IGV=VJ6YZJVa_KF]_Lg9^KFm_L7Ad
MGQjNWYjNW]jNGb0Ph5nO7UfMgaoOWeoPhN8Q8F?UiJ@S8N2PhfBU9JGUY:@SHZ>
Ti2;RXZ9RHnIWZ2PWY^FTY6CUYbOWiVASXj?TI:BUYVFTHb7Q8:2R96CSXZ<TYFD
TI6EUiJAShj;Rh^8PWelOGemNgYnPX1oOWikMgQkO7emNWQjO7UfMGAeNGalOH::
T92=S8f?Shj;QX>3RHf>T9BGUiB>Ri2GVi^HU8f7RHZ8R8J7QX9mNWb3R8N6RH^;
S8f=SY6CTHb:R8F6R8Z=S8IoNGQlP861PH1nNWMfLVa[LWUkN7QkO7alOhF=THn;
QGmoPhB3PH:4PGmnO7n4QhR7QXF6RH^8QHF4P7j0Ogj4Ri2BTH^5QHV=Si2ATI2>
SHj?RhF6Rhf;RHR8QhB3RI2>RXZ>SX^=Shf5OW]gLg=aL7AkPH9nNgUiNW]kOGim
OGn1P7elOX62PGelPH^BTXj<RXV7PG]hLfmeO7mnP8:5QX9nPhZ?SXf:Q7eiMG9`
LGAfM6eUI6Y_L71`LG1]JFU]LgEdLgEcKfe_LgUnP7]dL75fNGYhMGEgN7YiLg1d
NGf0PhN<SH^=UYfKUHn6P865S96@RhV8Qh1gM7Z1PWikOH26SY6?TIFETHn=Rhf@
TXj8Ph60QHZ=T96?S8Z4OgmoOGf1P7anPH>5PgmoQhnCThn:QhN5Pg]cLGElOgYf
NX>:RHB0NWEgNWUgN7QhOH1lMG9dN7enO7YlP8B7RHR4PXB5QHF3PHF:S8j@TYFE
SXV>V:2RX9R?SY6EV9>=RXf?S8AnOhF:SHn>Qh:3RHZ;SXnBU9:>SHj?TI2=Qh5n
P8F8RHJ5R8Z7QXAmNG]nPH:4QHJ7QXJ;UifMUhf3P8F;RX9mOhF9QG]gNh>7QX>0
OWn3Ph61OgamP7moP8:3QXZ;QX1nPXJ7Q81oP7ikNGQfM7EhNGQgNGn1OW]oQHZ=
RH9nOh>3OWQeM7IeKVEQIG1fM6mZIfadM79cMWMkOgagLg9bM7QhLfmaMWj3PWil
OG]iN79ZJG1dM7AdN7YgLFmhPHF4OgUbKg5aKFMVJVi[IEmKGFA]LW5/JFU]L7Ah
MWAfMg9/JF]aNH1nM6a]LgYlNWMfNWf1PWehNX25QXF6S9:DTiFIW9fJTXZ7RY6F
UI6>SHj;Q7akOX:5QXN4PXR>SXn@SHfAU9FCShb<T9FCRhF5S9JMWIVETiBHV9>=
Rh^:Rhb<S8j=RhfAU9NGUiFASHZ6Ph1oPhF4OGUiOH:8RhV2OWn0P7mnOh:4PGae
LG5gOhJ5P7j1Qhb;Q821PhB5PWagN7n6RXb;RhV8SYJNXJ2MVINFUYJEUIFDTHj8
OgYlPhV?T8^4Q8J7Rhj<RXb>RhJ4PhB9S8V1N7MlQ8Z;RHN6QXZ;QGilOX64Ph1o
Q8R7QhZAUiVFTHf;RHV9RHN3PX1jMGEiOGmnOG]lP8B7RHR7Rhf=RhZ8QHJ=TY6<
Rhf>TI6;QH5nOh:2OGIcMW]oOganPH>5QXR=TI6@SHV5Q8B5QHF6QX9iL6e`Mgj0
OW]oPGmoP7elP8B7QXB1OWj0P7]eM7R0PhF8S8b:RXN1O7MfNGn1PHB6PgikOhJ:
RXZ8Pg]gMWA`K6]YJfYSH6A/LgMgLFi_L79dLg1_L75aK6MXKWEiNgM`KFmcLG1]
JVmcM7IbL7=gNGMfMWb0PH:3RX^:SHQoOgj0QXR7Ph1oP7I[JFQYJW5eMGYnOhB9
QWelPhN9QH63Qh^?ShElNGQmPGihMWUnPWmiM79dMgIdMGUlNgYhN7n7SHj;R8N5
PWemOWn2PGUbLGQoQ8N6PGmmO7enP861Q8B1O7MeN7j5R8F2PHB7QH:2PX64RXj=
RhbAUi^MWIjQXjBVZJ^a/jfTX9jOXJ6PW9ZKUhj5PXB:TI:>SHj>Shn<RX^=SXf<
RXR;TYNDS8F4R8j@THn>T9>EUI>@SHZ:RXV>TY6CUINLXjNXYjNTWINDTiNFTiBG
T8J3Ogn2QXn>SHj<Shn;R8:2RX=lP820QI2DShIoOGj2NG9bKG=nM6Q]LW5eNWQi
Nh22OX>;Shj4PGmfKFEUIfUXJW5]HeQCEemUIfQYIfMZK6m^KW9iOX22PWejOH>4
OWAaM7j5Q8:3Q8F6QH5lNW]oOWalNgUeLG5cNGmnOWinO7UhNWYeM7E_J6IYJfig
OWn1Ph>6R8R7QXN6PgimOWajNW]lNWIfN7QgN7I[J6mbKFQYK6]/KVa/LWUnPHJ7
QhR7QXB3P7enQ8J6QXJ4OWUfMWQiN7EeMGIhMW5aLgQnPGmjMgQmPX5kMgYoQhf<
RXb@UIJHV9>>S8f<S8nCUIB@SHnDVYfPXZ2LU8Z4P7ejO7mjLW9cMGb4R8J4O7Qm
NWAiOh23OgUjM7=iNW^2OWMhP8b5Ngf1SI:1NXB0PHB6Q7n=ThV9TYVJV9VQXYfL
WIjSXInTYJVPQGU^J6MTJWAiOH:2Q8N5PWmnOWeiM75cNGj0Ng^3Ri6EV9jTYJNW
X9RATI:@ShfBW:2RYZR]];Fc[JVUXIjIT8^:RhV2Ogj1SIFFUIRIUYNHUYBBTiNF
TXf=TIFJWIfLVYVFUI>?SHZ3O7enNWUmNG5cM7AlPXJ4Oh65Ph9nN7MeMgIeMG=d
NGQbLW1`NX60OGYcK6aaM75bNGmnOGY`JF]]K6m[IVU/KVm`LG9hO7YiMGAfMG5/
JVe`KVY`Mg^1R8^8QH1jNgilMG=dLW5bKf]^MWn3Q8>1NGR6R7mmOGUfLVEXLgIh
NgmhJ6YgLfQPHV]SHficN7U]K7AUGgIlJGB:O7j=RHVAS75aThAbR820T8EnNX25
PXbDY;2BOX5gGUaYGF9iMGEhLgV0Ph:1PGMhNWQoQXV7Rh^3Q8J=X:NTZkB_XI^C
S9BHUiRETXnDVYVETI>DRhB1OG]oPX=oN6iZKGIoQhnCUiRCSHR5QXN:SH^8Ri2E
V9jPWJ:VZ:NMV9RARhN6Ri2ATIBBRi2GV9RFS8F7QWmiLVi_Kfe/JFQ`OH:5R8Am
O7imOgmmPX=oOWenPXR9QhF1P8:4Q85nO7j2Q8N8R8Z:QXB;UIBATY2?TI>GUiVL
U8jAUI:>Shn<RhR7QWmnQh^8QXV9Ri6>SY:9Oh:6MfUZK7V3LFejMF]]LfePH5aE
FeiQJ6AKEeeSIfi^LX65QH>:VHEfR8]oNX>1M7n3LfeZJVUbO7Z2Ph6ETHJBSgU`
LfmVIfMXJfeaL6aTIg]lNH=oN7UjM6m^JV]/J6mnQi>MW9>AUIBCTHj=RHR9RH=m
PXV:RhQoOhN=Shn=QWiiN7]lNgaoOX66RXf;RY2FTh^7QhEoMgIjNgf7SXf:RXf?
SHb=SHf>SX^7R8b@UI:=SHnASXV6Q8=oNG=[J6UYKG5bMgUjP8R;Rhn@T968Ogen
PXV>SHb>SHfBUYJCShj?THf6Q8J5Q8N=TiJCTY2@UIJCT8b;R8F4PGn3PgamO7Mh
M79lP8:5Ogb1Q8F6Q8F3OWaeKg=cM862M7V0O7ihNH1eMW5WN7=UMWM[M7QbO8Ai
M7V:QgJBUgAnSHjBQH^HRhF5P7IcO81fOYZNUJF/YjJISXAeLGAhM75oQWQ/K6e/
LgUmPXJ?TH^>SX9iO8F0MWb;VZJZYYjGVJF^ZJNWY:6KThj;RhV7RHjCTi6HX:2N
VY27QH>4R8^?T8f8QHV>TINGU9BEThn;QH1kN7]lNGQmQXf>SHR5R8j?S8V9RhfB
U8j7R8V9RHb?SXb7OgUeLg=bLW5`KFibMWanNgUkOGYgN7QjNgQcKfi^L7AhNgen
OWUgMWA`KVe/KG=iNWYgLg9bMgamNgIdMG=aKfa[JVUWIF5NGEeQI6QYJVa]JfYW
IfMYJVISHfI[Kg1^J6AVJ6]]JfQYKG1^IfAVIfETIg9kOh1kN7UlP8F8S8Z:S8V5
QHJ6Ph60O7UiNWj4RHZ9RXfAUINHUI2?SXb9QhR=TY6:QXV@TH^3OWn4RHf=RXV=
T8^4PHB9RhR4PH63RY>GTXR3OgYgN7f2PGmkN7QiNGb0PH1oOh:6S8n?SH^9R8V:
RhjEW9nLV9JGV9VKW9^IVibKV9RIV9FCU9NLWYbLWIjNWijJUiVNX::QWYVFUYFB
S8AoP8J<SXj=SHb:QhB3Ph:2PH61Oh63PX1mO7j1Ph>1OWf0QX^;RHN4PH24RXj>
S8Z;SY6EV9^IUIBARhF1PH:3Q89kMG5`M7YkMg9bMganOg]gNWemNG=`LGIjNgQf
MWMgMgMeLg5_LW5`L6m]K6iaMW]lNGEfNWn3QH:0PhR8QHB5QXN7QX=oO7f4SYJF
Sh=jNGn9RhN3PhR>TiB@RH9kM71_LGAgNGYjOGmmMfm[K6mbKfYXJgEnOgQ_JV]b
OX>3PX9oOGemO7YiMgEdLFa[L7QnP81mNGQlPXJ9RXR3Ogj3Rhn=R8>5RhnCThn<
SI:HVI:<QhN9RHJ2PHF:S8f?T96AU9FCTi2;QhF5QXR8QGihM7=dMgUjNWb0PXB4
PX:5RX^9QhF5QXN6Ph1oP860OGYhN7b0P7ahMgMhOH63QHJ6Ph60Oh68S8f;Qh>1
OgelO7]iMW5^KW1dNGYgM7=dN7]jMWEgO7ejMG9gP8>0NWEeMgYmOgelOX61Og]j
NGUiMgMjOXF;S8V7QHF;Si2AUIRIVIbPXj:JSH9mNgf2Qh^:R8Z?Ti:;PGYjP8Z?
RhF5RH^:Q7]`JFacN7QgN7n7S8f;QGadLWR2S96@SXjAUj2VYJ>RXInJUI:BUIRG
TXb6PXB=U9VIUI6>Si>DU9FGUiJDTI2BUIRHUI:?T9FLWY^GUYF@RhV9S8nATI2A
U9FDU9BCTYBCShf>T8n;QX>3Q8F4PWihLW1bMWIfM7AfNW]lOGn0P7iiLg9dM79_
JfQXJFUYJFMXKG1^J6MWIfETI6=WKG1^KFa[L7AdLVaYJFY]L71^KF]WHf9LEe]P
HV=TIVQYK6YUIVYZJFMUIVU]K6QSHfIZL75]J6Q[L7IgMG9`KfiaN86:TI6=R8=m
O8>=TY>=QXB6SYJGSh5fM7MiNWb2R8b?SHR5PWmnPHR@TXj7Q8N=THj5NgIhP8R=
RhV9RX^;S8f?TI>DTi:AT8f=T9:DUYRHVj6UXifEShf@Ti>BTHn>Si6BTi:?Si2B
U9BDTY:DUYBCTHn?SX^9R8Z=TI>CTY:DUI>?RhR6Q8>1PH>6R8V:RHV;Si6?SH^;
SXn?Shj>SHZ5P7eiN7YoPH20PH>3PGmlOGn1PWmkNWanOGYhN7EeNGamOh>8SHb8
Q85nOH21PXF9RX^>SXfBUiNGUY6>S8Z9RHV8QHF6Q7mlO7anOWalNgf0OgimOWn0
OGQcLGIkOh63QXV;R85eKFY/Kfm^Kg5dNh:6QX9lMWIlQ8V>Sh^:S8b<Qh1lOH67
RHF0NgMfN7UfL6YVK7V6S8Z5PHB:SH^7QHJ6QX=nO7f1QHR7QhV=TIBHViZESXR7
Si^QX9RBTINNWYZETY:FVYZHUI>>RXN1N71/KG9iOGimOGinOGYiNGYkNGEbLWEh
MgEbL79hO7]gLg=dLg5_KFa[JFIWJg1bL6eYJFieNGYiN7EdLg1ZJ6IVJf]ZIV1N
IFaaMG=aLWIjNgj1PX9nMW5_KWAhNgYeLW9eMW=`L7=gNWUkOX>8QhB1PXF8Rhj=
RX^=SY:BSX^;S8f=S8^9R8AoOWn3QHN:S8n?Rh=kMWEiP8B2PH21Qh^:PGMaLGMo
Ph5nNgUjNg]hLVe/KgEkOW]hNWaoPH1oOWn6SYFGUI>BTiNIVINCT8j@TiJGUI>G
WJ:TY:FY/[Rf[ZBLVIfQXj6MW9fOX:6TZ:^][Jb/[ZjYXijNX::TY:>TZ:b^[JZV
X9^ET8j=Shn<Qh1hMGEgNWajMWAeMgQgLVi_LG9bKfe]KW1bLg9_Kg5cLFi]KFeZ
IF9QHFAVIVU]K6a/KFe]Kg9eMW=bLG1aLG1aLFm_KVi]JfUXJVYZJfe_LgYmNW]m
OWejMG9aLG9fMg9_LWAfMG=eN7aoP8:2PX>1OWj0QHZBVI^KViNBSXb=T9:ASHb=
Si6AS7m^HV1WLW]lNWEaKVm^JFAOGEiQIV]]KF]YJFQWIFETHfUcNGUeLVm_L75b
LgIkPHN:RHZ<SiFLXJ2LVYbPYJRWY:2NWj6SYJRZ[:b[[:b_/K:c];Rk_[fi/Zn]
ZjRUXj6PWifJUYFGVIZIVIZKViRDTXn>T96@SXf=TIBGUY2<QhF5Q8>2OgajMg=_
JfMVJ6QVIFEWJFQWIVITHf1NGEiPHV9SHf1QIVQUHV5QHV9TI6ASGeiMGV5UJ6YY
J6YZJfi^Kg1^KW1_LgEcLFm_KVUVIVY]LgQgMWIhOH22Ph:4R8^=SY:IWZ6NUhj8
R8V;S8n>SY>JWYjJTHJ1PXZEWIjHTY6FWZ:NTXR4R8nDU8n9Q8:0O7I^KG5gOX60
O7MhNh24QH9nO7f2RH^8Ph22QXb?SHZ:SI:GVIJAT9>LY:NUXInPYJV/[Jb/[k:e
][Fd]KBb[Zb[[:f/Z:>NVYZNXJ:QX9nOWinOX:2LUi:>SHf<RHJ5Q8F6Q7mhMWQm
OgilNGIcL6m`L71`L6m]K6a]Kg5`KFMSIFMVIfQVHf1JEDm<CU1DEeEACe5BD4e=
Cdi?Cdi?DeIJFeYHE5AGFEeNGF1QH61PI6QYJVQXJfiaLg9bLGAkPXB2PhB7Ri2D
ThZ2O7QlPX:1OginPHN<RhInNW^3SYNIThR2PhJ8QWieKVmeNW]hMGIgMgIcKfe]
Lg^0PH5nNWUkPHJ:Rhb>TiZPX9^CSY6GViZFTI2DVj6SWi^KXJN[[Jj/[:j]ZZJT
YJR[[Jf/Zjb][:RTXZ>VZZj_[ZZSWIbMXJNZZJFRXZBWZ:FOVYNGVYbLVi^KVIB>
Qh1oPhR;QhB3Q8F2OgemOX1oO7UeM7EhNGA]J6ESHfIZK6e^JVETIF=RI6=PGf5T
I6AUI6=RHF5QH65RHf=RH5mOGUiLF5QIFf1QH61QI6IVIVIYJfa/JVY^LgQkNgYk
OhR@TXn7OWYkQ92ETHV3PXJ=UIJ<OgQkQiBMWYR@RXV<SHR2OG]mPHB2N6m/KW9b
Kfa^LgZ0Q89nNGMgNWn4Q8>1PXB7QhAnNGQnRI>GUYBEUiRGUI:@TYVQYj^/[Jf/
ZjZ[[[>g^[Zi]kJe/Z^TWIVGV9fQXj>PViJCTYFHW9bHU9BDUIBARh=nOGn3QhV9
R8J3PX5nNgYkOX22Q8J6QH:1Q8J6Q8:0OWeoOgajNGQfMWEaKW1`Kfi/JVa_LG9c
M7EeM71/Jfa[JVYYIfIXJ6QXJ6UZK6YZJV]ZJ6MVIFAQHV=SIVYZIFAWJVa]LW5a
MGQmPGmeIeiJG6=XJVUYKGR4R7m]Fe9GHF]cLg1/JFeaLfiRFeQFGFU`LVeYIf9K
EE5BFFEcNWikM75cNGj0OWb0RYBKWifETHn?TiBDU9FKXjVYYZ6QXZF/[kFl_l30
_kbm`L:o_knm_;fm_/2o_KNd]kg2a/K0^KVi^Kjn]k>f][Rk][6ZYJJUX9nOW9VH
UY2:QGn0Og]mOgekO7j0OgmoN75aMgYgMGIbK75cL6m[IVMYJW1bLW9`K6Y[Jfe_
LgUhKfYYJG5aLGQhMgIeMGAeMg9dNh21NGEfNGQaLg9aNGMiPHJ:QWinPXR@TXao
M6i_N7akKf5PIW1oS8YjIeeQIFibKF]WIFI[LFeTGeYNI6ASGEiSH5YECD0h?TM?
E5aKAT=9FFm[IUmBHFi^OWUSGfEYNH=jM7^0PH1lQHjDSXF=RYJVXYbQX9RW]:>K
ZJb][[>`[:jZZZBKXjb/YZ:QXY^K[;NYX:NZ[[Rj/9jPZ9nEVIVMWZBOUHb8RHfC
VJ2QSH>EVj2OTHV@RGV8UIfIShUjPYZPRg5_O825QWn3O6a^KfmTFVagKfm_Jfmd
MVmWHUeIGfeUHVYWG5QHE4MFI5mPHVEGG6UTHFI[LXRASGeWHgV>OGQmLFQePhF2
QhAiK69iPhJLTgUbN8^MRWEjOhF6RHEjSYB6R8R6R8>7QWUeN8>1LgJ7TXYnO7Mb
OINJR:J_PW2B]J65Qhf=SX^?SGj3UiZ<T9:9SiV:PHZDXiQoPHjFU9:MUIRhVGRA
V8n>Ti^GPGb;WHebP:Z/VIRKUXjI[JV9T:^GPgfA[IN4R8^<QGeoQXN2QGmhNG=i
UhibNV][QXZ5OWR:U8J<P7QcHg6:VHR1Qg]_JFa]LgIkQH9hOFeQRYV;M65WNWb5
OVYhN6efL5iVHVb<U8EbPjBBRH5NI7=hR8eeKWabL7^6Mfa^LG1ePGn3PVe]MGIT
GUmHI69QL7QaLg]cLVAHGFZ=ThIjH55PIgVBNVUYEW>OPg5bLkj8E9NHOhF3JGfN
[X5gW:Fi`ZZYZjBQ[[fZSHnR^m;0Xi^Pa]7A_kC5WX6PdmFIOi[5^if<RZJYVj2d
V7><[ZFHS7RBUVY^RhU^MXjKTGeaHff:LT1HPgF0JUAhM6]dF5EVI61N>Ba:ASPf
@3lo@d][JEaJA4QVMUYKI4]=N7UF>bi2H6Q^BU67HeUlF4E?C5AVOWbBZK>bZKNP
NfAGJ7V4SXf<VIn?Sh1dMFElUYZ/[k6?MGUkPVE@GG^<W[NUV9fJW9B0IeF3WIZM
MemGIYAcDVYhQ:k=_jNU]ZEhFW1`L7N:WjfTPi:^/I6D_KZS[j5lR96Z[WaOJH:J
YlcNZK3cl[Vb_/BdZk^CPWFC^9IkS9>OaK6CZk:ZZJRXXYVASHV7OGZ?YZn]XJ>^
VIB7OYB<KhEdKYV8NGJ5TYb;RjNWYif4Oi:HM6mdDFfBOe5GMFmfOGb5G4ISRX9=
ATmAIFeD>d<n@cLM@5Y3BE]LNI:QShJKX9mR60PB820[HWALL8MhUhaRHD@`JHaj
JCdA4ALQ7R`_;CiLLVDgFY:5OG8h=3dNB6Pi>DiDMiRn/IS1kM6[WjnXUYjNQg=a
PXN8ShfT[J>lj=o3dlG7e9b?TXBGPW2H^jjac<Bg][>jbK:ebK:F^;bNViK7f;2[
]j6A]<>PLW^``KFbT61^SWUbM5IFHhAkJI5TE9F9MGn2H5fN_8EJSHE7KiIZMI2F
QWJ2SiV?J5Z0TFedPG:8/:fH[9N5YkW0/iZFVig3[UYKQF9EIE9FH6eMKJ3Cfm_;
f>oL]752>CUEG4MACUb7QiJOKgETCG^@QW]L?c8a;24900@K=dICM9fNW9j;LE4J
:6UG?5I>BU]QOiF3R8^Q^9n^`IjBVi>:PgZBTg^@WJf=IYReVJg;_J^]]:^BSXQX
H7B0PIF9IInjUXfCS9fb]K6IViVIWjR9LWiiOHnSOW>RWiZk]9>_/k6iVYR@PJ:N
O8j7LF]dTZ>EXjMnJGEiNX=fH5INH5mXKTm<NIVIPg27VX:>W:FZJE5lQX67O8B6
QYnVRH2=UheJGG=:7DY`F65ZKXFMaNKC_kf<J5m;=C/h93I7A5IDAUe_O4/gRIMd
Rhi`EDiDFV9;;QXB;gJKT8R<ViNDSXE]AS@dH8b2IVR4Yk>PT9Zmbl34bKR[Uh^N
WIFENFYjR8^DSIBl^KNk[IUnQXj1PgagR89DGGUnQHR4PiRTXhmaL7nTTfQ_OW^1
Z9IfQ9FX_JbAXKBd_l[2VGfB[Y:<YXmbKGJ>QW23LCi4KGidGTiPL7^GNf1[I69c
JeETK5aULXR:LVYlU9bFMVf1Q8^R[9YiSK>]XimgKI:/[iUfQjbVYK3Gl=FgYiZP
TVMTLUa0=CY5=cQLF3]ENfaCG6UVH5QRHdMJIeM?9Pd^;1HG8SUBHG9gLfijShQY
J9AdFGb6OG5_Jf1^PHF5Ri2P`MJeT9ncXj:TUWMFDER8cnNkT:6g`m7:bKJXZZZI
Shj>Pg:1SWebQgZ5_:RXe=SAcLO4YJ?OfmkQ_kg;`loShoK^cmOHa;FT/:]cMXmm
OViCHgIgMg9WF5UiQW9VK7UZH6eKBU9?HFARRhA?E6=aRWn9V8:>Y9>1Og]XJHN9
J6n;PV=NF6AmKFQ[QZVXZkZjYI6BRE`g?4UIH4a0?DIC?3Tj9C9TO5i2BEUECe=E
@B057Shi?TaDIgicNH69UiFS[K6^UX60RINVXYJUZIZ?QiJYXI>AV9bXZi^DVLSR
ZgV3RH^=SifDRYZUT8b<L6QVKYB9H6Z5VIZ0QI^0LHbBP8:;RiZSVj2LUYVZ_l2k
[9UlKWAfLFaVGeaGFFQUDE=XRJB?PhV3SJ>RPV=ZM5mVOX:1KfakQ8EcJ7IfLhb=
KemUNXV0OH5oP7MoVYj=SZ:QX:RbXhEhP96?QHnFRi>W`]W1UXR3Qhn<Q71KH5a5
=c@c;RDkHdDN<UaTDdDoACa6D4I4BEIIBDITKfA/LWB;YZ2>UZNlc[NZ^lcHaKK7
c:nK[=O_bZ>RWYVU`n7EZ9N_]ibDVh^6XkfjWG9GL8Z5MGAkJeQMLGj?U9nUSH>A
WJ:/^/?5akfh[j6iakk2a;Je/[2kZYfTYkFcUWifLgN3RXUcFEZ1Uh1QFF5ZO8Uh
B3=7HF]E?CHo>S4a<3i4C69/IVeeNWQaM8NCQ7Z7RgmfKfIOGV9PI6]PD5moUiZQ
^L2k]<;Cb[V`Z9J7Mg5QATE1>C`f:S95BCd^9bTgADM6@3`c=C]4GE`^5SA3DFEZ
IEYFLHQnP7j;XIbQ/jjV/[^mZ96QZ8YmR9fd^k>KU:W0^in>UJV]VGAKFVUlOFmU
I6mkK5UOKW=]NIB?OX:;TiBDUI:8Pi6b`KF/Z:RY[jbMOG27U8R8UiRDUJJe]Zbj
e=6n^<k@/Y^O];^naL2URhnQUh^AR75WJGR8O6A_Q85lOgmeKWVCXIR4NIJJMVQn
R7]hS9YlNYfMTj2NVZV[]L:h[l;>a[6GTiF4KVI^PgmKDEmEBDhm91djB34O61PL
;cLb?Dm==BXgC5E:=c52CeQNK7QVHW^<O71VKiBT/ZN>WKJfZiB7Z/6]TiFUZjVX
ZZ2HWZ6JY[2RX9nJ[[NVYin?W:BHRW1PJGV7P6e]QHj5OW9YJ7:3V91lU;BiXHV6
RXV:Q6UZS9nKS8B2PWf5XZnTT8bLYjZXXIF:NFISGDI:GEmA@SPeBEYIGFYkPWe/
IVeaJEMTO7=UIf9QGei/LG1kMWJ;Ti^YZjbb^Kjc/<SA`[o6a:NAUXf2Ogf3OWf?
WIAnJGJ>NV9MEe5>CDiGFeQDGVEMIg]cFEecJFAkSH5UGF]iLfaZJ7>2S8n;Uk_C
d<OAg]6bYlOQel_;blcBbkJJUjRXZYj:SZ6Z[;F^X8j;U8R3QH5eJW1`KFIRGUAB
GfAGAT5<IgIfNG1OD4UGHeY?CEI[MgYoNGZ?Z[:LQX:7TZ2]Z9JEYZjJPGb<TGAY
OXI`LGUZHVYiQ85fLG9oRWilP7j:UWYOHEYIGEiWH4A0B5ERDTURKV9aSYbIR8BC
]LbnT723Thf3LF5^Q7YJ@456@44o<390@SXgAe=MHf1QH5UIFE17A5ekHe5ZJemY
PXQfKgF1UIVHZKRbZk;?ekbbYj6hblc2];G6`[NZVZbn]KFn]:BW^<_9]:jZVi^P
VYVIT9>OW:Ba]:fIUIfFS9BIU9nPWYV9R8AjMWQlR8MaN92CS8V8U:Re[Y>1Q9J`
]jBFUj2[[jF=OX1nKfn6UH5JE6j6RGaRFfIMGFQUFembPWmaKFaVJGEoP7AWIV9N
Igb8P7YjUJj]ZYnAV:jk_ZJ<Sj:TR6QWNWmhKf9EHVaPFEIJEd4e@4U3BDM8CTU9
C4a>C4QKLWeoK5IMLGUeI5eQHW29UiF<O79^O9ZPUXQjOiJPUi:DVYVCTh^7TiZK
THZ;Ng:0UYjBPH6=UX]dO8MiN8VLUX=mKe59EeaOFe5HIF]XH5YGEfQ_HeQFH6M[
N9BQUiFQZ;2k_[jm/Jja];Ji^<3BdL>bViJZ`LBaYjN^/Zn[XibETHf0MhBGT8F2
Ri9gHFYjM6afNgalPHfFWInOZ;:i_[nZT9NZZZ2MTG1OJFiZJG5^IF9SJ6]OB4eJ
GeeIGE0m?DaOHeYACeIIEUEAB59_NfiQKXJ?PWMiM6maNh9oN7MlNGb4S8j6RY>?
TZ^l]:6N/kNOUZ2W[[6]ZYnGX:VTXZR/Z9VDV9jXZ9fCVjN_[iZ4P7n3QgiaJ69X
M79dNgMaKVY_OH5lN7N5SHnARGakN6UUJFedKFadLVm`NhV9LV1YNWehNgQ[IVig
MGUjHDY?J7IcITm<GFU`Mg9OGG5nOGioMVeeQH^7QH>;UiNIViRIThfATXbCRWUl
P8VFR7^6T8n@Si2BSI>MVXmhH6YaKWE]FVEjMf1@HXB:PGn4PH66SY67Q8b<PH>I
[:ZGS96EVJVg[jBZ^l:n_[^]XI^NZ;BZVINIUYFMWi60OXnNX9>1Q9JKV9R>PHjY
ZiF0MG1`M7eeHFQjP7YYIfYUIG9eK5]<EEeCF6idLGQnLEI@Ig=ZK79fQXYjN8F?
WJNSU8jJY:BUYiR=Vj>PUgm]MXVARhB7QG]lP7igKVMQI6e]HTi7G7UoKfE^PXR7
QW]fRIbGQ7IfMV=BE61ZJUe@BDA6C4Li<S<j@T@l;Re2FEiOFTa@H6Q]MgIZH5mY
MWakM6e`NWiiIemhRXMnM7=mRYbQT8BBYk6UW:6WZ:>JT8V7QXAlNhZFU8b9SI:N
//2n][g@fmoShMoVl?Gci=K<al2la<JbWY><Si>=Q829T96AR826TibMXk2`X9ZO
WIF8Oh>8Q7aeLFe`NWaaLGQfJVI_LW1aNH>4OgQbMG^0SINDTY6@SXfDUhEeNXRA
T8EfN8J9PhB5OX6:SHfGZZbXZJ:LVi^ITXMnN7=cJUQ@B41;Edi6BTe8?d9:BTQ9
DfA]JFAYL75bO7ilQ9:JT7efLVe/IEeOIfU^LVYUJgIlN7R2QhJ<SYBQXYN=P7Ee
NGM`KWMkLW1`GDa@EeYPI6I[L7=dNGj2RYFGSXF8RhAjM7bCV8f:QGn0PhJ6NgI`
HEQJGUeMHg9fIV1YM7j0MG>0R8nERhF@U8Z1RJ2WV8nAVjFPUiBDTI2FUiBHViRN
[;Jf/ko<c]C:^[Ri^;feYjJWW92@WjREOGZ8V9nKUJ2]/[2TT8F8SiJ@R8J6Pgei
MVA<C5ACAcDe@DA1?d97@TE:@T=GJFiVJ7EkQi:=TYF<TInRWIZIU8b@WIfCR7ii
OhF0P8NEZ:jRVibOWifOX9ZJXjFWZJ2DSHnLWY::RXbATi6=T9RLWZFZYIZKZ;>m
_k>RV9^WYIRDUHenLWAlN6eXJW=iLeiDHG9oO6YPJG5_IeiPJ6YRG5eKEU5>Ad0n
?Ca1CE17?Sa4Ce5=E65WI6QfOGE/J6UbNG]kOH61Mfa/L7UoLE]DGG21OWIgQIVK
R7imO8>:RXJ1R8^3O7=[KgUlL61MGEeNFU]UI5eIF5QIH69MI6miQXj7Ph^GWYbF
UIbSYJR]/;Fk^kbn`lS3^KS1eNSNa[^naLBiZYfHY;JjZ96<SHUoNWU_JWMoNW9`
NHF@UXj4QHb@T8j=SY2?SHj7Q8N:UZ2GRH5oP7mmNGAjOgAYK79lPWefN7]nRHjB
U92=UYjGRh5mQI2EThV2RY6>RXN7Ph:<Vj>OThnEWj^ZT7AeRHMhLWIoOVIFGFY]
If9RHVM]KVegQhn=SXj9QXR@UiB;QhbDUHYiJfA/MfeKC3/h?3i3@Sdk<2Tf@Clj
?4I<BTeACD]EGV=TGf5WIfQYKW=eNh9iKgEgL71gOH>>UIJFTiFKUY2?T9bVY::G
QhBAUi29Q824U9fBRI>MXZZc]kJ^YJZa];Rg[k2e/[6_/:jQUIBJUhj6QXfJZJVK
TiJOYZVZ/KRe[k>d/:^SWj6X[ZFCR8b@QG5UHFIZIEYBDE9AEUmNFUQPNh^1N7A]
K79iPXV?UY>4OhF>T8V1P8>7SXf;TibOW9jUZJ>N[;^j];>/XjFWX9BDX:>GTiB8
O7UkOGM^IeeCD55CCdQ=EeMIGUaKI6USG5mQGf5[KV]WHUYIHfa]JFQYKG1dN7n5
Og^5Ti26PWehO8R=Qh:5Si>>QGeeKfidMFmbOWmfN861LfUZJFIZL6e]LW9bLFic
Mg=cMWIaIFEcNgM`JFU`LFQTK7MjNWn9SHV;RhJ<Vj:LS8:1QXfDVZ:QV9>CT8b6
OgQlPX=lMgf4PWf1T9B7NWb<VI^CQH>;THf3NgUhNhJ?Shf@V::UX9ZMYk>k^;:d
]kbo^KBb];Jc[Zf[XYB9PGelNWIZGeiMFUQFDDLk>T15BD]<CU9GFemNG6=YKgb3
P7UcMh62OgUiQ8^>UIfOXJ>QX9fLWj6QXjJVYInNX9fPYJBRXZF^[:>U]Kji][F`
Z:J]]K^k]k2[ZZnk`KFSWIjLUHj9PWj5RX1bJF=OH65VJfQVKWQ_H5eXKFEQI6U/
HU=AEeeQF4Q2@Cln?3e3B4Q>FFA/KFa^KFe^JfMZL7MkKfE]MG1[J69PG5aRJ6QR
G5aSHEiRKh>FW9ZCTY^JSHjOZj^PShVAV9F=RH^?TY>9O7UiLFeaLg=aK6a_KW1_
JVETK7YmM75eMgMjNFmWKh2>T8R0PhnDTI2GYKJk/JVWYJBSXZBTYZNLSXJ4RI2=
Q7YhP8J4QY2KWYZGUiB?TY^U[JnSVZ6_]kF^[:fYXYbITX=lPhIoN7A_KW=dKFQ_
Nh:5RHf;RXb>Si6CThb0OXNBU8Z2PX60Q8:4Rhf9RI:NWY>?UZ6ZZZBRXijKWj:P
VI:>S8^3MFmhOg]gNGEaMGUcJfagP7]kOGYbJVQ/KVe_KFASJW5aKVi`KF9MG5YG
E5IJGEiHCDE6BTa@DE9EEUAHHfUTFemZK6QSHF9SHV9VIEiKFeULHf]_KFU]MGIc
L6i]KgEhLVYZKWAkQ92=Og^5T96BWJJWZjn^ZZnka/S5`lS=dm_NfmC<cM3<aL?0
^JfUY:FLSX^:Q7]eMGMgN7UeLFm_M7EeMgE^JVe^Kg=iNgYcKVm]J6EWK6mfQi:;
PX62Qh^;TifMW9nX];BZXZ2V/K>][;2_ZjVWWi25OG^4T8n:S8nASH>1RHf9QhV@
U9:?SI6IW9B8RYVNUHZ9SXnATXMmP8F4PGYhNgUgOH:2PXJ=SXAlNGEiPH9lNGj1
N6a[Kf]SFeMGFUeRHUQ@B4=:FF1JCTA5B4E4B4Y:BTeFG5mUJ6YeP81nPH:3QHJ=
UIVHUINMWijMWZ>XXYNASX^:S8^3MVaWHF5WJfa[JgAgJUeLHF9PHFU]K6UWK6i^
JV5OK7anLfmoShj9Ph65RH^CVijJVYjOWJ2WY9nPY:6LW:6SVY2=TYRGSX1gL6m`
KFiaMgabIFARG5eQIFa`LW=eN7MiP7edL79dN7f2QXZ?T8Z1P8N?THf;TIF>QXZ?
SHb=Shj;RhV5PhJ:S8N4R8N3QXV7QhbGXjJRWijNWYfKUhn9RXj>SHn@Sh^<UIZK
WZF[/;>h_Kbma]3@d=KKgMcHe<o=d]SHcl:k_KV[WIBBTXYjL6mbLfQIDe9DEDi9
BdY9AdI<DeMHE4e9AdU>Cda9AT94BU5FEeeZK65MHfUdO7]hNgekMG5bLg1^LGQj
LVQUJFi_J5]DFF=[KFebNgenPH5oNWQmOWb1PX64QX>0PHRAThb7R8V6Q8Z>RXR:
QHB8Qh>2PhJ:RHB2RiBCSHEnO7ekMWEdKg9jO7]hMWIdL6m^LWf3OgE]K79gLW5i
NFeQG5eOI6e`Kg5dMG=^KWQoPhfGUI>EW:FZZjj/YjF/^<?6b<Fm^KJc/k2YZJ^S
TXN6Rhj:QXV?U9RIUY:9QHR9SYVMX:J[YYVBVjbf/Zb]/:j/[JZPW9nNV9VNXJBS
XIjHShbAVIZGU92?S8J0OWmnOWemNgI_JFATJ6UVIVebKFEOFUQIGFMdO7ejMW9g
QHb:QX>1Og^0RHR3OWMaK6Y^LW9_HUE?CDeBEeQHETm7@Cdn@T=5ADE:BdDo>cXm
?d12BUQRI6MYJ6MUHV9UJW1fN7MkR9>FV9^QZJj^ZJR/[jjXYJJY[Jj]Z:BPWJ2/
][Zo_kno^K2_[JJLUYJDTHf7PWeeKFQSHfEUH5]IFf5XJfmdLFi]KGEnPX9mNGal
N7YmPhV6PGefM7MmPhJ1Mg9aLFm]LGIgNGamOhVATi2:RXf9QHJ:TI2<Si2BVjBT
W9JEU9BGVIfRXZ6QXjN//kJ^[KFi^[fo^kNe/k6ZZ:jbZijCT9FGUI>BShAgLVmZ
JVUSFeEBE5MED4i?DEAEDTe>G6MVGeiSJ6QXJfYVIfQZJfU^Mg]nP7adLWN0R92F
UHj8SIRMV8f6RHf=T9FGUiJDTHj>TIFFT8EnOWijLVa[K6YXIfadMgA_Kg1eNgel
OG]hN7MeLWAlPHB:S8f=RHR;Rh^>S8V;TiVIThj>TYFETXb9R8N5PGakNGIcLG5b
KfYUGUmXKfi^LgaoO7IZI6YcP8R;RHR9RH^;QhJ:SHf;Ri:ARhZ=S8V9RHZ?UiN=
PGIcMG=^JVU[JfAHCdeCF5]LG5]MGEaJG69TH5iQJWZ:UI>=RhnCShR7SiJGUiZK
VifTZ:R[/:n_][bo_kjj^;o:d];>aL78c/c:d=WKem7?c/g8_[:TVibOUhMmNgUg
LFQSHV=TGe=<D5YPH5iLFeaRIUiDE61YJVQVHUiOIV]]K6QWKGImOg]eLGEhKF1N
HVY^JFI[LWEgNW]gLFm_LG=eMW9/JFU_N8:5P7YiO7inP8F5Ph>7RHN4PhJ9RY2F
TX^=U9NCSHN6R8^:QH:4S9:@RhR5Q8R9QhF3Ph=oNWQjNgUfLVeZJVUVHF1PH6EX
J6MYKFm[IfIWJfi`LG5eOh>0O7]eL7J3Qh=oOH6;TI6;Pgn2RY2>SI6FWZBSYJ^_
[ZJSYjNPVYZJUi2>SHR6Q8:2QHN7QH:5SHn:Q8:2OgYjO7j6TiRFUI:>SIFKVYJ?
S8nDUiVNXjNXYjFQWifQZZbZZZb/Yj2OWIJ@Si6=PW]mPH>5QX=mNWA[I6QdOGik
NW]kNWj1PH63Qhb<QWegMWIeLg5aM7QjMFm_LFiVHEaGEEAGEU1>D4e;CUMNGUYI
FeiLE51>C4mCEe]QJVm_K6][JFEXL7EdMWUkNGb3RHZ<TYBAU9ZHSXV?UYRGTiBH
VifQY:N//kg4`lO>bl>m_;jk][FaZ9fETi6<RhV2NgA`KViaLg5_JfU[JVQXJFQP
FU]PHEiRJFYYJFMTHfUcNW]mPHR9PWaiNGaoP8:7SiJEU9BBTI2?T9>FUY><PGUk
OWimOX62PXJ9RXZ7P7j2Qh^;RHR:SY2@Shn@SY6IVI>>S8Z7P7f1RiB@RHJ5R8Z;
RHN9SHj>T8j<S8j?RH5mO7ajMWYkM7=fN7b2RH^2Ng]lOX23Q81nNgQdM7YlMW=h
OX1oNGEhPhb:PgelP8>2PX>3PGn1Q8V@U9NIUiFFVIVCShj=S8V3P7miMgb0PH66
RHAkMgIbJfMTHF1WKfmYJ6]YIVagNGIhO821PGmlOGf4TiNCTI2?Si6DTi:BTY:C
UIB?SXb5NgA`KfmcN7YjNG=]JFaeNGMgNGMdMGIeLVe`MgUmPH1mOX1nN75_L71`
M7IeMGUnOGA_KVm^JVMZJFQ/LGEgMWIiO7moNgUjNGEeNh26R8V=Si6CT8b>Shf;
RXR1NWf3PWinPXB7TIZJVIVJW:2SWiJCV9nSXInRYjfe^[bj]KBi_/2o_l;4aKnf
/[2]YYjLWYjHTI2AT8f:Q7moOWilNWYiMgE_IUmSJFmfNGQ`IfM^LW=eMWUlPHN7
PWmiLG1fNGIgO8:3OgU`K6meNgaiMFmYIFMZJFMVIfQ]MgmnN7IiOgmkN7EgOHB7
QH:2QXb@U9>;PXB8Q7eiN7b4RH^:QX:2QhN1OGf0QX^>ShZ2P8F;Rh=kMW=`KVm^
JfYXJ6U]L6]QGFE^LW1bM6iXJfm^JFEVKGR2PGEZIVabL6i]KW1dN7YhN7QjO7Yj
O86;UYbSYJ:RYZZ/[:n`ZZ>NVibMVYFEVIfMVYVIW9jITH^:RXV>Thj3Ngf4R8Z;
Qh5kO85oN7=_KG9kP7YbLWMnP820OGf4Rhj@SXf?TI6=RHR7Q8:0PH:0P862PXB8
S8f>TIVMW9^JVIbRXj6MVijOX:2LU8R3QXB0NGIiOWefLWEeKfQTGeYFE5QOIVEK
De5CFUiJDT]7B4Q;Cdm?DeIGEU=DFfA]LWIfLW1aLGAgOH5oOX>=V9VDTI>IX:>O
W9^KViVGUYRNY[2g]JjZ[[Nm`<G8bLO8b/[7_[B/Yj6KUHn=SHf;Q7agLg1`LW9a
L6m^K6QUHV1OI6Y/JfQWIF=UIVIWJ6YaMgMeKfa/KW9dLW9dMgMgNGMdLgEkP7eh
N7EdLW=eMWIiOhJ9R8R>V:2UZ:6DSXnFW9jPX9nPYZZYYJFVX9J@S8N2PHB3Og]i
Mg1YJFUXIV=PGeiRHf9RHfIZJfUWIfY/L79`KW5lRHn<QX>4QXN?VI^GU9FFUYBC
TY6CVIjOVibQX9^HUI6@U9NDTIBIWIjLUhj7QHJ;TI:FVYVETY>HWInJT8Z:RhIo
O7]kOGihLg=dLg9cL6QUIVMWHf1SIfU/LG9_L7MlOh60OW]mQXZ8QH1lOhB6QXB4
QXJ1NWf7SY6ASH^>TI2=S8Z8RXb:R8V:RhZ5OgakNgYhMFm_MG^2QXR6PH24PWml
P8Z<PgU_K6a]LgIeMG=_KFQTHEeNGEYIEeMIFUmQH5mPH5mRIFQ[KW1dMgYjNGIc
MH:=TIVQWiFATYRMWj6RXj^a/K:e^;fk]kNi^KJc/:ZTXZ>UYInDSHZ6OGUnQHZ@
U9FDU9FBShn?TY>=Q7imO7n4Q7ijN7EaKgAnOgekNGQfMgb0PH>4QH>4SI:AT8f9
Ri6ETXf:R8bATY>ASHZ4OWYeM7QmPhN7R8^=RGigMWQiNGIbKFUVIVQWJg1cM75[
IVAXK6YVIFIZLGMjNg]oPWiiMWAfNGYmPX=nNWUgMgYjNGUjNWQjOWn2QHJ7RXj>
S8Z8PgiiNgioOgilNGEaLWMiNWYgMWAcLVi]KVmbLg5aLWAhMg=`KVi^JfIVJg1b
MG=_KFYWJVYYL7^3QHJ:S8fAU9FJWZ2RXIfKVibMXZRYYIfMX:2QY:FSViFFUI6>
SY6EUYNIW9jQXJ2MVijUZjVRV96ATiJIUi>@SH=lNgamNg]jM71^KW5`JFEXJFES
Hf9SJFe]KFa[JfUVI6I/Lg^3QX^?Shf:R8N7RXnEV9RES8J7RXbATI6CTHj<S8b;
RXJ3P7UcLgIeLg1[JFe`Kg5cLG1cLfm[JFEPGf5YMGQcKfaXIF=OGF1UJ6]aMgUg
MGEiO7YlPH>4QHV<SY6DTi6@Shn@TIJLX:2PYJ^^/K>e_<S?cLFn^KNg][Vm_;F/
YJ2PXInLW9N>R8>0OGakN79WGe]MHFIZJF9NGf5OG5UKGF5[MG]lMVmYHEYHEeIJ
HV]aLfeYKG5`KW1dMWMlOWinNgb1P821PX1oPXF3P863QHJ8S8nBUifOWJ6VY:6R
YJfc][B/YJ6MWZ2OWZ2PX9^DShZ:SXf;R8F9SX^4OWaiLFmaKfaYIVIUIFIREdm>
DU5=C4Y;DeiTHUeNH65QHfU_LGIiOGn0Q8^=S8b>SX^5PXJ<SHb;RX^>UInQWZ:Y
/K>a/;2^[k>f^[fn^k>]Zj^/Zj^^/JjUWIF>RXN5Ph62Ph9mNWYjNGYgLFYRH5mP
HVEWIUmGDeEHFUePHVI]MWYgN7n4RH^:Rhf?TiFGV9RHVIVFTHV1OX22Ph61QHN7
Qh>0O7YjNWYmPH>4PWikNgUeLFaXJW1aM7IhNWMdL6]VIFIXKW9cM7AeN7YlOGYg
MWEdKfUYK6e_K6QZKVm`KfYSH6AYK71bLWMlO7b0R8nDUYJIVifRYZJTXj6KUI:@
T9BIUY:FVYVGUIFHVj2SYJBQX:2PXJ:QW9VIUI6BU9>BT9:FThj<S92@SY2=Qh>1
OG]iNWakMFiYI65QI6MYK6maKfYTHV5NFeePHfUcNWakN7MhNGYkOGn1QHN6R92C
Sh^8Q8F7R8V:RHN7RHN4QXb=Si:@S8V8Ri:GVY^JUiBBTHn<RXZ8QhR9RhZ7Q85o
OX27SH^9Rhf@TY6@TIBEU9>BTIJNWifHU96=Qh1iM75_KF]VHeaABTI1?CTg?3dm
@4=6ATM:CDmADU=FFEYPIVUYJ6UZK6meNWj0PhB6RXb<SYBHV9JAS8Z8QXN<TYJL
Y:NXYIfIVYbRZ[6j`<2m_/35b<G0^KJe/kJh][Bb[JJMUI2@ShZ4PH1nNgMfMGAc
MGMgMWIhNG]lNWUhMg]oOgYeLFi_MWj4QXJ5Ph>5PGekN7A_JVQ[L7MjN7A^IfAR
HVI/LgMjO823P7YcK6QXJg1dMG1]LGMiNGQeLg=cMGUjOH63Og]kNGIhNgQfN7Uh
Nh:8SI6DVZ2PWYjQXInSZJb/[Jn_Z9f@QWmkNWYhMgMaJfMVJFi_LG5bMgj4RhjB
UibITXf>TiRLW9^LWYnOX9nKUiJFUYBCTH^6QH9mNWIbLWEgMG9aLWIkPXN6Ph:2
PX1nOh20PH>2Q8R?U9JFUYFDSXR6RHj@SHR1OGQbJEiGEEEIG5YFDU=HGV9VJfmc
MWUkPXfIYjj^[:FSYZNVY:>QWijMVIJBSHR3PH61OgenOh23Q8V<SHnATI6BU9NL
X:>QW9F@S8Z:QhJ4Og]jMg=_JFEUHUM=BdiCG5iLFEMHFEULG5QHFEeQIFY/JVUZ
K6idO8:4Ph:6RXb>Si2AT8f5NgIbL6eVHf=PH6=SGeUDE5MLHFEXJW9kPHJ;TIJJ
X:FTXZBY[[2^Z:6NViRBSHf?T92>S8J2QH^=S8^<SI6EUiZNXZBSXjFY[ZfXY:>W
[[:e];:a[jb[ZZRUXIfGTXj<SXnCUi66NW5`L6i^KVi`LW=bK6ERI6IWJ6Y/M7f0
PXB6RHR6QHF;Si6CTY6AShQnMFeYJFUYJ6ITHf5PHfIXKW=eMGMiO867S8f=SHf>
Shf;R8F6Q860OGUeLgAeMGAbKVe`LWEgN7f1OW]jN7EfN7YmOgn1QHV9S8f>T96A
TI6DUIBDT8f<R81jNWeoOG=XI6EUHemNFUIBC4Q8BTQ1?3dm?d98CeAHGfEYKW5e
NhB=TI2@TYBCShb9QhZ9RHb=RXJ2PH21Og]jNX6;Si>EVJF/[Zn^/;>c^/?6bLc:
b<O6a<?:cL_6_[Jc]:nYZ:ZYYjJSWijMVYJHVi^HT8^;RXZ>THf;RHN6Q8F7QX=n
MW5ZHV=VJVm^K6]XIV1MGf1JEEACEEIEDU5DE5ADD4mBEEYMHfaaN7YhO8F8Rhf?
T9:DUYFBRhB5QhB4QHF7QH>3OGb2QHR5Ph>5Qh^<S8f<SY:DUY>BUINETY6DTi>H
VYRCSHf<S8j<T9NFUYNETi:AShR2OGYjNWYkOGehLfeXIf]^Kfm^KF]ZJfUUH65W
KFi]IemLFU]PHUmMFUUIFemOGf9NF5IEEUeWKWIlOh>2Q8^AVInQYjnc][Rg]:n/
Z:BQWYZFUiJDTi6?SHb=S8f=SHj@UYZKVYNDTi>CUIBEV9F?S8F2QXjDShZ8Q8B9
Si>FUYBCTi:DUI:?S8V;T96<PgmnOX:5Q8B6QhV:SHj:QXF7QWihNWf0Q8J6P7Qf
N7]gKf]WIV9PHEiJEeADDdi<DEMNHfEUJ6]]M7UfMW]nOh64QhV8PgemPH1lNgf0
QHZ6OgijNGf1QHB2Q8bFViVCShf?UIRJVYJCTI6?SY6ATYNLW9JASX^?UINHV9F@
T96BUYNETHZ3O7n4PWejMGAfMWAdLG1fNW]iMWMgNG]hMgf3Q8>0MgIjNgMfMGAd
Lg=bKf]VIV]ZJFYXJgAoQX>1QHN8RhfBTHf>T9:DUI27PX=nNWf3S92;Qh9iOHAm
N8F?SHf>R8^BRXR9PhF;SHb8RY2=QhR6QX^<SH^8QWiiOhB9S8N9THj8QH^?PWQk
NgQmQ8F0PhJ1Oh:2NGIjOGUfOhV4OGb1PgmnOGamNWYkMWEgLg1]KVmZJFa/IfAQ
GUiTJ6AWKW5gMgAhNgYjOXJ;SH^;SHj=Qh:2Q8=oPXN8R8V<ShQnPH:1Q8J5Qh^C
UiNBSHnBT8^8SY^PWYZCTIFETY2BU92>THj8R8V8QXB6Q8:8Rh^5PHB:SXIiMWMi
O7elNgQjPHB4QXN6RXV4QHbBSXAlOXN?UI^LTh^BVIFCTXj;RXYoLg9iO7Q_K6m`
Kfe/L7EhNh24Ph:1P8>2PGimPX1mNWMjO7MiOWj1P7ahO8J4QHf>RX^DVIBFV9>B
VIfKViZDTINLV9FDTI6EVIbJU8f5Oh24RHf;R8jAT8b<ShMmNGAlQHF5Q81oOWij
MgEdKVYZJVMWIfQVGeiTJEe?HW9UFUiPHFMXHf9UHeYCCTY@F5eQGEUIFfQdLFmc
O8F:R8V>RhjCS8J7PhB9RhZ9R8>4R8B2Ph64Q8F;Shf<S8j?SYBIVIFAShb>Uj2O
WZ2KV9RLWIZMWYR?QhR?UYnMViJ@U9NDThb5R8b7PH21PX62OgEcNG]iM7IlPHN5
Q8F0Q8Z9Q8N?TI:NYijEVIVGUY28PGekM79bJ6Y`LGAaHf1XMgUfOG^3TIFJWIZN
XYRDVI^IUIF@R8N:QH62PGeiMWJ0R85kNgQmPgn0RXR8S8V7SI6CUiRARi2@Ph64
PH20Pga]L75/MGj3P7f7SXb=Shb@WJ:GRH5mOGihM7YhMGQfMGEfN7UlO7=_LWMn
PhB8TXn4Rhb1O8F3OGQ]K6i[K6UJBdM4AT]4>CmCFEMGF65[KFUVK79_L7IeKfU[
MG]kQ8EgMW]oRi>ASHV<SX^=TiRJVj:XZ:Z][ZVOXJVWZKB^XZ2VZZ:HTHZ=SXV4
NW1]MgejMgEhOXB1MG5fOX60OGQjPH5mNWelOGejP85nOXJ?SXJ8Rh^>TYJFUI69
Qh^>RhJ4SI6:Q7mmO7mlMGIhMW=`LWYmMG5]L7UlP8B1NhJBShAoNWV2PGj5RHB2
RXZ;U9NIW9ZAT9F>Qi:JV9VARXN:V9F=QGj2S8j>RGYcNGajK6aeMW]mN828QHB2
OhN;R8F1PhfCSX=lPXV?Qg]kO7]mPH^CS8>6RXnHTHF0Pi6ESXF3Pgn:TH=lPGaj
Mg9aKFMPGfAPFemSHUeCBTY9BTmAEf5SHUmSK71fNWaoQi2NY9nPY:V^[Zn][:RW
ZJRRX9VCUYVOXIF:RY2GThj9QHfGTH^2LG1bKFaJDUM?AD8l>Ci7GHBag]VaTG1U
IfYZLWYhNH26P8:8QX>5PWQfNWUlQHj7O7mlQZ6d^l3<d/Bg_MCYm>[GbL[LfL32
e<J/XXiYAcM1DEe[KU0Q1aDcEWj>TYfCSZ6[YHeYJ8ZKTXQgH5AGDdi6A4a1<2e3
H6QLB3XjB5QIDUALIEiGFUA3=2`O5R4f?cT`<3iBFVE]JGnKXY5cSK:dc]c9]mco
`IWooon_foo]`jnbg?OC[]cb]IO5o?[Eb]c@d<VKTjf/YjJ9OIJFR81[HgMY@4IM
D4mHGVM_P964NgYUCdmTMFYNEU9NLVeGGFiTHfURJ7ajHfajRYF>RhbCPgQoT:VL
Ri:>Q7meK6QQE5mPC4E?EDU3@cXe>c<^=3Pe@EQMDTM1Be=:C65[MW=KI7=ND61O
G6UmRgefP8F=TifV/KB/];J`/JJDT8j8OX60PY>JT8j=TibMWK6iZJRWWHb7RXJF
Wi>IYJj^Z9fOYJNf^Jo8g<cAm??QfMOWk=S2`mCSl?glo>kLb]7A_Kg5fn7Db/O4
a<o=c<c6b/JjWI:DTh5gOWQhP8V=SHMoPh>0OhN9QGmaLFaPIV9ACTi1<Bd^=CXf
>3LX8B@Y:S<i91HC1`4@20000000000000000000000000002PlB5B8[6`H01aLL
8B`Z92D`=c<f@4QCGEmOH6IgQ8>>X::BSHjAWjjf^K:_[ZfhamG;`knmamkUeM[R
f/fj_<WDe<[Ad/W6e=o[l_;goooooooooooooooooooojMcZoOWZd/GHim6neMRc
Zk_>dmWVfl_6`lW8_Jj`]Zna_L?1/IV9Qh]lK8:?NV=/SH^2RhR7OFUGG6MVKFe[
HEABAdUAEEM9@4i7<2LL4al/8QT>1Pl?3B@e<Ci8C4]3ADQ<CDe5=CLo?bdP9BlW
7AdF3`X500L>3QTY>2hS7AdY<STi>C`h=SY3E5YGDTA8F6=QD4eMI6M[GTiCFEQU
KgJ1P7aoTZFSV9ZKWj^ja<No^lS1]k^]/;fm_Kk3_/76`l>j/:^c^;2e`L_=c]KK
g^Cdoogfoooom?Klooolk>GWflkDfL^oa][Qb[k9g^WLd/_3b]CCaKk=f=_>bM;B
c<_LiNOUi^WAZ9^W/JR=Q9JIU9N@T::XYinHWYV@Ui9kP8F5S8N0OH60M6ERI61Q
E5MOEda<DT4j@EEHBTU1?dE9Ef=I=1PV@4]7?RlX<2TO5`L00000000000000000
00L?4PP36c@a9R`^9bT`=c`n>D=9@3i6EV]/GeEDHW1dLGEiNgf0SiJEU9:GXZj`
/;F[Y:JZ/l2[OWJ5PGmnMGakOY>IUinW[kBl^;:e^l6nYIZdblS1_lO>cMGBaLG8
_jbESj>]W9FAQi2PVX^<VZ^`/<2jWiZTX9FCVjJYWi:JXYR2OH^JVXn?Wj6FUiVM
XIR9OWYoS9:BV9N:Ogn;S81jQXI`J6efOWUaL6aUHEIKKVUPLhZ4P89iMgAcLFUT
GUYED6IlN7^1O7b0IDeHIV9JJGE_J5e>C5=3=cTh@48h=cD]<D5EF4a;De=HHfi`
EDECEdiIHUaIEUIKGV1MFfb6Q7UoRiNJSHnV]KZeYZc4bl?4`[c1`L[8ZJB`]KFe
YXnJ/kRd`KnQVjN__mOJakRmalFj/JFIXZb][;:m^KC2eMBn/kW3`[c4dm_C^ZZZ
ZZb^`MCAb;ZUViRJUINJRH:FZZVAQhfAVIRLVi>@UZJWUi2FU8UmLG5mPWmaIWB2
NVQECV9bL6AFCUUTK6eRFT]1AeELGU]ADV=QDE1GFV5WHfecKW5bP::RPWanOW]c
KUmHI5Xg82@]:Bda=CDS7QhR;2PW:blnD5IJHfYPAdE=D6I]IE]LH5iJB45<EVEZ
IW21TibESh^;UHn;UY><S9BMUHJ4Q8nMZ;Re[k[0]:nbZZNPTHb8OH2GYIjERWYo
S8b=V:Re_<35`;k:clo:`/G>e]?1]:j]/:fUYKG0]:BSZ;:j^ZRP]KnhZZ2NXJ>P
TgQ/MG^5RXR0OHV?Q7IYJW5^I5iXJFIYK7b6NF]XLGihKV]QFUiWJ5I9D69dNgig
L6YUI65PF51BFV]_GT]5B5MRGEEEHgb;T9JFT8nHQfYD@da@BSXT;dA4;Q/N9c<c
<3e2?DiOHEYDF69^LWF0QXF4JTm:E65RHg>4SXj:UJjn]jZJUijQ[:B?S8alJUiK
KG]jO8FEX9ZJY:J[ZIjMYZ^V//35bL>h[:^`[JVga/2a/;6^][o0`knf/[2a/jRN
XIfEUYBLXjNZ[:ZGSiR/]:RR[[^aVhf>Rga]KGAoQXImNXElIF9_Q8UnNWj6Shf8
RHB;U8QgKgIgMhbOWXakOWI`MGN0Q820Ng9aJfEZLF1AEEe^L61PI5A3?D9?DE5G
EUmXHVIXG5m]OYZQSHVJXZ6EOWMlKUaNJVecMVMEGg=aIVE/L7B0RH5^HfETHV=T
IV]_LGMeLH2FYK6`Z:>NX9fAR8V;PFa/Q9RJUiZPWinOYJVTXYfMY:bkalBcYjff
`l[7c<o9al_FfMG>`Kg4b/K;emK@e]gCal2_[l33^KJeZJJ[Zjjc^[jh/[Zm^;6X
WI2:RhF3Sj:SW9^MWYVFWZ6JSH5kMFieRYNCP7=hP8F8PgUoPgY_HUEFG5MEE5IP
HVYmOW9cLFM^MFeUEdA3B44nBe==CUYMDDYAEDLk=C@g>CHe=3iFHf5RMH6=WI:9
QgIQHgI^Dde??2i1Cd<mADDm=2dV9c<l@38I2`H51@<03QT@52Hh?DE;D6IaH4]=
FeaHHUiAHWanL7>0QXjETHN:VIN@TiB=OgAdMGV9TINGS8^ATHfAUXZ0QY^OU9BE
U9nV[KJaVXZ@T8Z=TYFHU8f?UijOW9>8Q8J6PhJ<TI^WZJZXZ:^[[JRWZ9RAV9nX
[ZRU/l2o[jNYWiNRYJ:RT868TiB;P7aoOgafOXb;Qh9cKWQmPHN;U:F[ViFIR8>@
T8R;T8b5QXR5TZ6RUH=jMGaoO7M[KVeSJgElRYN[]9nLXXI]K6ULBC4T;dYNI6I`
LVa^ITP^;cTh>Cha:C<nADeLHemSKVm/NH62S92?SIBPUI2BSYNNVIRS/[>//[Vl
aLW4`;:PWZ2JVjBUXZBTYJ:SXj2WYj6VZj>OXJ6QXIjLY:R[^/C9e=7>emC6aL[=
c/[4`L74bmGDd=7Eem?7][2e/:Z/ZZ:OXYbFWjBUZZbXXiNCVYbMVXj=SHJ8QWmm
OGEYHVEdQh]iIfamQhJ2M6ETIFIYJVidM7QjO8B>SWeeNgYkNG=gNWn5Q8:0Q8Uj
L79_KfEHE4e5AUIVK7bDWY1nMFmYHT/_:ce9@U5VGUEHFeYJF59>B4@j<C@g<b`Y
;SLoA4=<Gee?CUYOHFUODE5A@SU:IW1aMg9^MWUaJgEiLGMjLG1hM6a]If5SGeMM
LXVETXn=Rh^1Mgf9S8f4MGF8Wk2i^kRi`]7EdM3@d]34_/?4a<O@eLoDg=C5_KJb
/jnXWY:4MW1bPHV2PHJ2OhB8SHQlMG=dKVi^KG=bL7N3R8bBSY2KXjJIQH65P7]d
LG^2QH9lP8B1P864Og=^JFioSHikJFI]Nh9gKVaTGUaNJG9bJF=WJfESIVabQJW2
b;NWZib6MFa]FdI8EVb6QWYoRHZ8P75RG61OEEACCDY>G6MbO7f2S96BV9nGRH5k
NG]jNWUbL6m_OXN4PhN:ShUoN6YPI6YYJ6mcK6idM7f@WIbIY:bTTXV=U9>?SY6N
ZJjd][Ji_;bk^:nYYjfaYYjSXYVHW9bIViRBTY2CU8j0LgIoQ8AmKfEUH5MMKGI_
J6=MHVe[L7UhMVe[LGR1QXB1OWj0OX63O7=]KF]SHfYcN7AePH9gLg9`K6IUHVAW
GEUMHFQSEU=?AdQDJWEYJWMcHUUFF6A]IF5cQi2BW;W>akVYW9ZDNFIXI69UIVih
PH1gNh9lL6IKEdm8ATA8@S8dAdmFHVmcKFM/N8>3P85nLf]ZKg^1OH>AShR?U9FH
VijOVY6?TiJITh^@UI^NXJN[[:VWZJj`ZZ6OYZVWZ[Bj`<gAcL[?d]7=c/_4`kno
_kg0bM3<aKZ^Z:RVZJZTWIJGWjJSVI:;OWb0RHb7QXZ7PXV=T928Oh6@TXJ3RY>G
TXfEW9VBRhEnNWEbLgAdKFY/M7amOGadKg1aLGAfLFmbL71eMW=]JFiaIfI^L79^
KgI`LgU`JVMYKg=nT9JIZ[Fj^[6PVXinKEmQI6UbMGIcM7UhLf]RDTQ:C4];ATE9
A4=:EEiOH6A/LFmWIFm`Jf5RJfe`MW^4SINMVIBARXbETXMoO7b1PX::TXn?TY>C
V9nMW:FTWJ2VXYRASHN=XZb_^Knh[[:j^;>]ZJ2GV:6^];>c][Re[jZXXYnKV9ZI
Uhj4O7b4RhEiMWn>U9B?R8J4OgUiOhB7RHJ2P8>4RYFFShnBUI6:Q7n4QWieLWEb
KfiaLgEfLVi^LW=aKFANFUUNG5]MH6=KGFEQEdm;BdiAG6AUK6ALGeePIfafOHfO
Z:BFU8Y_HU]>?Ca3A4aADUEJGE16A3dd;C0b=3D]:RX^=Sa<EeaSIF9PH5]FEe]Q
IF1JG6UfOHRHWYfHTHV6RHZ8QX5lOXF7Qhf>QWmmPHN;Shn?U9bQW966Oh><VZF[
/kRla/_:b<6i/jbc_/C9a;F]ZJ>RYJJY[K2`/K>_YJ6PW9NEUYJJWIF@TiNIViZH
WJBTW9^QXIfHU92?TiNHVIbRYZ:LViZHTY2ATY24N7IhN7V5T9FDSHb:PG]iLFmb
MGEdNh>2OginP7moPW]aLWR5SXJ2OGIgMh6BUibQY[2c][f/SHR7N6eVIfYZMWej
NgenOWY/GeQ>A3do@C`m@dM<Ce9FFUmRIFIVI6EXIFIYIV5KFf1XLgb0PX:0NG9`
Kf]YKW5XHV1TIf=SJ6UWK7MlO7enOGEdMgEfMgb2RYJIUiJHWJ:Z[Jba^K^d/:bY
Y9bHUYFJX:2MWYnMVYRBRXN;Shb8QhR5PX1lOX:6Rhn@Shb:R8F6QGelPH1nPHN7
P7YlOg]fLVm/JFERIfi^KF]YJV]^LgQgLFm_J5iKHVU[JFQQGfU`M7=dP8V2OH1n
N7=fMVaaOGekPHbAU::XWZZj^KR]XYjFTXAdNGn2UJ2IVZ>WX9>?Pg9/J6IYJV]W
HUaHGVIVHF9YL7MnO7A`KFMWJFU/M7j5S96HVIB?TIFCSX^>TY6ATi:;QXR<RXV;
RXjHVifQX9bHUIJCSi:EUYRMYZb][jjZZJV[/[Fh^[F^Yj2NWINBT8nAU9^RX9^I
VIJEUIF@RXF3QXZ>SXjCUIRPXijGTXn<SHn<S92BTiBCSi2EW9nMVIBEUI6?S8Z5
OWf0PXJ<SHZ7P7UdKVMRH69YK6UVHfAZKFm`JfQYJfaXIfmbLWAeNH23RHf=SXbG
Zj^SX9Z@P7EeLFidNh24NgMoP7acKfmYGeYFEU]NG5UABd]AFF9]MGI`JFIVJFe/
JfeaM7EhOX>8RXR5P7]gMgMhO7ilO7mnOWmoNgQfMGIjOhB8SHj=S8^5OWn6SI>E
Ti6CV9^OXjJ[[k2_/;6]ZJFKSGifMWn<SXb:RXZ7R8b9OW1TGEaMH6MaMWMgMgIg
NWalN7EbK6a[I69WJf]WIFAVK71cN7amO7UcL6m/J6I[KFIRIFadO7ioOGQ`If9Q
H69VIFAXJfe`N7eoPWmmPH>0OgmlO822Ph5oQXV<VYfKXYjGUi:8O7=eMgV3Rhf=
RHB3RY:DShIkM7AcKf]WHf=WJVQVJFi`LFiXHU]GEUIFEeMJGV9XKW9hOW]gMGAe
NGmoOGf3RHfATiFEUIBATiFFUiZPYjb/[:nc/K2a[jj_/;6a/[Jk_Kk1a/K4`l2l
]kNi^KRd[k2d]kJa[jb/[Zj^[JNSYZJPVIFHW9REU9JIWJ2QX9jLVIF@RHB3PWmj
MWIiOH65R8EnMW9`KW1cLg9dMG9]Jf]^LgQjNWamO7M_JFMWIVAXKFi^KfiZIVU_
L71/I5iNHfMZK6i/K6e^LWEkPX:1OGQ`IF1PI6Y`MWIfN7UjNGMfMG9]JFY^LgEf
NG]iN7UhM79fNWYgMWEaJfEQFE9AEEiVJfe`L6m^KF]WIfa]JVU^Mgf1PGmlNWYk
NgMdMGMiNWYiMgQkO7akNWMbKF]^MWj5R8R7QX:0PH>3Q8>5QhZ?TiJBRhR4Ogj4
TIbSY:6PXJ:RXJ:PWYfLV9FFUibRXI^EUYZMXJJWXinLW9bKWJ6UYZFRX9jMViZF
U9NHUI>>RHR<Shb7Ph:4QhR:RhZ:RXZ9PWUcLgAeM7AhOGajNgYiNX25QHF5PhB8
Rhf;QX:5Rhb8Q8>4Q8=oNGIgNgemPHN8QXJ4Ph5mNWIdMgYiMG5`LgMhN7EaL75c
M7EfMgA]IV9SI6Q]LWEgN7QgNGf3QGmfL79fNh>8R8R:SY6BV:2TXijIUiNIW9nO
W9^LVIFDUIVOXj6LVijNWYnMViZGUIJHW9jNW9VHUi>?SiFGTXV3P7j2RI2AT92=
RXV:SYBFUI:>S8^=TYBETi6?S8^;RXEoNgUhMG9bM7UoPGmjMgQfLW=jQ8V7Pgml
NWYjMg=cMGYoP7eiMG9]IUiGE5AHG61SIfY/K6eaM75]JFY`L6]VJW5dMG5/IF=W
KGAiOGekNWUfLgAiOX61P7n1PX1jMG=dL6UUIF9JEeQHF5YKFEIEEe]MFeMCDDm<
C4mDEEEEEUQLGf5QHfEWJV]XIfQ[LGMmQ8R<Si6CTY2;QXF9RhV:SY6?SHj@TI2@
TYBFVI^LWjFYYYnJVYnRX:6VZjj]ZJJVYjNPUY2>T96AU9JFU96=RXN<UIVHThn>
TI:@Shj=S8f>Shn?SX^7Q81lO7n6SHj:QX5lNWYjNGQgMGAgN7YmO7QcKfa/M7j2
PGimO7j2QHN7Qh9iLFi_LGAgMgEdMGQmPX>2PX:2PH21QHN:SXj:QhF6R8^>SHb=
RhR3PhJ9RHN2P865R8^?Ti:BTY>EV9RHUiFDUIVKVIJCTYBEUiZKVIJCTY2=SYBJ
WIZFTi>FVYfMVIFCShf?TiNIVinPWYfLViZHUiFBTI6DVYnRY:BUZ:VWYJJYZZFQ
X9jMW9^GU9FGVIZFT8b:QhF5Q8:5QhF0NgUgM71/JfaZJ6a`L6aXIfMVIfIUIVY^
M7IcKfe^Kg1_JfQZJfYYJVi`L6eWI6=PG5UJH6AWJ6MZK6mdM7=dMWQmPX>0NWQd
Kfe]KVaTGEYLGEeKE4a9CU=EEUMIEe9;ADA6AdI6A4E9Ce=HG5eMFUECEUQHEUEE
FEaPIVacNWeiNG]lNgamOgejNW]nPHB6RXZ7QX^BUYNHVY^JUI6CVIjPY:RZZZ^/
[:bZZJZZYIfJWJ:UZJb^[JVVZ:jc]KJd/:^VYJFW[K6_[:^[[K2d]KB^YjBRXj:R
YJVZYZ6NWIjNW9ZGThn?S8N2O7E]JFYZJVeaLW5eNGQfMGEeLg1]K6UXJFUZK6i_
L71`Lg]oOWYiNGUhN7MgNgekNWYnQH^@TYFETXf7Q8:1PXJ;SXf=TIJHV9VHUI:=
RXb?Sh^:R8AlO81mMWInOgn1PHB8QX5kLV]^MGQgN7UhN7E^KG5dM71/KWIkNGUk
NW]iM7=dLWIlOX:4QH1jNgakPHN7R8N4PhF8QX>6R8=iMGMjPhZ5Ogn0QHR6RI:C
THf9RXf>SXb;RXb=QX>:UI^LUi2@T9>GUYJFVIbIUiVMWYjMWifHVYZFUYZIUI2:
Ph64PWj2Pg]hNgajN7IdLViYJVi/J6ITIFERHVIZKg=aKVe`LW1/J6QVIFASHV9P
H6EXJ6ETI6AYKg=bL6i^KVa]Kg1`LG5^KVm_LGAgM6e[Jfa]KFicN7]kN7YnP7ae
L6m^JVAQI6MXJV]XIVAWJF]`KFEXKg1fO8::S8Z9T9^QX:2NTHV=SXb?UIZKViB<
S8nCTiJFTY6<RhjDVY^JUYFCTHf;TIJCSXj>RhZ<RhZ:RHN5R92DTXn<S8j<S9:K
WYfRXYbKWJ2TZ:bZX9^LWIjLVIVES8R:TIbQW92<U9JDU9BGUiJIViZCSHnBS8B2
QH^@Ti>;QXR5QHb>RhJ3PX=nNgYiNgf0OWQkPWmhN824PWmoPH62Ph5oPHJ<TYFI
VI>=RhR6R8^=RXN8QhF8SXf7PX:9RHF6RY:?QX>4QHJ8PG]lOh23Qh^7OGMgMW9^
K6YVIVUYJFU[KG5bLW1]K6ibNGejNGIaLgIjPh^>Rh5kO7aeLWAfM6iZJW1kPXB3
Ph9nNgUnR8b>RXR8PG^0S8j<PWQiNWUhMgn5QXJ8QHF:R8AoOX64R8J1PHJ7Q8F6
Ph5oO7]mPhR7P865QH>3P7M`NX=jL6iaLG9aJVM/K6QVIfYUGeYEFEeKFf1VI5Q@
DEEKGf1RGVEWGV1PI6APG5aKGF9ZKfaaMgYlNH2:RXZ?SXb8QHV>U9^RY9^IW9ZB
Shj9RXf;RXb?U9FGU8V8SI6CTiZIVIN@SXn?S8N6Rhj>T96BTHj=SXjBW9jGUHf<
SXJ4QXjGTHJ3Q8F8SiFJWIZFTXf<S92ETi6@TiJJY:FRYJNSVIBEUYVOZ:NRVIJD
TiRJV9^CU9J=SH^AVHB2QHb@RI6GX9bLW9:@V9B;SXQnOG^5P7n5R8AlQH5mPhZ>
Qh26PWajM7EgNhF5RHj?THb2O7]nO7AeNH>6PX63QXZ2Ngb8ShN0PG]gM6iZJVi[
K7QlMG9/KFY]LFe^LGAdMW=fNGEbLW5bNX1hLG5eMG5[JW5cMG=^NGYgMFe_LW]m
P7ijMg1eMFmaNW]`JfiaKVecLFegOWUeMgf1PH62Q8F5PGUnSi>=PWYgLGMkMGYh
Lfm^KW5fOhN6T9RHTi2CTiFHUINMYZJRYJbUV9NGVIZNZZ^//Z^QX9nOXjFRVZ2Q
WibFV9FAQgmkNgj0P7UmPGajMgIgN7EaK6aaKVa_KVYZJ5mHE59=CU]OFEYOH5mJ
EUMJFeEFG5]IFfE/JFANGfEYLWamPhAkMgIdLg=iOGn1Qh^9Rhf9QH62RHV@T8R>
THnBTHZ6PWj0OX2;S8j?RH^<SHf9R8^:Q8VBRhF8TI:5NgimO7UeNgikNgj1QHIn
MGUjQ8n5PG]aJfYZHf5TJgEgMWZ1RXj7N6EYLg=kPXF4R8N7RHJ<SXJ8RhfCU9FJ
W:6WY9fKVYnTXZbm_kN/[;Jd[:BTYZBTYZ:RYj^ZZK6XVifKVifSZJf]Zjn`[:NU
YjRTX:6X/K>h_;:YYJJY[:FNVXn>Thf@UYVKViVGUiRITXV5PgilNgI^J6Q`MGA^
JFe`Jf=PHV=VIFIWI65OG6EYHUeGEdi;F6EVHfIVI6AVHfIZKVaUIfAWJ6QQGf9W
M7MdLg1eOGmoPHN?Rh>4R8Z;RG]dLFaWIV1PI6EYK7=bK6ahQX9dJVU[KVmcMgen
NGUlOGimNG=/IW1jNGEbLgUlNg=_O866T9VHW:6KTX^5QX1fKVIUJVeaLFicM6eV
IVY]MGQaLgUoP7ikNgIaL7MnO7AhRYJCQWakPHfDV9bMV9:DVJ2QW9^LVj>_];>^
Zj^WYj2GTiBHWJFWXijFTXZ5R8V;T92:R8N6Q7mkOWaiNGf0Q8AlMG9dLFIQIVYV
IF]bLg1ZJ7=gK61PIg9oPXB=SXR3QHR:S8N9Qh63SI^JUHMnO7QcKgIoRiFGV9ZE
THanMG9`LG9cL7IoP7EYIVYYJ6AQIFaeKf9KGfAUJg5bJVQbPiBKUi:DTHQoQ8nH
ViNCTYFATIRQXYbLVYRBTif[/ZRQXZNXY9nLZ;Bc[JbWY:>OW9BDVjBZYIjNWifD
SXb<TYJHUYbX[ZVNVIR@TYfSW929RXf>Q7E_LG9_K6ebMgamPHB0N6e/KWIiMW1X
HV1VKFeVHVIWIV5NH6YbM7AgOW]iN6iYJVibM7EaKgAgN7QkPXZ<RX^AW9jIUYJA
Rhb<R7mkOH^IUh]oOH:6OWA_KWAmQXfCU8n7Q8J6QGmgLFi]MGeiLgAfMgYeKVe`
MGAgPhj?SHElLgAnQhZ2M6a/LG9^JfQVIEiIGVU_JFQZJ6I]LgAcIf5ZL6UNF5UO
I6AMHFafOGmoNgM_JF]aMg]mNgUhNH>:S8f>TYFEUYBAW:VXYZNVXj:RVYFIXjNX
ZJFSYJNTWIF?U9^KV9fQVI2@T8V6QHB6PWeoR8j<PgehNh1gJFE`N7eoOW]cL6m`
LgYoPX9kMg]oP8J2OGYfLFeWJgQmO7MgNX28Shb0P8B5QhV7PX>6QXB4PhJ6PH69
RhB2PG]eO867QW]eMWioOGf0QY6ISH:8SY>EThn8QHR9QH>0Oh5oNWj2Q8N5PHN>
UYN>Rhb@TY6=SYJIVIF:PhVBVYnNUXR0OWj4SY>DTHfEXZJUY9nGUIJNYZFNVZB`
/jRHRXNAUXn9R8f@T9BETYNHTHb7PHN?RH>0O7UiN7McM7UgLfm`MgilMGAbLgUi
LFMWKW5fLfYOFUeNHfU^M7AiQHnEUH]oLFIVJW1ZHVAcPHB1LFE/N7e`IVAVK7Ak
O7b0P7aiNHBBTHIoP8F1P7icKgAhMgEbKW5fMWYoQ8F7S8F3R8Z<Si65MgAcLG=h
LfEOIVidMfmUFe9BHG5eKVERI6IWH5MGGV=PFEYQJW1hMfiVHfEUIW1lQHAkMgan
Oh>1O82>W:N/ZZV//K>_ZjJUZjn/YjRVYZb_[JZXWIFO[k2/[:ZVYZFMV9F>SiNO
W9B@Si:LWI25PhJ6Q7n0Q8J8RHV5Oh5oM71iRI:BSX^;SHj:PgUfNgmnN7AcO8B3
OgehLW9cKVUWIVI[JfMSHeiNL7UeKV]THFEZKg9[FU5JIVaaKfU]N7Y_JW1dN7al
OhJ>SY>IVInXYYJ9S9FIU8ImO820NgE^L7n@V9>7P826RHZ;SXf<SHR4PXB8RhEj
MW9bNHF:RXnBT8fDWJ>SV8jDXJFVYYnJXJZTVYVHTXb7PhF:QhB:Si:GWYB1OXbI
XIn@PX21P85mN7ImQ8J9R8N:SXn;R8B4QHZ>T9BIViNHUi25O7j5SY2DUiNKY[6d
[:6NXjJUYj:JUIVISXV;R89nO7YiO863QH9nPXIjKW:0R8QlJEmQJg1^I5MFGF5Q
HF1MGEaKFEiUJ6]YIF9/LVi_LgMfM7AgO7QbKFUTHfU_Jf9NH6A/MgU/GeYIEeAD
F5]LFUYGEUYLEdi8BeUOETiCGVQYHUQBFEiQGeUGGV]`LG9dM7Z3Qh^@Ti2DUhj8
RXf;SiRIUI>EVIbMWJ>VX9ZMX9fMWIREVJ2NVIJFU92:QXfAT92?SXfDVIF>RXnG
U8AdN8F>TY6>SI:GVIRBSi:KWibFTi6AUiVOXj6PWYR>Ri2CTYRKThZ8QhVBVinK
U8^?W::QWiZBSY2<P7^0PH9oMgInPGejO7YkPhJ1OH::U9VAS8jCTXj5NWAfNWQf
MGR1SI6@TI2=S8Z9RHnFVinNVYVJU92ASX=mOh61QHR9RXR7SIFCRXN4OWf7Rh^;
S8f>RH1mPX9oP7a`J6ibK6QZLWUgJV5XMXF=S7a`KVmXH5eJHfe^KFmaJfQ/K6YZ
Kg=hNWYnPX24SXn4NGMeMGUnPhF3PhbFUiBGUI>HWIfHV9ZNXj2FUIRHU968OX>?
TX^7RXnBSH9mPh^?Rh9iN8:5Ph1lNgj0NWAdLFMUKFi]LGIfMW9[IVATJ71cLG=i
NgYnPG]aJVM/KVaXIFAYLgYeK6Y[KFaYIVM[J6EPFEQSKf]OG6A]Lg9]KGEnP85i
KV]bNWIaKFmhOWf1RX^;U9bHUIZRY:>OVI6<R8bEV9>@THj;U9VESX^>TI2;Pgn1
PXJ9QH21QhZ8PgmmNgQfMWA`LgekLg1gP7mgJfI[LGEgMg9eP8F0NGMlQh^;Si>?
S92GVIZQY:6PWIJ@TYJOZZVNUi:=T9ZNUhj;RHjFV9NETXn?TXb5QHR:RX^8QXV;
RhZ3OX:7PWn:VJ:TX9^KYJf]YYV?Si>ARX>2RY:CTi>ASHZ>THb:Si2?Shb3Oh62
QXAlNGUhMGR4QX1nOGYlOgmjN7AfOhF1P8N8QhN9Q8:6QX>0O7f6QWU`LG^0Ph1j
OXZCUY23N7MlNVaOGfAZLgUiM6YUI69OHfebMGYhL6]`NX21P7YaI5mYMWM`K6]]
MGf3QhR9Rhn>R8R@U9JIV9BDVIRCT8Z:SXf2O8B?UI:;PH28T9BETHb=Thf2PhZ<
Rh^9QH61PXB5PX:6QhJ5PgYdLg9aM7^0P7enPh^<QWmlNgeoOgahMgMiNgUiNgQb
Kf]VJ6e]J65MHFMUG5IJHV=PFE1@FF9VI5YADe]HE5EGF5aRIFAXJf]^KfmePX^A
UI68QHbCTiFMWYVEUYbTZ:FRX9fIVIZIV9VKVYFATYBDUI::Ph64QX5kOXF;RH1k
P8V>SXQmMWMjOG]bK71bKFUYJFQ_MgUhMgIeO823RXj<RHN5P8>=ShfAUi>:R8N:
S8Z6QXR;T9JGU9>EUI:>SHnDV9^IUI:EW9fFTI6BU9:=SIFPYj^ZYJBX/;FaZZR/
[JJSYZFTYJFUYJFSWijJVIbRYJBTW9:CUHn9TYVCRH5oP8F7QHN7Q8B6Pgn3RX^8
PgilOX5oO7UfNhB5OWQjOh9oMVmcNX23Q81lP8R;Pg]gMW=]IfAQGV1UJ6Y[JVEN
FEEEFEeSI65OJG5bMh25P7UeLW=fMG9bLW1`Lg5/KW=hNgn0PHJ;SXn>S8nEThV2
PH:8RhZ6QHR;Shn7OGaoO7UiNWakNWUiN7EeMWE`LG9`L75aKg1cM6aSHVEUHVA]
LW5aMGZ1QHF5QXJ7S92=RH^=S8V6PhF;TI6:QH>9T8Z1Oh:4PgmgLWEjOX:2NWQn
PGYeN7amOGYgMGEfNGj0PhJ6OWYoPhVCWj6KUiJDTI2FWinHT8fAUi^IUi>@TYBC
SHV>TiB@S8Z;TIB;OG1[KW=aJfU[KW1aL6mbMGEfKfIVLGQdLG1`Kfm[I69RI6Q^
LGAkOG]jNgQfOXB1Ngj3QhV<TIRITh^4Og]lOgagMgj6Qh9oP8:0O7]hN829RH>0
PXJ8Pg]gMWIeLfm^KgAlPX1nPhZ:Q8>7RY2CTXf:RX^@UYZLWYjLWYfFUZ:/ZjNU
Xj2NX:Na]:bUXYnOY:FOVINIVibMWjFWXYVCTIFKW9F<RXjEUi>AUYZJUY>CU9JL
XIjFTiVNViRFUI6ATHf5OgakOGn0Ph=kLFYMDU9IGEiRIFATI6UbNgY`J6AXL7Uk
MWAhOWmlMG1`LW9bLWInQhZ5PH>6RXV0N7QoQHV;S8^AVifDQgmmOWmnOWj5S8n:
PWelOWn1Q8N8RHV4OGZ1QX=mNW]gKfYZLGMeKVUWIVQ^L6a/L79fN7UlPXR9QX9k
MGIeL6YZKg1]IV1RJFUTGUI@E5mQFeMHGV5PFeMGG69XJVIRGeiOI6]^L6m/JFQ/
M7f3R8jATHn?TYZRY:6PWYnUZj^XZZj`/;2_/;:c[j^//;Rl^:VMV9FBSXF2RY6D
Ti:<R8b>QWikN7UnOGYkOX62OG9TGeeHF5iQHF=TH5eMH6IYJ6Y`MgMfMGZ3RHV4
NgAbLgEcLG5eNg]gMGIjNgUeM7IoQXF0PHJ@UHf3PXR>TY:7Ng^4R8B4QHZBUYFE
V9bNWIbIUYZGUYbXZZV^ZijLWI^NYJNWZJbVWIfNX:RXWI:>UIVJVI:>RhB0OhB;
Si2>Pg]nPH1hM6iXKWMlOgiiOXN5Ng9dOX>6QWn2S8j<QhV>T96ATYJHThb<U9^T
Xi^EShf9PgajPHb?RhZ@U9JHUI6=QhJ6PgelPhjCTXb3PXV4NWMiPXV@Sh5jP89l
LV]XJGAmOGYgOHJ8QX1iMg=[J6Y_NH:2NWAdK65RIf]aMW]lMFi]Kfm_JfMXJVIS
I6ATGeM@C4U7B4a>DeYQG55?FFYcM6mYK7ImOW]]IG1iN7EdM7UoQ81hM7Z2QH=o
OhR7OgmkN7n1Ogn0QH9kO7ejMWAiOga_IFM`LgImNWQiO7amRHj5OW^1SI2=RHR?
Ti6<RXnKYJ:IUYRQ[:bPTi6ETXf:PWYoQh^=SHb=TiREU9ROY::MVj>`[IbARXR3
N75_M8:>Ti>>R8>1Qhb<UJ6TWibQZ[:_YIRASi2EUiJGYK2]XYJCWJ2DRh5jOhB7
Qh66UZ2JShn>SXj:R8IoP8AmL6miLfASI6EZLgikJV5WKg5eOGIYKhB:NFaYK7Mn
QXn@RHN;RXJ6RHN3PhF0O7f0QXMoPXZ5SYNBRhR6R8f=Q7aeKf]]MWYbKH6=PGAe
NWeoNGIgLgQnKfAcPWmhOXAoMVY]MWAdNh>:QWn3MfejP7QYJG9_KGB0OgalMFmc
OGmjMGYlOH>8RHJ2PXF5OGj?Si2CTXn8QGifNHB<S9BKYZVLVinDTIJKX9>2PHVG
WYFAT9BEPGIiP8VKZ9fATYRGTiJASYVJSHR@UiVDTY:?PGb;RH63QiJCOhB?R8F6
QXN:TijIRhJ8QGA`KfQcPWEZMGAdNVm`Lfe[I6Q[IF9LF5QLFEA?CTe5CEMFFV=/
K69CBe=NHf9MGfY/Ig1oOW=lPWagNginTIf>QiVXYZ6JQGVAX9bGTY>:Phj;PG]i
MW=dNFmVKGQcJFacQXJ0MWJ9TXb6QHJ?T7YIB4M8BD8gCg26UI^MS79`OgYhPF]Q
Ni2JVIROV8fEShfPYHj7SYn^/InBUI:;PX>9RYfl^j>IXJN[]JjEPWUbK6EUJGV;
QX6;UXigKVm]M8fX/JJCSY6>RGioR92?RX=iQZ6XWiRCVI^9RI:OYIJMWYZJU9ZH
PiRn`l>hZJfSTJ:STi2BZkF[YXmnUJfTSHn[]Jj^[[[5^Jf`YIB3Q8Q]O95dJFiN
IgUbMWB6RUA:OFmLF3U4FEU?:Q`mH7=QCT]HJ5iGHUmKIFMVIg^7JTYEIeeYNFAJ
J8NMSW=dOH1kMhfFO6igT:BAQXIkPi:1NHNIVWV7U7j:QFmeOgQTHgB:QXJ<Q8An
NWYnKV9SJFEZTYQaK7ihLX5oL7N1PYjZM66CW8>=UHn6Qh:1T[Fn[j>@SYZBV[>[
VYZQVi>>UIBCPVYWGV9/L7UhMUYAHU9EEVMfBU=kI3AOY64dMiUe=ciLMXj3NWQn
KXjfT5eFRjVNX[G?g]Fh^=c7SXBFYKJVWZbf]9JG]Hn5NDm]Y:bYSFaiPGiaHClf
EFafJEiOIVmjR75IH5Y8B61SGVaYCdQEDUELEd]QK6n0NVa`QIjQPFahUJNZWGb4
[ZRGUi^/^ZF:S8n<VZR;R9F=SY29VZbVZJJ/SX^b/jZDRHR5Q7mdNGm_MFUHKWV3
THV6UiF>U8nGSW^;W9J]/9bAW;JLLhoA_geYNlG2Q8nPV7N1YXMDBUJ2TXRE[HQS
TjaoKgUlYKbGVZNNPFF3RgUnVXb2QV58@fYVBF9aOXj;P7R4Mfj4TgU:AF=W>1@X
9a@bCTTP>DLk@SmHLH=dJHjJQ75ePWUQKi^1KgAgV:nHK7JGWYBIRVYcTX]kOf]J
IGRKTGjCTIjSVJ2i/YZU^KJ@Qi5lP8fHSGMmYKb=PZ6eYik3_ZnO[kRHVY>JVHV=
RiB>UkNkZXnAWjbSR9RTX::PU86Q^JJPYJJZ_kFQ[[Zk/[JWVJ6RThN0PIB=FeAm
ShEnJd<lDVQPD5ADFDTZ9SMUK5YFC4YCJVUWI5iRCD]FDeY`Nf][LFeeQYZ?QiF=
SYn`^i^A^[RHY9]`JGQhMVmG?4MTGdA8De=MKW1HF660QfaIDTi==R`X92`X92`Z
<d=8E4LeB5e9B4lf<CY2AD=NNGUiLgV>Uj2a[[:_^M?DakJ]]l2c[lC6/KVi`moQ
j^gNhn3Le/GDem3Da:>=P86=P7^:VIR:N820O85kNFiWOg]FEW9lKEmVNfigSI:X
YhanR9bGTHnBTHbUZi:GViRKVIJMZKF[Zlk5YJRe`L6mYI6FWZbMV[G4[Wb0WiMm
JEiYLh>FRg:3X9N<Q7R:YJFGVk2/WJBHPVi;=b`_=c0lDdTmBe=:@SLmATMLEdAC
GfAKE4Lh>S<R3Q@fEg9hI661OV1YQ79AHU92B51[PHR0SJ:ERjN]YK6l]jnb^;NV
Uhn1OgabL7UlMGR:SYfcXiJGWYbIWI=iMWQ_JgIdM7AcNH1nKWV;NgNCTI>FUI1o
MgmmPiBHU9Z[/lK<`/o=`=?McJfb`;>WV8ZE[JJ@Q8EhLh:FVHN8UIF?RYBHSGEJ
JG5SGgV=OFYXHf5IGW9OB6nAOX2<PHNMV8fG]LK;dLNn`L2JNGj5Mf9DHGEnQg=H
LGmODUIAGVa?@V5fLEa=BeiXD3a1@cm5CF1YL71/LVEFBd0k<CHd:2HdBdYCHVE/
K72;W9>LXHn:W[2]TGAoU8I/KX65Tk:[W:bfa/^gZk>iZj:XZIJ1LgN1MfEUJFb4
RWUnS89dL6Q`O6U<E6IRET=6F6UkLWnT];:RWIbFVYRASHF8QW61ThjSX8R2M7:;
WYnPVj2^XIbWW9FS[ZnPWJbSXJjh_J6@XJFSYJ6V/lkZh/k=eMCC`;K1^:j^WY6B
W:>EOGf?Sh5jOViMEUIPG44Y<SPX:C/l@T@o?4MBB4eRKWf9O5eOOHb4IU9QO8In
MgE]LXnMTHbFXJRd`L6j`<_;b[^SZ:^KUjJ^VHVAW9NEW:JXWY68OgEaMWMaNX1c
JfYWLgQ]MGadIdaAMGUXHUYHFeEBCeEPHFQ_NHV5OHJDY9V1RIjVUhF;UY>@Vj2I
TiJHSgn1R7maJV5HDeIYPgm^N7EdNfiMFFI/LW9RFfA[HfQ]GeY[Ng]oQhVCVXaj
KUho>DYHJ6EKEVJ0P7^6PVMXO81nKUM@Ff5OHf1@BC/^:2Q3F65XJG2M_kRaYZ^c
Z9R0Kgf@WJ^URi2RY:F]Zjfc[Zf_YYZRZj:R/[2PWjVZZ:fRTiBMXjZ/W8V>Wif7
Mg1/L6i^JfQbLG=mNX2EU8F6SInTSWMdLf]bOh1/GFj1Q8V9PhNCWZFTUI6LX:>T
XZ^[ZK^[TYnX/;o4^[2^Z:RYVHb;S7UVKG=bKVAQMXIdHFI_JWV;TZJQS8nQ]/33
bKn`/jb2IFacK5YAF65YIF=`NXfDPgZ0SYjLOVEHAd17BdLd8R`j=3Dk@452D59K
KgekMgYaLFYDD5m^Kfm/KGElTYbHY[k5`;nl]JJBU9nRVhb4QGiiQX^:RXVG/<3<
dkjY/;o4^IAnQhn7N7A]HF=`KfihQinUZJnVVHj9T9ZFVYF1OWU`MFiUIFIZLh:7
R85eM8:7PH5mNX1mOHR2M7N9TXZ=SHB1S:B_X92?RH>8RGi`KW=eM7]jKFM`QH]j
JFnC[Jbic<W2/jFBK5m[GTY9ADE7ATI5@TICHEa@EV9QEEMIB4eRGe0h:3Dm<30j
>SDlE6ijO7ajMVmZJfMSK6UWJfmfM7B4Si6O//3;en;E`LG8]ZfWWJBSVhn3R96G
UI6FVIfOWZJ_[Jbc[If;OX9iIfALCDaBBd0f>EIZK6=SJfQXLgj5PgeiMgMmOWMe
PH9gOHJ8Si2?X[:b[jFJVj>ZZJFWVYVSWiRIXInHWJb^YZ6W]kVd_/W9^jJZ/Yf8
PX:3QhV2NH^W/KNd[[6_/l2fWiVHTh5^IeiLJUa9CdeGJg9/IgEoMVMOF5]OETi<
CU=LIfQNDd]1@e5YOh>6TiVKX:6JQ7QmNW1YIVYjQhfAS9:V_LW5`L;8b;feYibP
WiZERhInMGQgMGn1NGIhPH9hNh5kM7V0Qh5gLFMWK6a/KFY[LWM`Jf]VIV]cN7E]
MXR0NGinNX:GWYJJY9fDSYNOQWEoRI:MVYJHVYV@PWEfP8N8QWebLgN1R7mfNhbD
S8F2R9NGRH1hL6maM6aTMHfAS8fHXiZDXIV2O7mlKf]^I5iUGeADE5=PLVaTLgU[
JViTDD51DE=GFde5Cf=_JVE/KWEoNgb2PX64S9NHUZ>OQg9PGVU]I5UNLW^5VYjR
^/Vo^;^i]kg6b<:bXibDQgeoQXbCVIF;Ri:HUIFJUHj<R8R=RH1nOWEYGeIAD5Y]
LfQSIV9PJg5WI6icKV]YJGN5O7MmPXF4R8^8RIBIVYJ3P8jFWZBQU8bHX8e_G5aW
K6e`N81kNXB9RY6EVjVZX:2VYZZ_[J2DU9FDUY^U//?<`kRf[::NUY2=QWe`IV]`
LW=aL6]SGeUEFeaEF61ICe1<@D9@F5MHFE9AGVY_KFMWLWU_IF]jSIjWYZ:SXInQ
W8f6TI61O8VBVZf`[[S5akfmalc@fMC6a<BfYZN^ZJN_ZYnNXZ:ITHR1PHN=QgYb
NhN<QgUlShefJ6ARIVY[HeQKHVELCU5MH65WIV1NGV9/Ohf?SXf:RY>KU8Z<THZ4
RHR2QXb9Q7]`L6YOI7AnP8>5Q7eiPhZ>QWUgNWMbN7ihLGZ4Mg1kNW9eQ8fFViBE
Wif@S8Z4PWebHem[KVMNEeIFFUYEFg1iLGAjLFQYHdi0?3Xk?d53CE5CF5aTJgB5
RG]aLWMnRY6EX:RPSH:1PW]]IVUgOgakPHN?WZRVY;70a/S9c]??`:nSW9bQY:2C
RXjGU92DUIROXInMWYbCS96:PXj>Ph9kLW1`LGA`LGAcMgA]Jfm`LWEdLW=kOG^3
RHB1PGmlPH1bJg=nOGZ1Si:?TIJHUY>4KFAYJ6M]MX23OGE_M8^ESYVZ/K6TVijS
Z:^VUHJ6Si2;SY6P/JVFTiVEUINDRXF;RX5hMgM^I5eHC4E;CTa@FFUgMFi^JF=U
IfUVHFmlLF5QJg1YI6ISHFE/LWMlR9VMSh^GWIV;N79lQXJ6OWZ1SIFCT9BGVZ2V
[K:f_lO:`KRi/JBNXZV[YZ2ERGmiO7mkNGioNWQjQHnFWj2GShUnKf]jRHQoMWQg
JfIaM79iNW5/KgR0QiJX/ZjUX9ZIUH^9TI^MUi6;QXj@SHf5P8>5Ph60Q85lO7MX
HVIZKfeXKGf8PGZ2RHR9RGecMWQgMGA`KG9eKfU/KGJ0Ogn:UYVNWiZFRh1aH69V
HV1MG5iULGIaLW=]Kg9bN8>>Thj7PGQjQX1hNWYdKg1]K7Z9RXB5P7b4QGU/Kh:=
QGAYJFm]HfAVIVQ/L71aMH6<U923PhJ2PX::VIbIVYJGWiN=TIJJUhn:PGf:V9bN
VY2:Qh9lOhZAShb9P7ioMfaTG5IJHEmOJ6iaNhAoNH28PgimNg^0QXN7S8b0MGEm
Q7Y[JFQRH6QbOGifLFeTFe]SLGMnSY>AUIRGTXb;RX:0QXR3PhB8T96CTHZ8QHJ@
V9^U[K2d^/:o^;6TX9fKSgafMGZ:RW5RHemHFF5VK7n:QhB3Q8N7NWAgNGQdLG5]
KW9ZIg=kNgQeLfaVKWUkMW1dPX=nQHjGWIVIX:FZ[:R]]:n[YIfGV:Fb/K6f/[2e
/jb]/[Vg]KF[ZK2ZZ;Fl]ZZNV9JKX9jKVYfJUIF>PGIcMWQ_HfMfOgioPGefMG9[
JVMRHfI[KVaXHEE=EF9ZJV9NIF]]K6][LGEgN75ZJFI[MGUgLg5iPH5oNg]mN7Ac
LW=cLFeVHfibIf9SI6YfO7AaN7emM6UVJ6abN7n0O827RY2FTX^6OgUaLW]lO7im
O7EVGFAZJfmbLW=iQXf<RHB4S8b8Qh5mMg1`LWAaIEiRIfaaLGN3R8fETi6DVZ6W
[J^GQXN<TIJKWYRBTI2DWIZCTI6EU8R1RYNMX9fBRi:IUY:ATiRGTi2?SH9bJf]]
LWEcMh>=TYJFUI^JSXZ=SHF1RiNITXMnMg1cOXAmM75dO8B6OgMfMgAaKfYZMW]l
PX>3Qhj?QWmoQ8F8TINGVYjLUIJNXYN3O821PXB1QXb;TXmjLWUnOWQhOW]fM6m_
M71WH5mTK7R2RHnBTj2XW8f8RXn@RXB0Q8ImNGaiLVi_LWMjNgQcLFMSKFYNGEmL
EeeYK6QZL6iYJ6U`MWQiLfa/K6iaLgQlNGMlP7moPh5oQXZ7OWQnR8V2OgmkNWn3
P7]hMgf:Ti6>SHb9R9:Q[:f_/kFd/Jf[ZjRUWYZJVIfU[JjUVI>?SHnFWZNWWIbM
WZ2OVIJGU8f5Ng9]JfYYKGAlPHF5Q8N8RI2FUY:=RhR3P864Nf]WJFUZKgMiN7f3
Ph21P7j1QHV:RXIhJ6M^L6YOGfQ]LGMeLGQnO7YeKg5hP8>7S9FSZj^NTiBCUI^H
UYF@RX1gM7AeL6QVJg=dLgR0R8N0OGMaLg^1O7IaJF1DCeIUKfaYJfU[M7UeLgEg
N7MaJfQVIFE[KVigP7n1Rhb9RXZ8PWefKFa[KGR5R8F9SI2GVI^SZ9jCUinPY:JS
XY^BShj<SYNJTi2DV9^KTH5jP89mOWegKfaaN7j3PX67QH67RhR5Qhj?RXj?R8N6
R96?R8R;SXj?TiFHUi2@SXfEV9JGV9>:QGe^HVE`MGEcMWioPXV?UI:=TI6<Pg]o
Ph1iLgA`K6iZHV5]N7j4SHj8RHb8RHZ5PgmjNWUgM71`Jf5MH5eIFUiUL7UjLVid
NX29RhAiMGIeNX64OgIcNWa`If]`KFU/L79dMWIbLGUnPHB5QhZ=TI6GY:VWYIjI
VYZGTY:EU9ZRWIFIWZ:UX9fQXifFUZ2XYijBS8jGWIZDShj@THb1NWQbKgEfLgIh
NGn7RXb>TYRKWI^IUXN1QhEoOH24PH:7RHfBU9F>Q8RDUYB?R8AoOG]kMVeYI65W
LGEeNH61OXF6OgYbKFU]MgUlPH1gKg1bL6]WJGF2R8UnKfMZLWAaKG5gNWf6RhZ@
UIRITH^=SXZ0MWQkLfYWI69XJVM/MGUeMgimNgimMVaXIV9SHf9YKFQVJVYQF5QL
GEeNFEMHEUYRIfabM7MiOhJ8QXJ9RHB2QXEnO7j2Q81nPHF9TijOXJ2JVYfPYjRO
V9RFT8R4QXN7QHF9TIRKVYVKVifSYJZa/Z^QVIVLWj2HS8Z@TYBFT8bDXInHVIbK
VZ6RWjFQU8b7QXnGU96CWZ:MWI^GU9>CRX5mMFeaLW1kPGilOh1kOhR9RXR2QHIf
IEiMI6ERHV5RI6Q^MWj7QhB5PhJFWY^OYJRTU8B4PgI]I61SIFadLVe^LG=gNgUg
OXN6Q8V?RX5hJf9OEe1?CTmGHV=HDE1EG65OF5IKG5aVM7amO7aoQHN3PhB0PhV7
Ph>9TYFFUI:JYjFPZJjXZ:^[Z:FOW9fMW::_/jb[];B_[Zf/ZJNTVi6>SI:IVi^K
VIFBTY>CU9NBRhjATY24NGYnOWehKVU]KgA`JgInMfmZJF]WJFiZJF]ZK6QWKW5a
KfALFEUTK71jPHR;R8AjKg5fLg1^L71[IfIYKf]PGV=WKG5fOHNDUI6BSXR6QXZ=
Rhf>SI2@RXEkKFATHf1MG5iUKG5dMWMiOX1lNWj2PH1mMFaRGEeLHFESGU]KH6QZ
K6iXH5m/MGQkO7j6S96BSHfCTXV3P861PXB8RX9hMGn=U9>AVjN//kk3`lC0^K>c
][Zl^KVm^[Jh^K^n`L6j/:VUYZZ_/ZbWYZFTXj:MVYB;RHR3OgUgOH:5QHJ<TY^T
X9bGUY^@O7UfKFa^JfEOG5]HF5aMHFYeOhB3NgAaLWEhOGe]GV5OG6ESGF1JEfAc
OH64SI6?TY2;R863Si>>TiZKVi^HSGY[HemSIEiNH5mUKWAbLFmZIVAVK79fMG5_
JEiIFUaFCe5CCDiHFeQKHFAVJg1cLgAcLW=aMWegM7Z1QXF5RHZ?VZ2OVIJKWYbL
X:6IV:Bb^/G>blC7c<Bm_kZ`[[>^YJBVYJBYZInLX9bKWYfLWIZCSHV2P81hLFaY
JVMYK6]aNWakN7MhN7agJ5iMG5YQJFMYMGIgQ8V3OX65Ri>GV9^TZk2c[:VVXjNX
YYnCShn>TXb8QWaiPHV?TiBASHb6OGf1P7b1Rhb8RHV6P7IWETY6ATA1@3dk?3Xn
@418BTY?DEEKGUeLGeeHDda8BDY5@T=5BTi@DeMMHV5UKW9cMGQlPHJ=TYF@RY2C
RhV>Sh^9S8IgLgMgN7UjP8VDWJF]]KRh]k2WX9VGUiFDV9VHUiJKXZJXXijRYZbc
]KZn_;Ja[ZNMTXN1Q8R6Q8R:QhbKXYnPXInJUI6<RHZ5OX66PX60O7YkPX=lNh63
Q8Z>SY>ERWj0Q868TYFDRhN:QhImMWn4PHJ>TiFJXj>V/;:c^KNa/KF_Xj2OUXV3
NFYKC451A4=5ATU>DUIIEeYKEE9CDTa:BDQ7B4M1>SXm@DeDE5aUIVI/LWEiOGmn
PXZ<T9BFUYB@T9BCShf>U9VOYJJWZZRSY:RXY:BUYjb][[>h^;6VW9NDS8N7SIFG
VYfMX:R_[jbZZjVUYZV[ZZFPW9N<QXR8Q8>3PXF9SY6CUINCQGimMVaWIF5SKW5a
NWU^K6MKE5UNH6Q^JVQaO8:>V9ZLW9B<QgieKVMJDDm@EEMDFEmTKg^2Q8J:Rhj=
R8V<RX1hNG=YIVAJC4A2@CdjAEMQKG^8TiZOW9:?ShEgJee>A3`d=CXf<3@k@DYC
FF5_MG=oRhR2OWUcKFQPG61TJ6mcMgf8TIBKXZBWZk:i^K:_/:fWYZRXZJRUXZ2M
V9VLVI>BU9>CUibT/;_0`/K8a/2g[jZVXIbMXJ:X]lK@eMOEclc<bl>j/jJERGm_
GUEFFUmXKWAoQHB4SI67OG=VHUiHEe]NFeaMFUaTHfE]LGEfNH25SI:BUIRDTiBE
Ui^KWjNVWj2TX9RFTXQnN75_LF]QGEaFDE=FD4Y<C4U=E5EGG5Q>ACld9alJ5alX
:B`g@e9PLX26RXn@UY^HTi6ASHV7Q81nOWioQ8b>SY:EUIJIVYfRY:RWZkFi_/?0
^kNc[ZFPVI:@RHF6PhR<SXn@UIF=RhZ4PhN;RXR9Q8:6P7UiMW5`NGn1R8jAVYnL
VibMWIjOWYnITYJLWj6LUYBGVYNCU9JLXJ:Z[JNOV9>9P7I[IEaFFeI9BT]=EUmY
MhJBW:Zm`[g3a;fdZIb>OfiOFUUFC4eEF61]NhVFXjf_]KR^XYJ6L5]7<b8K4P/A
7RTc@E1HH6Y^L7EhMgIdL6iaLg5aMGEdN7UcKW1bLgZ5SiJLY:Z`^Ko1a;ndZj>H
S7e/H5iSHf9]NHFCVj6WZJ^YYZFPW9ZEThb0NG=[IfY]KFi`KGAoQHjKXZZc^;>Y
XIZFTHYnL69HEUUPI6YgPXV>TiVLVYF<QX9jM6eWHUeLGEeNI71nT9fOWIjU/;Fj
`LkRh=CAc;nTRGMXE4<f=Cdk>3e9DeQXNGj5Th]gKVaKBD8k<Rha91<H6Q<F9Blj
C5ADGg1dMH:=SI:HU9>ETHAkOWMZKGMnRYZX/L3Ce]WUinKYi=G7_[>PViJ=SY:G
UiBDUYNKYZf_][Nd]kRaZJBOVIZJTHN3PGmoQ8F6TIbQZ:nd][JaXIF?QWmlNWYg
Mg]oQ8R=U9jSXJ:X[:FPWIB<RXR7QH65QXB2OgahLfm_LWb4SIRT]/O<dNGYg=SG
c;>KSWQC<aD000000a8Q:cM1?3]:B3@_=2lV8R<L61lN4a<E3PhG728dAEI]RijZ
^lO:`[:RUhb5O75^KFicN8BDYko=d<k:c<o>bl6aXIJARgi[GeU@CUIKIWAfLGN5
SHV=Wj^^[:JOV9F@SXn<RXb?TYRTZZV`/jNNWijFTY:@RH:2Q8F=V9VFTH^4PH>6
QX><V9RIXZj/Z:FIU9B7MG5]G59=BdM=GF9YMWE[N9JX]m;^l^3DaZjCKe4m8Q@:
1ADN7bH^@UYZMhBDZJZDRH9nOWEYHEE;@30V9BT^=4=GMIJY/[o<d]?Ab;RTV8]l
LF]XIVmoS9RV/K[3aLC5`;Nh`KfdZYnGT8IlLFMNG6=^MWn7SYROZ:^Z[kJg/:fW
VXj<SXnATI>JUh^3QHV;SY2FXZ^YZ:NUYZNOT7]SCC/b=Sm2AU1HH6U/KVYUK7Af
OhB5RHV6OGQiL75nO7j2QIfZ]<SKl??Zl>kLbK>LO54f91<:00003A080PPE9ce0
@UIJDe9DFEMAAC8^<24C6bPc@UUhVL?RinCSgmG4]:RSY9bCT8Z6QX=jMX2<ShnC
VIVEW9nNXj:FRgmbJVAHC4mLIWB6TYJMYZ^b_lgEfn3Le]C?akfeZi^?Qg]aKFe`
MGEkRINKW9bHShZ9QH>1OganQHF3Q8B2OgakP8ZBWJVXYZJTYJFQUhN1P7UbLFi^
LgAgP8B7R8bU`]GWkoSoonWD/XmT@3DV8RdV9Rd^>dI5ATiVO7j4R7agNgMbJUiG
BS`_8RH];SU?Ih>J[;F`YijCSY:KY:RVX9^CQGAVGeeQJ6moS9FPYjFRY:>WZIj8
MFIGC4iFEUIIFUiMEE1CGfj1V:R`][NbZZ:OWIVETI:CTiJESHZ@V9^NYjj[X9J?
RHB7R8R8Q7igM71[HUeXLgYnPXEmMG5/IV9VJFa[H5aOGUYLIVaaQXj5SZ6e`mGh
oooooogUb:^:GSX/92LZ7alS7QXD2`/I<DI7EVUXIEiCDEILFDi@F5QUMX:H[/CH
i_;il^KJc/oBe=cLdl:ZTWUVFTa5AdaAEUmVJ6MSGeeNGV5WKFe[JfUYK6meOHND
Vj6^_/kIioOooookkn3Ec<6m_l6n]ZNKT8InNW=^MGj0NWQgMG5YIVMTH5Q@CE1G
GF=_Mh2<TI:EUiJGW9jNWYnITY:<QXB2QXZ?VInSWiBDUI2@Tine`/;1a;FEO6M>
<QlK4PT?4Ph>4aDM92XhC65YL8:;S96=NF]UH5ADF4i>EE=CG6YdNHF>R8>7RHbD
WinDRgmYETe7@DEAEf1^KfeeOH26TYJFWZBNV9NBS8b>S8Z7QXfFUYbY/kJi_kni
^[N/X966PGU`IF=XIF5PHFE`P8J<Uj2UYZFSXInKWJ2SWINFUIZOXj:OY:NUYjZU
XZ6NVYNIU8N2P8:7RXn;R92EUY^DUZ6MVYBAVibMZkkKmOO]jn;>^9j<N6ALD4<`
4P0000001QHP;d15E6IVHEeCDTi<CdmHFUILIW1iQIBT/;^l^;fj^Kfm_KFTTGQR
ETe9A3m0A4E4B4aAFF=XKWEgNgmlMWIiNgUfM7UmOXB9U9jW/KRl_l?3_;N`Zj^/
Yj6PVH^2PGn0Q8R;S8f?U9>>T8f5PH>7QX1iLFe`M7N0Ri2CU9>EVYnX];g6cM7=
`[VbXj2RV9BGVHA^LFYMEeYYJ7:0KFR2VkS;bM7JbkJGOfe8>Sh^9ah600013aHU
<cUEK7>2RXF6RXf:NX29Ph9dKGIkQ8bDYKBo`kN/ZjZZ[:VSV8A[Cc/a:2HX9bda
=CY1BeETL7^:VZVb/:j^[JVSW9fSZ::NX:6RZK:h_;o4alG1_kVc/k2ZYIjFT8^8
R8B0NGMjOGn3RHjEUYJBRXN9RX1mPGmgL7=gLW1aLWIkOWimPHN:Shj7QHF4PX20
Q89jLVa^L7=gNH63Mg5cNG]jR:K2f=cAe]O7[Y20Lf5A?blR3`00000000`M=UMT
IV]ZIf]bLVaZLGA`KUmEGfaaN8NK[K:`/KW5a/2aXIN;OG1WGU97?RhO8BP[=dQI
JH6IX:Vla;fd^knk_;R^[[2/Y:Ja[jjc][g2^k2ZZZVRXJ6GRWeaIV5XL79hO7ak
Nh68RXb>TYRLWIbJW9fHTXj;SYFMXj>RXIjMW9bKVIRETHj>RHB3Q8Z9QhZ8RXn;
P7inOGedLWYiP8F:UIjjf>_Zgn7OgMC1[IB1KEQ6=BD;00001P`?73A<FV5UJfmd
NgeiOWieJEmJDe5HGfIbP8^EVibNXjZXZJbVUX=eKFMTGEABEEA>BdeKKh6;TIfT
X9^GThV2O7=/JVebMGIjPh^CX:^e^kjn_;o0^[:[YYnFR7YbL6URG5QEEUmWL7^4
QX:1O7UnQHj@SXf8QHF3PGikO7f1R8f@T92ATHf0N7EdLg5fNWf1OWUiOhV?S8n@
RI6CRhn:R92<TiNUa/Ng[j:GQg=XFDU=Bchi90h500086cI1DW62SYNDTY>O];Bc
][:e[9:0N7YlNh:9RhnATY>GVYJ@RH9kLfYRGEYCAchk?45=FFMhSZ6Y[[Fl`/71
aLW?d<Ro]Jj[ZZnc]l36bm3BeLg0]jZPVI27NFYTH5I>CE1CDU5HIgN2RYFPYJJS
X:2SYjRYZZNUXjBUYZFNVYZIV9FAS8N2O7E]K6][JV]_Kf]WJ6]]LFiYJ6=WK6Yc
M6EYKFQ]LhNW`m[MfmWB`:VJPfeQEDln;A40000000H@6RhkATY=CTmPL6eVJfe^
LFiYHVQeNh6<VJbh_lcCdlno[jBEQg=^KUiDDdLe;C8e=d]RKGV7QgamRI>GUYBD
UYJDTX^4QhR:T9jZ[KS4a/G7al:oaLC0`lK1]JZQUXj8Q85mP8bBTYFEV9RIW9VF
VYbOXZ2OVXn>Shn=RHR;SY2>R8N8RHjIXZN[[JVTXIfHTHb6PXR8PWmmNWE/IfUU
IVUYNHNAXkC2aLFmZJRTViJ7OFaLF4P_500000XC7bTc?D9:Ce9KI6Q`MG=^J6EP
G5]BDUYLI71gP8ZGWY^MWYjJT8f;QG]]H5I=@CLd=Sm;GG>5TIFDTI6HXk2i_;fj
]ZjRThN6RXnFX:JX[Jf[Zjnb/:f^/;2]YIV;Q85oOWekN7n?VjB_]JjQUi2;Rhj;
R8f8N6]UGEYTKW5]Jfa]LgZ0RHn:RXf>U9NIUHf9OGEjO7]lOh1mNWMaLgQfNgae
N7Y`L7R2R8jWamoMbl_Ee/N/VhQ^GE17>RPA00003b0W;caBGeeQI6E`O8B7R8f?
TI66PXnET8Z8TIfZ[JBRYZ>HRh>4QhEfJVUYIU]AD5IPIFUbPi>LX:B_^Kjl][Fh
_Kfl^KJa[:NRYjj`/KBh]JbLSH^AUiZIU8]lKfa]L7MhMgAdNGf2R8nBSHV4Ogn4
SI>FUi6:RHZ;SY>GUY:@Shb:S8Z6PginNWIbKViYHUiGCd]9BU1EEUMOIF=TIVe[
KGQcL79kSIVhf]oA_[k0_[NXUgmbIE51:1TC20LE:2PM9Sa8DFAYHFIfOX27RH5l
NFUPKganPXbFX[Jm^KFd];:aXY28N6AIF595>BTJ6AhW=DEDHFmdL6idOh^EVYNG
V9JDUI^U/[_0`lC9d^7/knoWe/Fk][Bf/JJMUXj6PX60Q8Z>SXb;QhF9SHn>S8N4
P821Q8V:S9>KY:Z`]K_0`knf/Jf[ZZVXY9bESXjDUiNHUiFBRgmmO79UG5aIEeeK
E5eVHeiSI5iQMY:cf^S9]Kk3_ZnRSgI^J5I9<0d010/I:c8W7SM>DUmTFEYSJ6MX
LWEfNFUHFEYEEE]ZOHnERX67RhZ:QhN:QWacLg9SEdm:BTi@C4mNK79^IV1RLH6<
UIZHU96?S96HVYNHXZ^][jn`/kZn^;:c/k:d/::HTGmaMGeeL7j6QhfEUIFR[K2n
c<g3_KZbZJ>LTHb;Rhb;Ri68N79bMGEfNG9/Kg5dMGQgL6eaM7EmQXB1R9NTZ:NR
W9RETXj@TXV0OHNSa=?0/Kc7`:fGOVIDASPZ4P0000004RPZ:d1EGfUaLGJ:Wj6G
ShR8RHEmPY2CRXB=X[[7b<?0_;>QRgikMVeQETXh91@@7c4l?dQLLGj4QHR@WZ^a
[jVSWYjQXInNX:Fa`m?HfMSFeM76^k>XWIB=PgUdKVMTIFYcOXV?UJ6XZ:JPW9bM
XJ>SWYR?RHJ5Q8B9TYNGThb2NgQhMFm[IV5NFeeSI6=TK79`KVm`LFm`L6e`KfUW
KWEgNGQgMWV4RiBT`^7Pa[Rl_:fDPGMQBSdd;ah<0@0373Dl?4APM7YoN6YTIFed
LFm/JfeSFV5aNWUnS9bX[JNHTYJ@Og1[IUeDCDiEETa2@TYDG65[OI2LX9fJX[:l
`<;5aLC1`<2n_Ko0a<oFe=3<b<Bi[JJSXj>RWiVAR7acLGAiOXJ=TYFMZ[Be/kJl
`/C3_[RaYifGT8R3Q8AnOGinNWYmP7imOWb1QHF0O7Q_JVYYJg9eLW9hMGAiNWQd
Lg9_Jf=RJf]XKWN1Tk;0[IfY/JJIR7]_Ge13?Bl?00002BHi=3I9GFUaMW1cP8N=
RWmiLfeQEUMNHfIYLXRKY:>LUYNIThAhMWA]HUQ?@3@];SQ4CUUZP9>RYZ:PX:NY
ZZVRWIRCUIB@SHfFX;2oalc9`k^`Y9>5QH1aLWUcHemRGVUnRI:T[:>U];FY[K:T
VIZFS8^@RXJ;R8B<UibMY:n`[:JKUY:<Qh1gKV]^If1RJGJ0S9BDUinWZJFQVHb9
RXB3PgUgMGMjNXNDZ/gSgLO0`lFnZ9B4KeeAASLT6QLG93Y;C4]DIGR6SHV2PHF<
SXV2OgYbKficNGUhNXNGXZ:HRXJ7OfiRHfMSFE9?C4M4A4YBDe1?GG5jNWMeMWb6
SY:EV9ZJVI^JV9ZNYJf_/JfWXj:LThV0O7b2QXF5QHB4PGikOhF8RXfASXb7Og]m
Ogn0PXR9QhF7SYBEUYVLX:FSVYBBTi6:Ph22PH64QXJ2OWahNX63Ph>0P820P7j0
PhB7R81mOh61P8B<W;?6d<g4`lG9a;FOQG=VG4P_6`/001DU;SQ3BUEVKF]VIFio
SXE`I5UBCUANGUiUK75gQ92?S8jDU8YmM6]VHE]HE4]1?D=9D5]WMXNAV9nY/[[2
`k^e/ZjYYjNXYJ:SZK>ob]KRj>WSgmO=`Kbg[9jFTHInOh:7SiBDVJ:XZ:^_[JJP
VI>DUHb7PhB:RHB4RY6HX:VZXinJU8n;QGmhKVQSHV1MGFM`MGAdN7YkNgQaKFYX
I5iUJVifMWMkOHNH/<[FcL6k/k2OQG5OCd0a7@D0000011HY>d17EfUaLG5eLg9_
I5aFDEEKGV9YLG=lRij[[ZfSWYfCQWYcKVMODD8k>d5:E5mXL7Z5S9:DUIFHV9>B
UiZKVYRIVIVLXZnk^kg5a;jl_kF[/kJZXYfCSHR8PWj3P7j4RXb=TI::PWmjMW=d
NGn3OWj4Q821SI:BUi^PX9ZBRHF2NgYgKfUSHfQ_LW=hO7mmO7amPX5kMG9bKVaa
NhJ?UYJNZ[G3dnS^iNGRe<c6]jJ@OVYGAC8W8b4R;C@k@T=9D61bMGAhMGN1QhJ6
QX9kOH1kNX65R8jEWIZETI2EThf7PGajM6aZJF]]KVUWJVigPHV>SXn>SHjAUIJE
T8b:RHf>TIFEVYnOWInRYJBSY::HSXf<R89kMGIcJF=TJVmcMWQhNGj2QHbBT8b:
Rh^6PH26RHV:SHn=RXf@T8j:RX^6P89mMGIdKVaYHf=WK79jOWemOXB7QXnES8B9
TI:=U:Ba^<71_kJVZ[2XVHIdHDa0=28G5Q`P7R@_=CTmBf9/Jg1kQY2BTI2>SHZ2
NG9ePhb>TiB?S8j;RXf=Q7igM85mGU]VATIRE5IXJWMjNXZATXf:SXnFWIVGUHn<
U9fQ[kk4a/WEg=[Lf/_5^JRUVHf:P7UhMgYgMhFAU9FGTY2DV9B7OGYkMG=cK6ml
Q8J>VZBWZ[2h^ZjVX9NBT8IfJfaWH5mNIVIVKW5hQ8>4R8R5Ph9iLg5]LGYmOHJF
Y:nlaLNn_L:j/J26MF=:=2@D20/H82@c?DAHHfIeP7ahNh5nM7IiKfQUHVEWKgZ1
RY:GVi^EShf7OG=XFeA>@Cdj=3DmA4UGKGb5SiVOW9VCRX=kM79cK6YcKfUfRiBT
^<;=e]?AbL6l]K:gY8n=R8^:Q8F=UYfNVIVMXZ2BRX=oMfYWIVIVK6eVLH>:T9j]
/;jm/;k0[ZFTVHYnLV9KH65SJfQQJW]jLGf7QHZ@S8J4OgYiOX:6UjVb`M?IgMW;
b/o:[I2:PFYGBT<Y93L[8cI9EU]NIG1jPGUYJGAaJVQXLG=]LGN4T8bAWJR[Y:jf
YIFBT8f4NW]bIV9QHfEXKgB2UIjRYjBSZ:2MY:FTXYbCT926Q8jFXJ:MZ[Fe/k6a
]JRKV9B@SHN2OGAfOg]iOGmoO7aiMV]KEeeUIEMGHf1^T7]YOhZ;NGb<SYF@MG9k
LFMZLWA/KWf4MW:6Ti:DRWj3P7inNgilI5e[K6A/O8ZBVk6h[ZRJRhEkJ5E0;R4=
2@P000003QD[ADIBI7AkL6ehMFQKC5EMDUmOFf9SL8B<V:Nc_;bZUi^MTHb8P7af
K6=OGf9YLgZ6UJ2_]jne`Kfe^;jcW9bTUhnFShf?UjRRX:R]/:fWZk6mb<;;g^;M
bKB^ZZBOZ;:lalS5_;FUSXF>UHEjOWmeLGMeLGnAUINO[k6ZYj:GSiBHUXb;UI>:
TIjGT9bSWIN8QhUgJfe_KgZ0MGZGY:6KWkK0^:bQX9^1JeM6>B/W:BTY<C0Z=DQE
FF9^LgEkPhEmOHAjIEiOGfEdNG=jSHf<VJ:FTInHOG1WFD`n=cDe<bX/=SQ>Gf1[
PYJBS9JKU9:AT8j5QHZ7R8Z8SXf7SijNVYnOX9J3M7b>S7ahOh:0LV]cMg]oO7R9
VY:;ShV7QH5kNXN;QWmoS92:QhJ;Qgf1SHIbLgUhLFQ]O89hNXREWYV=SIZMTXbA
RX23R8R3OHJDVIfQ/loHf>3Ka[>e/iIjLFU:9b@Z:2DR92La>49MJ61VM7E/K6EG
GF9FBe9[MGJ0OH>EWZ2OVZ6^ZYnJUXMfLgI]FE=HFEQXNh62PGj4TYRLWj6[ZZFT
VYbUXi^HUiZX/kFc/[Jj^JfSZK6^Y9R@S8^3LWR2OWMiN8:CTXZ<SIBDRhV2OWf2
RXZ=Ui:6RI2BQg5[M7MeN7Q[GEM=CF5]L7IfQi^HVZJTWIfQWiRLZZZSXjZ`[:N/
Z:^f^l76`kJ[WHegGDP_8Ad<00000P047ble@DUCJ7b2MG1eLg5TEf9]J65OJ7Ej
NGIkNWMmOWQbL6e_KfEF@dA=AdE>De]SIF=SLgiiN7V4U9B?U9fOXjBUZjff^l79
c]SKe]WLfMK?aL>l^KR_[JbSVIFNXibDU9RFUI69P8:3N7UmQXj>TIVW^Kfg];[?
e<Vm^kNVXZBPTHZ>Q7EnQgijO7edJW1mQ8=nPh>3QhbKYJni^;k?i?3`jn;Fe=WH
`:6BPVYOG5UCBT4l@4A;EUYLGfQeO7enNgj3PX5fKGF1PGj1TjFRVXf6SHYhK6ML
D4i?AC]1AdI1?TQAF5aKI71dLgAdK6ERJ6EHDEYQG5YMIVi/K75fNGUiMGAdL6QM
EeAGHFEJEEYLFfE[JFAJGfMTGeYIF59=CDe;BdmBEEAFHVi/J6]]Kg5^K7=gMG5`
KfUQGEYBDEIMIF9SJFYZJFYbMW=kQXJ3RI^SXjf`];N_ZjRQWHieKFYPE4E3?3Po
?S]?GeUDFF]eKfibLW9[L7QgNH28T9NLWJ2Z[ZJTZZbRWin?Q8V5L6EiRXZ:TIfT
YZ^_/[:a^;N]];Na/;:cZjbcZ:6a`lS3aLoBdmGAd=;;bM3Gf<o3a<2e/KNe[KC6
c/c>f=[@`kVe[jNMVIfRVXn?U9ZOYJ6PZkS0`lK6^:BNW9JCU9ROWi^LY:fXXZbd
_/Bg/K:e_;F/[JRTZ:bf_;c2`lBjYJ:ORG=TH5eABTXk:RX_>S@]?4E9C5ESGUMO
GeQDDEMOHF1VJfMVL7AaO8EhJfmgLemACTm;>RX/=cLa<3U8DEYNGemPGV1XKF][
JVUZI5mWMWEbLg>1U9fOWJ2ZZJNVY:BSVXf3PX5hLW5_M7E`MGb1Ph1nNgQjNGAa
KVIOF55BEU]THfM^KG=cL6m_JF9TI69QHEaHHVUWJW5eLg=`KGInO7QfN7Z1T9NB
T9RV[:^NVjBNRgMhOVeLDD8g;c0a<CU2Be15@eIJEEaUJfe^M7YmP8:1Ogj;U9FI
WibOZjn[Wi^PVhb7S8n2OGe^GUaOGUeRMHR@TXnFWIVASY6BSXb=SIFOX9nNWjZd
`m3Af=cDbl>m_KFXWYFEUXV2P7E`JV1XN7ikMWIoQH1bKWN0QH5mNgYnPWj0QHJ<
TIBETI2<Ph>7OW=ZHeePJ6UWIF1HG6=SKWAeNgYdM7b:R7]nPhVFUiBEX:bVTXZ>
SH=YDU1BD4/o;R<R92DX>Te=BdYBH5mLFf1XI69QGV1RIFM/M7f9UZ2NUibRX9J9
P7AXIFMUG5mWJ6M^Mh:9RI6MXj2MWYV?S8V2QYFQVYJS[kNl`<OEi>_[jno`l?7_
kNkWgM?;b<G1_K:]ZjFMShZ?TI:BShn9PHB?UZ2OV9jRXZjk`l_>dMORi=:n][:d
^[V^XYZFUYFLYZZ//;2^[kJdYinRYZNX[;2oeMoJd=7Db[^e[jNNQW9WFUA:?S`i
?4Q@DEIPJW5`KVUZLG=`J6=^L6IQI7AmLV]aMgj8Qh5kLVYHCe5=BD0e=SLg>cTg
?DIAF5aOGf1LG6AWIVITHV]_If=OIGB0R8^=TI:FVifQXInQYJNZXiVCR8>5RHb3
NGIeNgiaKgA]IV9NIVUQFTe>GVITH6AdP863QhjDTHMnOX5hJF9QI6AUKFiZK6ed
O7A/JfQ[L6eTHVU`LFigQHb@UIVQZZJ>PhN2NfaHD4]:@S8gA4A8D5ALHfY/KGIl
Mg5ZKG5]KFmZIfISHUmOHfaeMG5cMGIiMG1`J6ATGU=<CU9DF61[LWMkPHZIYZN^
]k>`[:JTYJBMV:2QVjNb];g8bLG1`/6i[jRUXj>KT8b<RHF4QHN=U9NHV9RGUY6:
R8J3PH5nNWEbNgimOGj3QH60OWUiOGU^J71_GE]TIg9mNG5cMWE`L6aWIf1TKVmb
MW5cMgj=THnEWInKUiF>QGMPDU9ACdPn=c8j@ci2CE9MHV5UHeiSI6=OEeMEBDaI
Gf9PHFQ]MgaiOXJ5PWmhMWE_HU]RGeIGE5MVLgn:RhnBS8V<TIJ@QHB8SYRKVijR
[[o5`lC8cLo@c/[3_;VeZjfa/jnSVinZ[Z^W[;>d/Jb_]K6`[ZZd^;Bf_/cDdM?7
]K:^ZJBOWj6LV9REUYVHU8n?UYZJWifNYZVSWIjRXYnPYJV[/KW3a/o?c=?DemSF
ckff_K^^VhQlLVaUF5INHFMXJ7f=QhB3QXR3Q8>1PgiiO7QgOX66SHfFViRIThV7
Qh=gK6e_J6=LEE=EF5I@DEMKGFA/LVYPEde<C4Q6BE5NIfY_M7QmPhJ7SYJCSHN6
S8j4PXF5Q7egM7InO7IcKFMVHV9WJ6QYJVmeMgUiN7UdMh1mNgIdMG1ZI5mSJFYX
IFMXHeiEEUiMFU]PIFY^LWMmQh^<RhJ6P7IeMgYnOXJCUiNKX:VWVY>GUhmjHeY>
AdLm=Se=G5mHGf]bLfedOWafMW1ZKW9^If9XMGj2Qi:OZjNKUXj9RhMoOGUiOgii
LFmdN7MaL7=^J6=RJ6QQHVM`NW]oQ8VDWj6QY:^_[Jfh`<;8cLg>d=;?bl[8alS7
`[bi]J^PViZLWYZKVI:BTY:EVINCTYVQWibOXJ>UYIfDT8^:SXb7Q7eiNgQbKW5j
NWQlNWUkNGf6QhJ0Ng]lOg]fNX:>UijUYZ2JV9R>OWEbK6AGAd0k<bhY9Bhh?dM:
Bdi?C4Q5ADA5AD58CdmABdI:C51HFf1TI6ARFeMBDEQIEUQKG5YDDU5DFEMHHEiI
FUaMFe]HD59KI6QXJF]_MXB:R8bBW:JYZj^[[JZWYZNXYJ>VZK>j][B_ZjfVW9N@
SY>DTXj6OgQiPhR=U9NIVinRXJB[ZjFVZ:BTZ:NSWifHVIZCRHF9Ri2CTi6?SX^?
V9jMVYVHUinPTXjDXJj`/K>^/;Nh^[FUW9RFTh=/FDi<B453BUQQGV5/MgimNWIf
NWiiL79cM7]iLW5fOX:5S9FGUIB=QWifLFYTFeURJ6UXKWEiP8>2Ph5lNWYmPWaf
LW5fN7IeNXFAWJN[ZZ^YYZBMW:2PXj^_ZZZ^[JRSXj2KWinHTXb9Qh9oPH>1PHB8
RHR7PWikN7UeN7mnOX:6R8J5QhR:RhF1OGaiLFeVGUaIFV=YK79eNWioOW1TJF]Y
K6QRIFegPXN9S9FU[jn[YInGS85oPGe^FU1;B55GE4iAHFIQI6afNGIbKfe`KF5M
H6=TGeaMI6ibMWb6Si2<RhV2OGUfL6Y[LGMdK75mPH21NgN4TI28Q8N2NWMcLGZ9
UZBhbm;;bm;Bdm?BclO7bLW7_kRg]k^oaLkDd<No^kRcZijFShR:RHF7RXR4PXF;
RHbBVZ2MWZ6MViVCT92<QHB5Ph63R8J3PhN=T8f2NW]oPh=mMWIkN75]LgagLgQe
LW=bLW5cOHB7RhnCTI:?Q860NW9VHFASFeQIFV1XKVaaOX60NFYSG599AT=3BTiB
Eem/MGb1PH>8QgUZIfING5eJE5ALI6YcNWUfM7IiLfYWIFEXJFMTI6U_OX^?TY>I
XZ>MV9FCUIZTZjNPVYNIVYfNW9fLUiNNWYbJThb;SHV1OX23Ph:2PX>9SXnEViZI
VinRXZ:FQ8B5PH64Rhf7Q8F8SXn6O79bM7AdLgEhNWj1O7b3PhF;S8b7PWelOgmm
OX>4RYNOYjZ][jbYX9VKUHIiLVUTJfaRG5mVJfURGf1NFE18BTe:AD=5AdU:CEAS
Kg=bLGMgLW=dLW1ZJW=eLg5/Jfa_M7=eM7=fMWEdL6ILF5QIEU=CEEeVJ6mgOhN?
Ui^OXI^EU9RNWY^JVY^NWZ6XZjRVYZ>KTHV3OGYfMGEbLgAfP8V;RXJ6SY2:P7Id
LW5aL7N5SI>GVj6UX9F?RXN6PX1oOh:3QH60Qh^>TIBFTXV6QX=oN71ZJG9hO8:5
Ph>8TinUZZnc]JVQYjZVVHIgKFQYHemOGfARGV9XL79/IEmIEU5:AdU3?D=6BE5G
H6egOHF=SXf9PGMbLfmZKWEhOGn1Qhb?T8^9RXZ:QWY^KG9dMh28T9bV[;>j^kk0
`/K4`l:h/kVn_KZl_[k3`[Ra[jja]JnZY9fJUI2?SHb:RHjEVYF@Si6>RXV=U9JF
UiNFUIFBSXfAU9BFVIVJVIJARX>1Q85lNW]nOgUeMgMeMGMlP8J:RXN3OWn5QhJ=
Si:FW:R/Z:FNU8R0OW]jM6QOF5IFF5A?DEA?B4E6B4U3=R`Z:b/Z:c8lAe9OJfmc
MWQkOh:5QhR;QX60O7inO8:7RhIlNWUdLVm]KVi/K6aYK75`JVYdOhJ>UI^NWinO
XjR/[[6f_/C6a/C3`lG6aL2k_;bfZYfBS8b;RHV6Qhb;RXfATiBBTYBCUI2;SHb;
R8J=Uj6YZjbb/k6c/:j[Y9jIThf4OG]lO7j2PhZAT8f9QH5oNgQdJEiGE5USI6E/
KGZ5QhVBXZ:OXifBR7mhJeYEE4eBF5mXIV1KEU=;AT8h;R`];S8d<SDkAU9JI6ik
RI6FThV1NW5/KFYWJFa/K7AlPHF5QHV=TYZHShV9PgI`MGYoP8>8SI>GUIJNXJFV
XJBYYjNVYZJTX9^HVYZDShb=V:2MV9BBSXV7PX20OgmnOgagMGEfMganOX24R8An
NgYiN7MiN7AdMgYoOGUeLgMiNWinO7]dKfiXI6MZKg5cMgUkOGemOGn8SXbCW9^Q
X9^QXjNWXj>SXYnCRHV8PGUaK65LHEmHDe9@Ce=DDeIHF5UJGF=VJFefQHf<SHb>
UIVEU9NHVYZGShEoO7n4Q8B7Ri6AT92<QhF1N7=^JVa]KG1dNGj2PhJ<TIJJWInP
X9fGUifPXJ2R[;Rl_L72`[ji/:FNV92<RXEoMg1ZHV=]L7=dLWQmNWQbJfaaM7Eg
O7n2QHN6Ri2=T9JMXj2HTXn<RhJ0Oh:5PgmlNWMaL75bMWYlP7ijNWYhM79bLWAh
OH63QHbCUi^OXZ6RYj>ARXb8Q7M]KVe^LW9cLgIkMV]VIfMWHUUDEEMCDUMIGFAZ
KW=iOGUgOH21OgMeLfi[IF5RIg9kNgf3Ph9oOgmjMVmXI5iIGF1MG5iQJ6efOh:7
S9BOYjZ[[[2`[:RTY:JY[;Bk_K^cZj2KX:>PViJFVIZLVIFDU9JEU9JFUI2:Rhn=
Ri6IXJ>QWijRZ:NTXInPWIJCTY6CShV8RHnARhAnNgYfMWYmOGQfO7iiN7UfMgI`
Kfe_LW5`Kg1eO8F6R96FThZ0NG9]JEmHFUMEEUEDDe=CD5=GFUeLF5EDE5ACE5QQ
JFm^LGYnPH9nO7f1Ph>4Ph66RHJ<UIRHUI>BRWihLfiTFe=BEe]NHVUfPHZDWJ>]
/k:a[jbXXYjLW9nTYJ:OWIbNYJRY[:f^[JVUXifFThn=SHbAUYRIV9BFVj:UXYfJ
VYfOVYRHUI>DU9BDUiRET8f?SXb:QX:1P7n0P81lNGYgLFm^KgEiOGekNgUdKfe`
MgQkOX::TINGSXb>RXnFThZ1NWA_J6APGf1OGfEYJ6ERGeeIF5ECEeiWIUaHFEYI
FV9WKWMoQXbCVI:<RHF4PWekOWeiNGamO7UfMgb1P7ejNGUiMg9`LGIeLW=hPX^@
UINHW9fLVIFCTI6ATHn@T8j@THn;RH^>SXb;S8f=SXj=SHnFVYbLV9JHV9FBTHn>
RhV7Q8>1PhJ7RXj@SHR8R8F1PGmjMG1aLVaVG5MIF5MIHFabLgMmPH60OX21PHF8
RHR5PH20Oh:7RHnFU9BEUiRCT96?RHN1NGMdLW1ZIVIZKVeZJFYcOH>5Q8:1P8>8
RX^:Q81nOhF8RHV4P7amPH5jMWIfNGQbLWMnQ8F4OWYgLfm[JfmaLWQnQ8Z<RHJ8
T9VPYjZ/[ZVSWi^EShN4QXb>RhZ<SXb7QXV?V:>WZZfXWiJAT9>FUI:BUIRFT8Z;
Si6GViZJVIRHV9NFU9:@Shj:PGQ`KFibLW1^L79`JVMZJVEPGEmRI6ETIFMSH5aL
HfaaLFi[KW9fN7=cMG=`L7=gN7QeMWf2P7ejNGj6RXV9S96>R85nO7UiNG]kN7Ed
MgUjMWMnPX9oOH23PGadL71aN7elOh60OWIdM7EiO7]jNWj2Ogn0OGalNgn9U9ZF
T8Z5QhN2OWioPhF3Ph>1OWQfNH26S8n@UIZGT8j?Ti>=R8^CUiB=R8Z@UI:AU9BG
UiJGUiFBSi2CTi:EV9VGUiZKWIbJVINBShb<TYJBRH1kMgEgMg1^Lgb4QH:2Q8J7
QhN;SHb9PgeiNGAcLgEnR8b8PGemOGeoOh1oOG]gMG=bLFi/L7EfM7=fN7IeMWAe
MG=dMWEeMGMjMWAaKfa/JVUZJVe`LG=gMg=aLWV1QXAnOXB5P7UiO7ejN7f6SHj;
Ph:5RHf>Shf;RY2IWIbLW9VCSXb>TY>DT8^8RI2CT8f=TYJFVIZDSHb?ShZ3Ogaj
NWUlNgQfNh:7S92BTXj<T9BGTHN4S9JDSX=bI5iPHF5RIFIXIV9MH6]dNGaiMh28
QGilP8>0OGinQ8fDVIVJWZ6RWiZIUiJGTHR9TIJJVi^LWIVDTI2DTXZ5QHJ8RH^>
Thn6OWYmP85kM71cN828QhAoO7]oQhN1N75_Lg^1PgmjMg=fO7emN7IgMgEdMG^4
QX=oPhbBShZ8Ri:DT8fAU9:>RhnHWIN=RHfFWZ6NVIFHVibJTh^=SHZ9QhF4R8Z@
TY2=QWelPhN<SH^8QXR?TIRZZWmF?C4d=T16A3lh=3];Cd]EH5U;BeUPGVI`MWj8
T96DU9bWYIJI^KZEQIk:h]FRLhfma]Gbf7HZ?Yg>Q0`0>KGomKIG000FGI_3e]C3
]:VHP6]B>d9MIE0b:4=JAAlD<55C>1T;6cU3@4A<B40n?SHY9S0k?3Th@51JGF9X
KgN3Si^[]Kc2b<:`ZJb_^/kFd/[4cNgooo_loooK_;g:d<_7cm[Iak>]];o4_KRn
b/o2/JNTZ[Bka/g1[:BVXYR?TY^LShF:UYfHT8nEVi^?QH>5S92=S8nATXYmN7ao
OG]jMVm[JFAPI71gL6ALG69SH5]?AdA0>C8]:BT[91PB5Q/M7b@Y<3Hk?3`g<RLO
8RT];RLI4aPL6Q/R9b/b>Ci3AdU5@3m1@49=EEaQHV1MGVAUJ6ibMWUmPXF7RXnF
V9JGWZF]]/3:cm7=alcEd/K1bMKEcLgFh=oGd/_8c=;Gg=oUkoCkoooonoooo?oo
oogflO7cmoGThNk_k>cUg^OZhMSBfnS_l>;?a;ni_;fh]:bUZZfZWiNFTX^7R8N0
N7=^JFUTF5IHE4e4?cln?dE4=c4i?Chl;1hO8b4J6AlS928J4@lA51hL0`003@T0
00000PP800033P`10@/F5a0H;3Pk>S<Y92LgB4Le9R`i?D<m;c13FEQ9EFmgMH>B
TIRIVjVVXjnf[Z>HTZ>h`LFl[;?9bKZo^[K:hnWSiNKTgMKTlo3Mc]?Qj^W/o?oo
oO_ooogalN3Ce=?7a=;Xk=C=e]?8_kV^XZZl]K6nbL2//;naXJNZYjV^]KF[WiFD
Xk6[ViFIVYNBRX>2N7=dKFidK5iJGV=SH4m1?D14?3Hl?cT]8b4M5Q4I;C<]:Rlm
@c/f=SPi;2Hd@4E7@d93AeUZGDU@EDQ<FUYA?c8f>cPe>TUDBSi@I6Q^KVIQJ7El
N6MHEeaTJFYVIF=HFG60N7=kQ7imQhR7Qh60R8j9QHbNYj:MVZFd_/;3`/37cLkD
el^fZ:Zf_[JXXjVf^K:ZYjVdbMSNe/2a/[Rm]ZNY];Vj^;:c^;>XWZNd/kF/Z[6W
X;C7_:RKX:jeZIbJW9fLXJbWX::HV:Zo_Z6;T9fNTHEjN824Ri6@U9J?UiZ0JVej
N6QDD5aPJF]OGV=VHfIPCdQ6B48oA458CClY81hH5aDD;dUBDDQ3A48h<SHd>di;
A4UDFUQ@@Cdk=c`^72a5@SHfAeI>@TQCFEHg81dF83Y@FUiTKGR2QhZ8Oh2:SiBK
VIRFWZjf]ZRT/knhYjFZYYjCT9f`_L6m[Z:]`KNMTHB4SXfO/jbW[[S8fMSFeLk3
_[bb[l7Ab[fibn;E`KVlaLC8blkGf<_0_KJlc=OViLbh^;Zh_[niZiZQ^<6k[ZFG
R8V:PXbV[jVQV9BDUYVCRHB:Shb3MGZ<THUnN7AbLW5dP8EdJ6]^M7IjNVYIEf=Z
JUa=CUITI5M@EEYIFUYKG595<BdoADMADDI=GUU8@D=0=blV:blY:3I2BEAFFF9H
@cmEHU]ABe9LFdm@G6IZHeaNHFefMWA[JFa`MGA[IFQcO7]fMX6@UIVDR8ZEXZn_
WiBJZjjTXJ6RXj6QZ:^QU8Z6NGfEUXB1T8n1NX2>THn1JVn5T8V0PHV:Rj:_Y:J^
ZYfHWj>Z]K6VYJ^^ZZNOXKRdVI>EShfFXZ>QX[;4a[>TW8jE[;RgZijR/;2NUIfT
WifQYZVXW9BOZj^SVYNGW9nRXY25RY27OGj0PgacMGEcKFacNh5jKf1AFFikP7Y^
IE]>CU]SIfA??CLmHWa[FeMACeMPFTa4C5MJEda<Edlk>4M9@4QGFeeWJFA[K5Q6
CEeQFdXmAV1WFe5AF5iTJ7F6PVaSIV9JFV^3QGIgQ8bCUI2?U9>8OgAaRYbFRHNN
[Yb4RIRNW8^7U:BVR7N5UJ2P[;o3_ZfU/LBjZ:FOWIfGW:nd[K2ib=;Gf]7>c[nd
_<c>^K_=aKJj_k^c^/2k/ZJMUI>NYinN[KRYUXjATY>GRX23QHZ<TIB?PWN5U9>E
ThaoLWIoO5a7FWInLVagMf5?Cei[G4E5D5]JEE]KD4aBEEUIC4]IG5eIBTmOHUaB
BdA6E5YICT==Cda=@C<f?CTb@EieM5U>BdePJF]ZKG1SGVUdNWYjP81iPHUmKFAV
IV=_QiRNVHF2UYjERhJ:UIjUYJFSTi2Q[Z^GPHBJZkJf/;Fk/ZBV[k2ial6ZXJR_
];2TX:FYYYZM]K>`_<SFbkVd/kRaZk:f_L6fYK2o]JFGVj^/Z:b[VYNLUXZ7UibB
S8^EZ:nQShRFYY]jKWf3NW5cLW5bKG5kN7V4QGmbKgA/GU1EJ6EC@Ca<E4Ll@TU=
C44mA4<f=Ci0@CX`<3i>CD<o?c`k@3/e?diRLFYQGEYQJFaYHea@AdaGI7=aFe5J
HFIZN8EgJ6QXO:>UQfeXLgj<VIJ:R8n@Pgb?XZRXYZFQW::YYInIShN:TI2=UZZV
ShfN]<>oZJJe]jfIT8Z2SIJMXZ>UYjbh`;JLUZRc[InL[;N]YZn^Xj2LXZj/[:ja
/:FLTHfLXYfQWinSXZFWZJ>KVHn1QIFNU8^BV9VDVYj=QHZ8N6Y^LgMmOFm[MgYk
NgUmM6Q/MXF5LfIKFfAYNXV4NWUiMGUiLfiME5YMG5QMKG^2OgUaI5mRJgMgKVm`
IV5RIVaUHW=nNgIaKVa[KFeVJ6a_Nh5jJU]NL7QfM79cMW9cOX5mJeeSNhEiM7Af
O7imMg1cMW5]JWV=S8J8SXf1MWEfNX:1OGefLGN5U9>:Q8ZGUHUoNgn6SI28RiJI
U9FOWH]mQ8^7QXJ5SYnZYijKVY>AUIfPUI6<TJZj^:bMU9VQThF>WIfCT8b3Lf]l
R8R>T8V1PhF<UHn?RgmnS9>=Ri6=PG]lQ8N7R8R8R8N7Q8VHVHUoOhB9RhF0OgMm
SI2HW8n5RH^7QXV7Og]nO7b6S8UkIVMbL6icOX1lNgn=UHn4OGmdJ6EQI6ifLVYV
JGAmQ8Z9OgMdLGV1NGQiLVU/LgMlNWUcM7enO79bMg5YIg1dKfeaLW5dK6AYJW5d
JV5RJ6efOGEaN8>3NG5`LF]SHVQ]LG=hP864QWmnQYNPUH^7RXV3QHB5Q7Q`Mg]h
Nh>=SXN?U9VTTWn3RhbCW9bGS8J5R8nGZ;6/WI>LYj2IUYBDUINGUYBGXYj;R9:E
TY>DTI:PZ:>QViBEUI:@ShZ7R8N;RhnJV8n:R8nBU8n2Mgb=QgMfOXZ>RXV8SiB>
PgUnPhR4N7QjOHV@TIF?RI>GQ7IlO7=dLf]QGVQ`LViVI6EQGUiLGfIODDm>CeYW
M7I^J6]aJeQIJVYREe1GIgQiLgf:RX5lM6YXJVa`LW1]JVYbMGQoO7EfLfMWLWMe
NH5mLVmjRhf9PWR0QXB?T8NAVi^MW:2//:ZJTY>GX:>NXJNRVIBDVYbLWj6PViJM
WiB<U9Z?R92M[kVcYJ:W[k2TXZJRVibKU9bXXiZBSY>RZjZYZ:BTWiBCTXn?Qh>5
Q7ekPXN6PGMbN7agN828TI67Ogn4PgMZIF]eLfUXKWIdJfMZLGYhKfeWJ6a[J6QZ
IF5ULH1oOgmdKFa]LWMbIF=XJfERK6m]J61MHfeeM6UTJfaZJF=MHfMTHV5OGfEZ
K6MQGf1aOgQ^LgUgOXJ0MG9iPHJ5P7ijLgb9RH>3R8R2Q8F8Ti63PhV6Q8ZGXJ6F
TYVOX9jGTYNPYZVXY:BUXj:VXI^JV9n[Zj>OWj:VY:2MWjBY[[6`ZJ>//j^PVYbU
ZIj@SI6JX9V=SIBMWiJ9Q8V8QXbCU8]lLWAcLWn1LfabM6m]L6iVHf][JVeXI6U_
MgeoNW1]LGQfLWMjLVmbLW=`IfYeOgmeLG5`MH9oJVAZKVaVHEeKFEMHGVAXJVAJ
FV5SIfYYKG5YHfEWJFeZJG9gLFiaMG]oMFIXL7=cMgUkNFe[Mh5nN7Z1QhEkMgf6
RXN5S96ASXN<WJBKTi>CUibLWj:GR8jP[JZLT8nKY:NWWYjUZJVXZJVYX9::Ri:I
V92GWYVHW9bJVINHVIN<SINIThf<Qgn0O7R1Q8:6RGmfOHB8Shf2NgAeOh1kOWmi
N7YhNX65PWmnPXV;RHJ5Q8J:R8B3Oh67SXIhMgEfP81kMWIhMG=bKg1bM7YmNWIi
O7]hLg1dMg5XK7QnOWj0PX9kNX:<SXImN7QnP7imMW5cMGIkOgelNWYlOGj1P7mm
NGUjNh>>S861Ph65SiRFQgn6TI6<SI2BUiR=PhJ?U8n?TYBHUI2<R8V<TI6?SHJ4
S8f:R862QhZ:SI:BRH9oQhn?SHJ1O7UnQ8J2NgQkP7mnOgelOGUgOH:4PWQ^KWEm
OgelNgUgMG1]Kg9bLgIdJfM^Lg5_LWQnPGihM7=gOh1mOgmjM79gPH9jLWAjNgIa
LG5dNWn0OWikMWMmPH>3PH>2PH>5R8R3Q8^=RH9kMWEfP8F4Q8N3NWR2SiB?SiBJ
VY:=SI>HUY:AU9bOVIFDUYNGU92<SXj<RHR=S8F6SYJDS8V<Shj:Rh^9S8n?SHN3
P861OG]iNWimNWYlNgUnQXMnNWaiMg^0Ph9mMW=bKf][LG=aMG]jMgAaNGekOX62
Ph:0NgQmP863PhB2NgEbLWQkO7moN7=iOX:8SX^5Qhf?S8EhLFi_MGb0OWilNGf0
NW9gOh:3PWioQ8>0PXB3PGj1QXR2N7V2Q81mOh:3RHV2PhF5QHB5QX5oRIBAQhN<
SYBKVIFDUiJDUiB@Si2>RX^=Si27PXV:RXb:QhbBU9RHUYNGUI>BU96@T8b;RhN3
PHF8R8R9P7]oQXF0OX6:S8EnO7akO7enPH5lMWMbIfIYJFY_L6aWH5mUK75cMWMh
NgimMg=eNWYhMW1ZK75cMG^0OWYlP825SHb7PWYcLG9eNgahN7IaJfESJ6iaK6Y`
MG9_M7EeMGEhO7emQ8V8Q8F6QXR8Q8:6RhZ7R8b;RHZ:Ri2EUi:ATiRLW9nMV9JE
Ti>GV9B@SXf=TYRHUI>FWInLVINIVYfSZ:VWY:>TZ:Z/ZZNZ[:j[YZBPWYnJUIJH
UY>ASXR0O7]mQY2CTHf6PH:6RHN3PGacKV]/JVQ/L6iZJFQYIf9QI6]`LG1[IfES
J6i[HEmMFEUHG69TIVMPGF5VK6aVHV1QI6=TJfeZJ6MUIVU_MWQjMfm]LW9^JfYU
HfI/LgIiMVi]L7EkOGUdMgf1QHR6Ph>4QXN5Q8B5QXb@Si6BT9FLWYZGV9NFUYFA
SHb?TiFCTHn>S8jCUIJETY2>Si2?SXf;RXf>S8V:SY2BU9JHUY:CU96?T8n@Ti:@
T9>EU9:CU92AUI>@THj<SI2?SHZ5Q8J5PWmjMGQnP8>4QXV;RhN1Q8V9Q8:1PH1m
OX23Q8B2OgmoOW]jNgYhN7UkO7YgNGf0PH5oOX23Q7mhMGIjOWaeLG9fNG]mNWIe
MWMhNGaoOWQeNGenOWj2RHb8Q8F4Q8F5PGemOWioP7moOGYfMgUiNGUjO7elOHB9
R8B4R8b<RHB2PX5mN7]oPX>5QhN8S8nATYFIV9>BUIJDTXb4Q8N5PWmjN7]mNgIc
MGYkNgb0PX63QHN7Q8B6QH9oOG]lOGeoQ8V<SHZ:SY2AU9BATYFETXn;RHJ6RHZ9
R8b;QhN8R8N6QXF2PX>3P7n0OgekNWYjNGQgMWQiNGQjO7UfMWMeLgEfLfm_LG9b
Lg=aLGAfMGEeLg9`L7=hNgelNWenOGejMG=cMWUiMgEeNWemOWekPHR<RH5kOX:2
P7ijMGEgNWamOh61P865RHf<Rhj@T8n<S8b8QhN5Q8>5R8R6Q85oOWelNg]mOWan
Ph:1Q8J7Rhf=S8^=SXj=S8f>TIB@Sh^7QhJ;Shf:RX^:S8n?SXj;SI2BTXf7Q8B6
R8J8RhV:S8N7S8f@T9>KVI6>SXf9PgmnPHJ6Q8F8QX60P7ioOh:4PX:2PWilNgQm
P8:6Q8:2PX>5RXb;Rhf<QhJ8Rhn=QhB3Ph5oO825Q8R8QXEoNg]mNgEbLFi_LWEc
L75aKfmcMg]fLgZ0OWYiOX61OX67QhJ5QXV7P7emNg]jMgQiO7ikN7]nO7anOGf2
Q8:2PX>4QHB5Qh>2Oh21PhAnNh:7R8R7QhF0PHF4Q85gMg]gLg5`KVmdMWf1O7Mh
NgakNGUmP862OGUoQ7]fNGZ0Ph1kP8>0OgYjQXf9R8b@ShZ7Q820PX>8R8F0Nh>4
N7R1QhEmPhV5Q823Q7elOX1oPHB6QX21RHZ4PXR>S8Z=SI:FSX^BUIB>SYBATI6@
RhZ>S8N=TXf<SXj>SHjDT8b@ShZ:RXN9SXR1Oh>2OGj0OGj5QHF6Ri2;RXj<RXjB
Rh>4R8>6RXF4Q8=oOHB6PG]eLWZ8R79ULgigL7IhLW=`J6m`K6iaL6UXJfYXJW=c
MGIcMGUlNGMeMG]lO8J5O866PGYeN8B3OGEdOWmlN7UoQXF6RXF6OX26PH>:QHb?
QHb<P81mQ9F9R9:>TIRCUYN@TIB@UYRJUXb?Ti6EWZ2MU9:EXJ:CRXZ4SibEU8j>
UXVCXi>=SHVKXYB9OhF?SHMiMhJ<Q7AkP7UfM7AbOhAkOHJ5O7j4NW5hMVi[LGQj
K6ajP7f4QginNgZ3R8MfJ6meNWUbM7EWIg=eLFmaLgEeKVeaK6efKFM[KWEbLWY`
JW1UKWIfNX21N6meQX9lO7AdOGmfJW5dLgQdN7YdLgIeNX:3S9F:OH:>T8YmO8>5
T8^3RXV4THn2P8B7TI>7U9j@TIZRV7j?WH^4Q7MlPGEkKFE]NXV8OWEiNh:BVIR=
RhV0T9FJSfenSI:APh6>V8j4Q96@SJVaWIFBShB4TiBBPgb6R8B;PhfOVHn2QXj@
Ti::RI^EQY2ASiN?S9JGRHVBVZNAQiB@Q8:<OFb3PVY]NWUmN79hMgelP8I_KI69
LGJ0RWUaPGb1QfU^QhMdI7R@O7QmPXIhLVU^LFj1NfI]OgEWLg=aMfIRP81eM7I^
IWN1PgEmXZ:5Q8F6PH28OWn>S7AgMg=gMGIoOgB4S8>4R8V1Mg>:W7i[PhAkQh^:
QWEfTIF6R8N7SIFBT8N=UXV7OWJEZ9><RhZFWIfAMXFISHb8PIBRUGUhPWemOGN0
Tj:JWYJ6V9^KWIb?NWQiOXIhJ7F2HU5ZNh5oLWE/H7j1KFa_LWF0PW9]MWIZKWYS
Ef1dQGmoRg9XSHn7WY9dJ7EmMGR<SgF4UhZ9R9:3HGZISG5_Q81dQHZ3LgbOP5]S
R:BHOfMhSYVXTW>=[giTNXRIVHQgL8j7Egn:MIb:MJ2^TGAYR9f>OgFD[YQnMI^Z
RWA`O91jO9FAUX9nU71WSXQeMY6?QYNAQH1OGH>0LXf5FgbOWG1[SXn@Yj5/LY1l
S[2bYVULTHZ7T5]UWY26W7m^NgA_DEB8PemfO8F@LGUhM827OW26ThZ4UZJGJfN9
MGN8PHJLRgAdLWZAN6NN/YJ2NZ2QKH>KPWQkLWjFX81/NXBGU7aVOXj3SgASRJ>3
JHJ=RWEUKFZ6RgV>LUV7MVYkLg=gNIFTJEQ_KgafKWAgOh^EQ7R:YiM_Ni29Ti:Q
XHJ5TZ>@SXM/LXfWTgMnPYJ3IgZ;V8EMDg2CW8eeN8F3X9V6Q6IZTjf[W81NQkVR
TWmgPHJ6Q8^DJ4QiPFMhOf]JJi2BOGYiPHMgMWnDS6QZM7JERg=bPH]ZMYB8O7U]
O:6QPgUlTi=nTI=bL8=mIVN8VI67O7^1MWUoN8>GUi5fHFARKhjOTg1`YjQfLhZF
UWUhOff<WWF5XIbEMg>BPFYiQ8Z2MgQnOYJ?NFmgUHj4P9NNKFZ:RXN>SfmSMW=b
R9NGR7B=YX=eNVIePgfJY7YXMXEcN8n4LG>1MgEfMhb7Pi9hJGN2UhMJGg5eK6M`
MFegPWV0JeA/Qi2FN6>0V8moOHN@V8AaPi>BO7QnNGQcR9acJI^c]KV/UXZCXIRM
TGJK/H1fUiVFSgNKYGb2RXjIUZN/WHmnSjbSPhnUUHn?TJ6^/YJ:SW]cTkJ`QWEm
L8Z:G5QbJTAMTI>4I5J1WWYWMf5QQHj4OGi_FU]WO8IfH6V<XYf2RIn4RY5bNWic
Kf]kLVV1N6^CUfAgUhj3KVakSHUbIfE^NWMbIeedUH5WO7EJJWMiPG^3QWYaIG2>
THn;KeYn[YinO8RBUI^JOg2<SVmoSWU`JF^2VIF4QHNHWi2;SYNGUIN/a:MlOZG6
^j:8QjZkVWb4PXRJS7mkIEeiV9FBTW]nXJF1K6UdPVaGIhZBJ5V1U7ID@d]VOXUf
HVQaOXZ7M6AWJFMcPGebI6AkOWA[MZ2YQGB3UIV:Mf]TQ9QlOg5GLfiXRHJ2Pg5g
Oh>EQWJ8S8F4SJNJMGJB]<:SOX:P[9B6Rg]dNVM]RHB6P6A/NG]eIGR<PgMbTJbC
KW2:VYR3MgR4Uh9NJ822PH6:Th9dPY:<O8ZLY:2:S9BA[;nQSX1bWZ>3T8V:WWMJ
NHmmHE9VRibNP6AfWJfHRi28OWYjRYAjEe]gT9:3M7J8RWUQLhj5Mf9VQ8n:Qgee
R8ihMH:?RgIePhN;SWekSH^<RWMbMgYeP92=N6f0Rhb5N7IoR8R?V81`Nf9KLgN0
MF1jPgZ2O7=[H5maMh:4Jf9PNjBILfQ]NHZESX1dJ6EWLgi^IWaiMHf?S96=QHEf
LWI]OI:8RYF<Sj>YRW=oTYjMTHR<RhZD[;^RS8nJ[ZV=NgaiOXV4O7fCYYf=U9fV
YY^LZ:Z][9VR/jZ=OYBMOfn:WIF9RX9TH7R<VX1TNHR8S8n7N5=EQhm]E4eEMXn9
MfYSHV1^QgiaIeehUXf2RI6;L7FETXnQUh>:VjBPRg5NIWamMX68P7U]JG=fK6m_
FUIhTXQiMHRCNFMbNW]aKXjQRGmhGVMhQY60LWAiPGmbQ7mLGgAoMFQaNWUoRHMg
LWj8QiBQS7EfRiF>SI2>TjFnb:R=W;JeSX6LW8b:QXAgK7EoTiMgKGEo[;V3Ig5h
OXnFPVicQH5oT9EfD59cR7QOFF1]Oi6DShb7K5E_Uh]ZI7=mPHbDRgM^PYZDQGmo
N7N4Q89aI75eM7mjLWN1S8f<OW5jOH:HSgEhRZJZSh^EUiNDVYb=RXnFYj6EViN:
ShYmMg^<ShV9MfM/LX6DViJ0L7R@Y9I_FF1bNgelJeUSQXenMVMPMGmdLgakMX:9
NWZ7X;6NSiRW/JN=Q9R>MXBR/Ij1Ie]^Q7ITKW5^Jfj4UI5mIfAaP96>RiROY:VS
TGYhQ8^RZiEmM8bMPf]fOgUdM8B8KfYeMWJ3ViMYGXJIUXU_I7R8Og=bOW1EHhVB
SHeoOXVFWiJ<SH]lO8F=PgEkP824QG]bO8n:I5MkRW9KDUUHG79fLgQjOWieL6a^
MG5SHg5iOH><R7MmUZRPNWJ>WZ^MPWQhNXVGViN9RHV:UXE]OHj9N6ioS8nEUIJA
Q8N=P7UoSZ:OT9JPV9BMWYNEVjJWWYjXX9RBNgZ;SXnASY^ZXHafJWAkPhn9PGYh
PXImN7YYHFmfN7M^JG5aIg23OW1TEF1jPFeBF6]UGFQfO7eoP7J0VX]eO8::RhR9
N6UaNWagLgA[KhN@R7YWLHbBOVAPMI2=NGQmO8NMZ:2>R8f>TiN;Ogf6UHQiSI60
PG]cPHN?SGE`OXR8NFETNIJPSHN=Q92LU8j6OXVMXY^JV9VHT8f@ViV:Q8NS[YB:
Pg^4QHB=R860TJVNPGYcJVmUHFYTJ7MbJFikPXf@N65TLWaaGFA[G65lQ7M/MGUh
QXUnMVUYP8f9OfeQLXR4OH1`H7>FUWYSIGj3MGf8QXYlJXBLQVe^Sj:7Lgj8SXF3
UIfQ[j^?SInXZ9J3QhnCUXMgQiZASiIoK7^FWXUhPY6=RY:FRWf8UiVOUH65QGE]
K6mdKf=dRGm_JVU^N7n3P7ajOI2PYJNAQIRAOGn7RY>QXhj0RYR;LVioPhB2MGEl
L65[PhMkN7UnUZBDR8::Wk:aX8b<YK:WUGmgPhf>RXf<PHN<PH::R8F5NWN1RY6B
Shj7LgbR[I5kOWakQ8f:M6j2SiJ<MFmaP9F=S9V6LWilOga/N8=lOhR<OG24Sgae
MgE]GfQ^F4iJD3a4FU]?FV]QFUmPIfAWMg9WM823Ogf1PhF?R7U_KH64LGF5OgEd
M8:GSG9[NhfARHJ4PhN<Pfi[Qj2KRH68U9VCRhJ3R9NKUHehO9RERX62TY>HW:2/
YInc[iF7RYf^Y9fPThQnO8N5QHF1TIVES79SM7QfPXUoN7amOHJAR7=/JfaREG29
Nf]^LgImQY>BOhZVXh^:Sh20S8=fN7iiMG5XI5eQL8N;MfAGGgYnK6egN7enM7Ai
N7YiNH^GPVU/PiJGT8=iOHnGOg1eOgmoRH5]Lh^COfU/P8B:VXecLH:?SHEeL8RM
VXV;VIZDR8B7RhjJYJRXVIRYZjZYX9F9Q8bCU8j4PhJ8U9f;LFQ]NWmjKfIZNH>2
OGE]JWAcJFacP8R7P79ZLH:6OG1cRI:IXI=oOHJ6NVi/JfIWLFibMgYnMg9eNhN<
Q8:5Qi28PX5oQXEjLWJ?XiN9O7V:SXb8OHVSZ9b:RIJFUiInKgZ=XIj1Mg^3UY9n
Jf^5QWI`LW9eNg]^Ig=mMVY^NWinOgicHV1`O7ajM6iWHfYiNGF0Pgj8V9Z@NVif
PYFPUXQjOIFERHN5PGUhP7QXKGV6R7adL7:6V9bIV:6Y[:fYZKNfYiJ3R9NMVh]g
MWMmTI21N7J4ShJ1P7YjO824QXN6OgR2Vj>=MgIoR92>Q7]nRX9`LhRDRX26SXF7
VJJPS8NHXj6CPGUjRIVHT85iP8R>RGEWIFY`LF]UGeYYL6YXJG>0QHR:R7mhP8B8
RhF1NgV<W9J9OHFLUh=hJW27S8Z4PX9dLGQhM6]bR96?R8F<SY:BQ82DXZRTXJjb
YIZ8Ngj4RHIiLWV0RI>DSgahTJ2OUXAkOi:TY:2?MG1kS925NW9`NH5lLVYKFFE]
KfYZIUeUMgenMg1dN7UbK7AiKfQUJGQhLVaLGVMZM79ZM7UhO8J?RW9WL7Z8R862
Q8F4OG]mPXIlOhj@RGE]PXf9QWj1R7elRXZ<TiFAQXjOWhQbJ6McQ8^8P7EgP8R8
Q7]iRIRJT8VAUYJHTH1jQI>KWINHW9^IV9N7Nh^MVI6:S9ROXi^FVHadL7jBTH1o
PhJ?SHV7MFehNg5TJgeaGF9/M79TGfIhPGedKVegOgI`KVe[IfIYJViYGfIcPHZ4
Mg1`MgQ`KfYPIgAjNgemMW>0SXn:PGEkRi>8M7^=VIfDR8N1P8B7RhR8TXakQ967
PH^DTi2>R8JBWYjAQY2NXIRBVJBSW8n1QhQnO7j0Ph:3PWilN7=fOX1gLX28R8V3
NgIYJ6m/If=gTi22OGYlRi:=P7^0NWV:T8N0PhV2NGIkQHR2PhN2OG^0PhN:Pgn3
QHF2Ph^?Rh^FWYJ=TIFATiJ;OX2AWYB6RHV:Uj:SV8AhNWf3QXNAVIfJSH>5QX5f
MhN<TIZBNg=jP7McNG=fR92>R8ZKXjBTWINBTIRLUI:7O862PhAoOGelNgb1Nfm[
Jfa`IUQKHW62P7Q`JVe[IVYZLHB5OgefN8B>T8AhN7AfQ8EkO8>=QgAZKGZ3PGj5
RY6BTYRFSXf@ShN4TI>9Q825VZ>DPH::Pgf7S89bK7jAUI:5RIbPVIFEVYjHUiNO
[:fWV8Z>V9ZCP7MoQhb?PW1UJgAdN71NJGmoMFi]M7UoQ89mOH66QH5mM75]GDiC
GeaJJGUmOGj3Og=eQ8ElM7AmPH68RH>2O6mTH6]iOGaeKgAgM6ePHVm^JGEmOH6A
WI1jK6ilQGieJFb3QGUiPX^=RHF1OgmlOGIZLGQ^KGEjNWR1R89kNh6;R8B3OHZO
XY^FW:ncYibKYZfTV8b2QYJVXiBDUHn?ShV5OW]mOWi`I6YdN7IXIGYoL6alRi>?
QhF;UI60LW1bM7R2QX5oO82:ShAaJgJ1P7YlQhF1QX^0MFaNEeUZMFeTIVmiP8N8
OWf5Q825SYFBUIjHRh:=WjFUXYVCVinHSXjCTi:GUiJIVibETIBET8b4P8F5PWmo
NGAhP8EnLgF8U8n2NGf<SX9hMXBASHF=UHn4Q8J2OgigKg5dJeaPMH1eJFeoPWMb
JVmmNFURJWf7QHV>Shj<R7abKVm_Kf]]LG=gP8jCSXF5QhjEU9RDTIJEVIjCQW]h
QiFDSh^;RhR4Ogf1NVi`OhJ4OXBDUX]mM7MnPWifNGmhL7V<UXn<UIFBUYZGShZ9
QhN>RH22RY:CT8n;QXb@R7YgOgmeLgIjPGiiLg1lPGQeO81mMG^3O7^4SXn8RHf8
R8^:PWInRhj<QGUiP8:3Oh26PWn<UYF?R8F2NG9^LGMlQ8AmNW^7S8N5QhR;Si>F
UYZRXYfNT7mdLW]oNWb5Q861RY>=RHR3OWYgMW9cNGUdLgQeLGEmOGalNgmkNWmn
O81mMg^7Shb8S96GUhZ1N6]PF5aYL6eREUQUKg1YIfadPX^9PgYhPX1iP8^8Ph6>
VI66PhJ7OgUnOG^1Pg]jQHZ8QXN8QGmkNWQaKG1fQ9:CThn=ShYlMGIiOGiiLVYU
JWIlNgZ1SIFHUY6DUiBAS8R=T8N2Q8bIW9RBSI2HWifHU8IjNX:6QH:6RX^>ShZ1
O7ioN7^4P7QhNWUeKfe]J6M_LFAPIfMWKWUiK6IbPHV5N6a]MWYdJ6M^MG^0R8f7
Q8V<TibIS7ecM7McM7V2OWN0Si6;P869RHR:Rh^>RGehPXf=RXjHX:BRWiVDV9jJ
Thn@SiFTYIjIU9bSWYJ9P8jLU8Z9SHn?Sh^4Q8=nN7AlQXB2QXB0P8R=SIFKVijN
V8YgL6mVH6EZJfe]KVmgPh5iN7UiN7b5P7AbNHB6P7n3S9ZOTh1iQ8j=Q7A]O8Io
Nh2;Thb4RI2CS8F1OXB7PhN:Q8F9Rhb:RXZ9Rhb8PGQmQ7IYK6mbOHZ=Ri:HTH9g
MWUoQi2=Q8NFWI5oM79fP89nMFieNgQhMgN1QHB5QHbAS8>0OgegLgEjNgIgNgYc
KW5lQHB0Lfa`NG]bK7R1Mg9aKFaeP85fMH5oMWQkMW=kR8InQYNPUh^<TXj9QX1j
P8b?SHN2PhF6QH5oPhV:RXnCTI2FViZKVYZHTXQoO8N;QXN?W:BSXZ2KVibBQH:5
PWilOGeoOg]iN7f3PX21QXR6R8j6MVQSJg1aN7ajOXB:SXf<SHImLf]]LG=kNWAd
LgAdL6m]LWj4OW1_N7YeMWIeLW9mPg]iN6eWJ6]]K79iN7f4Q8AlN7imOXZ9O7N2
ThmoOXZCShB4Qh>3Oh25PGUdKFa[J6QVIV]`N81nQ92FVI>9S8^2P8>=UiRLXZNU
ViZQW9ZPW9B;Q8>5QXR3P7mlNWV0R8N2QXR3OX:=SXAhLW1/IVEWJFUTIgAgL6e/
MX9nNgQgNWUjP7YaJF1SK7N0PGejMG=hNg]lP81kN79YK7IgLfm^LGInR8V3QhZ7
PhF<TI>IWijLUYNKW9nMU8^6SIRKUXf?VZ2TYJ2KUHj@VjBOThf<TYVJUIBGWInO
VY>8QHbATYBFSXJ:UY^KVIF>QWmgLGEoP7akMg1]LWQhMg^3RH9lPhJ0O7elLfe`
M7IdLgQgN7emO8:4NVi`MgM_KgN0PWeiO7j0Q8>4QXZ;RhZ9RXj9Q8:2P81oPXF4
Q81iMG=dNgYdLG=mPgaeM7j9RHV>UIVETI>@SI:HUhn7R8^>THj<TY6=S8bAT8J3
QhV:QhF4Ph>;UibCP7=bNXF9RX^;Si:>R85nOW]mO7UnPGmoO7f3Ph5nMgV7UIfB
PhJCVI>5P7efM7MlOWMbLgEiOGmoO7YjNWj0OH63P8B5QX^;SIVW/K6XXinPWI:>
SHJ2OG=]KG5hOh5kLVmfOH9lLg1aNH=mLW=mP7UbNHZFThj?T8MoOX5kLW9gNG]l
NWYnP7miMGEdMgUfMgUfKF9MIW1^HeI@FFQ]JVUZKWImP8B3O7IfLfYVLGelMg=a
KWB1PWQdO8R<PWMjR8n7NWQoPGenPhInLg5eNh20OhF:R8R9Rh^1MG9jQXEkMG9e
PHf?R8:5SIRPXIbETHf4OGUiQ9:GS7moR8b<S8V:TYN@QX:8SXf3NWn=V9REUI:?
RXR9QgidLGEgK6AVK7MkMG9gNGUiOXF6QH9oOH24QWmfLG=hNgelN7V1R8IoNgQe
N7UaKgQoNW5_L6i]L79fNgj5Rhb;R8fETHjFVYNCUYjNT81iOXB4QXbFWY^DUY^I
THZ@V9^IThj:RYNTYJ:HSi2CTY68PXN6O7MmQHV?TX9dO8V9P7j5RXV:QGn0QX^=
RhF0QXj:QH9kMgIgNg]eKficMG9jQ8V9PgmoO7IeM7R2QXB4Q8N:SHn8OgYkPHB3
Ph=oOh63QXf?Rh^;QX63Q8J<TXj7PXF5QHN4P8>6OgEfO7aiN7QjOWn7TI6;QXF4
PX>4Q8VCTXn@TXn9RXn>RH^>S8N<UiN<Ogn5PWj0P8>8R7]bNHF6PWiiMWQjMW1_
MWQgNWioOGUgNWaeKgJ0Q8J6RHb=S8R8Qh=mOh9oOH64Ph1oNgQmQHZ=S8=nPHB1
O8:=TXn:S92CUYbQYJVZYJ6PW9B<S8UoNgn4Q8F8PgUiOhJ;SI:FThQiLg^2OWMh
P8F3Q8N:QW]mQHAlMG=gNX22P8>2OgamQ8AkMgIhOhF4OWf1PGUfMgUgLFUSI6]`
JVU`LFQPGf5WK71^JVQYK6][LWQfLVUYLGYlNWUkOGMbMGioNGUiO864RHn=QWea
LWUiN7f3PX68RGihOXF3P821Ngb5R8B0PX5jNgijP8jHTh1kPH5mOGeoOgf1QXZA
VinJU9VRYIf@RH=oO7amPXAnNW]kMFm/L7EiNgeoOgQbLFmXGf5ZMGYiNXB?S6mL
NZ2>MG1kQX64R81oQWmjO7QfLgIlNGM^K6]PJXAoPX=fNXN?P7j;Ogn0Oi6ESIJM
WiVEVInRUH^;QhVGUY2AU9NMYj:FShnFXZJOVYJGY:6JUi:HWIZKVIJHVYF?R8F7
R8V4QXN3Rhn9SY^KUiB@T8n=SXj9N7N5RhR0N7ejKF5IJ7=]Jg9eLW5eO7n3QX62
RX=eMH2>SXMnN8:=S8EoOGY_LGIeMgb1PWYdNGUgO8:1O7]kNGf1Oh>3MgQmP8F6
OWamMg5cPhfCSXB2QHR:RX5kPXV<Shn7P7j1R92ES7ehQIZOUHb:SI>GUY>=RH^;
QH26TIFASHfBT8j>SXMkMG5eNGb3QhZ2O7QhOG]iNGUgLfefPGihMgIaKW^>TH^6
P7QoRH^5OWYdOHQkHee^RYF;OhB=SHn8Q8J5OWEhRIFFVYVCS8fASHB9RWelPXF1
P8B3OgYjPXJ7RHV1NGemN7IjQXAmOh>5RXn>RXEnMW=dMg=cM7J0R89bKWJ3R8F3
Q8J9SXn8R8]mMGb7RhR9R8InMW5WHF=TGEEHH61SKWn7QhJ4P7eoOGQlQX9jP8V9
PgafKF5WN8B<SXV1P8V;OWAcMh6:QgM]Kg^6Q8:0PHJ;S8V?VY>6PGmlOXB8Q7Yk
PhJ1O7QfO8B9QHB9SHf4N7IlPXEoOXR>Qgn0RXj?THZ2O7j2Q89nNgMdMWb3QhF4
QHAoN71aO8F0NGQjO7aoOgmmNWelMganNgj0OWQeNWUjOWYbKG5kOgn0QX=mPXV;
QWn3T9F?Q7alOWigKfe]KgEoQ860QX^?TXb;TIFGTXV5QhR=VIfPY:BSY:RVYJJO
Ui>GWINATINCS8V;S8Z>S8B4QhB5RXb;S8^7Q8>6QhJ4Q8^9Q8:5RHV8R81gOHjG
SWmlOgakMg1WJ71dMGIgNWalMG1fOGimPHJ7QHJ9Q7elOhF?T8b:R85kNWQgMg9b
NX>1P8F>UIBATI6<RHjARh=lMgEcLgAgM6eaO7adLgZ0P7n0PGmoP7UhOh1jMh2;
THf5QHZ?T92@T92>R8J:Rhb9QH:4QGigNX23OW^1RHZ5RH^5Ogn3QXB3QHR6Pg]h
O7mnO7]hMgZ0PGelOgn0PX:3QHR=TI6;PGaoQXZ8P7f0R8j>R8J<THb5QXN8Shn:
Ph23PG]kQHZ5PXN:RXjGVYRETi6GVI>>SHf:RH^BU8R2Q89oNgamPHZ<R89mOh:3
QHJ6RHV0MgAhOWmjMGImPX1oP7moNgEfMgIhPXR1OGmnNgUiM6YYLgI_JFIYJF5L
GV9RHFE^LG1aLgZ0Ph=mMgIhOh9nNGA`MGioNGAdMWZ3RXEmOH67R7mfMWUiNWam
P8>2P8J@U9:?R8:1Q8V8PGUdM7IhNWIhPY2KW9JFVIZGUIFASHZ4QHb=S8nCTHIn
P8J7PGakP8F3Ng=_L7EgLfe[K79kPWegNX62Q8N8Qh:0OG]jMWIgM79dLg9aLGAd
N7enO7IbM7YlM6e[K6i_LW9eN7UnQ8AnMgQlNgYkOXF5OGQjOh:1PHbGW9^GUIRK
Wj2QX9jMUi>FWZ>PVibLVi^ITi6CTi2;RHV5PX21PGimOGn:VJ>RWIfSY::MVYZG
Ti:BT8f?Thj0Mgj>V9B<SIBKVY25PhB6Q7igLG5eMgIbL7AjNWUlO7ejO823QHJ4
QH=nOgmnO7YiMW1cNgeiMGMkNgQiP8F8R89iM7UmNGIlPhB0P7iiMWZ1Q89oP8F9
QX60PhN7Q8:0O7YnQHb:Q7mnPHJ8R8N9RhnCU929QhN5PX62Ph1lNW]jNGYjOHJ<
RHB3RXn?RhZ@Thf4OGf1Qhj>Qgn1Rh]mKfU]LWMgLgElPHF6QhF2OX27RHV9QXF3
PXB3Og]jNh6:Sh^4P85oO7akN7MgMWYoPGekOhB4Oh27Ri2ASi2EVYRCRH:0Ph=m
N7AfOX>2OX24Q8>5QXR:RXnBShR4QXj?SHb9QXV>TIBHUXf2OgmoP7n0PXB2OG]m
OW]cL7=fLgElP7YcMGUkNGAfNWM^IVEWKVm/KFi^LGV3PginPH1oOh1lN7MiNg]h
M75cNh21OWn0OGYkOgihLfm^LGIkNWQlP860PhR9QhN8RHZ8Ph:4PWakQ8fATHj>
Shj9PgelOG]iNgUiOh^AS8N0OHB<SHN2QXb<RhR5QXJ8RHR4PWinPXF8QX9oOGf1
QHF5S9>?Q7UdMGE`JFIYLG9`M7QjMg=fNWaiMGAcLVm/KG5bLG9gNWUjPHZ@T8N1
OGYiMW5aNX^FTXZ4Og]mP860PhN<T9FHVIVKW9fMVY>=Si:AShjATY6AT96CU96B
TXb5P8F8QH63RHbATI6@TYBBSHb;QGj1RXb8PXB4QXV5PH27TYNETXf=SXb5PX1m
N7=jP8:1P81jMWUjNh26QX5lO8:8S8Z4PhB1Mg9fNGMiOX>4P7n4QH>0OWahMWMn
Q89iMgb6S8V3PXB7RXR3Oh:4Ph1mNGEgO7ikNGQjOXN<SHZ9RXZ8Ph1nP8B3Q8>6
Ri2CTHb:Rh^6PH20NGEfMganPXN>THf6PX:3PX:3Q821RiFGT8R3Q8R:QX5nP8>7
PgUdM7Z1R8b=S8Z=TXn<SHf9QXN9Rhj@Shj>RhJ6R8V4P864PgikNganP826S8f:
Q8J;S8Z7QhF7SY:ASXfAV9jIS8>2PH1kMgIiOXB6QH5mNWMgL6Y]MG^0PH>6Qh^@
ShZ7QH:2QH9mN7QmPWigLgEgMgMhNGj0O7YmOh21PGn0OGQbKG1eMW=ZHEmRHf5Q
HF=YKG1bL6i^LGQhMG5_MGj2Q8:1PX>5QXN:RHJ3PXJ8R8B0OGahNGekMW=eNWim
N7=fOhB3PhJ5P7f0QXR8QX5oPXJ8RXb;RHfBTX^4OginP8>4R8nFUi:;QHF8R89j
NX25Q8:3Q8F8RXF0OGenP8:2Og]kP8:2OWQfNGemO7emNWA_KW1dN7UfMWYlOX63
OG=aMGEdMGIhNGQgNGj2P7UgNWn1Q8B0P8F:Qh62R8V7QhF4Ph>6R8b=S8f@UYnS
WiVFTY6ASXZ=ShElOXRATHjATi68QHjFV9B>T9RJUY6BShf@UYZKV9>CVI^FTH^7
QXR>ShZ7Rhj9PWn3PWmmOhR@U9:;R8=mMVm[JVicMgalNGA^KWEjNgf0Q85lOX9o
NWQkOh:5PhF;SHV7RHV2N7AdMh64OWMdLFi`MWf0OWYjNWIgOHB<U9VDRWecMGn7
SHn=SY6GWYV@R8=oNgf2PgmmNWUfKg9fNGb3T9JAPWQhNG=bNXJ9O6iZL7QnPH61
QXMoOH:7QXB2PhJ<S92CShb7P7QiQXZ3OWYmPXR;S8^6Qhb>SXZ8PGUgNX>;RX9m
OGamOXFEV9FBRHB1OWemNh27R8Z<S8Z5OGIeNh>7RHN6RXj?SHN3Ph:3PhB6RXjA
T8j<R89iLG=nQhV9Rhn?TI:ATiNJUXn@UYJ>Pgj3Q89oOGn0PhN9Ri2ETHQoOh1o
PhB5Q7ikNgYhMWQiM75bLg=aLgIeKfe/JVUXKFi`MWQjMW1aNH:3OWanOGYnQHF6
QX1bIfQcP8N8QH5lMg1^LW=cMGZ3QGihNHF>SHf7RHj?S8=nOgQaN824RY:BSHZ7
P7UfPXj:PX>;QWemO7YgN8:6PGeoPGicL7J1SY:EUhn9QhN5MfEMHGJ3OGUkNG5[
JFigNWb2PW]^JFa/LGEbKFMUHf9`Phf9NW5fOWU]JG9iN7^3SI><P75XL7f6SIBF
THImMWAjOh26TINAQgj1RHN2PHjPY:2CSXn>TI2?UYZHTX^>V9nPW9ZLVYVGUI>@
SY:HVIJEUiNGTHb<Si6EVibGU9BETi6?S8V3Oh24RXj@TY:BUIZJVYVHThn;Pg]e
M79_JFEWJfe]JVagOgejNGf0O7QfMgIdLgYmO7amPHN9Q7]jPhZ<R89jM7QmOWak
NG1aNhB4PHJ:S8f>Shn:QH>3QhJ8Qh69TI2>SH9jOh61PXjDPFmaNH66PWMdMGYj
NXB5R8f;QWi`F4EDLhREUXj3M6a`Lg5ZJ7Z4Q8nFTX9/GfMfQXZ6S8f5NGAkM75l
OX63RiZGRHF3MFYPDUEKKX:5SI6>QFiMF6=ePI:NXZJOTX=YH6agQ9BS/:RAOgA^
JFUdR::mb;jQNfYbO7YdQJG1aK>IR820OWMlRI:KWifMVHmoL71eP9:KXjZYX9>?
S89lMgb6SiVPWijJThZ1P7mkP8Z<Shn:R7meMG^0PH67SY:>PFiQGUmQIg9fLg5]
JVMYLGIdLGAfNG]kPh^8OGIfN7MhNWYlP821PWmiM7AhNGEcM7QlOWM[JgN6UIbI
TXUoOH62P7n1PhZIV8j;SYF=Ogf1PX24S9NY[jJMTX=eMh:@W:>TVXIdMWYcOY>O
Whn5RH=kNFm]LVefOGUkNG]eI5mQKGn;U9N3HeA<?T5OQIfCKF5cKUA8BTiOQ8mn
NH9iE3DkCUEQK8:LTWmiMfE:B5ioVZN_^;NRO69RGUYGF7RHV8n?U8edJ69OMHbC
T96TYY:5Nf]JFW>BZKNg[If9OFiWNhF4S9^b^J^FRhZ4Ng^:XZn[XjRdYhb0QXb@
SY6KYK2^ZJZJNV=MIGZ?ZK^n^::8Mg5ZIVQaOi>SYYf>OgIaLh2@V9>>RXEnMFm[
JVigQ8f?Si2ARWacMgikMW^7RX1fLWAjOGYjPHb@Uj6WZZBFR7n0Q8R9SINLUXMi
KfY[NiRZZIjETXf2Mg5gPhR9SYbRWYfNS71ODTmRO9:V_L6URGUPD5U`OGn;WjVL
MTi;KXbHVYV>MfMVOj>dYgUABUEULh:F[JfAN6IA?CI0G8FV/JN;KEaC?c15JHFG
WIn@N6E=@TIINHjNWX^0O7IPBdIKOi:6MgAoTijBLUQ@J8fLTWV1[kVELV1/Sj2=
MXFWXWMRNIfVTW1DGWEkMGB6Y[N/WYbLV81TFeajZlK7^JBBOVi]Lgb:UjVg^:nK
OeiDJGj8TJ6`^KN/UGe]G4i?HGbHZjbQU8UlKF1WOh^:Pgj0OGIdL6QWL82AVinH
ShV1Lfe]L7V0PhB1NWAcMWj5SHn8Ph1lNWQgNWn:TYBBRWifM7b5R8MoNhJEVI:;
S9:FS826VjbWThV9QgimRiJHUXj4OGIhRiVISFmVPYZQTXAlH4M6EgRF/lZiTga^
E2hH6S]j/[jZZk:IG2HH8D1ZS9^NYJNJPE<[9C13JiN`^;JWPU<n@3/a=f>I]l2h
XhMP:009>Vj;XKRiVV]DCDM>HWV6UJZYRW5aMG1VJh>S][>XVhAbL7eiHfUiP8F;
WjNKV9>8Qh9kNX><U:S1a:^@OgQdM8>FX[>o_k6KOEmAFg26WKK8aK6PRFUNIFin
UJJXUXJ1OG=/KgbBXZ2DRXV9PgajNGIbN8NFWYbEQWE]K7F3T9NIViV8LVASIfeg
QIJRYIjBQ7QaK6YaO8fMYJ>HShn<PgmoQ8VDW9RLXYjAPGUhNX>FZKVn[Y23SH]f
KWf3Ng^1V<CB[XIoPVY9AUj<[k:ga[nSMEMRPI9iKjWZj;IjHEeHDeMbSinQWY^2
HV5bL5i8FI2OTY6DT7A;?deTM5m>Ji2RXXmfFeISCCmXT:2TVHUiFBD066VY]9]e
KVQRKVaZKW9nUYn:JVZ2NeI:I8F7Jfn6QX:5QXf=NE0`<U1cSjJe[J2BPGihIEaY
QYVLWibJVYF<RH9kNWMeNhfGThV4PW]]K82;SiFEUiZ;NWIhNgYjQHnDV9B@SGm`
KGZ3NW=kP7]dMX::QX:9UY^JVIR@QW]eOXV>Si:CSXAnPX5kMgjBXjJSWIJ9O7f8
Si6FWZ>RX9bIVJBd_:b4HU]cTkG8b<2ZTXEnMW9VGWRMY9j_]i=OAT14E8?2hmNL
DblnEV5_Zmk8W89_If]ZHfB9V7QbOG1aMVYLA3eLJeaDN:J]QTXD4E5nMF9ZQ9fG
QhAS>SPl;4MoZ[FfZWTn6BaEIGZ8PhnPTGAUJfTk73AZSYbHQX::MVMWGD<fEIBl
[:c1^HA:=d5DH7:SeMk:[Xe/A2LaD6j>[L77`;2SUWeKAd]KIVn7[L>l[:BDNV9N
KG]nP8RFYIj8OWMdNXFFXinNWiR=RX^7OGZ1Ri>ETYJU[jjNShb;QhF9RhR<UjBe
`KZib<BPQ8j[]:VOWJZh_/O7_:ZEShmoNH64U:BX_<RgYYF5Ng9/O;;Tcj:SVGen
KdU?VLNgZZ^AMIJ[OTeOSXN3XIYX>S=FMH5gE3LaD8f[ZkR_Jb488ef8TX60T9RC
NEE3@3]3FWb/_Z9eGePh5B9>LhjASG0m:S0iAEi]KWjBSf]MO9EhCU=NEdQDOZFf
[h][JVMCDVQnUY9fO9VFNEQ@IFMNLX^M[jnVTG5FAdYCG6f6TiJKVHf6N6mWEf>0
T9RMX:VVU9BCOVINIGB8WJZVWIZGSXN=VjJSWZZ^Wi>@SIFKV9nVZ:^^/kZ_XJbd
[:R^ZZ2^`LFn];Bf[jNAMGjLVINX[Jne^ZbGV9Z1Fe=KHWFG[jjb/J6Q[J=kCdea
U:27KX6[/Y^4L6e_E4QEJ7M`GDmPPK:eO6B6Uf4h=dYVPHj;TJFbVF@j<3M6?cI?
OYbJQ6]LE4m>@SUHMgi`DD]JJ8FLSW9HBD52F6QWGfR5X928SWf2SHEcCci0BF5b
MGZ2L5YJG4XU51d_?DaJK8>8MUYDCTUEFemYNHbMWYncYh5fRK;HcJ=fMKOMcLgV
giY19fgGgg4SD<;oooo9N4HbA7RafoSooogV`Yj7N7VBYiZ2QJ6eZ81RKHjOQEm:
ADiSO8bCShAmL69RF4UFLH>5NgAWFU1IIf1PKh>=RHNPb>?^jMFiSg:2[]3G`JBV
/K[Ek?ooe;6PVZ>:HFVH/9j8ZlfVLF5SIW6;SFiSK6e`LG5fOi>KT9FLS7U]EcDP
:d=AFX2MZkg2[8aeGd<R8CIBKWN7XJVLQhN2Hda8>b<H934nF6]YIf]^J4hi?cHZ
8AHQ;CM1DEYAB4Y<@BP;01DY;dAOKGEiJf]iPG5<?TA8@4iTLFQKIhJ5Kgf<P7^3
KVYnSibNUXF=WZ>QXJ:RYYbJYZ:S^Kk9f=;Dg=W:]K?7d<:Z[<;Pj]_8`];Pin6k
^Lo:/jRRXk_Rn>[JfM_?b<SNlnkZk?7oooo_ooook=3FdL>U[lgIi>G[m>:dZl38
_<geooK>^JjKRXB0RHR8V[2l/jbNR68g:2@W:bY6Bd=8FV5EB38C000000002`/H
:1lP7QT=0000000000D<5c0n=BHQ7A80000000006C<f=c<hA44i<RdX:391ATI@
GVA/I5mLEEYQEE9WJF=[OHn>SiBBTY2BU9VPUX^;U:>V[k:^_<[Df=gIeMFlYZF]
`M7@eNC[f<OAfLk8c<C2bn;eim;Kk_?Xf]7Hh]_=aL;:e/_9gNSQf<bnZJ>WYZ:S
/K^`/K_4ioODUHVMVgUaVIV4RY^T//gDaK>FJdE7FUaSI5=DO9VCT9R0D3Y0@blJ
9c4]?eAYO7IRDd`l7000018J4@DF=4ULJViM@B0C6B8`=TeUJFQTI6I`Je=0?c`k
AUQ]MXB=R8JCXJbXSG=]MGj2PXZ>R8F;SHVJX9>8NgZ5S8B:V9RBShb:SY:KXIJB
S8J>UIF8OGQmRY2FWZZYXIjLViJDU9>9OH6G/;g0_kRZVHQjMWMlPH>:VjFT[;g9
b<O@i^RoUY>DMFN6ZZ2AUJ2cd_?]ck:EMV=MH6anQH1kRZ[5fMBWOFA9@eETIEUV
S:_5clNjY8eoKTe3EV1OIhNIVJVn^ZRMRW9MF5aMIfiTIGAnQXb8QGadKUU:B4aH
I6AIF5aGEFYfIF9YIfU`MGE/G5QOJFi]KW1lQhIjL6mTEDU<DDm@Gfn1QgagLFiW
KVI0;d18?TIHJFi^KWn=P6]PHfUMDfF5V:6e/jR]Vhb2NGM[JW^CWJ2jg^W^j<>M
T9fLP866MGF0Wl_VlN_7W8Q_DU=NMHZ?VYjR_l>]Z9b6NVAKGUIJJ7fM_LBk[inL
UgYPHW=^GV9iRIBHWjnb/:>6Nh6?WIF>SGf1Uj2[/J:>N7:7XKRlZ8n5QW]bJF5h
TiF@S9JSZjFAR8EbHFb9UH]lN8:?TI>GTGi[GeQEHG1]JV][K7ImOgIXKW9VF4I0
@T==E4]:DU9BB34gCCd_?44b8Ba1Ad4f9RHc>3iIKWZ<W95TBf9/HDe:GEiIE5ed
TinDRXR3ITM8CTi8Cf9[JWNL_;n/RGEiQHinKVijPi>[YjB`/jZUX9bPXIN=PW^4
VZ2KX::ISHN>V::WZJ^f_k:OX:fbZ9fDU9nX]L[Gfm;8b<WEd/Fi[K?;fn3[n?G_
jN?/i/O1c<G9d/o=enOXelS8a;JVZ;[1_;Rh]ZbZ]k>TWjRb]kN_XIRHUiB<QhMo
N7R4QG]mR8V4PGMbMWI]JgEoP7f9TXMlLVUPCda?@T5?GfEZK71lPG15<CLg>Cle
:Re3BDM1:al]=2lb;bD@1PH98C<]7aTH7B//8A@A6QLA5Ql/@Dm191l/;2m6Ee5:
DUA8>3A?Mh1^HfIXK6ieMVYcQH=eK6e^OYRKWJR][jnRTHZAWYnIXK:i]jfRYZnh
_;2SXJ:XZjNWZJja^[fkb=32];:^[;Fi]l?9_KFmd]g?`[^fa<2RSIbc/k>h[jZh
`[N`^/O5/JV[Z:6NUXEiQIbMVZFb[:2SYI:4RI28KEeTJFebMhVBQVeOJF]RHEe<
B4Q?DE=RHT`_;4=CCdA9F595AU5DDU52>d]CCD]FHUiKHV5JGEmVLFiRFF1[K71k
PgeaKG=jQ8N3SIjTYIN;Shf=W9jDV9nY/jjd_KBVUY:NYjJSX9jMZ:bPUI6EUIFJ
VHn6RXJ2RhfAUYB:PX:4QHF7RiNUYZ2CQhJ1O7j0R9RX/<7IfKRMViB9S9^KRHbI
UIRLUi6AW:2EVj2@R8bKVh9dNhAoN7elOXf?RH1oRH^1LfYYLgY/G69XJG9jOGE_
JVYfNWIjNW5aM6i]LW^2O6iTHVimOWIgO8ZBT9NITI2=Q8=lKVf2SXV6QHb?S8R4
QhZ5OgZ4RGeeOI2LXInCQh22Q7alP7]bJGF>VIb=OhB:Rh9`KW1VH6f3Rh^=PG1a
Oh=eKG5fNgEcN7QfQ8b:TIFKTW]hPWebMh68RWeODF9cOh^DThMcI6adLfQEBDYF
FEaOET]5CeaKHG1_ET4k@4E;FV5FC5ETJ6m^FU5AFUeGGFIVHfI^KgEnNWf9QH66
RH^EVIF>QhZF[[^_Y9nMWIZ?QHZGXJjf/kNl/Zfi^JnWViVOZZbYZijBUIjSXib?
R9>MVI^TXYfFTY25Oh5mMGF0PhB<ShYoOWajO7UfO85lLW1iNGQjNh26QhZCXZ>=
O8nVXX]lQ8=eIV=aRIF;PhfGQg5^KWMkMGEbK6UTIg5YGU]NGF9WJVUNEU]_O7ml
JUaSGeMKHFMWIfe]I6I]JfITJgAlPGU[K7^2NGb9Rh^5RiBHXJb[ZZ^UV9:JXjB_
^kRf_lS4`;o2`KBb]KBf^L>jZZZe^[^g/;6_ZJBITIZNVIBFWI^ETH^4QYJPXIN<
QhF5RXJ5QH60P8B4PXF9P7=bNGj0PhnCTj2WWIZGTiJBTI1oKg=mPhN9R8InMVMK
IgEbIUeHEEYZJUY<Bd8lAD]0=T=>BCdf>492?D54B4Y4Adi>B3hnAdU>EEEACU5P
JFaVGE]LIFefOh>7R85lPHF8Si67OWn@WZ>SX9nOZ[Ba/[Vj]k[3`;>lblRj[Zjk
aKb`Y9fPZkO0^JnYX9^DT9JOXZJQVYZOZZ>ETi^TW9:GXIjPXjJXWYNITXV4RYfU
V9BOXJB`/J:MXIb:QibLRGikNGIlR8V4QhV8S8b8PWemQh]nLgZ4P71JDE1@AT55
BEAOGeYPJ6MKBdMDGE96ADDm?D95D65NCDiGFf5WJg5_KgAfMGAjOWQ`MGmoNGf5
QhN;TifQUXAkOXB8SHj<QX1mPHR=SiBJVYN?T9VQWiB=Shj0MW^3PX>3OX28S8Am
OWiiMgalOgYfLVYZMWaeKFeaM7QiN7^:RWEYLHJIYJZMR8FI[JJ=PXB6PG=YNHV5
O7YkNWUhLFa_Kg1^K71cM6UTHEYGFUYFEUIHHF5OG5aWJFAOHF]YGeIKIFILDUAI
I6i/IFQ]MgYkPXF:RhbCThZ=TiFFT8^=SYJMVYJJ[K:VXjJUWYVNZJVPV9RNUXMl
N7j@U92>QWafMgj5QhAmN7IjQ8V6PX>4PW]iPHV;RHZCVI26PG]eN7j2R8J1OWaj
Oh62Q8J8QXVG[;R_WYj/ZYZ<QXN5PH1nQ8V9QX^DTi6:SINHS7IYJG1iLEeKI61E
EEAADEUVL7=_MH1lKFAQHfQTG5]XMh1oNgioPhZ5OXZLYjZ]/k>d^;>[[J^XYZBR
/LG<a[o8dmO?`;Rf^;Zm`LS8^[6d]K6b_<>o_<2j/KFe/;6d[YjOVi>FVi>6OWMk
QHR8TIRJVYRGV9RESXEoMF][M7n0OGEbMWamNGI^IfUfPXfP/:BLXY^;OWIaL6YL
F6=^KFU^Lg5YIEmKH5mDAdQ@EEUBB3/d=2lZ;C8e?TiFC4e@Bda8?3a0>SLmC5A>
BDYBFfE_LG1jQ7mkQ92FUiJGU9:?RY>NX9jOX:2SZjf`]K6XXjB][k2c/ZfV[;^k
^KNZXJ6UYj>X/K6TXJ:LXj:NWjJ[ZjbXXifLVjB][ZZKSXf=QhR?Rgn6UIfLVYnK
UZ6UWiZHV9NHXJVZZ;Bc^<g5YiNNVXb1NgaoQH:4THn6OgAUFUePHU]FF5A@BD50
@Cdc;CDa92P[;2L]=cXm>C8^<cTf<SLl?3`oADiEF5ULH65VK6i^LGAaL79fNGQg
N7MeM7MmP8>3PXV>SY2CT8f=SXjAV9nUXYZFUINLXZ6IU9BEVYfIT8V0MgAfOH9k
NhV?RhF5PXB8Ph65QWn2Q7U_JEeLIVQSHfIYKFeZIVagMfmbNWj3S9JSXY>6NVQJ
EUAGGF5XL7MhOhMmLfiXFTe9C59@BTYBEUAACTY=B497E5ePH61NFEIEEUaIEE9?
Ce=IHVUTI6ikPHN<S8R6Q8N8P7^3RhfHX9nQYZRZ/K2_/:^[[k:ia<K6al:m_<?<
blK2`LBo]KBna/FdZJne^[Rc][jk/JZ]/Jn/YjBSZK2[Xj:MVIVDShj=S8^7P8:8
RHR9QhJ<R81kMG5dNGYiO8>;S96FTHf;R821QH5oPXV6PX>4QhF4OGIgP8R@U9B=
QH>5Q8:4PW]eLVmbMgUnQXZ:P7EcMW9WGeePHV9VLgekMG1/KVm[J69OIVeaMWMh
PXZ<RXR4O7^2QXB2OGj0QhnBTYBKViNKWj2QWYfT/;>_[J^[Zjb`/K>d^;fg[Jf^
/[N`YjFVZJj`];Bg^[Zm_;:YYZ:RXjBUYjRYYj>OWI^GUiFARhbCTi:?Shn?S8b:
RXR1O7YoPhN8R8V7OgAaLWMjNWI`LGAjOGYfLFQSHf9OGfM[JVIQFUQIF5MFCdE2
@D=6BDM3?S`n@da@CTHo>c`m?Cln>cXj>d14C55DD4<k>cm5CDmEG5eRJg9aJemK
HVYZIF5SK7MlOX:7RXb?U9F>QHB;T9ROWi^JVY^LWinLW:B[Yj>SZJb_/:jWXjJ[
[ZRTYZJVZ:FUYZFPVYZLWj6SXIjMXZ>NVYNBSi>GUI>GVYVCT9FEUY67P7n6RHZ6
NVi[LGEeLFQ[Lg5ZJ6abMGEbLG=iNGIfMgQeJFEZL6mYIEmLF5QKG5aLFUYJFU]M
Gf1UJ6USGf1OHV=SGUUKHVIXK71eNGE]K6aXI6AWJW9mQHZAU9:;QH>2OhB;RXfC
V9RAT96BTiFFUIBCV9^NX:2IUIJLX:FWY::RXIbMXjJUYZFPViNJW9nRY:>TXZ6P
VibPWiF?TIVLVIB=S9:ETXb>Ti:>R7mgNX:9U9ZHTY2BTI:AShIlMWEjOh>6PGM]
Jfi`M7EcLg1`KFeaMWIaJfANGV5QIFESH69VK7AdMW5]Kg1^KW=iNWAaMGf3RXb8
PGeiMW=fOWmnQ8V;T9JKViJCT8^;T92@U9RGV9fNViNEUINGUIFGW9jMViVIVi^K
W9nRXj:OW9ZIUHnBVIbKVYZIUiNBRXJ5Ph1nNGMkP89oO7YlOXF:R8J<SH^4PHN:
RhV4Ng9YIficM6iVHf=XJ6EXJFIQG5iSJVmaLFaVHV1PGEQGFUQBCeAKGEYGDDiC
G5iLFUQFDe5ADUEJFeUKH6=SJWEmNFeUIVehP7ioPhN7R8V:RXN1NWMhNh24QhnC
Ti>CU9JFVYbGTXf<SI6CTIBHW9nOXZJVXZBWYj6ITiBIWYnMX::RXJ6QWiZFU9FG
VY^JW:2PWYjOWinLV9JHUiVJVj2VZJVYX9VFVIjRXInMWIbNXj>NU8n?SXZ4PH62
PGj0P7mlMVm^KVaXIfMWI6=PF59?Cdi:A3`d=cm9C4U<D5EJGUiLG5]KGf5PHV=T
IVMWJW5fNgamNgeoP7ilNgYlNgj3RY:JWj6NW9bNX9nNXZR[[Jj^ZjJNVYNFW:BW
Z:BOVIBHWZ6SYZZ`/k>_[:ZZZ:FQWibKW9bIV9bOXZBTXjBRWY^KVibKVIfTY:RY
ZZZYYj:PWJ>ZYj:LUIFKXJ6PVI2>Si6DTXUnMg1ZJ6EVJFQUGUQMIfe/K6YWGeE@
D5EGD4Q2@4E>FUYDCde=CD]=E5eRGUYHFf1UJ6a]Jf]/LgYjLV]ZKWQlOhF;S8N6
RI6IWIZFTY>GVYbNWIfMWIjNWYnPWYfIV9VHW:>WZZJSXIfIUI2ATHn=R8F6QHB2
PHJ9S8n@S8N5PWmjM79eO7elOGf2Ph65Ri2BSi2?Si6=RHB4RXF0NWMiMW9]JVU]
LVm`KVEQG5QJHFQZK71/HUMADUAEDe1=CDe<Bda=DDe5A4U=C4Y9B4M:D5EGG65U
IVERGEiRI69OHVI[MG]mN7AfNWn0P860OWYkPHF8Ri2GVYZMXj^b]kBb];Jf/jVS
XZ:RXJFY[J^SWJ2UYYbHUiNFTi6BU9JETY2>SHnBTi>@SH^>T9BGVIVJUY>BUIJ?
Rh^:RHV;TiRLVY>>SXf;RHF2P825Rhf<QGedL7IjO7]hMGIlNgUiO81mLfe[K6a^
KVe[IF5OH6AWIF1FDDe>DeQLHF9MG5eRHf1MFeUKG5eNH69SI6MZKgInOganPhB6
RHb;RHZ8QHB7S9:JXZ:NWj>SXj:V[:na/ZnYYZNYYj6OXZN/[k6c];B`Zjfc^;^k
^[Nd/:f[ZZ>LUiBDTi6ATY2BTHf9RHj?SXf:R8R=U9FEV9B@T8^8QXR8PWYgO8>7
QhN8QH9oO7YkNg]gLF]WJViaLFi/JfUZKgA_If=TIFY`KfIOFEAEFf5RH5aGDU1@
DeQMHf=NG5iUJfi_KW5bL6mcNX22P7ilNG^0PhN9S8j?UIZLWYfJVijMVIJFUYZN
XjRXYjNVZZf/Yj>RYJV][Jj_[[2e]KBb[k6d];6[Y:>RXInPXJFZZjVUXj6LUi6:
QXB5RXjBUI>?S8fBThn7OgalOGYfLgAgN7UmP7ilNW]jN7YmP85iJeiIEeULG5iO
HfIXIEa@BTI5BD]9AC`e<Bh/:c4h@D]CEEYPHEeGD4]5@416CeQRK6m`Lg=_K6US
GemQIFU[KW1YI6Q^MWZ1RiJT[:VUXijIV9^KWIZ?RXnFWj6S[[RfZ9nHTi>EVjJ`
]KNc/:j^/Jn_/[Ji][6VVYBCUIJGWjN_/Jj/Yj:QZ[W4bm3?`k2FNF5LHf]jQiBP
Zk>]Wi5nKEa@C4]5>cHd<C4g?dUBEeQIEeE@CDPl:aX?4AlbB5IIFemVIUiGCdQ4
@3m8EVQeMgAdMGMlQY6CTi:=R8=kMWMcKgAlQi^_^L7:a[f_VhZ4OgUjP8NCWZ6S
YZRZ[ZjXYZ:OWY^HUYFDTiNR[;:e];6a[Z6BS8Z5PH65SYVSZ:RTXYfKWibKVi:7
Rh^<W:fa]<;@gO3iiMcG/Xn2NW1fSI6?TI6JXJFLSW]IACdh=SHa7aTN9c=9HFAQ
GeE>CD]3>c4T82DbBFV3T8Z3PhN9QXF2NW5XIViiPHJ@VIbU]<;;dLjjXH]iKFi_
L7R2T::ga<W;aK2KRG]eM7IkO825RYFPZZn^[jfWXIbGT8AiMgMdNHNIYJf_Z9nF
SHJ3Ph=lNh68SiNLWZ>OUYJAQH>:Q7]oNWb9U9n^am?Qm^[>^Z9lG61JCfN<SX6<
VIbNTXAeG4Hj=bTO8aL62a`_AUEFBD=3@che;A`:00036SURO8:0NWE]KWUgJVEW
HU]]QXf>VJ6QYkO1^jZEQFmFAd]EG6QgPY2Q[;2_Zij1IEICFV5ZLgMmQi6GXZbe
_;bf[ZVSVYNCTIFIXJnoc<o8^:JJT89hN7YmQ8V=TIRW[[2^Y:F[X8b:UIV?P86G
Zk_Dl_ooonS=YGUVKg9SJHfKUYNT/ZVBNUa4>SP_9R4I40<;9356FEeBADA9ACTe
:QD30AXmH8>KWYV>Q7n1Rh^0MF]RH7>>UXb8QhRCYK:eZi=jJ5M=EFQbN8:>WJ^c
]JnQRg9PEE5GHg=jOhRFY[2i^kVf[Z^YYJ6NW9^JVIVMY:nka<Jm[jRTXIfHUIJF
Ui^U];o9bkbZXYb<OhF@TY:CY[k6fOOoooodf/JNMfI[LFUhTYVOYkFjZY5iGd0_
91dG20<41QP]?eMPFTlo?dHl<2HG2`@?<UEiWJNPUhf;TYNDRhEoLVYbPYNSXIjY
^;o=e<Z^SWQPC4I9Ef9VKGV=WJ6TWi5lGTa:C5=NIg>3SYbaa<Fl^k6MRhB;SH^<
SY:DVjR_^<30]ZRIRWegLg9bL7R5R8jP/[6SXJNMQh63Q8>:TY:R^;o:goGoonW5
/XYLEFYhJ6^AWHb5U9Z6LFYB9a4?1P00000;6BTgCEE@AC@`=B/F2`H0000SBG:M
Z9bBS81eMWE^K6ELHG>=XJfc/J^V/;Zj]JF?MEY?CTiCGVanRiNT/kFUS75D@C/n
CV1ZMhfIWInTYj:MV96BU9ZLVZ2WYZBZ]KZi_knfYiZ>Og1[LgUmPi2U/kVo_;:[
XHejNX5jMXjZYZ?2h=oWoooolM33YX9aP8agLXNNXZ>^/ZF;N5lf8Q`@1`X=1`dZ
AT]?ETXg;B/i@3<]8`l00BE;JI>XZ::IViF9QgYYHVMhR9BR[K:/XIjMXJZe]9Qm
LfaYIF5RJGR4TJN`[ZRENfYND4M@I7J8UZBf_l2n]jbOV9:AVZ>V[Jn/YjJXYJ2N
W9bHTY2=R89mMgJ4VZZe`Kb/X9ZER81lMFe`QIBO[[c0amGSmOooj]6lRfERL7i`
K8ZXZjbo`[2OPU8V4aHN7b0W:RXfB4iDEdDa;C8l>c@c;BX/<TIXTZnm`JfCShmk
Kf]XJfehT:Zmc]S>_K2ZZjf`/jVBO71YJg9^K7fAVZ2WYj2>OFM<?49BFF5hUZfh
`L[4[IN<Og=nSYFMZkJg]K:]ZZV][ZBJV9F:OG5_JfIYMX^FU9VKU8j7MfEJFfE/
KWN>VYn/^Knkb>[mnnC8/XmYFW><MEidTiNEXjRBMf0m4@0630H92@/D8bli@T8k
<bHS;C@Y8bHS7B8fEWfLXj2NSXF9Q79PHVe`Ni:V/kZk[iV2N7aoPi6JTGebKfMO
HVUcOH><VI^@Q7EMAcll@U9WPYRV/KBc[jFKVI67TZ^k_/O?blG3`<2o]ZjZXibI
UI6=QHNDWjJ[/[>^ZJBOUXN0PXB1QiJW_<_8bM31_]GTk_7T`jZQPVU[OhMbLHnV
Yj>WUfiC@Al>6BH[:1/@4al[?4@j;R<D3a/^=cDf<RTdBUelXKRn^:F@RXIeHemV
LX:F/LgFd<J`VXYlP8nFUIFCPgIgLFUXI6YhMg5gPWY[HE98B4YCIgN;ZK>d^[FQ
U8elLgZ6T9^Z]kJ]XibHThZ4P8J:R8N=S8J1OGf1R92EVj2TXiRATX]lMhBHZkNn
a=3C`;:kc=CMo?omc[^^S7^DWW]TPYjGSYF@M5Q8<Q`Q;R/K61`L6QdY=38a=cLd
>DA;Cd`f9RHbCgBEYJVb[ifFVI:7QY6JXJo0d=C:_k:NTIbYYIjPYjFGRWmiMgI_
HF=`PHfBTHb7O6aNFUiYN8JEViJETXZ4QhV7RY2CV:6Y[jfRVIB@QX>;SXbBViVB
S8R3O7aoQHF6SHj7PH>7SHb5QX>9Uj>VXZF/YZ:T[L?QmO7Pb[VVRG^;Tg1NKX2D
W9bANfM=<aT@7QlA30T:3@l?5b<V9RT`=cdl=38d;c51EVf3W:b`/jfQWIJ6MFa[
LH>M]l[@bKf_WIBFUiVMWZ2PVY::Q7mdJVI_OhV8QHJ0Mf]QHFM^MGb2S9ZOViRG
U96<QHF?UYnZ[ZbXX9RBSXb<T8f>T8N4RH^4OH26Ph:9Si2@RhF1Oh5nMWJ3VYfK
Z;2^XY28VJ_6k_ook]NiVGamUHUTIXNFV:2WVh1RABPG5aTI5A8B5QhR:SLl>CDf
=ca:C4M3=BTR6RA7LYBY][Z_XIN;NW1hQi2EZ<[Wj=G1[IfKWYZCTifUV7mcMgUa
JV]^LGb=U92=QgYSC4I?FV9`QIBNYjf_ZZFOUiFKYJje^KJb/[Be/JVUYZ:ESY6?
RHJ3P7]cMXREWZJWWi6:RHV5Q8bAUIVNXj^a/JfRVjB^^L_SoooQ^jfCNH:?L4aL
PY:AV:>HNf99=2h/:RTV8AhO7B0d@Sm4CDi?De5>EEE:A494FgnLYJJa]:jVWYJ7
NGZ6T9BSa]oLb[Z/Vi:?S8f<Rhn;OWMeKVIYKVEOHfehMVIIEeA<B4aHJgZ0QX^@
U928Q8B6RXnEX:^_];Re[JFNUI2;QHV?S8B4Q8J=TY6CVINEUiBAShZ8PgU^JVib
Oi2CUIbGQgn1PhJKb_Wooo[B_Zj;MhVGMfAeR8Z6Rh1WETL^720/=SH/8ahO6Q8K
8RH`<SM0CeYHE4Lh<BhnHXJS/Kc0^:ZHTiVDS92IW9jZ^<32_[:ORhB9Si6GX::I
S8>0O75YIFE^MWYkNW5PDdU0AE9KJGR1Ri2<PgaiMGMkPHbIZKRn^K2XWIBEVijM
Vj:/ZJ6PVXf5QHB6T9NLWIJAS8B1QX^8QHZ@THn<SX^2P822P8NTb^Kbo>NgSge[
H7=kIV9mTHj9Rh9/FTD_:RTT92XV4`T;2aXc?DICFeYFCT53AS<X<3Y@LiV`_<O4
_KNTUI6>QX6;W:Znc]GGdlRk]KJ_XinLUI2;QX>6QWeeKfUTH5eRIf9EBd@oB5UT
JG1fNX25R96BR8F7S8fFZ;6c/[:e][Be/ZVVZ:NUZ:VSUHjAUiJCVInQXZ>PUhQl
O7n4RH^;TIfOV9ZRYZVOUYZV_]KWl?KacZfIMf5cSHQ`K8VMWijIS79LCc`c=SLl
>BdT71XJ;dM4@D52A3`f=S]1>c/o@5=hVJN_]kF/X96=T92GXZRY]]?YknG<]jfW
XjBZZjJSWiR>QhR7PGATG5E?E69[JfAMEeAKI6adNWYfMGIhNGYkPhb@Uj2Y/Kk4
^ZnYXj2RXZ2LUYFJW9^HU92<QX>4RXnDUI2>SHAmQHj>P7=fN75]N8R8PGn8TZO5
f^7Vmo34YiR0MHBDPFaoUYbKUhihFd0U5aLC6R8K5@h:1`d[>CTo?d=5>cDa=SH/
:2<^D7F@W:6Y[K>^VHb:S8V1R9BX`<cCeLR^VIBAR8F:TiVGU92;R8N6NfULF5E=
BU5IGF5MEeaTJ6Y^LgYlMG5fOH24RiBNYZjh_;Rc[jbXZ:RTW9VKVI6CVibERXB4
P7UkPWmmOgadLWEjPhJ9T8j7RY2@TINHShN5S9f`a^Soonk7[JF:MH6ESGJ4V9ZP
WYZ;JU<l8aPM;S@^9aH>418S=c`k>C@Z9blc=38[;34kE7JCWjF`[:BOVINDU9NH
XJVda<kFfM2jZJBSWInWZZRRX9nGT8f9QG]_IEmMFeaOGf5RHF=[M7QkOXFBU8j>
T8b<UYnSZ:b^[jj^/k:]ZZfZX9NCUY^QZ:bYXIVBTYNBQhF7Pgn4PGf0PhV=TY2<
TiNIW9bJUINOWjBedNceoooX^jFPSG9lXJ>=SJ6/XIN>NF9<?3Hb>DM;>b0B3000
4S51@3Tf=38c>Cdj=3<kA5UlWJfg^k6WX9bHUIRPZ:n`]/KAcl_5/YR4Phb;QXVB
UYNIUY2?ThmjIUeGDT]?Ff9UJFi`LG=hOH63P7emP8:3QHZEXJ6PYjj_[k:^Y:2L
TXR7SiBEUYNET8V3P81mMG5`MGA^LGYmO8><RXR?THIeKWMmNWR1TYVMYKOGkO?k
nMb_RG=UM8f<LFF1UHn>THM_E3`W8BX]<S@S5A0B6c5:D4a>AcP_;SQ4B3`[9be2
I8FLZKNk/:RRVYJHW9ZJX:g3g^_/j^;>]Z6BRhZ9QHB6RXnAT92=PG9WHEA6ATU7
ADI:EVE^MWf2PXB2Mg1_KF]cPI2NYZZ^];Nc[jjWVi:;QXZDVIZJUi>AShbBV9>>
RX1hMWQlP8^ASHb=TYB@Si6=RXInOXR;PX>AX;C:gNOek[ZAQgmbN8QdFFn<RhJ?
TGeXFCd/;bT[=RTD4Q`L7cLm=3]1?3Hj@4=9>B@U;dEVRY^N[KJ[YjNPWZ>SVYB@
T9nib]GPhMG5]ZVNV9NESXF4Rhb1NGaoNWEaJfIWHe]JGEiMGF9/MWn4RY6BSXR5
QHF8SYJMXjZe`L[Acl:i]K:^/KJaZjNTYJFPWYjLThV3P7mnPH>3PgmnOgn0Oh:8
SiNKUhf1MGN1OGN=[ko5gOGaim>aTh5oQHZ2IfEnQH26TXU`JF18>SL^:R`N2@46
2A/jA4iOHU93?CDh@ST`<3Q=KHjNY[6^ZJbVU8ZEUhZ3QiV``lkGg]W9]jVLU9>C
SXN:Sh^5QHJ2M6QRFTm6AD4k@Ta@Ef9]MX24Q8R7OWQeL71kQXjN/ko3b<_8`[Vc
[ZNRY:BKUIZRYJFVXY^IThV4PX60PXN9RXnATIFHUi6:RHJ3OgMdNhZCTiNGWKG:
d]?NjMFXR7QVGGF7LF5iUIZCUIAnITlh:Q`L:S0/6Q4H72Dg@D=:EDhi:bTb>c/d
<SU<K9B/^L_Ba;6OSGelQhZ9R8ZM]/C7c=37]J2;P7n2PWelQINSXIfKUXQhJEU?
BdQ2ADmDEUeUKWIiNGUjMW1]K6]]MH6=VJB//KNi^KVdZjJPUiJLWj>]]KJc[ZNQ
Vi6;S8Z2Mfi`MG^9V9VATI69PH61P81hM7EgNX>>Si>Q]/cJgn;QbYYiLg9lR8Md
K8F>PX::QW=UDcP];2DV:b4E6RDX=4A3A5AA?S4`=3a2=c4oCfR7WZR/][>XY:6O
Wj:TViBIZlGGgMoOelNgZYbDUIB@S8Z?VIbFTi>8N71XHV9PEdY4@TI?EEQNJW5f
OXB4PGilNX6:TIbX[[Bna<G7a[fj_;FZZJVVYJBSYjbYYZVWX9^EShb:QX:4QhEo
NWaoPXF4PX=lMFmXHemQKGEmPXjT/l;?eMgQbYf3PXF8T8UeNXjCS8V;PVeMBcH]
;c4c=BHB4ahW<d57BeMD?2`/<Ca4@Ce3DFN4X:nha/Vn]JbSXZZ[XinPZ;[:blcE
e<JgYYJAU9>9PH>;UIREThn3N7EcKF][HeI9@cloAeIULGQjP89lN7]mNWQlQYBQ
ZK6i_;Vi^[Jc[ZJSYjf][:^WYjFMV9bOWi^GSHF0MVeZKgAbLgYlN6i_MWMjOgmh
L7AdIVE`OHVD[<?8d]c:V7ElR8V>Q6UTN8AlMgegJEe;=R/]<C0a9Q0<5adQ;c]2
DU8n<cHi@4Dh:bllC6=nSib^][Fe[ZJY][Zc[k2ib=GJfM_Hbkb^XIbQXYJ:P7j1
Q8F8RhMkL6MLDU5@BDM:CeAMIV]^KG:0QX=mNWakN7MkQiRV[kS2alG0_KVd[J:N
WYfLWZ2PX9fHV9ZERhJ0Ng]iKVYbMgIaLWUmP8>3PGaeLVaVJ6mgNh>AUYjdam?P
jng?X8nCWZfXTX66TY:@ShImLV=@>2d_=SPZ60hB7BH[=d9AFTll;SE6Cddn=ci;
IhBK//38b;jh[jV_]:jYZ[:malk@dmOA`:bJSY2ETXb=Shj<RHF2O71ZIf=NG5aE
B4=8CU5EGVQ_LgIkNgQnQ85lOHB=U9bSZkO0`[ji]kF`Yi^JXJNWZ:RVY9jBR89o
OGM`KVe[JFagPhZ8PX5mNWf3QX9lOhJ6NgAoQhbFW:RdbMOKh<fMQ8J=V9^BO7B:
UHj@ViR4LEm5=D14@3TY6aDM8bXmA4UHF4Hd=Sm3BTLl@TiPNY:T[KJh[:JXYZVg
^k:ZZ[G5eM_KgMW<^jVITIJGTXZ5PXF:RHJ2NFIHD4M5CEABCTiCG61MGVQcNH23
OWYjNG9]LW^5T9^V/Kg0_;F[Y:JTVi^RZ:Z`[jRXZZFNUhf3O7YhMWIfNGf1QXn@
Qgj2PGE[IfibKW1gPhnETYFNZJnda];CeL2FNWfDYJ:>N7^8QX60Pge^IE<h<CLe
;bPL2PPH8BH/<CU5AS8P9BhhAD4k@eE/Oi:TZZZPUYJIRY2`^Zn[/;[3cM?GgMW=
]Z>JVYVFTiJJUiRDS89fMFUHDTa4A4U9Ad11AT]@F65UI6MdNgn7S96EThjCVInW
[KRm][:`ZZNTXZ:RY:bf]Jb[[ZFERGijMVeTIg1]LWekOHB;Rh9iNgQdMgIiO7f1
Ph:6SYbV[;S6d]KJeKR;MX:M/:fFP8bSXiVDSWQRG54n?dU<BSl`7R0/<CPf<d=A
AB`S<T5AET8hAUicPiZUX:V[WibKWZR`]kBa^<GFgM?@c/B_WYVFUiRFU92:Rhn@
SH=kMV1IEE=BDU=<DE9DEeEEFFYfM7AmOgMmQ8J:Ri:QZjj[[l78_;NdZJVQTiRK
W:R/[JjXXJN`Y8QnNfe[M7A]JFUZJfebNgY[K7M`JFmaMgf7S8R6T:Ji^[kAg]gH
d;^BO8^X]:R9NGj2R81kO7E]H5AACdHlACdP6B4e>CE2BTmE?bT/<3a=Bca4GG21
SIbW[:j`XhnBVJ2]/YfHXK;7dmOBd=6mY9V;QH^;S9:CUYVKVHj;QGa^E4]=D5MI
FeiNEfAjLfYYLHZ@O8bLR8V<RJ>WVJfl_/_?^[6VVI^HU9nHSYFBU9fIRI6DMV1W
KEQ@GEEJL5mRPXEiNV]OJVe]KFIUMGUZLXZBQHnLVjZg^KFka;j/UiFV[[>JRH^0
OgV4R71B?bd[>U1MHUeA>BXY8aHK>dI1B4La<3i6CdPc:T]RHhFZZIfKW9RPYjbf
`<W8_K:ealJa_/k;`[Fa/;:b[kBd][FU[k6DP6YJFFAcMVUXJfIYEdI<Kf=cQWJ3
PG9jRgUnP=KoX7Jc/j30_KW?c:jNUij2LXVCR8fcc9:2XH=^L5m?FfYgFgZWIdAI
PX5UHVacHVIFK9B9JgB2OiJ]ZJ6halOGiLb[Yj6EY:b5KFefPh:<M51ZI3TZ@2h<
;UHR000G61`[2@/nDcHb>AXO=CPa;cLnIGemQj2^[YN5TZ2MXI:6UL3K`l;?el[3
_:FLYjfRPh^VTh26TI6RWGicGe9KFV=VDUEJI8F=N7AhNXVEY9b:SIVSYJ2D]kfc
am;Ia;WDb[Jo`KZWTJ2iYj6iZXjVZi2ERgE`J8jGRhU`OinQRH6CVYB?Ph=cMh5a
O7agSLC=[/gZn?oLa<Vo[ZR[Vi>/YXj7QhNFUGeQHW9Q=1TH7c0G3`l>7b/[9a<J
@D<O00X/FE4P23A[OHB5O8ne[H><Xi:8U9ZPYI^Xc;^ne<;0^JF1Phn3NV=PIg=d
NXJ>S8EPEfEGCeQCFeE9DVIVEEalQG=]J6n7XI21SYfSTXbLXIbU/m3;ZZB/]9Qo
Ti2MWZNVTInXWX=mO7AlN6iID6YYCf9jQH=jRI29KX2FU89NMX=iNi>PU9jocmWS
hmZgWIbEWZf[WH^1OX62TjFBKeM4CEEKDBdoDRD45dHn;3U@ICliD3Lb?eEE;d=Z
RI23TYF[^jJCS9VUZY><T9F/al2c`m[A/IN[ZhR6OV5CKgiZOW5`TH1eNU4`CU8j
?E9LHEU4GfeYNW=DJHakH5eOQh9eRXje/9^/[[K8ek^[`;2_UI2XUGfH_l:JW9b=
ZXQXRjb5AeZFRWmcMXj8Y:28VHjHX7=cMY2JNgfW_JRZb]7Eloodf<Zh]Z:L^kV^
ShNNVXj2S7EQK6Hm;3i7B4P`7BhjB4aCG4iCK5DZ<TiXFca0AX2US8VX_lO1]JVS
ZJZgUg^:U8n>UInU/Kn]TifBRX5_L61gRfmEJW]/FV1G@e=NAR`bGFUHG65SHE1Z
RhN0MhbSOf^9V8AnUKjiVjJndLnd_kRAUjZ[VIRPSXJ4Y;FTX7QWOg]MHFeRF6Ef
O6agQGZ?Z:2HShbDV85cSYB9RIbm`l3?e<nnaljgVI2]ViB_Tgj2R9R@KgfBKClh
C48j?RT?1a`G6D8d9Si<HDHnE4<k?R`X<TI?KHJ5Y[Z^PX2LZ::DP86ETH>=P::]
U9:QXZJXR5M@J6YaJeEPO8j;LfQIG6IECE=IF5abFeYdNgafR9AgJHIoPhenM8JJ
XJFHW[;5bkC?aIF[[I^<RXN4QgV8VIRDNXRFOXJAMUILOH>5S6]RKh:9NX1iKgj1
O8AoJ75jSJZbYZ?3dMSEakJJTIjYYINPUHZ7TIZ8S89WKGiiECQ5GUA:B2TS?4AH
I5Y?DemGD7N0E3UFLW>3M7^PZ[32fkZF^<>YUibNWYZfc<W@bLS0Zl3Lf:bMXI><
M7:;WJ^AOHjEYXYVGdmCHFIYJGF>Nfj2V:JYVXJ3RiZFW91XL8n/Z9NM[/c7^/_>
/I^JUY^e/i5aR:>/VWaiOGR<UHYkOG]/IFiiMX1bCF:3QHEkKG65VXQZEfFHY8B<
XZbnb=CAcKV>OYBOVY>;Ph:AQg^7PFeYJehk:SE0BCD;00XS9aHR@592=3U:@T53
8Q`fAUa^H5elY[ZUYk6IY;2f_jJLViVM/L^^UI:?Ui:GXYMoJeURHW1lIEi[K7n3
Lf15>SE3CU1KBDaVEU]]NFa[MWZ8NWR7RWeaO9>?SYB8Tko4][2CR8J:SHR<KEIZ
PHJ:PUaHJe]DJG=RBd]CIF]_Hda:JX2R[H=oSH9oV8n=P7B9Z;VRZ]GAf?Oeg[n^
X8jB]k2BPgjFY:NeY99nMFUJADICB34?5bl_=ci8CeAULFA?FeaJFE5AE5eeUijM
Y:^XT9jd[L;0Uh:0W;b/ZlGC^9:TaK^k[WAVQIJ4HEi[I7jLWXiYFgA]LGADDUeU
J6fGWhf0PhVBXj><TjNAN8F?UIF;VJBbdlk2a/6n/Z:OX8VLX8^P];nVSYfGPIf^
V7QkPH>@U91eJGZ6UIJ<Pgj8Qh9eR:2BPHNGXkg4/L;BfN7QbJV;Q9NLU8=_NIZS
X9fRV7UdR81R;c9@Cd/n9QLnASU8B5QOIVaND3/kADQ<EE5=LYn[W::YVHn=SYV]
UgB6RHV^^;Ne[<32/ZVLTgUdSIa]?fQ/HX>IQfQQLEEPOePe9SY3?Fn8JFMYJGfN
Uh=^LX=cPIF8OfUgZK_JcjNH_mJgXJ6;RIF5PYVS[IE[Q;6ZW8AnMe]LJgUYDUAV
I6IgUYEnOF]TKh20K5UHQiB3THV0Pi[<h/6^]kBNQXMoO9BQWIJ:O92EOVmIHEHj
?2@630lT3P00<C@S9cDg=T98=B@c>Clb?F5WMGj9WJjXW:N`/IjP[J2:TjR[[K6m
`kO1_I6HXYB>MFefOGQTKHFGTgAQHfMKHdTH7C`n?f22H4YeUYJ?RXb7O828TiNW
XYFXYk2n]kbWZl2h[::BR8R@X9^;PHf<WZ6<SH2:O5UTHV9cJf=CHW5VL7Z3P7^@
SWIdRh5TPZ2LVJC6dLSChnOGfLf_[:fHRI^YX8n/]I:SY8fDSWIQDE5DCD4]:CY7
De1BL7abJFUVKH9`EeUWI51TRYFQZkJZUkS5[kJo^9nacl:VYkoHaZboc[6?T8>8
Sh^0Mg=nRXJ>Q7^@RHMaG6aSF6IZKHFQZ8f8VkbnXhZ:U9fOT7MnW:fSRX2HZJ2L
Zj2DVifLRgb3U7YPJYN[RhB9QgYPGV=OG6]YEUmaLGMiIg2>RWUhMGYoPg]hMWB:
X9b7U/G=a/>]ZIB:W8EeP7akM8V=QXJ1PX9_G594@EQ5<c/_=C<d=S0n@4=UJUE7
G6a^NFYEGFa_PYZ[Y9>LY96K/kNYPHBFYk6cY92RYiFHWINFS8=kOW]ZFUM]Nh1/
E4iFJEa2?DU3:d=@>c=<MXQaLXB4QXF3QJ2cUGf@V9fVX8b1V[RmZ8ZCVIFMYhi[
M9>0K8n5Oh=lK75cHeIACdYHFUMFEF=TFEaYIWF0QW==F6m_LGfEUYFb`<CChm_=
akNRT9ZPUIVIRgF3V8nBRWEWHfU/Ed0h;28I7AX/=bhW:4iED59:EF=VHV=;AV9c
Uk2^XYfa^Kk3cm6mY:>fb<[;emO@e]G7_JjIW9Z6TiMbIg^<PHFMRFEVNgI]J69@
GWAeKVn1W9:<X::J[[ncY9f`/Z^hZiRKXJFNYkJYYK70_[BUTXN>Zl2WPGf<S7fB
RgMjKVY[KEY<G6UmR8F1MhbPVY68WIN@RhfFQYBl^;WWl=_9d>?Tf;:CY:2=OhV:
O6UcVYN2N7=_GFMX?aPYA4=0>SHk=b/fC5dn?U96Df1XLV5NN7abJX6CS9Re`J^Q
]KJZWYjOWjnKR9ZGVZ^VSh27PfQOMX5nGUIVKEiZMVm9@E]QEF9I>d=OO6mWIVao
NiBTZ9eoLhjNT8NGTh6>Z[VRWHQkRIZOQ8:ANVA/Ohb>PFQSLi>AMV5MFdiIKfiL
EVYaJgn2IfMeMVMIIXb7HVe^K8>EVi6<YK[Ef[nb]:jQYjF?OhZAOVUnNV^1PFi[
IUU6>c<Y;CPn8aX^9R/c@SLO:DE>>TYhLe5GJGmfIW=iPIbOY::AXjJLZKJg][6Y
[/?1ZZRVS8bS[:66RgmUKWf5NWmlJV1CGV9CAT8j>DiNFfeoKfYoQhN=VI>4PIbk
]KJ/Yj_0e/Fe`<2aVYZmcM39]9nM/[nl/ij@VJ2IV8UfKVi/N8:1PFmRNYV<JfEj
MFj;UhF0TZR@SIbG[<6k`<SJjn[flM_2a]B`SIfZZ961Vj6;UY^<Pga[AcA=Dc8L
6Q<L:Rhf:S0Z9S]5@D5EIV1XP7eZN8AhR8b[aZN_cL[6bm72/Kk8bKkEg[JKXK>Q
X[FPOfj0OFf<SF]_R7IFHFiQBDE9E71]I5m/OG5^MGA`LWQiPYNXZYBJZjROXjbU
UYNb/JnTUHMlUZJARhb6PW^3SW1]Ie=^L5e<DFQRGVmgKF9_O79^MW5SMHR>R7V:
Wj:Y[9fl_ZRe`/c5clR[X:FIQHElN6QRKf5BGF]/ET5?EdPd<B/K:2HM7R/[60@B
<SLjBTM1D5I^OG5YDEj;Q7MdLhVEXK2`]JZQX9^Q[jbHW;:SRXNBS8JAQHB5KG=g
LfeUOGQ[JVAPEUaLI7AiO7USJXZ8Mg1bKHNYTW:4SGf4WknNM8:?Wij<VXYkQHZI
Ti6BS9>MShN>PXEoLGf0Wjb3GEMSOi9lPHUhLh:QYXMmP8RHQXfCUJ62Pi^W]:J<
X;Bec<fm/Z6OUIfeXG]/LXRJSFaJJWadIVmSGf16BCdb?SXm>2d^>DQ0<TEVS:JK
RWmoSJ>MTYJDS8JNa;fVZk_4b=C3]/38`KO6a:nb/JjIW;Jd/[:GN8:_b9YgPhAi
NX1/F61VDT=HIea_MVINNj2FRifJQi6f_jBU];BW[[FGPHZCU9nbZZ>l^:RV];fP
XK>JQi>TY8V2RGj2Ri:5MHInEfR@P61TMVYYR9aaHWN7Q7:;UHB@ZjfX^/n^R9:N
Xj^US6m`LgUbJF5?F5]IBd9JF3dmCF1N>C8Z6B/e=2@:62m2CU1IIee;IgaOHgR2
MeQhWiJ<TJ:NXl;6_[Rla;Bja:ZARXbFUhjGPFabIUiUMg]XIF9TPX=hJU]ECE1=
AE1:>e9fLUACHFA^NGamK7>@Qg5WSJB9P8F:PH6FXXn7T::i[ZB[XXfPYh1aL6ma
JgUmK6mgNWmhNH9jN7Z2PGF4THnGTWalV9j>NHRPS8jRXj2]_kJCSIRGSXJ4NVin
Oea9CEU`Qh5XGVE_KViNAdHoBE8j=4A:>R8cA5eYCEicN8^DTXQnOI:COh29SXB5
WZJ>SiJDUj2^X9FHRXRU^:fDWKBSSHn5Mgb1QXMiO7moRIFKVY>=TYV4KFMmT7U/
M7F7YZNS/:JIVjZc_KZMV:J_/J^NRI2HWJJf`[Fga/B]Wko5Y9nWZkFe^9mlRJ^g
/ZJBUZVSTH^ARWQnTX=_PYNLRX1oU9f6U:^PWkG5^jBYX9^OTY^DO7MZKWakLG20
Pf]KJ7EaKV=MJVmaIf5NBCaII4@]?daGIV9FATmONi1eJWIeNGahK6Q^OHjCP8>O
WYN7QXF9U9>BT9V^Z9jJTWaXKhB0J5aePWYjPgeiSY5jJ6ilPGefOHjCQVmbOHJ4
T:FGNGfAUi:?S8J<RXB9Uj6NY:6AQHV3P7=oUXb6OWAhLFE]N7^0N6IXLG]lLW=Z
J6YaM6]jOe]@IFiPGV]QGfM`NWQmN61iUhM`MhV0QHalKF9aP7AeMEYJKFiYED56
D6M^DTeGEE1CFU]JF5EPIea]Mf1MJWI]Jf]IBeR2Rh5mNh2?WiR0P8B4ViZ3OGb1
S8:3UhacKH2:PXFEQh:OX92GT7elPGN5VIR4NXJDV9RLT82;TI:MXINAQXB@S7en
M7V7R9JGQH9nPX]oQJ6PU8N=U8jFUhZ<P7^:PgJ:UHZ?Rh^9RiZ?Q9FIW:2NWiJO
^kJDP8fHUijb/YJ:OWnN[9VCX8mlPXN@VZRQV9NY`:VR[[W?dJnKSijn[ZRWUhZ3
VZ^HPhb7SJ6KRgioRhb;T8n8OHf9P8IkJfMdQ7MfL5QXO8R2Q8aiK7R=T8=]IG63
RHR<N720UZ:LOg23VYjBSI:?NXFER8F4QWUjSiRJP79`L8B8QHf9K65iR8Z6Q7QN
MI1oNWQWJh:@MF^0NV]cNGI/OH^;P5mVSiF<Pgj=S8R:PgEUJ7b5QG]oP7mfL8N>
Q81eKV]hUI1bMI^ORXZ6KgR2OiBKQW9/JFUmSh1EE75YHfEdNEaGOG9>DfY]L7b5
SHR3M5aVM7J3O71ADg9TCTA@FE9VK5aQKWJ2PfYVJfafNg]mK6a/EE]QJFaHHFiT
FUQCCe9EGFUVHFETJ6maH51/RXN9U961PHb7RGioSh67UX5nXJ64RiB3QYRPT7f8
Wi^:O82?VIN3QGi[MgmnMFb<ThbJSWnGWhb8O7R8T9:PV868Vhn4SI:>R9JOTiRP
VinPVI>3O8^<SINPUXj3MhV?S8^?TgM[Q9RNRVUmPW22WIn1PXZCW9RNSWf>WJ:S
Vh^;/kfKRZBYU8nW[Zg7`Z:9S[O1VWF5W9>@Shf4RYZCTHQiQI>8NWYiNGMgR9BK
UX^9TiV>TIR=SHJ3ShMgQXfFU7Z1QHZMShB?UHn9V9N<PhjJS8bLWG]gOhJBSXj0
GFIeKWb;OGN6O7f:SHn4NXFAW:JDMWb6NHNFSWU`OH=oPh1cOhV4P75cO8ZIT7e_
N7n;RgakM7=gQHj8OgQmKVEkSGaSGfn4OGMlNGYnO8R<PFQNMHn=MWEkLWBAQFMV
IWioJ6eWJGE`OH1_IWN3MW5YJWA_IfY_IUiLI69OL7YkJV9PNH9hQG]_KVibP8V6
OXbGQ86@Qg^0QWY`MFe^PhUfG5A/Qh9TFF5^KfYnO6YSK7i]Gg5XG6MZKWIWIG1`
L7IfQHM[F7RIT8emJ6MhTi21K6=aTYEnQhF2OgnIVX9nUiekJ7jKTW=/OIJBPgJ0
NVn<PFYZLHb4NHZ?RXUkOXmoMX^>Oh6T]JVJYKJWW9^XY9>0TiMhNHF6QWa`SIVP
WX5iOHBBRGIcO8>5LgMoPgMZKWF0RhikM8NGQgf4QXnCNhNRV8V;Xk2QY[6`XJ>U
Y:na]jJIZkV^XINDTXjHTgQTN9bXVhJ0PGmfPYR@SH9XHG:?Y8Q]MXfNUhf7RYjL
V9VLU8:;TXEmRI1iLX2<R86GS7f:S9F@LgB=QGb:THN1QHF6PhB2T8Y^Q9f7JGB0
P863OWihNX:6SHf<T8b8TYZUXHQoYKneZYVESWf8TG1eVj:FSXJ3O7fETV]FM7IW
PWmdMHN8J6UTEea_PGimJUUOHg5gJfi`OinBO7EbSI9mO8R0HgFBTGacTH5aOHJ>
JFIaIfE]KVATMFmXRj1aGh:2Ff:5NemQIeaVMGikI5ebPYBJOG>7T8Q`MXf2JVim
LGb:OGAhOH^4MGE^MfQSM8=iH72;RFm`O8AoKFmXJ7J7S7e_KXJMW927PfeVQI=n
O824SGmiOgiiR9fHNVMoUh]kKgEhF5IdLVmoP81]HHF<NG=lQG5MKWe^JV]XJFUQ
IgJ4PXN<O6M_QhmiJ7^9SY6<SXf7S:2VRVidR8bEUXR4MWf<PVm[NH1dLGj4SXQ`
KVU/OhJBRg9/MH6CUj6ONfn<WhakOHJ0RYZMUXnNYj6RXI6<TYZ>QHREUin^WXF4
U9=oS:FCP8Z4Tk2]WI6BWJNPTWQdSIB>SiF=LW:U^9ElM7N2THn?UH1_RZJUWX^:
TYj`/:FHR92WXiJ5QI9gO9j@MXFITGQlXZR;QGmfPhUgJG5/GVn7VIAhMGb4VXIZ
KFEZS8EdPY6IUY>LT86<VZNVQ8BIWjR`YI>IZ;VbTiJOV85nYJF<PW]dRijFShf7
LhBERGaaQ8Q]MX=jJV1cRX20Thm^KY>FPVi]IV1[Hfb6LfaoQW]WNX]oLfeiOg9a
PhN3OgMiPGYeOi24F6ZFQ6EcQ6mQO9EkIfUWMGmoNFQQEEZ8TgilNGj6TYF1JfIV
MHB3K5eIGFmlR7aLHg60S7f<RW5cPXb3HUeYGVZ>RV=OKfI>EgN2JEiOI763PF9Y
O7j?SW]ZLH=hK7AhMfa[O8N5LFYlQgEVK6YJJ7YcK6eTHH:UTWbCRG26V7APLH5f
MXYfIG5hLW>@T7UiQ7IYNgeWFff7S8jBShV@U8EiOGe/LXN;Q7QhRI61LgAkM7R<
R7j=UiZMUhf;Si:@W:ZSQi2RXHUkT9F4OgIgSIR=OXNLUhVCPfemSiRNS89eMIFO
W9V3Oj2VX8IkQH>DWJBNQXfNYZRKS9BLV9bITiF:TjJFQiFJUIfKThbBTi:EOgn6
PH^>RYBGSi2;TIF1SY>@T8RJUh>8Q7j7UiInNhR:TJ:@J7RAU8^5RH9fQ:6GRHB4
RXVDQfj4V9:9TIb>N82OWWedN7UaJgIbNiNBTiJ2NHVSXHMdPJN[SX5fM8fBPGAd
HfN?T6EJM8MoN7YfKFYfQWM]Q7ehUYanNXb>SWe/JG1jSHMOIGeYJh:0J59kSWb8
Oh6>W;>AJWj;OgUeJg1mOf9XUW]MLgeXHeaVNW5jLF9gQ8QgLWMdQibCL7b>OgjB
WI:5RJFYQW^7RH:5NFENIXJIQh>BUH5jNWAkM6EQHEQKN7eQDEAXLV]PBD5?H6AC
FEU4DW1`EU5LL7ImQFaIKgQXLg]hLg63OWN4R7]YOHajMFa]OhnCQgj3Qh:6T8F4
TXJ8Pg=mQXJ5KWR9OhN8QhfCWZ29N7RHXHV4UYjJX:^]W8N8R8nGSI>EPH:8SY5l
JG9mSHV5QVYUNHf=NFMbTYJ7Q8f?V9^@U925RHVDXjF>RXN7ViN3MhB@S8Z9Ng:1
RYNNU8IlPH><V9bJPGF0QhR7NFf0TIRHSXjCUI:>THb1QiJ;Oi:OTGnFXXb>VJnd
/jb[];JbYIZKX:6WY9NDPH>?TXQhKfZ0PGEhKgAnNgmiN8J9QX1jOi22Mhb9M7b0
PiFAN7^IZHmnU966W:fHRXnEYJnQVIVFV8n1RXb5SH1hR8R:R7j1Ph>;RX26P7Qo
KF1UJGM/L7Y]M7V7S7Z4SHAnO8>>VI1jNH^FU8mmKWN5QHQjN8=lLf]gPX64OF]`
M71dL7n>SXaoKfmcO8F2MgIZFFaiIW24NfMWO8F0Oh9fM7f2RXZ6NW5lNG^8Oge/
Efn<R7j1N71nS8iiJVYVNHIlIDUFGfMmM6YGFgUeJg1OBEA]Oh5fQXnCUXf<QhnN
VX5dNVa[JFISDD@n>cY3D4lnC5A>Dd=5C5UaLVUXEdUHMGeRCEeKEVMVJ7AkOiBY
YJ:NVH^>/;jNQI>PVYNP[J:<VJRHRHbDSg]oVYJ5RiNKWHb9XIf7QX^7MVQbTHY^
NXV3M8:SY9>NUhFEZ:^MQGf?ZJnLRHjGRi2WXg]bRXb9RhinK7bHVHR:QgEXO9>8
N6QYK6ieMWEnQiRAS9F?WJVZSgb?YIR3OWb2Ti:DWj>VVY6CRXZGWYJ>V9ZCUYbJ
TYnWWIfMU8fHWhn4VZR=PZ:]YJ^`[Zn^];bl][6/WiZNTWe/IW1^KGQ_KVIFGfih
Q7ekNgR1OWQbJ6Q`LFQFDEIFFfQbMFeaQhMlRjZbXZFk]k2bXj>QU9Z=SIfDQY6O
T8ZBUH1fKgJ:RHJ9Ngf<Ri2:K6=]MGQ]LWUQBeUOJ79SK6][QGmkPgMfPHIjNi6E
RWnBUH:>X9j7MXRKU9NYYI6FXjnj[9JARWn=T8MdFFJ9SX1hNWYhQI:7Ni27P8=c
KfaXMH:5OW1/KGB1PGYhKFUcNFmSIfidNGagNW9XN7QhOGQ/I6YlPFa/KFE/LVmd
LF5AF7AhJgEnO8V4Mg]hOX]`L6iBAD54?cU6CC0[?T=3Cg5^CSm3D5aGAd]5@51G
BTM:E5eQFU9TK6=SJGJ<ShJGYYjASJFh[9NCXIND[JAmNHbP]k:_[IR@Wk2eZ9B3
QIJEQhV4PHF<TX9gPH:8Rgn5U8V6VIJKYI63Q9b_U6m/QJ2JSI2>Si:HYifAVJFQ
XJB`/:>DRiNRY9NBUXn9TjfdTh^UW8b?VZJNOWN>ShF=U9NLVjFLRhJEYiV;SI>>
PX^PWYfNUhehPi2@QWMoSH9eNXR@PG^4TH=eS9jANWZBVi2CU866VYV:OH62Q8>>
Yin6Q9BXZjFUY9nBS8b=QGAcLVe]KGEbJ6IeQ86;T7m_LX6>Qg9PD5YQGeiEF5aV
MGI^KX:>TXn6PhF<TiJ?ShJ7QgenNG^2OX:;UhajSZBKQgIeRXf;QhN6Rh]kQI2>
OWQgMh2BViZ<S9nLP723S7QfN7AjPH66PWj0OWYlOgQaJFYgNfiVKV]PHgmmG5=O
LXF5JE9PLgb2P8B=TYJ8OhZ:SHJ8UHj0PXZ7OHFBQVYRJGf:Mf^2QH1lM75aOhAk
MG9aKUeFHGN0KeY7DW1lKfMSHVijQGmQHGQmM7=dK69[Nh:4QWATJH>TWW]VIfQ`
OWi^GfafN7AZMWAcJVEkNfiZMH^DTXn6MWV4P7]gMgYkL7Z2L6]/MhQjL8JFTXN2
QHEiNXjGRWn3R8NBWI9jKgQeMhB<P7N1RHZ2PhR3Q8MlPINDOgf;SiFGShN1S9BJ
XY6;W9ZHXjFWXYfNYInLXIja]YVIWI>AWjVNUI:EWJ>UWYNCRXZIWXZ7Tib;OYBA
PHN?UIVWZYN<Q92W/jZPWIRCUjBPV8b>V8f=XZ6;QH2EZIF7Oh26RiRGO79nSHn1
Mh1eIWZ;ShUbLh:0OhJ;OFilPginPHF6QXF9SXZ6TXimOY2LTWahO7J6VIMmIfR3
Ui>2OgYaL7:@W7afOHFCS8R8JfYgNhYmKGV6PVeWOhj:OgAoQGYoP7ekO7ihOhB3
QXEmN7b3OFUaP7IeQhYgHVAhM6IMGVQYIfAWGe]ZP89WHFI^NgUmNg9ZKG]nKG5e
JFYlRGedM86CU8elKW5nO86<PWEiPgmiRY60MW]lOhNAQ69SNGUiN7=cKWf6LgUi
KgEiQhAdNGQ^PHN1OfQRKGInQhj;O7:2SHB3P868Q8F7S9:?Ui1iOhb>RXQmOX:3
R8ZGUG9WPI^DMFQQF6V6Qf9<EVE^KGajI5MJM8B0Oga^I6bBW7Y^P8MnNhIkLh6?
U9BCPWIjOGJ4SGYaJWBAQW^<OVQ^Oh=aIgMlPY:7P7aeRiF;OWEmSI:3RIJ>NX6J
Y9j0N8nIXj>MThB5VZ^LShB<V8JI^IefKgb=TYBET7mmRYRNUhZ9U9VQYZFUUY6N
XJFJQXN:R8j?R9FWYif?UJ2MXJNTWiV@R8^IW968Si>AViB0PWeiRIJER71fQGj1
RWaYKgYoOgi`IVj4TXJ1P8B8RI6@RhN4Rhj5QYN;N7V=ViR=NX6<Ui^EV85^LWZB
VHj8PHbBSHJ3S8EhOGmjT9anM8nFPHB?U8f6RY:KXJFGQHZEVIVDQ8VXXX=gPXF;
RgioNVYgL59KJ6agN7Q`GDiJKh5lIFaeM7M^IfMNHgUgJ7V@NV9/M7^1MFUVLWEd
P8f8MgfGX9fAT8MgTIR:QG^2QX2<QG1dMVn2S7]YHfU^JF]XCe5RM7Q[HFadKVib
LW1]J75oOgMhLVm/N8j3K7R=SH5aN7ecOI:?O7EoR8jGUXMiLVakPVQFFF9OG71a
If=[KUeZMg=SGVa[IgJ4M6]_PI2=ThAVLhN:SXf4NGB5UY^LUHF3R8R<OW9jQ85e
J6IiPGihM79YIFicK6QRIW=gLVIPKgmgOHeoOXIoQY6EVXmoO8B;SI29O9>/Xi::
Rhj0PYZFQhRBWYnIU8^JYYZGShJ5SHn5R9NIShjPX8R;UHAnRY:5NX^8OiBHV:6]
ZiZHYjfTYJFJWj:ETXnCW:2YXYb;QYbUVGQbSYBBW8alMX:MVXn7RY^QUHJ=T8j9
W:^DS9fPVj^^VibXVHfEX9f<Rhf6UZNQSi6PWIN9Q8V6Mg23SWegP8b<OhB9N79c
NgakOGEgPW1^OGUhOHEoN7mlNhF9QX:BT7MfPhB7SHUfMHNGThnLR7J8T89aMX=m
NWMdN75]OWmeNgmeKFabM6afPGMYKg=hOX5mMX66NG=_JFefJFanOGn3OGA]LgEc
LH26OGYfMWZ2S8ImO6maL7^:NEaMMh5lKf5PJWN4QWU_KG9fNh=iLgA`LWb2Ng1i
OhB0NH1lNHB9P7QiRXAgN7=XGEMSKEmHIVaNEEi[He=IHUIIJfiJBF1dIV9YIf=V
MWQUIGIcJGAbKWYeMhbBNfm_L7V6O7b1KG60Tj:=NhJ4RiVNVXj>VYjPXY5hPhEn
THUfNG^0PXAiI6n7PWEkRhekOXj;Q8><R8F<S8QgK8>MT7QgN7nAXIb6P8=oQIfN
T8=nRH^:U9bDSXf;UJRe[ifBRhR@WIR8PHJ<SIB@QXZBVYR?Si:CRhRP/jbNV::U
XIjRYJfZ/ZR9Qj^bV9:@ShN7X9j4Q9NKQWfBUhfHTGinQiVGPhn?QY23NY:MUifG
PG^?ZZNKWIjMWZ:T/:ZRZjVQW9VAUJf_WibNUYBPU8bDWHedIfYjSXQlPWY]Jg9^
I6igKV5]NV]AF7AoLfALHVifNG9UK7]lPh=mNhF4S9B1Lgf2Q966L6U/LG5mPWI[
K5mUO7j1Mf5MJgAeQ8MjMWb@W9Z7NHJ;TInKShF>SWf9VYZ;NgQaNXmoJWR2Q8>@
TFENO8f<O79`JgAmOW=ZK6abJFe`GEURL6UNHg1WIg]iN7f5RXj;Q7j2QINNRGEj
PhVFU7YcLVa]M8B8P6I<Gg]_IVIOCUEhOfmNEfQgP7]VIG1QIVYLIf=HI71]JV=L
IFmnN6E/IFEaMgmkJV]/O96DT7UTK7n8Uhi[G5m[OhQmIfN:UWiaKVn;W9N6N8^?
RI2BRhF0PY:FVIF6PhfEV9bXWX^>VjBg^JRFSi2AXJZEQ85mSjV[Tg]_JGB3Q7ij
MhF;NgYcLgUeOHN2Oh5lNGEmPgfCWhJ1UiN:ShnCTHB<Sh^EU8f3PIBCT9R@Ri6J
XZNKRXF:TI^FS8N6TInJT8f<PG^2QhN:TI6:Si:7S8V@ZJnMSi2DYZFGVYnJXJ^L
TIbJTXn4Sj2LU8b<RX:7SiFCS8^=Si2>PGM^PiZBPWAhQH>;XiIgNhAiNWU/M8B9
TWaZNh1gN7n6MWF>ShBEUhB0MgNCV9FASXYeL7UnQhUkH5Y_Lg5YHFMhO6eQJ5Y:
I7YhN7AkOW=UL9>:M7:0Qg^5VHijNHZ?NWF5ShB2VijIU8fHUX:0QXb5MWJ3PH=h
OWQULgImTXmhG5AQMHb<NE]MOhEdNh=mOWMWJGF2S8MgGF]lOH:0PXJ9Mgf0NXEi
Jfe[J7AfJfIjPgU_N8EhLGEZGW66QW]THgIdJf]aMWIjQHMWG7Z;SGmcOgiaO89o
L763RY>=OGYoNgV7RV]RJ720Q8QkLgUVLHn3I5egO6I/LfMaP79TLh9nLWB7SGe_
Nh61OHFERHbKVI:JYZBTVYRZZZ2GTXjH[:>GUhQjQY^FR8Z8O82BQg=kQ7Y`Oh:6
RW]cQYNDRGifNXjY/If0LHBGYjRGNUn0V8VAUHn>S9>ITX:3V9^HSh=dKhB@PH29
QX6AR6UVL7Q_NHUiIWR7Tin@RHj:RHV?RYBQW9F@TIVMVY^LZ:ZLRh^?Si2<Rh67
S8fJV8AaQ9B1MhBBPg9jPGEYPX=RH71nMgMdKGmmK75iQhakPhaoOHMnMh^HRgj3
T9nTUgi^N9>KVXj9Qh23SIBGRWb7U8]nNh>ERWaiPi2<OgIlNXnOOVj5ShMaMiRO
SgUlP92CR8=kQI^JRh5iPIBLRGYgOgA/RHQYHVUlPgV5PVYWK6mUMG]bLW6<UHI^
O9B<MgMiOhb4Kh:0NYF<KFEhMgInQhn7Qhb:MfQaOh]fKgZ;ShUkOH>8SH5oNFek
R8B8RHEcJgA^KgM`Jg5jNWahNg5^Lh1oMG^4NfV2S8N:Qg5WNhR2QH]nLgj9QX5[
K7n4TX^3Rhj5OX5lNX^=QWU^KGQ]HWN:PGMbLVQILhAnLfe[JWJ?TWIeQhF>WHIM
HWIlOXN9M6QiOhMkMXAnMEiRO85eN89kMgEkNfEUKg5nPXF@Ph:BXJjCNUdo<dEM
FgNV_LSOmmnXRGmSH6MWKWbMYZW6cK6BKV9A@411BfjS`K^[Z[VVNF=_QGY]L7VC
SGebMh=kQYbEMV5YNgQjQhjEUiZRXj^/S6QWGfn<OWfU`LJaX:BDQH1ZIfImVJJR
TiVGT8AmNWe^HV9SPIjKPgMkOhfDSXaoPXb9NWN0RY^:O8jQUhF<SY6PVfaLL8:=
OG1eQZ>XQX6:QhQoJfmfMF]VO9>QZj>FS7j:RfQ:Cf5aRJc2_ZVQVh9iOGUkIFBF
ZZng^kBc[If6J5IFLXJ;SHRHWIb@Q7icHEmTIG:4RifZWiBBSWI[JeiNKVU]O8B=
R820Og]eLG9`LY6JT85ZHFigNgN5SgV>^;g7eKb=MFIOGUYOM8NK/KffYj6^RUQ@
D5]OL8R<Z/JZV9b1N6eCFe]JMI2BT92BR7f2N6QbPGb2RXR5PH6=T8=^KVaWMH6=
T8^:Pgf9RW=NI6eiNgAhNgN0RHR3Pg=UL8:3Pge^KW=jRY62LG^BWIB9V81PLGER
JgEmUI=gPW]CGVQGDf1QJ6I_S99iJW=iLfMF@Si=F6]]KhN1LX9hJgE`LH66MGV5
SXj?Ph=nJW5kRJ2JNh6<Vk6POGiiJWR@WYBDXHAeTZV`X9:BS7mjOhZNVhnFWYnT
Y9R=O6]/NWf4OhV5LWf7Q9JGN7R0Jfb2Ph20PWicLgIfNWMkO79iShQlRYbLRGQa
JGJ1MH5oNX^LZJnCOhIiQiB2R8ElR8bRZ8egK7f@ShQlN7egJfefN8RASHn6QH::
UXMlPGi`L8NIVi^FP79jRYb:LGZ:UHMkR8nAS92FSX^BUY>=OgihNYFWVXf2NgA`
QYnVVYBEU8YnNWjEY9ZDWjJFR8AmMHZKRGR8U8R7QGmgN8nOUYJ<RXYdJVAXMW5e
TifAShIhMWYcJEibS9R^/iF8OFMcKVAYOhN0S9JHS79]K6IbKF=YNXN0Mg]gKG9k
PWmnITULQiAnMGAaN867MFIiOGj9PhjARWf7U8^5QhQlMX:SWH=oPi>FPXF5OGmf
MhB2R9nOW:b]XYb?LfifMFYaQI:LV9AoJWEiMWYdLgN:V8MlNW9]LWb<Ti:>T9:;
SI>AP7n6Ph:9PGR4Wjf:FUenRGmmRI^PUi>>UIZCPG1aO824Ogb1OgaaKgEZIFUR
FF=jPWmhKfeWDe1RN6eLKiF_/YfBNUa[P7IVIW1fMh>7Qh9kMGn:Rh1dPX=jPI2I
Ui1iN8JOQf>4UVibZ9enN7:B[H5LHVmiQhRQXG]VOhY/IG^LWXNHYIeoKgIgOGao
TYZ<QXn[[X^Ha/6BI5ebJEEQFeamLf5/NX67Ui^6MHVDQ7ilQ8bKVXn;QgQcP8Yg
Eem/M7j5RHJ;Xj2@QGioJEEFKfmeQhjJY:VHPWabKfEMNYJ3LX1iLGUgJh2;OGMc
LV5;Bg=hI69PG6]gJEe_OgaeKV=RIV5VGUi]PHR>V:6MV9bPYX]kRIJ>S9jPXkbl
ZK_0Xj2c]JVAQifUXYV@S8nHOFmcLhN=RYBDT8jHYIUkIFIRJW:1T8jGYiF=V8=T
E5AMNHn:N8VARXn?THUmNX=mN7amQG^3Qg9hRhEXEVM[AD=PLX2NaMg:ZYEdHFei
MVn@Yj6ZWhnGW8J<XIZOYZ2LXIZ?PhF@UZBQV9VSYjNZYjJb_KR_]kR//;Jg[[S3
/KJdW:R_UG]hOXbBSYJMW9^VXYBK/[F[/jbJU8f4T9^JU9ZVW9ZLT8RBUXn5Og5Q
L8jPUH9gKGAlIFIbG4Q6EeiEEUQ>G7B0KDm;A3dk=2`R;DE4@3/k>Se4@4<o=b8W
?ce8EEEHH5iMF4]4=CQ0;2]3@CPnDD8V620_>dHg;caBCCi4>BT]<CDb>d]KIV5L
Ee92@Ti<CeALKhVBU9VBRX^?PVi[MW^6TI2=RZ6^VY:=RYNGSY6OZ:ZQY;Bg^[Ng
a[j/Y:2//jbZ[:f`][bj/:fb[jRSYkRn_<C8_Zn^^;c3_[c4bm?Cb<73]:Z]ZJVK
V::SZK>XZ:ZKUI6HX:J^/:Z[ZYZEZ:VX^/W2]lSA_:BCPGIjQIf>Lg:2V9::SibZ
Z:nn/j6LUYZfb/N[XJne/j^COWa^H6AYKVmfOWiiJdl^6aLL:B/]@51GBCdo>blb
?DUKFe][M7n=U9VPX92>Zkbga<:_]LBjZJncYJc1`[g4b];@_jVPXi>2RiZBP82@
TXbAS7n2S8f>S8F?WZ>NVibKZK>c^ZnLUYNCThenRIbIT8nIWi^:MW5/ETQ;EEYZ
Nga[G514Ae=IE48i?DIEGU]AD5=5>41=CdU7DUY8@451DVU[JUe@FV5THeeDDUmX
Jg9[E59I@T5H@B4G6bPZ;3iPMi2LYJbKRGIH;P/00000000D>dU8Acl^6`T00000
00003R@kAE1]Q92FVj:MX:^UTX1iOh:<WZZg`/GLo_ogkMgB_JFHRGajRjJbZYfB
TIBCUi^GT8b6Q7abKgF6VJ[3e=?OlNSFb;jg]LC;alkCf>K]h]30^kR`ZZNZ[jNW
];6SXjRWYZ6NY:bZXJ6TXIJIUh^=UZ6YZjRPX:VVWib<RXnBTHnOZjni`/?=ajfY
[J:CT8j5SIjUY[:kZYfNSG5SFda4BDYDKWakRYbX`mWWkNGK^iB9M44W;RTI;UQS
IWV;TYB1Gd@e8@lA3PHF?4i@GGRAXjZWYinDTYNKT7a[GV5cLFn2TZ6e_[Vk_[BW
V8E`HeiMHVMcP8bFXjf][ZNSYZff[j:V]K6/]kNZYIfIY[>b/;F_YiV9PG9^MWI[
L7j4QHjKXIjIV9:?Si2>TIVISHB7QhR5QHnMYJ>LRgaiMV]PEe1@FFaiNh6<TiBA
QX1kKUaBDeeSIg=gKW1jP7ebKGEdH5MDBT=?GF9ZHda<GfYWL7amRYZMYkgHfmG<
[We:6`00000001`mGW5_IUPm5@000000000C9Sa>G7F?XJZ`[j2=P7M_Jfa]J61N
GEYLIgV8RX1cK5a0;R`_:BDX;CY;EfIgPi:IR6iZKG25V:>^/Zf[[ZjYY:V^/kJ[
XZ>PWY^;N7=nOWb5Ri6LYZb[YIV:PX:7SXn3NhF=X;O1`[jaUH1fJ5E@D4]EHfE^
NGn6SijXXXijMX2<TI6>TYjU[;[8c=3BcL:eYinJThUkKFUcQIFOY[2i^kBYYZ:D
R8R;Si^cd__oooooomBHGc8E4Qh[@5QeW;>j`[^TRF0`2@4C;Te[PHnDU9nng^gc
lNC<]jZJSXIiLGQiLWElR9V]_;FNQfeICDA7DeaRJgN3RiFP[L7;al:h]Kg6bm3A
bknb[:bb][Bg_[jf[JFQYk>fZ8igJ5iDCEARLhBBVj6OUY:GWYV>PGYkO8:AXZf`
ZinHUiF:Q8>3RHf9RX^0M7AeLgEeLgAjPhR8Q8:4QX1iN7=[HVI`MG=_LgI`KFe/
KG=mQh5[HV1HFfYeNh61M6QdRYk8l_kaeKJ<FB`A0P0<82i1DfN0Shn1J4DJ0000
1algDVIUGEYTOZ?0a;bg/JFEQG]bJfAUJFY]Mh^P[:bGO5hh7ALP:S<lATmMLX>A
Y:fZWXQdIV5SJGB4TIRNVYFJYZjYW8j4NgA_LgYoPhF9RhAoQXb@W:JQUXn?S85h
NhB5PHFAVI^ITi2>QH1nMg9_JFI[JfI[KfmcNWakQY>DSHF3PWj1Ph>8SHnEXJRW
Z:FLUYJEShR8Q7YdMGb3P8>8QXN9RH>2R8Z9S8^?/^Sooo7@ZgiB?c/i>CPe=d]Y
OiN[XXmgCBLL9CYJMH62Ng=^KWZD^Lo;_JnUWiZFUY:5KDl`7RiFM86>TX9UBc/g
@Ti?CU=JGf5TKhZY]KBf^KZlaLoGf]O;_JfPW9jQXZFYYj6AOWE]J6IOEU5CH71h
O8:=UINLWI^BRXnKX9fHT8^CVY^KUHnCVINAS8AhKFMUJG1fOX61Qi6AR81oOgU_
JFMUHfIaN7]iMWYnNWQfL6YRI6m]IFajQXjEUhf5RINTYZ6LWInP]>3ooo?F_YMO
;0/0010S:2XhFHBSYiQmCAH000037SI=H6afQIN/a=KJe<BZSW]eLW1[IFIXJWF:
WZfb[9R2IChH1@TG:d1>HWb>VjN/ZjbWW9:AUi^MWJ2[]kR^YJ>V[;2/YInHT8Z9
RXR5QXR<U9J?SY>IWYZBSiBNXZ6PV96CV9bNVI:ATiFFUYRFShV6PWaiN7UjOX>3
PHF;QWelNWQhNWalPhb@VZ>QX:6TZj^TVY:CT85cL79gR9fRWj>_]kF/WHeoLFAH
GgJ:Y]?ooooSbjj:JT0V8BHjBU9SO9b/XifHQ6mKCE5NIFMVGeUNKGnE/LS@eMC3
/:2>NFAIEE18ADiTOYBPW928NfE=>Bld@D]DH6eiQiJR//7:`kNb/k>d];2]ZZJU
YJVe_l2n_;JWTW]XGf1NE51EGfM`P8jIXJJ[[ZbVY:FSX9jKUiBHWIbJUi:AShR1
NWAcNGeiMgA[H5UIGfA[MWn4QXZBUXalKEY4=cLnA4Y@Ef5SG5QKHfU[IUaGDUMT
JFY_LgMmQ8j@SHnDUiVCTjS8jOcZaJAnDRH6008A8bPa?U5[MFYIAc@P4A<W@EAM
J71bMGMlSZZo`KNSTHZ4Og9SGV9XHeEDIWb>U8ioK5M8?SXe=3Xh=T9GJWR6Tj6_
/:>BQXRBVYnQY:BMVIVEVJF][:FPVi65O7EaMWekN7Z1S9ZRYZ2CSHn?RHN<TY>G
XZRUX9ZIUXQhLVmXIVa^J6IXIFA]NH20NW=_KfaYJ6]`MGYoR96CUI^PXYb>Q820
Q8EkKFQZK79hNWf4SYFEU8n?SGeiNGAbKW^FZ[o=gOWoooo^a:AmGTY3@3e>Feie
T:Vo^Z27LELo?TUGJWMiNWj5Tj>aa=gTd[RRU8YnLEmDEe]KGFMiSj:[YiEmIEA7
?3e5D5aPIgN?YkG1d^7Sdl2/UhJ3Ri:CU9RQ[/7Fh]kA_jV<Idm:B4QAGEQ<DEi`
RJO1c/^m[ZRRThJ4Qi2HW9fT]LGBe/VfY963PHB2N6ULF5QFG6]eN7f1Og]hL6=G
E5EGFfE]LWZ3R8R9QX1oPX>0MgAeNGedIfQePhf@S8V8PGMcL6MPGf5/NXF@YKgA
k_oog;FQOE<o;A855S53F6f4WJ:AP79MBD96D5MHEEAIHGZHZ;?2dM7>dL^hXXea
D3di<BX_AF1fPhV6Q89hH3@=008<5R8`?DmXRjk6e=WB_jbMT8V3Oh26SI2IZ[W3
alBfYIN<P7E`JUe;?d5:EFEbPIZd`lC0^:ZOW9NCUY^PZ;6i_;jl];:g^ZjJR7ah
MW5[I5mQKGf;UIR?S8j:PGYgMWMoR8R1NG1`NXB9QWmnPXF4P820Q8fDVYjHUIbR
Yj>CR8B6RXfEUi6DUij//KkFk_S`e;ZYS6MBBcX/>dPmAF1kU:2LTXYdFTe3=Blm
C4e>De]VMI>leM74_[V_WHUiK6]YI5aDEVB1WZ^TT7i_H5A=CTe9@cXh?4IEJHBH
ZJn[XijOWYfOXZ>RX9jNXZNZZJRXZ:JKRGQaM7MaHDi6BUEUMHNEVYZNXIZBTYRR
ZJRQV9>=S96GV9FBSXj?SXV2NVmWHUUADEMPKWf4R8V8R8jEU8f5Ng=]IV1OJGQo
OX:8QH5oNW1YFd8c=Cm9DEi_Oh^BVj6GR7QXHf=SI6AUJg>1U;7GhLB]X7a;91<>
4b0N5alaD7fCTi62HTHlA5MXKfUPDdE5DV^?]lo;]j>BQGejL65HD4U9C5AZQ9:B
RW]_JVMQGUaGDTHf=TEDHWN@YK:_X9FEV9VNYZb`/:nZYj^b]:fQV8n8PX1oNgQg
N7UgN7b5T9fUYJ2IUYZRYJ:TZjf`/:ZUXj>XZjVRViRGUiNDSHN1Ng5RG61NGFao
QXB6SXj;RX=kLg5cLFe`MgQdM7UoQXbAUIVIT8N1P81nNGZ0PhRBWJJ_]Jn//kNb
ZJ>SWYREUIVT_=Wamn?6]9agIfMMD4e@BD57Df=bMG^1MV9JI7^?Thn7PG]gP8bM
^M3B`k6SViRESXIoM65ABU1PLGf5R8=gKFIPGfI]K6URGfI_Nh^O[[>aZZ6QZkBk
_Kbl]k6^YI^JXJRZYZ2IU9>HWYnFRWicKV]VJWN3SY6ATi6<S96=PgilM6e`Lg9c
Mg]nPHB6RH^7PgikNg]gKfebM7MlOhB<UIZMYJNTXI^BR7a^IVM[K6YYJfmiO7f0
O7E`Kg5]If1LGFE[LGIlQ8J3PhZ>S8nDTXZ4Ph9lQYbjf=_7ZIJ7LF5KD3hg<bXR
82m>KWahKEHj;cE9H6]YGE9<DfAgTkC<bkRMPgQlPWihMVaH@SU2DfYoQh=kMgAW
FUeUH5E:?cHd@EeiT:>`/ZVKTHUoLfY/KVaYHf9YNHZKZJj`/JbNS7mlOGETH6Q^
MHBFZ;Nm^[F`ZjFOUXj>RW]_K7B4TI:@U9VIU8j;Qh1hLFm^J6IYL7^6T9FKYZ^V
WYVIV9BAShf<TIbSYJR]/kB]XifGShb=Qh1oPXJ6Qi2NZk6`ZIbDSHF0PXN9QXN<
UYnLYK>jalgHgM2fWiR>N6EKCT50B4]=CfJ4Rh5bJUa;B4aIGEQDD59JLHNCXKG2
^j>9MVm]Kf]OE4Lm>3i>G6amQ7mbK6i`K6]dMg9YHEaML8ZIXJZg`KZVVZ2TXIjM
WIRCSHZ=U9VHTXb=TI>ASXf?SXMkL6YWJgZ?WJZaZj:TZZb]Z9^CThn:SYBIWjFX
Z:BKTHV3Ph1eJVIPGF=ZKG9iOhJ<RHB8TiNAQgijMW5_KgN1QhZ<T9JGS7]bKfaW
IVALF5eULGEdLVmYJG1`JF5TJVIRHFEWHfYmQXbAShZ@Wj2OWH5MGfMFAd@o>dM=
AdA4?dUIEDm;@SU1CUe[KfUTHf=XM7b0RYJITH9eL71cM7=eN71UG5UQJfYUHEiO
HV1FFFenPXF6PhF8SYZSXYjQYJBPXjN[/KW0`kj_WiB@U9VGSHB4QHR=TI>EUI:@
R7mkNWZ3TIJCTiFHY;:e/k6]YZ2KUYNHU9>IVYF@SXf?THn8P7QdNGmoOX:4P7n5
SYJOZ[Jn`;jj/JRPUHZ5O79dOH:8T9F?Q7n2R8R6R8b7OgakNWMjQI>LWibCSIRP
W9BDV9ZPXI^CUjJ[/kZn`<>eUi:GQW5`J5EBFeUBD51NKg=[K6YSIWAoPhElKf]/
NI:T[[c;cLJk/ZjZYYnER7U/I65QKGf1OGUfM71^KG5hM6ILFeeQJWR5SYBCU9^R
Z:na/;2^ZJ:NV929QWmhMG5]KW1bMWUnP7QaLGEjOh>4Qhn@RHF8TIJ>Q7efLg=b
N8::RhF2PH1nN7=cM6eUHV5TJg5fNh62OWI`KG1cMG=aMWMdMWQfLW1cNX22Ng1^
KFISI69PHFAXIfARIfm]IVI[KgEmPH63QHJ6PW]kP81oQX^8S9:BV:B^^/?1Zi64
KUMACSld;C4i>C<c@UUUJVIGCDa?FfY^IeaEEfR1SiBP[JfTTGY`LG=fLVIEBDUA
FF1[MG]hKfIOG5aLG61UIF=VKgf<XK2^XIJ>R8N<TI6<QXVDW::[/k[0`[^[V8V1
OgmmNWb5SHjAWJN//[:]Yj:NWJ6UYZV][Jf`];o8b<K4`[fh/JRPVYNJWI^EU9VM
YjfZXijFT9>HVIVIV9RNYjb_/[Bf][BaYiZCTHj9QXJ8RY2DT8V3Oh:4PGalO7Uk
PHB2RI6?SY27OGUcJfUXHV9cOgj9WZVb_[JQSGa`HUM=AdM5@d]?CUa/LW9^IV5H
E5ECE51>CdeAGFQ_O8^FUHUoNWMdK6EOEDY6AdmLIfmhNgM/HE]FEUMGFeeRJg9e
OhnKYJVQV9RLVYbLUY2ATiFHVY^JUi25OGakNGUgLg1`LWMlP8N>THn>TIJKW9bO
Y:N]/[Be/JVSWiJ:PGYiOhJ3O7MaKW5eN7amOGigK6EQGUiRI6E[LWEjQ8f@TY><
P7UcJV9OGemNG5]RK75hP89nNGEaL7F0Ph62P7YiOgimPhEnMWEfLVm^LWZ5R8F8
ShjDZJ^AO75LBTeEE5EHEeaSGf9dPhJ6P75THfaeP8R<RhEmPY2JZ;Rm]Z^OU8R1
N75eNWE/Jg1iPHV@RWYWETa?Ff=[NhR8R8Z5PhnKXJFUWi^MXjflbLk>dM;?c<S3
_;BXVHanL79kPhjGUHf8RY:KX9nOW9BCUiFATiFLZK2_ZjFQXJBSWiZASi>HW:6U
YJ>SXYbHUYFEUYNFUiNFUYZLV9:=RHZ8Ph1nMVi_LG1^JVQZLgf5RX^:QX9oOGf0
Q8^EVIZMWYfOYjJOW9:2OhJ9SY6@T8f<T9BMXjBNRWIZG4i?G6ISEdm:ADE6CE]M
G5eMF5MPK7Z2QXV6PgekQINY[j^QTHJ2P7]jNFeNDTPm=3Hk@D=1?30U8b/kCU]O
H6AXJVQZM7j2PhV>T9VX]Ko7b<:h[::KTX^5P7aiMW=`JV9KFEQFEUMHF5]PIVeb
LW9hPHZBUYNIXJJWY9b@QX:3Ph5oOX24Ph62Q8:1QHJ1NWAdNX65S9>CRXB1P8F7
PGajNGUhLfi]KFi^KFaZJg1hPH=nN7IjP8J<TiFDVYfJTXb5OX25QGmnO7n5PGYn
QHN=UIZBP71TG5ECEE=9ADYBF5E?E5aKGV1OGEUKJ7R1Q85iLG1kQhnFUYFBSHnB
U9ZNX::IQWEVFUUPIF9ICT<n@DM@FV9]MgYnQH^DWZBY/K>c][k5d^3VhMWBc<No
]k>`[ZROUHj7PhF>UiZGTY6EWjZa/[2c][Vn`L32alg?c<Bk]KFe/ZfXX9RGVYVF
UIFFUiNJWinOY:V/[jjXX9ZCT9BFShR1NgUhMFmVIFY]L75]KG5dMGMgLVa_LgQn
OWQhO7YiO7aiMgE`Jfa]If=YLWQmP8NAVZ:]/ZZGQGATGEE=CTi8BU1<@3PmAdmE
E4]6ADaNKG9`K6IQHfeiPXfGWJ:OUH^5R8nBTHYnMgA`KFaYIV5GCDU;D5IOJ79k
OWUgNX:BWZ6PXJN/[[6b[j^VXZ>UXIZGUIJHUXj7PWn1QXJ3PGeeLWAhNGIgOXF9
RHR:Rhb>RhV6PX63QXR3NgMiNGQeKVIRHF9UJVeaMh>AVYbFShZ7PgijMfmZK79h
OG]fMGEeMgYiLfUVIfITH5]LI6]_MGYiN7eoNW=/HF1UI6AXJVU[MH:=UYVOZKBe
]kRYVY67N6QOFEICDeiUGU1;DEEIFEMCCUITLh68Si>ASXfAT96IY:n`ZZJZ/[Fg
]:ZIQGQfMW5^L6aUGUaMGUeQKGIgMWIfNHBGYJRTY:Z`][bo`<2m]k>b[jVRWj6T
WIB<QHF<TI:=QXB4QXZ=Si2CVInQY:NYZk2c[ZRTXj>VZZf^ZjBPWYfJTXZ9T9RN
X9bJW9bJV9F=Q81oPhV<RhV8RHV7QHF1O7]jN7IeKfacOH1oNgYoR8j>RhR5Q8Z>
T9FAQhF:QgUcMgQjQI:HViNGZ;g3_KFUSH61OGMcIEAADD@g<bh^?U5GFeaDE6Ac
MgQfKF]cNWf2S9>FUiJ<OWAbNH1oMVYRFUIIFUE?AC/h=cHf>dEBHW=iMWEgOXZA
U9B@RXR<U9RKViRHVIFASHR6QhAlLFQMEEYTJfaVH6A_Mg]oQ8J9S8b6Ogf0QXfD
VYVETI:GVIB=R8F5QhZ:RXV4P8>6Q8:3Qh^=S8R2OWMbMGMgMgQjOH63PGekNWem
N7=bL6iaLgAdMGQjP8R<RhJ6RhUlK6EQG5eTJV]cOX63R8^:SiFDUYfIRh5oMFYX
G4Y1?SHb>T15E69SHf]_L7R2RY6IV96>SI:MYjVYZZNQVYFEU9B?RXR5OgMaJfMV
H5QACU5JJGIoR8n@TINMWIfOXjR^/;>j_[k0`l;0`;bg/k>`Z:2KVifLUi2<SI6G
VYfU[:nc^KZh^Kg2b<c:`kfk_K^g/ZfWY::QXZBSWibGTXj;RHZ=TI>DU9:<Q7em
O7UhN7MfNG]hMG9/IV=SHUmNHfMUJ6a/KGAkOX1oNWUkN7EfLfaXI6AYKVm_M7f2
Q8N9QhZBV9fNW9J8NgAbL6ACB4M5@496BTiEFU]OH61WKGEjNgI/J6]bNh:5QhZ=
Shj<TYZQXIF2LVQPFUIBCTm>BDM?FfYeN7MhN7UlPhfEWJ>SY:VXYJJ[[jnYXI^H
UiB>PWQcL6m`L6a[Jf]]KVe/KFi^KVmbNhJ?Uj2SXInNVIFETHV3OgYhNGYmPGmk
NgahLgAfN7UiN7IbKFabMgUmP823QHF4PWn2Q85kMg=_K6][KFm_L7MiNX25PGam
OGQdLF]VKWEcLWEcLWAeM7Z3RhnDVYjVY9N>RH9jK5Y?DeUIFeiKFV=ZJg5gNh>;
S8f@SXN8TYjX/:fXZJfa/kBh_KngYYVETHQmLVUQETi:CEQXMWenP862QX^?U9VL
WInTZJ^]/;>f]kFc/:j_/:nXW928Ph63QHJ7Q8:4R8Z<SHf>TI>CUYbRZ:nc/[:e
][Je[jZWXI^KW9VDTY>EUiRGUI2>Shn=Si:>RH^;RXf?RhN6PgmiLVm^JfISH5mR
IFIXL79_LgYjNGakLg1dMWIlPhB8S8J4Rhf<RhjBTY6FVY^NXJ6GS8Z7Q8=dFe1>
@cD`;c4jADI5C5=HHFMWJW5aJfY^LG5dNWb2R8V<TiZPXj2IUHn5NFePE4Y2=bdY
;CI0BU=JGF1UK7=fN7YjNh68S8f;Ri2EVIjPX:FWWi23MV]TH5eHEUIHGFI_Mgb2
QhZ;SHf=SXj@TYBFUiVLWYnMUHYoNgYjNGE`KVe/KFi_LGAfNX>:RhfATiBEUYRI
V9NIVYF?RhN3PhJ6PgmlNg]lOGj0PH62PGmoOh66Qh>3QH:3Rh^6P820OH24QXR:
QX5kLVmeN79TFUYIE4/o@4E=G6QYJgAlQXj;QXB0Ngb1PX:7RXZ>SXV:UJF^/K2[
Y9nKUi27Ng5YH5YGG6=XKG9iOX>7Ri:HWZ:TZ:fa/kFh_/?5a<O:b/S5`KRh^K>W
W9B?RXAnMfi]LGMnQXfCWJZc^Kfm_L33`;^h]:n][JRQWj2QYjj_[J^TViNBS8N5
PGj1R8jCVIfMXZNZZjNNV9><QGQVGUYCE5aPH6EWI6ATGeeSIVEWJfiaMWj8TIRL
VYRHTi2CThj9Rhj8Q89gK6idKf19<bHL5A@H724`?TE<EUiWM7j3QGeaJfa`LWIj
Ngn2P867RhjBU8j6PG]fLfaXKF]MDDU8C51AEEYOI6Y^L7=iOh>;UIfMV9FGWZ>V
YZNWZZf^ZjNTY::LTXImMFm_KV]YIfI[LWZ1R8f@UY^KViZJWZ2NVI>;PgilO7Yf
M79bLg=dM79^JF=MFEQIFf1[MWj3QXZAVJ2SXYbHU8f<RhAhKfe^KFQNFEQJGF5V
If=QIVicN7^0Q8J9SI>EUijQY:VZYj6HSXV7PWAOC40m>S<Z9bXb>T16C5MULWb4
RXR4Q8J8Rhb9RI6GV9RGVjB[ZZ>MVYVDShV0LVQWIVE[LGIjP8R@TI2DVIbTZJRV
XifHV9VLYJJQXJN//KF`Z:FUY:>TYZFVYZNRUHUnMgYoP8>7RXbBVj6UYj^/ZZFN
UY2?TYJIVIVKWj>UYZBRWYRCShb8Q81lNgemNWf2QhjGWInRX9V@R8F5QHR<SI6B
SHF1Q8F5Q7U^JfMNGfETIg9jOHN?SY>PYjJSXijLXZRXYjRWYZ6@N6i/Ge59?C0^
=3XoA4eHIfi/LGIhP8Z>Shn>SHfATXj<T9VSYJ2ERX=oN6mUFe99A40m?T=8C59I
GF=^NH>>TXn;R8J6R8N3PX5nPHJ6QHB1PX>0OW]gM7=bKfaXIFATIVY/JfadOHN@
U9FJWYfLVY:9PGM_K6UTHF9UJVi_LWIjOWmnNgE^IVE^MgYlNgE`LG9dNX22QHR5
Q8N4Ogn0OWYiN7MkP865SI:BT8b9Qh=mOh63PGMbLGInQHR9TifKUI^PUIFOWIJ:
L5eMFU5BF59=EEYHG6EYM861OG]hMGMlNgEcLgAgN7Z3SiVPX9V@RhV8Qh=kMG1T
FUUDCe=KH6M`MG^7T9FMX9fNY:R]][c3b<S8b/S3^kNb[ZfVW9>:PgmkNW]gMGQj
NWYjNGb5SiRPY:Na_lW@dm7?cm3=a[faYj2GTHj<T9JIVYbOX9bHUiB?RXN8SI:B
U9>>RXf@U9fPW9NBSi6DThj:Qh>4QhR9RHbCUiB@S8V;TYBEV9NASi:AS8fBT9>J
VI28Q7eiNgEYGDXd=3Xc:bTW9blj?3i9CeEQJVibM7=fOH60OgmhLgAbKg9gNh21
NgEcN7f1OgM]GdXn?Ci0@493B55LI6UdOX>6Q8>4Q8F8T9NJVibOY:fd];Je/:^S
VI2?RhJ3OgUeLV]VIfQYK6maNXB>VJ2PXZJVYJ>OVYJEU96=Qh1mNWEcLg=fNGUi
NGMeLfmZJ6QWIf]`MX68S8n?RXN6Ph1mN79`KfaZIV=SI6=RHF5PHV]dMW=aKg=l
PHJ<SXj?UIVGW::TYZ:JT81eM7EZEd@m?c/g>CLe=CY2A4YDG6E^LgIgM79cMgao
OgemPhF1PHJ:SH^5O7UmPH5nNWUhKUmJGV5SIVU[KWEkPXfFWjR][kFh^;k5bLW9
a/72a/S:c<_9al6cYj>RXjFSWIRBRhB2PX1mO827SI6IY:fc/jn^[k2d^;Rc[:BL
VIFBTHf8QhN:T96?SXV0OGYcKg1aLgYoOh65RHjBUIVLWYbIUY>BT8n<QhJ4P7Yg
Mg^0PH62QHR:SHb:SY:=RhnBT9BMX:>Z[Zj/Zin=RXZ6PGAND51?B4E2?3]1BDa>
EF1aOhV<R8N9S9:GUY2:R8^<RHN7SIFGT8EnOH23OgAXH5aDBd]CEeUKGF=^MWb5
SY>DU9>@SY2CUj:[[JZUXJ:VYZ:LUiFBS8F2PX:3PGU`JfEPGEaMGEUIGVIcO8:8
SI2BU9>EUY>BT8^4O7EdMg]kNg]mPH9mN7IcKFMQFE5<BdmEFEYKG5iSJG9hNGQf
KfaZJ6MXJFISHFAXKG1cN7moOH64QXZ>T8j9RX^<RhN8RH^?T8n@UibNYZZSW9RF
TXQhH5ACB3X`:RXbA4e?Ef9/NHF:Si:@TYNJVYVJV9JGUY6?TI>EThV2P861OGQe
LVmWG515@d=3ADM9D5QQKGIlQY>KX:N]/;6d][Nf/Zn`/[Bh^[g2a<2f[Z^VXIfD
SHf:QXJ7QHF=TiRNXJ:UZJNTY:BSX9^LXJ:OX:NXYjNTWYbNVI>DTHf=RhZ9RHZ;
Si>EUI>DTi6CUYJDU9>>SI6@SHj=PgalN7AfMg=bMGIeM7AfOhbCUYB>RHJ6R8^:
S9BGTY2?ShnIZZn[Z:JLU9NFUXY^Ed]2<R@S9BLa>cm6CeAKIW5lNgE]Hf=YKG5b
Kfa[JFQWJgAjNgUdL6YVIVATIEmCAclm@TM9BTiEG6=YLGb5S96DUYJBSHfBUYRG
TiBIWZF]/K2a/JfVW9:;QhF2PX1lOH>;TIJKW9^NY:VZYinHUiRFTY6?SHnATI:@
RhJ3PX1kMG5_L7AgMgIfMgMdLW9bLG5dMWQiMgEeMgQiNGQgMgUjOGihKfYUGeeL
G5mRJ6i`L7=hNWinN7UgL7AmNWQoPGf7THfBXZZ_^l6h[J6@QH=kIUE=@cHd=C@f
>d13Adi@EF=aNX:8PWYkOGj5RHJ7Si6>Si2BU9BASH^;Rh^:R8B3PWY`Jf]_MW]l
PHN<T9>FVIjPXJJWXj:TYjfd]kNf][Rj_l6m^[Vh][Jd/K2^[:jaZjBNTh^=SXj@
T96FXJBVZJRYZj^YZ:BNVYbITH^5OGYnP8J<RhF2PGimNgUiNg]nQ8N9RhR3P7mo
P821Ph>7Rh^;SHf9R8J0N7=_K6QVIFEVJ6Y[K6e^LWAaLWE`KG9hN7YmOH69TY^V
];c2`k^eZijHV9N8KeQ8@3dj>3Le>D13ADmKHfecMGMfM7ImQHfCUI6<RhV5QHV>
TY6;QGmmOGM`JFMYIEeFD55GG5YFE5AGGFI_N7j2QhnEUYBCUIRLWI^GUiNEUIJH
V9JDT8b6OWUeLFeXHUmNGEmTJfe/KW=jPHV;RHJ5QhV<Si6ASXb:R8N6QXN6Q85m
NWIcLW=dLFaXIFAUIFEVI5mNHFEXJVY/L7EhNGUhNGf4QX=oNgQgNWalO7enPhV?
TI6BUIFATI2;S8jCUIJHVInOXJZ_];Zn`l30^JNKUI29OVeGB4A0@DI8ATM@DE9K
HfYfPXJ5Ph1kOh^CVYfIUYJGV9bMW9^FSh^5PGihKfQXIEaDC44lA4U9B4Q<E61_
O8^GWZJ_/[:c/kFi_l2n^kVk`/S<dM7<bL[6_[N`ZIjCRWebKFQUJW9bLgUnPhfD
VIjOWj:X[K6e^;^k^[F]YjRYZ:VXXI^IUiRIU8n;QhJ6R8Z;RH9mO7YfMgb1R96E
TXj;QhN7QX9mMg=cLgAeLW=eMGEfN7QjOX61OG]kNg]kP8:3Q81mOGekNgn3RXj@
T8f8OG5_KFUSET4_:RLQ6aTI6b@_<cHnBeUVLGMiN7QjP8J7QH9lN7MgN7QkQ8^:
Q81lO7eiLfm/IUeDBdQ>DeADDeIKH6M_NH>>V:2WZJRXZk:h^KRh^l76blc9aL2k
]J^QVYRFT8V2NgAaLG1`LG9fNh67SI:GVinTZ:ZZZZf^ZjZ[ZJFMThb7Ph5mN7=b
LFe[IEmPI6MWJV]/L71_MGQfMgYgNGelNWaoPX5mN79]J6MYJ6ERGU]KGF=YKgIi
NWYjNGMeNWf0P7YhMg=`MgaoQHR=UZ2RXJFYXiVCRH1mKf9HDDa4@Chl@TM@FV=/
Lg^0P862PhN7RXf;R8F3PX>8S8fCVijLW9fOYZZWWiRBRh5gKFQVIVM[LWV1QX^@
U9JFUYVQZK2h_L32`l>o^[Zk_/2m^k>XWYJ=R8J4PX60PhR=THb:RXJ7RH^?UIZJ
W::UZ:b_[ZbYY9bGTHj<QWifLW5cM7IhMgIgMg=cLg5`LGMkO7ajN7Z0PhB4Ph60
OWj0P822QHJ2OginOh:6QXB5Q8:1OgekO7akNgUiNginOh>6QhF4R8J6Ri2FVJ>^
/KZk]k:WXIZETHAhJ61PFUA9@D52ATQ;E5iZMGb0P7ejNG^2Q89oNWUlOX20PHF9
Qh9lMFm]K6UWIfIPETi8AT=2@CdoADeFG6IbNGanQHR;TINQZJFKShB2QXN2P8>5
Q8J7Pgn0PWadLFi[K6eZIVEWKgMfMG^1R8b>Shj?T92ASH^@Thj8PWn1QHN5QX=j
NGYgNWinPHB6RH^:QX>3Ph1nOh63QHR<TYFGWJ6QXIjLViVFTHb9QhAmN7AhOWio
OgelP8J4Oh24RHZ@T8nDTiNRWYRMXjFUYjnd[ZJZYYB9PGQdJf1??clj=34W8b@X
;cM0AD]IJGAfMWZ2SiRHTXf>THf<T9:BU9^PWI>;SIBBRH1kLfa^IeeLH69OGEaT
KgMkP8F>TY:FWj6QYJNUZ:Z/ZjNSZ;K0_[Zj^KZn_KJd/[2/WiNFUifJQ8bKT9ZN
UIBHV9^NWIZFXZb/[JJOWZJWVi6HX9^DSXR7RXb:SI:>Q8>7Q8B:SHR3RXYmOH:7
SXj:Qh:;S7mnOWinMW5WDT]@DUI@BTe:CEAGGEQEJ7=^KFefP8Z@T96:RI6GTHf@
UZ>QUiFDVYN9MfaXJf]EA3L/=3Xk=c0];3=:EU9EFfIdJFZ8ShN7S8jCS79fT9>7
NWZ=VY^CPH2DWI^FQh1cJFEHDEA?Bdi@E5=KKGIaL7=hPWikRiJ@V:nbY::`/k[1
^KBb/[6XV8jIWYF>RIBTW8AcNXR9LEaMIFmhLfQ[MhnMUIBFSHF9S8f;OFY]LW1]
IgR2LXFGQG=mUI1dO9R;OXJ>QhJEQ7V:SXZ9PW]nO7n1PX^:P6UPJgQjJF5[JV9J
GFI[N7iaIW:<PG>8Uj:XWiZRYJV_[jJFW:Nc_kFMW:bk^ZZDOG^7PGB1P5Y?GDU8
G5]5>dISJfn3NVMYPIFFSYJQYk6ZZ9j@XZ^NVIZ8OXF:VjjTQgelMh67LE1DGEUJ
EE18@4]VMfmYOH5bP:ZkYX^7UiBS^jNAWKBZVYZ>R9JQRXnGM7jFV965LW=VT^RX
DG^[SGEgQJVWT760_jb=W;:GIHBl[7mnSI2<VjaXB6j;QGV;OVn4WJRTThn7PjFc
[jJ;PZFbX7iUK8fKP7^:ShN=UXZ8TWaFI9VSU7U^M7fDViRLUHRR]9bJRh:LZ:2C
S8Z1M8:`^ZnJOFaiXXQ[Gdm=Ad8l<R@`?b/GAfPk4SE/K5Dh9SIYPWaJ@fEVHgim
GUUVIFE^GU5A=SUHIf9@@cI0BcPfASDU=414Ce5EEeUlUhb7H6n_XHnAW8eoTJ6L
RGI_PZ2QQXB=NFf9T7YeMG1fOh6;V9MnP:Rl[ZVFRibjelNb^LSFa/6m[;K0fmo7
WhfIZlk2X9RHTiRa]ZBj`Z>`_Z27OXN4Ogf5UGQUQkJeSjVCMZ2[ZIQeQJ6ARj>B
LEeTRH2DZW5<P;BXU8>?TF=^TgE]RYRFVIV>S8IgPIVOP6M_L6Q^I5U3@4Ld@T]9
=b/iAVaiJ6]fHF:I^IV2M6F:SHFOP6Z0TXQUFEeDIW1PK6]=?da`JTYDIEU5IHEU
E5m[OhJ9OW6:X:Za/kJbZifZcm;0[JnWY=38VX=lXkRWSgb1O8JMTXMdJgjIYifK
VkG=a;Vd/9ZR`k6[_/[>]:OEhKRQZK6]Y9fMPgB@/iafMg1?AfYgF4aRKF1NRhaZ
M5MTSi5oE5EQM9JEM5]BJG=fSgacNEaUSYZ:RUm>P9b=LWUmOhnGOFYWMXB3Q7a^
MWYhMG9TG6aE@4T^6Ad_@SiKIda;EfIjP8jAQGUPPZN=QhZ6OXjKSW9TKg>8U89^
Fe=IOY=hIgJ7R7USHUaECVj8MVM`NGMVT;Z@NGR:[l;:h=fZWZnd`M2nRY:o_i:<
UXb2Q7UYOG=OLIIaCX^HPW]eKG5nNH^^XhFH_;2Qb^J_S9^FRYB_Xi20KGZ?NDm<
FT=7D518AEQ8Eh=dHWB8Mf68OdIDOGMXM8b6MG5jVhU@FiN<NJ>n^JVKP7j=RHV6
OWR;WYF:P8jCSH^HV8n8Um3<[:BHOh6eXfUOEUaWI4i9A3A5J7ehI51AG7VXYHN5
SHRO/iEmRh5MKI^1EU]iSXb4NG:6Ti:QUGQ]K6]^MG]LCTToEWabAT9IHWfNV9JQ
Zjj^^kneYHV4X[beTgMkMH>LTGYdIVeoPH9nMGb:W9^?P8>FWiF<PWF7P8nh^I^J
];Nd_;R`/;C2akjNMGikK6=ZQg]cV920QH>2SYJGWHQ^IH2JZ;J_VHf6S96JUI28
QH6:WI23PI>XShBFW8b:UinYV969O9:_VGQmMgnMZ;J^ZKZYVZ><M6R3S65HFdQ2
B4A9A2lJ42A3G69:=D1NHfEjGc8lE7B;S6QCFV1SK6eGB5n2MFIlLEIcPWMoLeeF
E6E/Gee97BYBHUiWITiROH=nLHbNSY>W_J^0O9NYXY:=U9>3NIN_QFQoUIF6Ng^0
Q9RJNX2K/K^gb=W7X8B6VJ2JSI6XZ8fCXi1aJ6aeR8i[@5V1PYNCJfb7YJfQWhUQ
Q[^i[9bMWiVGWJ^@GF9nS:6[[jb9L8b@OW=QI6M/Rj1lIh:DUheaOifUY:NRUYRL
VIBHW9j8P96;Qh]hLFeKJ7=V?BU<F4==GTQ3G6IWN89O>daSJX:2J6AfPX>4Q8b=
T::UZkZTSJ2X^;ZTXIEoOHbASg=RJVidKfaSHgR4PgIbN7=jUJ:JUXj?XjVXVh5e
QJFkZ79WRiZ]a;JLS9RZWIZQWjR_Y[7;a;:_];BV[JZGVk2^UIJPVh5PHW^2HUAG
HgehOX1ZL7iaFUegNgJ3QGmoLfe/MGM^OWiXFfAnRHMlIEmnSWI`NgB1W9AkH6=k
MG:1JeYYIG25T:^UR8V3UZnHP8F5QiZe_:JDShj6NhEdC4A4B4Xh<diHB2h^C4Tk
FW]hL71_JfQUMHImJ5eZLFmcLW9nTiZ1J75oVJV7Kgj2OHF7OW=oSGaUJ7B1Oh5l
JG5oUJfILfj:[[jWQgV1SiRQT7j4UIR>S8U[D5acTYj?SIBBRXJ=UXilPXZ6UiEh
N8BEXGQKLgabJfELEVEoQgUeKFU^LWN5TF];HH>9MG=jK6EaKFUbK6imRjK0b[BF
TifY][NPRXF9UY^KRFm/PiNKT8:Pc<Ne^jZKVI6LXZ2ALG^QZYfATIVCT8M^JfUQ
IUA=IfYgMEYIHfALC5EhRI2APg=gR:FnZXQkQYZSZ9n7Q9FBWj^MPF]hPh6>TGES
IFadNGU`H5UACFEXD4IAKgigG5=kXZ2=QhREZkNRR8ZATXn<TiBHVGiiRiBJSh>3
R8bIWhn3PX6:XK6TTIN]^[ROS8f5PHfES7IkT9>N/:F2M7bFYZ6KT9jUQX>LW8U`
HFiiNG9VLGMnSi>DQWQiOXZNZ9jVZjJ[[ZZQUY6OVgeaO9:[/j^KQGfA/l6cTWf=
Uibe_ZF;PI2QWXU/F55=E6MN@3=0>b<I7BXW8R]:Gd91EU]]OW=?=dERGE1TKfee
K65^MgB3OFYbMGidFeUUOGQRGU54AeIRH5ICDf61RFaPM8VJXi^=RIR_[jj[XijB
VIjMQ5iEFf9[LG1oWIjHZ;ZmX8F8U:6RUiBJT9>WYXYfSiIfL86>TiBDT9bMRXB4
Ri^SUhj=T:JXU8n@PgUkQgiOD5e_O9RWTXZ?RH^LXIfNTXbQ[JB;Q9ZHQH>=W:2F
V:RST7akSY>2MGIhPXV=V9^LXj6HS9>GOViLBU9VKVQMCe9DAchn>D5@FFmaIVU]
Nhf6Kf]jS9bUUhbAWIf@U95nLFU`T:B5Ff1bLfMYQI:9MFU/LFmIE6I/LG]jNH20
R89jS:J_XIVJXZndZjBY/K6MSY2DSG]fN7ahO9NMTXYmPiBHVj6RZ[W3akZSW9Mm
LXNKV8b8UKJ]RX>0P7abNHB8Sh^6SHUdHf9WH5M9>CmAE51JJVm]Mg]XG6N7VX]m
RZ:]][:/ZiV=Rh1lN8JUZ::[ZIZHUXb2Nh^HWjZRXJZUWIFFU7QSH65WHU=DFe@o
:3]IG4lc>5MRGV5ZOhj6P8:1NWMjO6]PN8InMFiUHF=_LG1dLWUoOWUnOG5gPX9l
O7Q]HeILLWYgLgN1NFiiQi:KShN=WkNh^l_IhmZhYJb]V81jQHMeKX>;OW1WJ6Q/
LGIlOHfHUh^0SinAMFaZLXZBPgf6TY>2PXJ2QWQSIX2EUYJNVHV8SHQnMUa2DVij
MFQZLgUfNi6HT8B8VZ:LUiVJUHN:V9VCS9:NZJf//kRh/::DQXNGZJfPVYBE[;Vc
XY6@T8AeNh=kNgMTGeQ6A3/fA4]IH5EKN8J9TheeKh>;NVmkQXJ0NWf<QfMHMYRA
MEeTLf]RGfQjO6ibPhR4JTI4F6MVDDQ:FVYGCEa^RI5iKgB=YIRF/;VURX:;TiZH
Rgn1Ph>:S8f3MFadRYZ?LFb7XZ^_^;R^Y9NGX9:5PhJJWhb7R828RX1oQ820UZfe
ZYfHX:BJQ7A_K7F<THAiKW1kP81lNG9hP8B:Tj6VY:Rd/Z>LUHZ:VZVTVIBN]L>h
W8^9TY^QYJ>QUYZY]KR/VH26Wib3NhB0J4a7EUA2;b/m@SL[7bE2F5M?EFIaMGIc
KVMXKGQhJ5aFDE1NKFQLEU1IJfmWF4DjB6QlNVYIEVV4S8AiKF=OHVU`M75/MH:1
N7:0Yl_>^JfSTHVFYI^@SXZ?Y[FSQgMnU:2OViVHTY>MZJRRY:FPXZNYYYbMYjNP
UI6:R8bBTXMlO92V[Jf_Yj>c`KNPQ7E_KWN7V8a]I6n3SXZ0N7R=Y:BLRgMlTYbO
VHZ0SjRWTX9nQ92HT7QVIG>6SHE]KGEeQ9R[[9fHTYFUZj^RThV8PG9H<R@`?4=1
=24ZBEA;B55QHUQUOXJ2OH2AWIn@MV]nTHMeKFAGC59aRXE[F6J3RhJ2M6UjRH5d
JV=TH5iRHf=NGVYkP867S9BL[K>ZYjJY[kNjZ9F@WkcDcjb;R9fY[JnMPgAePI6O
WINAUjJ_Y92<WZZNViZ=MfUbOi:OVHjAUYF;MFYkSHakJEmBDVYlNW5WF59HHfe_
H55>GG1aKW9iN8FHUX=]KX6=S92>SiNBRiNOVXMbLWn?SWMRJ7f6RXElPH^CWk6c
Wi:LZZbZWGMRJV]JA3`i<b`V:2ld=C]=G6]gLfieR9bSWYB;SI:9Q8V4LFM^NGQY
E4aOOIJLSH6:U9FFVYV7MFe^LFUOGFEcPHF1MgAoTJ6`/jJKWZNldLN/Y;JnZYfI
Si6PY9jFPViZKGIkOH1jLG9iPY6EPWV1SIbMQg^3RH^?T8^8Ri:ETYFGVIbHUj2I
OG5mRHb7P6mRGfEVJ6=HFfYmRH=^HF5`PXV8Ogf:Tib]]:ZXZJFW[:^MQXNCVYnI
R8>;QX:8RX^?VjV`]k>Y//[Id/:_YZf[X9V@Pfi??T=6>R<F82d_?T]<EfmjQijU
XIB?X:j_ZYnIUiNHTH5aLg1WIVa`LVmWJFe`KEmAC4aGEd4fA5i^LFYMEeQTMGae
JF]jQXV9Q8B@Y[6//;RbYZB/_;fYU8^@VijLUHj;S8j?QG=ZM7ehLVUNG65[MG5d
QHR3Q8bGT81nR8EoQh^:OW5mTYB<Q7mmOXVDSWYjRYNGSH=kNh:>T8AiOH>:UZJZ
VH^<V9R7PhZ<RHR?VYZCSHJ5RHZ2NGV9VifJUi>M/k^h]kVcZjje/ZFBQ7AQE4a1
<1dG61XJ6A4;52]3BCd_<dMOKWQoPXf?QGf1RXYiJWV>Sgm]KX27PGQ^J6abLfaS
I6=LJX23MFALG69WIEmJGV=UJG1jNGEeNGj0Qh9jPijd_Kb/Z[_5a;nj`<O9bl:a
X9JEUI:DThn7QHnBShn?SIFS/;FYW9fS[;>f/j:@UJF`/If0M7V3PGYoS9VQZ:VU
Y9Z9QIBQVXelN8J?Rh=jL6QXLWYiLFYbOHF9QGAWL8:4L6E^O89nPI2GSXJ9TI>E
Ui:EZKo5^Zn^/:nXX:FLQW]kOgY[E4=8D514<RHM93<h?DA;BUA[MWYlN7V3QXJA
Th^9SYRNSGU]GUQNHEeHEFJ5T8AmN79`M8>:QgmbJ6=ZMgM[IgV9PWEbKVUaPY^Z
YZ2PZKS6bLG6c=OE_kc3`Kb_X:2QSgb3SY6<Og1]Lgb5PFmOFfZ1Q7eeJ6M`Lg1V
HfM/K6U^LgQdKgQmN7YhIe]NK7E_J6inRi:BRh9iOHjGVYF6PhnLXj2ES8^3NgUl
MVYUHfI_NG5TJGf<SHF0QX^>U9JDR7aiNgUcKfmdQ9>HViVIXZRVWI65LEiFF69Y
HUE;BU=LGEQEGEmLI7=hNhFAZ;N[U8:8UY>5OGUjOg]lPGY_KVmfQX^4PHF<VYjI
Uh^1OGA^I5AAFf=WJ6][K6QSI6QeQYBPYJN_]kc0_[JkaKn/ViFHWIV=PWioOh21
NG1^MhfJW96;V::PXZ6LVHn5Q8J9SXn;V:VVTh9nP7YhPWmfMG=kQhAjMW^1PXB6
QXVGXIB9SIFIUI2EVY23OW^0SIbVW8b:Si6DUifTWYfZ/:bUWInOVHmmM7=aL6mf
RIRJTY2N[kJYVYRPYZ>MVYB:R8EjLFIFBdU6ATM:C51FEDe8BdU8DEiYL6m`MWf5
QGY]IVYeLVQTGe]EDEEMI6M[K6QNEUIHIGEjMWEhMFi]OHV4NWIjPXb=SiZNUY6?
Si>EVj>Z][^XUI>=PgEdNW9[KW5eOX5iKfmjRHf2MWN1R8N6R8RBXZNXZj^SVI:I
YZFSWI^SY9^BT9:ETY:KXZBKW:jf[Ib<Q8jHTH9gMWj5QXJ>SXR8RXf7PXR?SXN;
T8f5O7=WHVEUETI5Df9XIUmLGU]MH5aOJWV2RYFGSXF5QXJ:Rhb?RWmdKgAdJEaC
CDLg928^=S/l=3M=G5iTKFm/IVUeNgakNX><RH9mL5iFCdeAFEiMGFA_LVmVI6mn
Q8:0PWn1R8N6S9bPV9FGU92EWjfl`KZe^;^k_LS9^;:f]l;;a[Vf]kB^X9RJX9bC
VZF/ZJ^c/[Fh/ZVUYjNUZj^PVIbNX9jAPGZ5TI::P7j4SiFGThf7Ph=oOGmoMW=g
NgM[IFI/MganQ8Z8RHZ;RXV5OhF=THEgMX26R8MoNW9XIfIOFUIBEEm`O7YdN7Yc
NXJ<SHb?UIjTWiVGV9^FQ6UGE5MBBT8b;C8f>cm2B4eIJgEhNW=aNH65Ri6?Q7Mh
Q8Z4P7aoQ7a`LGMfNhF3Q8Z@TiJLWIFDU96ATXZ0OX:3RIVIQG9]KgN4S8AcLGb9
S8R9RHF1O7QiN7N1RXb?SXQoOhF2N6iZK75jP8J@Thj@UiZGTIBJWJ:PUI:OYjNT
Y:NSWYJ@UIVBQg]fNh:2O7UiMWn?T8nASXjEW9F4MWAiN7Q_IVUaNgn0PX61NW1`
MGinMGN0QHEnLg1`M7f7SHV5QY>KVYbLZ[c2_k>`/Jj`/:f[Yib>OgIaJF=HBT=5
Bde9A4]OLW]eKfQRKgUgLW=nQHV5NVm[KFmdNWUjO7YfNHF3OH68Q7]kOGYcLgR2
RH9`FE=LI6AMFf1[LG1dPXjAU9VKWY^CT9>MYJ>QYJR[ZZJWXinJUi^IS7ahOH23
OWIiQY>HVY:4Ph>2PXN>S8=nOhJ@UI:;RI2ETXn=SXjAUj2QVYROYj6ESHN:T9JF
T92ARX5kNWioNgUiO7U`JFQ_M7]oO7=bOHF7PGAZHfE_LgMfOHZ<RHB4Q85nP8ZI
Y:>NUY>HVY65QH^:P7Q^FT0a;c@`8alR9RTZ:bdhCUaJF61WJFUZKG1cNWn3PhB6
OgUcLgV3RHV3OHB?Th^0LF=MG5aKIFY[JEmBAT92A4E;DEMHEU]YOY6JXk2f/k2d
]K>e_LO>d/Zo_<;8`[B/[JjWWYnUZ:NOWjJ^]K>[[;Jj/j^XYYjLXJ>OViZOYZ^[
YZZf`<K4^:jZY9ZASXV5PGinQHb>RGQ]KVi^JfIUJVi`JfANFfAaMWEcLW9bMWA]
KG1dMWEbL7=lO7MlPHB6PhB3QXN7R8R;U::UVHb5R8Z2NFMHDDLi9adI8C0g=B`[
:RPY=4aSK6eaNH>=SXfCU8b9TYZMVHnDYk>cZZ:QWYR=OWf7Rh^8PW]jNWYjOH:0
MgEhNWaoPhR>U:6Z[[2b^<7:clk;aL?5a/:j/jn][:bVX9bHTX^=UYR@PW^0Ph5n
PXN8PWelMFYTJG9kOgmmOXJ>T8j>Shj>T9:JWj2KUYRFT8Z4OGEaKFQWIfieNWU^
I61PIVQPFUQKGVA`N7]jMWIiNgQ`IUmMHVYXGeYOJ6]^LgEbMXNJYJRV[;Nn_:nX
Y:BNTH5fL6QOEDi2<RXY9RTd@4A9E5YTLGUmPhV;SIBGTi2?TIFDT8^:RXQnM71c
O8F;TI>ESgmcLgb2OW1RGUiNFemTGUQKHEmHD4mLMHB4QXnKXjJW[KBe[ZFOWYnV
Z:JSX9nOWinLVZ2XZ:6QYj^ZXiB4Ngb3RHZ;Rhf@TYBIWYjLUHb4PhN:QXJ<UIF=
QGegLg9dMgMjPhZ<QW]fN7j3PH>:SHn;QHB2PX>0PhV<SXZ6S96<QhAnMG1bN7Yk
MgEjPhN6PXVGXZVYYjZa/JjYXifFTX^0MF]KCD0l?dM@DDm:BTmJIFUWJG1cLFma
MgQgNGUmQH=kM6eXJ6e^LW^4QhZ=T9>DUYRJVY:<S8R0NgUaKgIgJeiLIFY[JVih
PhV:RHjHWYjFT9JOXibEUifMVYNFUY:@TYFGUiRS[:NKSXF7T9RNXjNTVI6<SI2C
THN5QXJ6RXb;T9FIV9>@Shb;QhR<SiFIU8f:SHn<RhR0O7]mOgioP8:0P864R8Z7
PhN?Thn<R81hM7UmO7I/IVIWJG1jPXJ5OWj:SXfATY:EVIJ>RXZ4MfYPEU1<AT<l
=cPi>CU1Be5IG5UIFUmWJfUYLG]mLfe/If9NG5aLGV5SH5iOI6MZL7AaKgMoPH20
PHN<RGmhMW]lMW=iQH^9QXN>V9nOVi^PXJ>[/[S0`[nk^[o4a<2i]KVk_/>n/jVT
YJFRXZJ]/JbRVI>EVYnMV9bPW9JBTiFCTYJESh^;RX9mOWimOgihM7MlNgI`Kg5`
KW1`K6UXJFefNWA/KVmVI6Y]Kg5fMg9`L6mbNWn0N6iZKgIcL7=eNGj1QXAnPH>4
Ph60MFYOEU=@CDe>AS`k?3Da=3Xk@e1BD5ASMGf0PXF>VijHTi6CTHZ6QH=mO8><
ShnBTI>MZ:^ZZJFPWI^LVI:;QhR:S8Z:SHn?SHV8QH1oP8RDVYRDUI^RZk:f][:a
]kZf/Zj/[[:d[:JWYJ6MUiBBTYFFTX^5OWEbMgimNWb0PHJ@U8b9S8^9QhAnMWIk
PHJ1NGUlPHB5QH>4R8N4Q8:0P864QhR1MG1bLg1dNWQbLGE]H5YKH6agNWEbNXB;
SY:EV9ZHUIJJV9JFUiVJUIBGUHn<SX]oMg=]JVIIB3i5DUYMGf5VKGEmQ8IoMW9e
N7IbLFi[Kg5]IF=WK71cN7QbLGQnNgIbKg1hPH5jMWUfKf]YJFQ[KFUYLGMhO8B>
V9VBSH^<T9:CTiJHUYZNWYfKVj2VYZ6OXjFTWiJ?SI2BUIVLVY>:R8bATXj<R8>2
QXZ8QXR:RHR6P7IcNX61OGUcJfQ/KW1cMgQiO7ekN7UmPhR7QX1gMWf2Q8B6R8J5
QH5lO8:;TiNESXV7QhV;RHN9SI6HWJ2OWIbJV9>@SHR1P8F<R7ifKVMMCcd_<Ci7
AdU@F5YLHf]dO7YeO8^AS8J4QH1dIEUFGFI^M7b3QXB3RI2?RH>4QhAlLfe/KVaZ
Jfe]JVUYK7AhM6ibOh^>SHb:SI6FUi:@TY2?UYbMWZ>YZZVXZ:Z][jj^[J^SV9JI
VI:5N71`N821P8B;U9^PY:FWZJVVWiZIVIJEUIFETHb8RXj@THj;SXj9PgemOgeg
MWIeLG:0SY2=RHF3QHN5Ogn:UINIWIbERH5nQ8nBT8jDVYbOWINGVYbIThj;QX1o
OgU^IF5LEDa1>cLh@TQ9BTiCEf1XK6aXI6EZKFaYIFIWIF9OGEQDEe]RJFQVIfa^
JVASHfAXJFa`L71_L7ElO7MdLW5`LG5_MH>>UINHV9VNXj>VZJZ[ZZ^`]ko8d=GE
dL[3`/O8a;jdZjBMVYbLV96<SHnEW9nOXZR^[JZTWIRIViVFUYFASXj>Shb6PXF9
RXZ8QH>7R8AlLF]VHEiMG5eRIfY[K6INGEmPHfQXIVIYKG5cLFm]JVIXK6maN869
SY6?RXR:S8IhJV=OEe9DE55CEE14?415AdeGH6IVIFMZL7EfMgIaLWUlNgYmP7n0
PX1jM7=iP8R?TY6=S8jATY:BTi2<RHN6RY6FV9JAS8Z9PWajMWAjPhN:S92BT96J
XJ2KW9nRYjng^[Vh]K>c[JFRY:^a/JbVXJ6QVY2<RXJ1OW]iNgj4RHZ9RX^5OX27
RXb<R8J8RHZ8Ph>8R8F3PhF5QHV:QWegN7QdKFY[Kg9bLG=hNGI_J6Q^Kf]ZKWR2
R8EnN7QkOH24QhZBVYjMVYRETY6=P7EbLG=dMGMgLg5bMGMgNGMbL7AeMWYoPX:2
OgUeM7EgN7MfMWEdMGMhMF]QHFI^MGYkNWQdKfYVHUiNIFYYJ6YaNHB@THZ1O7Yg
MWMeM7^4RHJ4QhR6QhjBShb>U9jTXj2QYZZ/ZjNX[JjZZJNTXY^ASY2>RhJ0OWn2
QXR8RHbCUiJ?QWilOh9oOGf0RiJDSHN4PGmoP7ioQHR7Ph9nMg=eNGQbJf]]Lgb3
QhAiK6MYLGUnP8>7R8J2PhJ7P7E/JVicN7n9UInQWiVDTXn9PGemP8B6RH^9R8V7
PGUaKFmcM7AfNWf0QXN2OWajN7YnPhN9RHR1N7AaJFAYLGMhM6i[JVU[K6YYKG9b
L79cMgUhNGYhLg9fNGYkOGUeN822O7EbLW9dMWMcL7=mR96FUI>EW:FXZ:>KVIVI
V9^MViZOXIZBSi2=Qh5kN7Z3SYNJUY2=SiFHUIJLXJ>QVi69Q7mmO7inNgYoR92B
T8^2NWQhMW=^JFikQhnCU9>CUI24O7aoPhR<SXj=SHnAT8b9QXZEXZ^/Yj:MUi>>
QgmlOXJ?THj5OGYnP7Y`JVUYJ6=NH6IZJV]_M7IbKFa^KfmaLG1_KVUQFUMHFf5V
IEmGEUaSHUaDCDiFHfY/Jf]^LG=fNGIcLgAcKVY]LGAiOhB3P865QhR9QhJ:TYbV
[Jj^/[Vm_l2o^;>e^KZj^KJd];>^Yj2KW9nLUi:CW:Ja^[Ze[JJOUXj?U9RLWYnO
Ui29QHVBV9>8P8:8RXN6QGmjN7QjNWYlPhR:Q7UaKVm^K6i`LgEeL6mbLfiXHf=Q
GUUFFf=]Lg=^JfQYKFi[I5eLH6EUHEmRIFIUIVUZJfiaLG9dLfi`MgakMW5^Kfi]
L7AfN7UgLFUTHfI_MWMbJfYaO8>5Q89nOGj3RX^8QXR7RH^=Rh^>SXj>S8b:RHfA
T8b6QXfAShb9R8R8Ri2EUY:EWZ>VYj>RXZN^[jb[[k>`[ZfXX9ZIVYZJVIRKXJRW
WYVGUYJGUiVKUY6@TY::Ng=cMGEgNW]kOXB3NWA^JFUYJfm^JVQ^MWQiOH5oMg1_
KW1fOXF;SHQnN7Z1R8=lMg9aLgAgMgIcLGAcKFUWJ79hM6aXIFEYKWEkNW=ZIf]e
Ng]kOX>;T92>RhR7R8J4Ph>3Ph9nNGMjPHN6P7ekMgIgMWEaJfMYL7MgMGIkPH1o
P81nOX64QhR6QHF5QHF6QXbCUYB?RXR9SI>FUI69OWYlPXF5QX^AThn9QXF6RXj?
RX=iLGInP7ilOX:3Ph^DVYZJVi^JVY^MY:^^YYZETi2=RXV6PGYfMgE`K6UZK6]X
IfY]Kg=eLW1bMGUoQhf>RhN8RXR3P7mmOhB3P7mlNW]mP8>6R8^=S8N1P8>5QXV<
RhR1N79`L71]JFadMgEdMW]mOh23RY6EUIBFVYZKWj:QWIVJWInNViVGThj:RH^>
Rh9jMgYmOWimOWmmNG=_KW1bLW5`Kfm]JfINFE]MGF1WL7UmNgQfNX67SI6EVIbL
Vi^LW9^HU92:R8^=SHR0O7amNgUgM79`JfIUJ6iiPXJ9SY6@SHf?TI>DTiBCT8j>
Si6@SHb=SX^6QXZ8P7QiP8>1Ogn3QXJ7RH^>SH^;TIJDSXjDV9F@Si6BT8j=T9NN
YJRZZZBNVYbPXjBPWIVETHj=SHf:PGA/If9NG5]MGUaHEEURJVaZJVmaK6UXIF=U
JF]YJFeeOX1lMFeXIfIVJW9hN7IhNGUhM6m`Lg9_LG9dMGIgMFeREe5GH6AVJ6ec
MgMgNX24Ph65S92CUIVMWinOXJ>UY:2KV9RGTY2CThb4PhN8Q81nPHZ?Shn@Shf<
SY:CTXn=Si:EV9ZKWZ6NV9BCTI2BTiBCSh^:RhjBTXj8QHF5Q8J:RhR6QH>2PX>4
QhR3NgAaM7IeM7=cLFi`M7E`K6]`M7AdN7j5QGihM79aKg9iP8F7R8b:Pg]eKf]Y
JW1fMg=aLG5^JVERIFebLW9dNh:4PWmnO7UeM7IjO7eoPhF3Ph1kN7UlNgYmP823
RHf=RXJ3Q8F1Mg1`LgMgMWIiNgUhOHF:RhfBUi^OY:JUYj^[ZJFPWJ2UZJBISXV<
TY:>R8>3QXB5SIJJVYRFUIB@RXb?SHN0N7N0Rhj<RXN0NgYgM75_L75_Jf]/K6a^
LgIhO7n0Qi2ASHZ;SHf<RHN7QhV?UINET8Z6QH>1OgmoPH^CUIFDTY>BShj<QX:0
Oh21PX>1PX9mNGIbKfi/LgenNWaoPGefKf]_M7IgO864Q860P7efKgB0QXF3PH21
OWMdMg]lO7aiMWMhN7f4Qh9lMgIiOGejMW=cMWYnP8>6Q7miNGenOh:7SI6BTI6A
TiJFTXZ9T9JDShN1NWA^JFMYJFMWJ6ihOh:4R8f<Qh:2QhfAUIVHUYFEThf4NG1_
L7=hNGYnPGiiMWQfKVU^M7MgLW9gOGn0Ogn1OgejMgQkOX67RHR4O7UiMgIkQ8^<
Rhf@TY>CTHf2NGUjOXbJY[2bZi^7OHB=UJ2WYinGTY6FXZ^][Z^SVIFFVYfITi2=
Si>FVI:4OWeoQHbFWYZASY6CT8Z7Pgj2Ri6AR7aiNG=_JV5LG5eLEeEJGf=UIFU[
HUUMJWInOh20OWaiNGn5RHImN7j6S8f8QH9mN7EeMFiSGVAaOH>3O7=cMgE_KW5a
JfU`NGemO7UeKVU/LG5`M7QhM7=cLFm`LW=eMWMfM7MmP8:6SYVOWIZGUYRETY:E
VJ2RVY:>TI>?RXbGXJFRWj6UYjJPVINQ/;JdY9JGYJfOSXV?UXb0QI6EV9NBRHF3
P7iiLfILH6ekPH=kL6aWJWF0PgQ^JVedMgIhP8V<PG5]LWQnOWQfPY6@NF5UOXb6
NgEfMgA[IfmiPXV8NfURHfEWK7ElOGadJ6MaPhj@TYNEQgYcN8ZMY9Z8M6ISKWZ4
QhZDVYN<Q8ZCVIbJUXn7Q8^HZ;6ZVhIcL7f9Q7UgOhR>UIJAR81jMgIfOHN8RHjB
THEkO7n0QXnBU9FCShR1O7QnQH1aJ6ALFEaQJG9iO7QbKVeYIfYbN7MdMGMkOX20
NWEkPGmgNX5mLFifNh29SHZ5PGn3QHJ3PXVBSX5hM75^NX^=OVURLH=iJ6M[KgIj
OWmiO8V@V9^>PXB9S8MoOhF>Thf4QI:JSG]kS:2RU8V8RY6GU96IZ:JDPGEhPI2Q
X9bMWZ2MVYVAPWIiQi6DS8N6R9>LW9B<RXR:UjJ^YIB>TI2;QXR@THQoNFeUKg]k
M6eYI554CfEfPhMfEdaWQ96@QX:9QgM]M8FCSGY_M7UgMGN1QhJ3PH68T9:<PWj4
RXV6QhR8Q7moPH61NFUNGE]GF5eZN7mkLFU]NhF;S8EkMG=cLgMoSIbQVHUoQ8j<
Q8F;SXf7Q8AlKfY^MWf6Shj3P8fJUXQnNGj3S9BASiBATZ6XYInCSI>QYijGUi6<
UjN/XZFa]JR?Ph^CU9^UWX1/M8N@QGM]IVQhS8IiPhj7OhBAX9j?T:ZgY8f9TINH
UHf2N6aVKW^6Ti=oJfYbK5MPOX1YH6YWFeMQKFYUJ79fLV1=BUMeQh9cJFETJ6eg
PGQL@d9HN8bBTYB>OFUVM7f2QXjGUY>6NgIfMFYLF6MoRX1gN7f1OWMeNX25RXnK
Z:RJRHNEW9J<QHVEXJRUVHb5PXREViF9PGn0P7YcL7=iOX5nMFmYJWEiM6aVI6]j
QY2CRGn0QXZ6PHRGYkJm/Yb7NWb<V9>2LGZN/ZNCRHZ5NW^8RWacNXbHT7]]Kg^>
UiVEQWEYMIJ`[8a[J7fCTX>1QHF2P7miKf=[Q92>P6]VIEM>G7b@S85nPgEXLhbB
NfUYIfA[PifPRF]MJhBARGb2TYJ<Qh^>R8>7T9n_/IZ0OiFY[::?OGQkOX64R8bB
SWmcJFE]L6ibM6i]LX:@R7I/JgF4T9B@R8J9PWEgRYFARX=oOh1jM71`Jf=MFem[
NH>6PGakMVmZHeeTO9BJT8EmMW9`M7f9Si2CTXf9PWQaLh6GY::JThb>ShQfJgF5
S8N2QHJ4QHF4R8jDW9ZFWZZe/Z6IW:FZZ;6h^[Z/TGQbTK_<^9R@TXYjLgZ5S9FO
WY5kK6]aLWb@WYn8K6=^P8R<ShN0P7mjNX20M6]ePGENDeeaNWAZHUiSMXElL6UY
NXZ@QVmOHfm`HEi`OhAnKUmJGF1LGfM/NXZAQfeQKH:;QXB8RH=gJg20SHb2MV]W
LGenOh5nNFiPGEiQIVemRXIhI5QNKVmQFFAiRHYoNWM_J6I_Pi6@TYFEU8UjL6Y/
MH:DZ;Bi]:ROUhn7PhB8TYVFT8b;RHF5R8=mPh^?W;2j]jbOVYB;RiZX/;[1_Zf@
OGMnU:>TXIfFTINQX9V?RXf8PH^O/;6LShn>S8YnKWB?Z[F/U7USEUYdV[RhYY1g
HEUSP9bYXY26Qh^4Lfj4ZJj4I725W:N=KfINDe=/T9V:L5iPH5QEE59JHfY/LGQj
HT8oEFj2S8^8PGQiNf]GE61_Kf9KIWR7SXQfI5UON9>KSWEWK7AbIf=eRHf;R7ed
NHV?QX9oNhJGVXejL71hQ8n8OXNHWi^ER7Y^I6UfNh:?VIbCQ7ehLWb<UIjVZ:>J
UIFHW9nNXJVWVYJIU8n4MgR3S9RKUI:EWIZ4K6f3UinKT85hOhV?THZ0NWZ1S9>@
T9bQUXb5NV]TL7QjQIBGSGicKF=JF6V6WJVVT8>8R7idJ6EeTjRNQ79XHFj7TX1S
GW:6THemM71YIW25VjRPPVMMGV9UNI2EWJ^TUXagI5mWNHfHU8^3OGIdMFI8@Uai
T:6LQWAUFEYNIW5bLgV1S9:DUH]gJfQZN8>5Oh2:QgQVHgfFWIZ@QWecL71eQ8Mk
MgeoP8R9MF=TJgN6SHf8PH>7S969P8JBV8UbHf1XJfYcNGIcMGUkM6ecMWb0MW1f
PXnJT861QHF5T9^NWI:=TINQYI^>RI:SZZj_Z9VBTiB:OXJHY:bg^JfWZYb4PIbc
_kZWVYZNWiAoNhVMYIR7OGYgMX2BYJZLRGI_MWajNgn0SjJQRWf0S96AS85[DT]C
IGnHXZ26HT@/=VZXeLZRMC/P6b<kB4i?BC4R>UIUHDm1<B4D5SETS9nZZHQKC5a`
NX>T`LFgY9bJV[7SilO2ZHfN^jUQGZ[:Q5V`k]:EHFnj_8iiJbP4?jGZcjVgY79j
KT=5H7IfEEfDX89E8@DeI3854BY1EUE3>c0/;3E3?S4c?Si9CTaGK7]aHV^0O7f;
SIVaYiJgdm?Ab=3[oooZio?^_l[ooooomOoon^[cooooooCbkMKMd/;8]INCUXR5
OhFK/mOQelVeSFY_QJ2XW9bKTH><TWeOCEUOGVZ8Xj^EKd`j>TUTHTY0AD<i7ADc
?4MFDDXi7@/H@4e@E51;@chlATa8=bLhACPQ4QX_Af1]FS<K5b0F4a<652di90d>
7cTl<C4W;CU2D51DGF=PDU]ePgeoMV=MJG]fMHbIX;BaZ9VIWifRZIUnQZg2/:>h
g>gC_/Fn]KS1dN_oooWYcl75`lkJfmoLe>;Rb]GWi^G`ookKcMSMe<O1^Zn/^mO[
k>ojk]g<`/k0]/CIjNSRfN?noooQ^[Bk_kbf_<_B`kBZXYB8QXJ4QIZTS75RI71`
JVA]K6IQG6=[KVaPB3U2DDm4@3T_>TM2=Qd:1@PE7B<K5RD`=4A6;18<20DB61LO
=T8d;d12;QT5000>8BdiB4iNHdH]=CDU40/J92`d@4a5=cY6Dde2E5MGF44i?EIH
AShd<d=@DE5JHV=ZM7IbO8jEW9f:O7V0QXNEWZ:__L?<e^;OeN7Vhncck^KHh_go
ooofj^[WhnOoooogc/CEd/KBdM7JfmcNfmOB_lGEeljj[[K0eN_Gb/RfXh>9[JVK
VZJh_:nCO7f@W8ekPH^7R8EcIg62MU92DFEcOh5gJU8j>TM9@Shg<C4hCF5SCSi;
FUM7@Tlo>SlmCU9ACTA0F5i6<CM7A4Df:BdcADiEGeMBF5];=d=HGDm7EFU/IfYO
DU=ICT94@4ECGF1BD512>SDnG5U;IX5oKW69UH^4Ri:CUiF@Xk6_]JbY`<O3en7=
c=GKi>GQf]KSjNWPj?oonNcZj>SJeNC^l>g_i]C>d]6n^lK?e^3MdLO5b<?5dmC7
a/Bn`M3QiLng[kcCelk7_;:nb;ZVW9JDTHfIX9fS[kFNRi2FU8f6SHinPIFNUH9m
P7nAVXn>T8EaFDe<@CPfBF=dLF9ICd0k:`T0000001XgAD4a9bH_<A/:0000000D
71LI820B008300000000000><D0^5Q060PX90000004E6AX/AeYA>c0jCU]SI5aJ
F6J6UZ6ZZJ2FXK6URH6;UYB<RIRiclj`ShnHTi:JZ;:^[JROY[W1/ZVTV8j8Q8VH
/mCE/iNIY[S>e<KEkNoRc/kDe=[]jljlc_3^dlODg]?Bf=G:d^OPc<gEfLg4`;W1
^k[1aL:o`/7;h>?=_k:JRXN1OGj6RiR^`/C2]JfbY89>8bM5G7>?WIF?SXMgHeeB
=1DSA4]>HGAdJV99<c]7CDPi;c=0CEEFF5I=CEQZJE]OJ5i9=S];CTUHIF=MIG5S
EeUTMGQiMW9hSjVKRXUfHG:5MFefQhagNhnDUI>FZ;RgX8UjPY2CVj2LU:Jk]J>H
WJ:DRiZPWIFNYYjS/[F`]ZjMV8MlS965P8VQ`lJXYJbNUibW/Z^BQibaZj2OUXZ9
TYZBR8VDXj6KYKC5dnCdkLb_Wi>CUJ2b_<Bk[[fo];k5/I9dGG29Q8BAW9Z[`JUh
HfaWDU1PJV=JHHBRZY]iJfYC=RPU>d`nBVe]GVAYK6Y_IfEaM6UCDVElRX]mHU=N
MhJ=SGIGCEaRDE1FFF9VGf=hQhb1IUaLC3TY:cY1?T=JK6IKG5M5<2H]:1XB6SQ7
B4eIJg5VEDDk=cU7DT]6CEEFDd8jB5URI5mFF6AaLFIPI6a_L7f9QWYcO8>0OG5a
NGYkPHR3Oh>4RiJPV81gRjK0fMffRW]dN8Z>T9FDTZFn`;k6b;V?H4e>IHRIUYFI
Y;C1_ZbVWXmoJG27S8n@TIRSWi:@VIB8Qhb:RY6HW:NRUiVDR8bQ^kbZY9RGYifF
X[6l^[>k`[bk]k[:b[><LH2V`<RaWjZf^K^d[kbiXI:L[J>;Q8f@TiRHU8bBSX60
QGaZGeiQFUQXO7YaJf1PJVICCe]TF4mCDeEDE5eTJ6MPHfegRHimLfe^L7=oRY2B
R8>?Y;:b[Z>:QYb^X8n<TYn`/Ib@Uk34dMJoVfmGIVmQDf=lR8bJ[;C5b;RVRFUH
Ce1UMg=cNW^0NWAfH44j?DACF4a=JGigMWn3OFiIAce5F5mQN92APgYgKGF=W9FC
XjFV[k2YWiJCXjfT[/7;h??_k^_=[jZYY::PVYNT/[Zi]kNTTINLV8n0J5aYLG9R
CemZJ6UIBeEME5=LFe1<DUUMIf=7?Te>@S]=HV]cLfUUHV1UGemZIfYlSYF?QG9/
Mh6<RGn7R7UlSIfOSgmhO7n7SY2RXHnK[[RkY8F<ZKk:e=K4ZI9nHeM[Mg=bMX^F
VZk0`JImFdI1Ae9UKg5fP8bM^L2JLUa@DeUNH6a^I6QaNhR>Sh^8R8RAXJFLUibS
VGiaPIje/k>l`LW<`;6f`/FfX9JDX;[8cMOJdLc@dLc7_:jY[Jn`[ZZOThnDViZG
Sh1ZHfQXLGYiM6mZJW=gJfQ^IE9?F5Q7?S/h<RT[=dAADT]4ADiABT=8CUETIeI<
ATICE4]:DEQPF4]>De9<AdI:B3PV93aEC3Hh@dQGHEeGDTI1@T0m?4EGKhJ7J4Ho
?3Tb:b<N61XS;T]MFdln:aX@5BT/7@`:8DUKCdaBDD8Y8CI@FEMNJ6aUFU5DIWAk
QiNZ];6d^KZm]jbOW:6UZK:k_<OKj>kUemW[j=3>g>7Xm_K[m?onmo3Tfn7YkOGo
oooooooolN;NfM7:`l[@al70_;g4a;bh]K:/Y:bcZ:FTX:Rb[Z:T[[:/XjVf_[^f
/:ZVY:fi]Znb]kRh/:V^][BVSGb1Qh^?QGn?Ui6<QWigKfEPGUmJG5mED55CG6IM
AT5CJGIkQZFn]99fJF1OJ6YPEDe:DV=bMFiRED/g9bm0C44T72hm>S0a>C@U50P:
51/S;2TS6A0D7b/d>D1=EUYSKGZ6S8UmLFY/LWf8SYBGXJZ]];Zh][Vd/:ROXZb`
Z9nKVinMThj?SYFU/;Nl^J^MVYN<Q8^;Qhf?SYFLTXIoOH1lLFQWL7YoQhZ5PX5l
KVAVJFM[MGZ6T8j8P7EbMgUcKFilT9ZKUiJGShR8SiVNUhj<UJ:TYIjDTXjEXZ6E
TYRPY9Z=QXR?SXV8QX1iNhN?U:6dcnGTbZfFTI:BUHUhIf5XLXF@ShAfLVYQJ6]S
GUQBFVU/LgUdKG1eNGYjPI2GTi29Ph:2OW5YJgR6RXnIY:nd[Yj?TYnPV9ZXZJ2R
YJjg^KZd[[Bj^;Rg^;jm]kFh];2c/:VXYjV/[:nb^l>mZI>7QH9hLG1WGUQCFE]J
Gf=ZK65RKViTGUYKG5eOH5eFFVAWJGJ3RXUnMgUlOGEZJ6ifQ8b1LV]^MG1^Kf]X
K7AdJ69THE=8AdA3@TI7@3i1@3XlADa9ADaFEe=>CeMRJVibOiFWZin6MWMiNGAW
G5aOHV9JGVe_HU53=2P/>DA1>SPd<S8^8Q0;5B<c>dI9AeAQHUiEEEaMGfA/MGYn
RYBEV9V=OGV5UjJ`/JfTXJnh/ZNTYJBOXJne^loLgMK8`l:i[jZ^^Kno_;g4a/W:
aLG1_[fk_/?3]:JTXIVEUY>8OW^4TIJPXYZLYZn`YYjNWYZIThR4Q8ZEUhn;T9JJ
WJ>]/[6_[kBh^KFa/[FcZZBOVINDSh^:S8nEUY28PX62P7M^JF]cMg=`Kfe/KFa^
MGb0RY:CUZ:b`<B_TX9oNgf1NFmWIF]`NH9oMfYECDmDH61A@C<^;R/V7QD:0P<9
41PR:cM3BDE0@DQCEe5AFeaGEUYUM7YlPhB2RYVW[JBHTIJOXZ6RYInBTiVHTiBJ
Ui2;Rhf=Shf9RHV>THV5OgEaKVYXJ6a]JFUYI6=]Mg]gL6][JVATKWIlQhj=RhfC
VIbRYj6KWY^LYZnd/jfVY:J/ZjN[/KFm_;>b/[:b/[Jd];Jf]KJi^K>/ZJ^d^;Zi
]KB`[:NRX9bGW:BNUiBDUIFJY:RVXj:UYj^famKMcJbKUibUYYn?MFIVL8F@S8N1
NX28Ri2ESGYVHVMVGEMCCT@k>C<d@T]<CeQOHF1ULGM`I5M>DV1ZKW1aM75XIFel
SIRFSh^?VJ6YZZFSXJ6RX9nOXJF[[Z^WYJ6ITi6?SXj<R85iN7U_GUIHHFicKV]X
GUAGHVYWHUiLG5mRHF9VKFmZIfQ]MX65QhV8Si>CSh^6PX:3PgidJ6M]NHN=RH=l
MGEkQXMnOX1lNW]lOgmmN6mYIFA]N7YjMVm]M866PX67S92AT8^7QhR;SHZ>VZ>/
/JN>OGIbM7MfJUQ<AdY<CTi7@3Xi?D9:DU5BDDI5A493?CHd=cdn?TE@F5mSI69Y
NHZHW::UY:JXZ:VYYZZ/Yj>V//KGhNGSg]gMhng/h=38b<_>dLk;bLFo_l>n]K6a
/JbVVY28Q8B3OWI^IfAUJ6IQFUENJg1cNGioOh65RY2CU9JBRXF6Ri6GVIJDVZ6Q
Wj2NVYVJVinPWYbHTHnCTh^3Ng9_Kg1bLViXIVQYIEmQJ6e/IFAVHUmLFEUIEUEB
CTe@E5ULFeYLHVUcM7^8TifX/KJj]J:GT92CT8]nJeeIF5UOGUA8@TM9A4M?E5=;
BTe8?SLb;BXU7ALC5Q`X>D=7BT]?G6ajOgmnNWb6SYBESX9hMWMiQiRUZJR[/;Jn
a<K3a/c9aLBn^[Re[JBIR7]bKFm^JfmiOWn0P7ikMFaVIV]_KVQPFUQLHfMTHVAT
I6UcP8Z@VIfLVINETY>IViB<RHV>UYNCT92CVIfQYJ^_/;6c/k2/[:n]ZJNUYZFP
W9VGU9BAS8^?VJ6Y[ZbWYjNSWiZ>PginNg9cMgf1P8B5R8f>U9fZ_]7LfLc1^[Fd
/::BPgUbJFQ/K6]VGEMFF5YQJFibL6aZIVEMDTi>ASXa;2lg@4I8C4mCI7N6TIJG
Wjjk`/K8a;no`/6l_<73a<G4a<S>dLo<c]3AcLS4_kZeZi^?Q7]eL6m/HUQABdY;
CU9BCdeBFfE[KVm[HE]MH65SIfMUIVY`N7j0O7f3RXb:RHV<Ti>?RhR3OgelOGag
MGIiOX1nOgn3QHB5QhJ2P8>5PgemOWelNGA^JFQZK6iZJ6ARIF=PH65SIVMVHfE]
KW1cLFi/KVm_Mh6=WZjg/j^UXjN/ZJ6KUiJDSh^5Q85eLGEhN7MgMW9bLgMkNGIe
L6e]JfIPGemMFUUIGF5WLGb5Rhf?UIfV/;Rl_kfi^l35bLc?d]39`/72`;fk^kZi
_<C9al;0_k^e[:>HSXR4OgQbLFi[J6ASHUiJG6A]LgMhLg5gOX61O7=`MWenOGYc
L79dLfm/KW5fNGMcKVa/JFMWIVMXJW1cMWYjMWAeMG5_KVi^L79gOh5oOWn0OWYh
NWemNg]mOh62PhJ9S8J1Oh61Mg9`L7AcLgAeM7EeMgMaKW5jQ8AnMG=hOWiiMfmU
GeUDCDM1?C`o@d=6Be5EFf=THf5QGeaLG5MBCTiCEE=DEUA?EF=`NhB8Ri:JXZZ_
/kJf/k2a/k:c/k6^Z:BRX::UYjVZZZNSWi^DSi6DT8N1O7McLF]RFEMJHVUXHeiL
HVaeNW]kNGQjP8ZCUYJIW9fNWinOY:VXZ:VZ[;6h_;k0_;Fa[jfZZJRVY:2HT8^;
SHf<S8V4PHF;SH^4OW]hM6m]K6ibMWYlOh>5QHF8QhB3PhN;Si:CUibNWIjMVIJB
T8n?TI2=TYVR[:n[XINEUibPWY:4NWE^IUaAB4A0@3dg=SDf>3/o@3hm>STmADa?
CTa8B4Y9ADA2@DA;EV=`NGn6SIBO[;:c/kFf^/?:cL_6`Kfk]k:/YjJZ[k>g^;Nf
];6[YjJSX9bIV9F<P7I]J6EPEDY5@Chl?D=7AD=3B4aBGfacNH24QXV=SHb>SHZ<
SXj>TIFCT8j;Rhn@S8^?TiRMWYfMVYFARh=nOX21P7mnOGn0O7]kN7IfM7=bL71d
N7MdLg1`MWYmOWmnOX>6QhZ=SY2?TYJFVYVIViRHWZBY[[2/YInNXJ6KUI2:RXAo
OWIaK6ISHVAWIfITIV]^LG5/J6MXKG9dMGEfNX26RHN4P8:<V9nPWj2SZkFk_[no
_[k1a<G7b<C1_kZe/[Bb[[2c][Ri]kFf]kRg][:ZXYjLVIJCSHR2NG9^JF9HC4I6
BTi?D55CEeiWL7IiNWaoPh>1PX:3Q8=oO7UgMgIgNW]gLgEkOgilNWUiN7EcLg1_
KV]XIfU[KFi/JV]/K6]XJ6U[KFa/KFm`KfURGUeNFe]QIVifNWakNGMfMgYkN7Un
PhV;QhB6Ri:GVIN=PWmoPXN1MVACCTa:AT0i=C@e=S0/;C0g?T4l>C`o@TU@EEMH
F5MIGEmQI6AWKWIoRI:DUifSZk:d]KNnaLW?e=OIf=KCd<g:a/6k][Jk`<;1_[Ze
/:fZYj:OWIbHTX^3N75^K6YTG5IEEeYKFe]KGF5UKWIkPHR=TYJHVINGVinTZ:V[
[Jj/Zj^[ZZNUY:6NWJ2VZj^XY:2MVibKVIB?RhJ2P7ehLfiYHeeIFEaOHF9PG5IE
EeYOHVIYKFm`M7QlOX62OgajNganOh1oPH60QHR:SY2AU9JHV9FGUiB@RX9hK6QU
HEiGD4]6BU1DEE1>CDeAEeULGUeNH69NFUYKFeeNGUiOIVmhP8F8Ri6KXjVb^Kk1
al_9a/G1_[jk/ZRTXj6PXIjHUi^LVYZIUYFHWJ6UZ:NSX9bFSHEjK65GDDm@D51?
CTiADU9DFEiUKG9eN7aoQ8V9QXF8RhZ7PWmoP820PX60P8B8Rhb;RXf@TYFHUi:C
UIBDUYRJVijNViNCShf<SHf;QX:1PX5oOG]lNgUgMWUnQ8Z?SHZ<SHnAT8j8QHF3
QHJ9SHnBUi^OW9ZIUiRIVijHU9BASHR1O7E[I5]AC4]>DUQMH61PHfEYK71bM7Qg
M79cMWIfMWMiNW]oQH^AV9nPXZBW[k[2bL_;b<K5`;N_ZjRMTHZ1Ngj0P7mlN7Mj
P8>0PXF4Qhb<S8Z3O7MdLFUQG5MADEEFF5]RIfY`M7IlR9>HWZ>RXJ2OX:6PW9J?
RXZ7OWQdLG1aKfe`MWakNGanNgenO8:6Ph9oNgIaKfi^L75aL71/IfMXJFY[KFia
M7IjNWQjOGn4S8j<SHZ5Q85mNGQjOH20OWelO7UgMWIkPHN@UINET8Z;RXV5O7A]
I5mMFDm6?cXh<B`/;C4g?4=:BTa@EEaQHVAZKg=kPhN;SXnCTi>HVinX[[:g_LG?
dmGEdm?Dd/g9`[Vc[ZJPVI:?RHB3P820Oh>9SXj:Ph61OWenOGUfMWIeLg5/JVYW
I6AXJfidO8B:TIZQZ:ne^[bl_l2n^[J`ZjVZZZ>LViJATi:=RhjDUYRPWYfRY:BU
YJBMVYVDSH9fL6USH5eMFEABDEEHFf1QHFIYJfUUIVa`M7YkNWIbLVmYJFi`KFi`
MGMjOh25R8Z>T9BKWIbLUY:DSXb:Q7abJVEPGUaECT]:B490@D52@TA:CDa>Cd]=
D51BDU5GH61NHFEVJW1gO7n2Qi6KY:Z^];^m`/W5^kBb];6ZXijKW9^HU9:=R8R8
Q864R8nHWZ6NVYVGTXV1O7QdMWMaKFUWIfU/KFi`M7b6S9>LX:6VZjZUYZ^ZZ:VY
Z:RYXiZFTXf;S8Z6QHV@UYFBTI:EViZIW9bKW9VESXR6PWejMVeYKFaUH6=YKG5g
NgYlP8>3Q8F2PH:4QhZ9Q8:1O7YlO7QdLg=dN7n3R8f<S8jDU9BGUiBBTXj6NfiS
G5QCCDU8C4a=DE1;AdY?E5]TJ6eeOX:4QX5hM7AbLg=eMgMjPHB5Ri6CUYbPYJR[
/;:`[JZ[[:VTWYRIW9R@SXf5OWn1P7imOGj0P8:3Qh^=T92<QX1hM7V0PX1nOgaf
N7YiNh65QHJ>VJ:[/;6e^kRc[ZFOWZ6WYIfCQh1lNWQcKFIVKFa[Kg9fMgIiOGeh
NGimMG5bLW5]HUQFFeUCEeUDEEaPIF]^K6ajR8b@UI2?W:BNVIjMU96FThb6PX>5
R8V:Ri6HV9F>R8F6S8f8QH5iLFicMW=^H59BDDa<BTI3ADM7C55@DEAEFV=ZK6i_
LGInQ8J5QhfAUYVKXJBSZK2c^;bk_<32`knm`Knl^[>_/:nXVi6>RXV:RHAoNGEd
MgUiMW5/K71dM6m^LW5ZI69SH5QEFEaMH6AWJVedNg^1SiFGXk2e^Knm^Kbm]Z^S
WIJFTHF1Ph>2PgihNWf0QXZ:R85kNhB<R7YaJ61NH6AXKFaVGF1XJVUYJF]^KW9n
QXR;TIFIX:>OW9ZHVjB]/;2f^K2//;6/[;2_Z:6QYZVVXI^DSXJ1OGA/J6EWJ61D
CTQ9Ce5=B4I:Cde<Ce=KG5EDGVAQGfQcMgMgNWj5QH9nNh::TYRIWJ:MVZ6UXZ2O
VYFIVY6>UIZESh^<SXf;QhN>Ti:<QXV=S8V7PGIaLW5^KFaYIFMZJFQ^LgEiNGQk
P822RI>JViVNZ:ZXXZ2TYInOWiRCSHF1Ph5mNGQfMWUfLWN1R8f9QHN6PX>9RXF1
OGalOWecK71_IV5QHf5UJf]aPHUoO7n3SI6@SY>KXZ6KV9JDUIZGShR1NGQkOGak
NgAYHF1QGEeMF5=HFeIBBdM5AdY9Ad91A4A6D5IHFEaTIfM/LW=fMGIjNh>?U9:C
TYNNYK2d[Z^][[6e/J:FTXn>Shf:RHnGVIFEUI>DUI:9RiFFV9RCThj<Sh^7RHV2
PhJ4OgakMWN5RHF1Q8J0Q8R7S9BDTi6IXijRZ:JWZZRTXZ>UYZFOUIBDRHB8Q7]e
LWAfN7MaJfY_M7N2OW9gN7UlMgEbKFY^KfYUJ7EgMh:7Q8R;TIZPWIZS[Zj/[[Bg
^<?9a/:o^:n_^KjhZjBQXYfAQ7M`HeI=B40f=3]4ATE1>cTj?T93BE=DDTM6CeIG
FFM`N7imN7R3RHZ>Shb<V:>/_<:gZjfd/JRVYJ2PZJfVVYZDRXN<Sh=dLG9fNWYg
MWE^JVifMWJ1PWelNgM^IfIZIFI/JVi_JfmgNWZ2QXF3QXnHXZZ^ZYbIVYZETIVP
WIB>RhR7QhR6QXN8S8^:RXF3PHF8QGmlPXV7Q8nETHV3O75ZJFMXIV=UJ6i^M7Qe
M7AgLg1aN868T9:EWZ>QY[:d/kNh/k6f]JRUYZ:LU8MdJVIQFeeLDdm?D4]8B44o
CEMBB4QACd]DFUEADUAHGFEYJfa]Kg9iMgQiNH:AX:bh/JBWZjFPXIjGUYVHUYRK
UXf8RHnGVYNCTYVHUIB@RX>4PgikN7eoO7mmL6]aM6iUJWAjPhZ>SXV7Q8B5PhJ7
QhVAWZ:SXYfAT9NFVYV>R8fCTi>?S96HVYNGWZJ][:FQXJ:QVHnEWInMUhYdKg1^
K6MVIVIYJF9IDeINGEECE5UOIW9gMgIlQhjDUYRGU9VKV8n?SHN9Rhj?RH9nOGUi
O7I_K6aXI5mEDeEBAD12@4=3@d10ADY?CE5QKWEdLWAdM79aMgYaMHNCVjNh_KNh
]kB^ZJZ//[B`Z:2DSI6>S8nATY2?TYNLXJBMU8b5Q8F:SY:FTHfAUXUgLW^3R9>G
UIVPZJZYZZN[/JVQYZb`/kNfZY^KWIN?S8f9QX:2PGikMgQhNWeoP8:6PGf1PGad
JF=WLWaoOg]dJVIPFeYPJVi[JVmcLVi[JVQZIf9ULXNCUiF@TinPU8b?T96LYZJI
T8f7MfiVGU]DEeeMF5=CDDY3A490AdmEGfU]LG1TETe?DU=FFV1/MWUjOGj0PGYc
MX6;UJ>_^l72_k^k`<6l]Jjc^;N`YijGSHJ4PWYaMX68S8j>QGinPXAnNh29RHR;
R81jM6mZIV]cMG5aNhZAUibIV9^NX:N^[Jjb/j^Z[JJMV9ZDT92@SHb;QgedK6EW
KW=gPH^;R8fCRGafNWahN7UjNGj4QG]ZHf1JFV5TIVeeNWYfMGMiNgQjQHnIYZb/
ZZ>UYijGUj2VYj^]XY21N79YHemKFEmYKfQLEU=CCdmEGF1VMhRARGagKV5JGV5O
GVMgNg^2QX9iL6UXKGZ6SI:LZ[>_YJBYZJR][j^PVj:TWI6=QgaaLganO829T9:@
UYbLV9fSWYFCV9FAT9>>OgEbNGATGVE`LgAlPX1mR9JKVYZHTHR3Ph=oOGahM7Im
P7]cLW9aKfmbLVm`NhV?U9^QXibEVIRFUYJAS8^>SXMnN7MbJFEVJ6ASJ6USFf5^
KVUXKG9fNX:?T8Z=Thn7QHN5PGYeKFMYJ5i>?cXh<S8f=ci7DU]QHeiOIfQVJWEk
N7QmPHN:PWAWHVI]NGj3SYJHVJ6RWIbPYjBPYkJl]JjYYYjFUINBSYBKW9ZDRh9i
L6Y[KG9hNW9aOXJ4P7n5RXb=TYF@Ri2IW9BCWJBTXj6OXJB[ZjNX[kk4`lSBe/k8
`KFYXj:PV8V4RXZ4O7UhKVY`LFQLEEALIg1`Kg1aLW=aLGV0NgQkP7aiOX9oNgf3
PgelPXZ?RhZHYJf^/;Nh]KJg]Jnb]KB^Yj:DQG]gL6ERHfAMCT8m>S8Z:R`X9bld
=c/nA4Y:AdA0@DUEH6E/MgeoP8J:QhB8S96BV::ZZjZ]];6VYJfb][Jh_/6l/jjU
ViRMVi:<SHn=RXN1M6EPH5UDDeMNGUaOH5]KH6ETHVAZLg^1PWmmOX>2OGf1Ph9o
NWb3RHb=RXR>WJRXYjZ]XiB<Rhf;RXZ@UIFCSXIoPhR2N7EjOH23Ph9jLG5bLFa/
MX64R8n@RXR;RhV9RHjCU9:AShf>T8j7QhZ:Q7mhMWQhN79TF59EFUYKHF1IE5IK
G5]FEe]NHFYbLgImPhR;T9:FV9RNYJBTZ[6`Z:B[/[>b/:VMUiVNWYNCTiNEShb:
QhF5PGYiP8J6PWj0PH1oOWYeLGN1Q8F5Q7edKVi`KV]YK75cNHB<SY2CTHnDWJ>T
YZZ]ZZ:PYZNOV9:9P7mnN71WIVmiPHB6R8R:SX^5Q8Z;QH:2QX^8P7YfL75cKUiE
GFEZKgIfLVaXKGJ1R96LY:N[/k>c_;nk]K>g]:na]K>XTXB5PG=WH5Q@DeIGD4@j
=3Dk@DE2?TAAEeECDeEBC4Y=CDU;DEMMIGJ1P7]mQi2JY:b^[:ng_l?3`l2j]KJd
ZYnFThenMWMeKVieNWQ/J6mdLWAjNGb2RHZ5OgYiNW]nO7=`M7UiLVe/JVISJ75b
M7^4SYBHVYN@RXV9RHV;TI2<RHR7PWeiLFQXLWUiO8NIYjf_/kFd]kk5_JbPXZ2L
VYJ>QXF5Q89hK6][JViaLG9kRXn=U9RKWYjSZ:b^[ZbVVY6:PG=UGUaGDU9BD4To
>Si8E6=_LWF0Rhf9R8N5PH20P7ilPHB0M6e]KFa/Kg9dO8J@UY>@U9^PXJ2LV9^U
YJ2HTiJCSHZ;RhF5PgYcMWj0NW9_Lg^0PhF3O7=_L75bMWE`KG=iN7EgN7EdMWf7
SHjCVIJ@SX^6PH>7Q7n0QH^;R8=lN7MkPX=nP8F>U9>FUY65O7YiMG=bKVaaNWml
MG5eN7^2RHn@SI:IWJ:UYZFU[;Nf];k5`kV/Y:2NWJ6MT8EmMg9YIV9NFeABE59;
AdA5@T=6@dE:CeAEEeQJFEEJIg5bLgMgL75lQX^=TY^U[K:g`LC1_;Jc/;2`[jfa
]K6ZYJJRUh^5Q7ihOHB5PX62OGYiNWakMG9aLG=dLVaTI6EXKG9hNWMeNGinOh:9
TIRNXIjGUI^QXIbKWifGT92BSXR1NgQkOGimOX>8RhR7RHV:Rhf?S8Z?V9bKVI>9
PWagLFULDE9MIVmcLG5bNH:;UInY[:bb][B^ZZfb/:RLRWYgNgU`IUiEC40j>cdk
>cdm?dA:DEUPIFU]Kfi_LWAfNGUeKF]_LG9cL6a/M829S8f>UIfRYJFWYZJX[:fY
ZZ^YXY^ESHAnO7aiNGUfL6eaLg=eMG9/HE]OJW9cLW5^KgMoP7n0OgikNhB<RhZ?
U9:>T9>EUINHU8n>TI>BRhR7R8Z:Qh5kMWIkOGUgMgA_LWQfL6maLWIkOWefLFma
MWb5SI2;RHjJXJBUXYjLXj^]/KJj_Kbna<C3`lO4]ZJGSHMkLFePCdE1@c`a:2DZ
=459BdY:CE1@DUIHFEeVKFi]KW9hNWYmP7inQ8nKY[:j^KFa/KO0alc<b<S8b<Jo
^;J`YIbIThV5R8MoNWIfMgAfNW]fMG]nNgQhN7]oPh5iKFETIF9PIV][K7=lOgio
PhB6SiRKViZNXj:MWZ>OU8Z5Q8B4QX9hLW9cLg9cLW5_LWUkNh6=TiFDTY>CTi2>
Rh=lNgakNWQeM7MkOgilP8ZCV9jY/[>a/[BaYYV<OG=_JV9FB3`d;bPW:BPU9R/b
>DADGfATJ75gNWn7RhR6R8^9R8R7Q8:0O7f0Ph^DUiRKXJ>SWYVJXJbg]k6XXj2K
Thf8PgefLgEeM7=^J6IVIfYYIVM[KWN2QhF0OgeiOhR;RXR;T9JGV9nWZZV[[ZfY
YJBPWYVEU96;QhR8PWenP8:2PGioQXnCSh^8Qh:1R8jATI2DVibGSXN6QHB1O7Qi
P8F6RY2DT8^=TYNOZ[>d/K6f^[Vi_l2gZI^BRGmlNGA[GUM@BDI6@SXb;Rh`<C4d
?DM@F5iPGf=XJV]aNGaiMgYmPXN6PGelP8R@UIRJVifOYJf`/JnZYZBTXinGSXN4
OWEaKFMTIfUXIVAPGUmRIfY]Lgj5QH>3QXb@SXb8R8V;T96@TI>?Qh:1Ph:2PH21
Q8J5Ph>7SY:AT8^7PWYgN7IaKFMSHfM[KFm_LGAeN7n8RhbAUi^MW9jSY:2NWY^N
Y:NVX9ZHVY^KV9NFTYFJW9nSYjRSVi:8OWA_Kfi/I5Y@@cPb;BLR8B<R92`g@4I<
D59DF5aSJFmcLg9_M7]nPhZ>SXb:RY:HVJ2VYZN]/[:_Zjb_/k>^YIjJVINCU9BA
S8J3PX>4QXN6QHB3Ph:1PXN;RHN6QH9oOh21PX>1Oh24SYBGVijPWYfQYZVZZJZ/
ZZFVZJJQWYZARhN7RHN4PH22Q8J7QXF7QX9nP8J8QXB2OgajMWIhN7QhLfmbNX22
PXN;S8^?VJ:Z/:n/Z:V^/K>c]:fLSH9gKV9FD4Y2>C8b;bDL61LF5QhU;3@mAdiC
FEeLGVA/LGAlPX:2QHV=SXf=TIBHWZ>UXYnQYZBQX9bETYJGU9FDSXMoO7n1OGIe
M6eYJFQUHV1RIFITIF]aMWf4QH>3R92DUIRIVijPX9nRZ:f/ZZ^]ZjBMU8n=RHR5
P861P85kMWIfMWIjP821R8f>TIFDShF1QHN4RI>FTHj@UIVFTY6?RX>2QHB3R8b8
Q7mlOhB6RHfBVZ2SXIbNXj>NUI2;QH5lMg9/IfAOFeQBBd92Ade?E5eOGUmTJFUW
JVe]K6acMgMlPX9nNG9]LGMiP8R:SIFOYJ^b][Bd]KS0a<;3`KZe[ZJNUHj7PWil
OWilNWUgMWAeMgQjNh64Ph>6R8B2QX^=Si2@TY:EVIN@RXZ?Si2@T8n;R8R<T92@
T8j>S8V5PX20OGYhNGUeM75[J6IXJVIWKW1bNWf1QXF2OgalP85oP7n3Ri6CTYJJ
VYZOX9ZGVIRFUIVLWIZBSHImMV]PFU58@S/h<Bh`:B0L6ATP:cDoB4aAFV9WJfe/
L7Z0P823QhJ3P824Q8:9TIJKX:>XZjb_][B_/;Bf][B^XYRDTi2?RXN8PGMdMWMi
O7n0PGj0Q8F7QXB3Ph9nO821OGinO7MgO7emNg]oP7imNGb0PH>8SiFCUY^MWY^G
SXfBU9NHV9ZKW9ZKX:>TWY^LWinSZ:VYYZBSXJ6MUY::OWUfLFi^KVa[Kg1cO7n0
P8B5PhZDVjJ]ZZNZZZf`[JVRUY2>R81gJf=MDTY1>SPe=3Y1?Si7D5=AEEeSIF]d
NWf1RXf5O7IeMFm/JVaaMg]oPh^FU8nFV9RHVjN/ZJbZZ:ZXZ:>IVi>1NWMeKf]V
H5mWKVeWJW9fOh9nMgR4Ti>?TI>DTi2AU92@Thn8QhjHWijKW9RATY>@THZ0Ng]i
LFMWJVi_KFMVKfi_KW5fM7AkP824RI2BSXnLXYjIV9bLU8Z7QH64Q7ieKgJ3RhjB
V9nW[Jne^;Jm_[F_Z:JVW8j5N6IKEDXg92D/:RXT71hO92lb>3i0AU=QH5MBD5IP
Jg1_LF]PHfETJF]XIVUgQHZ@VJ>^/:VZ[kFn_ko7d];6`;ff/[2`[Yf:OGYoQ8fE
R7UkNgj8RH9mNgQeMGYkL6]^KVm]KgAeLW9mQHF5PHVIVijKVZb/ZJ^VZkB^ZJn/
XZ>VXYbEUYJIXjVQV8n6Ri:KXj6RWY>@TiB;PGijMG=bKfadLFMdNg=[IF=VJ6EV
JVenSiRHT9>IWJBXY:NVUH^=S8^5JF=MBDI1>3Pl>RlY=3Tb>4YDGUU>E61UHEiO
HfibL7=fMWYfOHIhKgAnQHZBW::PXj>TYZRYXYVT/kBcZI^LUXbCTXB1PGn1QX>9
RW]bLG=gOXJ;SiFFVJ6RV9bXX9NGV9NDU9^HSi>FUiV?VjNSX:Bjakbnc<J[XJf`
]Z^3M7b2QWmZGEmUJFi_J65]P8V8OGinN7^2OgUjN75kOGijI65VHV1QGeUIHW5h
P8Z4R9^UYZNOXk:e^LO5^K6UWjNJO5m>EE<e?DLo7Qdf720R<4U3DFQS=cihMU9H
J5MUHeUNI6EAF7a/HeIBIEY]R:6QY8Z@][V_ZLG2^;N[c]^kXY6?UkFcW7EbTYb>
RhIhMXFIUYBASHnVX8AjOHAgKf=cOXF0OI:@NHBDVhefOYZXWi>JZJVLVY9kRIV@
ShjDVjVSNY6]ZJ:EPh9oLgnAS7QXJ7UcKGAjQWa[M8NCSWaaKg9bKgInKV:0TXAb
NhB5PGV7WiahQY^PY9JSZJ>YUW]XJV]F=cU:BD@h;D1@FTi1=TeREF]JBWFBPemH
MH9aIVieO8QfLHF4S9f[/Ij@[in?_lFVVj:]`jf>YJjDPhnRS7YNI95kGgE`JX=h
ETEUPfMNN8b5Q9R8L8BAQWb1NH6FS9neVY:>TZ6FRXR5V:Na][:_[K_Bak6Z[[6P
Ti>;XYQYGgMgHV=QGUYBK7Q[IG2;U9J;OibXV9FIUJ:MNFE]OWIAF7EfKFamOhF9
PW=fUj^RXjFV]<32`<?2/kN]T9Z@M6n3Rfe4AEU<?3I1@bhL4BY2=S52AT9FM6m]
NViCF6MjRWUQFfF7VhAZLYJ6Ih6YWibOUKG4]kF`/jbd^K>X]l2/[YjCVHb;UI24
MfQZPhEXLH9`K7idMXMbFeIYLVmIF6i]Jg1`MW5_NViVQIBRTGV:SHB2TW]QM8Ih
G5aQN8AdNGERL864OH>HSh^AXIZ0K8j<KXVHMUEQRXUgQIJER7UjPH9TQJN1OWb7
PG>7ShZ>VX6SZiRiWH2>U:2bSg=gFVj@LVIPDUDn>DMCDd93H6EAHVQgR7VBYYjD
Si>AVKR_UJN[Wjn^ZjjSV9Vcc[JKX[[Rmlk3cK2oh^[A/Zf[/=GAZ:6FPI:OPGf?
RWnC[:N8KgV<XiF3Ti>ISHZVVXFHOU9fMG63KV9PFGMmB5mRGHaQDhYdMY1]OY6B
W7EVS7emO5ILBdY`H3e3G6M`KEYIKFeYLfeIHX^=MGinMEmOLFa:;DMLBcYIJ6EE
D75/J7i`IiBZZk^ZV:nlamC0b;:5]kbL/7aPNFARE3@c=c/d=dXb6DAQ?c]FL8IU
FfMhXhmZQH>6/8][PWB0PVjFS7UoN:KNdY6G][_Bc;JoamG4`N_9UY^Y[:FVWGYb
PGj?UWi/GVjAO6MmOEm[NWUlIg9mI79jJGmdG8B=Og=fRfiTQ81/J6ASOXalNGi_
KHJ1KFEMNhmfMWASLHnQWhZ4UhUmQ6UGK8ZCPTm<Qhn2OVETOWioL6QlN8NDNGEd
PJbBIFUjX;BQZ:BM^l:^YinZZYW0/8Z;NXJFK4i=DGYMCW5QJ6iOLfaKNU=BNVIb
L5ajQ55?JGEbEEifL6Q`N8VHSY:d_;_Ed[boalK2cmOBakJ]/;FjbkZOXZB:Oi25
OYJ@O8^FSgQeWIb5PF5LQh]iN5i@GTUFNU4hFWF4OfaHEWjZZYBGY<;KajJ`a/7D
`ifSXI^JLV=aR:2=JdYMMVebM71LB6NTSg9WH8jGSX]RHheoOF/jCV=CCdUHKUMH
LGV@Kdn4WI6JY/3=[jRWYZ^a^8alOG6;QTa0BC4[;d4k000Q;Bhc>DDk?W>3FeE[
OY2BNGZIUgacL6eWH6]HHhAiOgAgU7ijZY^I]9^[aKV/[LW2XKKIci^AZj2CSgin
MWVOW9^_MfnbYXN8U[VeSYRXUijPQ8JKVY61L75fQiYlKi1lIi2DOGEOMIJP^[fI
Rh>Qf[B<TIJQXZjkWHRJUib>NXMnOXR1LEM8Ge]iQeYMJU=BEd1HIFaWF7f3LXV7
JVEMJHb7NgQ]NIRRTGb6X;2SSW=ROI23O6AEMWY@?TTg82@cAdHl?ce;IF5JFT9B
JeI=H6f7OVj4UYBXZiji[;c?^;W>e?KogLJfc?7QelNQY<:iYZJBRIF5OYnJNH2>
UHETMgmIJX^>T6=;LGi_E4EfUVIIPiFCPh:4QhR5Tk:e/:ZP/:^DZKnT/KVjZXZE
XIN;Qh9bH6IVHf]GEf1HNG1FJUURRfMFPY^GOF1ZPXR2KVEBCVEXHT8gGfUNFE1M
KFM^TIZIVYBT`knobZj_^Z^UUW>1Mf5UF5eZB14A:DDk7ATF:d8f>D92@eYaLU]A
Gf5bQgigNhImL8=iIfibJVn=ZiF6W9Z^ckc1dk_6f>KgkNCQdLBfZkN]/;FRSgi^
KGB4Pg9ZJ71NI82GY95jOHnQXHUoPW1kO6b2PVa[IFefHF>1RgaaJVmkQHB?SHRP
]:^PUJS1VX2DSG^BT8J?QXMfH6U`DdUUOXinF4mbU8UcOIZWQXFHTi^PVYJDT8>5
QhRDUIJFT9^NUIjNX:JAQ8bCThegJGUhN6]:=TAIE3TI6c8/:4=4B511CFeaHeY7
EWAnQ8V:UZ63MY6LTHb6UjFKWJ^g_[fbZ;BlZIR]_kJWUHJE]:ZHQGE`K7N3PFi^
RH9_KhR>MfmoTZZKJfn8VXQXIH5kJW1cR9FDUHeoT:2T[JVO/;^QWYB8YJ^SZ9R6
R8AnQgaTJg9PHFMVJ7f1OI>LViJ<TiR5SI^ESibNSG1[R8MHB5AdTfL^@g5dNWe`
NXVH/[RbalZm]jj/[jFNXHejKe50@Slk?b803@`=6QPdC3i2FEmZPWekOVY_QGUW
GTQDHemGB4IJGf9WDE9fU9:5Tl;?`k:`cL:gbkn^^kRZ/In@UXQeGU9TKEiQLWQb
Jf=`SHfAU8JNb/JhZj[3b;6c]9jSWINXXHb4UJFBRY>UYhUkW[:ZWIROZ;>WYIjD
T8nBQWI^LVMMJg5bL6ikPGEiOVmRHFanPh25R8J1TY^IV8f=Q8VSZ9FBVZJe[9n[
ZZZfZjR]XJRl]JNFSXYjKVYVK6]OACi<ACXU5PhL=b`I:CXg@e=JE44f>UAaOGAc
K6^<Vi>=Qi2QVY^U/ZjZZZ^o^jfZWij[[JbJRi:?T96=PF]OJWYeJfiRCE5OK7Y_
Ef1cGU1LFEMIK7]iLfehOgQnR8EgMXfHV:6Y/KFZWk:hZYjCW:6NRX>AT85oNg]l
IFelN8V9KGF9SZNYU8b8U:RNU8M`QIV3L6]ZKf1FJ612@EIHCEAVOX9hNhbY]jnc
_;fc/<SMe[NSX8adH4m:C4a6@3Lb;cPoB4A0E5m^O8ZBX;N^ZJ^MX:>ETi:;Q863
PXB2M6Q]JfaiQ9BJW9b>X/2m^:^R`<Zf]kbf[9ZHVHYdIFaaKg9dJEQPLGakOWYX
MX^?ShQkOH9oP8BEShF<QgYjPH5/FEecShZ2PWj2RXf4OG5/RZJVX9B8UINFUh1a
MgJ1RGE^IEAJKFQODdiSL7f3PX21Q7n:VHn7PWB7YJ2APXBR/:Zb_jnL[M?D^jJV
/[k3^KRaT7AoTHebCD1;E4a:Bdi=>S8kA4Q3=Ca<EUUKF4Y>HG1hMFa]N8ZQ[k:O
Uj:`aM75/kFh^<79/9VRZjjYSGIiPX9mNg=bO7A/KfULFeaNI5mTJfUUF5YMFf9O
GfU[KgIaJVabLG:3R7adMWn@SGafP8V?WYR6PI6ITWmXJFe]Kfm`NWIZJWAoQXF6
R8ZGW:J/ViRX][2SWZJ_YInZ/ZjLSXV;V9MoLgf9VJNRTHZBXK2YVI:AXkNh/[2]
XYjAQH]nL6YNFU]==B8T?Clh?chd>TEPN7I/IVihTZ:KThUnSZn]Th:9UINGT8B5
SHnIWJ6SWIn[]/?;b<2a`=7<_ZFJWj:GUX]fLVUGFf]SAbd_Be]JGEE5CVAfKEUI
HWB0NVe/NGj0Ph5nQGekT:2LS7mePXnAUI68N7nQWHB2P8N:R9BDRH1fLX5kM7U_
If1RJW=/F5U`O75RHW5fOHB:UI5nQijTZIbDZk2X];o2^k2l`kZbY:BYX9FGV8Ej
M6]WGeE8?S/c<CTh<BDS=4M7@TE@JWMfOGUWH6ahOg9QIGN6U9J;PhFCYJfX[kVj
^Kk9bKF//:FYYi^QVH9`N8Z4LfMQIF]YMH9iKg5nR8NASGb7VYjIShZBUYRUZ9n8
Mh:AV:6MTX^5SZ2_ZIbUZYjLY9f6OXbBRWmaLW5`PXM]F61PJGEaIEIHIg5iOFe`
PXB=UHZ5RHN:SHUoN7j:PgEgKVY/JVUYNHf>Tj:QY[S4a;NhaLO1^ZJ:OXN8NFED
?SE2@30Q7RL]=3Q4DCleA51EGVM]KVQaNX1nJ6EiO7IdLh2<S8^FXJ:OWZZe][>b
/;W@d/gDd<K4b<Fl/:VRWY^@Q7eiK5eHGFMTGF5OGEiKGFMQFf]bJFj1Qh1lP7mo
OWelO8F?ShMmPY>OXhmfO8fCVYZ9OH6;ShV1OX9mLg=fJ5]PIV]/H5=EGgEkK75h
N7amMFQZLV]RIgV7PGMgPhfEY:RQXjZ]]L2cZ[O3`kk1^:JJU9:APFUOE4Q8ASPU
6R0/;2dh?d9AFf=dM6ELIh6>SYV@P821SifKSX21U9fEU:c3aLWEem34`M[WfmSF
b[jna/FaUh5iOG]XFEIMGV1NGVMPFF5[LhB<T9R@SijXXHn5R9FHR7E]LWQgOHF4
NG1kT9fGS9>Q[;Jj]ZVOY:bUThAjMgEkP7EVIVi[JgAkNf]LJ7MoPXN9R8fCViZC
RH5jNgifJf1OJFe[JF9PJGZ7SHf?UInX[[ZcZ;>n_j^?RhA_H5UECS`U4``F6a/M
7b<S;4AHGV1SKgYnR8N3RYFKWi>4PXVCSW]YJ6ejR8jBU9JT];Vm`L75`lK:aLK6
^JRNUhEaJfEJGfAOEeAECe9TJV5HEf=_K6QXI69WNHEmMgIoTY^GTibXZZ>W[K2e
ZZ2TZJRSUiZVZZRPW9V>PX:3P7UbLWAdMGMgMWAbLGMfJVAYL7n?Rh5lNWUiNGMe
M7R1QhV8SinTY;?1_[Zob]GEem?>d=GLfLZcVHb8NVaMCd8g;b/Z9al@51dM6QLQ
<CY:FU]JDTeKIFUXG5QJGVafMWIkPXfDTiBN/knl_m;OdlW<c/Zm/ZnYWibRWi>4
PHAjM7MmMVMRJ7N9S89nO8::R7mgMWj5PGYhMgMgMWQcJVEUL7n1OH>?Ti>LZJJJ
WJJZ[JfVViBEU8n;RXIcIVaaJV9RJ6e[Lg]hLgB1SY68Q8nOYZFPVYZBS8n6NWEa
Lg9`NGmoP7U_M8FCTXnHWZ6/^KfiZibCRX9iHU5>DDTi:R0L6ahM5A4K9R/_=Ce1
A51JG6AeOgadLW^5R8Z2OH24SI:CTI2GXjV[/[Bd`m7BcLK<c/Fh[:>OV9NJUhim
N81eHE5;EEQ@BUIUK6aZK6YYIf9MG6QdO8NCVYZFVIfHVZ6SXj6Y][RmaLW:_[6Z
YZ:KUI:?RHJ<RhB3QHR9QXJ8RHZ>U9ZU[jbVXibESXV6QX>0NVm`NWQeMW]lM7B5
TY>O_M7=`/K=akni][Ff`<S2/Y^9PWAQE4Ha6Q8K9bh[<3hi;Rli@dQ@GFE_NWae
Lg1]KViVEdiCH6MXHemNIGN4QXbK[;BkaLg>b<>l]kbo/Yb>RXIkJU]DCTI7Ce=@
BdU>F61[MWMhOXZLWiNDThV6R81jMgMnQ8J5O79^L7IiNX:9T:6f_[Ja/kJh/JRU
W9FDTi>BQgalMfUQH5iDBdmII6ENGV9VJgB1RHR6Ri^]ZJ2IU9bLTHR3Q8nBSY2F
XZNX[;2e^[^m^[Rn_kZdYIbRXYJ4LV9D@cPb:R8S;SLd:BPZ:C0k?3Te=T5CI7=d
K6MZLWIfNHF@TiBGWj^c]kRf^[jl^[Fb^;Zg/JROW9^GRh63RHZ8PGUdLWEmQX^6
NgAdN7amO7n0NWYoNFmUGEUFGFUZK7EkPHR;TI><S9JMViZQ/;o6a[ni]k:]Y9J8
OWQjPHV?RhN=TI2@TINOXJfj_[bh][B`ZJ:HSGi`Lgf2N6EIEeEADEYUKGfDYK:o
bM3Aclc;b/S2]ZjZXiJ0JEQ<@C0I2@L;41HG5A<D8S8e>DIDG5iTKFm/JVY_KEm=
BeMJDdU8DEYPJ7N:UYfSXJ>_^[jm_L34a/6bYj>NUhn2LF1GF5MECTM5ATQ;C51E
G6E^N7UcMGf0Ogj5QgUaMgf5RXV;QhJCWZNd^[Nd/kJbZ:JY/;:]ZjbVVI6<PGQb
K6igOGajLfe`OXf;OgUnRI>JXJ2JVIRDTI2<RH^>S8nGUi6>T8n8Q8^IXZRg_l?5
`;Zi_LBn[J>NWYnCOfMFDeA<?C0[;2`hADI7Df5TIgJ5QXJ7QHNEZ:jOS8J:SXQn
M6aUG5aXKF=QLXV@SY2AUIZMWY^LYZfYXYfJUYNGRGAXKG9]KW^9RX=jL6UYKGIk
N7MkPXZ@RGeeK6=SJ6e_KFeYJVmcN7QeN7]jOHJ@UijMUi^NVYVIUY6>RXB3Ri2?
Qh23RHF2PX60PH=nM7N0P7]fO8F0MFaSHfIYJVEXLgYnOgmlOh^EW:Nd`<K5`Ko6
d]SAa;JZXiF6NViUEC`^;2<H6B@^;2hc=Ci6C5MNGFIaKFERK7^3Og=WJ7=jNWn;
TiJIWj2PY[?0cMCDd=3FfM;>dlk0]K2YWi63MFEHEUUGCTQ4@TA>F5eQHFI/KW=f
MgYoRYJERhN8SXj8QhMmM7EoRiFHTHfCWjN[[kJi^;Fa/:fSWYN?SXUnO7ajNgik
M7=iPXV>S8N9TY^T[K6a/[>a[jVPV8j8QGmiMW9bLW=gMgEeMGfAWjBVZJj_/K>c
/ZVLU9>BQg5TIg9gL6=EBT=2BDe<BDYAGVAVIf9OH6QdOWmlOGijMG=jOGE/IVIY
IVIcP8F9SY6?SI:HVYZDT9>HXJRZYYnMUhj8Pg]gNh:2MVm/IUmJF515A4Y:ADM@
E4e4@T10@dA8D5YVK6iaLWAhNW]kPi:MX:6TY9fHVj>RUHMoPX^AU9FHVIRIUYFJ
VI>CV9VCSXZ7R8^<QWehLg5_K79kO7EdNGM_LGf7SYBFUIJKXZVb_<?6`[fl_Knm
/jNOW9R;MfAEBShk?3L/8b@Y;2la=3]4CUINJGN5RhV;SI2DTHj?T9:@Q7ejNX>7
QHB5Ri>IWZ6U/Kk3`/30_L?AdLS2_[V^ZZjZW8]mN7YjNGQgNGYgMGQoPH62PhN?
U969PhR?SX5aL7MjMFm^KFaZIfU]KW1dOXR>TY^T[[Bb[jRJTYRQXYZDT92ARhJ2
OWemP8B1QHj@T8n;RHfASXN6RHV1NgYkOWmhLViYJFIPGUmQHV=dRiBFV:>_[jJJ
UJ6[[:b[Yi^=P71PDT<h<2HN6b@^;2HO7R@/<ca4CU]RJ6a[KW1]KF]UIfabMgMe
L6][LGEaKF]bOXVCW:Fa_lS:aL?7b/6f][J^XYF;R8Z8O6mTG5UQL7b2QHJ9QX>7
S9:EVZ>XY9fGVZ2LU8n8PX:7S8j>SXnATHn;SHn;R8fGX:2GUi^PXYfGThZ3PWef
Kf][Jf][IV9QHfM/LGAiOXB>THV9Shj=Shn7P8RAT96BRX9oOh:7Rhb:SIBHWJJ^
/Zn[[kJh/jZX[:^MShAhJf5ICd8g<Rd[<SHh>3LmBE9HGV9UJ6]/JFYdNWaoP7io
PhR<SHnBU9BEW:RYY:N_/kBf]kRi]kJg^;Fa[Jb][:RPViR=QXR:QGejOh>4QGeb
KW1cL6YYKWElOWn0OGQeLgAgMgEiQYBJWYjJThImOH65QH>4Q8J=TY>CShf9P7j1
PH:8TIB;Q8F4Ph9kLVYYJfe[K6e]JVEOEe9?C4I4B51GFE]QJFiZIVMWIVM[KVe[
J6EXK6YUH5]KHW60Ri>JWjRZX9ZKXZNUXZ:LVIRBQg]cK69KFeYFE55;B4aBDU9A
DeYOHVM]L7=gOhB5RXZ3OGj7QgaiPh^=S8^<TiVHUYbTZ;2maL>n]kBe^KJb][Rd
[[6g/jJOWIVDU9RJWZ>RWIbNWYbKWZ:QXZJUX:2TYinDTI2CUHn7OGEaLWEaK75i
NG]lO863PH:2Og]eN7j0Q8R9SHf?TY:BTYNMWiJ:S9NHTI6CTHb7QH5nPXB1PH1j
Nh:3NVeWJ6QTGemPHV5TJfaXIfEPGUmRHF5]MgUjNgb0PgmeMW]lNWMgNGn5QG]^
IE]CC4E1@DA6@cm1ATI3A4U<BDY@EemVL7R0Qh5fM7Z2R8nGViZPZ:bZXIZMXJ2N
WJ6WZk2`Zjne];>]YZ>VZjZRVY>=QGmnOGinNgIeNGn4QhR8S8j8PX>6R8J5Ph21
R8b>TIFKVY6AUYNETY2@U9ZKUI:?QX5oP863Q8:4QhJ6QX1eKFmeLg=gNG^1OWUg
MW=ZHf=VKgUiLg5cKVMWJ6EWKVe/L7EiOXF7OWMjP8:3PWimPXZ?T96@RX^DUiFK
Z[Jm_kfk_L2n^;>]WYFESX=nNgUdJ5U@DEIAAD52A4M4?3e4CEUTIfITIF]gPHZ9
Ogf6SY:BU9VLW9VIW9^HV9VP[KVn`<?1`LG8aL2n_[jm_KV`Zjf^[::EShnBT8Z:
S8V5PH64Q8B4QXjARXJ:TYRFTH^6PGYcKVIQI6ESGEiRI69OGV1ME51?DU]UKW=a
JfEWL79]Jfe^KVmeMg=bLG1_IU]FEEQRJg1_JVY]KV]THF=YKW9`KF]TGEUKGf1L
F5MIH6QbLg=cLFm_LGEdLgn;UIRM[[bn_kjk_KZh^kfl^[NcZZBKSX9eMGMaLGIe
K6EZJfe`KVeZJfedNWM]J7=kOh1jMG5bMgZ3QH22QH>1PGikOX>7QH25QhF:U9jO
W9ZFVj:PWj>/ZjN[[jfWW9BEVijNVYNHWJZa[jn[YZ^/[;>i^[6XZjj[YYbIW9ZE
SHB5R7]/IFE`LWInP8V<R8V:Si>:PGenPX:6PGQ`KG9cLgAdKVe]L7QnPh1kO7Ue
N7]hMWIeMh2;Rh=mNG9VKGUjN7AbNh1gLFmaLW9aLWMfMgb1R8j<Qh:1Nfm_LgV3
S8j=RXF:QhB5Pg]fLVURG5aMGUmJEUYKFUQHFEiUK79hMWAhN7IgMgEcKVMZLW]l
MW9aMgUfMWYlN7AeM79^IVUbMWAaKf]`Ph^=RXB7Qh1jMgA]L7EiOhJ?ShnBSXZ;
RHJ5SYfMVYjLWZ6QXJ6TXibIV9NFThn8QHN;QGYiQYZLU9:?TYVJX:>SWhb1P8:1
PX:0OgU`Jf1HFEUMIV]iQ8nBSiBFUYJ?SiJAR8J5PH6:SHJ1O7YmOGQlP8:9QXND
UYVKUiVGUYRGUi>9R8f?S8R7Qh9kP8^?R7ahNWYmNgMkOgmjMgV0QX>1Q8fBSXR6
QHN:S92BUiRCTI6DTi:HVINIU92BTY:?RXZ8RHnBU9F<QhZ4PXB3QXV;RhB1P8>6
PGioOh:0NgMgOH>4QhR3OgEbN7YhN7QgOhF3OgUfN7QcJVabM79`MGEbLgIlO7ak
MgIiQ8b9PgadMWaoP820OWf6RHf?PgQiNGA`LWMfNWYhNGUaJVEUIf=PLHB9R8V:
RX^1NGYjMgIhOGenO7YiNGQiN7YmN7EeN7j4PWeeKFM[LG=dMGAeLg5_Kg5iNg]m
PH:2QXf=S8V2RI:ASi2<S8^5PhJ6O7MmP7ifKf]SHFEVIg1cJFEdO7EfO7j:UYNC
T92;Qh^CVI67QhJ4PhZEVYFDV9bRZ:f/ZJVZ[[2a/Jn^ZjJPVH^3Q8^:QH>2Ogmo
Ng]mQ8nHVZ2Z[JV[/[:`[ZZXXjFUXjVZY9^IVYF>UIZFVZBTWIBARGamRHZ6Q8B5
PWn3QX>2OgYiNWakNGUhMW=aKFESIV][KW9^K6m]JV]bMgAeMWAaKg9jNWEdN7Md
MWeiLWAgMgE^IEiNI65LIFi_L6YSGfIbMWR2PG9YKWIdKf]QGfM]LgA`L75/JF=K
F5aNG5aLGEmKEEEIGF9ZIfY_KVm]KgMlP89oNW]kOH>=Thb8SI2?RhV;QhN;SXnE
WIjFTYRIVI^KUHb9RXZ>RgmkOGmoO7n5RiNOVibPXZBSXjJ^[:JJV9bRXIF@UYfI
Rh>2QhZ<S8V=UIBCVI^FUI>;SYZOUX^;SXAiNgUaK6abNWYnQHJ5QXZAT9FJUYFE
U9>@SI2GUHQhMgimN6m/JVMPGEQBD55DE5QOH5aQJW=gOWijOXZEUiRIVJ:XXi^M
XZJVX:2V[:VTWZ2WY9B9S9JHRWimOGf2P7]gNh:1P7ahMgIjO7]nPH1lNgEdNWmi
LgYmMgQnQ8AnNgUiP8F3PH23QHV8Ph>7R8J0OWj0P7miOH=oNWIcM7QeJVE/NH=n
N7=fO7mnOh1lNWn8T8]oM6i^LWMgN7MgNH1oN7E`KG1bMWj8Shb5QXfATHj?TXn7
QXV:SY>DUHn?SXN4PH>1O7^1R8Z7QGieKG5lPG]fMWIeLg1YFUIIGF9UIFATIVQS
GV5ZKfiZMH:7RXb7QHJ7RXVBVIFEThj;SiJKV9>DSi2CU9>CUYVPX9fOWijOW9^G
RhNBUY:=SYBDTHb9SHb@UI:<SiVNWYbITi2DWY^@SiNITXN3Q8F0LVMWHeYEF5aM
E4iEG6U_KVMVKWEiNginO7j5SYFGU8f7QhfBUYZETiNHUY6CVZBUXIfLVY^KU8n@
U9>=S8j=RHV9PgaiO81oNWUlP8B1O8:;Rh^;RhnBTHj:SHj<SHjAT8f?U928PHB=
TiB>R8B2OW]nNgAaN7ikLg1gO7YgN7eoP8=oMgAeM71]JfQUKG]mN6mYKW1ZIfUZ
K6i/Jfm_KfQSH69UIFEXJVQUJG9fMgAdNGYhNX65Q8^>S8^1O867RHMlLW=hMW9b
M75WHVAXI65SIEiLGUeLFEEOJV]YJfiaJfAOHFIVI6EYMG]iNGEfO7ajNWf3Ri:C
U9JKWifIUYBBUj2RXjR][JBHT9>KWibLWIVDUZ:/[JZWY:JWYJ6NXk:g/jNJV:6Z
/:nUY:JSWIbQZZZUWYJFV9JDSHf>RHB5Qh9oOgajOX:3Q8bCU9:ASY:IViVESXbC
WJ>TXIfIThQlMgV0QX5fMW]nPh:1RI>LXIbBT9FFU9BDS7iaJVMXKFaRFU]LEDY:
EEmPFUaSJ6QWK71cMWE^J6=TIFQZHfATGUeKF5YHF5Q@C4a@EUYRKG=gN7AdMG=a
LgEfNGMaJVe`M7EcL71gNG=bNhRCT8F0OGj:TiNOXYfFTY2@SHZBVIbMUi6AU9VJ
V9ZJViVJWYnQZk2[XibJVIJ@RH^>TY26P820PGmhLFmdNGQjNWIiOWmlNGEdL6ib
MGf6RHR4N6m[K71bL6abNh>5Q89oOhB6OgalO7f0QXb>SY>@RhV=UIVIUibTY9^J
VYbNWj6RYJ2GU9>=S8N6QX5oP8>2P869S8V2N7IgO7ilMg=/HV1RHUeOH65QHV1Q
Ifi_JFQZKWAfNH>;Shf3NWQgNXF;R85lPHb@SHZ8S9:=Pgj2R8n@TiNIUIJLXZ6R
ZK2f/[6_[Zn/X9jUZJfYXifMXjJTWiVJXZRZYinJWJFVXi^CTiRETY:EUiF@Rh1g
MgYlN79]JfYcMG1aMWalNWQmOGamNWIdMgUeKFETKGIaK6]YIfANG5YJGV=UGUiL
FeQJGV1RIfiaLgAcLG5aLg9^K6YZKg5eMgAbKFMXJg9jPH5oOWmoPHR9QWYeMgio
O7A_KVe^JfMOG5iXMGM/GU]OIFUXJVibLG1`M7MjN7EeMgEbNGj4QH5kO7UhO822
PhAmMgEgOXJ7QHN=T8b:RhfBVIjPXJBYZZZZZjfc^K^j]kc1`kb^XZ>UZ:VVXZ:U
YZRSWijITi6@THn9Q8R?Shf<RXbAUiF?RhnFW9^HV9NET8nBVifLU9>LWYZFThj9
OgI`LFm]L7EfL6]YJFa_L71^K75bMW^0P865Q7ieKfmhNGEaLG=gNWQeNHB9R7mi
N7YoQhnDT8F0QXbCU969Ph22PWifKVi_K6Q]LgIaJfYaN7]hMWj6RHZ7OGMhNg]e
KV]^LGAfM79]J6EVJ6edO7]hNG]fL71_L71cMW]mNFm/MXB8P7MhPhZ;R7i_JgB0
RHj>T96?RHR8QWmkNh23PX:6SI6>QX>0NWAeOH>1P85oOW]iOH1iLW=kOgejO7ej
Mg1[K6a^M7YkNGj2NG1bMWEdNWejMgUiOX5mMWEiPHR;RhN5RI2FUiFCU9RPY:>R
Y:NY[kF_X9RJWIZDTYBDUIRHVIVGU96BU9>GUXf<S8V8R8=nOGQdM79YHfMbNWMc
KFY[KFa]L7=cLGAiOHRCTHnDVINDTH^3OWeoOgilO82;UI:5NWQnR8^9PWj0S9JN
Vi66PXN=TiVNViNEUIBCUiZJVIfRX9fJVI^NX:FXXYfPWiVIVIVJUi29QXJ4P7mn
N71YIfM^MgMdNhR;QGijNWYhMgIhOGn2Q8>0O7UiNWQbIemQJG1aKFUYJ6Q^MGQf
MgYeKg5hPHN9R8N6Q8>0OX64Q8F8Rhf@UYbHTHnAUIB@Si6=QhN6PgedLWUjM75g
NG5WHfIVIF=PGf9TI65IDEEOJ6YQEU9BE5QLFUABF5mRGe]IFU]MG5]GDeIOJG=d
LgEfN7UgN7MaL75hPXZ9QXR=U9bNViZKY:f^YZ6LVIVIV9RJWj2PY:BQWIVFU9RN
WYbNX:2SYZZZZ:BNV9JFUYJETY6DVYjOVi:=SY>HVYJ>RI2JX:BOVIRDTYFDShb:
R8EoOX22P7YeMGV2R8N5PXB6QhF4QXJ1PHB9TY:>RhR2NgQiN75ZJfm`LW1/KWMn
P8>7S8b6Q8>2PX:5QhN3O7b3Q7mhL6e/JfY]KFYXJFiiO7IdMg]iLFi_JVQ[LG=c
MG^0PGaiMG1bLW=cLgIgMGAbLgMfLFUYL79dN7QiN7YmOGamO7MfPXj<QX60QXnD
UI>FV9FFVZ:UWiJAU9bRXi^DUIRKWijITiBIVYRGTHZ<T9BEUYBCU9BDSXB0Qhj=
S8^:S8b7PWioOgaiLg1aM7UiLfi`MGEfNWQgOX9oO827QH60OGQeMW=aM7IgMW=b
K6=RJ6YXJF]`Mh::S8MnNGekMG5/JVa/K6]VH65WJVIWKW5^KWEmQX^:QWmjOH5n
NG9`L6e]LGIfLfmYJFiaKfa`MgeoP7moPhB4QhR1OX>:T9FEShZ;Si:BT8j:QXB9
U9fOW9jUZJZXXj6RXIjIThf<T9BHUY6?SY6BT8n@T92DVYfNX:6TYZNVY::RXjFW
XibHUIFJWj6NUi:BU9ZUZjROVYbLWZ2MVIRIUi6?TI2>RX9fKfm_K6EPHVYcM6]V
Jg9fMgIcL79iNgQgO7mkMg=aL6m`MWalNWIjPhZ;Qh1nPHZAShV6Q8:0OG]iNGUa
J6=PH6AYJF=LEeEGG65QG5IDFF1SHUmJF5]JEE5=CE5BEEUKFU]QJ6mcLg5aMWj6
RX^?UIfOW9VJW9jLV9BDU9JLXjNUVXn9RH^>Shn>Shj>U9fSXinKVINGVYbJUiBA
SHV7QXJ8RhV5P868TYVMX9nHUY^LW9^MWIbKVYRDT8b8QX9oOWaiN7QkOh1lMgQk
O7UdLWMnQHZ;RXAoPHF4PH65Q860PHF6QXV9Qh9mOH24RHf@Ti:AShf<RhV7QH:0
OWYfM7=`JF1FCdmBF5ePI6QYK71cM75]KW9hNGA_JVIZKfiYI6=UJ6QYKG=eMWIe
Lg5cN7UhN7YnO7A[JVmeMgIfMWIfN7b0PH:5RHV8QXJ;UInTWYRFUYRJWZF//[Fb
[JZXYJ6MW9^KWInRYJFVZ:RUXj:RXj>UYJBVYJ2IU92@Shf8Q8B7RXn@S8J2Q8N6
Q81oPH>4PGimOGQcL71^JVY[KG1cMGIfMg^0P7agMGAcLWMmOGmoOWahMG5[JF]Z
Jfa/L7MmPhZ=RX5mPHR=SX^7Q8>1NG=`K6]]K6IPGf5XKg9bL75dN7j4RHb<RHR9
R8AmN7MjOGafKF=MFUYJF5MGFUeNGf5UK79iNgIcM7R1RH^:R8J1OGj0QHZ=Shn@
TiFIWJ6VZjb_/;:c];Vh/ZbVY:RZYZ:NWj6NUY:BTXn;R8F3PhF5QXV8PgmmOH63
Qh^?T8n>Si6DTHZ5Q8V=RXV@UiRES8J7QXB3P7YgMGEfMGAgN75YIfEUJ6ESHfAW
JW5cMGV2Qh9kMg^1R8b:S92AUY^NWYZFUYBCU9JCTHn<QWmoOgioOGM_L7MgMgb1
PgmfL7EmOgajO7n1PHF5P7mkMG5^KFe]KgAgMg=_JFAXKF]UHUmOI6]_L75cMgUk
OX20OWinP85nNGUoQHF2Og]jO7n3Q8>8Si6FVIfOVI>ASi6DTHf5OGQbKf][K6ic
NGajM7^;UIJ@RhbAU9NHVI^OXIjLVijRWiZJVYRIVi^NVi:=R85nNgQcL75eMW^2
Ph:0PXZ>RhJ6SHn<QH:5QH5lN7QmOh63PX24RXb<S8f:SY>?SIJEPHRHT8n=QHf=
P7n2Q8V:QhF1QHjCTX^6PhJ9QH:2PhJ:SHf?THf<R862PGijOGaaL6aVIf1IF5IG
F5IHE5ENHfU`LWEgMW=eNGQeLW9_K6Y/L6m]LGYnNWYkOH65Ph21PgekOWikN7Mc
KG1eMWf1PH>9RXfCUiRFVIVIV9ZMVIF=PWf0PhB5S9FHVIfPXj>OViZHUiB?S8R9
SHb5QH^>S8N:UYjMVYbUZZf^Yj6QX9nMX:6SWY:<RHR<Ti^JU9RFS8N5OWUdLFeS
H6=UIFU/Jg5iO7j7RX5oP7ecKVe_Mg=ZIVAPH5mKEDmCFV=ZJg5kP7mjMgAbL79_
L6MLJ69GFEQLEe1=BD]FH6IXIF]_L75aLgAcLVYTI6YWJ6iZJ6a]LG9aN7MbLWQi
MWE`JVARIF9TKG=cMh66S9FNXjJ`]kJb];g4`l?3`[nh/jn[ZJ^^[Jbb_l6m^KNg
][Ba[jf^ZZJUXj6QYZBOWYZFT8jATY>BSHb;RXZ:TI6@Thj@VIVIWjN[Zj^ZZJJV
XYVHVIZHTXN1OG1YKVm^LGIcLWV1RH1kPX=oO7b3QhJ1NgE^KVmXHEiIDeADEEUI
GfEXJfUYIV=NFEUKG5]ICTQ;CT]>C4I3A4e=Be5IGEiTIF=OFeiWJ6IWJF]ZKWIo
Qhj@T92=SY23NXQgMGMbMF9LI6ikQHJ6TI6AWJ>Y/K>f`[bd[ZZ/XYfX[JVOU92B
Rhb@TH^7WY^@UiJJWIfJYk6AU:6LU92NY:NRU8V@RWMkPXEoN7f=THjFUiB9MWB:
Thj9Ph^=TI>9PX69QXN0MX20Mf1MIUmHBE9SHUeMH6A_O8JHYJN]XXN2R8R4O7F0
Ui1nPXb9NgEnRYJFT96GUYBEUI6=QginPhZ<Ph>4P8B4OFaVM7IcLG5_I5QHF5QK
G6QZKW1XHemRG5U[LgN3R9>DT96:OGnAR7AdIV=UGVMcHfj1M6i_R9nSWIJW^k2J
XJVPYZRPY:VVXYnHS8bBVYb=TJFRTi6X/JFIXJFEQ8JCShbESWeoOWQdL7IkMFm_
LWEeKg9aK6UXLWA^L6iZOi2;QiBBT9FDPH6BS7ihQH5kNgE/HEiLFU5AFEaRJF]b
NWA`NhF4PH:7R8ZCTHjDVYnIShQnOXR=PWj0Q8jBSXN7Q7MdOhJ3QI2ASXb6TIbD
QhbLTX5nQH5/IGIhMgYfOhjCRhR>SHZAVjRXYk2n_;>/X:>TS7f2R7mdM6iVIfI]
IUefRXIlO7alPWieNh>8T9N@Ri2HUXj>SgmaR:2KSi2EShbITXR9Qhf=SHR2S9FD
Wj^]/;:ZYjNMUiZHQ7=^ITdY:daTN8f1KViODE5HGVImP8B:SHUlMVQRJfeWHEiS
HDTb;c4g?C/g@eEZLF]NBT=6A3]2G6QOJGMbK6aWF5EDB3li=C@j?CTk>C8nDU]F
GFi]L7UfM6m`N7UfMWAoSH:2T96;Q7Q/J6]SCTUKIfEXL75/Ig23QX>5QhfFXJ6L
WYfW/jbXZ:b`]LBn]k6[ZkBo`<G@em7:d=_Kb[bnblk0^[k0_<?5_kbm^kB_]K>W
Zk6a/jbVXZN_/k6c^/31`LO;e>3Id=3Cd<S3`/_5]ZJNZJZMWIZ@Qh>>UI>NVhb@
V9::R89oOX29Rhb?Q7]gKg9/IG5fMWIgQY2>TYJCSGifOXREXjR`_KZb[JRYY9B;
Q7j1OGU^HdX^8A0=3`H32a/Y=49;Ef5/OhB9UYbV^<O2[ZZ`VXElLGAfLVaeNV]R
FF5UJFm/KFmjPGQeO7I[J5];?2TS9BDQ6aLI7B8_>3]8DF5bMh:@WjJTZ:fZYJj_
Yj>LV96<RX5eIUmTH5ACE4]4@DQLHeI0=D9?DUEEEemMDea/Mh6@V9FLX9ZETiRJ
U8^;RWYgMF]_LgMkM7R2Nfm^K6eaKV=EDE]C@Sli;1`>4Q/X=SU1EfY[Jf]YMGES
Ih6BS8B=VZR]WYZOXjjj`<;=e<c1`<K0[I^8N7IfKfAHCD=1ATaED4I8EVQgQ9>L
Z;6b];VcYk2g^;Vi^;bn]:fa^kZa/kRl_KfjaL[4a/2gYYjMW9nMUXb2NWMhLFac
Lg9mRijWYJF[^/[Ef]GDfmcMi>;Ad=kLeLo7_k6WZJRQW9^PUiRWYj>QYjNSWIB=
R8^ARGMaNWQ]L6eYM7=WIVUUJ6IVLgIeM7b2OgYiM71bJfj4SHEmM71ZIFQYLW]e
KfmaOHAkLVYWKG=[GUaQJ6Q]LFMTI6f0PX6<V:2U]<G7`L73a<:hZYb@SXikI5Y:
?c<V9QdH7bm0@T9<EUiRIFQ[KFIWLgn:QgejNg]kPH5kO821P7b4THnDV9FBT8n@
SXEoLVe_IV1SGeaQFU9EFfA]JVA[NXF4S9RPZ:VWYjfa/;Fl_;F]XifET9>GUYRP
WiJBT9BKW:2MW9R=R8Z?U9JGVIB?S8ZCWYF7SYRDTYNMVZ2/[:NRWYN>Si29OWUk
MgIeMFYNHEmKGF=UGEmUJfecMfiVIVQWIfa/IF5WJVQ]JF=NFUaLGEiUKgN3QXJ8
SI^UXZ2JVYjGUIV?Q7ERCShk<2HX9QLC8b`b<cI4Be5ADfMeO8ZFViR<Og^1QGM]
KFQRGemQHVQWI6EXGe1GGeYCEeaGFf=TFD]=EEaPIFUSEe5PMhF7S8f;SYjYXJFe
]k6e]k:[YZFPYJVUYJ>MVYZHThf8PGUgLg1dOG]iNWE/JFY^MGMeMGR0SY6EW:2]
/[>g^;Zd[jnWViNRZ9nJV96=Qh>8SHn3MG9^MXN<SHbAShV=UiF7P7emRHj:OGQl
P8N:Q828SiBDUj2GQh6:UiVHVYjW[k:f_;bh]JjUWYRBR7YaJ6AVGe11=C8[:B`[
<SY5EV=^NXfNYJ6RYZJYZk6e/ZZRXZ:NUi:ASHV5O7MkPGelPX=kL6a^MGUjMW5a
LWQiNh>1PHJ9T9bTZ[O0bM;>a;g2bLkHflk;dM?Bc]7EeMK@a[ni][_2`KVd[jZ[
/;B_ZZVUXjZb/Jb]/KBhaLc8a<72b]OId]7?a/75`;>TVYZHU8V0NWMjOGimN7Ih
NWn4PGehNhN>T8^1O7MbLW9TEEIHF5YFCdi@DeYTI61RKX>EX::NVYn//:^PUiJE
ShEjMW5TEU5>?bdR6QXO8RL[;2/X:3A5Be1LHfYeOX5oOWUhNgegJF5RIfibLG5f
O7Y`K6YYKg9[Ge]CBTa@CT@k?D0o@TLo=ca9EemQGeiJE5QSIfQ^LWIeMgj0PGYg
Nh:7QHB9S8bBV8n8Qh>2OgETEeMHE59:?3U2CEIJFUQCDUYVLG9`MgmkLW1aM7Ml
OVeJEUADEUQFDU5@BD=0A4a@D4U;E5]PHF1SJVi]Kfa[KWAkNgM]GUA?DE=@Bd=6
DEQOIVa_M7amNGUnR9JPZZj`];:VUH^9QhAfHUUHDTa6AT<f<SLi?TA<EV5`NX:?
VInQWYZIUI:JXj>NUi>EUiJ@SIBHUiZOXYjOYjNSY:2CRHN9RX^BTXjAUi^KVYjR
/<C>c<C3bm?Ee=[Rj>?IgNCSi^_WioConoGcl?3gmncVhmoId<[1`<70_kVc/KG1
aL[Ef=KGg^GVjN?He]O@c<c4_;Rf]K6`[J:LWIRDT92ASI2JWINARhN8RXZ=Si:D
U9RJVIRCRh>0OGIdN7YkNFmZJVQUJGInO7b3RY6FUibRYJV[[ZZRX9nNViB>R7]Z
GEE=@3H^8ahK7B<V:2X^<C<i?TE:D5IKHFARGeiQHE]HFUeLGEmIE5IED4m=BTY:
BDQ5@d91@T53@38Z;C@f=Ca2ADUBFV=`MGQnOh23PGikQ8nEUiJETi>HWYnKVYVC
S8N8RXJ3OWI`JfMRGf5TJgAjOH69Si>IWI^FUY^ITHV6QhN1NWE`K6ifNgemO7]i
O7mkLVYUHV=WJV]]L7AgMgaoO7f2Ph5oOh26TiR@QGefKV]VGUQEE5MKGF5XJVUY
LG^1RYVSYk30b/k:_K2ZYZ2KVYB2LfIJEeM@BD<k=C<i@D=8DUYRJg9fN7n8TYZI
UIRNWYjOX:NZYIjGTY:FVZ2RWIF?SXb8QX>0P821OWenOX64S9JJXJVZZk>m`;nn
_[bh^kjoa<W;b<K6aLcCem[Jem3:cm3;b<:l^KRf^[fn`Kji^;Bd^;Vg/jfWY:BM
U8f;S8Z4O7IbLWIiOGmoOgUgMW1]LgamMFiYIfedMW9ZI69UIFEYK6i`LG9`L6m[
J6ATIfAQHF1OGEaJF5EDDe9EEEINJWAnPh23SIFEUIFDTHf7OGUcKFaYGDXh<C8c
<2`];BDO9B`Z8b0U;SI1AdY@FV9WJ6EOFE]SJF][K7AkNGA_KVaUH5YGFUeKFeeI
EEEHGF1TI6=WJFY_N8B8QH60PX^ATi>=Q7]gNGb2R8b?TIBIWYfKVYbRYZV[Zjf[
XYbNXIjJVIZIUiRGVIfHT8R6QH:0P81oOGYmPGejNW]mPX>1PX9oO7]kNgYiM6e_
LFa[K6i`LgMlQ8Z>SHb9Q8F9Shf;Si:ARX:1PhB3PGejN7b7SXf=RH:1PX>4PXB1
OXB>VIfKW:2RXibBSXZ;ShIfHUEBD51>BdU9Be1HHFEXKG=hNGYhMgb7TYBCT8b9
RY:IVYZNYZb/Y9ZHUiF@RXjAQh24QH>5RY2GWInUZk?3bLWDg=[Ge]OGf=O@cLc9
bLK2aL>m_/G<e=KDf=[IfM[Fclg7_l;4_KRi^;Nc/:jUWZ2RXjJTXZBSXZ2HTXj>
VJ2RWifPXjFSW9F>RH1hNWI/J6AQGeeNGU]KGV5RH6E^LgAgNgf1QHN:SHf9QXB0
O7EbM7=^HeYGDdi@De9AFVQ[IV=XJ6I[Kg=mR8MkNWeiLfYQGEaIDT@i=CHl?CTc
:Rdi@DE;CdmBEUUOIfMTIfmcLFeVIFegNGQgM7=fMG9eNWAYHf9QH5mLEU9?Ce=I
GfI_MGYkNGn<TY2BVInOWZ2PX::X[;6f_<75bL_:a/K1^;6`/[Jf/JZPVi^GU9:>
RXN4PX1lNGYgKVU]LGAlQHV9Q864QhV>THn@U9FDTi2CUY6<RX=eJf=JDdi=BdU7
ADE8BTe@EV1WJ6UZM8:5Q8B4Q81lNG=]JFISGe]LH69SH61UIf5KG6=/MWf2QXV;
TIbPX:6KU8n:PWE/K6YRD3X^<C/o@TI7AT]EH6UZIfinRX^9QH:5SYNJUi>AUY^Q
ZZ^//JnTWYfLWj2KTXb>Shf@T8b9SY6BVJF/[jnZYJFUY:N]/:j^/[Bc]KNi_L;:
e=SDdmSLg=_Id<G1_k^e[jf[YinDS8N2NgMiNGAcLg=fM71aN7agLgAhOX1nO7f1
QHB1Oh62OgakNWE[Hf9OH69RHF1RIFYbN7]iMgAeNgmmN7=^JVUYIf5PHV1LFEUG
EUUMGEYJGEmLFUeSJ6U[K6edNh6:UJ:XZJVVY:>OWIN=OfiPHVQWEd4e<S8d>C`n
@TM<D5IKFEMNJ6i`KVY[Lgj4PGakPHN;TYJDSi2BSXN2NWEhOh>8SX^3PHB3Ogek
NWaoOgmnMg1]K6a_MGUjPHbDVIVEU9VMWZ2TYjNWZJNRViFBTY:>RXJ2OgekMg=`
Kfm^KFe`LFe/KW=hNgn0OG]lNGEbLGEgM75]IfEWJVe_Kfa^Lg]nO7f2QXF5QH:2
QXV=T92;PgimP8>4P7YfLVi/JF=QIFQXJFeaM7Z1Q8F2PHB=U9RLWYnU[;2f_;Zl
a]GLf<g3`[neZJ>WYZBKQG9_LFm^M7UgN7n7TYZHT8^<TINJVYZHVZ6WZJNX/;Rk
_lK9alG4_[Rg]kF`[Jjb][Nh]k>_ZZRXYjBQWIVHV9VFT8Z8RXV6QY6NY:V[YZ2U
[kJh^;Zh]KNb[:j/YZ6NVYFBSHN1Oh62NW5]K6a[Jf][IfEXK6i_LGIjNWUhMgIh
O8>7Q7elOX63Ph1kNGMgNX24P7AaM7E`JVETIVIWJ6MNEeYKF5MED51HGEUFEE=D
F5UIGV5QIW5jNgI`KVi`MGUnOgajO8:8S8b5OgioNg9[IEiKH65ICDA0@DA4@d8o
?D5;De=ACdmBEeUFEU]TLGb0O7QjP8R>Si2EUiFDTH^5O7=[IFETHV5RIVUXHUaH
E5AEDTe;BdU7BU9JGV9YLWj9SHj@TYNLW9ZIVijMVIJFUYNHW9jMViNARXF5QH1j
MWIgNGUfMgf4QXR=TIRNX:>WZZJOViVFSh^:RXR7R8AoPHN:R8J2OWYdLFm]JVQW
IfQ`N7YmP863QhV7PgmlNGUiN7QjPHR<SHb>TYBFU9:BUinSY:FVYjJRX:>VYjZ_
/kRn_;J_Y9bEShb<U9R@Pgf0PhF;SXb:RHV;RhR3PGmjNgn3R9:JX:JWXjBWZk6h
^;Ba[ZJKUI>?Rhb>RhV9R8Z9QH:1P7emNWAcMWAaLG5bMGYnQiBLWj:RXJ2OWZ2Q
WifMW9J?RhZ=SHf>SXf<SHf=RhN3P7n0PXB6R8J5RHj?SXb;Rhf=RXN7QXB1OWj0
Q8B1P7mnOX:2OG]fK6IUIFAUHUeMHVQ]Kfi]L7=bL6m`L6aWH5]IF5MEE5EFEeQI
FeaMGEaJFV1XJFANG6=/LgEhPXZ=TIBLWiZBRhR1MVaRFEEIH5mIFf1TJFibLfeV
GUYIEUECDUQOHfAUJg9eM7=gNWf1Q8J7QH9nNWIeMGEcLgAdMGQjNgE]If1IEE9?
CTi>D5AGFV=ZK6idOhZ@UIVHU8n:QhJ9SiVQYJNY[K6a[Zjb][Zk^K:a];Fb[JVV
Y::UZjf][:NOVI>>RHB3PWmkN7MgMgMgM7=fO8:9SHnATI6ATiRJUi6>SXj>Si2B
TiJIVYVIUY>ASHZ<T9:ASXf=SXb5OWamOG]jOXF:Rh^?TI6BU9VMX:FZ[K>l`lG6
b<W7a<2i/Zj/YYnOXJ2MVYZJV9FCTI>DTHf8PWafLg1^L7ImQ8^>SXb<SI6GWjJ[
[Jnb/:VPVYJAS8^;SY6EUY>?RhR1MfiYIVIUHEiLFEAADUAGG65TIfacN7YlO7en
QH^@UYfRY:V^/[Be]K6/ZJVZYj>QXIjJV9B@RH=mN7AaJEmFDDm?C4U:CE1BDUAJ
HFM/LGAfNWf0PH61OgahMG5^KVe[J6IUHf1LFUaMFU=?C4U5A4I8ATI7B4M7BTm?
C4Y9Bde@E5QLGf1OH69TJ6]_MGYoPX>3Q8J6QHJ:Si:CTi>ATI>ASHR4PX62PGim
O7YiNWj1Ph>0OGajNGf4QhB0PH>2OgelNgYiMW9dMgUhMgIcKfe/Kfm]JFISHF5N
FUYMHFEXJVa_M7MhNWj2PWn1QXb?TYJKWInPXJ6SYjVWYZFSXj:NVi^KVYZHUiBB
SHAlMg9aLgEfMWMhNWf0QHR<SXb;Rhf@Ti>CU9FFV9RGUiNFU9FGVYZIV9FASi2@
SHR6R8Z:R8F4PhB3PX>5QhZ=Shf9QHB7S8n@SXb=Si:DUi^MW9bPYJV^]Kc0`;no
_;Zn`[nj]ZjTViJ?RXR6QXN6P7YgMWV2Rhf=SY6CTi6>RhR2OWj3R8R8RXZ8QhR7
Ph60OWekMW1^L71/IF1MGf=XKWEeLFmaMGQiN7EdN7eoOgeoQ8V<SHj@TI2BV9jS
Yj^][ZbWXj:SY::MUY:>Qh>1Og]eKfe_LgEgNW]jOX>6QXR:Rhj@T8b9RHZ9RHV5
PX62P7mnNgQeLg5]JFEQGf1QHEmMGfEZK6iaL6e^Kg5cLg=cLg=aKVUVIfY/Kg9e
N7IcLW9_JfY^M7QlOh:8SiBBSXZ5PGilN75[HeiOIFUZK6e^L7=fMWEdMWMcKfi_
KViaMWQfM7AeMGEfN7IcKVQRGemPH5mLE4e9BDaCEeYJFUYIFf9XK6i^KFe`MWan
P860PH>6R8V:SHn@T8n?TYNIUiFCTI>GV9JCTHj:QX>2PG]eLgAdLG5dNH26QhB2
Ph>5RHfAUIRHUYBCUIbTZZ^/[jn]ZZVXYJ2ITi2BTY:BTI>EUY>BUIFEVI^LW9VD
TYJLWInNViZJW:2QWifMVIFGVZ2W[K6e][Fe][Nh]kBb/:fXXYfJVIRCTY:?R7mj
Ngn4RHf>SXj>Shf:RHZ;S8b@U9VNWibHUIJGUYFASHV7Q8:3P7UaK6QWJW5gNGIa
K6MYKWEiN7QiNGYkOX64QH9mO7]jNGQgNGUgN7YmO7UjOh:2PhF7QhB0OG]hLg5e
MgIeLVm]KFi_KVi^KW1bLgQmP7ikMgEhOX:2PH>5QXJ7RXb9PgejN7IfMG5/JFQX
J6MTHF9SI6EXK79eM7EfMW9_L75`KW1eNWalOG]gLg5bLgAfN7UjNgYlP8:1OWYh
NW]iMWEfM79aKfi[I5mPH65QHF1OGUiOHVAUI6ATI6Q_LW=cLgEhNGMdLgIgN7Ui
NGA[IFATI6IYKg=fNgn0OgmoP8>7RH^<SHj?TIBHVINBSHf@U9NHUI6<RHV8Q863
PWmkNW]kOGn0OgYeMWYmOWilN7MfM7EkOh1mNGUmPh^BV9RCRXN:SY6BU9FFUiNI
W9nSY:6OX:6PWI^KV9:<S8n@T92@U9BATYFDTiBDTi6?SiBIWjFYZjja/kFe]kbm
_L72`LG7a<72`Kjo_KN_ZZ^WY:R[ZJFSX9fJVYnRWYbLVYJDTXn;RXV5Ph>7RHV:
Rhf@T92ATY2<R8J7R8N4P7Q`KF]WIF=UIF5PHVAXK6meNWUiNg]mP8:5R8^=SHf>
SXb<SY>GUHj8QhB2PGmlNWUiNW]jNWMdM7QjNGMgMgAaLG=cLViVHV=TIVQXIf1K
GEmRIVY[JFISHEiMHF=PG5YJG5aLGV1QGeYBBdM4ADI4@d=5BE=OJFmbKf]WHf=W
JfmaLgEgNG]mPXR<SY6HWIjOWi^FTY2@U9bPWiZFTXf;Rh^9Q85oOGalNgYhMgIg
N7UlO7alO7eoOgj0Q8N:SHf=RXJ5QHN;SXn:PG]gMG=`KVa/K6a/K6e`LW5`LGAh
NWakO7imNgUhMGAdMGEiOX61Q8N7QX>0O7UjO7ajMgEeMG=_K6]/JVQXJVa^L79e
MWQhMWEiPXbBUYVLWjF][J2FTHR2P8B>V9bQYZ>LVIJCU9FIV8n9QHB5QGihMWMk
OhF>UYNBR7egMWMiOXB;SY:LYZV[[:b[ZJ^b^/35b<>i];Nj_Knn_K^i][Bd^;bj
/jb/[[6d^;bj]Jn/ZjZWXj>UXYbIWZBUYjfc^;Vh]KBc/[2/ZJRXZ:V[ZZJQVY:8
OgYhMG5]JVYYJV]/KFi_KFYYJFa`LG9_JfQWJg9hOH21OWYhMGAaKfeZJ6IUJ6][
JFQWIVIUI6=SHf1NGUiHDDi>E5MHEeEEEE9>CTm=BT]@EU]MGUmOHF9UIfIWJFic
Lg5`KV]ZJVQVIVARGf5TJ6Y/KVi/K6e]KFaZJ6ISIFQYJ6U[KFm`MGj7S8j:QXF4
PGelOh:6RHV;SY:DT8^7P7]iMW5]KFYQG5aSJFY[Jfe^K6QSHVI]LWEfN7UiOH>8
RXZ7Ph:2PH62Ph5lNWanPXF5Ph:2PX:3Q8N9RXV8R8^AUIFDTi>ASi2DVYnQXjBV
Z:VZ[Jn][:b[YZ6NW9bKViRDTY:CTY2>RHF1OWUdLW9eNX66R8N6Q85nNGIgNWYk
OX64R8V9SI6ATI>IX::QX9nMViVFUI:=RXN5QHJ4P7ilNgYjO7n0Oh>9RXV:SY:C
U9>EVIbMWj>WZJNUYjb_[:JSXZFY[kJk_Kjk^[VbZjb/Z:FTX9fKV96<RXR;TIBI
VHf1NWIdLg9gOh61Q8N6P7EYHE]IFEQIGVEWIfAOGEaKGV1RIFIUIVU/Kg1`M7Yn
PH>1OGQdM7IgN7YnQHZ=Si2>SXj?RhF1P8>5QXJ6R8V:SXj?TY:@S8R4Ph5oOX::
T9FGUiJEU9:>R8>3QhV9RXf?TIBBS8R6Q8B4QXN:S8^:R8AmMg1/K6e_KfeZJ6UZ
JFQVIF=SIVMWJFYZK6m`L75cMGUkNWUkNgUiNGMdLW9`L75eNGanPhR:RhZ7QH>2
P7ekNWYiN7IbKFUWIF5QI6QYJ6MWIfESHVATI6=SI6ATHf=UJ6U/KVeYIF=RHfIY
KFi_Kg5eNWn0OW]kOGmnNgQdM7IhNh67Q7MZIVQ/Jf]_LgAcLW5]JfQTHEaKHfmh
OX61OgmnNWEgNGUkO7aoPX9nNWYmPXR;RX^>SXR3PhR<SiBKXZFWYjFSXIjMW9nT
YZNY[:bXYZJVYJFW[:n]ZJJUY:BUYZNY[;:i_;^g/k:b/k>e^[no_KVd[:RXZjb^
/;>d]KNi]k>/YZ>UYZBSX9jNViJAShj;Qh>3QHN7R8Z=Si6BTY2>RhJ2OGMdM7Af
MGAeN7UgMG9^JfY[K6YVI6AUIfQZK6YXJFMUIFEUIFI[LGEiNgalOH22P7inOh1n
OGYgMGAcL71cMg]nPH:1OWn3QHJ4Q8F3PXF9RhIlMG9aKf]/Kg1aM7^3Ri28NG1_
LFm]L7MnPGmmOGiiK5]?C5=KH6EXJFMQGEYGE5=CEEIJHFMZJFISI6U/L7EjOh>1
O7YlPhR:RHV;S8^9R8F2P864S9FLWj2NViJ?RhV8RXb=SHb;RhV7Q85mNWUiNgen
OX26RHZ:SI6DU92:Ph1oOGamOWmoOh22Q8B1O7IdLW9bM7EgO7ioP7moOGYhNWak
NGMeMgYjNGUlOWinOGajN7IdM7=aL71cM7MjOWmnOX21OgYiOhJ;S8b<RXF2Ogaj
NWYhMGEgNG]nPhB3QXR9S8f?TYBCTI>GVY^GU9BEUiRETi6ATYFHUiFCShZ6QHB6
RhnBUIRMXJ6MVYRETHj?UIbNWj2TZk6]X9RHWZFWZk6d/jfXYZ:KU8Z2PHJ<T9JJ
V9:;Qh9lMgEfMWQhNGanOWYfMGIeM7AbM7IeMGQlPH>5QH>3QHR:RHV6QXZ=Si6A
TYBCS8J5QhZ>T96EUiRIVYZIUY>ATI:BTi>CUYVHU96>RHF6RXb<RXV9RXZ:RXbA
UINIVYRCShb7Ph1kMgAbKVYXIfETIfQXJ6IWJVe^JFIUIVMXJFQXJ6QXJFe`LW1]
JFIVI6=QGf5QH5iLG5eNGUeOHfQ[K6a/KFe/KG1`Kfm`L6m_Kfm/IfIWK6maLgEf
N7UgMG=^JV]/KW5dMWMgMW5^KFYVI61OHVEWJVe`LgIiNgeoOWYgMWIhNWQfMWMh
N7UmQHR1M71bMGQiOHJ>Shb:QWmhLVeZJfiaMWb1Q8B2OgYdKVa]Kg=jOh:6QhN4
PGmmOWj0PXB3PH60Q8Z@UIZLWYnPWi^GTi2=RhZ9S96DTXb9SYFIVibPYjb^Zj^_
/:j][Jf/[K2c][Nb[jn_[ZbYYjNVY:6PXZ>RXJ2QXZ>UZ:Z[ZJNVY:6OW9ZHVIZJ
Vi^KVYbOXZ>SY:FUXijLVIRGUiVIUiJIVYRFUYVIUI6:QX>2PH63PWilOH66QXB4
Q8>2P7ilNWMgMgEbLW=bLW9dMgYkNGEbL6i_LG1/JV][Jf]]L7AkOh20PH:3PX1n
OGakO824QH:2Q89lN7IdLW1`LG9cLW5`L6m^LGInQ8F3QHR;S8b:Og1UH61NG5iR
IFQYJFUYIEmHEEQLGUiPHfEWJ6]/JfMWJVi`LG5aL6iZIfARHV9PH69UJVmcMgf0
P7mmNWUjNWYlOh61Q8N8RHV8QhF3PH24RHjBUYRIV9NGV9RGUiZOXJ2QY:NXYYnH
TXb7PX21PGmmOh>5QXF3OgUeMWQfLg9dN7QfLg9bLG1_L71_Kfe^L79dMg]mO7Yi
NWYiMgQjN7=_Kg=eM7AbLW9bLW9cM7EgMgMfM6mYJ6U[K6]YJ6U[KG5gOX:1P8:4
QXV>Shn>Rh^=SY2>RhR5QHF6RXn>Rhf@TY:CTiBEUYRJVY^KVYRHVifMVYRFUIB@
S8R6QXJ7R8N7R8b?TI6@TYFIVi^JVifOX:>RWIJDUijRY:JZ[k:c/JZPVYFASi:E
V9^OXJJ[ZjJPVYJBT92BUIFDTXn;R8F3Ph5mO7n3Q8J9S8f?Shn?SXZ7QhR:S8nB
THn>SXj=Qh5lNgamO7f2QHJ9Rh^:R8J5QXF4QHZ?T96@SXb8Q8:1PGmmOGj1Ph>3
PGmlNWaoPhB3Ph>4QXR9RXR5P7ahMG=bLFaUHF9TIfQZJf][Jfa[JfYWIFIYK6i_
LG5_L7=dLFe[JfUVI6ATHf9QHV5PGUiPHVEUIVU/KFaZJFUXIfMZK6e]KFmaLW5`
L71cN7amNgQgMWIfMGEfMgQjNg]iNGQhN7A^JFU[K6UUHfAWJ6U/Kg1^Jfa_LG1`
LW=cLg=aL79dMGQlPHF8Rhj:PWn5RX^;S8j>RhN3OWUeL6]ZKgIjNW]mP7mlMg9_
KW1eN7YkOh>5QHF5Ph1nOGaoPhR;RXbAUIRIUYFGVI^MWj6RXIfGUI>@SHf>T9>E
V9ZKWj>VZJZ]/;6`[jn^[Zn_[k2a/[Jj^[B/Z:FSXInPX9nNWj2QXZ>SXZ:RX9bI
V9NGV9RHUYJGVIbLVYNGV9RHV9RIVIVJVIRFTi6ATiFFUiVGUIBCTXn<RXN5QH:0
OGYhMWAaKfmaLW9cM7EeMWEdLVm]KG1dMGEcLgIhMgAaLW=dMWIiNWYiNWaoP7mo
Oh20PHF7QhB1OginOG]kO7ajMW5`LGAfMgQgN7b0P7n0Ph9oPHF8R8F4QXJ3Q8J6
Q8B3OgajN7IbJVIVIVQZK6a/Jf][JFMVIVASHfI[KFi^KFYYIfMVIFATHfEYK6m`
Kg1bLg=bL71cMWQiNWamOGakO7YgMWIgMgQiO7n0P862Ph>0OWioP8:4QhZ<SHb;
RXZ9R8R8QhV:S8b:Rhb>SX^7QXB1OGYiNW]kO7akMgAaLG1`LG=cM7IiO7ioP821
PhB4R8Z9QXB4Q8:0P8:5Q8:1PGmlNWQeLg=dMWEbKfaZJFY[JfYYIfIWJViaM7=e
NGj0PXJ8QhN:SY:EUYJFUYFEThj;RhR8RXZ8QXN7QhV<T9>DUINGU92<RXR5QHN9
S8f<Rh^;RHV:RXN5Q8J;T9>DU9FGV9NEU9BDUIJFUYFFV9RGUYJHVIbNWYjNX9nJ
UIFGV9NEV9bOX9jIU92<QhF6R8^:RH^<RhN2OGQaL7IjOGinPH>3P7mnNgMfMGIh
Ng]jNgn3QHN8R8N7RHjBTY>EVZ2TZ:ZZZZVUYJJX[;2_[:RTX9fKUi>?RhV9Rhf<
RhZ9RH^<RXN5Q85oPH>3Q8F6R8Z:RXZ;RXR7QhN7QhJ6QXB0Oh:5QH=oO7QeLVi]
K6QTHf9SHf=SHEmLFUaMGEaLGV5SIFIWJFYYJFUZK6ibLg=aLWIgMGAcLg9bLWAe
LfiYJ6U/JfUYJViaLFm/JFESHF1PHVI[L7=cLW9cLVm]KFm`L71cMgUkOGinOGin
O7]mP820PH1nO7]jNGUhMWAcM7IfM79aLg=dMgYlOh:6QXF6QhJ1P8:5QhN9Rhf<
Qh9mNgUfLfm`M7MjO7inNG9_Kfi/JFY]LGMmPXR:R8F3PX:3Qh^>TI>BTHn>RXF2
OgaoQ8^AU9FFVI^LWYjNViRFUIJDT8f=SXj=S8b<S8^8QXJ9SI6EVYjOWj6RXZ6R
Xj:SY:NYZJNUXj6PX9jLVIRIVYRGUiVKWIfLVibKVYZJVIRFUIRKW9bKVYVGUIBD
UIFEUIJCT8b<SY2?SXb;S8b;RhV6Q89oOgahMGIhNW]mOWilN7EdLg5^KW1dN7b0
QHR:S8f<Rh^<SHf>S8Z8QhN8QhB0OWn0Og]hN7UiNGQhMg=_K6a]KVe[K6e_L79d
Lg=fN7MeLg1_L75aKVe]Kg5cMGMiN7UlP8>2OWYhNG]mO7YkNg]jMg=_K6YYIVEV
IfUZJFQVHEeJFU]MH6AYKG5eMWEcL75eMWEcLG9eMgYlOWekNWUiNgemOGj0PXJ:
SI2BTiBEU96@T96BTY>DTY6ATI6?SHf>SXb<Rhb=SXj?Shf8QH:2Ph:0P85oOWin
O7YiNGamNgUiO7ioOWakNWYlOh>6R8^;RhZ8PgmkNGQgMG9_KVe]K6IOFe]LG5eL
FeYJGV=VJ6Y[KFmaLg=fN7YmOh1oOGUhN7EbLG9cM7EgO821PhF:SXnATiFGUI:@
SXb>T9:AShj;RHN6Q8>3Q8>3PhF6QhZ>TYBFUYJFUIJIVibNXJFVYJNZZjVVYJBR
XjBX[Jj_[J^YZJZ[ZZ^ZWibMWZBSXZBUYj>NVIF?RH9nOh:6RXf>Si2=RhZ7QXB5
RHZ;Rhj>S8V6R8Z8Q8>3QHR9RHR7RHZ;S8f?THn?T96DUYRLWj2PWifKV9BBShb;
RXV;SHj>RhV8QhJ4Ph:2Ph9oO7YiNWamOh62PhJ9RhV7QH9nNGMhN7EcLWAeM7=b
L6i[JVUXIFEVIfIWIfMXJ6UYJFY/Kfm`Kfm]Jf]/K6YWIF9OH61QHV=SHfIXJfe_
Kg1aL71`L75bLG5bLFm_Kfm`L6i]JfUXJFYZJfmeMWMeM7EbLW=cLg9`Kfi/Jfe^
KFUUIVMXJ6U/KW=fN7QiNg]mOWn1P861PXB4QHF4P7ejNGUiNg]kO7eoOGeoPhF4
QHN7Q862Ph:1PXF6PgmnO7YgLVi]KVi[Jfe`LW=dMWQhNG]mP8B8S92CUYRGUiFC
THj;RHN6QXR9RXZ:RXb?T96CUYVLW9^JVYZJVY^LWj2OWinRY:NXZZ^[[:b/ZZZ/
[k6b/[2^[J^ZZJFTY::QXZFTXZ:QWY^FTi>@TYJHVIRHVYREU9BEU9>BTYBDTi:B
THn?SXf=Si:BTY:?RXV8QX>2PGmnOWimO7ajNGUdLg1_L75dLg=fMgEbLW5]KG1a
LW=fO7eoO7UhNWYjO826R8Z9Qh^<RHJ6QXB2PX>5QHB6QH:2PGmlNW]jN7IcLG9b
Kfm_K6]`MGEcLG5eMgAaLGAdLGAgMGEaJVMVJ6ESJF][Kg9`KFe_KVa[JFMZKg1c
MgAbLW9_Jfa^KFm`Kg9dLG=eMWMgNWYgNGj0PH:4Q8:4QXJ4QXJ2PX61QX>4RhN3
Q8J5P828S9:IVIFFUIBFU96CTXn?SXn>RH^?RH>3PWmoPhN3OGj1OGQgLVedK6M_
JFe[IVEYKFeYJFe^KG=fMGEeNg]hM7EnOWj2PgmnQXZ5PX:2Og]lN75kRW=ZQGYj
NFUfNW9aJfYeO7]lLGZ6OgYmOh5oOh:3Qi6@Qhn=P8=oPX^7QH>5SHZ4RX^:S8^;
R8:6Shn9RHF2R8^5QXF1Ph1mOWenPh>5Rh^;Ti>>T9:GVY:@WJ:MWj>[]J^MWIbN
XZFXX9bTYJ:VZ:jb[[2_Zj^WX9fJUiZCTjJSUifSX9bHVY>8TI:6TZ2NVYFATiBA
Shb=QWIjRXJ2PWadNXIkMgeiLGF0O7IjN6m`OGihPhF2RHV9SXZ9QhV:S8f>UY>;
SIJ=P8B<Qgn0R8F4Si6:QhQjMgeoLVI]K6]fL6e/JgI`LWmkMX1kMXF1N7EdM79e
OW=^PW]MMgaYNgUfL6U_K6n1LeeUL7UaIFEZJg1nP6QMLGEbJVQ_GfIgHUEVKG5h
OG]kO7]kPiF@NGn=S8b6ShieLh2<RGAlP7R6MFUlMXFEOGIeL863MgU_LGeXFVI_
M6]_PGYkS89oRXB8Nfj2Q7MnQ7f5PfmXKVM[Mg1RG69bM6e_L6e^KFELF6QnNFM[
O8N5NgeoKFmmOX:3P8nCT9RGRHZGUI2?SXV<S8ZARGn0N7V1QHF8O7f4P8>1PXZ9
PH>4RHb4SYB:PX>?TXn>TYNITYRNTiZSXJ:QVIBGUi:JXiZEViVDT8J?X9:3L7:8
UI^DQGIbQiEoLhJ>LFQiLfYaQ8N8WiQfL82CVh5gTXN2U:6UWhUdUKOE`8R3]mBI
OXEfOX>ARGn:QXJ9TH9ZNiU[D7b=NX6YX6]WRGM]PXZ8OX61P92IOGFJYh=cSZBP
VhafIfefVk6:KIF[RGV4Qi2@RXN1VK6OKH2lZ7EcM7F0P82=S7Q[UKVXW8nOUh^I
R7]dUHagTHE/HFENJXEfEF=_NX1QE65hLff7Q6MVMhMmMg=`N6m_UhMKEen6V6]V
O7]dL7IbJXV?MGA_OWi/IGZ2JVf<PVAAFXfLMfAdR7]cMg=YG6mcHfUgKVecR7^0
Ugn0WYEaLXV?RXRRUe]AHX6?L5IJEg^=Ie=BG5]aPFedPY20O8fGNFA`P862QhAg
O:^XPWN9QIVCMI2HQH^=TY:0Sij2KX6BUIVISYfdZIR7X:nMRXJYXXEhRhR7QFnB
Z8R?RW1hSIjAX:F1KVafNGITE65lOUmKFFadMFe@H7iTCFaaMiF7OWE^SZF?MgIg
U[6BH6B;[Z5QNI=cM9=aH71aM71nQXMjDTAmWXR=SjN/TH^GQgB;OGZNWW]fJg>E
P8FHTHJHViNU/:MhW/[6^jnYZl>k_lBaUjJk^k6UX7QcS[2SO6a]PH5fQ9>9Ni6H
RXVFRi:DPG9/YIIjW9f;SHF0SHf?Kg24Mfn=VX:3NWAOGhn7L8BPNg:1LfmiSHZ2
MG9lS825Sh62NFeiQ7E_PFMBOZfER9NBWjRGSXb:OGF;TGAVKW5ZK7f9NGamHVM_
KW=aLg5hL7R0NF]OHGjGGCaGP:69Jf]FFh9lJGA^IgemPhNDSUmUPfmaTY:COUUl
SgYhK71fL6]CJWYhTGedPgn6U8egNHn4TIZ>VJbeX8V<S8:BUI5hKH^2O5i7CgN=
K5EPLE@k?4IFN8ESDf1gK6N9Q6QOHgJHYHahRhN0QGEgNgJ0SIjWW9B@WZRGOfV:
Vg=YIgBBSH^<NIBdU8B6M7:0Qi>AOH5nOjF<G92FMW1fVYJ>VI:6PWUPLX=`Nh5f
Kh6CPFiWNXEdG4=FO7UfPXfAOWV9RGZCXh]fF5Qk/9]mUJJSMGbRMejDYJ6FOiRO
V9MbHh1bKhn>NWnEPfU`U8aQJ7]aKFeRM7QWKh:7QIVHQ8AhL9ZNT9^U[9VF[knc
Z[31bZZPZZfaWi^QXIVDU89mPhF2SYV;RfiVTij?R9R3E5]/PZ6QQ7EmPZ_2W95n
K8NBRJ6TOYNOO7inLfElVhb4P766/KNSTg]nSXEhN9Nk]YfBYJ:8Sh9dOH24P7M]
Q:FlaJB8SibQU7ajPYjJQI63DDmmPHJ;LUeCF6AaP91fF6]hJGB0KTmNR8nTS7Ed
OY6>U8EfKgVBS6b1YWigQgIlSh5kTWmdNfe^R8adI6=YJfEYT9Z0MGV5P7]aHfIN
D6NAQ6ADHIJ_UiNXQgfKX:JGMGf7SXM]M6A8FWa[=b0/>CUEHDa:CEE[K6EHFEa7
B6^8QX1`LXNAQf=QJEifX9f4RGYfUi2>UH>6T8f4PX^EThnSa;Z2H7FCX9f8OW=`
PinVQ7V0NV]aN8>2KHROVY:0LGf0Ng=hO7YiNGZ;X8I^KG=nPVUXQG1TNgE/O7QX
PIfGQ7MdOXbVZIfKW8f6U8V=PFQcTIn?N7n:Nh2WZ85SHXbTWH^?UXR=V9IhIVel
OX5nI61ZP9>:RjjZRgn4[<>aWi>:W;>a/ZnRXjFc`J^GSYNnb9UjMWfCYZAnMhZ9
PXn8OH1oUYnFRGEVKFioVHn0Hej0VZNXPFIQFff?UXakHWj>OHB7MUYBM9NAQ8R5
TI2<VHAVKhZ=QHAjQXEbPIf=I6ejOGecNY6DTYZg^JBCRIFNVXB0O7AoUY=_GU=>
KY:>L69MGG>0P8^0IE9QMWiaGV]_LXB8MFQ]OIVTUhI^IHJVUVaXQ8EkTJJUT79d
QXn1OYBIRX=hGU]LKWicPIj8HfAYP9Z?OWj9VZ6GSXV6R:Fn[inRXIbLX:jdTFa_
VJ=kLgYMD6^0LeQIF4YEIFAHCEA]Q85ZFFaYHh^GKfA_N7U_KVINGWV9PWUiP7J;
Z:BKWY9[H6QeQh=WIhZ2IFAMJH9mQi23KV]iQ96MV7Q_MW^6NWN2Shn3M7jEQWAn
SHIdQHEWJ8BFShE[CDMGMHEeGDY<GF=HGV1>DV1YHVM[I6]lQX9lLg20WJnQPXJZ
/::ARXbG/Jj[[8QYQIbJZ[:DQ8jKSg20U8UoO79]JW5`IFI_OXj:MX:DSI>UZIVJ
[k2[YjVk`kBd^KS5d[nhc<VSTJBV[jnIR821T8a_M8fRZh=UM8V=Rh:0SifHPGMo
RI2VUGImPGAmTWiUOIbAPG9aMg1fPYf`Y8n<Sh6<UXMdKXJY[:>DOhB9X:F5MGUj
N7ijO8B6R9:NTXNGXIFOZYfDYK>EN7N6Qh1gMh5mMfUSHV5ZKfeXG4aBJhAjFeM_
L6N3Ne]JKGV8UhV0QX=fM7edH76?RhF<R7b1OhZEQH^1J6b3QXR4KFehP85jLFQH
Df5ZJf]^F4EPP7igKFR6XYf8RHfDXjBLUj6CQ8FBSgQiLf5/OWESEUURHfU]HFYa
EUe/GU9OPI:COgMbHU]JJ7ilH5MYL6]_Lg]mOhb@PWb8T8b:V[6PQWUdOXRBWIYj
OJ:dV7n7Qgb2RXAgEeEnSX9lQX9`OhmbFem[OHN:OhnIPVabQX9aJH:=MWEmKFAY
KWI^Fee^M7f<RhN;RXZ>RX>2PgibRZR/VhijJXRSYiV?UIfKQWR4XkFTSHVAT8>4
UinMSH9hNXJ6N6UePXN5QH1nP7V9VYf<Q::`YZb]UI:NVIV]^KVj/ZFPX:>[[JRC
PHREW9>1LgAnR966LfI]PgaXJ7N;UGYKG6miNh:2N7^2MWQnMFUaO866JUMGKGii
R9ZMR7b4SX=^GVN7Th^:Qh^9Q8=nPHf8OgmnPh9oSYRBRX^<RHf>QXf/^;VjXGac
Q9FDRXV:SW]WKWV7Q71/Kg1_LWEbKfQNHGInKU]?F79kN8F?U9:9RXYjMH6FUXF=
U9JFTY^[[J6HOg23ThIcOXb:PXZ9Ogf;THAlPGilPG9WNIB?OgeoT9N1LH:P[:6J
X9b@TYnUTWIhQHJ9NEE=IXJ=MVIVIV]UIfmWCTQOLW=`Nga`IEeWO8AiKVa`LgMh
KfiiPh9lO7b0QXF:UXf1QhQ^GF5ZJ69bRiEoHV24Yij>N61MK7MfM6QPHW1iNWQc
K6e_JG21SI>DT8^7PWAbPXR9SiB9NG5ZKg]iKfa[HEMIEe9XRY6;RgQYLW]iNXVK
XY^CRHbBQX6C[[b/SG1_T:f^W8V8WJ:IWZ:HTI>SXiJCTHZ6Ogf<ShMgLgalPHV8
S9>DWjf/UhRBVINPZ:F//JRYZJZY[[B`];2BPY>WXX=gPXZ7O6aaO7IkSYR?QGEW
JGnBSX1eLgE`N8nAMfM]LFa`K5mZNgA^LgEjPI2LTH5_JGAnM7F9UXioQhn;ShUn
OGQdN7Y`KH2CUHMkNhNFT8>5VJ^f[IbOYJFIT9^TV7QQHG5nN6UTHV5^MfiZI5]U
Kg1^KVMNJG1TG6n3SHj4P8RGTX9oMgB7W9UmJgF3PhVGWZ>OS8EmM7>:YJNEPhF9
Rh1^M7j5P6MIG6E_N8BATX=aGf=jSIbSY9bBUY>DUI>BUIF6Ogf2O7YmL6]lPgad
L75[GUIHG6E`MgU`JW5gLGN4Ph9hKfY_MFmbMWA]K6i]MHB0NX:KYYbCU9fBPgj6
ShZ4N6i/Lh>CV8b7QGMOFWAnM6]RH6]dKV9VJ6emQ8Z9Rhf3S9nQSgf4TI2IW8f2
OGM_LGZ2QH5fI5]JHW^ATXYhMX:5MV]kQHN6PX>4Ph><Uib?SIJ7OXR?Tj2SVHn7
S9^OVY26Q86DXi>4OGEdOHbAQWIXJ71_JfAWMY:YY9:4U9jHUiZQXijLV9FFSYBW
[:JMWJffXi22QinWVHYmMg]iOX>1R8MjHe9GKWb4QgEXIficOh1`I6Y`JfAHE5UN
H6j1RH1gNh:BWY1kJW:6SX]jN8>4R8^8Qh^IUH=cLg^AY9VBRH64QG]YLIB[X8b1
RIVLVijLVjZ`[9n7NX:CVY66PGAePXV=Og5fQXYmJEmNG6EeQWiNG7R6QXAeKgZ?
XYf8Pgn1Og>2UIZCRH1oQX5kM7R8Si>BTY>4NHZIUHb<R7]iNGEePXnHUh9WEem[
OI>JSWmoRINITHIaLhbITgi`N7UiP8V@T8R3ShimL6iXHfMaN71YJGEkLfigRHYm
OHF3Ng^:R7AcM6MFC5MeRHImNH64Q8MkJg21SHf0N6YTM8bOWXMkPHZ<Q7edKg=c
M6mYJf]SGg:5QWM[MX^DS7eeN8:HYj>LUhn7Q8V@THYgJfIRH6=XKG5`L6YZNGai
OXF=SHB7T9FAQGn2T::UTWEJGhFKViRFSHF9TY>@TI6>R8B;UIZIS8>?WZ:GRXF1
Mg5`IV=]PXn:R8J0Oh:6SiFIXjNWZ:RXYInS]Kni[ZNHV;6m]:B?OX21MW>3SI:G
SWedLWAnQX=nOGMiPH63PgYbLg]kKFAUGe=DI79lPX:3QHJ8SHR3R8jCVInMTHB2
Q8bDT8=gNX20OX6:TI:>QX:0NWAdO8RGXIbHW9JCUibSZZRQW9J8O82:SH=dIf1N
HFUdMW1`Kf=NIF1EEEmZIfM[KW1`L75bLG1jRXEjNgETG6MkS8f:RX^9R8N9QG]n
RY6=QhIoNhB?QgMdMVQFEfQkRHE_GUiSHfM^KFY^NHB8PH67QX^:Og9_PIJGPG22
WJ:ISgmcNH:4Ph5nOWU_LX>;O6AULgUfMWn2Ngb;TH5ZHVQXIfIMDEAVN86;UIRI
Thb<Si:ESh^:PhB9SHZ<TiFFS7YlTI^?OFmQHg5cJFIXJVa^NXR?RH>1O8B>TY>E
VJ2QTh:5VJ>MUXn0Lg5fOhN<Q7YmQ8N2Ng^2QHN;VIR2MG^<TiBHTXAkO7inOX>9
SYJHUiB=QHfFTHMnNhNFUXn5S9JQZZ>FS8MnMG=kQXj=PWenPXR:RI2CTY^VY9>>
VInOWYNEW9nPWZFXYjnk_kVTQWMoT9ZMVYF?QX1hMgmkMGUnNW=fQ8AlNg]hKV]]
JfALFUiMFEiUKGQmNWE`LGMlO7AlRXAgMGYnOH>>UHieJ7Z9SI6@QX22RXMoMG1e
OH>6Qh1iOGeoRIBJV9::Ri^QUHn?RGeiN6eOH6YXIFI^Nga]FeUOHV5RHFIbO7ac
KgZ6SHn4OhB9RH=hKVeiSXj0O862N6mbOX:3P7YlQ8b=TYbHRhR5PG]lPhbGUH9^
IF5YNGmnMg9cP8b8PXbCSHJ1Q8Z7PHZJXYbASiBOYIN7QXf@THj8R8V5OGUgMgMg
MWMgN8JEWYZFUYNGS7I[Kfm/JFEVJVYeQXQoMWZ5T8n0N7QfNXV>R7egNXF<QX22
PWj5S8MoMfm^LW5^JFMaP8B0PXB1P8^FThb:S8^BVIfRXiN8QXF3PgYZHFQcNgac
KgIhJfA]O8B2P8>1NGJ0SI:FTGUSI7J<TXZ1P8jMVXb8R8Z6O7V1QgibLgn6QHZI
XIfMWIB6OGenP8F<Q7QbLGEoRi2:Q8R>TiBCUINHUY>BTHV<WJZ`/JNBSYjTUXV1
PIBSVh^1Nh65OgQaJF]mPg]jOh:0NGB0ShM]HV]^IF=UIg9eLGAkOG]nPhZ8Q8B:
SXZ6PhF6PgmmOH1lK5eJJ7Z8RWmdM829SHZ6QhZ6PH:4Ri6HWi^<QXbCXK>dYY^E
THYnNXB3KUiMJ7EhKfYaL6INHFUjPgUcMG9[L7emNGj6PgY`Kgb9QgaeO8R?U8f1
Q9:BRX5iN82=Thj6PXF5QHB0MG5lRHn;QgedMg]fLFmcNgE]L7^6S8R6R8InMWAd
O8J1NXZITH9jPi>IThj@U9JOYY^@RhV9Qg]/KWMjMgYkNh:4QXV5Mfa]LVi]Lg1]
LgEcKg:0SYNMV8QiNHNET85hNGinOWn3RhQmMG9eP89kLf]ZJFihOgegN7alN7Uo
Qh^6PXJ4Oh:9TYJFSXZ<R8N=RgmnO7QoQ7iiOGiiM7IoRHZ5PWmgNXZFVHf1P8>7
QgecMhNCS867V:RXVi:@SH^:Q861OWb3TINFVYjTY9V=QXN=TiJ>OgaoNWMjN7Z0
Ph5mP8Z=R8N=THMiNHRFVINQ[ZVNShF7UInQWIVCRhfGWYR8PXF2NWIkR9>IT7ab
M7QjNGIdK6ETK7MeJVU/IVE/M7MaJVYgOGalOWn1PWeoRY2CT8AjOHV>QWmoPhb<
QhN9UYj;L6MdPXJ4PX^DTX^AUi>AU9jXYYZ>RY>JTH1eLFaZJfe/K6aYIfefMG1_
MWinN7EhNGf8S8b;S8j2LG9mQH1cKW9cMWYhMWMlO7UgN7b5U:>RT8B1OWinRINH
U8f6QhR2N7J1Qh5]GVMnRhR5PWahNh60NgEhNH6=RhJ8S8YmLg=jQXV2PHN:RhV0
NGUmM6MRH6UfPhb5O823Q8N:TXemNX64OFmTGeaNIg9gOHN;QX:3PgikPHJ1N7Ag
OHJ9PgahMG5aKfe/Kg5bLfYSJG9dLWMlM6mcNhVEWJ2HRhN<TY>EWIZBT8^3O7]j
NGMeLViVH6]lQ81kNGEaMgn3QhR7S9BARHB6SI2?RGmmQHjFUhn;S8n?SXj9PWQ/
Ig20SYBCSHZ?TXn@TY6BSX=nOgmjO85mMWEnRi68PhbDSh^CVYN>RHR>XJnWVYBE
VYVEV:Fb/:FNUXZ;TI:<RXUoMG1fQYBDSXEjLVa`M7IfLgMoNg5_Kfe_NX9oNgan
Q8fEX:>GQhN=RX>5SXb3O7YmOgioOg]eL7F3TiVCRHR?THn9RHf:Q7imPXR@VYZH
XZZWW9nVYJ:LSXB4Q7YaLG9`IemNIVi`LWIdL6iaM7AaKVegP7ifL7IoP7UeMgn4
OgIbMgakNX67RhEjMWMlPH^GUH9`Jg9kQY:DRGafN7YeMW]mMVa[L79bLfi_MWMa
JVaaLFm]KG5kO7]nP8:1OWeoQ96LXZBKUYNNX9VCTXj4MFUYMH>7Q7ikOGimOhN;
RHAnOWQ/I6E]NX66Q7UfPYBOVi:?RXF0O7enMgAlQ8=dIf]fO7E/L7YmNWAdNGj1
O7EeMgMbKWF4SiJIUX^2P8NBW9bCTiFETiFIV9NFT8ImNWUlQH^:PWQbMH>;QWmf
KW9lOgajPXAmMg9gP8J7RY:DRH>>V9>8P7U_J6inS8j9QHB<UijNW9NFVYZGTY67
NWb8U9>3KVMaOhV;R8AoP861QXb?TYZNUXJ0QI2PYIfDU:2YY9VBUIZFS8Z?T8Qm
O8BDVi68PWQ]IFQdNgQdM7EbJfQ_MGA/JVUUHVenRHQmMgAePHZ4NFm`PIBJSX1j
NGYjMG5aMWn9T8f5PXF9S8R0MVmdMgN2TYZGSHN:TYRHU96AShIiM7UiLfUQFUIE
Ef5^NgimOWYiOH5oO7MhPX^:OG=eP8N3MVUSJgIkMfUTLGimMGElQ8J7RHf;QH>4
QhfARhJ7RHR4Q8J9R8=lOXF8P7A/JW1iPH>1OWMeN7]nPhF4QXf@RX5lP8J6PX28
UYnSXIRCVZFUWIZFRh1oRiFDT9>ARH>5SI2>Si6<OVeVKWMeJfEWLGE]Ig66UIR?
PWj1P7]gN868RXV4O7QgNGQ`JF]bN86:RWidMg]jN7YmOX25SiJCS8R6PWakNgYh
NW]jOHJ:QGmiNX64Og=`MgmoOHB;R7aiP8V9OgZ2S929OgUeNGeiLFibN867R8J6
QX>0PhR6P7]lP861Q8^EW9bJW9nQXJ2KTHJ6SiZOV8b5PX5oP8ZFUXj3Ngf6T9NG
U8f6QhnDT8N3SIjTUHN?XJZRTHJ6RHZ<Si2=RXjDUYFDSh5cL7=eMG=aMWf0NW=e
NWemOWmnNWQiO8>9RX^7OG9/K79gO7f1RHIjL7=lO7YkNgj3RI2FUY6;QHB9TXin
NH><S8R7QhR;T9>@QhB<UYB9OWUgM7=eMFmSH6M]K6adOGIUHf]cN7E^K6]^M7Ef
NGj1Og]kNGEhPXQoKf]hP7inPhN3O7MhOH>9R8F6RX^7P82;UY><R8F6SY>ARh9h
MGIaKW=hM6UWKg5/JW9lO7A`N81oNG^2R8R2PHRDWj>QViVMV8n>SXMmN7^4Pgik
O8B=THn?S8R8RXf;QX:0PXB1NgQmQXR6R8^<RhEkLg5dN7]hLG9lP7U^Jfe_M7Id
Mh25QHF0MFmcNG]hM7QnOWanR9>EShZ9QgimQ8fEUi26PHF?UiZERhB2P7]kQHj?
R8F8QH1oQ8b;QhV;Rhb8PWmnOh1lN7f;UYRAR8R8Q81oP85oNWZ0QHN8SYNKViFC
UYVIUYNKWIVFUHn2MWEkOgYgO8N=R8F:SHb<S8R1P8N>ShnBU9BBTIROXJ6PViVD
Si2?RHF9SHb5Q8Z9P7QdL6aWIFMWIFUdO7]eLFm_L6i/K6e]JVU`OXV9PWYdL6ea
OH9lMGEmPh9mNGUgMWMfMh2@VIJ:PhZ?RX:4RXV0NgaoQ8N7QXJ6QhZ;QhN:R8=o
O7IbLW9^JfmaLWAhO8:4Q8>2PX60OGQiP8N;QWY`KFiaM75ZIfmhOgmlNWYjN7Z2
QX5mP8>1PXV>RXF1PHF4Oh26S8n>RHF9SXZ3OGalNGQjOG]dLWEeMG^1P7QfOHVA
SH1hNWinNWMhQ9NTYj>OViJ@SY:GThV1Ogn2R8^=T96AS89hO8ZBShN2OGMhNgj3
QhEmNh26RXN4QHF0O7amNWIdLg9/IF5QIVY_LgEcM7b5QgidMWenO7n2PhJ<T9>E
THN0P8B5PWYfOX^@S8V;Rhb?T8Z3OWn1P825RX^9QH>7S8n>RXV;Shj7OW]jMG5b
LG9dNhF9Q7QbMG]lP8V<QH21PWimPX^@T8^8RH^?UInXZ:6GT8f=SHZ7Q8>3PH:9
Si6DV9R@Pgb0QhN5QHR9QhF6S9BIUhf8SYNJUHn?SXj=Si:ASHR6QGihMgYkN7Ic
L6ibOHF3O7MkPhV:QhF6QXJ9RXR5PGimOh1nO7j0O7QiOX>3OGMbLGAjOG]jOhZA
THj;RhjAT8f=SXZ2N7AkQHf@T92>RH:3Rhj8OGIgN7^1PX20OWemNgYlP8>2OGUg
Nh:4Q8F2OGYgLfm_M7MfLG1dO8:0O7YiN7=aMW]mOGenP8>4Ph21OgUgMGEiP8R<
SXf6P7n0OgajMW=[HE]MIF][JVQXK79eNWn2R8^9PWj1R8b=SY:KY:RTVYBDVIVF
Thj7PX5oPXJ8QX:0PX9lMGElQ8N4P7ioPhR7PWafMgUgMgf6RXZ:QX9oOGajMG5a
MWMbKgEnP860NgAbMWemMg5^KFmdNgn1QHZ9Q863QhZ9QH9mNWn9TYBCSXJ2QXb;
QX62RH^5P7moP8:9SHZ4QXf@S8R9S8QjKV]`MgQdLW5bN7ajM7EkOX>8RXV7QhV;
SHb:SYFIV9>=S9FQZ::ES8R8SY2<Qh>0OGn5SI2?SHj<Q7eiO823Q8N<Shn=SHnB
Ti2?ShnCVYjLUiJHUY6;RXb=RhV;S8Z3OX64P7EZJ6igOWihLG=mQHEnNGj8RhEn
Ngb1QhV5OWQfNGn6S8Z1NGIgMgQiNWUeMGb4R8F2Q8^@SHV9RXJ2P8:6QhJ7RXb=
Qh5oO7UhN7IbL7EmPh5kNX66Q860P822RiBCRH64S92:OWE`KVeZJV][KG1`LWQj
MgAbLFm]KW1fPHZ>Sh^7PhB6Q7efMGMkPHVATXf7Q8J7Q7iiMWIeLFi]K6]^M7Mc
JFQ`Mg]mOgikLVe]L7AfO8J;RhV;TYJHW:6QVY>@UZ6RV8n>U9RESHJ4QHF3P8:5
PWioPhF6QH1kNGYoPX:1Q8N<T8UnMW=eMG9/JFY_LGAgNWanPH61PXB6QXJ7R8N0
Ngn7SXn;RHEnNG]mOWYeMG^2Q861PWikOGn0PH>9T9:;PGeoQXf>SHV8RXnCUIB?
RH=mLfa^LWEfMGAfMgUmOWj1QXN8RH^?THn;RXR4QXR7QhbCUYFEUIRIU8f;TYF?
QXRBVIRCT8j=SI:FThV0P8F:SH^8QhB2PHB:T9:CU92:RY>LW9NARhJ3PXF:S8^:
RXR4PH62OgekNG^1QH=oOh22Ph>6QhN5P7emOWUdMgf0OGUiP8J6Q8:1OWUgMgUi
O864Q7ijOHJ<SY:DT8V7RH^7Ph:1NgEeO8B8Qh1kNWMfNgmoO7]mPHF2NgMhNgM`
K6icN7moOh:4QXR5OGE`Kg5bKfa`NhF5OG=aMGMeLFi]K6a`M7QmPhN4OWYkOWak
Oh:0OGn3R8Z5P7elNGIfN7QaKFaZIF=XLWYgLG1gPHN:R8B0OG]jOH:6QhF3PWmo
PhJ8RXZ8RHf?TI:ASXj@T8f9QHB:T8n6PH:6RXj@Shb9R8N3P7n3RHV0NWf9ShUm
MGA`KFmdM6i[L7UnNWMlPGigKVadP8J3P7ejNgj1PhJ8QXF5QH9oP8B8RHR6QHR9
R8N5Qhb?T8n9QXN8QhB3PHB8Ri2FVi^IW9nKTHV8R8EnNG]mNG1]KVi/L7Z4RXR5
QhfATY:AT8j;R8N8RhnBU9:>S8nEW9bFSXZ<TYZGSHN8Rhb:QhR>THj8QHJ<T8j9
QHJ8RXf>SH^9RHnCSXR7Rhf:Q7mnOW]jPHb@SXf9PWU_K79jNW5ZJg1gMgAdMWQk
Oh:0Oh:5Q7ihLW5gO7moOgj2RHb7OWUkOWilNW]mNG=_LW^5RHR9RHR6Q8B5QX9l
OH1nN7=bMGQhM71^JfabOHJ9R8R:SHV2PHJ:QhB4R8fAU9JFT8EoP820NgA`L7Aj
OG]eLWAhN7IgOX5nMg=eNginQ8bBTXf7PGemOh>6RHV7R8^?SHN3PhF8R8N4PGik
N7IcKF]_MgemNGQmQ8AnMgAdMGQlOgn1PhB1OGamP8B9T9FIUiJKXZ>OVYF>Pgam
PXJ5OW]mPH:4QHJ7RH^;SHn<RXZ;SHn<R8F2OgYeLG1bMGA_KGAmPhJ5PgmkOH23
Ph>5Q7moPH:0Ng^0RXn>R7ieLgIhN7UiMgE`KgN1R8V4PH>6QHB9SY2=R8J4Q8Z@
Ti:?RXR8Qh9lNGUiN79]KFe^L7=bLWQoPH65RXb8Q8B8RXIoNgf0PhJ7RHb<RXV9
RXR8S9:IWInNViRFThj>SHN1Oh>9S8N0OX:5QH9oOGanP863QHN9R8EnNgamO7]j
NGQjP8R@U9:BTXf7Q8B6RX^9Q7igMGMkP8B6RHZ9QhV=ShYoMG9bMGUlPHJ7Q862
QHF3P824QhAlNGj6SH^9R8Z=Shj<Rhb<S8n@Sh^9QX9mNWYiMg=`K6U/MGn2PH21
OgYgMWMiNW]oQ8R;SY2AT8f8Q8>1OWeoQHZ9Q7mkNGMeM79_KFiaMGUiMWEfNX66
QhF5PgmjNWf2QhR7P7MbLgMjNgQfMgUkNgM`L7=bKF]_NH64Q8B3PX9nNGAcMgj4
Ph1mOX60NFm[L7V0QXfEVYbJVIVJW9RCSh^7QXF8SHn;Q7inP8:3PH20PH>3Q8V=
SXf:QH1lNGUlOGYcKG1fNW]lP8:0NgIdMgUjNgaoPhJ7R8N3P825RX^:RhnCTXn;
R8=mN7IhNGanOh63Ph5nOH24QhV<Shn=RhZ<TYRKVYN?RHV:Qh9mNGIeLViXIV]b
Lg5aN8>=TI6BTHn=RhV8S96ASHZ8RH^<RX=lNGb3RXf>TiNGU9>CTXj<S8^9RX^9
RXjCUI:<RHV7P7b0Qh^:Qh>4R8R6PGYhN7^2QXJ1Ngb5Si>BShn=RHN3PH1oO7Qc
Kg9fNG]kNG]nPhR9QX:3QH=mN7MkOh:4PWmmOh5nNWQlOgagMgYoQHR7QHF6QhZ;
SHnBU9BCT8f;R8B1OWY`IF9WLGEfMWZ1Q8J4OWIaL7AiP8B7S8f<SY2?S8^:Q7ek
P8J7Q8B5QX=nNGEeN7YfLW5eNgmoOG]jNW]oPH>2PH>7RXJ0Oh64Q81iMGEhNgn0
OgioPhJ6PGinOW]jO7akOHB9QWeeLWAgN7YlNg]kNGMiO7agLg=iQI6FUYBCUifO
ViFCU9B@R860QHR9RXV5PGemP8>3PXB:SiJHUY28P7]kN71XJG1gNGUkOh5oOh1m
N7MhN7^2R8b;PgalOh1nOWelOH22QHV=TI6=Q7YdN7j2P7UdMW]oPH1kN7]oPhF5
Ph20PH>5QHF5R8b<R8>1OgaiNgijLF]YJ6]`MWQhN7b2QXJ9RHJ2PH1oP8:5R8Z6
Ph60P7n1PhB5RI2FVi^ESi2BTi6>S8nCTi2=RXV>TiJCSHR9S8j=SHj=SHn>RhJ2
OGA/J6Y^LG=hOX:7S9:GV9ZLWY^FT8^9S8n>S8J0OGn0OG]nPXF8RHR7QhR:RHN3
NgUmQHV8QXB5QH:0OgimOh:3PhB7RHN1NWUmQ8Z>Shf;Rhj?S8R5PG]cKFUYKG=g
NG]lOWeiMG=cLgAdMWZ0Q8V=SXZ7PWinPXB0O7b1Qhb=R7mjNWQbJfU^MGMfMGIh
Nh64PWejOH62PHJ=Ti>>QGmmO7]iLfi^LG5bLg=bMGYkNWYkNW]kO7emOGf1QHAo
Ng]mOgahMWIeMGAbKfiaLg=cMWQkPXfDUYJGVIZIVIVHUY>BTHj<Rh^:PgQdMWUk
OGn3R8V9RhZ7QhV9Q7Y^If]eNgalOh>5Q8:0OgalOWmlNWeoOgajNGamNgUiOH25
RXb?TY>AS8R3OGMgNWj1OWYiNgalOh:4QHF8S92BUIZLVYRFUIJGU8n8Q8B5QXAn
MG1bLg1^LWQmOGn4RHZ:RhjATHn>Si2@TiVMVi67P7inPHJ8RH^=Shn=SHf>TI:B
Shf=Si>FVIN@RXZAUiNBShnBTiBBSXf=RhN5PG]fLFi^KFa`MgYgN82=Ti:BUYZH
Thn<RHJ7RHMlLVi`MGEbLWEkPHF8Rhb:RX^:Q7ejNWn6RHN2Og]gN7]nOWj1Ph5o
OGamOX22Ph5oPXB5Q8:0OWenOWUdLW5/IfYcNWaiMWIgMWEeMgMgNGn7S8f@UYVD
RXB1OWj3RHZ;Si>ARh9jMgMgMG=bLg=bL79eMGEfNG]lOGalO7n4RH^6P7emNWQh
Nh23OgI`L7=fMWMkOh1mNgf2QXEoNWMdLgQlNWIdNGinNGA`LWEfMgQhMgIgN7Eb
LWV2QXJ9SI2ATI:BTi:?SHb:RXZ:RXV8QH1mO7n4QhJ5PgmnP81kMgAcL6i`Mh25
QH>3PhB5Q8:1Q8Z=SHN2PHN:R89lN7YnPXF9S8jBUI>>RHJ7R8F4Qh^;QGelOh22
PX>4QXN9RXZ<T9:CUIFEU92:R8V;RXb?SHR4OgUeN7elMW9aMgemNGEaLGN0QXJ6
QhR=TY:@S8N2PH>8SI2ATHn<RXV<T92=Si>BShZ6QHV=Si2?RXB4RHj;Q8B;TiBA
S8V4P7mlMW1]JVU[Kfi/KGAlPHN<SY6IWijNWIZIV9J?Rh^<S8EjLW5eMgUlOWio
PHB4PX60P7mkMWIkPH5nNGUmOh63Q8B7Rhj:Q7j0QhZ9Ph63PhB9SY6@S8R6PWag
MGUjN7MeM7IgMFm[IV=UJFa]LGMmPX60PHB6QH:1PX61QXf?S8^<SHf<Qh:3Q89m
MFm_M7MiNWQgNGf0OgioQ8R9PgioP7egLg=bLW5aL6eXIVUaMgYlP85oPH>7QhF5
QhV4NgAfOH:2OgimNgUgMgUmPH:1O7QeNG^0PWemQH^>TIBFUYVOWI^KWJ6MV9>>
RhZ7P7]kP8V:QHB7SXj9RHN0OWn0PWmjNWeoPH61Oh20P825R8>3QXJ0N7IjOWml
OGikO8B>SXf=S8b?T8b;RXjCSHEoNGIlOgemOGakOH62QHZ9RHb@UIF?Q7j1QHB6
R8AmO7elOGelO7b1QXN4O7YkOX27SXQmP8b@SH^:RHJ2O7YmOG^2QHB3PXB2O7n1
PHN9QXF4Qhf@SHb?TI>CUIRARhfAShj@Si:DS8V:RHV6PgaaJFITJ6i`LVmaNGn4
Q8>8SI6HW9VBS8Z9PGYjOgmjNWakNW^2RHV:TI29RHf=R8V>QWaiMgYjNWmnNX69
SXn5OX20P89nNGQnQ8Z9PGimOG]jNWehLgAeO8B5PhB1Oh9oNGEaKg5dNGYiN7V2
QHF:RXN9Qh=nO8B8RHf>SH^3PHF2OGaoPhJ7O6a/L71cOHB2N7=iPXR9RhV0OHF7
PgahNgYiP7]dL6ifNgQgOH>5P7j:ShR3NgQiNgeiNG]eNhN9PGMdNGj0OgYjPhJ1
P85hK6Y`MgYgMGanPHV?Thf;Vj6OXJ:KTY:CTXQoNGb0OX68PgakOhN6PgaeN7j5
T8anMg=iPX23QX20R9>CRhF8Rhb=SHamM7EgMWEhO7anQ8N6PGenPGenOWf5R8Qm
MGemLg9iN7MeM7IgO8J<Qh:2P7j1PhV;QXR@SHV5Ng9aN8:2O7j4Q8AoLV5SMGio
NW=fO7n7RHJ4O7QkOH>7QXjGVinPW9>@UiJ>SHn:R8Z@U9NESi2GUiVNV96ATi^O
WYfKUY>DV9:5O7aoQ8V0KUmQKW9aKfi]K8FERHF;SYNITHV:VIjFSH9lQI:;Nh62
MWR0O82:RXN7QhEnPHZ7QH=jNh5oPHR@U9FHUXf9QXJ0OhN8P7YmNWemMGN0Q85i
NgEeNG5hP8J;RX>3OGIeKFa[JWAhMgEhPh5oQHR6QHF3Q8Z>VINCTHfAUIR<PH:0
QHZ6O75gN7M_IFY_MgAXJVQYMgA_NGYdN7E_M7QbM7n5Q7U/KWEcKFibMW^0Q7im
S9>;QXJ6PX25QXZ9PX23QXV3M79dK71nPgmjNWMfN7]eM7enQ85lPhZ8PHnPVhj<
TYNBSY>@TiJ8S9Z@QX1aK7MnNg^1Qh5dN8nJUYJCV9R=Q8:8TiVBS8R6RXR9RWaf
OhAkLWAiOhV>TinjbImfHEY/KEa>Ae1GFU]BD5]TFDQ;E5YKHFU^MH>BUi5oOi>O
TXBG/LG;_kBa`=[Wj^KDcLJf[:VJSXR1QIB_^95?:CUbZ[R@DBXbE6j8UHEjP7ak
NVMREDaUC59gP81L;ba]S68Y84M9B6UcJDdd=3U0Acl];2h/:T9XLG:5P7I`NhYb
KhB@R9:X_;g4a;?3j?GXh^[]gmcgooo/f^CboooYlooom]W=cL_7d]_1`<K3b<W5
ZifOZ<KF^Y6J[Y]hJHVSTWZ5Ui1mKF=]KV]RIGj7RWakRWiQHG=YC4Q>BDi8>3]=
Fe8e>TM5FV][GeIPHDi9BS0W>3L[:SU4>cU4AT]?D5IIEDi<CD0[71494QlS6@X:
5AD821`L4Ql`>CY<CS`n@CPh@eMOEU1?F69XI65VLGf3QHbDUI6BU8f:SiRIV9RM
WI>F/<:`Wj6U[j^W[:ZZYZ>SVjFma/Bm]k>oc/O6enono^S@emWSkm2b[;_Ee<cN
lOcon?7ooooPi?GjoNgWloOZj_[kjN?Gd/c>g]OBb/>m/[Rl/J:NXJBSXiF5PG]h
MW=/IfMTHVQ^IEQICT=4>C0iC4e1<BTc?dHk;BdR9RTC3ADT<cL`82hi<2XO82@?
00084ATT81L;5RDR5a0T>STf@4@j8Qe8HTXe:c=9GFMFB4mJKHR9OWQeNIJBN868
SYFGXJ2?R92?Ri6IYZbPSj6nb;NOVZ2/^kB`^kO3g>7KbL_SoOonl>G]oooooooo
ooc^k??mo>kWi=gVkO?kim;?b;Bgam?C_l36`KbVSI2U/JRFWkJcZJBXYIBQZ922
SiVOTW1SL86<QWUWFEM<@eAXEc@jDE98?D90@da=?B@Q9SY6>cD[91lD6b<Q7A0<
6BXa=c/k=BTc?SL/:C4h<bDW;R/_>CY1ATD`7Q`^D5AEEdM5A34Y<Shn@DU6?C4Q
:CTm@daAF61JCdQ4AD96ATUFFEeJEee]KfQ[KW:0QHj=R9>LVXUoRi^MWjnaZ:N_
`;j^Y:FV//OKh=O<bMCLdL[Ah?;aj^OSg=OPh]cLg^?[gL;7e<S4e]kKfMWPg/kD
kO7VjNk[i=kZmN_Ph>WWj?Oon_3bimkSglno`M3Ie]38_loEbLFlaMCCdl6ob;^g
[:^g/J^T[;6XXYF7P7Z5U9=oJ69RI6efJeeEDUUGC4Dn?3<^92I1C4Xn;RTR:CPY
30<G:bl[<S8b@ddo92@kAT4Y6aXT<CPo?Cdc:B4O:2TL8RhmACTc<C@i;2XlCemI
CEQMCd`m9ca]QXIcI6IVDD1MPX5iMg1aNXRAOWAgMGemPhYcK79ZLGf5RGYZLGj1
OH27SYBPX8Z2RYf]YYN=SibUZYnFV:>[ZY^AV9FEXZbWShRN[;FkYhj1MgjK[Yb7
SYZFUj>]XHb=XIj;Og^:QgYhSZNa[9>5T9N@Ri:=P8jITXn@QfmXNHNBSG]eMW5d
MGUkMVIDGWAnP7YcJf5HFVigKUeAEfAVGE9LH5eMA3A?LGEYIV]QFf=WGeUHGee>
CE1HK71]Ge9DEEe_LeiAHfeLA3iFHE9<FFI_NWM`LGN2NWJ0R8J4PXJGY:2IX:VW
ZZRRZJNW/;6UWZjnaL?4d]S@b[c1bl[?em;5a/c@cmGB_kW7d];Jf/Fg]/7Fc;Zn
d]gQiM_<`lG5a<kIeLBh^/_Ib[2_cM[;_[jn_LO1_Kbc_<2g^Kbn/9j``;Rg_K>V
[;S3_ZRLTXR4R9ZSUgmmR85fNGmfJgQjLW=cLg1/IFE]M7anLgIlKF5IEF1fP79^
Lg9UBTmJGFecMVaUGe5AG6QNBd<g@Ta3@cL/:3=9B418DE9<@TQ1<Bm0C4aFBS8i
CD`d>5ILF4U3ASm5DeIOJFANI69SJVmfLFiaOGYZKgalOhA`GfV0Rh^8LFAVGfj7
SH1aNGaYG6MlNfQRL7b5PFIWNGQ`LWZ5S7a/MhR:Ngb:T9ZBNFmcQ8f>V:2JT8j;
QiR[Xhf>W9f`]9ZCX:RQSh:3UZn]V8ImLgnHX9j@NfidPH=jM6mbOG]bEca4FV5F
BEAOHFY/IfASIVa]I69UEdeFHfi/GEIJGFEXHV9SGUA@EfEUF5EGFE99C4]AGea7
<cmPK6=PHEYPI5iTLGMeKVMTLX>6SX9bPhf;QgUaNXB1N7Z9WJ2FRhBGYZ>]WhV;
TIfLUiZab;^][:6JVINL[<2o^[2Z^lNm[[W3[i>@YJ^LWYnQ/;Rj^/77`[>QUIjj
cLN^X:O0b[2QZ[kFdkVa]kBe]kJe/;:g`L2h_;Ra/KW1][2k]JbYXjZ]Y::WWHjK
ZjZY/ZjITIfXXiZLZJNIUYFN[ZRJSiV[ZZJLTYVWZJ2P/kfcZj^`YibMUXn@T96>
PWB4TH5cMX65R8J3OVaXLfMPJVi]GU5EET]FKGEhL61GFV9VI6AXG51PKVEPI6EV
J69OIV=GCCm9GFQ_GeAKJg]`K7EbK5eGGEIFJ6iWIEmNJg9]HeiWMG=UGEiYLGAa
LWYbJgZ4OgekMGQoOWQcKfi/MHR;MfmmOGQhPi2?UIF6RYbQVHJ1RY6GVZ>]Z91j
QYbTWiRNX9bDT9:>R8R?ShV5QHj7Oh^?TIBBQW1VKh>@UXmiKfifPHMnLGN5RhV7
QX>8Shj:PWb2SXn7P71ZPHn4JeEKKGU_GEYMI6iaGU1GHVEQG5YRK6]]MG1[L7=b
LFeVIVeYH5YOJF5AC5QPGE]MGV1YKFAKFVQgMG9]KWj0MVQFCEEUKFeXI6Y_Lgb2
Of]MJGn:P71VH5mNIG1eO89mMW=]KGZ7S8=bKWV;UYR>OGf9RWeeO7inPXN5OWj9
VJ6QViRMWIVGUYF<QHjRYYRBSi>SX9:DV9>>TijVX9RGVY^DUYF6QY>LWYN?TIjZ
YiZNZjn`Zi^KZ:jc_/:j[Z6JYJ^/]kF`/JJGU9jMRhNJXYFEXZNHP7V4U9ZCSiFH
TXj9RHMnOGb1R85mP8>8ShmlKFaiRHYhKWZ6RHMlJeePLX1oKV5YLVmVGVV0PgI^
JFI/N7UZHFI[JVMQEe]THVAWGUMLJW5XGEaVIV=WI65SL7AYIf5XOGmkNFmVIgEl
NH>:PX26Qh=mLG:7UY28SI^JSH^>SYFIVIZIWYbM[:^LVj2SW8^8RI2VZYIoPYJD
QG]cLWb5Ph>BUY:OYIF9UInMVXb3SIFMY:6IUYZNUHAnRYjNU9JS/:nVWYZNV8n>
RWecNXNASHR5NGEkO823MfacOHB8QH22NVmiR96AShf7PXF8OgYlP8R6O7f5RX^9
R8EiLX:ETh5dMX:3Oh:4QXF1Oh6?VY>7Qhb<RX^CUYB@SHZ0MW5iRXn2LFmaN89m
O824OW9mPGIcLG=fNXB1LgB4RhB1OWAdNgaoPWmiNhZDRh22S8b1NGIkR9FKTHB2
R89hM6a[MhJEUi6ATi:?Q7IdNhN:RXfAUI>GWIbDRX:6T8j@VZ>g`K6HRXVBXZVO
RXFHZZVKUibERY2RZjnST8N7SiB?Q7b6PWAjQ8F0OWimPhMnLW1hR8f4P81oP8V=
Og9eQ8n2JV1OGUmNI6e^IEmQHF=WJFeaLG1_LG9^J6EWJ6IWJ61LGf=VI5iJF5iV
IVETJFaQG6U_K6AGDEATLFMQJViZIfEXJVQZJ5mKHV=OIVYXLG]lN75[LWYgLfaW
JficMF]QIW=fMgZ5SHMnMW=fLfm/K71`KVaXI5iPKW1PE5ILHFEWIfa^IEiRJFi]
M7j0QHbFVHQlOH24RXn<Ph>:RhbDVYVNX9N4Mgb5Qh5kOh=mN7MkPhV=S8F5QHJ9
RXb<SiVEQHFAUXb8T8f5QXb?TYZLTh^?VYbHT96PZZFRY::KVIfQYjVVY:>SYJ:Q
XINCVYjQYZJTXIbOX9^IVZ6UXijFU9FIW9F;SiRIUYFGWZ>NUY>DTX^9S8b6P7eh
MgMkQXIlP92BRHV?RWikOh1jL6mjQ8bCTXf5P7iiM79gO7IcMgQgLFibMWEeNGej
L6MYLGEjN6m[IFQcMGV3RiFIU8b8SIJET8j9QHJ7QhJ8QGimPXN4OGUnQH^AUIJE
ShZ;RXF0P8B6RHnCTXj@UIBASi6CS8B4QXF;TXj6PhV;R8Z<SI6EVYNDV9:>TYNH
Ti>IVINHW9fIThb<SHJ2QHJ<SHV8QhN3Og]kQY2BRWilO7UgLFeaN7]iNGYjPhb7
OWYkO865P7b9TXUhKG1fNWn1PH5lMg9]MXNATXIkNGf3PGmlMWIkNgUkOGYhMW=a
L6m^K6IQHfUXGeMHGeiIFFIgN6iYK6eaLVYXKgQjN7AcN75QGfA/M7MgLFYYKWIi
MW=_LGMdL79fNGekMWAdMWYjNGalOGmkNG^1Q89nNG^3S8j@U92;SYJFTi:9PhV?
ShfDW9bFTY2CWZFRWY^JW9fKViVLX:>SWYRFVYZJX:BUXj>UYj:IUYVKX:6GT9VW
Z9bDUIJIUiFKXZFPUXb<RhZATH^9R8V<RhR4PhB4Ph9oOXJ>RX20S9NHTXMoOh60
PH>5RH^7Q7meL71[K6i_MgekNGEbLFe[K6]WHf=[LGAgM6eTGfE`NWj0Q89mNgUj
MgAgN7QlOh1oOWQfNhB9Q7miN7f2QXJ6RHR3Oh23PGinOgn2PgYcLgUkOHB4Q8F1
O7b6SHV9R7mjOGmmNWj8SH^9PgYeMWYoPH:1P8:1OGf1PH27RHEnNWf1PG]fMgQf
M79gNgYhMWV1QHB1OgYcMGUhMWMmP85oN7IkPhN5PX21OWaoO7EeNgj0PWafNH:6
PGf2Q862P825Q7ahMgYoOWYjO7akMg=cMWYjMgUhLfi_M75/J6ETHV9QGE]KG5eG
EUeNG5eTKWIhMgMbLG9bLG9bLGElOGQhOGeiMG=cLF]_Mgj4PWelNG9bMWIeN7]m
O7A_LWMfLG=gMgMkPHF4OgQgMWUkNWYlP8B5QHF8S8b;RXV8S96@TYFAS8Z<UIfQ
Yjf[XiZFUYF?SI:MXY^EV9jRXIfHV9bRYjBNUY2DWJ2MWYnIUIVOXjBQWI^LX:>V
X9NCSXZ;T9BGTi>FTi2>TYJET8fBViJ>S8jBV9ZHUIFCSXnCSh^8QXZAUYVJVYJ=
QXB7RHV:R8N:SHf;RHR>THnDVINDTiVOW9JDTI6EV9JDTH^5P86:RH1nP8:3PhB6
RHN5R8f;QhF5QXB5S8f<SY2>R8J8S8f5OX:;RGmgNX:2OGUcLG=eM7ImQHV9QH5k
MGElQ8Z;QWegMg^0Ph5mO7imO7j0OWYiO7UbLWAeLfm_LWA_JW9jN7A_J6IZKg5]
J6Y`MgUiNGUjOX>3OgUiOWikNWUkNWUlNWMiOXJ8PWimOgn1RX^4P820PX9oP8>0
OGinNGIeLViYJG=jNWI^J6U_LgEdM7MeKfibLW5dNGanPH60P81lMG9aLG=dLVi_
LW9^KFe]LG9_KVi^Kg9kP7ikN7EdMg]hLG9eMgUkN75^MGQaKW5bM7MjNgamO7al
N7MiNGE^KgMnQ89iMGMmQHZ<Rh>1QXF2Q8R;SHn?SXb;RXZ<SXn@Shj;RHJ5Ri6B
T9NQXIjLVYRGUYJEUiF?SY2CUiREU9NIV9FDU9B@RhR:TIBCUIJFUi^PXjBSXYnO
XZJYZjZYZJRVYJFSWibLWibFT8fAUY^LV9>ASXV5Q8>4QHN6QHN9Qh5nPXF6RH^>
TY>DU9:AT8f;R8^DV9JBSHV8QhF3QHZ=ShZ7S8b9R8=nOH24QH1mP8:4PGemP8>2
OWMbLgIlPX>3Q8F6Q85mO7ajN7MkOWn0OGIcLgAcLgEdLg5`MG]lNWQdKfi_KFYZ
JfYYIfESIFQZJf]WIFMZKVaYJV]/K6][JFIXKVm]Jfa]K79lO7E`L7EgM71_Kfm]
KW1aLWEhMgUmNWEbKVigOh1nMgAfM79cL71bLWEfMWEfN7IbLWIhLg1bLW1_K6a_
Lg5ZHeiLGF9SHFE]MWQcKFQVJ6idMWA`KVa`MWUhMG5^Jf]_LgAcMGf5R8J4QHF1
NgE`LGIiMW5_MGenNgQcKg1aLG9dM7AeMWQjO7]lO7anPHN;SHj>SHf>T9:DUiRI
VifLW9jPXJ6TYZFPW9RGVIZJVibLW9bPXjBTYZFQW9ZJVi^JVIVHUYNKWinNXJJX
YjFVZJb][JZXYj>NWJ2OViRDTI:CUIRJV9B@TIBDU9JHV9NIVYZGU9>DUYRJViRC
T9:FUY:=RXR8S8n>TYBASHb:RH^;Rhf<S8f=T9:BUIVFUYRHUIFHVYF?RhN5QXB4
QXR9RX^:RHb?T8j:QhN9S92@S8Z<Shn?SXnCU92:QHB7Rhf;Rhb:QH1mO7alOH65
RHIoO7YiN7MeMGIgMWEhNWYlOW]fLgMmP7eiN7]iMW9`L71_KVeZJfeZI65TIfU[
JFETIVEQGUmMFUaOH65TIFEWJ6U/JVMVIVEWJVe]JFQ[JfUYJV]^LWEeMGQhMgAb
LG9cL6QTI6I[L7MjMW=`KFYYJFY/KVeZJ6ESI6Y]K6][K6e`Lg9dN7YjN7EeMgIc
LWQnO7QiNgYlOgagLg9fN7MhNgn5RHb@Shj?ShjAT8Z6RHj?SHf?Shb:Rhf?T8f;
Rhb@Ti:CTXj>SXb8R8fDTi6@T96EWJ>TXInPXJ6RXZ2MWInRXIfKVY^NXJ2NVYB;
QXJ7SI>CTYBHVY^LViZLXJJTWYZHVIZKVIJBT92CUIFFU96=RHN4Q8N8RX^:RHR7
QhF6Rhf;QhV;QHF6RHZ:S8f;QhB2PH:6R8J3PhJ8QH:4QXB3P7inOWmkNWakNGIe
N7akNWQiNgenOh>6Q8:2QHN6QH>2PhB8Pgn0PX1mO825QhN5QXB2QHB2QHR:RHV8
QHB1OG]kNg]iN7UfLg1bN7]iMW=aLW=bLW=eNWemNWYmOGf0P7ejNGYiNG]kN7=`
L71_Kg9cLgAgN7MeMG=_K6UYKW9cLW5`KFi`KfaZJVYZJ6EUJF]/KVi^KVi[JVe`
L6e^Kg9bKf]/LGIiNgQfMWQiN7QhN7UkOWilN7IgMWAaKVe^LWIgLfeZKG5fN7Qg
NWalNWQeMGMiNWUgMGAdMgQiNgalOX64PgmjMgYjN7UmOh64QXF4QXF3OGUgNX>7
QhV@Ui^KV9:>Si>EUiFCUIBASXf<SI6EU92>RXN:SXn=RHJ5QXV;S8V8SIBIW9^K
VYZLW9ZGUYZOXjJWY:FXZ:FSY:FTWi^KW9ZGUIFHWJ6TXj>XZ:BQWifLV9NFTi6>
RhbAVIbLVIRKXJ6OWIZHUINJViZJVYZJUY:AShf=SHj=SH^8RHZ;SHb;SYBHV9B?
RXN8RHR5QHB1PHB7QhN8RHV7Q85lNG]mOh61OWalO7emO7]lOX64Q8F7QXAoNgUg
M75cN7anO7QfMWMiO7ejNGamO7YhMWAfNWaiNGYkO7inOGaiN7QkNgUiMgEfN7Yj
NGUjNgYiMgMgMGEfMgAcLW9cMGEdM7=dMWMgNGUeLWAhNWMeMGMkOWahLg1_Kg5_
KF]/LG1]Jf]/KFibM7EaL79aKVa[K6m`L71`LgEfNGalNgQcKVibM7IfMGQjO7]k
OGinOGmoNgUlPHN3Nh62OgimOG]eMWYmPh>2P7]iNGIfM75_MWalPX5kN7UlOGUj
OGalPX1jOH:2P85mN7IdMVmZM7A^L7A`KG5cN7YkOH>=Shf5PHB7PG]lMgQkO865
QXZ:R8b9PGmlP8J9QGj1PH:3OWQhNWj1Q8Z?RXR9RY>FUiFEW9^JW9^OXj6OWijL
VY^OVibNWZ6GTI>HUI2IX:FZZJJOWYjNVIRHUYZKViNJXJJ[XYjJVYVAVIfKWIZH
UH^:RH>5RhR8T96BTIRJUINFUI>DV9RIVIfERX^<RHB1NGj2Oh61QHJ8RXF4PH5n
NgUgMgElMW1jNWAcLVecOGIkOgn1Ph5dLW5`Lg=bLG5gNgYcLVe^LgMcKgEgO8J3
OGQhOX:4O7anPhEmM7=dKg9bK75bL6]SKh21Nh20N7YoOgamPXN9PGYlNg^5Qgf4
QX:2O7V1RXV2OgimOgeoPh24SXR3PWYjO820OGekPX^=R861R9:@QH:0QH^4N7Qk
O8MmLh64P7ieMh>5QH>1PgilOh>7QXN9QhJ3PWf1Q867QhV9QX=oPX5lOGMcLg1c
MFejPgemN6eZMGmmNGAeNX29PgeoP8F3NfeTJg^7P7MbNHIkKVeYJ6UTI69RJFEU
KWA_HfUcMW=jRX1jQh65RGilNWYaLGUiNH:8SXUoOg]mM6icL79oO6m[MX24OGYg
MWn6QH>2P8fKTXN9QHfHW9nERYFIShjAUi>9Rh>2SHj<QI:ER8^DV9JFVYRGUH^9
S92@TiZFTiN>RHn@V9NEU8V<THjFVIJLYZ2DRhR>Shb8P8NETY::PHB@VI66P8NA
U9Z@PXb@S8^8QGn3QGYhP8b9Q8nFTHV<UINJVYBBSh=lOX>4QXZ6PhAmNWUnRXb=
S7ioPW]dN7QgPX^7M6]gPH>1MWAkQHZ5PH61QXn:N7UmNhF6O7aoQHf;RHB;T8Z3
OhJ1Oh:9R8:2Q8J8Qh>8RXV:QXR3PHR9R8F5PWanQXbEVXmnP7ieMgAdMhBARW]e
Mgn7Q7ifNhR:PWUiOhN3N7amNXF<PWYfNGaiLVUZM7e^HfUbLfedOgijM6ijQX5n
OhR5O81jMG^4RXJ6P71`NGj2RhQnOgmgLg=_Jg23S81aK75jOGYcLgb3OgM^KGR0
O7meKGUlNgQiOG]mPh=kLh22LV]aO7EbM7amNVi`NWUbJ79dJfYcMFmjQX:0QGa/
JFe^OHZ8Qh1jOH9oLfmoSXQiIV5]OWefM7UkNh1kMgf1Qi><PH:9S8B1Q8R;TiR?
SI:BSXJ4Ph20RIJGRGn2QXf;OX>;Qh28ShB3Ri6CV9^BT8^>V9bISXZ9Ph6=SWin
Tj>OTh=lQ8R6PHJ8Q8^@R8J3OhB>SWmnRY24PXF4Rhf3O7n:SWigNh5lNH6AThF1
QHn?QXB=U8R1Qh^0N8>8S8f6O71`M7Z0OGn8Qh>:SH9gNhjHUHAkOhR=Q7j3QHF>
T8n<RHVFXY^AUIj@QhR:TZ6VVIFNXiR<S8f:QX><UY>;QHV>T8fCVY>@SY:=PH2:
W:2NVXj9T9VNXj6MSh9mPhQoM7Z7ThmoLW=oP7]lO7UnQH5jMWElQ8j6O8:1P823
QHR;O6MULGE_Kg1]JFI]NH=iKg5iM6AXLgYfKG1hOG]fNH:6R8EgJfaeP863P7Ed
NGUaHeUSNh9iKfi_KfmcMg=_KW9bK6ifOh=fJfifNGQhLVmbM6m[N8B1N7MjLFMT
K7AdKFMfOgQcM7UeKg9cMWI^K7AkOhN8OVmYLGJ4TI2:P820NF]XN8R=R7mdKFQZ
JVQ/Kg^8QWQ/M861P7enPHB4OH28UiV>R8R9Q8ZEUhj8QXNATHZ;THb3OhV>R8F4
R8b:R9BW[jRTWiJMZJJQZJNHRX>6R8N4Qi:KWibIUXj:QhR<SI>HViR<UJJUVYFA
Rhf>S8V:RXR4Q92HSgn8U8^1NGf<U9:=UI^FTiZOV8f;Si>DS8J9SXb=THV4RHEo
Qi>DT8nBTXZ0NH2CUXR0NgZ1S969Q8N:THmjMHN?RHV9Qh^FV8MlPHN8QhN>THR7
Rhj5NWUhNGajNXF0K6EdPhF4PGn2OgQhO8:5RXAiMW=bMhNARGj0QX:0N7AoS8Ei
MWMbLWE/JFeaO8ImJFQcNWj2P7MgQ8J1RY:?S8N3MfURHFY/I5iSL7j1NGYjL6IS
JVaZKg=eLgAkPhN7OgE`KVm/IFMcNgMeN7MbJV5TMh9oP8=oN7f7R8B4Ri2;OgV2
RH^7PWASJG5/KG=cJfM`N7QfMWZ1NfiWJ6i[IV]dN7QgNGQ^I6I]Kfe[JVIWL7Ii
N7EfNGMhOgmlNWeoNW=aNXJ9R8Z8O79aKf9DG7>4QX5jNX63Q85lOGmkLG=lPH67
TI2:RHR:RXAmOXfDTIBLVi68Q8R>SHbDViF>TI:>SiBIW9ZKWjNd`<JmZIVBRged
MGf;WJng/JBKWj2ERiJRXInJVYjTZZFQW9ZJU96HX9fDUYbITHj=S8b7OhNFVIFL
XYfFVIfTXiZGWZ:KVijITYBHTXV4PWmoPXR?THf=THQjMGUnPHR9QWeeMhJ7MW9n
QX5lNWEeNgUcLWIjP85nQXn>Rhn>PWamPHZCSHB:ShZ7Si25MVa[KW5^M827R8Z9
N6egQHJ4OgQiPhb?Sh=gNH5mKf]^Mh>@UHn4NWn1LF1UO8F1PGafNX1iM7UmOWel
P8jHVY^LThAnNGQiM6QSLWj2RHn6MG1_KVa[JVigMWJ2PWIcOGmjMFaPHFUdOX1i
L79bJF=RGf1/O89iK6M^LVYVLWmoOWegMWn2OGUgLF]XHUmQJG5jP7eeL7R0PgYa
LgUdJVe`J5mUKFeaLVmcMg=dMfaIF6E[K6e/JW9nQHN3MF]`M79bNGMdPI:ESHAm
MfeSHW1iMWAaL7EiMW9dNGMdMWEiPXR5P8B3NgV6TI6;Q8J<S8jETh9fN7b0QH^@
TYJHVYR?QHB=U9^RXj2U/[c2`;F[YIb>Rhf7RIj]ZJ>SWiJ?S8fDViZASiBKX9^A
UIbLViR@RiJPWYnSVHV8SHj<RHR7QX:6TI>=SIBDTYZPWIRNZ:b/X9JGWj6NVhn7
Ri>FU9:?TI29QY2DSY6IUHR4QGmhMgMlR96;QH9lOGeeJfaeNX66Q8NDV9BFU89d
N7n3Ri6<QXJ;UYfEPgemMgJ1QGYeNX68S8EkOGmoQXZ2NH29RHJ0N7IiMWAdLG9o
S8b5PG]bJfMNI7V3O79[JFiaJEiOHfM`MGImSI6@UI>8P85mMgYoNW=bLWIiLFY^
LFMVLG5ZJW9bMGM^JFifNX:1LFAWKW1dM6eVGeaMH5mNI6e]KgUkMG9WGFMjPgik
O7b3RHF4Rhf9QX5jMg=[KgamLVicMG^9Rh1fMGUjM6EUKfm/M85nMWQiMGA`I5mU
IfY_KfU/NGahMgQbK6YXK75eN865PXN;QgidJ6EaPX9mNg]jOh1kNGalNWb3Ri2>
QhJ6P7^1QHB=WZ2BQhJ;TI:<Q85oQIRQVYBHVifMTXAlOh:9TY>BW:JRWZJ][:JP
V96BU9ZNWYnRYZFQVi>BWJRTWYnNVibMVi^SZ:>QXj6NWj>[ZjFOWIN?Ti^JSHN<
SY6CTiFDT96IWY^NXjFTYjZXZ:VZ[:ZMTYJITXjCThf=T8n;SYFHVI>9QXV:Q7eg
NhZEUHf9PgekNGAfOWegNh1oOH:7R8N2OW]jNX:@S7mnQ8F4Q81mNWQkOW]cLgYk
N7MaJ6I]M7McLGAiMVeZK6m_L6iXJVm_LGQlN7]nNW5XIF]hPX1lMfiWIF5JFUaH
EF1[KFmgO7b0Q8:0MW1jPgeeMg]hMW=cLgAcLgQfLgMkNg]iLFUXM7ajMWAfNWai
MgQeKV]XIFIZJFUYHfA_NgU^HUUKIg9dMGIdMGIhOXbCShj?R7YhOWalOWinNWV0
T9:5O7alMgAbLG9bLgIjNWUkOWikNgUeNX60N7=dMWMeLgYoOGUlNgQfLWEmQh^<
TYB=PgmnPHN7Q8:0OWioNgf0OgYmQ8:1QXV7PG]hMWAfQIFHT8^=SH^7PX5oP8B<
Ti>@TYFFVIF:P865PGj0QXf@ShnIXJ>TXZ6PWYfLWIRDVj^`XiJ>SY>GUiNJWj>M
THZ?VYnQXYfFUYnUYJNZYiZ?TI^SWHj4PhJ6R8^:QXB3Q8B4R8jBV9jLUIRU[JfY
XiZFU96GVYZGTY6@T8f;RXV7QI2KV8]mMWMnQh^8Ph5oOG]lOgekO7ihLgJ0QX>0
PX5nOH>;S8InO7imO820O7YlPXJ7PgUbLgf5PgYfN7UmPX60OGQdM7IeKfibMgId
LgAbKG1lQX9eJVU]M7]kNW]nNG5ZI61KFV1VIV5QIFM[MG]dJ6I`OXEoMG=eMG=d
Lfm/KF]XIfU/LWZ0P7YdM75`LW=dLFm`MH6<Rh1fLFe[JVa[I65YN8F7OG=ZIFU^
L71aLG5eNh24RY6GVYF>RhR1OXJ:Q7YhPY:GRgaeLgAkPh1fLW=fNh:2Ogj1QH>0
PH20PXB5PGahMGIkPH>7RXV3OH26Q7elQIFMV8j7QhnHUi:=QX5mPHJ7QXF7SHn<
Rh^7PhVBTXUoOXNAThf9RXV7R8V6Q8N7S9BHUI2CW:6SWiF<QhJ9RhR4PH:8SY>F
UiJ?R8VDW9bFTIBOZ:JMT8R8RXnDV9RFUiVIUY6>Si6?SY6CSi6LYJFIRXJ?V9N>
Q7agNXF9RHN3NgIgMFm^Mh24QhV<TIBHWIjKThZ5QHZAU9FET8^:RhMlMGAmRY>C
RGmhMgb0Q89mMW=hNgYiNWelN7QjMfm]MGakLfifPXN5OgeiMgUjNgb0OWf4S8f7
QHB0Oh21PGikNWb2Q89oO7MdM7V0P7EYJW1cLVi/L7^0NG1YIf]aMGMiN7QmOgQ_
JVUWHf=VJ6=MH6afN75]L7QoPXF1N7=gOX>6Q7ihNGMaLg^3QhV;RHR6PG]kNGIf
MWUmPHB8SX]oMWIgLfeWIW5oQhV4Ng1/KG1dLfaWJW5fOHJ:QhF7SHj:R8^BThb3
Ph^BUIJBRX1mOX24QhN0O7inOH26QXJ9RXR6QXB6RXZ7Ph5lMW5dPH^8Ogj4QhJ0
N7Z5TIFETXj=SY2DUY>=RXZ6PHB;SXb<Si2>R8:4SI6<RHf@TI6@SXV8RHV5PX:1
Q8Z<R8J;T9:CUI>BT8V2Oh1nOH21OgYiPXjBR7inQHf?S8R;UYjRWiN;PH25Rhf;
Rhj?RXN;ShZ3OgioOWf3T9RAQhB9Rh^=RX=lN7UjP8J7Q81kLfa[Kg1bMgaoPXJ;
T9>BSHb?TXj5PHZEUY2:RXb7OG=aN7n3QXF1O7YlO7]hMgYlNWEfOGmlNWn6QWme
MG]mN7AiO7j2QXB1OWelOWmmO8>;S8J2PX62PH:3QXJ3PXB6QX5nOGiiLgN0QXJ2
P821OGIfNWeoP860O7QhNWinP8>7RHF0Oh5nNGIfNGI]Jg=mNViYJfibNX64PX1o
OGn1PH:6QX1jMWMkP8>8SHj8QhV<SX^4Oh61OWj6Si6=QhB8QWidLGAkQ8Z;R8Am
N7MfLg1bM79^KWJ0QXN9TIB@RHR@UI>@T92>Si>FThn9PWj1PGf1QhR3OgekNgYj
OH62P7moP8B4PH:4OgMgO860O7IgO7aeKF]^MGj4R8R5PhF;RXJ6QhN3OgimPXB4
R8j>Q7ioQHN2OWj0PhZCV9J?Qh62PWejO7moOh61QHV<SiBGT8Z7QXR8QX>3Q7ie
LWEiNWIbMWj2PH1oOhF=TiBBS8>0PX>5Rhn<R8J7Rhf;R8^AT8N1Q8Z?TY6>RXJ6
S8n=R7mmPHB5Q8J3OWYhMG1[IVUbMgQhMgZ0QXR:SY2:QXN;SHj>SXj>RhF2PGin
PHB8Qh>1P85nP85mNWMeLWAeLg=mQhJ1O7n0N7YkNGQgO7j1PGahNGenP8B6Qh:1
PXB8RXb:Rhf=RhZ<Shn=SI2:P7]mPXR8PGn4RHV7QWmkNgn2PGmjN7IgOXN>S8V6
PhJ8Q7]mRXn6OgmnOWakNGAaL7J3RH^8QhZ5PX65R8R8QX>2QHV>TiNGTY2ATHj;
SI>IV927QHZ>SXj:QH22P7egNH6:THn<RX5jNWemP7mgLG5gN7EcMG^1Q8J9QWn1
QXZ=RHF5R8R3OgilO7QfMWEhN7EdMWAaL7=iNWAaLgEcL71fO7I`KW=jNgIbL6e]
KFe[IVU]KgIjOh1jLG1eO81lNGA`M7=`MXB?SXJ4QXEoPXF1NWEiP8F;SXn?QW]`
KWEiMg9aN7UjPhV<TXf4Qhn@Rh^<SHn<Q7alPX5nOgQgO85oO7j2QXbBTI:?QX:8
SXnAU8n<THn8PXF?THb>UYN@SI:DS8J6Qh^@ShZ;Si>FTXf<Si6ASXJ3QHB3PX9l
OXV9PWmiN8B=ShR3QXR:TiJBT8b;S8N6R8j?RXj>QhJ5OgUnQhEoOX=nLg5hPhIo
O7b2S92@RhR8PGj2PX:2QhIoO7n0OWj2Ogn2QXIlPhb:QhN5RH^<T96<S8R6PXF7
Ri>CTYBHVYRIShb?S8Z<RhV;QX26TINCSHV8Q8>:TiF?TY:AU8nDUI6BPGZ4RhZ6
Q8V@TX]oMGMmPXElMgeoR8b=S8R8TiB:PGR1RXR=Rh>3Ng5cN85iLFmUIWEhLgAm
RX^3NgQnNfaYKWEiO6YEGVa/FUm`MGUcM7UlMVeiP7mdM7IfNW9aLVY_OGa_IVE[
IfY]IVM]K6IPJVe^K5EFNgEIGgB3OVm/MG1[I6QRF5]^NgajHVegM6m^N7acLG9V
IfIZRYJ?QVijTXIfOHJ0QIjIOXVERHjOUGedQ81fOGf0O89kOHB3QXNCVi28S92K
VHb<RHZ3PHN5QhB2PWijQ8IhT9B9OWb5S8b8Q8B<UjBPRHF@T9^IU9FGUiZHVIZ:
S8b=WiIkQY:<RhQkPiNSWI28OIFSRX2?SHNCUiJ<PIB@TYjCR82=YYinQIj[ZYVB
RHVNVHn=UjR/VX:3SY>@UYN5NhR:OHfEOfekTI>7O7UnS9NSX9>@ShF0QXb7QGej
PI6CPGYiNhF;Q7B3UHj;PWJ7UHn4QXajKW9jQ9BFRXAnNX^ATH]nPGM`M7IdGemg
NW1[HfATM9BLP6]nP8N>OEaYRGZ3VXQVHG1mQ7i`EV:5NF]`H6=/OHQkMVi[M7]e
PiZ=NfmTJ8JFV7iTJX2CK6YeG6APIVMAHgb?U7n1Wi=aMH5kMgUbOh5bNG1bPXMo
OWAVN8nCQhZ?QHb@S9:DUH^0Ngb9UIjCNW]jM7b4U7i]O7]UF6j:QX1jQ7mdLH>A
R8bKRgj<UYRCOFU/QJ2IQgM_PYRST7>6TWejS9ijMHjBVWUOO8ZDSVi^Pi^OIUj8
QY^KQh=]NHYX>GFJJ725RXIBAY22J:6QOfimUiJ6LhigLH9XP:2:MGIdG7AiH82R
OFmcIh:OTWMfRGE]VZVXV96IUI:8TkVgS8J@Ri:R[iR3UJ2MZ9^8Q8bI^K:R[YF2
R8V@Yj2<TI1VFHZMS7Q/Oi^2MJRSSI>WYiJM]j:2TJ^/Xi1]N;6OLW^8YiMoOV9P
LWE_Fg1cEdmJKH5mJFE`L6edPXIjKGn>R7mcQ8j0K6ehLFmlO7aiViEhP76>[IEh
JXR:FUUjQXZ5SYZANVebRj>>MH28NFa?EG1lOVUTKgN3ViJ=RIR_[GabPXVKNG6<
WZ6<TV=JNUaDEVf6LeQFDCiSP6a`KE5OUIAHF71jOhf6F6EfOGMmXJnHWYJ3UJ2?
PHBHV7]RLI6dXFN?]k:YTI2>R8N?S8enNJFQNW9WOIBN[YEjSI:H_ZR=X9b;SWj:
`jYdNiRQYh=XII2JHfETADeQI69PPhEZJg5dSG]BR7U=O9]mEE9mP6]jI5YXK7J9
TFYVKFZ=Q8YhDUiDXMBMSJ:<JFabIf=/N71JIfE>K7]oNgAdL5ION4a>H51MG4Y8
G92EOIAgNYUnJ6abMiRYP5]MFh5f>DedNV/kEhidHGN@RgYZRJV4MZ^YQXjfhKMo
WKelOKng[giXWkRnbk^OR:W0bK2;^LB3VM?3_i9WTJZUShbIQ9Rk^J><MWjXUG:8
^Z]hOJ>__m3:a;FnZ9>W[JJUWjF_SF>2YIQlHgUR<Bi6M8Q^FDYMHfZ:PVAGKIMg
O:F0PI24V9McKWYbSh]UQXahSZ6LYX2FZG>RZh^<P8^SZIk0_j75[I[3[9VNR8JD
WheWJWj5L51YMhF5FfnGSG2;U9>HHU]lNXI_F8JHRH1^GdA4IEIEKG9/Jg=>>FAi
M65SJUA@LHF7MhfSSf=>HhN5JXN=GF6<NfibQgDn@7=mL6]>GFekVGQ[HEb@Y8Z>
NfajTZnINX>9KGB;O6MWRieoIY:;LXV8MhV9Mh:7RiBY[iN<QIFKXXHm=FR<MUmK
BG67MH6:TgeSMHFEOWJ1IgBCQ6iIDH2BMf5HL7nMX8R0L81nHW>@Rgm/LgUWM8]d
HWadNiUkEFJ?THJ;W8:3RFAZK5aNI6E8CGaiIfj8X7eZQIB0OY:Z^i>Ec^76RVjA
UFUVJG:1N6m^P85IB5M<D75T>cI=DWRYZ7QPV[BPWjZ[OWc0f]2`RYJZ]:^>Vij9
WJVc^kC0`[fd^lO6ZiRcf/g8bJ>H[ZVLUYVJT8:9Shf=VIZX[J6ZU7F3[m6nVIVU
/<o<]iYeSWmXQY=jHG>>LE=QK5]ZJW6:QHJ5OXbN]kMiJ9^TRGeYGW=[L6ECNgQE
G5mXNTT`AUUPLGANB4N7PEUPL7miTYiaM8f6L5MIIfELD4aSPYNBMgR7PHRYV8>;
RYNTOfMcNY2=W:Y`Ae]PFWJ7MDm:DfZ=QVYAEG6<ReLnKjV:E7B>KEi/QGijRiFJ
PGBAW:>ARhQVJWinL5E?Mhf>UGmgRIJFPWN;Q7Z7XJF9KVMfM5=?IVUXDEZ2T8Yb
Q9QjOHbQVg=hV;W;g_7Ea/jXRI:=JDAKEEA@?eUTET0^A5YDEci0HG^6XJB@R8:A
MfEnOFESMG>Q[X]jKG5`KJ6nU6^3f^F_WKCCf^S>^:F=[:RRZ9n@SXf8OhIoKFU/
P7fL/7igUiVE/;F<Ig>>X8EfQ7iaNHnUXF99H7n6QI2FPfR2[kBSPWEnOh>4KeiL
IW5`JfajMgJ7SGMaOhB<Y:BKSh=bMi>HKceEHEJ3Uh5^IWQeLY:>MfY^TY^JYHAL
LHj9LFefJ4Q0M9^=OgIjI7JNXHYlRYF9Pi2N]IbDX7]WJ7J:M5f2/j67QVikS862
GG29UI^RTgbDVHNJ[j=oFWRPV8J<V91iRiIaJX5aGgZIRVMaQWV;UgMSHEeYJEUb
VJ:@T:2:Phj<NTm=QJ^YbMRd]>?^gKn9HVZ2LFU`CU=F@EEKOG52>UaO?4E^M5YT
Ke91KgmX?`P>>4eFFfYkMgR3X9:L/l2iYl7A`k^ocMoWe;6UWIbNSH^]_lJbZ][/
b:Ba`:^U^;nOWZ:X[7=<O9YmIEj0Lf^N_L^NSIF9S9FVSfacPWnBXk>`RYNaTWb3
N7J9PX6EW8J1Tj9oDdiNHUMGJVmLDVn7IDQ=GEXi>4e/GEIfKVAOH5MGH4e_SG5]
GdQKQ9EiHf5WJemMFEYmQFaTO8MXFV5LIh:1C4=RL5iJI7]W?TADLhahGeEcRhjH
NVJ;U7acKfUlPVYKCVf:NGF3PX9KEGn5LVUEH6]UNhafHV^D[YJJVHnGWZRfYin<
MWF;X:FBO8>E[LW7a>ChfmGDbIi_HE53GXj7MGQ/F6icLWI_G621N6YM?3IWOGES
F5]4DFQhU[:PS;W>]ib8TK2]WI2>UH=gWIZEXlKBZJO<b;k1];gDcL2aUIJZVi^]
[jbMZ:JS/kZaZ[C7]8ajSY^<RHnEQ7b=W:FIXZ>L^M31YIF<X[:QS92=MHFFU8j8
P7Z<UhUaN8YaFGa_DUQJIdi4BV5XFee>CUU9DUPb7cIIHCl_?3dnC4i0?TmKJfEI
Ff5kQHB6IDe_T9ImN7IdM6U]NWQXE65bLIF[QTa<Qjb_TXb5R:bOUhijJ6adO8Yj
KX>EXif9Ti20SHJ:WH9XMIBCO760ThQhPh5nQg^?VHj:XZIdGFYTDeieLG1[KYnh
[9n>Uj:T`lJ[XYJ;NVe]GDeJMXfMVX9SHWR>TGQE?c0aCE17I75VJGQjLi:d[7A^
LgfDRG=WH6MkO8IkMX^AS8ZGXIBH^kb_TIB/V9JZ]J:[b:V>WJR:QYbX/k6;NZ:_
RgF;UY9oMh:EXYNAShNGXkNiWZ>`/kRg_<c7^9V[cK2Uaj>6UIfPT7UjRIFebK6?
P7n4PXf<Kf]bFFEgFeQZGf9UJG=WBTI?CU]dFd5EL7j7NVISOXUZKG1IDEIfSWYH
GfE7?VE^@D=/KEEMI6UXJ5QQMGZ3MGZ<Q82FNUmnO6E`NhN9MG9aMYjNRWQULh9c
O7YDKiJDO8>SSViiTHalO9:IMW28Pg5_MX6@OVQ[LTm8IGU_LiBES9Bde]2bZZ67
Bc<f>EUVJ86UVgEFCUI9Ae0]4R8`7bYMHeICI7EgNGabIfYjRWifP75VPh9lSI>;
W/g=YI>ASif/ZZRc_m3<b^[dj=Voa[n/[Zj`]ZnX_=3NfK[Be:B^c[VHX[Bf/:VU
WHjD]MBjZKFi_l2m/[>MPWjBVYZTYIJCXZVZUhV3PHQnN8F1P8f@RWY_R8elOFmI
J7=FEUIHL7QOBeaMGDUAJUAMLg5_He]`GDYRJV=JI6YRGVMZIUQDDeYTDD51CUaH
FEeONgiPFG26WIYiF4acRWAfNW9/K7n;PfQTNgIdP7=DBF1cIeYZOGY_MGMjOXZ<
UXj9TIZKT8jCT89mS:NMO762N5eJMi6?T7Z2[9J@[ZRFVYJ5QGUiLeaQL8BBQWIU
FEMQGUQYLWj1LWR7Uib?MFAhQZ:RN6IlXJ26NV]PGVUaQ7]_N7QbMWN<V8YnN7Un
RYj_/9nLWYF>OhBEViNBT:2_YJ>Y^KJYUgb5WJ>UVYfUXK:dXYjOYl3@^ZBZ]KJ_
]J^WYYFW^:FMTY2ASiRIXjj[VXjU[JR]X9FXYY>BS8bERViFK8A]DFA`JVmYE4Q5
D5MCDfE]JF=6>51_RW=8CFA]GeeXHFIYJ6EQI6]WE4Y?CT]RL6aUJG9lShQfL6iU
Eee]O7m`KgZ<VGiKGgB0NWIaJG25QhEnM7^4OF]PJh^HWZRWWINDTX>1QGmhOHnQ
X9YmK8:=QH=jLXbIWYf>WKF^YYj:V9AdN92QSh>:R7miPWYoPFEDE6N>Tgf1SI:8
M7EoNVUUM82DTfAHGGFGOfAREeEHGV=PJ6mZKFeUJG9hRINMU8b@XjfBPHNDWXj7
U9F=Rif]Vh2>TXZDXi1`MY2QYI^=Oh6H]lZnYibU_lg=/ibL[/S3_[^ZXIN<XkVa
UXFM]l[6]JV_]KBm/i:=VifCVZBSRG=_LWMUH6I^FUmnOFISKWYoI61HD5EWOWQM
GHAlGTTlEUm@E6MbGDe:D4aINElc;dAQK6MiQgETNI:1FU=WE5=cQ8=iOHN8OGb7
S7QYIf]eLh29Oh22PH9fIG:2SINQX9B7S8imOXJ9TGeQK7f3PgAiOFebP8VCUiZT
W8jGWiJ@UiZJUI27RYV@NWakGdaLN7ITIFMSEEQdNEmGE5eRIFILFV^0P7UdL69I
LGb4T8ioHUANJWb2KF9_NX6<WK2UTIb]YIFBU8n9XKVe/J5hPJNbYi^<RI:Q/J^Y
[9bMYj>EUiRAT9jncLnmZJbc[JR/Th>U`KBY/:^QWI^HQH2>Q8JIWJV/Y:6DU9:0
MhEnPIVHRGIdPHZ0NWASFVR4S7UNI7QnRh=YI6I^K6Y`LVeRGFYeKFEPDT]MFeMA
B49:CD93DeY4@5MPI6eWJGAXH7:0LFEfNG23R6]RP9F4J71iM85lGVIdMgY[JGIb
NHYjM8nTWHJ;WjZh/IZ;UJZSXJF:M8JASYROWY:6SifIVJVZW8V9V9>:SY:DV8b0
PWA_Ogi]FU9NGEaNJgMbKFibJEYVNWeZHFUQJH^DOWAcMgaaMHZ@UGaeTHIbNGij
N7bAUWb://6cWYjVXYVDW9J6W;_3YYnabLN[UHnM//6k]J>GZ;Ve[J:ITX6E^kfb
[Z^^`;bc]:jQX9jDWJ>SW8^ESWZ0QHjQU7n3UHn>Si27QIBGRgV9S7UgJ5afMEQ3
?De=@UAE?cLfAU=EDSd^AEmOB3mDG5=?Cei_H5QTIFYhJeE>AeQ/IeA>GgmkE5f2
T8b0MfmkRHRAUhiiLHB8O8Z;MWalJGUnPhQgKfQ[NgY^J6YXNGZ4QWN=VHUnPh^5
NWZ6TYFKVHeiJVb2RGamQhN5Qi2VZYZ5NX25O8NEQ7EoTYnQS7MiM6n0R6aGHgIj
PHMnPge]J6eoPWE[N8ElKfU/Nhj;NVm_NXf;QXJ6P6YGGH2UYi22OXbMX9fQX9ZP
^;V`ZiZKZjbb^[BXZ:VIVZN/Xi^>Phn<W:bQRgf:UjZXSHnf_kW9aKJRX;Ji];BR
Ui:GW9nOV9:CY:FOYZBNU9BMYhedPZBfVWM`PiAoGf5`G5a]FeANJFeC@eUdITe=
Ce1LGVEGBE5HGFYZI5Y9EgUnNFeDFem=HVaIEUaWLgAXHFinPWUYJfeZMh5lKFej
S8^GVW]^MXZJThjIVHn6M7=iQi:6N7F5SH9gRJ:GSJRZX9YlJG=nTif9NVMKH6j?
V8I`IFicM8:2Lg^EVhN4SHAWDEn=Wg]OGDmBJG]RBUM@DUUNJVQMDEMRIg=XEEAK
KWY`Mh64QY6KWiF<TiBDX:6CRX:@SXVKZ:6L[KBc[k;6eLjo_;fe]l>cZ;c7_KRU
VIf_[9nMV8j0QZNXSX^EUI>LZI5iT:6VUHNCWiJ3SIVLSX27PWEgQH1hNWn>SgMX
M8NBSXMkIEEOMH1gIVAjO6AZKei<C6e/G5YFFFM^J6YXH5UOMfeBGfYSGF5dNFIb
KEm/P7mkLVA/MWAPGfmeLWj<Mf5GNH]oQiFEN6N7WHUlNGb:UY^BMfmoR8Z6NGB4
P7MdJfQYNH=oPHRCRW1dVK2WThV:VYbJUHR;QHJ@QWmeQiIlNibSQ6UgX9bAUYB9
SZ2JThQ_OJ:LMV5[NGIbN6]>DF9YL7j5ME]GMXZ;NVM`PHF5TY=oLGnKVIRQU9JB
TJ2PUY6BUI>P^[BFTZ:WXJJg]jJMXk2`YZRWX:bfXiZL[;Bg/:NPY:ZSWJ>LTXn>
T96SVGf6S8jRZJJLQg^6Th]lOHEoO822PGa]KgagPHafGUieRi25MGZ0KfYXL7if
JFaWGEeQHU=8EF9TCRlbDU=AFde7DE]RF3dgBf5SJFMDE61VM7Q^M7MUIWZ:OfY_
O7AgO7QkJV^@WiZIV9><OY2/ZhehSJ6>PXb?T8J?UWe`OXR2Nh63LVacPX]iIW9l
OHJ8QY:>OGinMgf?SFi^LfmkRHn;P85oP81bJ6UaPY:@QWETGg63QHAnO89jMH1o
OhN8SX=_Jh>AQhB:TiBKWhUbJG6:VYNMYi>6VInQXYFJYifNYYB2T[6hZYV>R8J>
XjfMU9f/YijQVI^MR8nSYjFOUIROXjjaVH29U8J0PX27Pg^1R81cL6]YO96CS85n
PgmlPHAdLgedJWV1M8F8MG9]JFUNGW22QWEdNWQePhUjM7MjMFYWM75PHEaJIFEL
EU9JK6MHDUQTK6mcKUaNOXR2PWn:PgZ4P7j6Q7IoPg^3Q8nMVHAeLgIoQXZ2NgMj
Q8R8Ri6@QX66O75oRhj?R8FNZ9b:MGV1Lg=lL79eK6ASN8]oKX6;QGigN7elLGQn
Lf]VIGA]Ki2CRWaQEV5bRXmkN7UlQhNBV96CV8ekMgYlRY2GWiN@R8FBWiV<P7Z7
TIBLQW:3W:>HRYFOSiJ^/[>cYk?1/ZR_^;Fe_<>oYi^RYZRa]kJa/kFc/[2i`[ZK
SYZLWJf/ViZNWYN:Si:5N8IoJfm_KG]`G6ijKV]`M7MUHg5ZLWMbLEiJKVaTJV5X
NhAaIfIPI6]_NgMbLV5KIFeaJFanP75_OW9WMH9nMW9eJVYoQ866PgQfL6QOGFif
IUYZNG=WH760QX]nLW9SH6mfLF1VQX]jMGI/L7UiOY2AKf5YMWI[IWR1T:JHOGAV
GWAlMgM^G5aXNI>7K5mLEDM=GUA;FfmgIEQGGeiNOXQkN75XI6QWHfn3QX:=Shb5
QY2HVXemQiBRYZc7ak2Z[ZR]YiZSX9V[[iJ:VjVf^jRX]:VJVjR]Yj2GVJZUX:jl
/:JUWjB[[jVOV9BAYlO7/jbNRYRVUHnIVYfBQi^QS8F=RWj1S85aMhNDThf6Ph2?
WHYiOhEmNVmSHEiUI6QgMFYYM6mPHgA_GUeYK6ERIVEYMG]oJfIdLFIIEg=oLVe`
OWI/O8V6NFieOgj3OWMaL8RAOg9]IfehMG1dK5iLJG]gIFQMEFMkPVYEE65dQ8Ii
O8F7QH^;SYnUV8^1OGQNHhJLYjZ^]:F@TXIdK6mmLfI[NGA^RY20L6U]IUEFIFEJ
F55>EEMSIeMGMXn3HE9FGFYhM6ihPXbFUinVWY2AV9JERHVO[;Ze/;2UX::WZZ:P
Y:Vha/Bg/l77`<6l^JZK/KVa/ZjYYjbc[:RZ/:nSTXJ=S8:>TXfGX9NDWj:ANWF;
TGidM6mfNH22O7ajOWM/Mg5MIF]TFVM_MWmaI6Q/LWQ^IFAGE6IZGUMNI6=TIUe?
E5YJDTQPIUQRLgYmN7IdHF=`OGIUL7j;UIVJRGZ2UYbARI66P9FNWZRXVifXYJRK
QXR3Q8n?Q7QdP8QmOX5bLWeiMWAeMVMfUY:4MWR:Y:fVZ9YdLX5cH69^Sj^i^JF5
KFUcNg9PETmKLFi]OGY/IVaaKFEPEeIXO7]TFfAbNWB3SWQVJ6iUB41EGg6;PhB>
Tj6QUi>@Q7UePhnARH2H^[nn`[BNU9VUXInOXjJZ/kFh^KJjbLnkYjBXZjZVZJ2>
TJFhZiVNWiZKU7YYHf9]O8bAQh=mNWf;UXEgOGefOHIfMX63OGnEU7]YMXR0Lf9K
Jgb8UYb=PgYlNg9cJ5MNFEY[KWIoOG1XKF]LDEAGE5IMGeYNM8J9R8EhL7E_JVec
MG9mQ85lOGenR8n:OhV4MH29S8=jQi63R:2PRh61R9>EThIlSI6>SHV@UXQnQXn<
Ph1eNX9oPHVO[kk5YGM/JE92Af1lRI^XXIFCQG1SFdlh;CA6DF1iMGMcHfU[J5M=
De=IED]9C59OJ7>9Ti29RXUhJ6eXGf1ZN7MoS9VW[:^WUHB7PGj9TI:O^<S4/jbe
`<?7_K>aYZ6Z^KF/]L[Fd<_Be/S2bLB/VIN@RY>RYjRYZZn]YIEoKVYcMFY]LFmg
PXN@TH=nO7I_H5aXLW]mN71[NhN2QH9mO7]oOV]JGf1RHVEbJfa]K7IcI65RDdmG
G61YLHJEQh6;QG9hQGmfOX5_HfYjN6a_PYFCQWegOH=mOX9lOH^ATXf;S9:OTWn3
S8b6PXB:PWYlOGEoSXV8NGNBV7YTIGB>UhEdOGYZKWMkRJ2YXij@Kc<96SM>KWi]
HGB<ThUeIV=YHU=>ATUNLGn5P6QECDUQNH65Pg1PK6MFBe1dRhbBUHB5TYBDQgah
J6EoT8F3S:2a^kZVVYZAQ8n[[j6PWYfQYKJo_lG>d/_0][2_]KRh^KJ_Yjfla<Bn
`LBeU8>4Ogf0UZVHTIRW^ZBFWhb5VYJ0MWQ`I7B4R8J3QH:0PXb?R7QOFeQEIW>4
Rgj1RHB0Q85lJV9TDTIIJVYTGEmcMFY]IeUFGVMQGemMGV1/MWekLW9mQXYoNHIo
HV=/IV1RJFU/KgIoMVIVMGA]M8F>Qh5mPhZ:QXjETYBBR7Y`Lg9YM7EUHf]iS9NC
SHf<SY2=RHbN]l[:]JJDKT0mFE=1GH2?UHM]FEU/MgARBT99D5Y]LgEnMfm`L6mc
Nh^ETXemK6MTHG><SHnQ[K6PT9B@SIVGOFahRiVT//;8a<2n_/;6/jBW]/NjXY:B
W:Jba<o;a;k1_:B?R8n<R8Z3R96@WJ^_]JR=R8J:UIR8Ogn3SXb6PhZ@TiZFShMk
PHj@RG1YLF]cPhInOWUhPGj0NEQ2AeMFDE]IFFI[J6YZI6E_JVIYJ6e[KW9UEUiY
HUafTY5oKF]_MW=WGEARLV]GEfYhMVieO8:4Ogn2QhR3NgQiMgM[HGB4SXAeKgZ9
PGikKVikP8>ATXQoQ8j<RHR0O8F9TY1kMXJEUWmWGeiSNZ31c;bV]L6YMeIHDUmo
TJ:LTI2CS7=bNW=KH7Z@PVeeMfaICdU3C69bN8VDTY1kLWA]IVIUGg:7TJ:/ZJF/
[:JMVJBWVi2DUiR@RXJ0Ri^U/;2/^L6aYZZ[XYjHSiJWZYJ6R8]nM7abJ82BR8:9
SH62UXb0OgMoR8RIY9^?WjJGPgEmNG:2THn?R8V?PgalOWI/MhB2Mgf<Q7UmP81e
KgEcHV1gMgR3MVYcJUmVLGE]MX5nPGmiMgb1QXAkPhI^Kh>@Qh>@T9NBPgU/KGI_
HUiTHfaeMV]VJVMePH:6Ti27QXnIThN;TW]WN7adNGIjQHAiM7elKVMaKfQ]MWn0
PHV1L760QhV?QWAgPHQoM7:2V9^X[JRb/InDThM^JgR1PHF8SiN=Qi:>MFigQ8AZ
GVIJAD1=Dd8^>59XL7nCSH1lO7enKeYHK7^2T9ZN[;2TUXV;XjRQ[;F[VifJVjn`
W9bQXKO<c<S:b[jl[Hn@UH^6SijW]K:GSXn:PG]kPHjMWi>;ViR=UY5jO9:<Nh^I
QhVET7i]IF=NHWN0NG=iOhV>PVijShJ5SXYkLhJEQ7F9V8n9T9bLS8Z?ShMdIF1T
Kh68OgASG69QIg]oM8RGQg]jNVIAFFAOFUUIEUQ]QgiPF55;DE5GHGV4KVIdKE]K
K7b:U8ehJg5iLVn9TXEkK5QNKgEhJV=`KFieLFYYNYBGS8N2MfaVNXf=RI6JPVEX
LWnNYZ6WVXAeM8RV`/FcXIB<Ri:>T9ZQXH]cIUQ9BUMdRXEhKfa_MG^1PG9RIV][
KW=kPXVEY:JIQWUoTINOVhN2RXj5PHnGV9bUZYV2OhfDU9ZHSHnNXiNEXJRWYZJQ
WZVVVIbMWJ6]WXj?TY>FWj>FQ7]kO7QmRHB4U9RGUXYnL7F4SI::P7IiO8>@T9J<
Q92=PH26QXF=TH^5NgIlQHR5OWV1SH9^JFIgV:6>MfUQHeA6IX5fJV9EEf=OG6UY
J6iQFfb8TXn8O6I6=U9gNW1gO7EjPXQnIeMPOXf>Rfm/Qgn6WiN5PWQnThaYEGND
Pg9/JW9hNhN@R81kQYJEPee8DG2OX9>@L6b0QHJETX^X^J=bASeIS[W3/7e;AEb3
Y[JeZY>0N6eSKhnZa<g3ZHj4Nh:EWJ6HT8n:Pg^5PGV6UHaiMFa/OiZb/Yf6LVYj
Q8:4TjjOQhMoNGElTYN>OG9gPhf1NX1`HVj0OWF2UiN5MH25OGV1SX9cO8=jL762
Pfi]QXedJWImQHfATXU_HVegUkBYWX]nR9>OVh=eMhF7OHVFUX=eNGn3Mfj?ZYQj
NhF6O7:2PF=HIGEdKgijIUQGGUQLO8^5KUiNFU]ZTZjRRF1@J71TM:2`VWmmNV=D
LhR5MFEhTH5NGVeHCFjAY8IICeYaV:ZUSgn4RgijTI6DVi^IRhEcHX2OZi9]JgV@
[:JFP5a<IY:JTJJkXg9RO8f0PjFc/9b9SI6@TiNLWiJGXiinJ8jl_[>[X7aHFW><
Y<7:/Hm_EVB;YIYnM75XJG^3IdeEGF1fW:bLOFabMGF3RHAjPI:>SXYlMVinX[>]
WhYbJff1RiNZYIfSW7iUKIBk`in1NVi?AFbS[iR1MGebHH6YZinWXg]YN7ebNjG3
[79KLhB4QYNTW8ImMFaaRIF5OhJ;O6QUIGROXhUjOgIFE7BO]JNKVHYdH6nTaJj>
Sib@N71hQ8J9ShYiGeY^OX5fNh=lJVR0PW=aNhIgI6MgLUMEK7YiNWmoKUM;EFn5
QGYaDSQIP8>0QWaFCV9`RiR?U7mJHGmlM96LP7^DRU`hFX^>NG>8O65NJhR?TZJX
LCI9NY^/]kb_PTToMK;7/Y^NUem5MJFLU[ZmQEM`SH=oW:YiAeIfNW^=UhihKf]O
GFQeNWUgMH2LXGMCG6IaUJ^d/k:GGCa7MYFT]:nJPGanPhj>QY2RV7YfQ8R6MfZ6
ZIAaMHf?QY>]Z8A`M85iQ:JYWI>:R8Z7Ofa^R9RMP6MRKWU/Pk:XIe>6[ZFFUhQ/
LHRETHF>XYn7NXVYXiNJUI:CQE]:M:NYT8j/ZWY^U:fBPk;3UfE[NV]YR:6AO85Z
?T9aN5MaU8=VF5]VO9bPVH1FEW5lTjZ?GUf?U5mLR8moP8=dKgilKGN8OfUfU9=b
JX9oL7ZBT71SK7YmK76CX8UfRIZ9MW1fO7mmOWakP81dOIF9Kg63RGekSYEnNXn:
HUJ2YJ6=NG9ZI8>LS7EgQ9>MSX6AXi>1SZVaU7F2XZB;MWR1PWm_JWQhRYaoJ7>6
UIFFVYb9Kg:G]YafMH9eJYJbS6IZNH6KZib;Og1/Lg1jT8EaMgIaM7n0PifcZ8=a
P8Z:Rh5gQI>4Mh:ES6]KDf:5RG=FHHB>T8ihIVi/N9j/WYNCOEaEOiNEUGaMEg:1
O9JYUYJIMeAWVJ:EPWV6PW5gTI:7QWUeOHZBQg]/K8R3LHbGLV:3UWn>[II[J9:W
TGYdQH^=XJ^@JWB<LGNVWWamT8UXGHBQSgn9U8Q/LI6JTZ2dV6e[NX9kR[RnVG=K
JhZGX9BCSgATHW:H/I1]O89oT9MoJh>ETHn7Ohf:N85lIW^LTXFQWVE;QZ^9P8mg
BDj=[IF0PgeUKI6;Ni^kVV=UPWeZQ:=jCF9/CSmRSh5@Bf=VH6ifIW6@TG1UO7Qk
W8mWNY1nOGmiQI9iIH6GR8BAUifLP6Y[NH68Y9MJCWZITH:5P6A<I9FQUHN4QGI]
LJ7;Y5M8PH]VMI6@MeeTKW1oUij?M6eeN7Z8THA_L81lMgATO:NNMEaHO/GKU6Io
OgN4[:jDVin@UZnTPh^_V6McM65eU:6FPgQ_IVf9Y:VTVViAKGQnU9^ALEehV9Em
O9bNOWAhLW>:Vi5nKf1LK8FNWX=iOH>>U9>5PHMiPZFSSX^ISH6MTg1kT7eHIXN3
QY5nHfn?TWR8];:BSHAbMY2S/jYcL8]oR9Z6PJ67IHJLPgB9Sh=mRGQbV91ZKX:8
IEMkS7=9DhNBJ5]^Oi^<FV5cH6VT]h1MIUY]Si>NXGmVMi1fEH>__[=cAfVITY2Q
VW]SK6=HOJ^LLFU]KWb=Ofn<X9B5K55e[l6gREa>DFR?ZZ^TPTU0KY2BWIB4OE]A
K9fnZiZBPFMML8RNXINBSh9UH765Sh1nSIUXAGRPPGJCTYN8IX;5bYEjOHfKY95^
QIUcHHVMFc=YRWIIHW]_Fe9i]j9LFhMnGWf@LG:>QXFCITj5ZXaUMibMLeR<ZgeV
R8ebRZZEM7>0R9F7J7R9M6ISJhRTV82AXGM:FIN/R92QOE56N9jGQH6T[Fe5JjFR
P9^^Q5ASTiZATiNSSEiZWib7WJJGQ6U]SZ>h_:J?NHNb_:N:NHRLW9Z>M6f1Ng2<
VWm]LgNCYiIjP:fUNGb:MW6^`h5GIW=iT967TXibJhNNX8miMGIaKGEnJeYoXI5m
J6f=M5N3`:9[NfQ^WiR3RYEdGgQlKWEjOWMUKWYgMgb3QHR6O7QoTInMTGa/MhAk
N8B>RWUSIHBDPG21VINASHR2NGJ0SG]JN:bCI6^4T8UgKWV0MfieMVYdTZ9mGGFB
R5eUSI>3IVajKFY`QhehOGQ/NXFAXiQlJFYkU:ZHOVE?IHQkJHZCO75/JWn5N8bZ
W6QSMVEaWjb9HEm`M8>4M92_RE1ILVUhXkZHJWR;LG2BXK6jUFI`Rg]g[/6LQXJ4
JGNSXY^DTHa`JVeo[JR2MhF8NHZg`jF5MGf=R8:FUH>CR5a3EfIfXXeYJTdhHI2W
Zh]LDH>QOg:IW6ETTi^>N6Mm[;AbDi>^L6b_[Vm8L;FgSEaELgQnR8A/JY2CRXZ7
OWf9N8Nk]W50Ii1iRjV9Pf`^?7^[Yi9lFVB6NGN/[h=RBf>X[fa_VhUQNYUeJiJ]
XHQbKhZAO8nf^Zb2L9RMY<NoT8:KW7=WRJbWT7mnO6=MUKZ]QVE^NGN=RWf2Q8ej
KgI/JhNKWZREH6Z8Ff:SYhISHG1MDf67YWQ:CFMfOin[T7b1O79ePIVUX6heCI;1
^WE8C4TiD8>CThAF9DfRYYJDNWZUUUYRX[JKNeidV8UkRX]WHIBSOEj=_IAYLXJL
V6MQYZYRHj>HOXN8RgibRhAhPgiaOHQfMWn1Q8f;L6YbNHAnSYf7NGMaKHfk_HYj
UHANJYRZ^j5XGXF@HVfTWW]cRFQEYLN@LWAlPhNIUXmgJhJLSgj0MH27KW1oMh>D
QFUjWH^>WgY]T95YQ;:5GfiVQLR`F6:1NWUWJgn5RiR7LGF3R8^AQi6JMFZ4/LVR
S8aiOYbbX8:=WGiJJiBRU7Y[HEUBHijWI6R4KUm^Tj5mEUn3X9AbIWb>O8>cXdU7
SI>0RHn;OGE/MIJ1KHfYTE=<N92IThUnL6elSXIkR8U[HHnGM8R?I5YgNff5XI5e
IeiBKjbnTgn;MEaHJIOD`5X/CW6LaK:8M5IDW;MeL:VHEGJbUWN3Uhb3Uhj<VW=N
W:b4PHj2LVQl/jUfN8N7SX^9XK1lFHRDKgMoIYGLZF5XHU2Ak[eGJ71XT;JTR8=W
EWZEKER9WWIEGhVMSIbJJfB8V::hYg][QYRAQhB6OgUjF5bBS6U/Og1YQHn>P79c
KF^E_XMANHikS8Y5?HVjWg=YI69`SkR[Jdn4]8aQR:NHNV]kVJ5dHHbVU8NDVWML
L8QgVM2SL6U=CXfYOgioHf1cJfbQTGegBT6QeHAVQGiVSkjAL9>=Be2AXgmeNFV;
[X]CEXF>V:f:CDN:/;NNDe:Q/gAWWjj8NVmHF9;BbI=oOEQSRjJiZF1@SiR1W:5b
MjV@H7^JOh6UXfeSVIIWN91XK8IlNXa]?XKBOE6JV6J:^IUbKVV3^hPhGHEHKKfb
EC=3IIj]PeQHFGj[PeETOJ34WU1JSHb4Wi]aOX=AFXb;OHfBNGMaJWR:QWb;Je^:
WVi]W9B>Yi1RMHEaOYf?OiMoAgBhWVA`QfUcSV]GU8iHOXeXT[acC8VFLYJ/LfV5
If>Zd:aQA5j>[IEiOX^8N8R]QfJMZFYd_[>2PGn<]J9IEJVhOX1jEGVn_GE/Sh9O
L9F=R9B9BF2BNiJmRdmVRh64Uh]hQ7YOOIE[EWj9IFV9RG9[JF^;XXf5WH=8H[[C
VWjJNeMl^jM`NX=RLXJ1NX6X[WYWNgj3Zl2OMVEmWJ^KTZBVX9=gFefO_YV3T7MF
Rjf5S:9aFGMeOJW:TdePRgakYIacKgn0RIB0MjJTL6N3H3Eoj=ahBDdb@j7ae68R
:FJEY;fEH6UnP7n;Qi:MQW1PG5ePXL1k>e1jP8^8LfQFHYBTS6YEIY6SRGadJV^4
REMZ]:]QJ899B<3/TeaNCXg3N6BTXVeePF1JQjbXHdB>/WU=J;74V6mWMgiiJGZ[
Z8N6OE5ee]n5Gh9`IJkM^IB8Sg5NO9:Z[5ddLhMOT<R9FgAZ=cMVS<OX/4T>>j3F
_85N<dbja5e8UH]FMKJRIUQQO9j?FUj=WWU_L5aRPJo4Sb0PRi>1c=YS64j4UjbS
RfQ2CY6nWGA]P7QYUKjFC5jUX71`Ohj`WYJ`UFalVhf0WjJDQHARL/fjQYMiDHN@
L:c>WhIbH8jYQJSo_4MWVK:eUgN9YinTXg]VMIjdZj21G4Yd`]n/LV=RJgjQ_8MQ
Lh6VYg5:E72@`j]:=EbB]HY4G[>=DGb<JGNCWZR>K61bPX^JJdbR]Ui8M8J<O6YH
KYn6Cef8OXB^U4E4V;>>GEekOUUNSIj@O6MFG72=S5MPMeIBL8J3NdDjTJaoIFUe
J5mjZlNMKeUHLi6?RXYL;Da]G:7PF1j>SEM_P5]QQWM_XiIJL9UcN:bACe5cRIFF
QG=YM8j5Kh>CIDi^Pgf5Pg5_PGQQVKQmF5maSZV6IXnDQk?1LUb=P7Jfa8iRFWb_
^HV6XHE/XLjSSJRKNhRkjMj/WH^BZVi7TiILKWj?N7:cVgNCVIfeg[^1T[FeShZO
VhnJW7IUPJg9[611Sj1UK9ZZQXb/XZ:1KXibEXo7UgB@QfQHMGaWNhf:FD5WLhfc
UUUUJCMOVgQLIfQZQHU<CXf<EeB2Qi1R;6>4FEb5NF9JCUIaSYZ5GUE/QhR5P6]T
PXn3T9:3KFJ=/:5lNIN^WXB_[gYbTI5dOVenYjb5JY:XTHFNX7Uj[[FAQ7aSMIRJ
QV=[O7aKE6eXMhMQII^YUV96Fhf]RV1ePfedUJ>?GD9GSJB6MW9iR[36aImjGXOA
bYVDZiNIWHfZflZGRGYVWL1nS;^8GY[4R7:9Ogb6T9ni^WM8O;Zl[9IiJfJ=ZY6O
^IEIHHFMRhB7Kg^:Mgn6KgZOV61SQhB0Og^7WHn;UhUIFJ2KLiJJJeAE@VZ/XWmU
CUMeSiN6L5QOL6]TRZbAQ7AfLEf2S7EfNGUaMH9dLH24NfQ^LFaaKgQoK6f:PF5Z
NGAgHUebQ6]CMJ>AGF5mPg5SJVYTIV]/G5MJ?dMaIeAUEce>GEYZNEM;HUM6AEi`
N6mGD4PgB7Z7Me0lEX1nLH9]?W2]W:^SD2V2_::>J4m`ZI5^P8F7RVU3L<J]MW]h
PKK5OUb4TXj=Q7J@ZY29/KV8S;FdUH^f]Gf;][Z^^:68^ljm_k6H[<>gVXJB]/k>
^::[Zk_Dc9i_R;o</9nBUjNTWJ2PRY>bVj?9^[FeU9BTZK:dYhV>/]C2X:NMN86]
^iYUFXFX]l2NO9Nn/i=fP9FRb;jIWiQbMk3>ZhV=XZR<PHF7V:>7GfJ6T8J2S:28
HfUjQYnKW7m4C6miMH]lGeUONifLG4]ZLWIkQhj9OUU?W;N1M9:9LgZHZ7U[PYBL
Tib:GeagSH>6Sgi]LFmiO7f>R6]MDE5VMI6HN597G7N:LTMENFi8ATU1CfF:OT<d
<R]6JVeYNGM9?dm=GW1D<TEA@cm:?3E3A3DX;T]JDC/mFTThCE]MIfUD<S0nCF5U
CTU>ASlkDgMnLF5FFEiAAU1KIWAbHEi>DG=iMgemJe]GHF=aP8n:HemfKF5dRi2I
UGMJL9>CSWimTYb3IfeoPHBL/;:SRgmlRY^GW:NQSIBMWZZbZ:6]Z:B_/I^CZl38
_KF[XjS6e[^]]kRYYZV]]KBd_kfUUj>T^M?1[J_0a[BRY[6/Z[:VUZ>h_l75Zi6C
YJfe`;2JWJZ/Z[bmY8V>UiN_`:2:X;6d[Y^CV9F<Q92UUGANGG68XIN1RZj/QVUV
IG9iKW9nM6A`MXNBNV5bThMcS:JMMf5QMhEkOXJ4LgN8SY6GSgQhPY:KRhjFRXn:
LW1]MX9kM6YNH6IdPgn9VHemL6M[LF]YJFEZIV1QHUeEG71YI7MnPWQUHFEZHeeK
IGAcM7IkQ8R5O7UiOX5iLW9`L71eOH:3SXeaK8RU^:VDO6n7VXf1O8EkM8J0Mhb@
NGF3TYR=PG=XQ9Z;NVMHDVNCVI^^XibaY7ikRXRA[[>FOgb3X/gD`[[1`/oVmO7D
`kJUX9fPTGj6T9V@PGejOX5kMGIPF61KEEMJDCXX<4MDEEYXM6mQEUEPHEQKK7Aa
N85jQ9F7O7]iPhZ7RZF^UI2SYYVS[[2o`lK9a;6LSgiWG763P7^1TY9dHgAkKFIV
IUiLKGM^KGAVEUicPh1gOj>eZ:>JTHf0NhRDTXR=ViB@PgfDVXf2OX2:Rg9VMXn=
NXV^`jj;Ke9EKFmB?Cd]724`BUA=<AHK6aHX?SD/6P0000DJ9b@M6aLF8DALE48]
:2`_;BdgB4m;ASa6HWZ>UhEgLg9eP9:ISV]6C6AhT:6OTh=fLVm_LX6BOfMJATMI
HW5fKg5aJVn4Uif>P7]eMX6HZZVcaLNo][>maKfd];Nl]K2ka<:eY[:j/kJm`lNm
]K[3`k:`_KFi_/Cbooohg=[9][bhViVRU8F@[/78bL:eZYbAXjZANVEB@2l_A6R6
Pg^2RIb[XI^GPfaFBdiWOX24SHf4Vk_>jO3KaL33^:^`^kZTRhJ6TkC;f^KUf/W8
b<2g]KJcYHiiKWNAXj6X/;:fYYZKSWi`GUYQM8V7PXF6RhnAVIF8Q85nOgmnRI>B
Ng1gMHVPXjFg`kk4dLF^[<CToooWc[ZSVjZYThj?QWE]NHB4R85H>Rl[?4@a5``0
0000004F:2<K724P6aHD3@/D51LY?4MBFUUDGGJ;SY:MYJ:GV9bETIf[];Re]Kjo
_L7?e<_0/ZJY]K:TTGANG6ERHEmOHEY@B4U@Gee8>cU0DF5^MG5]J5mJFF1`OX9n
PHMoNGn3Qi>R]Lc?]kSBh>CRckS6ho_oooo_h/NJUjR@LGR3MG60RI>BNULj9Ad`
@C0K4@<0000000dE93<b=dA;DUI;@TDn>4=ILX:=TY2O/;c8cm;KhmkBcLO6cLk2
]:RLWJ:Y^<2dVh5`J61HEe]GAT=7=bT/<3@j>BhV9S0l@d<o@dI<DUIOLh:6RXfA
UiJIVYZSYZ2MV9NJY:fa/JjSUjFh_K^l_[Vd^=;momZeY9:<V91UAdeEDeUTKWUm
Je@m:Ah[=R`P4000000462D[;2P[B75kK69C?CDf@UmjSJ>^YZF/];Bc/Zf[XYJJ
YZ6FVYREUHYoPY:OWifDOVmPDE1LIW9dJ6=VHeQEGF1OIF]]MXNDWYRATIFIUI^b
a/[4_kneZJ^c]k6a/Zf]/J^SYjBJWJRSW:Nf^K>`_LkBjOoooM[A`;70]Wm^P7ej
Qi:CWk2LOFiWJXJ=NFUA@D94?DAPNXF3Ng1mT8elKfENGeUOKgfBZK:]ZJf]Z[:e
^lG3^JfUY;30aLG:cM?Le/Jm_;Fa[j6;OH>?UiF8QXIlKVEVKgb0Kf5MFV=^L6mn
RX9cNXfGVI:7OgQ_KGN8THn;QXVBW::OVI>BT8n?TYjU/KRi`LS@kOooh;o:bl;5
Z7=`RH9]K7f<W9amI5a:AeY>>38[7a45000?:BdV7RI5Ee=9?B@A4Q4L<T=EKGYj
QiNNY:^YYZj_YZN]/;Zl[::TZJb//ZnSV8j:RWe[GeQGETmCFe]HDU5?ADM;@ci3
Be1CE59@FfM[LgYiNX24RHMkMGMnQHZ=SYZ/[jb/[:^]/KBd[:2QZ[6j_lSDj>g@
Z9nea<BeSFQPFE9?F6QZIem=?Sa2CDdf6P0000hF3AH`?C]3C59[P7MVJFaXHF5_
PYb/ZZ:T]lOCgn3@`l:o_/6l^L;:a[jh]KO5c/F_UhN3OgQeMW1PDdaBIW9dMgUf
LfUICDU>FV1TJg:1UJRa^;Ze/kBb[Z^[ZjZ^[JNOWjR/[;?1b<>cYIZKV9>CU96>
UjFlgo?H[JZna[67IEaNGUiGEFN2ShEdJV=TKfiJ=QHA7RPW;Se@EE=CFG:ATgaX
I69E@Sm<GfiYFeYWLX>BV9fLTH1cKfiZJFmeLVicPI2DR7afKf5;=2T]<30^<3@i
@E5PI5iHF59;@cH^=D55AU1NK7J1RHjCSH63S8IhL6UQHf]bM7QoR96EUiF=Ph>7
Qh=mNh29UZRodn3QbK6kd/f/QW=_LgUiNX>I/kRRU9ZKVIAoGChd?D<l<c=2DEEN
JWbDXIR1K6]aI5EHJ7InR9VW[KO8e]G>al6k^kVd/kS4d=7AgNKUh=_Ba[JUUi6H
WijERXF8SiFGV9JBShZ4Ph=oMW5`KVmdO8JEZKZl/Z^/[JVSXInJUI:<R8nLXjBR
XZBTVI:GXJNWXJ:X]<77e>K`iLVhamW>ZXMkN7QoNW5jRI:6LfY_MgaeHTXg=3dj
:1XG92T/?EI_P8F2MVMPFeA;A4UGJ6mbNhJCWj6GSHjEV9B@S8V:RH9iNhfOYjNU
YJBNTXEhL6MHBC/d>458C59IFUeRH5UDCDI<E5=@EUYHGW:6U:6VWYBHW967Qh^6
OG^1RY>MXjBQVYJJWj>VXIJ>T9FKZ;G1d=O9/[?1^9AcGdY1CUUIGFj3ShAjN7E`
J6=F@cXj>38^<3Dj?418EfeoQ7mfL6QNEE9OLGb5SYFIY;Nm][2_[[2`Z:>NUi:D
VIbNZ;S0_[Vd/:ZMRh9mNGMaM7n4PgegO8J;R8B1OgioPWilNgEcNhRATiRQZ[>d
/[B`Y9bJWJ6TXIfRYjFVZ[2d]:jXYJBNV96;TijOYkG=i^?>a/NjU7A/HUEKI69/
QIZMSX:6Q7UaK6QOEeE=@CPd>D14BDiFIGN1OW9WI69LEE5CEUe]OXN=TiRIU92=
QX:0NFiRFUYPJG=iPHfGWZ:QWI>5NW1UGE]HF5mSHemJG6=RG69^LG5/HemLEU1?
Ce9NKGIlOWmnNgQiMViXJFe]JVU^M7MhMgEeM7Z2Q8J:RX5fMgj3RY:J[;o1]:jc
[Y^7N6YKFV=UJ7J6Rh9jOWUZIVU_MG5VFDi4?Se1@dI<Dee[O8AlM7=_IUaKH6EZ
LWf6RXb?TYFKW9RCUI^OVi>>SI2?RhZAVj>X[[>e/jRDQWijP8V@VIjHShf@SXR:
TIFGUYBCTiFAS8j?RHF8SY:HVYRNYjBFQXRFVIVDRH^<QXnMWIR@R8nESI2ERX66
R8R>TI2BV:Fa[::MSG]lQhZ9T9BAT8b2NganP8N<SXn>SI6DTHj<R89mN75_M7f7
S8f?SXN3QXZ8Ph5nOGamOgaeL75eMg=[If]cN7YlNg]mO7]lOX>7QhAnN7MhN7b0
PH:6QW]_KW=eMGEfN7n;TY:>Qh:2PWigMGQiMWAcMGQiNWeoOWQdLW1_L6m^KfeW
IFE/MgelMWAdLg5bMgUeLG5dNWakNgUiNWYjO863PX63Q8N:RHB2Q8V:S9:HVinS
WiN=Qh>2QhR4OgalO867Ri:FU96?SHf;RHN9SHZ4PhF5P7elOWehMWUmOGj3R8J0
OX>9S8b;Rhf@U9>?TYZOWIZETYJJWZ6TY:6NWJ6QVI2=SXn>RHB5SYBBShnAU9>A
SHIkMG^3QhV9QXF6QXF7RXZ5OWioQ8^8P865R8^?TI6CVIRFV9VIV9FEVYnPWYZI
V9VJUi:DWZBOVIRAQhB3QHR8PWj0Ph>2PGn4R8N7RXV6PX61P7]dL71`JEmMHFU_
LFm^MGj1P7imOgmnNg]nP7ejNWalN7A`JVEXJVMRHVQ/KFiaLVi/JVEKDe1EFUME
FV5SGeiRHeiGEeYLFe]MGf1PHVM]LW=aM7YlO7]hMGMnPGmmNWIbM7]mLf]/LGEg
NWilNGYnPhF2P7f0QhV<TI28QHR8Ph61NgMiO7inOWilNGQhOH5oNg^0PX>5QX9l
Nh:9QWehO864R8Z8R8jDUI:=RXfBU9BARX:2QXbCTh^8RX^>TiRJVIVJV9JIWYVA
TiNDSX^=Shn>SXf=SHZ:SI6ASXnCShV6QhV>TY2:R8bDV9F@RX1iMWEhOhF3PH65
RhjBUYNFTHf;RH^>SHnBTi>CT8f@UY^LW9^IThj>T8j<RhN4OWUkP8N<Rh^<S8Z6
PWmoOGYgN7]jMgIhMW1ZJ6]YI6=WIF5UKGIlOWinPXV?THn7OWYkP8>1OG]gMWUm
P8>7Q7agNGimNWUeKf]WH5UIHfa`LG1/J6Q[KFaVHVA[KfeYJFebM7EfM7=eNWj1
Q8J2NWMiO827SHb8QXR<TYJESX^>SXV8RX^9R8V;T9FBRXJ:Si2?Shf9PGakNgYk
NgQfLfm_MWinNGEfNX22PX:4QHF4Q8B4QHN;S8Z:Qh>1PXJ9RiBLW9JATI:BTI6A
T92<RHjGXJFRWIJDUYRFTY29P8:=TX^2Oh21OgajNG]lOX66R8N6PWioPhB4R8jA
T8f;S8^:R8R6PH:5Q8:5Rh^7R8^<SY6CShZ5P7emPhR:SHn@TI6@Si2BTHZ2P860
P8:5R8J2OgmnNgQiOH23R8n@SXb<Si:CTXn?THn<RhZ6PGelNWIdMGA`LW^3Q862
Q8R;S8^6PX62P7]jNWQmPX5iLgAfMWAfNWenO7YmOWUeMWIcL71`L6e[JV]aNGYh
MWAdLfmZJFebLVm_MGYmOGamOgn1PWmjNh23QHAoNWYoPh>3Q8F5Qhb9PWioPXF7
R8J7RH^8QHR=SH^;RXR6Q81lN7UgMGEdM7MmP860OWemOhB3OWYlOgmmNGMgMG=g
P8J8QX5oQ8R5OWYkNgf1QHR<T8j<SXf:Ri2GUHj7PhN@U8n6QHR<SXf:Rhj<QhB6
RXR0N7AcMWYmOgioPXB6QHF4Q8J8R8J3PhF7Rhj<S8^6OWYoR8b;RXjEUYFDTY:F
V9VJU8^6RHn@SX^6PXNAThj<Shj9Q85nNg]kMW5aMGb4QhJ9RXV8SY:@RhJ3OWUi
P8N8QGmkN7IeM7=aLWEhNWn4RXf>Shf=SXf9Q7miN7]nNW=dN7UfLVm/K6iYHV=Z
KFaWH5eLGV1PGEeOHfM[KFm/JFY[If1OIfm_JfU]MGf1PWiiNh23Q8F5PWn1QHR9
QhN9RXZ<Si2CUI6<RhV2NgQgMG=eNh23QXB2QX^;QGagMGEeM7=dMgQhN7EbLW=_
LG^4Q861QHF2P8B:SX^9RXb>Si6AShn=RXN6QhN8SY:ASHZ<Si6>QgmmPXZAU9BA
SY2ASXf?ShR1Oh:9Si:EUYBBTI2=Qh>6S8j;QH>7T9ZNWYnRXIZEU9NIV9JBShjE
WZ2IU96AUIVKVI6=TYZPXIbCSi6CTXn>S8Z<TYRLVYB?TINIThn=SHn@T92>S8R5
QXZ?TYBBSXb<SI6GVIRDT92ATi6=RhV7QXF2NgQkNgQeM7EeM7=dMgYjMgAcMGEe
N7QeLg=bKfYVHV1RHf1KFEQIFU]LGUiOHF=SHf1MGF9UIVEQFeQFE5IKHFI[K6YX
IfQ/M7YiMW=bMWj1PX:1OgemOGj1PH5nOH22OW]lOG]hNWejM75fOhB5Q8F;T8j=
Si:EUI>CTY2=RHV>THn9QHN<Shn?Shj;RHZ>T8j;RX^<TIJGU92BUiVJVIVHUiNG
VIVFTi6@T8j:S9:FUHn>TYFDTY2;Q8B9SI2AS8N5RI:HVIRFU92;R8R9RHZ=RhN4
PX63Qh^;RHR9RXJ1P8F>TY6>RXR5P7ajO7ahLW1eOXF8R8F1NW5^MGenMW1^Kfe^
LgEeMgQfNH25Q7]eMWQhN7UjNWYkOH1oOhB;SXj;R8F7T9NET8f<RXJ2PHB7QH1n
OGakMW9bM7=cMh28RXR4PH60O7QfMgA`L7IkNWQgMW9_KVi^K6Y[KFaZK71cLg=c
LViZJFa`MGE_JVY[K6a^LG9bLgIiO826RHZ;R8B0P8>5RXj=R8B4RHb=SHf:Pgel
OhJ=SXZ5PX1mNWUiNWamO7YlPh^=RH=mP8B6QHN8QH60PXB5PWmmN79aMG^0P7io
Ph>0P8B6QH>5R8V<SXf:RHN2O7b2QXJ8Rhf>RhN2PH>4Q8F9SHj:Q862PhF8S96C
ShJ2QXj>RXJ3PhB4QHR=SHMnN7UlOh64RXn>S8fCV9VIUi:?T9:CTiBBSXf=RH>1
QHR7QXV<RXN3OWYkPHJ7QXJ7QXF5QHB5QXR8QhV;R8J9S8V5QHF5Ph1mOH:8RHJ4
Qhf?S8b@U9::QXV=ShnAUYNBR8:2QXV4OWf1P7UdM7MoR8Z6P7aiMgIjPXN6OgUj
NWQeM7IgMW9/JFUZK6mcM7EeMGIfLW9gOX5kL6QUHVMcOH1lMgEeNhF<SXf8QHF3
P825RHf>S8V4PHF<T92?RXF2PXF5Q8>1P7moOWYdLWAhNg]lOh20PXV>SH^<SXf;
RXR3PH62PX5nNWQhOH>7QGikNWYlOWn3QXJ3OgemOh:4QXN8QX1iMg^0QX^:QGil
Oh:6QhJ2OGb1QXR7QXR;RXJ4Qh^:QH24SiZOWY^HUI2=SY:CSHJ3QX^?TYFFUI>@
Si:FV9VJViVFTi2?Sh^5P8:8RHF1PHB5Q8:0P8:1O7YlOW]iNh23Q89oOh63Q8>2
PX5nOGmoOWakNW]lNganP7ijNGn7RhR5QHJ6Q8>5QXF1O7UjOX5nNWIcL6maLWAb
Kfi^Kg=jOW]eLGAgMgQjMg9bM7IfMG9_JfQUIFMZK6e_LGAiOWekNGEdMWQiNGYk
O7]iMgUlOh1oO7]nOh1oO7YmQHV4OWamP8>5R8Z:RXf@ShZ6PWekO7j0PhN<Si6B
Shb:RXb@U9B@SXj@TYBEUYB?RXbDVY^LW9N=OgIhOX20OW]jNW]mPHF8RHV3O7Ul
PHF4OgaiMgQjNgYkOH20OWemOWimNWMhOGmnOh21PX1oPH:2PX:4QhV<Si2AU9VJ
Ui>?SHf>SHb;RhZ:S8f>TIFJW9fLVY^KV9BASXj@T8nAU9:<QXF8S8f9QHB4PH63
QXN6R8Z?TY2=SiJLVI6:R8Z<Si6EVIZGU9:DUiVKWIZ?QGj0Qhf?S8R3PX:3QHN8
Qh>0P8>5QHB3Ph5hKfa`LG1aM7=ZH65[Lg1WGU]LGE]KGV=THUiKG5eKFEYJFEQF
EUUNHVAVIfQYJ6QZKFi]JFIXK6m^K6][Jfe`MWQfM7EhMG5bMGIkOgaiNG]kNWan
OWekNgeoPXF7QHB5QhV:S8j=RXV:S8Z7Q8:4QhR9SIJMXZFWZZZVXJ6SXif@R8N;
Shf8Q8>4PGemOh22PGilOX1lN7UkNGIeN7YhMGEjOW]fLg9cMG9]JFU/KVi]JfUY
KG9aKg5iPHF4PX64QhZ:RXZ=TI>CUYVJV9FCUIVKV9JHW9bGTHnAU9JHVYZHUYJG
WJ>UXI^ETI2DUiJEUIJHVYbOXZ:PWj2MVIVLXJ>RX9bJVYfPXj6MVIfQXZ2JUYRM
WiZDTIBIVI:5Oh68S8V3OgilOH21OgYjOh>3OW]jO7inN75_Kfi[JFU[KFi]Jfe_
L71]JfMTHfEWJFIRHfETGEUKHV]`KFUXJFYYJfe`LW1]JfY[KW1dN7YhMGIiN7=a
LWEgMgMiOGimOX67Rh^8QHJ8RXbAUYNDTi>FVI^IUiFCTiVRYZRXY9nLVi^IV9ND
Shb=TiNHUiFGVYfOXJ>SXZ6OV8n6PXB5OgMaLWZ0PGejNWenO7YgMGIjOWafKVIT
J6a^KFYYJFMVJ6YYIf5IEUMLHFAUHEeKGEmRIfibLW=gNg]iNWanNgYlP85nO7Yi
NgioOWUfN7enOGamOh:5QhN:S8f=Si6ASH^;S8f=SY2@S8V:Si>EThn<SHf=TIVQ
YJ:KVIRGUiJEUIJCShjAUIJGV9NDU9VOYJJPV9>CTXf6PXJ?TX^8RHZ9QhJ7RXj?
RXN8RXZ8Qh=lLfi`N7agLG1aM7AbKfi^KVe[JF]_LG5aLVm[JVe^KF]]LWAeM6m^
LgUiMG=eMG9^KG1bLW5aLWIhMgUiNGUlOgmnOGenOh63Q8>3PX:2Q8VAV9VDT92C
UiVJVINFV9VHUiFCTHn;Qh>0OWn3QHN7QhR8QhR<S8Z:TIZOWIF=R8N7QWmfKg5i
OgihM7AfN7]mOWekNGQfM7EhNWYgLfm^Kg5]IfI/LFaSGEaOHV1LFeePIFQXIfMY
JfmbLW1_LgUkN7QlPXF5Q8F5QH>0OWj0P7inPhV@UINETY6ATYBHVYRHVIZIV9NK
WYjKW:>YZ:>OWinOW9VGUIFHWJ2PW9JBTYFHUiBAT8n>SXf>SX^7RHj?SY2GWJ6Q
ViJATI>GWInJShN8TYjPWI^MXZ2GRhN:RHF0OWekNWj2P7ATFemYKFURHF9PG5mW
KF]TGf1PGeiNGUiMFEMGFV1UJ6U/KFa[KgEiNGQgMWIeMGEcLWAiOh:3QXJ6RHjD
UiF>RHZ=SHb<Si6?S8jFWZ6QWIRFUiVIV9VMXJ2JU9:BTiBDTXf9QXJ8SI:CTY>D
Thj:RhnDUYFEUI:?TIROX9ZEUI^QWiB6Oh><ShZ4P7ejN7UmOGUbKfe/KW1dM71U
FU9AE5EEEEYOH5]DE5IFDU1@DU=CDUAJH6EXJfe^Kg5gOH1mN7IhNgemO7]kOX:6
QX>0PHF:T9JFUYVNX:2OWYbKVYZKWZ2OViRFUYJFV9ZJVifQYZVWXj2MV9BDV9fJ
ThnCV9ZJUiBCTY6BU9BAS8R8RX^9QhF6RXjDVj:TX9ZFUibMVHn5QH^?Sh^8Pgij
NgimMfiYJfmaKFUYJVUUHF9THU]HFUiNFUAAEUiRH5aHF5UJGF9UI69QHfEVIVQ]
LWEcKVebNGUeLW=fM71^LGImPHB8Rhf>TI>AS8F3Q8N:RXR7RY2AS8V<TYJFUIJH
VYZHUI:>RXN7QXF8RHZ<SXb<Si2=R8N:SY6BTI2BUi^IU96BT8f:S9>KX9jHU9:E
Ui^MTX9iO8B8R8J6QH1kNGf0PG]dLG5bLG=eM6aRFeYMGUaKGF5RGemRIFERH61S
IF=QIg5eLVmcNgioOGioOW]fMGQmOgmnP8:0O7]mPhZ@TY>DUYZOXjBPVIBATiNH
UYJHUi29QXZAUYVJVi^GUYVKViVHUiJCTI6ATY:CTi>BTI:DV9bMWIRCShb<RXR5
QHZ>SXb<TYZV[JfZYJ:OW9F<QX61QHN6PWimOX:3PGegLg9bLgEeMGAaK6EPHVIW
HEUEEUIDDE9EF5QFEeaPHfEXK6aXIFM[JfMVJVm_KFa]L7IkNgQgMWMkOgmnOh63
QHR;SI6GVIF@T9FJWI^IVI^MWYfNXJFYZZb/ZZRWYjJSWifNXJ>QWj2RY:BRXZBU
YZFSXZ:RWiVBS8R5QHN:S8V4Q8N<T9FKVY64OWj1PG]cKVmeMWEeN7M`JfY^LVmY
IfY/J6=QHf9JDTiAEeI>BTeDEU=@DEAGFUmTIfIQGEiPGe]HFEiRHUmPI6UZJ6Yb
O7ijMgMkOG]iNWj1PhF8RXb?TI:AShb:Rhf=SHjCUYNFUIFIWZ2PX:6TYZRVXZ6S
YZZ]ZjBNVifPXZ6PWijJThn@TiBEUIFCTYFHV9NGUYBDUYbRYJJUXYZHW:2NUXf5
Q8V=S8N5Ph>6R8R7QXB4QXN3Ogn2PWadKVeaLFaSGf5WJVUXJVi_JVAQHVIZJFQX
IVAUJg5aKfmaM7IcLWV4RHJ0NgUhMgEgOH>7RHR7RXnBTY>FV9FCTiFEU92>TI:@
SHf>T9:EUYFDTY2@TY>BTHj:QXR;S8Z;S8j?Shf:QX>2Ph=oNWQgN7YlP8J:SHb9
RXnFWJ2MV9JGUHn5NW9bMGIdLgAeMG9_KFaZIfIVIFAVJVe[IEmKG5iMFeUJGf5O
GEaOIFMVIFIVHUeLHVUZIfM[KFaZJfmdO8:4Ph:2Q8F2OgaeKficNH66QH60PhN;
SHf:RXZ:R8R8RH^>T96@ShjAUYRHVIjSY:>QViVLXJ>RWYRCTI6CUI><RHZ<SY2D
UYNIW9nPWifKUiJEUIFIWJ6UXibFUYRHSh9hMGUmP8:4QH1jMWQkO7]hNGQcJF9P
H5eGE5IJG5aJFUmSH5I?D5MMHF9SHf5OGUaMGf9TI6IXJ6M[M7YiLg9gP8J4OGYl
P8B7QhN7QXN=UinRXjBVYZ:QXjRZYj>QX9nMVifRYJJUXj:V[K>b[:R[[JbYYJ:M
VIRGU8n=SI2BT8j@TiJFTXn<RHV:R8=nNW^1R8nGW9VCSX^;SHZ2Mg5dNGeoOgig
KfUXK79eLVi[Jf]YJ6MXIV1OI6]]JFETIFQWHV1TJVaXIFEVI6=UJV]XIFEYLGIh
NWeoOh25SIFGTXR3P821PX>5Qh^>T9FIW9nRXIbETIJOXj:MV9FEUYJDUIZNX:2O
W9VFThn<Rh^<RXN5QH9oO7]nQ8V9R8V=T92ATY2:QXJ;Si2>S8b@UIVKW9nPW9JE
WJ:LSH:6TINGTH^6PX63R8Z6OgQfMWIdM7MjN6iTGfAYIf=RHV5NGF9YK6QSH65O
FUIGGF1QHF=ZLGAbL75dM75_LGMjMW1aMGIcL75gOH63R92EUYBBSh^6PX:7Rh^7
Ph60OWalOX67Rhf;RhfBUI>>S8nBTHj9QXB3Ph>3PhF:S8f<SY:CTY2=RXZ<T9:A
TI:DUYfUZj^QVINNYJ>IRGikP8B6QH9lLfa/KgAcLG5bL6YVIfa^IeeHFf9THf=X
K6USG5]LFeUIFeaIEeQMHf=QHFI^M7AcMGUlNGAbMG]oP7ilNWQgN7aoPXB6RXj@
T96DUI>BU9NJVYNFU9BDTY:EVYnOX::VYjV[ZZNPVifPWiR?S8b@TY:EV9bOXZ>T
YZJUXI^FTi>CTiBDTY6BV:2UY9bDTiNMWYZ?Q7emOh62PWmkMW5^KFi_KV]VHEeO
IVUWH5aJFeUGF5]OHF5NGV5SHF5RHV5TJVmaLW9aLGAiOh61P7mnO7b0R8jAT8j<
RHN9SI2DVInTYZBUYjRWYJ6PX::TXj:PWYnPW9NCTI6GXJFTXZ2NVYNDTXj8Q7ml
NGUlOX21P7mnP8F8QGejNgYhMWMgMgIfNWn4RHjCUI:>RXbBUHj0MGInQ8>0OGYf
LFi`LW5_Kfm`L75cMWMbJFASIFAOG61VJFIPGf9TI61PIVYXI69SIVU[KW=jNg]n
PH5lMG1bMWUfKfYYK6i/JFY]LWEfMgYmPXR:Qh5nOX:5QXF6QhR8Qh9nOX64QXR<
SXj=RXJ3PhF7R8N6QhV<Si:EVj:WZJNRXJ>VYjFQWYnPXJBX[:j`/[Fi^;Bb];[2
_k:VXJBZ[JZVXinKUiBBSh^8QhJ6R8N8QX5fK6ITI65LFUUJFUMFFEiOG5MDEEMI
GVI]KVYYJfiaLW5aLW9^JFU_M7IeLFi^Kg1cNGn3QXR9RHV;Si>ETH^9RX^<S8j?
T92@Si:GVY^LW:2VZJNSWY^JVYNASH^:S96DTHf=TYZOWi^FTY2<R8N7QH5oPXJ8
RXb>UIJBR7mlOhN7OW9YJ6Y^LG5`KF]WIfQXJFQWIfU[K6e^KVQNF5UOH5aHEUIE
E5IKHF=QHF=UI6AZM7]nOG]lP8B4PhB6QhJ4QH^?Shf=SXj<RXR:T9JHVIZKWJ2S
YZFPVINKX::PW9ZKW9^HUIBFVI^IUiBBTHn>S8MoN7IhNW]kNgamOGn4R8V8QXJ6
QXB3PX61P823QXN8RHZ>UYfNV9:BUiZGS7mjO824QhJ3OWYhN7QeLW1aLW=cLG=b
KFEPHVIXIVATIfUYJ6Y/KVm`LgIgMWEgNGYjNWUiNWalOWn0OgemOh:5QXAoOGn1
PGijMWEiOWmnNgUkP85oNgUjNgUfMWQkOX20PhJ8S96FV9NGUYJDTHj<RhR5Q8J9
RXV8RHb?TI6?T96@S8R7R8^=T96@SXjAVJ>//ZnYY::UZJFGR8:8TI>BT8j;QhF4
Ph1oOh64QHJ7QX9lLfaYJF]ZIfMVIV9KEUQKGE]FDU5GGfI]L6eWHV9XKW1^K6mb
LW5eO8>3OGMfN7YiM6m]KgEjOh:5RXf?SXf<Rh^<RhZ:RX^<S8b;S8fAUIVMWYnP
WIRCTIFKW9bMWYnNW9nSYjRWZ:NUXZ6QXZ:OVINGVYjPWinNVibQYZRSW9bQYInA
PgenPGmkNGQhLfaZKW5aKVe_LW5[IfIWIEmJFeeKEU=DEeUHFEeRHemLH6IYIfIX
K6aXI6I[Kg1`L71^JfabNWn0P820OgmoP8:5RHV<TYBGVI^LW9^FUINKWijJV9VK
ViRIWJ>WYZFUXYnKVYJ@RXN;T96ASHR5Ph5nOGalOh61OgejNGQhNgmoOGf1QHN9
Rhf@U9>?RXN9RXV0M71bN7YhMgIcJfIWK7EhNWamO7UiO7mlM6QQHVMYIfEYKg=b
LGAiNGYnPXJ8QXB7RhV4PXB8RhV4PXF8R8N9SHn=R8B3PX1kMWAdMGMmPXN7Q8:4
QX=mNWaoOh1nNg]kNGQfN7j0PhB2Q89mOh5oO7f3QXJ4QHF6PGn2QH^<S8f<Si:?
SXj?TiBCU9JCTY>FWZJ[[:n`ZJF[/JnSV9:CVYjFSXn@ShZ8RhZ6PhF8QH5oPHF3
Ng=_L7EcK6a]KW1]K71bLG1cLg1^JVEUI5iMGEeRHF5SIVISHV5VKG9cL6mbM75/
JfUXKGAkOGn4QXN;SHb6PhbCTi6BV9^FU9RPXj>RXjN^/:fZZZVY[;2a/:^UX:2U
YZ>UZJJUZ:JRXYjJVIVGUI2?U9RJUI>IWIfNWI^DRh:3R8IhKFaXJF]XHUeLFUIE
FUmMG5mSIF1KFEICCT8m@TI0?T54AT]<ATUFH5iBEf5LFEQAEEUEFEaMH5mNIFY/
J6ETI6IYKgAfO7ajO7eoP8REVIRCU9ZIVYfQX:2TXInQXinKUi:BUIBAUifHUIRP
X9J@UifRXIVDThb=TXj=RhN8SY6@Shf:QhJ2O7b4QXV=RXfCVYfQYZR/Y9^LZK>M
Pgb2RYBFTi2BUi>@U9VHRhNEV9B6LgZ9QGb1PHN7PHJ9Si26PXF6Rhf6QHN:RhMg
LG]fMG1_NGmlMWYoNg=ePi2@S8R1PGeeNX1lNW=_MXN=PWn1Ngb4R8MoO81hMGQ]
K6UXMGehJVYbOHZANgB9PgUaKWEhNGYdLG1]KFI[Q8^@Q6=ZNH>5JFB2T8EiNX^C
R7n<YZbGSIVMXIZ;QGijPHF2RiJYYiF?SHb7O7n4PXB3QgQTJ6aYKFebKUaJLXN1
MGMmPH5bL7UbH5MOL7YUF61LJGmkJEeZNfMLO9jVQG5cMXV=NG>BWgaaQIZWYinJ
YZ^VYj>IVkVnUINMUIf?QXnXZYRY^:^M[[6MYk>/UYfcXX9lVi5mPHBU/IZCTH^8
QhR?TXJ7TX9bRh=oShjKPW2>W9VBQ8jBP7=fLF]gOH69PgEmOgMdKEaEJFiNFFQR
DDI2@DQ1BF=EAdE=HemMGeQBEEE6CEYUGTM<EEEXMGZ6O6ERN8RAT89lPhN1QX^>
RWnGUWJM_j:CTj[2[i^T[:fg]:f[Xj2XTh26PXJ=SZ6[ZYVMZJ>SWY^FX:^BPi69
OX>4OXZ3N7YeRi^@N7N4SGehQWE_KWBBThbHYJ2ERHRIY9inMGajTJ6@R89lQXn=
P8ZDR8jOV7mYHgJCLDQIIg9kL6MRETA7K79NIF=JGe]?CDi=F5a@G6iFCFiVF5mZ
N71FEVMcOWA]KV9`O6A=H7MlLGf<QhBBThZ?RXB=Rgj;VGiUKX9lNhb6NX22QZFb
T86@SYZVVgn3ThQmPX::WiJ9RKF_P86Q]J6>W9NEVX^AY9ZO`;j]ZL7DYi^e/IbY
[9^4NX2S/iBD/L>GJgj@T:Z^SX:3ThYlT9>1HfYbGe9NQYJ8Lf5bLVImNVaaPhQI
Fga`G4]SMWE_JfIgOgIXJ75dPGm]EfEbEEEhNfZ8WW=_Rh^>THjCWJJJR8^;NX2H
QGAfM8Z@PGb>VYZ1N8B0SinQSGAYJhF7RHMNIVIdNFnCNFAcHFJ1XiYPRKF:DG24
UZV@WJR]Ne>7/:2<[iaIT[FJSXn>S8^7VI:BQhJ1FW>PRgmUTJEbCUIXLg]SKGY]
NhehKE=GOI=hEVYkJei_K6IaTGMUQHAiR:>@ABMoYG]ZLGJ7L6^CZiIhO8JGTWbX
b[R<JgnBSi2EQ6YRRhEiQ96:UJ>CNgR=WIZMPeml/j=iEUQjOHmaIh:FVWUdRiR4
NI9`G92HRHn>WiZ4W[B/YZFCVZ^TU9BDU:ZJLgZJZIb8OGb6U8j/^HURNjb8IHBJ
XXMDBT]UQ7QYJeeRQX=7=EelOU]EJFUiNWQ^If9TLhV4NgUZH72ETGEmPga^P9F;
TIFCR8RV_iB4QXfU^;FZSgRI]mO9V7ikTi>KX9F?Sif@Oi:dWWE/P9=aN924LGN2
NXfMNffBX9Z;N6EdVJBFHEMfV[2CNH>ZYXjY^i:H]YV@TI^TV9j8LI:/TX=XEgZD
VX]QGW]`HfaKG79aJe98F4a;IDeBJUIGDdiBEVMZDD1?HDa=KfA2I7AHEgR4K6UQ
Df5UKGahJ5QaU8QJL:5iJ7iRFg><ShN<QFA^IE]aRX1FGW9^M9^`OF:6RXV3Qj6B
Qj2AUYN?TWY`KFb5QfefTZ6RYI=kU:NSV:6]YIfZ/[30]hnJVYFU[[JQU92M[J^P
Jf6PU7F4S8akS8^5W9n6LXBFWZjVRHF7SEmUUXUmPG]mMgY_F722IfMgLVIXNGf3
NW5]N8>:OWV9OH>8OgUdQ7MQIh6NUX=bQIN<OhF?O8JT[YV@WHUkRJ^YQ7V8RWn7
SWn=QgbJSH9fOYB7Vj]oLGn7QX>9Q8j:JgJM^IETJ7b4P8=mNVmKKhalIGBAQG9g
S99dRkRcSW^EWGYlU9:9M6A/UZjRU9IhGW9ePIJ0EUj9YYE^I5YVTI^4OH:<MV9^
PG1=D4iCF61VEDiPJF1@?e9RJ7N4PTi8QIR5QXZ;OXVWZZRSR7YjOj2b[:><P9bL
TYNEWhYlTi^=SHbH[JRMUJN_Z:naZIfCUIZHWKFaP7:<Y8aeR9b>OYbNUI1iMI2K
U8F5S9J[YI1YH7j6RG]dVj:6MgJ5PVIOO8mgFf9fOXB7M71gIVMeM71`J5=7D5YI
G5U=AeMOEUI2>D4`;T5>ADiYLV=1@61hQ7I`RhQaIWEnKG1oNg9jSJ6RQGZGZk6_
XI^CU:fh]jJS[JRa`knAPIjST8Z:T9^JXZB7M7>7TYN_WH1nLgNDU92<PIF@PjNc
Y9=hNiZSTX^6QHRGVWe_OYNBNfEgV:^TX/JiW:ZWWjnj_JInKXN^^:NMVI64QHf1
MF]eP8jHUiB8OhB7P8b<Ph5gQ85`N6mYPGmSFF=dKUMIIV9OCeUdKEXo;41BCfAU
EEASMfIONFmIHFeVE59MGEYLDe=RJ5Q:F6=[Je]RLWejNg9TMXR;THanQIJDTYnL
QWf2T9F:QhfCWJ^]XZBn]Y2La<Rm]K>`/kJg`KVUXK_1[ZNk_Znm^Z2FZ[:IW:R;
M7AnTIJ@UI5mK7N7UHf=Pee<G7b7LE]ODdeDHEA3@dI@FEeGC45>GF5C@U9WF6Ao
KE]OEU=bMFQWGEYWOhUiJV9`T::@OGUgQIRY/kBTVjFWZ;No^:2=UJZ`Wj:f[9ZE
Y;>SW:JWXZ>GPGbDZ:BSVGf8YZfb/HY]O8R>T966R8Z0LFEWK7=YGe]XNWYfLFn4
Q6e]PhmnKW]gM8:=Sg]/LW1VK5aAIFAPN81fIEQ`P7EaL7J7OEmVO7acKg]/EV=W
I6M^LF1KIVi`MWUnQFiKIgN>Uh=kR9N[ZJB[ViB>QXFFZZFFU9fQX9b?Qi68NhVC
PgAgOGUfNhUoNYBGP6UXMXJASgEOGUYZOgYbKVI/Si^BQhB8RYJNY:JQSX2=VZVS
T8j2SInHT9RWVXnNUXNEXiV5Ph^<QGf7ViNETX1eOX^<T9B?OWJ3W:NCQh:7TXml
K69IH71iIUEABV23P5mEJ6e^KVIQKWEbK5YOH4hm?59dOfi/N7=WKG5UIG27SXV=
Q867U:V/U8R>U8f7SIRSYiV8SiZPVYjTUi6JTX67U927S9^WXiZP];Zg[JFY/K[3
a[JSX:VSTiRUXjFQSYFRXJVm`;Be/JVW[kRZTH^GXjbYV8^6OGamNW1UJWMoOWMX
Ig5`JVYUJ7=_Ge]RHeYAAT=6?Ca5A3hj<ca7@dM>A3LoBdLa<D9;DdmDK7UcKWYk
MWEXFUe[MhfFPgQiMgJ0PGAgQ8B5S8jAVI67RHJ2Q8nKW9NIYK6YT8F2PHRBVYfE
S9VQWiNDWjFUYZRWZjjd^:fg`kNXV9>LXIfPXIfPYZNLSi6CQGamQHQmN7QfLh>=
P7eiL71gP8Z3M79kOWUhMG9kQH1aHf1SKW9[HeaGFfIWGE9MJg1/Ig5fMh9nKVe_
MGU`JWZ4QX=hMWf7Rh]nN8JJX:6SWZ2UZK2c[:2HWj>KTHR2RIB=Qhf;SI:;SI62
MVaQHFQdN7^1N6MRKX>4LFicMWf1NG5_N7mdJg9jNVaPKW]oRHnFW921OGn7U9nL
VIVJWIVHUHajKFafP7U]KgEhO7I^M7akO7n6S8Z5P8>4OFmZL7IaL6UPJFeWKgI^
IfEYLgYnLEU=DfUhOHNATXZ3TZFZXHZ4QX26TYRCTiB@UIV>PH20O7f2P7EdLgEn
O7AcOiBNVI>BSi6DT89mMVegPH67SiBMVIfVZJFLUYVDSYRMWIVNYY^=SHfBV:6P
YJnVWYJ<T8j5PX>=RX:3Q8=mLg=hNGa_HFEbQHEgMgQhN7N0S8UkKFYWGeaIGFQY
Iem8B5I7?TiDF5aQJWEfL5mDDTeAGEaEGFM[JFn1PWQkOH22Pi6Q[K6[/;J_[jjZ
ZZZe^J^SWi^QYjRVWibHV9RKViJDShAoPhFAW9nRXijW];2TXjV/[:fi_[:QUiJG
Ti^VWYNJXZJRZkVcZ:>MV9FL/[J^Zj>NX9nPWi9iK6e^LWAdKVU/LFYOEE=MIFUZ
IVEUG5QHG65MEUABAdE;BDaGFeQ?B4iAEUUADTe3BTiBFEQFCdYIJ6ANEUAOJgMo
P85jLG5fLVQYL7ImOgaiMVm^N7E/JfmcOXbHViZLUXf5OHF<R8V=UIZGW::IU:2[
[:BY^[jfZZN[Z:RWYJbZXJ6SXJBZYIjPXY=kLgZ7SHR1OXJ;R8V9Qh20PGakMFmc
LVe^KVe`OHF8RX1^I65UJ6IWIVARE4eJGeYHF6IaL7=gOhR:RXAlN79bMgQeO8>1
Qhj9QXR7QX^?UJ:^/[O2aKfg[k2c/Jn[[:ZKV:R_Z:6LUY6BTY^VXIRBRX1gNH21
PX=jL7B1QGikRYfNTX^;QX9oMg1^M7enMW1mR81lQ96BQgeeKV]]NXF7RXMnNgMk
PW9PJ7V8Qg=YL7YhJVEXL7j8RXbCU8f3O7YjLfYWJVQVJFmeNGf0Ogn4QGa`KWEe
J61QJGb2PXIlKfe/JVe^K6ihP8>8RhV3O7E]KGMoOh1oO89mJf9^PXAoPX:8TYNL
WiN7NWEbLG5cNhR@Shb:RHb=TIZOX9Z?QhJ?W:>SXY^CV:>Z[:BSZ[6n`[VZWYR?
SHb>Ti6AVJ6JTYFIThEoQ85dL7^4QGieM7b2QXEmLFUXHe]PHE=;BTa;AD=4@c`j
A4E6DemQFUQGDD]:C55FFFQcKF]^KVURHfM/LWMhN8FGYZj/Y9VCV:2VWiFIXIbF
VinRY:BWZ:JSX:BVY:>SWYJEVIjZ/j^NWJVc[kFo^;Fc/:VUZJj]ZZ^ZYj>T[[2/
Z9jKX9jESXJ1QXZ7Qhb<QX:3N6e`L6eZKgQdJV9OHV1CATYGG5aOJ7AgJemMI6eV
DdmED4E2BeEIG5IAFFE/IeiNHf=MFE]QIfINFeYIEEYVKG=fO8:4Q8R>THb7R8J5
RXj@THb=UI68P7]jOXJ8RY>OWYVLXJ2JTHZ7S8j8SYVKUYJET9BNWiVGVI^ETibY
/k>ZWIbNV9FHVYJDVInSYjJLTHN1Oh63QXb?RX61PGijLViaMgUhNh69RH1oQhn<
R8^;R8AoN7IhNGaoNG5[HV1RHVAVKGZ7SHQoOh=nM6YSJG1_L7=bLFe[K6acO81o
PX^CWjb[XJBTViVQYZ2JVIVJWI^IWZBRViZOWYFATHf>UI:4NWM^JW=kNW1/M7f;
VYbCTY^KSWmlPHV:QHF8QH:;VZ2LThIlNh66SY>BSGagPH^DThAfM7^2Og9aO7ia
IVYaLfmYKGf;PG5cNWn5OFe]N7I]JFUUFUURIVacKF=SKgE^I6I^KfYYJVIPFeUO
IfINF5QMK7YoOWinNhN@R8F<SHF5SI:?QHBAW9V<OGZ5TYRFSh^?UIJFU8f0L75j
O7j2QXV;S96<Q8>2PXRHXinEUjBYYZ>NUiFJWjRd]K2[[kNg[Ib;PhN7QhAoRING
T89lOWQ[JWAdJ5iMHFYdLW1hNW5VHfY`JeiFGfi`JF1PHUI6?ci4CE1@EV5YHeaL
GV5KE5ILI6]^KFUQGEUJGeYCF6IaNH:?Ui^SZ:JSX:6UZZJNWZ6RZ:fb^[^g/:^[
ZZFPWj6ZZZ>OWInRXJJVVhf7Q8REYZn[XZ6UXijOWj6VZj^/[Zfb_<2i/JjXZ:fZ
X9VIWZBUXJ2SWHb0PhZ;QG]hOH1hK6MSGDm9EFI^JfEVLh5oKEmSHUA:CU5@DE=H
FeUFEEMMIVMNF61^KVETHemHD55IFUQFDU=NK7AfMW=hPhR9TY:9Q8:5Ri2>QXF9
QGagMGZ4R8V=SX^@UYBBTXMcKW^<SXJ5Q865RHImMWZ5RI6OWYB@TiZMViRBT8nB
VIjMVYnSXZ:QViBBT9>JU8EmOXB4OWenN75aNH5jJemTLgakM71aNGmgJF]iN6m_
N8>3N71[IFI/KV]/Lgb0RiZISHN<THIcJg5oRhj5Ngb0PX5lMWIkQ8V8TJ2RXJZc
]JbLTiJJUiFLY::KVIbPY:2CRXfEVi^EU9NDS8=mN6iZM7]hMg]oQHjFUI6BTHZ1
OhR@S8B1Qi6JVYBCVYjMWIfMW9RCRh1nRHj9R8b9OGQmQh^6OW^1QGmeLG9_IeYD
GFedK69WMWegJf9QHEeLGf1QIFQWIFAUIW5lOWE[JF][IEaJHVYWHF5VIV1HEeeT
J71eKfidM7EoQX1iMgf9U9:>TIB=QGYcMGj4QhfEW:BUWINFShR6SIJFU9^OVIFD
U8n;SI2KZJfYXinS[[>`ZJ:MX:N_^<75_;6[[K6YWHenO8F>SXnBUYJBS8AoMVm/
KgA_IfQeOX5eHEEHI6UVI69RHf5SJVMMFeYDCTi<@d56BeASKF]SHfQWI61MH6]j
OWM^Jf]ZJ6AUHUeSL7Z3S96EWJNYXYB4Q8jFWZFRViJEVZ:YZ9nFT9BQZJFQXZJT
WYR@QHB9RXAnPHZ@V9jRY:2IU9JQ[:^QV9RNZ;2`[:bf_kbe[JBLWJ6NThf<S92G
VYF>PWQjP7eiM79dLfaSG5aMFe]PKganN7AbLVYICTiEH6Y[HUeQIFEXJVEQIVe/
KG1aK6MRGEmUIV9JDDi?CTY6BTiEGF1OIWAmOW]fKVESIg1hNWUgN7]eK6YcOXRA
TY6FViN=R8Z>SXV9SYBLX9Z@Rhb>S8^=TIfZ[jfXY:FX[ZbPUYJQZjZZ[Zn^[K2b
/kRiZYB;SYFCSHb>SXJ1PGmgL71dNGQaJFalPWaaIfYhOWQ^Jfi_KG5`Jfe_KFQY
Kg=aLgQiNgn3PgiiMGImNW5[K7J1Q8=nO7egKfEOHVigOhZEW:>]][J[Vi2=TiVM
WYjQXZ>V[:nZXI^EUYfPWY^IVYVCRh1dMH27Q824R8R:SHb7QXF1PHF6Rhn=R8R?
UIF?Ri:MY9jDRhZFXjBFQg]cLGAjO7I_KWV:Ti6:QHAnLVISJW5eLfQYM7QdK6ie
N7IfMGElQH9eJVY]Lgn7QGYcNHN>RHB1OWacIUiQJ6a_KfaWH5I>BU1JGf5VJfaa
NhB5OgMcN866QhN:RhR2NgIfNXRDU8n>Si2>SY2=S8b9QHfJWI:8Q8:0P8:2P8:;
U9VIW::XZjVRWYnOX:Ra^;fm^;6YZjjYVhb:TYZNW9NDSh=lNGMcLGIlPWmaIVAX
LgM/GUYNGU]JFeaMG5QCEV1ODdY8AT90ADmIG5eQIVAKF5aPHEY@DeiYLg5TETm>
CD]@GFYbNXN?TiVMXJ2DQh>:T9>GVYfOWifNWIZOYjZ]];Rf];>a[Z^ZY9RAU9fN
VIVHShZ@W:JUWiVEU9>HXJNXYjNZYj:VZk6e]k6XYJ^i_[:PTh^7R8jDViN;QHV@
SH=dKFeYIVYbN7UdIfA^LgAaLGMjNGE]HV=_Mg9/L79aL7IlOW]gNX21NWIgMg=S
EeMKFeUHFUaMF4m:Ce]RHV5PI6Y_MGb1NfiVIfieN7IfMG5[JfmfPX^<Rhb<R8>5
RhR5QHB2PhV=Qh9oOG]lOh>6RHZ:S8^:SYJMWiJ;QhV>U9ZR[;>g]:ZTZ:bUUXZ7
Ri2BUIbQX9Z@RXF0PHVFV9:<R8N;R7QVGf5UIFM`MWQdJV9SJVi/IVAXIUmRKGEf
MGAaKFQRIG9jM6YXL7b3P7]dJfMUHEmTKGInRI:HVYbOY:FOV9ZU[[6e^KJZWYZJ
WJB[[k6e^[N^Z:JRWijKT8>1Qhf;Qh=lMGIoQXN3P7aiMgUnPhJ4PXB7RhbAVYjO
WIN>S92AT8UkJf=SIG:1RHJ3QHV<QgmlOWefL6e]KfeXHfM^KVUWKG=eM6iWHVAX
JFMYJVEOHFU_L75eO862PHF>UiRBRH>1O7EdN7QcKVeZKG=iO7]kNgf2RHn?RH9o
PXN5P822OGMhOH>=UIJARhN3Ogn6SI6ASh^5QHV6OGIbKVUUJG5iOh>6QhV;S9:O
Z:JOVi^QZkJo_kfg[JNZ[ZbSV9BJXjFSZ:f[Y9^FThf4PXV=RXJ1P8B8PWE/KgQj
NWYiM6iXHUaKFUA;B4eEF5QLHFIVI6ARGeYIHFidLF]WJg9aK6AOGf1NF5IMIfmh
OH22P867T928OWQhNgf2QhF3PhF8T9VSZJNTXj>RYjn_YinITXnCUiBDVi^CSi2G
WYfHUYRKVIFFVinOVYRJW9jQYjne]K2/[K2]YI^CUI67PXJ;QGelP8F1NWf7QgY`
K6e_KfeUI6a`Ie]KIVm]If5KG65SHV=WIf5MHVmhMFmdNgahLWAgMVaRHFEZJFQW
JFe^JEmLGfA[L7AiNWQiOWmfKg5dMW1YKWMlO7j1PhR?U9B@RXEoNX2>U9:>RXJ8
T926P8F:RHN9SI:DU9FBRX1iO8RCVYREUYfV[;2]YjBRWijRWYJ>SiNJUi:CUI6@
UI^MUhnCWYjCQGj0Q81eJ5iNHfAUIf]/JFQXIfESGUYIGF9TI6Q^L79gO7]fKVab
O85nOH27RXR4OWE_KfmZJ6afPhfBU9:<S9JMV9NLXZBPWJB^/J^PV9FFVj6PWInS
YZN]/JVOViVBSHf<QX:2PGikNgenO7^0RHf:RHf@TY6@S8V7Q8V?TiRHUY:@SXR1
NW]lN7AeP8F1OGUlP7]bLGMgLVMRIFMTGU]KGEeFD5=OJFYWI6=PHVIZJfMSHF5U
Jg1bMhBEWIZFUYVHU9:DVi^DSHF1P81mMFe[M7j2R96DT8j?R7adLGAhLFU[LWQg
LFi]LWf9Shb8R8J6RHj?RXR;SHb9QWmdKFiaKFYbOHJ;T9FDS8B4RY:FUYNLXjbf
^[>XXZ6RXZ:MUI:KYj^SUi>CTXn=TiF>R8Z@U8j4PH:2PX9oOX63OWYnQ81eKg9c
KfURFeQIG61UIfY/L79cLF]TI6U/JfMTIfe]IV5MF5EFFf1OHVagNgYmO7EbMGYk
Mg=fNGYkP8N9PgikO8:?WZ:NX:JZZZ^][JVXZZVVXj6QXIjMWIVEUI^OWInWZjVU
YJNXY9jMX:B[]Kg2`Kfn`l:m]ZbPWJFRUXj?UIB=R8V;Qh5nP7mhL6YWHEaJF5UK
Fe=<CUMKE4mBF5]KFU]MFe]NHf=RIV]aNX65Q85nNW=]K7AjNGMfMGIfLg5]IVA[
M7QkP8B2NgAdMgEaLWEeLVmbN7QeM7IkQ8^;R8N8QH1oQ8R9Rhb=Shn:Q7aeM7Mi
N7QnPhF8S8UoM75dNWanQHbFWJ>UX9B6PH:8RH=lMgj7RhQmMgIgN7b4R8V5Q8V9
QGijLfaZJFY/L75_KgAnOWI^JfmdMGEiNGEiQ8b:Ph23S9BESXR;TIFDSX^<T9BD
THj:Q8:1Og]jOhJ<Si6AT92@U9ZMViRKWijOXZ2ER8:4RiJJUYJKXZRVXYjKVibL
V9>=R8J4OWMfN7YoPH20Q8bCUiNETXn;RXb>TiNIVIZHUYZIU8n:QH60PGecKFid
NGMbLWIhM7=eKfUWIfAQHV9QI6QXHEQJI6QUHV5RIficMW1RF5IMJ75eLg=lRHn=
RHJ6QHB4QHN8QhB1OgQbJf9LGfYeOH68SI2:P7]lNgEaLWAaKg9jPhJ5PX::U9bO
XjBRWYfMVYJDTHf;RHV:RHAnNGEcMGUmPHB6QhN4Q8J<Si2ATYVSZjn/XYVJWjBR
W9>;Ri>MXIbARHR9R8J5QXN:T9:>RXR4Ph>1OG]kOGmoP8>1NW=]JVQSHF1MEeIM
J75aKFUXJfm_K6QZKW1^JFQZKFi^KfeYIVETHfE^Nh>5Ph5nOWn2QhZ7P7]kNg]m
P8:2PhB9T9BDTI:HWj:QWiZGVYbKVIJFVZ2QW9B=RXbBUiFATiVSYjJY[:^WYJJ/
];[1a<C2`Kni/J^VXj:TY:6JTHZ7Pg]fNGf2QHN2NgE]IfARGUQDDE9BC4aCG61Q
H65RHV=WJV9FCTiDGFEXIFI/LgEaJVU]KfmbMWb0P7mkN7A_JVIVKgb1PXF:SXn<
QhN:Qh1kO7emOH69Shj8P828T9:@TiVLW9fMW9jMW9bGTi>BT8b9QX9oP81kN7Uk
NWEcNhR?Shf>SY2FWIfDRH1mPXJ7PGA]LGQkO7UeMGQlOX1oMfi/Kg9`K6]^M7Ia
If5TJfiaNGimNWMfMWMfM7=fNGUjO7alOGenPhZ9Pgn5Ti^IUI:BTY>ETHb6P7el
N7ImQX^?TIBFUIBHWIfGTY6?Si6BT8f9Ph24S9:CTIBKWIbKVIFBTI:>QH20QXV7
OgAZJ71iOGeoQHjCTHn;QX>2PhJ8SYNQZ:NPVIRGV9J?RXR:SHn@SY6@R8:2RHV3
O7QiNWamO7YgM6aTIFUVHVUbN7E^JfMRGemOGUeJF5YQJfiZIVIZKfeWJG5hN7Uj
N7EcLgEfMFmXI6I^NH:5Q822QHB0OWmkMG9dN7QgNh6:TI::Q8J@UiFDU9:BUI^O
WY^ESXV8RX^7QHR<RH>2Q89nO829SXf=U9ZKVIFCU9^V[JjYXJ2SZk6`Y9B<RXnA
SHEnOh64QXB3PGmmOWikNWUhM79`JVU[JfQZKFaWGeMCDU9BE5MKGf9SHF1OGf1S
IfYWHVA[L71^KW5dNGj0Ogn2QXAkMWEhOXF8RXnBSHR7QhF4QXV:RXb<S8b<S8V:
TYVKVijOWIfNX::UZ:ZUWijOWifJUHb4PXN?UYFDVIfKV9NFUIJHW::Y/;Fl`<30
_[^i]ZfRViJCUINIV9NCSXR8RXR4PX:3Ph>1NW1YHUaLGUeIFfA^M7=aLG5^JFIT
GeYHFF5]Lg9/IVIYJF=RJG5fN7^0PhB5Q8=oNW=]K75gOHB9R8N9RhV6PWijMgIg
MWAfNGj2Q89kN7j9SHf=RXZ>V9jNVYF@S8b>Shj<S8^4NFm/KG1^KG=iO7eoQ8R7
QHB5QHV>TXn;RX^?TXf1MW9aMWn7RHN6QXF3PGehMg^0P7ejMVmXIfMTIVa^Jfae
NgQ_Jf]YIVQ/KW1dMgIeMgUkOH23QXV:SiBFT8N5RXn@TYBCSXV7QH:1PHB9Si>H
WIjMViZJVYZKV96:QXF3PhF9R8R>UIRIVYVFSXN5R8bAU92:R8Z9QhZ9OgAbMWj7
Rh^<SXj<Rhf?ShnAU9FFV9ZHUi^MWYjJTX^9RY2GViZFTH^5P7moOG]iNGUhNW]g
L6aXHEeMGU]HF5eQHF=SGEICE5IHG5mMG5eRJVi]K6aZIfQ_NGinOWmmN7AbLFi_
LgAaLG5cN7akN7QiMgEdLg5`LG9bM7EgO8><TXn:RHb@TiVOYJJUYJ>OViZGUYZQ
XYnPXj2GSh^;S8Z9SiNKV9FGW9nNViJDUj2WZ:BQWZ2UZ::ER7imQ8f?R7mjNGUk
NgQfN824Q8>0NG5bMGAbLG9aKV]YIUmLGEiMH6EWIFEXIf=LEEAFG6=/Lg=bLWIh
N7MhOXF=TI29QXF3OgahMWV1QhZ:RHV:RXZ9R8R7QhN7RXb;S8j>SY6DTXj=TI>C
U9FFUIRKVIJEUiNDTi68Og]nQhf;QhN9Rh^7QHJ9S92EVYnUZjn`/k:_/:nZXY^G
V9^LWIfPWiN>SI:EU8b5PWenP7egLFYTHF=XJFMYKg9cLg9_JVIVIfIWJ6IUI6AU
IfMVJ6a]JfY/KViaMgeoOWemNG=_K6YZK71fNGUkP8J<S8N0MVi]Kg1`Kg5`LGIi
MG1aMWb1QhjFVYfNVI>BUIRJWZ>SX:2SXYR9OGYmOGf1RY2ASH^<SXj<RHN:TYRG
UY>ATIFHU8b2Ngj4RhZ7QhV:QH5nNg=[J6UZJVibMGIdKFIUJ6UYK71`JfAQHV=T
I6=SIFIVIFM[KgEiO7j0OgenQ8J3Oh6:T92@U9VKViNBSX^9S9:HWj>WZ:NVYZ>N
W9^IUYBEUI>BU9>ASi6DU9BGVibLW9RBT9:CTI6DUiB?SHb:Q7ioQhf>SI6FUi:<
Qh9mNgenPhbDUiNFU92BUinQV8f8Ri6DT8V4OgYeM7QkNg]mPHJ6PGYbJV=MFf5Z
KF]ZJFUYJFYXI69OG5mVJVUVI6MZJF=QIFa_KFa_LG9eNGj3Ph1jMG5^KVm`LWMj
Ngf1QXN2O7QcKFY/LWAbL75`LgQmOWf0PX>6SIBGUiF>QX:6T9NLXjR[ZJJTWiF9
PX62PX:4R8Z9R8N8Rhj=RhZ=UI^QY:BRWinRYj>ER867Si2?SHf;R8R8Qh5mNWUj
O7ahMWMhMFaWIfQ]LG5`L6m/If9RGUI>BDU=CdmDGF1OHFMZIf9OH6I[KG1fOHB8
RX^<S8b<RXV:R8J4QhnDTHnDVIVCShn>RhV:RXV9R8N9RXV7Q8:3QH^BUYJFVZ2O
W9^KW9fJVI^HT8V:SHf;RXZ<SXf?TYBEUIJFUYVLX::UZ:NTXjV^[JBOXj^_[JJQ
Vi>:Q820QHN5QHZ<R8=nNgI^J6Q]LgIfM7AeLVYUJ6mcLFa[K6URGf=VHeiNI6eb
L6icN7UeLW5fNWQcL75bLFi[KG5aK6aeOh1mNW]lNWQhMG5]If9QI6MXJFeeO822
Q8V?TiBBT92@T96DUYRHUI>HViVFUIBBTYFHV9NCSHN3P864QXR<T9BEV9nUY9jI
UiF;Og]mPXN:SHj>S8QnMWAdL6eaNG]hM7MkOGQ]I6AYK6][L7MfKVIRHUmGDUIL
GeiPIVa`L6m`M7UkNWb3R8N5QX^@Thn;S96CTY:EUi>=T9^SY9jJVYZIUiBBUIRG
V9jTZJRSX:2OW9^LWj>TXZ:SXIfKWJ6UY9jJVifKU8n?SX^9RHZ:RXb=S8R6QHB2
OWUdMG^5TIB@RhfCUI>@Rh=nOWmoOh63PG]gMG1]KFmbLg5aLg=cLVaXJVi^J6IV
IfUXIfU/JVMWJ6QVHf1MFUUHEUMMIFU[L7MkNGIdMGQiNWf3QXB1PH9lLF]]MGj4
QHB5RHV2OWikMG1^KW1aLWMoQXR5P7n4RHJ5R8j@T9BJWinIT8Z9RhZ9Rhf>S8f@
Shb9RHR7Q860Q8V;RXN7SYZVZjbYYInKWj>OU8f?TiNJW9R@RX9jNGj3QH>1PX>2
P7moOGUdLW=eMgYoPX1jL6ENFUUKGf=WIf9MGV1OG61WK75hP8N;RXB2PGiiM75b
M7IiNW]mP823QXN6PX24QH5nO7]jO7enOh20OWamOh20PhN9RhjATi6=RXb@UYZM
WYjMWYfKUi:@TiJGUY>?SY:CTHn;R8J3PH>9TijX/K>/Y:6UZZ^UW9FDVj:TXZ:P
Ui2<Rh^8Q8B8RXN3PX>4QH9oPHB3OWUeM71WGeaOH5iNHF5LE55EFU]IGFA/L6eW
Hf1QHV9UKgMgLg9eMG1ZIfYaLg=eNGj4QX9kN7E_JVY]KfmcNX:7RHN3P8>7R8N:
TINMXZJVXI^GUiNETiBIWYjKVIRFU96;Q8:4Q8:3QXZ?TI2?SY2DUi^MW9NCU9VQ
Y9jAPg]hM6m^LgUlNgakN7IfM71_KVi_LgYlNGEcLViVHfM]KFIOFeUIFf1SHUaF
DeAJH69PHVUcNgj1RI6AS8R8RX^:S96BTY>GVifNW9REVIjQXjNZYj>OWIbGTXn@
TIBHW9bMWj2PX:6QWY^KWJ6UZ:RVXYfJVYZGUIFFUYFDU8f6Ph:2OWQdM7AeMWMj
PHZAUIRHTi2CUibLTHAmOh>5R8^;QhB0O7YjNGMfN7YgM79_KFYVIfY/KFiaLgAd
LW1^JVIRGUUEDeEHG6=ZJVU[KW5dMGQoQ8AnNWQgN7YlOWilNgYkP8N8QhZAUI6:
QH5kLV]]L6i_LWEhO7]hMWAcKV]/MH:8S8nAShV6QHJ6QHN=UY^KV9BAT8f9PX20
Oh21Q8N9RX^<SHb9R8bBVJ2RXZ>TYJ:JSXR4PhN<T96?SXb:QH>1OW]kNgUiOH>4
Ph:1OGMbK6Y]L7=`K6QTHV1MG5UFF5eTK6m]KG5iOgmkNW^0PG]gMWMjNWUgM7Ad
MWYlOgefN7n0PhV;SHb9Qh^7P7ajOH>9Rh^:RXf=RH^>S8fBUiJ>RHjFViVEUYRH
UYZRXJ2SY:2KViVCShn@TY6?TI>EUinW[:f_[Jb]ZZJYYYjHV9jRWYjOWIVHViRC
U9FATYRDSHZ8RHN4OGYlNWMcLgMhMFeVHemHDe1>BDI=EUUJGV5QHF=NHfQYKFa]
LGA_KW9_JFU]JfidMWQgN7]hNWajNg]kO7YgMGUkLfibMg^0QHR6Ph>4Q8^CUiJC
UIFBTIBDTH^:S96DUifLUY6<QhAoM79lQXnCTXb;RhR8T9FIWYnJVYVETXMlM75c
LWEnPXF5QXMiKVYWI6EZJFa]K71cLW=eLF]VHEmQIFITH65SG5=@DeACF5aNGEeS
IfYiQ89kNhF>R8:6QHJ>Thf9Ui^>SYZRXijMXZJ[[kBb[JbRWYbHVI^JUYRNWiRG
VINETYJHVIfNWIVDVIJAVinGT8jATXj;S8nASXN9ShQoPH1nPH5jNh61R92DXJZU
W9FBUI:7QXF5RXf?TH^6QXQhHWR6LFmfL71dL6eXJVa/KG9bKgAjN7MeKfa]IFAV
G69UGV9VIfETKG5_JFU`MWZ1PGekN79_KFUXJVmcLg^1NGQoQhb8Ph20QHf>RHZ8
Ogn6QH62P7akNgYeN8:;T96BSXJ4QXZDUi>DTHf<SiJDSXf;SYBATiB8QXf>T9NH
T8b>UiRG/KbTWJ2MYjfJUZ6LUiRHVIVCRHF<R7YgN7AfNgMdOh9jOGmbJFeZIfYZ
LGAVG5mYKV]QFEQEEeQHEeIEFfE[Jfe^LGb0P8:3PGedIFIbLGAjPHJ1O7EbNH>7
RYJOWjFQR8VLSXF;QHVHUXnDUIBAT9B?RI:ERX^>SINKRXF9RY2?S9BESXZ:RHR<
RXAnQhn:Q96NUY2IXJ2SYjV`/JVVUhZBWZ:SYJ>MWInNVhYoOGQhNh64PGn6R8>0
OWenOg]hOhR0Nh:0MVmUIfaYI5iGGFAOH69WKVMUIUaCEfEZGEmXJ6ULDUiZJ69T
K6a/N85jLFieOXJ>TI2<QX:1O827Q81mLG1jPhf@SHf4OGf1TI21PH=kP8B5VJ:D
QH:>U8R0Ph=mMWJ6UINDV9nMVIbYYIBETX^EXjVYYJBPU8QnO8F9OG=]Ig1gKf1N
JFQKF6EWHE]CFfIPGf]cMW]hLWEkMV=KGUmMEUQWKGB0M6M^K6U^LFaXK71eNGf2
OGf9SHj<TIFFVZ:YXifQWijZ[k:e]kc0^ZbUWYZLViVNZ:VNVIjMUXj5OWUoTHAm
W:2=T8f8RXF2O79`Kfi_MXFAU9JCRHf?RHR2OWYnSX^>V9:;S8V<UIRIUYNQY9RB
UHj?W9fCQX:6S8n>RgeiPWedN7QdM6YQHF=UGe9HH5I?DU]PFUMNFe9HJViWIf]W
I6U]NX1aI69WLWn5PWUbL7N;VjV_ZZZaYiVJWIbDSY2?Q7]cL6i_MgYhMWAbLVmc
NgMhOgilPHZ=TZ2VYZFMV::YZkNm[JJ[YYF<UZ2OX:2SYJ>UXiRBTH=kNW=bM7Ae
N7j3Q8B7PW9`LfiWJg=gMfm[KFibMGAdLG=mOFiWJVicL61JGEUKFDmDGf1SI5mN
JFUQHf]gLfiWGUeIEEYTJ6M/If9YLgeoPgmeMgf9UZ6TUXZ:R8^S^Kbm_k^fZIjR
VHV5Ri2>TJ6`/:2ERX1nP8V<RhF9TIJJVHj;SI:FW::WZYfDWjbkd]_FeLZcVXIh
OXb@VJ:PWZ:Z]LK5_;k2`/77akN]ZInFRh>1Ng5]JFEPDd]@CTE9CUEVNWmcHeiJ
CD9?JGIgLFa`MgaiL6QZLWAfMgb0MWB5T81[FdmFG5Q=?CU3@T5:E5mHCEIGEE=D
EUm/MXRJY9jBRW^8X:ZYYL3Ha[[<e/:LK6o2i[b@WL2hSWZP_K2XX7aQJfUSK75S
EfF9/<2`VYR@QGa[Gf16100GFTTN6bm@G447004hDR0EF8=S=b0fAS4O82HI4BM1
?cmGGeeFEd58KibNNXN^[Hn:ThZPc=K6`<C=d[JJZKZn_/;Kk>K>f>WHb[Vcf?oo
ooo[hocjd/KTnoO]k>oii^Gaim71_[N/VHAaNYjRVI^RZKK5dlo5dMkLdL[4^;>c
YijFYLO;aL[:^JbMRWmgMW9[G4U4ADI6?Se9@B`W:S0a;S4f<RLL71`L82``;2XO
?4a1ADmTK65AAD0Z4a4I4PX610L30Q8N6QPL5`@=5PX64AHc?c<Y=T0g<S8]930l
ADiBFf=YI6=YMXF;SiRQVibUZk2ZZk>k`[^ic]S4Z:o4akoEn?[gm_Gfoo?6YI^E
U9fOY;kFk?_ji^3Le=70`;BTVh^BYJVVViRa`/cTn_o`fm7Dd/[2a/S2al[<a[^k
_[bcYijMUHUkJEI3:aXO:2deA4Q5?d96Ae1?AS/c<2DN;3]5DeQADf5UH6=^MFYJ
D4A1?3I6FEI8>CTn=bP]>CD^:2HZ?4Hi;cA9DTmEIG9lRiRPXY^CSHQ/L8B5VHUS
J7F3SYBHW:FaZ8YnQHb:OGEeO8jEVijY_/gJi^gN`/C8][S:_kO7d]SUmOokloGl
no?/kO;Xe]GYn_cgo_omnOg/dmWReLRl/;6m_jJP^LBg^<76d<k8`/30^<3EcZNC
V9fV[J6@U::YXXN5UHinL6UiRHb>QH:5S9R@QI2U[9f4KVEMCd4f70L=3000000>
4PX00000000000000000014S:SY1ATU2@d@k;RTM4adX:bXW7BTm=bTW;c]3?b`T
9ah>2Q0@40/751DC7BPX:2TS8b@V:cE:F5eRK7J9TXf8PH>2MgjBTHjO[J2IYj^f
al6_W8j>ShF0Phb?SiFZal6`^<K8_lSUk?CoooSTh>g_g[nPWjfg^k2^d>7QhLo0
]jjWWIJBQH>8SibQ/KVmeNG_mn[;^;:g]:NaaLS4alkDfm>j/lG?bk^[/KJ]WYBO
];6ZZjji`<?0]JNWZZne^[F^XXUiMWEgN7YfLG5nQge`HfM`JeE4CfUeKG1lNWn:
OFMLGEmWHeMXNW]oPH:5Qga[JGJ1T:JSQFefQhMP<R`i=R@L5@dP<Qh82A@];A<=
4b0X8RLhCfQnUIJ?X[W2bm77[IfJV8J1ViV9RiR/]ZJ:NW]ZDTeHGeQA@SU8FVYe
PHR9S8IjN79/OhbEVZNn_lC<`[[0^kS5aKng[k2`/;:dZiNGYk:WVIbJUiZ<PY>E
SIbSXZZ_ZY^FXj>FVk72ioooiloEgL>QOEeOMhN3K6AjQ7m`HV=KBTQ<>b/_?D8o
AE9GD59ZMgj6PGEZK7=]JWN2PGQ/J7:9RGUkSI>9MFQMCDa:=bd]:c51ASe0EUmK
F4a8BeESJW^?TiFRXiVLY:6DP71SFUmXGDeCHVmfPXb:S8UjLWR4OVQNK86AWj2O
]Lk>_jbV[ZBM^M3NiM2a]/g9W5]=FeIGBdQPOi^LRWQnTWaCAd51CDa:GgN6TinS
YK[7aKVSW9bAQX:L_;>OVj>[[JFAPWMeMFEBDUUJF4m4A4]BGFY_Lg^>W9>1OHJ:
T:2RXJ6PZjj/^lS9_jfXYJ6PT8>0Mfi`MWb1QHIoNWMZGDi5Be=8@5A^LWQlMh67
MfeeOiNd]jJBT9ZCOE4X<de7=RXU8Ra1@SDh@Sl/4@D;628L4b4mGVe/KGN4THio
MGYhGUM`Ng9^MXVQZYbBS8R7S8ioKgV;PW=dM7F0R8F2S9fMVIV:Nh>EWj6Z/Jnh
bM3@f>SUfmO9`/G9al>o_L3FfL:n`<35a;jbY9fOZ[g6ak^]Zk76e^Sei=;Fi>[j
ooojm?Sjlm>KNXF;O7EUH8B_]j^ZZjZ]XhYmNGEmS96@UYREW;30aK^/XjZbWh1g
RiR@NG25TiZWYI5kLgEZCSdl;Q`J8B`h>T5=E5iXIUHj9Bdf<cQ9F5YQNY2FTXj:
O6QGCeMQGE55BEIHF61WHUUFCDi??3He;S8g@E9QKFMJHW=dJfUbQ9bU_=cD]JBX
Yin?KeMEFE8j9C54E5Do=CDf@d@a8AhV:Bln@TmPKHNUZifEVJ2X[ZBBS9BMVHf9
Ujjn^:fVX:6AL6I`JfA^NX23QhR@XjNIShb8P7IcN7n6R8bM/l78blo?cmW>[ijL
X:FUXIjPYZf/V9>?O7^4PWYkNWb6S8ImOXNI[:R@NW^@YJbedN[Yfl6`^;RSMTPf
<2H_>ci7CEaRFeQ<C59<?cTl?d51AV1nPWb2Ri:IVIJCSH=ZGV]hMf=GJ7b1PWn2
RhIjHdi0=S/n>49GH6McPINRThEmLVQYKg>5VjBTY[;2d]2j/kBUU8^2NgUnPHRF
THjGUI6;Q7abMX6;RWiiN7f>W:FXXifPXjfgZJFg`<[Vn^oHd]kQ`8ULDeYOIF9J
GW9hIdTh@4Db7R<V8C56EfMaPHR;X;[:akjd[JVDOWV3TIFASI2LYYb6Mg9bLVE7
<C4mA3HY=U5XLW^3OWaiKF=OGeiOJW5`LhBGZkR^XIjMV9RKV9F>SIRPX9jRZZVK
SX^3LfY^JV1ZPHE_HGF@THn?QHRJYJ:[a]gWm_obf]?D_heD?cdd=CU3DV1oTh9X
GfILAc//:S]?H6afOhVK/<?GdL2o]Ij=PW^7RWQ_L7b<UIBBUHioOGAUI6EODe5I
FfA`NXVGV9>?Shf5PHFE/L71aMGKg^;Jb[b_XZ2WZJZRSh^HWYNDVIjPWI:6QgeX
JWb?X:6GVZ:LYkBa[9nFUj6]_=7Unoofhlg3eM2ED2lb?TU<CUaWKfU<<bde>S<R
6APH7Re3J8bL[;Jgc>CNb;Ve/ZBBTJBj^jfUY:NPS8=hIEM;=Ah@2@dN<ce5FV]_
MgecIEa>=RXbAUe_NG^5TYZOW8ekM7MlM69JDDM>FfAcP8>1N7^5KTa0?C@]:S54
CUQWIfM/KVibNGI]K7:8^>ooongAf^W8Od0^<Rhe<bm4LIRKQ6]TGd`i8QHN>4]=
Fh2W^<KDd]?FakF^Xhi]GWJFWiRKZKkEeL6USXN6Of]MFUIEE5USLGn<Vj>OVibQ
W8^3PhN:RYBS]/[Jj>KJbKfj[IbARXN0NX6@UYNOWi^JUI:JVXR5TYRQ[ZjTXJV`
[jn_YIB9OW:0TkOaooGF`:fXZ8=450`J92T_@V5oP6Q<=C0_8PX031DN:35:KhZG
WZF_];:[X9J<MUMFMXb7OG^1QhIgH5=?@RdO514E72Ld@55SKWAkPXN7PgmdHV5^
O8ZFX:^i`;^bYIV<OG9TG65]Mgj:UINFUIVMTHEmL6MIC4mPKW=jNgYnQ9>OUHJ9
S8F6RYRkh_oon>7PhmNmO3PT81hR8C1FNhAhJe]HFTH[820/?4ULMI:/_L?0`/K7
cLJf[j6<OWjAX:2PZ[W3_JRJU8QnK5E:Bdm?BDQDIgAgMgn?UXUgIUaNJWV9VZNd
aMGKe<W3_K:NS8Z;QX9nNWf4Ri2BSHZ2N7UiNGn0Ngn@VIZIUYJKWiR>UiN:QhZ:
TZcAk_Sah]GCdk=hBCa4C5AQKGjL]KRTQgMXEC/V:C0mDV1bS:Jha=3Bd=3?c<Bj
Z9:3Q9JXYibHXk6]VX=cIe]>>BPZ;S@oCF=lTI^LW:B^YY67QH1mOGf2SIFR/;Ni
[ifBQ75YJfa]K6Y]MhJGXjNRVHeoNWIYG5YRIVEVL8:@UiVHUY6:RI2FT8NC//gU
l^SB^:RUSElX0`H9000563A?F4Pj?3dl<b<O8c51BEIUNHnHWJ2LViZJWZ2IQ6mZ
M7eeJFUfPhJ3NgEbJV1A?cPa;c4c?E5XMWYmP8J4O7QgO8:9SiBQ]<G@eMSGdl^k
Yi60LVifN79hRIJLWIRFUhj1NG9eOXF=U9fRWYZJW9ZETXjCWYnQWiZ/cNooon7G
h=g8W6E<CD];DEEROIJLRWE`JUe9;b@Z<dQNK8:L[/;Aem_EcM3<a/6YSXRF/l2/
X:be]:bHQGmbGDTh<C<gAUUYNXjPZ:b^[9n8O7QeN7YjQ9BMWInVZ:>ITXQgJV9O
Gf1PH6UbMX>@THb7OG1ZIE]IGV5PGf1OJ7V4QX=oOXB6Q8R7O7bC_NO[d[B/^Jim
>0000`h81QPjHGQdHe]GFE4i9b<`AU9KIgjIY:V][jnUW91mKV5??T5KKfYKH7N5
QG]dM6eNCd8g;bPQ:3]<Ef5[LgV0QH9kMg1[KW5ePIB[_<?4`kng[9nCR7iiM71_
K6Q[M7UiMg=aLWEfMX2:T9RLXJNVYJblaKZ[ZjnVW9VHWK;AoOookM[EeKj1?Q`J
8cI6C6>;ZjnIPgAYHd`_9b/b@E=WPIZ/_];Oj>k]im_>`k6LSH^MZZFQYjja/:6C
RWMRED]8BTU:FW5oS9b[/kJi_[bWU9>HWj:QZ;2kbL[4_KJ_Y9J6N7=dLVe_Mh65
R8b;Qga^H5QKEde<Ce9HG61XM82:RhB1P7j3QHJ<Tj6lh?[oi/>i^9]Q7`000000
01PnHG1ZHf5GASDV7b<bAeMTMi2NYk>mbLbo[Z2DS89`HfV0RhR8T9ZV[:NLPVQM
C3@V8b0R;ci<FFA]M7AcMG1YIFUdOHRFX[2l`L?5`kN/Y9R8MfUKE5IJG5YOKGIi
NgakNGE^K7J1PHNDWZB_^l74a;^]XiVBUInQVk;Woooom=oTejIW=RDX=T93CffC
[JjOSh=_E3h[8b`oEFUnUZbmc]gXk^CCbl2aYiJ5PXnOXIZJXjNVWhmmJEA0;R8T
:BdfAUacPXfNZjna[Z6BQh>2Q8B6T:2a^;Rj^[N]VhUfKFQNFEiWK7>3U:6XZZ>H
UIBBSHR6Q8N<SIFQ[;Fi^K2UWYbHUIBAV;SWoooWb/:jTe0B00000@X>:U^4UY>8
O6UB@BlS:cmAIGfL^/O=fn?NdKbVV8n1JdlmBf]gLgF5TiF>QGm^EdLg9QlQ9Bdk
BUe]MWb0Q8Z?RgebL7AjP8VBWjj`ZJNUWY>7NVQJDD<c9B<V9R/f?dQFHV=WLg=W
I6UUI71nRYJV];Ve[ZVOS86<SWenWLCPj=:]XjnOJ2H0004>5alcFhVQUhImMFM@
>2XY=DEBIh6K]lK<fnSXh=[Cb;b_W8MnSZBXXjN^[J>DQg]YETPl=34d>T5;FVI/
Lgn?X:R[ZJ>RXjFY[:b_][fn_l71^:ZKT8^1MW5_L79eO8RFW9fHT8Z<TiNEUibK
UIFHW::SYjfWX::QXIfLYk2gg_oooogXgMNgLc/Z92Lb=d=OSJnaX8akKULm;20P
<DIIJWjGY[:j^KfhZInAP7AVCSi=Ig5cNhRBUHb1MfMHB3L^:RP]>DQCI7J1Q81n
O7UbJ6EZKgEkPY2NY:6LVYVBS8IiKF=HD4Y7AdaLJg9hQ92CS8R:S8R0OH69U9ZL
XZbf^KJaZjFLQ71`M7^Han7G]j>SXH]L8`801a8N:D9^TifAOW5/GdXk<3=4DEib
R9ZW/;Fh^[V`YijDRWaTDEYeOgUcMhB?QgIZG4e2<AlK82TfBf9hT:>b`<S8a/6g
/K>g^[g3cMKIe<g7`KN/VXEdIEM@BDA4ADaIJW^9U9^IT8f@SHJ4QhnDTiNU[k2e
^;2WXI^EUibR^nCooooRb<_9W5@O51DH92TdDh2OWHYmNF]EAS/d>D]PLhJO^loI
iOKnm>WOc;RTTX1[K8:<QXJ>VjNUUhA`GT/`7aTC3@lP>4iTMH>?U8n9QGmjMG1/
KgZ9W:nl`/O6^k:YVhn1LfMMFEaLG6EePHN=UI^LW9N=QH9nOh62QH^AUI^TYYV?
UYF<SY2B[]Wdl=W3_;ngT58[9bHX;RhgFX:BS7iaJUm;>2XU:SLl@E=WN8F?VJN^
ZjJOV966M65LK7MbLWV2SY69OW9SDcdW7QlQ9cM9FVj0S9BLX9bGT8V2OX27SYFN
Z:n_[JZPUH^2MFQKD51GFEYVM8>AVZ6Y[kFg/JNQWiRCUI^OWZ:_]:jVXIbCR7U[
MI[7jo_beKBe`IYJ;QdJ5aPL:4I^Rh]jLgA_I5M=BTaGI75oTJViaMGSj_3ajmW6
]IMdIFidJf=ULH:<SHR1M6AD@30/;S0d@eIXNXZJ[;Nj^[N`ZZ6ITHjCVZJd^;Vn
_[BWV8b2Ke=2?Cdk@E5QK7IoPXJ?UYFBSHF3PWelQ8jBUIfY[jZX[Jn[X9ZP]LoS
kMjdWZNOM3dJ50h?5a`[C7:8OF]TH5I7>2PS<dECGg2?Z[Rn`m3Gd/c3/ZJORfeJ
Ign1NGYoQXf6M65BAS<H100000/P>E9UM7n7T9JERX>4QH>3R8nJZ;6b/kB^XIB9
NfQHCTM5A44oAEafP8FCWJ2NU8B1QGicLgZ0QHN?WZZ[XYbETI:@T:ODmooon]KG
hljHI4e0=SLe=DU]SYJ3LGAdIEI4=CQ4DEUTN8jS];k>g^3Pg/^k]j^ENg63RGYb
MX>@V9N<OgQ/FDQ2@3`m@dmQMhNBXK:n_k^cZj^VUXfBVZBa^Kk6c<_9a[V/XY:0
LfYWI5]NM8F8SibOWZ6TW8n9QWihOXZ<R8ZEYJVQViZDT9>CYLcXl^W<ZjjcRUHW
6B4H5A@I=EikMF=MHfA=>RhO93Q3AE9WOi>MYkO3a;nj[Z2GQFM@FG=lLV]_NhJ6
MfMLET/d81DE72<]>DYQLh2<WJV_]:jUXInHTIBMYjna]Kc0_:fKRgYXFD`o=cLo
@D=JL7AiQ8Z=THf1NWQhMFiZN8R;U:Rg]Zn][:^UViRWb>[omm2mbLnjQ4P]:2TV
5a8/EWEeH5=GGV1F>b`gB5=IHGFAZ;>nd=kZm_GWf/^jYhMfQ8n6MVU]P8f9N6MO
ET4/92DZ<3HhA5idPHnO[;>d[JjaZIb@RhjDVj2Y][nj/k>aZZ>BNFYVGeQIHfee
OhZDW9nQWiZFUHj2OGalOhNBVJ6/[Z^YZZng_/KHnooolmC;cl6BGChd:AlM8CAF
Lge`HEiQGe0m<2diBEANKX:FXZV`^<?:b;j`Yij=MVUeQXEjLWJ6T8f0LFURDSd]
9b/^<3I4FW9oQHfJYZj]Yj6LUi:<SINRZ:V]/JfTWI>8OViMDT]2>c]1Cf5aOXjL
X9ZASHV0NWA/JFa]KgV5Ti5oN867R8=hPZ:og^kF][G5_HiB;AlK70l00BMDJEY6
CEmWGdLa<DAACDYDKXbOZ[K<h_CgimOBbkNAKfemOW1QGF^0RGm^Jg5]F40f>3hm
>ci;H761UJc1c<c3^[J^XiF9QXR=TIFPZJZZZZVUWI>9O6iUHUiHIWf0OhjOXINB
UIJ@Q7UeNGn8SYFTZJFY/KBf^kNhd?7ooo7HdM_;T5Dm=cHh;R0YCGF5MV=YOWmY
CSPjDEeFEF9lUj>T[/?IhM[?a;nkXH1jRI2;OGEjQi2>OVi[JUi8=2la<RlU9ca@
FfMhRYZUZ:BSZ:BKU9>HWZBX[:jZZJNPVi64MVMMEe9?BdmLHV5/OHF9Rhb?UIF;
PWaiMgIoQhF6RHnHVINQ[;kNnO[RbL?<a95GAC//:R0B73aKHe=7CEiUCR`J7B`g
<S0mDVMhPiFbd>G/j>?Ld;JCQhQoM6]SIg9mPgmfMWAWFTXl>CL_8adY?4]KKHFO
[KRn_KbdY9J>RXZ>U:2[[kNm_l2o_;2TVXQfKfURHV9ULh:>UYfSYZNSUhV2OW]h
Lgj=SHbGZKZi^<[So?ooj<[4b[IoBCLg=CL[93aROWYOEfUmOF54?deLGDm>HGV:
SY>P^mo_h]7>cL:XT8b=PgadKWN8UIB8PhF3OW9RFUE:>2@P:S4f@E5VO96QYZ^`
/:ZPV9FGVinNW9^PXYbDS8^;QGUTEUEHE4U6D5ELJG9cNhb>OgYmO7M]K79mRHj?
UjJ_]l;3c>cml=O;fmngP5iHF517;ahiFf5@?dIMJ5Pi9Ri2ACT[;3e>F5UOMIg1
cm7Dh>OH`;J`XIN>OgQmPhR8QXN<R81mLfINEd/m=c<[:c8h@eEYO8^FWIfIU8b2
OXB7PX2:VZF^/[Jj^kbi[j2CRgmcK6U/LGAiPhnETYBLUXQlN7E]KWEhQ8bB/LG4
e_7ik]O@em6hRg5cJ65QD4IGKWIWFVMmQG5=@deGFdhm@51JFeACK8^KVYZ/_/2b
Y:>PUI28NGR6TIBDUYnWXi^GUiFBR7aeKfQQGEaLFf5/LGEmR8nAShf;R8Z=RX:0
RXn:SYNGUi^LV9FCSXN0NgUiMW=gOh>6S8^;RGmlOg]dKViaM7^5TIVU`Lk>f<fg
`ljbR6YZIUYMETeGHg1ZCTUNK6A:>SY4Ddhn?dYBEE1=DfInQXB7UZ^aY9NJZJ^L
SHB4Ri:9Ngb2R8^6PHVCU8V2Q7mjMV]TIFIYJF=YMWehKfiaL79_HE]QJ6]YIfQb
OhN7RIBMXJ6KUYBBTHn=RHRAThf=TI:=Pg]gLW1/IFigLGnDU9fa_LS9a;ZX[Jj@
OGUhNgIjN6ahQXN3L6n7RGQ^KWEmP7Y_KW]nM6INHg9iM75lRI6BRXVGWYF;Pgmo
OW]iNGn4QX>1RYbXYJ6PXjZ]Y9>:SHj9OW=aN822P8>9T9JCS8R9RhZ6PGeiN7Yj
Nh62PXJ<TYBFVYjQXZN/Yj>UYIj>QXN1OW]eLg9hPhR6QH^BRWmmPHF:Qg]eNXN@
SH^5QXn7MfmWJG1]IfEWLGn4PH69U9>9PgY`L6mZIfQ]KW1eNGb1QHJ8RXQmLFm`
K6YVHfI_MgUgMgf7SI2@TI>CU9B>RHf@S8^;RHR4PXF1O7UbKF]]MGUhNW]jNgj1
OGMhOH>6PX61OXB8Q7ioQhImNGIcLFm^L7IkP8F9SHZ6QH9oNFe[KFQXKgUmOXF8
Q8F:RhJ0Oh:6QX5mPXV=T96DVIZGTI6GUHb3PHJ6QXZ7QHJ7RXV7S8j5NWQlOgn0
PHB7S9:DTiBCT8j=R8>1OWUfMgMgN7b0Ph9oOWn2RHZ2NWMlQ85iN7YoPhR7PhV@
T8f9S9:BTHf:RXZ9SH^:S8b7Ph>5R8R5PgikO7anPH9oNWYnPH>5Qhb<SI:CTHn=
R7mhN7YlOX65PX2:THn;QhV>ShZ0NWYkO7]hN7j2PGamPHB4OgUeKg1gNWn5Ph21
QX^BUI>ATYBETXj8Q85iMGIhO7]kOgiiMgEaK6QSGEeMG61WKGAaK79lQHR4Q8>4
Qh9mNg]oOWYgLgAgMgAaLgUlOX5mN7MfNGimNGA_K6]ZK6i]Kg1]JfigO7UiN7Ig
MWMkOX>7Ri2BTiFEU9:>Rh^@Ui67QXN:S8b9QXR=T8j<RXR8QH=nNW]nP8>;U9NI
WZ6RXYjIV9FBSXR8SHn?Si6KXjBQViNETiFARHJ8SY:<Ph21PhF5Q8>6QGmoOh:6
PW]hNX68S8b<RhZ7Q8:0OGUeMWMgN7aoP81nNgn6QhJ6R8b>Rh^=S8^;RHF0Oh1o
PH:2R8f?TiNIUHj>Ti>>Qh:2Ph:0O7YkOhJ7QH>0OX1oNgMbL79hOh:5R8Z?UIFE
THV6PWmlNgYgNX63PhF:Shj7Ph5kMG5^KVa]L75aLWV0P823QHN3O7YiN7EbMGQj
Ngj2Q89nNGMmQ85kNW]mOGanPHJ8Q81lNgajMWIdMWQdLGAkOWanOWQcM7UoPXB9
Rh^;RXV7Q8B2P85oNG=/JVa[K6e_M7EdMWQiNGMeMG5`L71cLgEjO7alOXB9Rh^8
R8V8R8J6QhR<T96BTiFDT8f=SHn>R8J7RHj?Si6ASXj=S8R2OWf1PgihNhB=THn<
RXV9Qh:0OGn4QHF6RHb:RHN2P7imOGI`Lgb4R8bDVIZKUXj;QH:2OgemOGn2RI6D
U9>?Rh^=T8j:RXb<R8:1PhB6QhN6PhF9QhF5QhR5Q8J7RXZ4PhN=TiNGTXf;QGik
OX62P8:8SHn?Shj9QXF3PGefM7EgNWilMgMmOgj0Ph9nNgYlNgb3RHV9RHZ6OW]i
M79aLWIjOh>7S8b;RHB3PX1oOWaeL75eN7]hMGIiOh5kMWZ1Q8=nOH67RhN3Ph20
OgYhNWYhMGEgNGamNGA`LGEfNWinOWilMVi^LFi[J6IXJfmaLG9gN7EaL7=cLWMl
O7YkP85nNgMgOXB7R8J5RXb8PhB7R8V:QhJ5P7]gMg]lNWQkPHF8SY2@SXEmO7]n
PhJ<TiNFTHn<QhN8QH>4QhV:T9NGUYJGUY6>SXb6PX>6Q8>4Ph>9TI>=Q8>8S8^7
Ph>5RXf<SY:BTY>CUYVIUiBDTi6@RhN5PGioPHF7S9>FUIJFU8n:Rh^8PgekPHV?
T8j<SHn?S8R7QXJ8R8F3Q8B2PXF5QHAoNWUjNWUiNWYkNgYmNg=_LGEdLgAbM7Yn
OWj0QhZ2NGEfOHB7QhJ7QX5lMW9gO7YhMgEeNGioO7anPHF5PWn0Q8B2Ogj1Ph5o
PH>5Q8:3QXf?RhR:Si>CT92<R8F1O7QjP8:4QXB2PhV>ShR2OWUfMg]mOh>6QXJ5
QHZ<RHF1P7moP7imNgMgN7IeLg9eMgIbKfi/JFUYIVQZIF1QJFibMGUoQXV9QhJ5
Q89mMgIiOh>7R8N9TINFShZ8Q81nOh63QhJ0NgYnQXZ9QH5mNW]oPhJ7QhR<T9>B
T8n@T8f8RH^<RXF1PH5oNWEaL6maMGMjOhJ:RHN7QhF2OWamOGmoOX6:TY>>SiBE
THf<SI:HUi6>S8Z:RX^9RXj=QhJ7R8IoO7ajN7EeN7]iM6m`MWaoOWf1QXJ4Q8N9
RHV:SiFKWj2LUYBCTH^4P7]iOH1nOGj2Qh^<R8B5QhJ5PhJ7Q8>3Q8N:RHF1PX>0
OGanPH:4Ph>3PGmnOGelNGMgNGn1PHB9RhZ8QhB0OGYgMgUoQXR6Ph>9SY2;QH>7
RHInMgQmPX5lNG]lO7I`LG9bLVmXI6EXJVmgM6e[KW9eMgYjNWemN7A`KVe/KG=j
Oh62QHJ4OgeoOWUbLGR1QHF4R8^:QhB1P81kMG=eNWamPXR=TI6?Si6EUYBCTiFH
UY:>RXV5PX60OgelOh:4R8^=Shn=RhZ:R8B2OWUgN7f4SI>EUINFThf5PhV;Qh>0
Oh>9S8b<SHb<SHb9QXJ7Qh9mNgamOGj0PhV<SiBDSXF4RH^9QhB0PHVBV9ZJW9jK
Ui>ASHR2NWMjOG]gMGQnPGimPhR7PWelOh>6R8R6Q8>3P7moO7McMGUfLG9gO85o
O7amOGUcL71cNWmoPHF;Shj>S8R2O7I_K6e^LGIjOH23QhV7Q8>2Og]gMGMiMgIj
OX23PgmlNganOWijMWEhNWYeLGAjO7]gNH29SX^6PX>6PGQcLWQoPXF4PhB2PH9o
N71/K71dN7UmQ8V8QH61PhF3OWUfMWQkPHN;S8f<Rh^8Q8>3QHV=TI6@TI>ASXV4
P7YgMG9dNhNBVInPW9fMUi2:R8V:RXN7RXjDVifHU9>CTi:>R8J7QhR6Ph21Qhj>
RXJ6QH>3QHF4QH=nNGIcM7AdMWYoP7mmO7]iMW=cMWenO7n5S92CUi>=RH=nNgf0
P7j0PX60OX68RhV6Q8B4Q8:0QHfBTHj<S8j=RXF0O7UeL7=iNWQhNGYlO7UfMgYm
OhB:SXn>T9>DTXf9QhJ5PWmlNgn7S8n?SHZ;SY:ASXZ1NWMfNGf0P7]gN7YnOgal
OGelNWYjN7QiN7MjOW]eMX29SY2<QX9oO7E`Kg9fN7QhNWeoOWUdLW9bLFm^LGMj
NGQiOH61OWamP862QHN:RhIoOX>7Q7ijNGYjMG9bMgj1OWamOgigKfYXIV=UJVme
OH:2Q8R9QX:1P7mnOWemOX>8RXV7QHR<Shn=RhJ2PX62Q8F4Q8F6QhV9QXF5PX24
RXb8P7]jO7ekNgf3S92>S8Z8Q81mO7]jO826R8^BUINGUI6=R8B1PHN;RhN3Ph:3
Qhf?Si2@SHjCUYZLWZ:TXYjHU9>DTXf8RHV7Q8>4QXN5PWikNGUkOH26RhjATiBG
VIRFTXZ1OGahMGMkPHR<SHb<R8B3Ph60OWenOGamO7]kNg]fLW1^KgEjOX:4Q81m
OH63P7amPHF9SY:CT8^6Ph5lN7QlP81mOX63Ph1kN7IdLF]YKWEkO7]mPXJ9RHV:
S8nATYBDTiFHVibFShf>RhB0OWj1QHB1PH:3P7YfM75/IfASHfAWLGb2Q85nOGil
NWMgMgQjOhB;T9:ATI6=QH1nNgYhLfi/Kg1_K6]^MW]nP7moPX:0OGQfNWioO7]m
P8B6RY6HViZCSHV7QH:0P862PH65S96@SHV7QH5mNgYlO7M_Jfa^KViaNGenPhZA
UYRHUiJEUI>?RXJ6R8Z=S8V9RX^;R85kN7A^JfY[KFi]LW^6SXn?SXf;R8B1PH1o
Ngb1QXR8QhV:S8n@Si2ASXInO7enOGanOW]gM75^Jfe`LWAfNWn1P7imOh60Oh67
SI:DUIFET8V5P7]jNWUlOX21P7mnO7]hM7AgNg]gM7AeMgYlOWn2QHR<TIJIV9JE
UIFBSXf:QX>3QHR<SXnATY6ATXj8PgmnNgA_KgEmPhB3PhN9RXN2OWelNgYkPHZB
V9VKWIfIU92ATHb5OgelNGIcKfa/KW1`L75bM7=cM7IkQ8V9QH5mNgYjO866QhR9
Rhb<RhR4OWajNG]oPhB4QH>2PH1oOWj0Q8J3P820NgQjOH:6Ri6CUY^PY:>NViVC
SHb<Rhb@SXJ3Q8F1N7IhMW5^JfMTHVAYL7MmPH:2QH^>SXb9R8F3Q8V<SY6EU9:@
SXf<RX^;RXV7QhN7QhN6QXN7QX9lMgAeMgQjO7inOWj0PhR8Q862RI2AShf=SHb9
PgmnOgmnNgQfMgYjMgEeMWA`Kg5cLF]XIVQ[KgAfNh>:TI:@U9ZJVIVDShb:RXb<
SHR2R8j<RXEiMgYgMg=[Kg1]LFa_MG=eLgAdLW1]LG=gNgYnP8:8S8n?SXj=T9FF
Thn>SHV3PX9nNGIbJVIVJVUXKG9eMGQmPX61QHJ2O7YhM7IjNgf2R8N2OgekO7ej
N7QhNG^0QHJ5QhR4OgQjPH1mO7MdMWMkNgUoQhj@TibSYJ>SX9ZFUINGUibOWYjP
Xj6LVIJGU8n;QGegLgAkPhZ;S96CT8f6QHN8Shj8RHf@TXn=RHN=RH1kO8::SHn@
TY>ASH^7Q89nMFi[KgMlOh62PXB5P7QfMWA`KVmdNh64QHnDUINCShf9QhF1Oh67
RXN6Ph22PWejMgAfMgAdLg9aLgEcLg9aMWf2Si2>SXf>RXN:RhR3PH:1Q8J3PX5n
NgYlOWZ3QGEnQGYmOWanNWE]JW5fLfm]L7MkOhF3PH>4OgamNg=aLgEiNGn1NgZ2
Q8AmM79aL6]ZK6acO868TY:=THj:Q7YdLWF0Q8B3OX:4PGinNgQgMWQhNh:8S8nC
ShjAT8Z5PWejM7=dLWIcL75bOH60Ph21QXV<RX^?TY6<Rhb?TYBBT9>>QhV8QhJ3
QXJ1OWanNWImOh21PXR9Rhn=TYbNX9jMXInLW9jJTY6CSXV7R8Z=SX^<S8Z;Rhf=
R8N:RhV9R8Z8Q7ilOGA_M7QdMGAdOHR3P8Z?SXb<SH^4QH=mOX23RHZ:TIRARHJ6
R81bKW1kPGYdNhF1NgYmQ8F=Thj;QhR@ShR<Ti2?S9>@RXb7PhF2O7imOGYlQ8J1
OWelMVeXJG1bLW9ZI6AQGVI^Kg1_KV]/L7EaLGMkP8F=TYFGTXZ8QX5nOGQeMGEi
OWn0PH5kMGEnO7YmMG1`K6U/N7YfNWYkNgajNGYfMgf5PXJCUiRIUINFUYR>RH^?
SGQlPgenNGIaKG=hNGj8T92BUXn9S9:>QXR9Oh23QhjBUI6@RWUiPG1aQH5nPX=o
MWMjN7^5P7EnPWUmP7QkO7moO861PXnFQGYkMgb1MW=kP8R?UY^@RiRSXinPYjVU
X9j=OWIZJ6MXJfA/LW9fLGElN7UmMg^3PXV;SHZ9QhJ=Si>DS8b?R7ekQ8IeKF]T
Jfm_MGUjOH1lNWUoPX:4PhJ8Ogj:Sh^6N86<S8n<QhnKX9jKUiJJYinFZ9R=U96K
V8^;QhJ9RhMoNG9ZJgAbMgmdLWR3QhF3Ph2;VHj@U9FNVHjCVHf;RhR7QXMmLgf0
OhAgLWQdO85gLgYfK7AiMGAdKf]dN7=hO7I`Kgn7QXN9QhZCShB0RHV2R8MlNGQo
Qh>4R8B5RHnCUiF9R967L71jJV1YJf]]OWehO8J5NWMlPX28QgQbNWf4P7anN7f3
Q8Z9NWb0N7abKh9fLW^2Si6;PXF0NgUbMWMgL79iNW]gO828S8:0Q89oRHmkM7Uj
NWQoNV]`N7amOhJ8TYZGSI6MXYnLU8f:OHB3Nh1kO7j5SGmhLG20O6MEJWedKW9^
NhR5R9NPVifHVZRUWJ:STi>ETIfSXIR@S9>T[Y^4T:NHS8n6NWZ0PhJ4PWn<UiVF
OGEdMXF2NgI_Lh=nOY:KV9F=UZ>ZY9BETiJOU8Z?P6ieMGIdKgIdNGU^LH9hLgUR
H79^H6mWIX9gIFUcPHF1QWf6WiEjOI:?OHN?V9>=VH=lO7=jP71QEUU_NEeNNGYi
O8R4NGYnNWb0RYB0OWUbPgj9Ti2>Tif]]9jHTI^]VH>7S82>UXb3Mg5mR81hFDQ<
DEE@D5aRG5m[JVQTHFQUGVn3PV]CE6=]MGENFf9gPgYbKUm_Q7UlR7]aJF]lO7EY
IW1nKVYkNX5kQjFMU9nYY9:KXIRMViZ=RJ:IO8bSUIncZ:n`ZJ6IYYf9SXR=UYf;
K7ejQY2<OhIbMI6@R8n:PINMPHRVXi64S92?T8F3TYFCWI:4T922SIbAKfMoRYFL
M7JZ`<^iW9fKUjb/O7F?RG=gQf9YWX][H8:>RHV2KEaXRH9GC59SPHEME81ZKXfG
W8J7SXYYQ<_8WH6IYh1<D7edLg]lO86DR99nFG6QReMDS99VEdaNIGMcFFY/LHj5
IhidDFb1L6UIDWF=OfmhG5>5WhZ4P5eZUiVIVWQ_U[R]RYB2MXR:T8AlP8=hVKFd
_;f<J8k;`hf7S8jM_mO0[/;9[JFPT7]gOFebMdi=HfA?E61=F7EXH6a`L5UGC5i9
5b]5C51UN7ehOXJ;P82CWiB@V9N@Q7QlShZ1OG1jOh:LbkjDW[S9aJ>COWF1Mh^1
FE]PIhJXX7inWiRUUficKV5NKfMQJ5mEKh>3OFalTYJBVhITKX=hQ9f=JVn6WkFA
MHAhLh^<RIJ2GgVIT8jMSgElTI^;S:6YYjJKZ/ZkQUURY:AkEd9PS8I9?V5]L7]d
HUUUKW1hOFI7BE=@Kj>LQXN9WkW3/H1eUjB][J6OZ:2;OG1lZJR?OGjGYkVXY:>G
X;:TTYRCUiMhM8A`Ge5RL5]TP7f5WI:?V6=ENf=CF5EKH5UdU8Z5PGjIXhb>RX24
PI::Mh:6OG:2RVi^WI1[JXVc[j2OUY6[Z:>/TVETT9bIVIjHP9VQPFI@FV1fK5AU
Lfi?DValL6MZMhR7OH:6MFQMJgYA;C=RL79jNHRKWX>5VYJ>SWm/RIV6KUMNPHV?
QW1mVYnPWYAkPj2GRgUNG7^6M7b:P924PjJh]INHVYfPVY:4Ng1lPgAiMfQ`LEmQ
NWUlOW]nP8n2JgV1R8=_KGEjPi6HWHYfNi2DShf<NfmdQIV?OEiRPi^QRfQaRI2F
SWb@XX:@/j2?VZJHSXn3PXE`GffBRVa/NhVRXINHWjJ[ZI^QWj6IRHjQY8J7Ui2:
SiJ<K4e9J5a8Cf=aPXeoNWejKG9aHfa_GEYWO8MoIfYjLW21PGAYO8b>QWF3Vhad
L7^?R7=VIfelS8QjO8^1QYAjMXQjHF=aKem;C5eDGhE`EF1ZNY2EQiBWW9FOZ9R>
SG]mWYb9R9BMVHb4RhMkP9:GXZ>RYiIiN9>HSGMRMYJLTXIbL7IoRGiYJGMoRY^O
RGEhTIZ;NG63VhQoXj>DTI2;QhAnKfUjR864UXI_NHn3N7=OFF1/KgJ3QFeoWIR`
^9V>VIR:QGmWK7f2Oh5iKFmfOGEYIW5YKWacMgU`LGJ9VHQiLVj5VYb?Mff5T8>H
Wi2U/9jKXYb1QHZ6Rh9hR:N/Y;:`XZNS[[BRVj:AQJ>XSX:=Qgi/GW>8ME9BGUiY
O6U/SZ>Z[YnCX9n=SY:AU8j<WZFIUYZBRhQmLFADDV]iMVicLg]mKWMZBD]UMGYl
Ngb8V8YnR825S7Q^QXIWLXMkLGIjK69YJ6IPIgETG7j5Kg9aJW9dLV]YK6EaNVUX
LE]MOGU]MG9bP7f=UYJFTiNJXY^EV9ZAUY5iKH><O8B3N7]bLY2]ZhQbJ7B0LFj2
Mea]Rhf8RhAiKVEbPG1EHg9ZMXJ5Q7ImXJJ8MXNDUYj[Y9:QZ:JYY9ZDPh2GUIFJ
SXAfNHfCOVM`Mg9TI6m[L7b5T9NCUj>Z_kVHRiBLT8R:QgY]KWR1M6QfL7:FSFiY
If=QIg9hR8emO8J<RhaoN8N:PGf1RHQoTJ:@PXZ<RiJCP8>0MYJ_WHjCUXjLXY>C
SX>6Vj>PWI:AU9B5N6mUHF5LEV1VK7E_N::WTX27XJJEPH^UZIjFXjjLS9BAQ8^:
OG5kR8jNUX1mRhAnSh=ZFUeTM8^2LWIlLgUlL7Y`JX60KWF9PXJAPWAbKF]kQ6iM
JWN4T8n9PG^0PXN:PGAOIWIgJF5FC5aCDfE[KVEUN8f6PINER8J4QYZIQHfGRWmn
THigLg=aOHAgOHbCTH5YGf=XNXMkIf5OJWmmMg=REWF4MGEdM7f4S8f6OWIbQIV4
NGUiPGj1QhR;TYJAR8F0Q9BEU9FAUiNCT85mMG5mQ7n2RHbJXiZ>RYb/W92FSHnQ
ZJJFSY6=QX5jPWmiQh9gNWj8T8MbLW9_P96=NgZ4PHJ:Q8^5N7moPXn3Nh>DVhZ6
QH9oNG]bL6ULLXJ4M7V8R8nIWY^<SInHU9^CRh>5U8]hMGf7OVMYLG=gJ5YUOHZ3
PYB?MWJ0RIRGXk2RVijPU8F0QWmdNGn5RHb4Oh21RXjAT8IjKgJFXHf5S92:RY2:
R8:5SH^ATHYgLWj8QG]hKfMZMhf<R9ZQUhZ1Q7]aPHb2O7AkQXIiOHQmJ5aZMVaO
GVI_MG1dPGegMX6ASWn;XIfAT96DSgifOgmbOHZ=RXJ5Oh60O79cMfYVLVeRKgmk
KF=WKF]/L7=gNWn>SXQoMh2CXJ:QT9:NViFJX9nKY:RDQhN4RiVRYinESh1kQ8Ej
K6QQFVYoMfE]NXBBViFFVI2?UI2JVHb=Q7YhL71eL75^IVQ^LWEiNgA_N7YYGFQe
L6AWNX^2NW=TGfZ2UiF7PHF=U9V>PH^:Q8N<S81mRiN<QXJ4PH:;Rh23Ti2>WJRF
OGZ5V9f;LVANGEYZOgYaLg^<XZnXThZ@Ui^LXJB[ZYnQWIVFP71lRXR<RhEnKfYg
Og1VKFe^KFa[KgR8SH=iM79_LWb1NGQmO7b3SXE`LGj3PgARFEiZKWAlP7UgOXJ9
PWYoTZ:GOh2@THnCSGeaKF]UHfIYN9NUViNISXQoKgJ?SH>5QWiiRZ>KQGelNG^=
Uhj@Thb6P8:4MVifPHf<RY2=RXV1Mg5gPGeiOWmoQ8fIUhAhMWAcLfidL6QgSi^D
R8R?UIB=Q86>THb>ShAmQHf9OfaOG6M`L7YdJWMkM7f=SH5gOX1aO9JERhjBT9>9
PWicKgR6S8Z1P8B3PX9gIEi[OH^5NWf9SY6DR75RIGV@ShF4PhJ<RWmeLG9iPi26
JFIlRi:IUIFGVIZLXYbFTi6HWI:7S9JKWYVAQg]jKfIaMg5_LFaaPXQnMh>?VZFZ
/;6][k6[YYn?O7F2U9:8Qhb5OX26NfEMIg^5QW]WIWj<QW]`K6ijQHJ2QHN7TjBM
RH:1Pi2CPWUbL82@SG]oSH]jLWf5P7E^LWf4PX>6Og=iOViOFeeVIfahNG9jQ89o
MW=lPi>JUYZJS868Ti1nIeeRKh6;Q7QdPhV0OG=UFe]XLVePFfIhOW]fLVIOKGMc
LGV1PhZ=PWIdNH6=V9V>RY2JYj^MSXUoO8RDUI:@ShjFXj>DQhZ8MV]^KV]_LgAk
S9R<P8ZET8f>RXfNYJBQUhn8Qh5eJf9LIGn>QGEcOhR1OWU`IfEfRHV4QhF4Q8ZG
UhIhOHnIThV=TI2GV8f6QH>4RhEaJ6mfNXN@PG5iPhF9Ti^APXjQZ:JHUiNASH5c
JFISJ7AjO7n0OWj;VYN5N7MlQhf8Q8nHW:6OUH^:SYNQX9J;QHF8S8^1LV]cP8^6
Kf=UKGQoNVmWIVaeNW=/LGMiOWmjKfU`LWIiLf9IJh:<SHMnN7Z5S8b9O7Z;XZNF
S926OhR=QGI]LGb2Q8F<SH1jQXQdJ6U[Lgn2PhV4NH>HUhZ6QhN>VYjFR8:9Si:;
O79/KX2BTXF4RXb>THmnK6Y_N7igNhJ5PX20PW9TIg=nOWenPXjT/JRIU929TYfA
P8:8RX^@VYN;Q7mkO7EUGeiTM7elNGQaL7QmO7MfPY6KWInQX:2HSXInMg9kSiZ@
OgEjOGQjOGQ]K7EjO822Q8>1RHb5LF9XMh22QH9mP8fDQ7QiKfj1PfiVKgR0RI2>
RhfBV9>>RWilPh^DUX]oO7UoSHejIVAYIfMZJf]QGWF6P7UiQYFKWi^CTiVIVijE
S8V;UYbAP7UjNGYlP7iaJGAnQX^4NGIgPHn@Pg9]NHjFS8R<TIFOZJ>@Ri>CShf7
PH:;TXn3PH1kO7amOFiSJgZ4QH=kL6mgQHb5NG5cNG^1Q7]^KgInQh9mPgmhQ92F
Xj6DS8AkLFa/LW^5SHZ3QX^8Qh5eJfAWMgagNg]iO8B>P6IOIVekPWmnPHAoPH9n
OX:1NGAbKfmeMgf:UIN=R8V?UiVEUYbRXZ:QU8F;TXj4MfmbNGf:TX^5Q7ehNWen
P826SIBOXIR>PWQeNGadJVYcP85jMW5bNWmmKEUIGfQbLW=mPg]mQWedP8nCTXj>
Shb:S8f5Og]aJ6UbOGiiNXF;SH^7QXnQZjZNU9fXXinMUY>>PX6>TH1hPH:4RHV<
QWIbMWYmNG=aM7j?W:6OW9fOVYFCS8nKXIfGTI2CUY^KS7]gLg5lQXN5NfmePGid
LW9aN8>3MfYUJVmgNWEbLgN0R8b:O82:R8IoMWUlOH5nOWmoOh25R8=nOGj6RH1c
KFibNHZHT85kNWeoNGI]I6aoRY2ASi>FU9>?QHJ9Q8ZGViRCRhR7Q85hKG=oPGn0
OWQaMhB3Mfe_NX:6Pg]fNh:2PGaaJF]gP8F:SH^:SYVOVHf1OhZ=RXV:TYZGWJBJ
RXV?T8IeK6ihPXN6OgMaL7R0O7=/KGIlRYVGU9JKVIJESX5hNX>:RXMjKFa[K79V
EEUSJGN1P7]dMGelNFi[NH:5Rhj;QH65PGIdJV5TKW^7QWQ_M7Z1PgQ[Kg^2R8^6
Q8fEUibMUHj6Q8b7MVUTHfUXJfmZKWJ1RH=gMGMkQ8f?T8j9RY:IV9JAShj9SIN@
Q8=iNX=oMg=eOX^DWIZ<PhB8Q7aeL7F0SI^HR7inR9>?Qh9kPHZ>Ui>1NgejOX63
PgmkQ96;QXV6OH:AShR8SXn:R81eLGEjOhJ7PW]nRhEhNGUfNX22OWn7T8n4OgYb
LgN2SY:EUiRBS8f:PgYbLGV5QXJ<RH1oOgefI5e[N7UnQhV5RIBER7MYHVI`NG=[
KWR6TIFCSH^?TYFCSI6FSHfHVY>9QhjEThZ3OGZ5SHMoQHV9RXElNGUdLgV3S9:7
OHnJT8^>SXJ1RYJGV9F8O7j1MfMMFf5]L6MKHGZ?UgaRHFJ0WIZ4NWUmPI2BRWML
JGmlNgehIUeaQHR<X;NWMX6]ZiNHYIb4RIZN/:6;NF]kUJ^g[7YZKG5VE7>5KeeN
LX:9UY^FW:22LX:N[:VGQ8F__:63LG^5PWYhHV9hOGZ0WKNDG3]3LIRiU4I7N:FG
J5mHEG29QVYNO9^JO6]SIh:ETg]_N8^AR7ASKX>5OG1aOi2ISX5lP8j4L7V1QhAk
PH=lMhBFQF1ROXjDUjVYUh:6Xj=oGV:5Z;:MQ829U:>MP5mKHgjPWIAjJ6j6Uh]X
CFV4QHR3L6Q`MgUjLemHJI2SUX^=QWn;VHi_L7]oT9N6PY6>SHR@VIB7NGN=VY22
Mh:CUX]`I7B?R6]HH75eJg63T92;R8ZJVHAmRHEkQi>9OX:>SH:5OW5/MGakNG^>
VheeIVakQXb=PGV9TJ6PS7=/OhF<RfiHL9jPQgUbL6agQh1QDW>P[iZ:U9ZKYJNG
MVUmSX9aMH9kKFmgLVMNI75jNgA_JW=hLWfGUhIjKWnJVXilM7j9VIjBOf]fUJ6H
OFIiUYnBOGI`J6eiO71[OYJKThUgHemmZZafEVAiS9RHR7=bPXjGRGR5UZ2DL76=
SX5hQYJ5L71mR8n>P6idPG=gQ7Q]LH>CT7mZFVMnPG9MLZFYPGEkPHR:SHZ5SY:?
SiNOSWMkVI^2LG6<Z:F?NW=nOG=jPH:6P866Ph1nMW^?SgARI7:8SXb=TIbPSgag
PI:NYIb=QGV4XJZMTHnIWi1nN7nCY::?QiJNSWn0PXN>QFmNHhBNXI^>OWj<Ui68
Q9:RWI>;QgM/Lgn2L6EOIGV3Nfm/LWUfNWidKGJ1PgigO8V:OWQiL6YZIfagNgf3
QhV8PX60PXN5QHb@SHR6R85iPhn;QXEmNXVV[i9fMhV<MVEVJVn2T8]iJVYcPXZ0
MX6FUWmkTjV[UWenTiB3P8R8PWYnR89iOhZATXEgL6ejRHJ0M6iiOGQiMgMeLg9c
PHZ1L7B:SGYODf:0UIf8He9WTJ>8H5Q/OhNGX8]dO:JkUW1^Ohj;MVYfQ7adMGAd
Nge`KH2?T9BOWI28OgEfNh6;ThekM7UfLGR3R8=mOWj0P7M^Kg5cM79aLfeZKgM_
HVM`KFIKFfU_Jf5OK7AaLg=_Lh25PH25QHRBU92BVIVGWJ2HTiNNX9bMV8n6OXJL
WX^6S89nSY^BQXfHVIZHShfCTXnFT8B8VZRRT8bHW92;TXj4QY>KUX^5R8j;Qi2D
PgZ:VIZ?Q8B@WYQoKgEkMG^=TH^=RhN@WjRVY:BZ[JB>Oh::SY:DSh1fRIfKU969
LEiPJf]QEemVFTmOLFYPGeaCCEIMDd]AGg1iMG=kRY25LfikQX1lPH64Q7j5S8R6
R7igOh^<SYFET8Z6TI^EShZ6Qh^BVIZDQ7R6U8f<THf7RHn@S8=nPhF3Qhb6NW^:
W9^CVif@P8B<Q7emM6UaPHB3Q8J:X/G;cljZTYJ3JGb?OVIPJXfaZinY[9A[@Rhd
AD@h<bdb?T=5C55>D59?CU9;?d=>ASi8Ce5HHVmlPWmkMFiWJWMkNWZ0Tj>PTiVW
ZjVQWYnHTI2>R8bW^ZjKXK[7^ZbUVY6:QHB<UIJGXZ>LWIjMWIfFTiBGVIFEUI>F
UHnCVYN5M7R8Q79XKgj1PhbKZ;oSoOoXc/jfTi:<LEQLLWj?VJG0_Z:8M6QQED8]
:blW;3M5CTm?DUYNHF=KCTM2=BhlD5MNL8B?UI:>S8AlNWEZKg^8UiRCUZ2VZkBj
^kFWVi>3KfmhP8R;U:R/WYRKSGALE5ADIG9fOXB4PH:2NVaNFF9gQHB5PXB8PWn:
Thj1N7EfPH:1QXV>VYf_eOOooooYi/^VWX9DBfIdRJ>W[[R[VH]fE3L[6PT>61/Q
9b/dA4]7Be9EFE]@?BlU8CA>JHFJZJn^[JfTTXZ>SHZBY;W8en3H^ijN/;F/YZ6D
R8N0Ngn1PW]gNX:?TXZ1MfYSHf]mRY6O[:^MTXV1O79_MGf7TIZJW:>OUYNKVYJH
VIJGU9FRZk2_Z[_VooooooW0NEMJFV=eMgb9W;;2_ZEnCad0008=4Q0<4A/R9R/e
>SToC5E=<Q80000A=EZ0WZZXWI>ETHAjMgV1S9JXa=_Wj>7=/ZJUZjfUVHZ3MFI/
O8J<RXJ7RhAcGdm8@Ci7FfalRY^Y/[>TUY2=RHV8Si^U[[2]YijBSiBFUI:7Q8fH
YKNhZ:_9nooooon[CC]1G6Y/Nh64YloMh]ZgQe`_4`dJ:SU>C3hmAeMSL7j8RHN2
Le0R10@F>6^L`=kRc;2LTXUmKVEYLW^@ZkW6e<o5^jbOS7]`JVICAD]?Ce5LIGN<
ShMgESHZ:2`mCUURLWn7T92=RWiaKFa]MX:7SiNKViZERXF7Q8B;SXb?VZN`/:jj
g_ooomb1>DA7DUAHO9RMZ/;8b[b@GBl<2A8D6RiKLFYMEV=ePGi/H6I^H3hK4BY;
KIFec^;L`:FATIN>OWEmRiJX^lKCgmG2/IfETHZ0N6mUI6ESIgN3PhB=T8IeFclb
>D=CJWj>Y:f//:RNW91mNGn3Qi:Q/[fm]:VRViNDT9:CU9NJW9ZNZk[6g?coolMc
=d=AGUUEL8ZEVZ6RY9f0Cah100/?5beCN8AeG5ANKg=UEU]XJU@e:T1TQ9b[];Rd
XXn4PXF3Lf=TL8FK[;2b^[bdXH=_IeiGEf=^Kg1eNh>9Pg]jMFYODD4m@e=YPH^>
UiZOYJ6CRhN3PH27UIjV[kg6`[ZaYIB;RXZBVjB_];g6bnSoooc?VfQHFe1@GFQf
R92IY:BHQ68k81LF51/Z>eEYLG1`O7edKfeZJfABBDUELiF^aMSJd/BcYj:JSXJ2
Q8bKXZVe_lG5]j:DR7YZG5IJHfY]Kg9]IfY/JF9ICD0g=d1?H6akR9:JUHZ1Oh1g
Kf]]N8:>V9nWZ9nBSXQoNGZ1Ri2@U9bNYkkIlN>fWif4KV=7@EUVM8^BU:2OS7=I
?b`O4``C9cU>HFY`MgijKfecLVIJCeATLXBIYk[?dlc3_;Vf[:6LViZP/;c1b/c7
aKfbYI=mJV9OG5YQJg5iNgA/If1JDdPn?3lnBEa[O8fCVJ:MTXb4Q8Z:RXjDWk2m
_;^i^KF[XYZLW9VNYZni`<cMl_oZ/8J5S9B6BS9CJhFKUX^DUh9ZB34]<2dT93A9
EEQAEf9ZJe=4@TI6?C8lFgB:VZ>_][BZV8b:R7]cMH:HZ:fe`/k>`K>OSXUoL5mG
GfIYJg9nRX^3NFaLE4Le;bh^=49>GG:2RH^8QH9lKV]fO7n6SIja^KRi^KFb[jNP
VYNHW:J]]LCHl?ooonFSQYN/YFDZ?FF3YJRHTYB6JdLK2@`>2`TO@EMVHF9`N81c
GeUQK6UJDFB5X;O2c=_Ph=O9b];6Yi>CXkS5blkEf]?<_::BPFeMDdeCGEQEHG1b
JEmIEU96=bhc?dQ>E5mZM7n5RH^;PW1VKWZ7TiVNXjNXYif9NW=/IVU`OY>HSXjI
ZkgAin_7RFQkWZ9Y9BQEOj6`/k>f[YIhD3@S4@400QhkD5IFFUeLB2XN8Bld:bY1
JXbT];k4b<g5^KS3a[Za]<KKjO?ko?Sbjn??]Yn9MVUPGVAYI5iSJF=B?cDc<2HO
8BPhBUALJg^2Q8V;SH^9RY6LZKFh^L;:b/W5_;Jf/k2/Y:BZ[jj/ZZ^ba>Snijim
OjFhR3/^FWbAViJBUiB1J48S7AXF4QLfEVYXG69ZLFI>@D5BG512CVj5S8nL/KRZ
UXV<TXb0M6e`Q9f]^l6l][2VTX5jL6MSGUiRIFimQXN3N6IJEeIBBd]CGV]eMWIh
MViUGe]IF5EGFf9gR8nGWj:RXIVEThf?U9FK[L?Ei>g_lokooooo`9fhh=29Fg:D
ZK:ZWiZJRVe15@<0000002=0BDA=FEA@?2LP;D97@TadWJb]]lgLe/:c[kNo^JjW
Z;S;f^WalNcRdKVKOEi4>S]=J7EeMgj3NfMDAc`_9R4M8cM>GValQ8ZAT8Z5PX5j
MWEkS9f/][o8b/:]W920MWAbKgJ4RHRCX::SZ;gIfkZ0G82]V58P=V:5VYJEUIRH
OU/m<3D_:BloHgZ2O7^@VI1[BCe1AcX]:cmSNX68XK_2^JRLViZCOg=hR:2fbMWS
k??We<[4^JNDRhZBTX^<TifRWHmmK5Q1:1LD6bD`>Ce2ADQ8ADM<CUAOIV]eOhRC
X:ff`<G1`lO3^:jYZJff`m3Ih^CSm?ooomf[[m[JWUU9H7AnM6acO7eZCbdE2`00
0008:CXi?E9SHUE4@4iTKfUTMI6LUi:IZK6`YYnT[:jRTHJ4S9FLZ:^XYYf@PgM^
HU=5@U9WLGIeLG5_HUIJI6MSGEaQI6ITHVj3SHj=RhZ:QXB9TYZRZJb_[jRJPW=b
MWaoPHN?VJ2Y][bi/jnd`LkNgkR9VL[6R61fWK[7`KF]Z9UmH4@mA4E:ADIMKVUB
A4Y7?2/K4a`d@dE:Ggf=RX2;X:^TT8J:TiZJWJ^md]cOh]kJfmO?bLK1^K:`/[k9
b/Bl]JZFMDhb91D92aDW>452A4M3@CPT620e@TeGIW^>WjR_^L;4_KVg/:^TVYNL
YKC6emkKeLJe/k^jXWA7FY>8@A/eEfYhKF5YKFMHARlU:bhb=TMZQ8f7P8MnJ4do
?DQQJF9WPYnZYIbV^[n_TWYcLfaSHVf3WZ^d_[fg/jbOUYJDShZ8T:Fj^kNf]:bR
U85dL6mUEe9BDeQLI79nOW9TGUeFCE1MK7b6R8J0O7n5QhJ9RH^@TYFIW9nU[KBm
am3CcM_dl]VcW/?Ua7m`Vk>o`kFe]k2TTWYK@BXD1`0583Hh<3<k>S4I20496QdI
7cmJI6M^R:Bf]jn//ko3`;Zd^KVb_]?Ng]K6]j^HPgIXEDiDF5A@CeQRFTa8D519
ADE:C4a@EVA/L7UjNGn:SY:MY:V`][Rf/K2c[J:TZZba]ZfTWXmlJEaLKhRM[[O9
i^kD[YZ^`8e0=fB6W:BNY:fWUhMeIf5GBSX^=4eOI6QiQhElIe]DD59;?D5MLgmk
MXBGYZJOV9JNX9^CTYZPXJVf`<?4aL:o]jbVUh>0RY6KZ:fd^[2KTi:=Pg]eJ5M7
?C8[;38d<c@l@TE<DTm:Bd]9EF5WN8J>V:6]]KNd[K>l_KjoaLk?aKJgcNO`iL^c
]kV2:a4]A5EMFeUGFE96=bTU610>2R=6Hfe[NX:0M6EVJ6ieMVm`R9bPV9F_a/Vo
]:ZUYIfGUIFHThR5RY2GW9^HUI28OgIXIWAkOHB7Ri>?PG^4Qgi`Hf1WK6U^OHB3
OgE/L7QmQH^9R8N6Q8:1P8R;R8bBUiNETXjAV9jY/;:f_K^a_^7_im2/YlG7QDUL
Rj^j];>g^K>TUW]XFT8h;2TjD61JD59CBblM71LJ7B0U>E5FDTiLNHfBSXV5QhnJ
XjZea<JmbMgVi]c4]:fSUXQiJV]cM7MfKfiWCcH/9R4P7QhV<T1;EVMfOWeeJVAV
JgJ4SYVTZ[S=eM?Dcl?0_;6WW9FJ[;6_];Jg][:ZTgn<[;RONG:J[G4Y;f9jPX=j
OHF8QXR3M6YEAD54FgN5Q7n5RGeTD55HIG9bKGZEUH1/K7n=SHN2PXR?TXn@UZ:T
WjNf^kVi[jFTXIbGSH>8UiZIUi2>RG]ZJ6i`KFUYKgQnPX>1LUi=@CXi?3a9GFYc
Ng]iOWihMfmVKW^8TYNOYjnd]kZoaLG5c<k4cNgfg;fecM:FBTaiQGmZEeYOFTa0
>2dL0@0000@XB5QSMgmcDCY0BU]_MG>4XZf[Y:[9elZh[:je^KFe^Kbm/j>NWiZG
UHb3OgATFE18DfEZKW=fNgIRCTU?BdI>GVafP8RDWJ2SW8UfK6mgQIJQZJba]KFc
[J^WX9Z>Ph24QhR@VZ:VZkS5bL2b[;C;e/2OSJ6dRdY?PJ2[XiB<Shn3M6ENFd`o
=Bi1H7]kJV5GAc8P720Y>453E6iaJf9RMhV4L6EYKgV:W;C4d]C1^lC;bKj`ZJNT
ViFES8J;RXN9PG9TCS@O6ALG6R0]@4mDEeaLFEE8?d9;F72E[[Zoal[;cL_:aL31
`KVe]KRmalg=bLO:dMG<]IB>WJ6CM6R:Zh8[5dMWMWAXIFIVFe=?BDY4>cPfBfV2
RgenRH9VBDeKJWj9R8bQ[:NMTY^YYYJ:SIBASYBOZK[3`Kfn_kfh/:RSX9^ESH1j
R9BDThZ3Pgm_H69UGU]MHFabNHJDTX=aFTLi<S8jBUaWKg5aLgMlP8=oNgYiNgel
OXB?WZZgaLgAdLo:d>3UflFXZm7ATV5gSHn9Mfi_L696=BDH1000000?:T8n@Dm@
@b/X>4IMKFmbRZNc]Jnme]W9]:^b^;Ba][c9f]_BdmC;_JVCQ7]aI5iLFVIcMGEc
K6YSDT0i>SPj>CQ6FF9/P8b;RXMiL6e/KgN3T9fU[:fYXYbKViNCThj;SHf=T9RP
Yk6e][W1b<C3eN;@ZjC8dYaZOZZg[IfGXZ^VUX1[G4Th>3PnDFYoNFUXIdlQ0@0;
7Rlf=D9DGV1MIWf;R7U`NHNDW:6Y]L;3aM?Qin?FaKF^[JJLThR8Si2<PgaoNfE;
?CL`9A/L:SLm@TY=CUIJEe=@EFAbOHRIYZ^a]ko2`;JWWYbOYjbWXjbg^kk1`/K9
`jnPY[W1/iV:XKNDDdMZP85gLGF2RGiWD4<o=BTP72m6G6QSK7alJ519D5iYIVMa
Pi6@PW^>X9f>Qi:KUXb>W:Vd[YjO[kc0_[Nc]K:VWIZHUijPWIjQYJ2ANfQVJ6MS
J7Z6QH62R8MoKEU<ADE7C5MVLFmXIF=NGfU`LWEiP8B7SY:DTI>NYjjf_lcGhOGo
ooWF^LcL/6MINXJ;PGEnQH=ZCC`X6@000003:DU>>T5CDCXV<Ca2ATIBJ8RKWIfX
`lfhW9NTZJ:OYJ^id=SEemcE`JbEQ85nO7YcLWV4PgeiLW1[G4e4A44j>d9>GVIW
KGQjN7Q`If5NGfE`O8VHYZj/Wi>;Q820Q8jJWYRCTi>@TiVMY:VWY[37g>?B/[CH
f9i`T<3>c;V_]KRbWhioLFQGD4I8HWN:QgUgKDhS20P>7R`e@U=RGEE?FFYWFEAS
N7moQib^_/g;bM7Kf];;aLG5`K^d[J^_/ZVNV8QaESXY;Ce2?cm1@T8n>T14@DA6
?CDjB5aeRINT[KFj/jNMT861RiJW];Rm`Kbh^;Rg]K2[/kg7f^GAZXjL_ZMP@F^B
T89bKGR1NVaOFDXb9AdG9D9NJF9YN7UT@cY5CE1AEVZ<XIfBSI6<MfQZO8nDTIJO
XJ2NV9JKXJJZYYfHW9bFTHR:V:FYZZZUW8agJFagN7Z3RXf>SYBNVh^3Ng1WGUQH
GV9RJgN1Pg]`If=OFeYOJg=iPHR?TYFP[kVk_lSIjoKlk/^kbmBRJh6/^KR/Wi>8
MEQ9>BlX40D00A@U>3<Y=44o910L:S0c@59ZRIVJUij_[If=SibPVif``/[BdloA
emSBakR]XiB7NF]TKhRIXJ>KRfm><R@X;c8lDfUiPH:1Og=XI5eIGFQgRIJNYZfb
]JnUX9bCRH=jLgIkQI:NYZVUWYbDPWb4T:[8bZN:V;ZhPUYeXKBcZ:6RXib<O6]V
HUACE5ehRiF:Q96AMDTc?40m=S@kDVebL79nQWIJADMGHfj0UJ:X/k_2cMKHeLk5
`lS8a/:eZJZf^[FaZif8KE90=c4_<cY7D4e:CDXi:R<M72@a@U=TMXNCUiNFV9bK
T8V>UY^NXZbh_knl_/G:aKbm`/KBhN33XJBo[F<iHYRZXYF=Qh1aEcdb<2@F6b<a
B5aZHUeXJUHe<4IFGEiTL86CUiNL//FkX8b:QgmnQiRT[;Bc/:j/Yif?OWZ1PWac
L7B1Shn=S8UoKUmFEEYNIgAlOh:1QHn;PX61NG1_MX:8R8F4PWijNh:6PWikM6YW
If]jRY2CWJR][K31cm;Jko_]cLCPj[A`NK7<b[fc]KBURFQ>>1d500@?:4QOFd8g
<Q`000095b0]@EE]O7b1TjVURGMkQh^?W;2m`lkCeMgUi=[>aKjn^ZbMTHN8T9BI
X9fAPg9NC40f;RX[<Si5BUIWKVQVIEeIGFQdOXZIXZFZ/;2a/k6a][N`Yj>UZJFN
WjV_/kB[[;6ZY[6eUFQPQYieAeZ5W:BOVZ2QUh9ZEdY0=Si:EG6>XI^;SI:4GCXg
?TI>DUALL7MaKGN:QfmDCUEGEeMRMXVO[k_5b/o=`[J_ZjRSWj6[^lK:blc4]:>>
OgI^IEaDBChm>T1EGeM9>bdM414M:c]?HVadO7j3R8Z9R8nBTYRLVijU[Zna^/WC
e]cMgnCYiLR[]MK7O4ETU9fFR8NCWIN4KUE09@P21ai5HG5^IVe`EbTF9ca2@DYQ
P9^UZJZd_kJPSib`ZY^GXJRZ/KVk_L?3]jRGQgmoOG9WJWN2PGamO6mLCTU;CU5A
DU=FHVihPhAnOWegLG5dOY6LYjn[XYZ>Q7]cKgB1S9FIUHj;RXElNX6<VJB`_]CT
jMNaWKcGYeUIW/C4^Jna^;BXV8YlID4S6aLU?Da>ADePFC88004<51HS?Um]IfY[
P924KfZ4Ui6?VJBWZKFk`<SAf=K;`;o2`KndYJ>//Jj`ZY=iHTi8DEIDDe5BEDdn
>dQ;@T12@D=>Gg:2SY^PWYnQXJ>Y/;Be_<C<eMcOgMO?`;2//;>c_m;Oj>WAYXjK
UDd43T][KVebOXJ6NfaMCCLM4QLP>eedNWB2U8]UADIEHVYWJGZAUXV0PY:<KeUL
NhV1Oh1oMg^5OWn@WZFRViVOWiVAQHBF//?5b<RjXHQhM7MhMGIoQX9iKFAIAcXl
?CPj@TeGFEYRIV5PI6QZKGEkOH:;UIFIXj^`[j^ZZ[6ja=3Gi_Sbfl;7f;]]@fRE
XYZ>Qi6BP6mNED<U4A4?4bXnA3i2EUi<<RTe@4I9DFN2UYFGZ<7?_jNQZ[Fh`<S@
dm3@cL[6_ko0_[^i]JNMT7]bMh22PhR9Mee6=C@i=SM3DEePHFQZJ69ICdE5Cei`
Qinb^kN_Yj2JTH^6PH:9TI>CX:j^YIV9PH5oNXBK/<CDcjjZb/F2?Tj6WifIXkO9
`K2SUHA[DTI2?DYTLV]IGfeM=Q`V<bhZ9bXfBeeTJ7J<Rg9SJX2;RI>QYjbkalS5
`;Zg/[6d^K^e/:^VZkBb[K:^VX1`Ge=?Ad11C5QMF5IGDTD]7ahO8B/iEG1oSiJ@
Ri2@RHF5RiRV/K_4bLoBclg@e=GCb/SEgN;/i<V^]<:D?R5:LWeeJf]jN6YOB3T/
50X<5c16EUaDG7J0HclkCUePHFj7WJ>SXJ:d]jN:NhV;NW9hQ8ZCWYZ=Q81lM71e
O7mlOGekQYFMW9bSX9:3Mg1_L6m_M82:S96JVX]_Fdm0>ca4EfMdQ8j6NWI`JfY^
M7YmPH^DV:2^^Kk2b<W7b/oBiO_ol]?4dN30NV>7Y::KUI:KVhafGDhm7P`:3b8j
Ce9:CEA?;`h<838n@T]NMHN9S9bc^k2QWJR]YZVa_LOAi^o`l^[IaKF][JbTWj6N
WjJWXijHS7YOA3Pl?cln?dMCFUYOJfmUDT4i>3m:EVEdQiZPWZ2SXinLUiBJXZZZ
Y:6RXIjPYjZ_^;FZY;30[XYdPJFHDBA=PiVEQ8>=TX=dIEA@@c0Z<4=NNhb5O7]i
GBlH7bl_;3QCJg=`K6UbO7MUG6YlO7R6VJB`bMS>bLkCeLNi]:nSViZHY;g@bKk1
^ZR7JeYGFTDf?U9NIfa`M6=@B3@F0PLH9CI0DWV2OXV;RHV9QWenPXNGVibV^LS<
d=;Cc<OKm?3UfLZ`Xl3?ZFmTPYfKPW1_NG=PEE1:>B4A5RDeAeiRF5iaKThd=4EB
EEe`PY6NYJjlc]6nZjB^/JBQZJVX[;:i_/G8^Z>8OgARH6ISIGN>Vj>Z[:1nIeeD
DU9EGFf2T9>@Ti^>O7I^HeAAEei]Phj=QHRETH9eIeeNKGV0P824T9jV[jn_][>d
a]_SfLRcYkS?ZEaET;VlZIVCUhakJEaOCS0J2PlR=415?dAEEC8<00T=3A<VA5IT
K7F8WZJCRHbFW9BH[KZg^LWGh>;Jg=gBb/JeW96<PXVZ^;Fe]Jf>LUY<AcdhAEIN
JViZK7MdFTmPK6eiR96FUi^QXZFXZJV//Jj[[KFg/[Be_/W8a<NnZ:>QZ;k@g<^/
QWfKTEDX?fZ7QgZ0RH9fK5I;A3P/7b0]A5QSH5aWLFI>>30i?clnBEmZK6Y/O8b0
HUEKKgalPY6EVZNc^;Zo_[jg[:BKUH^1MWVCYjb^]/:mX8V3Q7UOE5]XKF=KEeE@
AS@Y9QlT;Si4@TQBFf1TIfIYK6Q[LWIiOXB4QhnIWJJ[XinV`=7AhNgB[Z>g_X]6
?VF1RX^3NG]_HUU8@SHM51PP<d]PIVE^P8M/D59RKGMfNYB[];>kdN?Rc[JdbM76
`LcAblcIfm;8`<;3`[neXHMaGUYXMGb2SibJQGAUH65IC45>IWQoQYBKU8b6NW1a
NGn2RHjLYIf<OhJATHV2PHB7RhVBWj2QYjnh]k[<dmgbooo[ak[Gik5ZJ9c8e/o7
aLo8]j:2Je0c;2`^@UaZIU=BHVA04@hU;b`V93=9FEiYOYBHQg=aPY:GUj6_/Jje
`<W<cm34^KbhZYZ;OG1bOGmkNGenLfYMCDPj91LG9cU:DeaUI5]GFTi5B55OKGV:
U8j8QhJ:T8j:RXZ>Uj2RXZV_/:NPYZRMUj6WZ[2ZUH>DYXPj0R1CFD]9DF1UEDHd
:R<<000032U6E4eAJgQD9QdaAeADEVE^LW=eQi:BPg9]NXMmL7J1RI:IYJb_]kN]
Z:FZ[9^AT8fFZ[^m^;Vn^ZZEQX5mLVMXKWEmOX6:RGQWEDQ1@DEDJGV4TIJ>Q7E_
MH:0LG>6TIZX[jjd^[k6al38dMCRk^gOc;kCk<5[Ch:YXXUoPXb=OW=QCT8Y3`<:
9dADG5]UN7]O?cU7EemTKX6JZZNS[;_7_JZT]<_<`LOMi>GbmngWiN;LbKbg[Z:A
PhFAVIVARXEjIE9:ATU=@c4cAEEWM7ElNfeVIfIRGf1XMX>BXZZZYj2@RHR2Mg1g
PHZ<RX^?SXN;TIFQZjfdaMK>[9RgfkY/HIRm^j>NZ:ZTUhUnM6EBB44l?dmWKF1R
OHIP:Q@P;C0^<DUTKfY[Lgb0MFecQiJ>RIJX/kc7b/S:d=_LeL^g[J:=O7=lU::P
Vi^HPF9:?SXh=3<h>Ce5ATE:AcXf>3De?4QGHFQbN82:TYFDW:2LUYNMWJ2Z]L33
a=3MgmcJgnCVm_cXaJNabJQL?fR9T8QnMfmTEe98@cHK4@d97Ca>EUALLGUUAS]6
D5UKG6ahQY:>T9^OUHAoR9:;RYFLVIRKW9FDWjZc[ZFPW9Z@OgN1W[Fk^KRgY8en
M79ZHEeIGF=_O8:5O71WHUiGEeUOHF1VIfA/N7imMW9]J6=MG6=aOhF9T9^W/K>f
cMG=cM;Fa;6jaZMQBGJKY9j=Ph=fIEQ4=1h5004011@V<2lc?d@_4@H94ahW<DQN
L7eoRYb/ZIJ<TIbRZk[8d=ONh=oRhnCTgm[Gd/2WSWmoR96DV9ZBPVQ<=2PM5A@H
93@nA59PIf=ID4];D5Y[O8RBWJFVYZZf_kV/XYN9PGn5TibQZ:VYZ:JPXjNR[L30
ZIFZa:EG@WfW[j^RZ;VhZj2:MEm6>3<f@UalRh>0TIEgD3e0C51<BEQ]OX1dPY^V
WhUkP8Z;S9b]];[1b<[4`l70`;o4akf`Yi^K[;J_Z:FVXiZ<NViK@cDg?DIDG5mU
HEE?CDM0?TA?EV1`Pi2FV9NCUINDUINDU9VQ[;Nm`l[@e^7ZjN;XooohhM;UmLYh
G8RUWh^4TYfCPG5IARlE3@`<7cU;De5ONWaOAD5@HFY^MXJHY:BP//cB`[Fd^kjf
/KJh/k>h^kN_[:NPWj6UYYZ9N6Y^P8V8RH^;QWe`L6iLC4Q<CUEQJWF4S8N2Og9[
L7J0R8jKY:RVWiB9PGUiOGYhOGijN7V1R8bEX:be/InUaM;0XI^f`8e;F8fRX8n0
PXj<PWMWFd0R5a8=83e<B3i4CdH/4`H?724P93U>FUYOMX^ESWn1TYfLWJF^/k[8
d=7EfM[CblG3`;R`YIZLZ:fRTHAjI4Xn?cTX5a<G5Q<E7BTc=CPl?3Le?DMFHFMc
PhnKXZ2RYjZ/Z::QY:RZY9nNWj>UYZZ/[k>`[JVGNfn3OSh>:UiaKFEUK75XH5UA
BBdK6a`Y>d9@GFYlO6aA?dECF5QEGGF;TXR<Vj:MQVeYMGU_LXRHThbAUi^U[jbT
WIZKUY2:PWYoRY:ASYNER7miMVmJA419C4Y;DEYRIfi_HDm9CEEJF5URKWR1Q8B5
QX^?SHV8Ri>HVZ>]]L7@eMWQi>OUj_?Xe<oNgJQ`NI^`/ZBRX:6COGERC3<K5ADF
:CQ8GfQaNG9J?SM0ADiAFWfGZ[:ec^[cjn7KfMCBenC_l_C`j>S/kNcSe/Rj]JRH
QFi[LgIdLgQhKfQTHUi:>D17BE1LIgB8Thj=S8N6RI6LXJNc_L75b/[8d=C?a[^a
Yj2NUi2?V::UYjje]l7EgmG0ZIBMWE/U?F^6SX^@WZfYWY1hI4@Q61PU@5E_PHRD
SgQG>2d[:2DN9CiCHf1UOXjDS821QhJ6SIbWYJ6MWJJea]3Cc/O1]ZVLS81oPH1m
PXjBS8B1PGA@;AT>1`002B4f?D=?EU=CCdHo@D95D5m_OX^JYjfa/ZjXXjFZ[ZfY
Z[S:f>?amNkYi^7=/YZJVg8e8T9IG5MCF6ESE4e3>B@800@12b@hCV1eRiF7K5]D
D4a9BUmiSYJGZlKGe<Jl^[J]YjJUWI>6OhJBXK6m`/2k/If6M5m:@TQ@E69gP8:1
OG]cGDLi=C]4CUYbPhZ@UINESXN2MV]UHFUdNh27TIZDR85lNgUiOhF9S9RU[[S1
bM7Eg>cci/Ff`JmcCembOH1nRj:^YZ6JSGMB=RPF3AXT=TA=H71^Fdi6@T<o=S]7
E6MaQJ2fa/[<eM[Dd=;He]?DeM?>c=7LiN__kn[H`J=oI59:B4E9Ce5ACU9CASDV
7Q`N8b@`@TaPLgj;Sh^=TI><QXV>TiRNYk>k_KVd/[6_Z:FTXjJYZJNTW8n;WKBl
^[2Y[jQ_<2Ha<3Dh@5Q]MGj2PW]Q@c<S62<]=dUFIGV2Ng1[LWI_G4]8BD]:Eg1o
Q8B2QXj?Rh^>T9BFUHYlOXJ@VYnT[kVf[ZJEQgUVFE5?DeEIH6inNFm^KVIHD4Q5
Bda;CDe:CUa]MWb1QXV4P7]jOXJ;RhbAUIf/^<77b/oEemOGe=7@f>_fm^kQiN_?
VW5QE4a4@DaKI6a_K6QE>R<C0P4D7RXhBEm`MVeVKh23NFa_Mgf0PYBS[K:d_lc?
c<W:cM?Ed<>`Xi^BShb7QXjGVIZJU8QaF4Q1?CTi?DIIIFU`MGEaKFe]KVmcO8:3
QX^DW:2UZZna[ZZRWI^GShR4P8:7QX>3QhjMZJRX[ZnZZKK3a<G1_/gB/XEbJeiG
DeUXMXBAVJJWTGU]HE9?BDA:DEUQI5m>@4YNJfUVKWMjLW=kOH25Sin^^LKDi?Cn
oogah]kQh=_;_[o2`/O@d/k4/IZ8NF=:>S4f@DA1?CXd;blb>4=;E61VJfmbMG^1
Qi:LY:^`/K>f/JNRXZ6TZJZ[/[Jb[Zn`/[6`ZjNVY:>MThjCWY5_GeU<@BhN6R@c
?DiVM7EcM6iHD59?CU1GGEmNEU=LHfI[MH67RhEjNWalMfi/KVmbLW=gO864R8^;
SY:CTXn=SH^7Ph23QX=nOG]eKfa[KWEiOX>4PGahKUmFFEeNFeA>CTi:ATUCHF]a
N7n3Q81kNW]lOX:;UJ2Y/kVg^/74blo?dMCHfmcLd<G7c<JcX9>1MFMDBD@n>Sm?
EUEBD4m>E5]KG5UGG5mPGUUIG61UJ6mdNX:6RXnCVIfQYZZZYjNZ[[:c[:BNViN@
RH9iKfY[LGZ1PWijMW=`KfiYIFM[K6mdMgYkO825QH>1Ph=oNWIgOGilP8fIWinN
ViF@RhAlMWAdLW1`L71_LG5`LG=eNgaiN7f6SY>GVYnTXZ6SXinIUYBDUINHUIFF
UINHUHn:QgmiNGMbKVi^KgEkOWikMg1XHV5UJFmgOXJBXJjg^;Jf^KVe/[6^Z::Q
XJ6PW9J?QgedKFMVIfQ]LWMhLV]YJfe/JfY]LGIkOgmlNWaoPXB4QhbBUIFGV9FB
TI:CTiBFVIbOWYN?RhV6OW9UGe]EDE1@De]SHUeMGUUEEE]TJF]^M7^3RHjCUIBE
UI>BTi:>RhZ;SYBKWY^IVYR=O6eXJFUXHeeLHFESGEMCDeACDU1@D59FG69XKG1c
N7j0P81oO7YlPXV=TYRKVibMVYJDUYJETXZ0Ng=YI6EZLGV3R8V8Q7YaL75bLgZ4
TIbRY:BPWj6OVIFCTYBEUY>@TI2<R8R8R8J2OW]iN7IeMgQfN7YkOG]hLW5dO8B8
QX:1QX^?T96GXJJUXj6RXj:PWYZJX:JYZZVWXijIThn:PGI[IF5KFEUFEUYMG5]L
FeE@D59CEUaTJFidN7n9Si2@TIJIVj2TXInQZ:nc^;Zh]JnTUHR4P7McMGMhMgEb
JfARHF=THUiOI6abMG9^KW9iPH^EW9fJUIFIWZ6VZZne^K^m_;Vg]KFe/:VRVi>>
SI6EUiVKWI^IVIVIUi::QhfEW::Z/;:_[ZbZZ:NUXj>WYj:MVIZMXJ>QVi>:OgAZ
H5YKGEiPIVibKVUVIV9MFEYPIV]^LGV3RX^<SHj>SY2BTI2>SY2DUiRHUiJJWj2K
TH^6PgmfK6EJCdY=DEEKH5mMG5QACU1EEUMLIgF1R8b@THn>TIRNXZBWZZf^[Jj]
Yj6NVYRBRGa`K6UUH5mPH69RGU]FCDI2@D51@TE9CeMPJWAlPhF2OWaiMG5bLg5c
OHVCV9ZIUY2:PgehLg9aKVmcLVeXHf5NGEiOHfEOEeEIF55>DEIMIg5hOH:3P7n1
P7]eM7EfNhB<Shf:QX9kLfi/KV]UI6U`LW1^K6]ZJ6U/KW5eNX>?UiZIVinSYZNX
[:j[YjRZZ::QYZb`/kFi^kZd[JRRUhYnMW=aKg=iO7Q_JVMPFUIBD4mAEf1[Mh25
RXjDVYjPWj6X/;Jj_[nm^KRh^;Jb[JRQV8j4O7=ZI5mMGEaKFe]JEDe7A4A5BDiB
FVA/LWMjOGn0Oh24R8b?U9ZLWIjRZ:ne^[bm^kNb[jn]YYbET8^;SY2@T96@SHn>
Qh1oPXB1PHF;UI^MWj:RWYREV9VLX:BY[Zf/[:ZWWYJ@RhJ3PX5oNgQfLFe/K6YU
H69XKgAiOH64QhfATi>@T9BFV9VJV9NJWInNWZ2RXZ2NWYbGTXn=RhZ7P7QbJUa=
A491?SXi?4A<CTe:AT4l>S]0CEeYKgAlRIBJWI^GTi6?SHf@U9FETi>BSXImMgE^
HU]JGEeIEUAEEEACDU1@DUMJGF5TIFEUIV]`LW5dN7aoQ8V8QhZAVJ2UYjV^];Nd
[Z^[Z9nGTHUoNW]nOg]iMgAfMgEcLG5aKfaZK7AkOhB<UYfMW9fNW9RCT92BVJ:[
/K:_ZZ>IShIlKF5QJGAjNWQfMWIbJfMVIFIWJFmhOh>7SI6BTI6ATiNJVifQYZVV
X9^IUY>ATI6>S8b<RXN3OGAWG5QFE5=ADUIJGf=TIfY]L71/J6Q]MGf6T9fZ]Kk1
_k^i][Ba[ZZVYJV_/[:_[:ZTVHf2NWMdLFaXJg1eMWEfMWA_JFEUJW1fNh2:TiRM
X9nNX:BXZJb`[jja][c0`lG5alS5_[RbZYnCR7mhMGEdLG5dMgYkMg5YH5E<BTeA
E5YVMHBCVYRBSXb8PgmmOH:9SiFLWYZAQgmjMFiVGEA@DUEGGFI_MWMdL6aYIfAQ
HFAYL7V4SY>HVYVIUi>=QhB6RXjBV9jQXjJYZZJLSGmeLFeWHV9UIf]`KVEMFeYI
F5IEEEMJH6M^LWIlPHN<SXnAU9NCSHV;TYNIVYfOX9nNVI:;PGE[IF=SHemIEU]M
F5=@Cda9ATA2@T=8CUELIFabMWQkPHF7QH:4RHf?TINPYjfb];>^Z:>LTXUoMW1/
IfAVJfi`M7E`IEQ<@CTh>C]1BeIRKWQoQ8V>Shf;RHV<Si:GVijQYZb`[jbWXIbD
SXV4P7n1Ph>4QHF8Rhj=R8B2OganPhN<TYRQZZj^[ZbYY9jHTXn@UYfV[K:d];B`
ZJ2ERX1jMG=aKVUXJFY/Kg5_IUaECde?DEEKI75nRI:FV9RETXj:RHR8RY2GX:N/
/:n[YIbBRH5hKfQVJFmcLF]VHV9QGEIBDeEFFV1WKW=dMWZ0R8nDVZ2UYjNVYZR/
[Zna^<35b/g=b/G0^[B]YijGTXn=SY2=RHR:RHAlL69IEUUPIVihPXbFWIjLUi28
PhB7RXfBVZ:W[:j^[JVSWINARXR7QhV=T92>S8V3OGUeLg=dM7AeMg]nP860PH>6
QhF3PGmoP8>6R8R7RHf@T8V2P860OGYiMg=^J69KEUACEUmYKfiVG5=;AD0o@d]F
IGB1RH^9R8R5P7imO7f4SYNLX:>SXYfDQWU_J6EVJ6QYJfmcLVeXHUaFDDi@DeMM
I6abMGIgNGYlOhB7Rhf>TYJKXZR^/K:c/k6^[:ZYYjBRXJ2NVi:5NGAcLg9bM7Mf
LFUUHUmJFf1XKW5eNGanOWmoO7UkP8J8RHZ>UIfRY:6NVYNETHQnMFm^LGMkNgMc
Kfi/J69LF5IIGF1RIFY_LgQiMWAcM7QlOGemP8J=TYJHUiF@S8Z9QhJ6R8V8Q81i
JeiJF5aVKgMiN7A^Jfa]Kg9eMgUmQ8jHWj>TYJZ`/k2][k:]XZNa];Zk^[F]XiV9
OgioPXN6OGMeMGEbL79eNWf0P825SIFJWj:UZ:^_/KBf]K:`/KBf][Ff]kJf][:Y
WiREU9FFUYF@R85hKfYYKWEgM6eVHV5SIfQVHf5RIFMXJFabMWQiMgIiOhF7QXN:
SHf<RHJ5Q8B2OgafKVUYJfa]L75_KFi_Kfm_Kfi[JfidO8F=TYNHUiFAS8V;SXn=
RhZ=T9BFV9ZJV9>=Qh9nO7j0NW=_K6YZK71`KFYTFDa9BdQ<E5aVL7EeM7EhNgj2
RXnCUYVIUYFFU9:BTHj:R8N4PX5mMFeWHEaGDe=FFUYFDUAKHVMVHV9TIf]_MGao
PXN;Shn<QWmkNGQgNWf0Q8^BTHj:PWemOGUcKV]/KFmeO8:5Q7mfJfESI6Q]L75c
Mgb1PX60PXR>Ti^SZZf^[:^/[:^YYjBQX:6QX9bIThf8PgmlNgYcK6]]LGIkOGem
O7alNWUkOh:4Qh^@UINHUiRHVIVJVY^OXjNUX::W[[6/XIF?Shj?SH^:RXb:QhB1
MfYRG5QHFEUKH6U`M7IgN7UmPXJ8RXfAU9FGW:2PVi>=RXIoNGMgMW=aLG9bLG1_
KVmaMG^3Ri:HVYbQYJRZ[[>h_;jn_/31`L6n_;Rd/k2[Y:2MW9^GT8^5OGMfMgA^
JfibM7EfNG]lNG9]JfU[LGIjPHJ8QhF8SiBFU9>CTi6>S8fAU9FDUINGUI:@SXj@
SXN0OH:9SHj@TYNGU9FFVInOVI>?SiFESXAkN7E/HeYBDEAGFUYIE4a5@3dm@dQ;
CDi>D5IKGEYFD4U5ADE5ATY=BTU<CE5FFUaLGf9VKWMnPhV?U9VKVYVHVinRY:BT
YJFTXI^BRX=lNGMgNGalMg1XIFIVIFIYKFeZJ6Y_MGYnQ8R8R8V>TYFHVY^JVIVJ
W9bJVYbNWY^ESXV8RXf=SHb9Q7egMWMhNGMcLgImQY6IVYZJV9ZQY:2LW9jQYZ>K
U8n<Qh=mLfUSHV5OGEaLFeUGEEMLGUaKFeaMHFQ^LW=bL6e[JVUZK6ibMgb4Rhn>
RhR8SiRLWZ6UZJZZZj^[ZZRYYj:MVYVIV9F?QgifLgEhNGMcK6QXIfU^LgMjO7n4
Ri2BU9NMXjJUY:FVZJRTXInOWibKViZNXInLUY>CT8f9Ph1nOX64QXZ?TiBFVI^O
XJ>W/;k3`/C8cMKOgmWEclBl/jJISXMoMfiRDTHo?3Xc:RDS9BT/;cDk?Chn@d]C
G6A]MGIeMWYoP7n1Q8N8R8^CW9jJUiFBTI6DUiZLWZBY[:b[[[:d/Jj/ZZNRWI^J
V9B<QGmkMg9]If1LFU]JEU9BE5QIFemVK6i_Kg1cMgQiNGMdLg=dMgYlNWEaKg5e
MgIeNGakNGUkO7]iN7QhNGYoQXZ<Si:IWZBYYjBUZ[2h]jnWWiRCShQmKfIPFeU?
?S8Y928N6aXK7bD[<ci6BT]<CeALIF]^L71eOXRBUYNHUiFEUiVKWIjNWinNWInS
Y:2KUYNHUiJFUIJFUY>=RXV;SXj8PGahMgA_K6YYIfAQHFI`MG=dNGj3R8f@UY^K
V9VLWinOX9jLViRFUYJETXb8QhJ6QXF2PH:2PXJ;SXn>S8^=Si2DV9jUZJ^]/;>h
_KbbZJR^^;Vb[:>NVXn2MfYPFEEED4U5@dM?DE=FFF1RHFE/LWMjOhR>TiFEUiNG
V9bPXYjHUI>CTI2ATi:>SHb<SHb=T9:BShb>Si:FVIfOWinPXZBWZZZVWIB<QhF4
QXV:R8J5QXJ3OWQeMWUlNgMdMWYkNWMeMgUjNgn1Q8B3PXF9SI:CT8b8R8V5OWUj
PHJ;Si:EV9VFT8R4Q8V@TiFHWjN^]KFb/JjZZk2]XIVDT96>PgE]JFEPFTm0=S8b
<c8^;C0f>c/l@DI:C51GH6IXIfITHV=YLG=_JVU[L79bL79fMgEeM7AfO8B:RhfA
UYNCSHR9SY>EUI:?T9NPXIZ@RXR:RHAnNGQeKfQPFEIFEeUKGeiJE59FG69VIf]b
O8F8Q81mOX:8Rhf@UYnTYZJVZJb[Z:FVYZFUYZJRWY^HV9ZKVYF?SHb>TYFJXjV/
ZJ>MVYjSWiF@SHR5OW9VGEI?BdU2>SPl?d94A4I9CE=EEeeUK71_KW1gOh>0NWEe
O8>8QX5oPXZCUiJBShj?TI:DUibSZJnc]KNi^[Re/kFd[:BOWYjNViB?S8R0NWMa
JF5KE55ADeEJGf9TJW1cLg9cLW9dMgb3RHnDVj>YZjVWZJfa];Fd];Nl_kjj]K2Z
Y9jJVINCSHJ3PGimNgUhNWeoOWj4Ri>IWZ6OW9bNXZbc]:fVXYbJVI66O7MaJfAO
EU1?Cda6@Shj?497BTeCFF1UIVEXKgAeM7AeMWUmP821PX61PhB3Q8J7QhN6QHF7
SIBLXjFUYjb^ZjNTWiVCShj?Shb7QHN7PWUcK6MVIVAUJ6]^LgQkNganO7YlP8B8
R8R8RHb;RXZ7Ph5oP8:3Ph5lNGMgMWEdLgAdLg1^KFa[JV]/KFeYHemRIFYaMGIg
NWj2R8nFWJ6SYZVZZZR[/kRe[JRVXIjGSHF0O7I`JF5GCdY7B4Y9A3lnADaCF5YM
HVYbNGf0Q8F5QXR=Ti:<QhJ9RXF0OGf1QHJ9S92DUiVJUiFFUiZMWYjMWIfMViNC
Shb7PWagMWMhNGQgMgYmOW]eM7IjOGemOh:3Ph>4Q8B4Ph:2PhF5PG]eMGQlOh64
QhV<SXj?Shj>T9:EUiVKW9bKW9nQXInKUiBARXB0Oh:4PGikNg]hMWEhOH:7R8J5
R8fEWJ6OViNASY2ARWmiNGUkNgQeMGMfLFaWI6I^MGUmPhJ7Rhn?SXf;QhF7QXJ7
QX61Ph5oP861Q8J5QHN:RXfEWJF]/:n_/;:a[k2^[:^XXY^GTHZ1N7AcMGE`JVQU
Hf5OGEaMHVQbNgn1Q8N;TIFFUYJGV9RGU8n<RXN8Ri6ETi6?S8b<Rhf?Ti>DUIFF
V9VESXIoN71ZIfMVI5mLG5aMGEYFE59ADE5CEUmVJFiaM7QoQXb@U9NHWjV^/JbT
ViFCSXEiLFe/J61CBD<o>C<a=3Lm@dQ:Bda@E5IJHFIYJ6MYKW9dLFi]JfQYK71a
LWEhN7QiO8><U9^QY:JWZ:b_[Zb[ZJ>KUiRHVIVFTXb4OGUgLVaYJfe`M7UlOGj2
QXV;S8f@TY>BTI2@T92?RhJ1NgA_KVi_L71]JfUXJg5fN7YnP8>;TIBHVYZKW9^H
V9bPXJ2MVi^LVYB?SHnBU9FDShf;R8AnO7YjNgb0Q8J6QhjCTXb5PX64R8^=RhJ2
P860OgmoO7amOgmnNgQfM75`M7^3RXj?SHZ7QXN7QXB4QXN9SYFHUi>ATYBBSX^<
T9FJVibNXZJ//;6b/k>b/:n][k:c[jVTWiV@QX1mNgQfMW=^J6=QH5iMGF5WKW=f
NG]lO7YgMGEhOXJ=Shj=SHn>SXn@TIBFUiNEU9NJVINDTXn<RXZ;RXJ2PH>6R8Z;
RHF3PWmjMW=`KV]YJVe]K6ibMgaoOgemOWelNganP8:2P820PH:0OGYiNgn1PhF5
QXJ9Rhb<RH=oOGYeLFaTGEQBCDU6@d51@D95BDa>CTm@DU9@DEQPJ6a_LG9fMgEd
LW5fP8N9RhjAUIRHUIBCTI2EVIVIV9RIV9NFUYNDSXZ8QhB0Oh:6R8N5P7QbKg1^
JF9MGEiQI6QYK75jPhR:RXbAU9BBT8n?SXb;RXfBUiRDT8n@TYBHWJ:SXJ2PXJ>T
Y:6PWifLVYNCSh^8QXB4PX5oOW]iN7EaKVi_Kf]WIFI/LGAeLg9eNGamO825Ri2C
TY2ATY:FVI^LVYNGUYNGVZ:ZZjRRWifFSXInN7AbM7EbK6MRFU18ADI7AdM:CU9C
E5MKHFM/LGIlPXN<TI:@SHZ<TIBETi6DV9bLViZKWjJZZjb/[:^ZZJZ//;6a/:n_
[ZVTWY^KVIJCT8j<QWmkNGMaJFMXJFMTHF5RHfASHfM/LgYmOWn4R8R5Q8R=TYFF
UIRIUYFIWZ6OWj6QXj>QX:2PWifMWIZJVi^IV9RCRhJ3P7imNG5/JFESHV9TIVUY
JFY[K6mcMGAdM7=cMGEdLW1dNX66QHF6QHF3P7moPH:3R8b8PhB4R96?Si2BUYJD
T8EjNWf0P7UdKfi]IemGDDY5@d=3ADA2@dI>EU]PI6IZKFm`L75bLW9dMgYkN7Ef
MgQeLG9iPh^@T8n@TiRJV9BFVI^NX:BWYInIV9VEShZ5Ph5mN7IhNWQdLW5bLgAe
MWMgMWEeMgUlNgUhNX25R8V<TIJHV9VHUi:<RHR7QX>3QHN:SI2?SXj>S8Z9Rhj@
THn>SXn<RHF2OW]hMWIiNGIcLG9eN7UjNg]lOgmnNWUmOh64QhZ=SHb=Si6?Rhf@
TI:AS8N8R8N3PGn0Q8R<SY2CTY2?Si>JW9fLVibIU8n9QH>0OW]iMW9_JfU/LGEf
Mgf4RXf:QhR:RhZ;T9FIW9bHU92;QH:2PX:5R8^<SY:FVIZLWYnPXjNZ[:b/[Jna
/[:c];B`ZjNSWIJ?S8^9Q7efLFaXHf1LEeACEEMHG65WJVebNGj2PhJ9RHV8Q85o
OGakNgf0PhF4PH:5RXb<RXV=Shj<Rhf=S8V5PGmoOWajNGMdLg=dMWMgM79cMgQd
KV][Jfa]Kg=jOh1nOGenOWeiM79`KVi`LG9aKfaXIFASHV5OGE]KGF5VJFY^MWj6
Rhf?Shb9RXjATY6>RHJ6QHB0O7MdLFm/IfESGeUFEEACDeAEEEECDE1CEUQKGf5S
J6ibMGQkOX20Oh65Rhf>TIBHVifMWJ:Y[k>e][Ni^[Zj^KVg/jjZZ:BPVY:=R8B0
O7UfLg1]KFiaLg=cLg=dMWMgMWMgN7]mOh64QhZ;SHnATiNJVi^LWJ6SXj6PX9nM
VibNX:6OWYfLW9ZHUY:?Si2BTi:?RXB1PH1nNGIdM7IfMgQiNGUhMgIfN7]nP7ml
NW]kMg5^Kg1_K6UVIfMYKG5gO824Qh^@TiFEU9NKW9fPZ;6c/Jn/[[:c/JbXYJ:O
W9F=Qh9kLfYQF59@Cdi;B4M9CE5CE5IGFE]OI6U]LGMoQ8J9Rhj?Shb9RHfAUINH
VY^LWYnNWI^IVI^KVYZJVYRCSX^:RHR9Rhf=SHf<R85lN7MgMG9`LGAeMGMgM71_
LgMjO7j0PhJ8Rhf>SXb:R8J6QH>1P822Q8F5QXR:S8f>T9>GVYfMW9bLWIfKV9B?
SH^8QH5mN7EdLg5_Kfm]JVMSGeYFE5EEEUQLH69SIFQ/L7=dM7IkP8F9S8jATY:@
SXj>S8Z8R8V:RhZ:RH^<RhV8QhN7QHB3OgajN7QiNW]kO7inOh1nNWQhNGYiMgQi
NgeoOgmkNGQgMgEcLgEiO7]kNWYjNGQgMgQhN7UkOGimO7]lOGemOWn1Q8F4PX:3
Q8F5QHF7RHR5PX62PGikNGQfMWIiO7ajN7IgN7QgMGEeLg9cMGUlOWejNGMgNW]j
NGf4QhJ4Q8R:R8J6QhN8RX^=S8Z:RXb>T9:CU9NIV9B?R8B3Q8=oNg]lOh63QHV=
Shj>Si6DUYRHUiFFW:2RY:>RY:R[[:b/[Jjb];>_[:ZZZJRRWIVFThn9Q7mjN7Qg
MG1]KFi]KFe[J6MXJVa_LW=aKFa]Kg5bMGYnP8>7RXfAU9>?RXR8QhF1OWn1Ogak
OH66Rhf>T9BFVIbPXjBSXInNWYbKW9bLWIbHTi2>S8N3OgemOWalNg]kNgMcKfaZ
J6UZJVQWJFebMGMkPXR:Rh^<S8b?TI2<R8R:RhZ8QXF4Q8F5QHF5QH>4QHB2Og]d
KFUUH5UCD4mCEeYLG5aOHfM/Kg5bM7IgNGj1PX>4Ph61Ph>0O7anOWUcKfi_LG5b
KfYWIVITHV1OGEeNGf5UJFebNGj1Ph>3QHR:RXZ8QhN5Q8:1PXB6QH>3Q8B3Ph>2
PX>0NgIeMgQhMW9`Kfm^KW1bMWYoP863Qh^:R8V:Rhf@TY>DUiVKWYnLVYZJViZJ
ViVIVINCS8J2OgehL6UUI6=TIFAVJVe_LGAgNGaoPhV>TI6ATYJKWYnLVI^PXj>P
VifNWI^HUiRIVIJBShR0NG9]JVY]Kg5eNh:4QHN=UIfOWYbNXZJWYjJUYZNUXZ6R
XZ>TXZ2OX:6PX:2OWIRBS8V7PWadKfm]JFIUIVU[K71fNgn0OgmnOGinO7YmPhN6
QXN9Rhb?TYJIV9FCUIRJVIJAS8EoNWEbL71^K6YYJVabMgaoPXJ;Si2=S8j@TYJG
UiNGUiNFUIBBTHn<QhJ:SY:CT8j9Q7igLF]UH5aECdU3@3hl?3dm?SdoADiFFEUI
G6=YKFmcN866R8Z<T96@TI2ATiBBShj?Shb8R8R5OG5VH5iNGE]LHVQ/L7AhOH22
PhB5QhV:SI6CU9BBTY:@SHZ8RH^<RXF2P820PXB6QH>1OgaiMWAdMGAbKfi_LWIi
NWn0P8B7QH:3R8f@UIZNXZJXZj^`]Jn_[:FQVI>CTHf<RXF0O7]jO7]hLfi]KFmb
Mgf3PX22Q8F6QHB8RhV9RHbBUYNFTi6ASX^6OgilN79]LGIdL6YUHfEVIfQZJf]]
KW1gNgalNGUeM7MiOX64QXV:R8^CVIfTYjNVYJJYZZRSWIRAS8R3OgahMGIgLW5c
LW5aMh65Q8N;RhZ7QXZ=SHj;QhF4Q8J7SHn;RXf<RHN:TI>=QX20PXJ7R8^9Ph23
QhN5QHN9T9RJViRIWI^GThb;RXEmO7j0PG]hNGQoPGenNWQkMW=gOGicLgYkMFiT
F5UNGE]OIFUbO862P8J>TYNJWZNY[:nYYJRYZJVRX:>JTiB@RXJ:RH9oOWM`L7Qm
N6mYIVERI6Y^J59MM89jIVE[K6]/MgQ_KF]ZKH2>QGJ5VIB@V9fMX:FQUY69SIB;
RXVFX9N?Oh>3MW1`OH=cJGb5OGI/L7UhLG5cHF1XHfagNG1XJ7V5Mg1cLgEhP7Yb
MWM[HVE]KVMYKFMMIGf9P7A`MWIfPX^0KVUkQFilQF][L71dMgmoOWn?VYNDTY><
QhZ5N6iiQ85_IGEoM6USLGYiNWN3SHQnN82@RhF=QHN>QGn2RGiXK8>9RHN5TI^P
V92AQHFCV:6BTJZMS8Z<QGR1QG]cKg=hNGf5P79iUi^CVHR>XYfBRWYkX:6BRXfP
VJ6`Z[6WY:ZS/KBTT92ETHZ4T9>7RY2GThNDViRETi>>TY^JTi>EQGf3P7Y_JFMP
G69RGe=SM5iRJVU]KGJ5QX>2OWinQHemN8V>Vi^@WIV7P8JOTWZGVi>KR8BBSHV9
RHV5QhemPhV8UH5jNW9cMGQbJfa/LG9VM8=_J7^7R9NVU9J[[:BY/J2MZjNHWJFR
ZZJWY8IiOXBGYI1hN7j5NFmnPgEhQ8^?Q7edR8IUKHJ4MGJBUFU/R862SH1jSX1[
NgMhQ89dI5M`PgIYG6MGCUmFFfEZJU]@ADm?C5Q=CeeLGVQiL6EmU8>7YIn?RYRS
UhV5S8^3PGYdIEQBDf1LEV1@EEmEGeMMMgATFemgR8B6Lfb>W9n]UhFNZJb`XJ6J
Z];?_ZJHZj:L^;>RTHnRY9^OUhj1L6efNgekIVAOKXZ8N7=fLWYmNX:7SI2/^IZK
WjNoZYj^Y8b9X:NDSIRGP7IlLVEMCUm[FVAeE4AVKf4i<5IRFVA[I5=RPhMgHFQi
L7Z>R7f6S7elS8f@UXJ3QI2cYgUgOX6ETh5iJV^:Rg]dJUaGJfaEFV=QK7idNXam
I8b`T8R^]K6Y^LbaZL2l[JbIXJYfOIEcKX9jLWQgJfAYMGQfKgVEY8eiRIJ4P9F@
KgNNXIJGPgBPc:R:W9ZLXK>gXINLUIN8NZJEP71kUHfJIDYYRj9H@gJQVf=8JXe[
ATiQJ6QhTH9aLiff^IeiVJ^jgL2JYZBbg]>QMf63VXF9OeYJIFj8SEhiB6N4QFAG
J81oN8>NU6IUNGUeM7mPMjJBQhF3V[:jZ7Ae[:nXXYK5aInN[In9TGU`I5=dUHAT
@3E6HE<n>Rm<JfEMBf66LgJ@QFMGMXjPZG]cLfnCTgAG?SYJMF1QLF9IGFiUJW1M
F5U[Lh^QMTYaYXIlVY5eL8N;S8>2W:FLNVQdVIn?Ui2MU7F@]KJAJGNS`;6ER8RB
Qg^KYI1OAUa^L58oCEUOFUIYL6E`MhbRVIj9PZG<cKVVYJJee<:^TfI>MKB/TW9H
Ni2?UXmjKWFMZg=WKg:3Qj>UMEiNFW5`IVUDL9ZXTG=lU9J:R9>:NHFBVZ6:UK6H
TIJDXX9ROHn@TI2;QG9SQ8ATE55LFf5gMFU_NiR`YY6@UJ_2akVLXJR__JMkLfMG
EF5oGTi/DD1KNgEGIiN4LH>;W8]^Lj^cQFicQ7U/Oh^>VXZ5Y[NVVibMXJb]WXjD
X9BIW85dQHB2QgmaJFmYSIM`Jg1YGG63Jf5MGgQVB5M^NWAnRGf=YIB2Z/VOS[_A
d]JeV8eoL8NOUXAdM7n@U9IlOI1oTZZYR7B9QiVi_jB<RVi]QXR9O6Y[M9bUVh5[
SiR>S92ARWenQWb<Xi1VJX=bGE=CKhIlKV]A=f=nBdIRIfQRJ6e[GemcT8m^Lg1X
LV]_Pgi`JWJ<NE0o=CA4KhALASi;MFiAE5Y6?VEgJUmJEVR9UYJ>HDeiSga[N9FI
PGR=T9>XUhf[/9B<TJF/UXbQ`;n^WYbXWXn4QjNdXi6:PGAZOH5iMV=aMfA/PWEE
OIn>L6ZDZ9bDWjF:MY2]ZiR4MVe]U[BURgn:ViZSVhR8SiVESh><O7ZBSIRINg=/
IEiTLWm_FW6R/7=>KiF=PHf5L6IOIgQiNh27RXN9PGIaN8J8P8j>QgQ]LWA`HUMD
HGB0L5]XR96CXJbHU9bc`KZc]K:XZZ6?PWajPHF6N7V4PGmbJXFHRWYmT9UXCW2A
WjJTPH>3K69bUH5^QI5nNinaU7N@Z[6ZWInBRZFh/ifEV:_2^j6AW:Fj`[2PTH:1
S9FFPfQOG5e]IeUWG4eNGdi>GWF3O82FXjFNVY^<L6EoPVeOGG1^FE9QNg]]HFYo
S9B6LfYhT9>HWYZ:MVi^LgQgJ5eQOHekLGUaO9nYV8j;OH6CXHUTMHF7SXf8RHJ>
S82?PWn5NF]eRGaUIWA`Fe9KI7N8P7MkQWifS9>EY:j`[j>ORg]/F5UNKGmcFDE@
NI1_BeA^NHF9L5ULPj:WUh:5OW=kSiV4OXQeJVebLfM^N6m_P7MYL7Z3PHn9SZB/
ZijISIZ`Z:bRZ[2=NX^BT8]jKUmXNW1WJ75jLgV:N55AMHRBSX1nPI2GSX=hPXAo
Ph=bKWN0Rhn;R8=jP9JRWYVSWXN9ZkNRSiB?QiFHShB6T8^3Kfb2RW=dUYZ3LWb2
Pi2;N6n4UhelNGamQ8RBYIn;SINEPVYLGVioMUYPLGIZM9RBNGikNXfIZK:UX9bE
V9VDRFiGGEaLJ6QF?U=gOVYTLG5lPGEQFV=mVIfCOVY^LfQhQ6m[PHMlLg=iQ8bA
VZ2BOGJ7VY:0Q8Z@X9JAUIFPZ;6m/9nJWjBTX9nGTHEbMHfASH1cMV]hVIA`HWVJ
[j:QYYbPYZ2PYY^DT9:<MF9YMVeeOg=/KgUlM7B3QGR1Uj^`XYBBT9BBR8R@UiJ1
NXf?QHJDW9^MU8n:QIBLRFmMGVU/LgI`GEEGF6I/GdYKOWaiLfaZJFaZIFEOAd9W
MF9NHVelQ8F;Ti^ITijNTHb:OWUoOfU;DV9E?dQ@BEENCeALCeAVOh^>TXUlOH^:
QI:?PG^6V8inPXR:UZ>NTX9gO8VLWI^PUY:<P8ZGQXNLWi>=WInJTHfCUYbGPG=g
Pi1nKGR1RXIbKfmYMI6IVjFXXifOZ::@TJ>LSI:;N7J7ShIgIUE:Ef9UJ69GH82@
VH9^O8NDVibSXIB<QGmlN867RXb3Qh5[JW1]M8bDMemXOi6@Q7V4Wij7PHR5Q85i
MGQfLgQnOG=]KgAVG6]gLV9TQ9^FTi>EX:R`]KVaWhf<WZ:ESXF1PgF6VgmbLFER
JFYNGfEZOHZ6NG5eNgj8SW]TIGj;QWY`Qj>TUY6BSHB0S9VXZiZU^ZnJWK:m];W:
aK2R[[2LWYAmOGimN7YoKeE<I6iPGEA>EEMTQIbQVINNY:fWVY6<QXbFSWabMhFC
Sh=jJUMMKfIIFW2:SX=dMWedKgf:Ti28Rh9dKGB;Sh^;P8B8PX>6SXZ5Q8=jJWJ9
SH1_MXZDRgieM71eQXj<NV9BGg5]I6I^GE1HF5YIF69_OXEnP8RDZ[>TUiRPXY:8
Nh2FS7MaNhR3L6QXHEa[N79TGg1hOXN1QY>?Q8MnJfahNG=[Gf=cPhMnPhb0L82J
YJ2@SiJCTiFERX:I[::MWibPX:2FPgekPX=]K8:3OWadIE]SIE10B5meQHZ3QXf>
TYfLQXJ@UJ6QS7j2SiV8N7UlO7M_JFM`RY26SYF=OXBS/k:XViJ>R8R4P8:8SHR8
ThQdN8^@TJ2NRGmnMW1mSY6@TY2BVIB3OH66Ri6:LfE^RYZDRX=eJFUgOg9YJ71g
M7EcKWJ4Q8B8V:>JV9jLRWn<VINFSWMWJ6YYLGEXDTaPKfmYGUYPL7a_HV=RG5]/
PX=bIeeMLGY]Gea[M7F5SXV5PHnNThj@T9FKY:je/k2`ZIZ?Ri6IT8^AV9B4N7^;
TH]lIF5dQHR4P829VjFOThV?W:BZYY>8Sj:`ZinDQWUkPH>2O7b0U:bQQ75]LgjD
Y9Z;RIRVXj>STXbGV9:CU92>RXJ<T96<Mfe/LH62L6b3TXb1M6abQi>?Q7=PFVem
M6=FBTI<D4i5A4iMKWanMV]SKGZ:U9>>S9FPX961OHFAU966MFU]LGB0Q7AUIF9S
KfmUJ7=nMW1iLVATKG9iN6aRJ8:@S85iQINJV9B=OgjDZ:2<Og^3U9nNV9VS[K:]
Y95mPHjEUY^COWEkQh=kK5ULKGIjOg]lOh2<VIV?Ph2>W9fT[:6@Q8FBUH=`IUaN
IfEMHgf>RGikM7=lPHN;PG9bPXN5O6AKKH1jK6a`MGV6Vj>MRgYiOgmlNgIcPi:?
PgecLWf8Sh1bLF]ZPJ6RRGIfNWEdLf]UHfQgR9>8KFAdS9V=OHNKWj:^YHjI^;ZV
XI^4P96FQGR0R8b@R7YlQXMmNh5mMfeKEfIfO7agKf5MK7Y`HF=hSI2?ShJ0SZRj
^:ZOXJ>W_LJgZ9nNXZNRRWF2V9R9OW^2R8V7NFe_Lg5_Nh1_JWN1Rhf:RWmmQhJ1
Sj>RTXbLZjfQT8b:SIJDS8N4QY2@QgUXJGR4RgmVFFR3UiV1HeaaPhB5Og1]Mh^G
SX>5T9B>Q7b2S8fBUHZ3QXZ=Shn>RHf?PVi/MWQeLfeRHV=DBe=LIfi`IeQDI7jA
UH]lMHJFUX]iKWR8TIZEOW5gRIfLTi6:QHN=SH=iKValQ7=ODEARIVEKDEEKDDUC
GVUdNhJ@ShnDVI:7QhZ:QhF0NX>DUhj:T9ZOX9^4MX:BVIV;MWF0Q7MMDUYQJgQf
I5YPJgn;R8EmKf]eS:VYV8n4PH^=PGYiM7MnP7^1SiBFVinOVi^NX:BNU9BHUi65
PH9bHVYdMgE_JG:7WZFHRhZ>T92:P8B;RY:HTXn<PXNKXiR8SYZIViVFVYjKUYBD
RW9TJW=jNFYLEE5EJgUdLg5^MhB=U91oPI>ITX=aIVI_LVe^N8B9T8n0OHfFTYJA
P7IcLG9kOW5WJ5m;@Ci2A4ICH6MZIVQdOXRATY2=QHFGZjjYX9JO[Z^VXhehQIJJ
V9ZHShbATXb:S8V8Q7]bM7E_N8V<Pg]gOHRFThZBWjBVX92?U8j9QhN9RYBRXijN
X:BVX9VKWIjUYJB]];>_Y8YjPXb3M6IIG6abKfYXKGMmN79iPGaoRXj>R862QXN=
ShJ3NFaUIG9lMFUUHU]HEeaQJFe[JFASIVU/LGZ0NgAhNGQkNWUoPh9oNFiXJgJ1
PH1lNH>ATHN7RHF2QHb:PWj3QX>:ShIjM6m_MGQiNGf4QWmfLg=fOHZCSXV=RhN=
WJJSXZ:PXZJVVXV4TjJ^YI64P8>5O75cP8J7QhJ5RYFPWiF<Ph:8RXV7Q8N;RhAh
LfmYFdeCJ6eRHEmSMHN=RHJ4Q8>9Thn2Nh>>TI>=Nf]XMW]aKg9`N8=oMW1bMWUo
P7]eLgElPX>2P81kP8f8NW^9S8R:RH:3SY2;PGMaKW5hOG]cLGA^JgR7SXYlM7^1
SY^IS8F@WIR2KF9TL7b3OWYmQiNITiJDSI>IVI>9QXR>W9^9OX>1Lf]ZKWMlLfml
PGn0RI6EV9>:R8f=TYbKV9ZLVi68SXegJWN?VYB:PGb3Ti^?PGn2Qh^4NgYhNX6:
SHImMg9ePHN2Qhj>RhR3O7UeNhN<QG]iO8B;TYFCT8V6RhZ;VJ:SWiVFVYN;Ogf7
RXJ0MfmcPhQmLW1lTYF3MW5dPHbATHf<T9FGT7YZKgf2PXN1MWAeN7aiLVmXHVI^
LVUQI6egOWmmMV]WIfQfQhIjNh:4PX5oOhR@T8V4QhZBVY62P89oO8B9O6]_OX^B
RWQ^LWaoNG9_LWUoQ7meKg5eMWYnMVMRIVaaM7j9RHV8OgMfNWMdNX:4Q8AhJ6Yl
RH9eKgF5S89iMgZ2RI2CSXV8S96?RhJ1Ph^BRW5QIGJ2PG]aJG9mQ8V=SXf>T8n9
PhR9QY2QXINASXZ7Qhb@RXF2QHjASh^;SYNLUhf0LfY^Nh^@T9BGViZCSY2CTiFK
VHf9U::RV9>=OW9fQ8AfK6]gPX=mN7AZJgZ3PhR?THj2MG1/HU]JGVM^K6IRIWF7
S8=kN7UoQXIoOXVDUiB>NfERLGagKVITJW9hPhV3N75gPHJ4P8F:QHB9RhJ1QX^6
O7IiQ8j@S8F5RY2FVj6QVYBGVibLViJ9Qi2JX9F2O821RYRCQ8>@VIR<Ogf3R8ZE
VXYdJFikRYJJVZ:WY::W[jbX/;6ZY:N/ZZ:NWiB2NGanNgahM7Z1R8j;OgIcKFim
Rh^6OWA^K6UOEEMUMGEVEe5IJGR0NFURIfebMW9YKW^4RXMhIUYJI6iaKg=jMg5e
Mg9^L7EfLW1cMW9cPHn@RXN6PWn1Q8RDW9VEUHn3OX>=U968PGijOXfBQ7UkP8B8
RX=gLGnGW8n>THR4Rhf3OGn5S92<Og=cNh>5QhJ7SI6FXjbWX9nQXjRXX9VFTiFI
TXIkLgN1O71ZIV1PJ6i]JFQVJG1jPgibJfmiNG5]LGJ5SXA_Hf]nSI23M75gP8F2
PHN9Ph>AVXinMg=eNX67QX62RHf;QGmhM7EhNWYjNWf0OWQeMG5^KVm`MGb4RHn>
QHB4OH2AVY>:Pgj2RXIfJFQ`MgIaKFMUJgF1RXf>RXAlNh22OWn6SXUmMVmYLH6:
R8=jLWR8V9fKUiJGUYJHTXV8T9RFSh^6PhF6P7YiOH20O7EeNGj4Rhj>S8=lNh20
O8>:S92@RH1mQYJPVi2<R7efNh:3OgahNh>6QGaaKgEkPhnBRh>3SiJ@SI:AS92I
VYRIXjZTUXQkMWj;RXB:TI>EUIBCV9N@T9ZTYZ2DT9JDR8N>R7ilOWU`KW=bL75b
MWajLVe[K79bLgQnPGidKgInRIJITXJ1R96DShAlOH>9SHb9R8b;PgmoPh>2OW=^
MWmoPXN1O821M71kPh9kLg5gN7EgNWUjNgEZJ6U[Lgb2RI2@R7ijPhb=Rh^>TiB<
P7=XIVacMgMcLWIfLgJ0QX1nP7n0Q8R:RhV5P7QeMW9ZJW5cKVMWI6E_LfibNh21
Ogf3QX:3QhF3Q8AoNG]mNGn>T8f=QWYdNhJ:S8jDVifDQWj0QHZAUIJIVi^S[:j]
/:nSV9:DVYfJTHR0NGQmNVmTFe]QIFMXH5a]NG5]MGj3PXF8PgmmN7AbKVi/If9S
J6]`M79dOXN3OgmjMX27Q8:4PgQZHf=MG6I]JVEVK6iZKGb7QhF4OgeoQ8R8QXZC
TXf>RX:4TijJT8^>UYR?Q8:<UiZIVIZJU8b7R8nCThn6QHnIXj^/[K:a[:JKT8Z<
UIREThf6QHN5Q8R;SHj@UYREW:fd/:^WXIfPZZnXX9F<R8R;PW9_NHF;R8B4RHj@
ShfCWijIVIF>Q7eoQ8=oNW9YJfi`LVmXHfIYJV]ZJfUTHf=VK6]QG69WIfYdMg=j
QhZ0MGEoP7UeJ5eSL7QjOgmjMW1_LG1_M7V0S929Q8V?SH>3R81aJg1iOG]fLG9f
OhAmMWQlOXB;RhZ?VYfEShb=TIFJWIbFSXV6Ph5oNWYnQXf>SY:JWijMViVDTIJO
ZJfPSXfIVi20Lf]/LG=_JVESHUeHHW=iMW=`KFaXI5iOIfi_KfiZJGAnO7MbKV]X
JfeUGFMdOXF7QXJ7PWQbMX>>SXV7S96EWZNVWiZFTH^6RI:HSWmgNGUfMG5ZKWYm
N75ZHf9ZM7]kNh28T9RKUhj6PWikOGadKVihOWenQHZ:Qh5kN7j6Rhf@THV0PhAk
MWQfL6i`MWb0PXF7Q865RXfBUIJHUI:@S8R3NgQjPHV;R8bDU8n:QhJ9S8=hMG^5
RXAjMGQmOGQbKG9mOgf0QX^>Uj6SWIZKU8f?UIVHTXanK6YeOX>7R8J4P824Qh^>
RH5nOGj6TiR?PX21O7QhLg1cMgYlOX63Q8F7SiNOZ:n^Z:RXWYJEUiNFU96ATi>C
UIBAT96:OGMgMgb0Q85gMGQ`HUmTJV]^MGUkQI>HUIBETiBFTHMnP8^>Q7j1R8Mo
LVM]OHV8PX61O7QkQXj=RXN3O7UkOGYeM6iUHV9QJG9aMWn3Q8F5QHR8QH61Q8F6
Ri2@RX9kNG]mO7UfN7QfMg]oQ8B1OWUkQY6CTX^3OWb0P7MaMW]gL79jOWilNGId
NX22QHF7R7ieMWYmPGmjNWn4P7f3QhR:R81jOX>3PGYgNWn5PG=YKGMmO7MmRY>J
WinQYZZ][Jf^[Znb/jVOVibPW8aiKV]bMWMjNWQeL6]^MgioN7=dNGajM71^KFaX
IFM^K69PI6]aLg9bLF]VIFmoRHb?T8j7O7=aL6e[IfIWIfQ^M7IgMgIbJV5ULWf1
Ng9aM7EaJfaaMW]jNGb0QHV5Oh27Si>@RXV9RH^;RH^>R8>2P827TIRIVI^LWJ>Y
ZZRVXinKVYfMUHb;SXZ2P8RCV9^KVIbQYJRZZZJNWZ>VYJ2IUYB<P7IcN7]lOG]l
P85kMG^9TY26PhfHW9RATIB>QGekP89jMgalN7n:RhR6PWUcLG=jPH^=PW9YJVe]
JF9NI6]_LGJ0S8n;QGacL7AkO7E_LgYmNW9ZJ6a]K6e_LgZ1PGekQY:GThj@U9:6
O7j3QHB6QH5kNH29TIJFU9>BShZ;TI>=RHV<S8Z8QHB1O7]lP8N<R8B8TiNFUYBC
Ti6DWZV[XiRGVI23OH23Ph1nOWeoQHInNh21Ng=`M7MhNWahL6YTHF5SGeYLI6QY
K79kOgiiLg=fN7]nPGilNWYiMgEgNgQcLWAlPhV<RH5kO865R8b@SXJ2R8f7OW]m
OGEZIVQcPHEmNGn8RXN5P7n4QX5mOh61OX20OGYiNg]fLgR0QXJ0NWYnOWQhPHfB
SHN5PWYbLGV3RHJ2PhJ6RHjATiBBSHJ7SI6DViZ?OVmXJ6a_K6Y]LWEeLG5fOH:1
P7n3RhUnNGUkO7]iMWMfM75aM7b3QhZ;QGanQi2EV9bPXI^DTXf8QXR:R85oPHNB
W9^ES8F0OGj2QhZ9R8J1NgE`KfiZIVEZM7^0O7EdNXJ>T8n>Shf=T9^UYj:KTX^?
Ti6@Shf@UYRKWIRCUINBQh:3Q8J;S8N0NG=cM7IgMW^6SiBHVINIVYRDTiFJWYbF
SXZ5OgalOh1lLficOXB1OhF8QH1oQ8jFTHZ8Q7]hN7Z0PgieKW5gNhB@THQmN7n:
SX^8RXjASX=fKVeaMWQfM7IkPH:0OG]hLVm_L7MmOWj2R8b<R85jMWMhMWIjPX^:
PGj6SXj>TI>>QH22R96BRh=oP8:0O7n3Q8F;Shf6P7mnNGAbMGn7RXImMgMhNWj1
P7ahNX6?WZ:QWifHU9BEV9^MWZ:PV92:Qh^AShEhMWanOH:9SHV1NWQkOgmlO863
OWE`LG=aKFUUHV9WL79[IF5QIFQVIVY]KG1eNWQeMGEcL6i]KF]WIf]^KFmaL79h
O7YhNGMcM7E^I69VJfUUHfM/Kfi/JfmdMWQnQHJ2PXR?THb6Q861PhB4Q8>0P8NB
UiFEUiNFTiFHW9jPY:>LTH^:SI6CTHZ;TibW/[Re/ZjZYjNZ[:ZXZ:^XWI:9Q81i
LViaN7inNGIiO7]lNWMeMWQiOH:4Ph61OgQ^IfARI6]hPXB2Q8N=TiFCSHJ3P7]l
PXB0NgYkO7Q`JfedOHB3O7UmQ8N5P7ioOWikLfQRIVe_K6Y^M7MaKW9jPHF7RXj=
RhV:SI2BSh^7QXB3PX>6QXF8SI6FVYfOX9jHUIJEUYJEThn8Ph:6SYFBS8^BWZR[
Y9VAT9:CT8f>TI6CVIZAR8J8R85eLGMnNgUlPHJ8QhR:QWmkNGUhMG=cN7alMg=`
L6i/Kg=iO7YdL75fNGMdLW5dNGalMW5`M7MeL6mbMgb4RHN6Q8F6Q7iiN7^0QXZ7
P7n4R8R2N7EgMW9`Lg^4Rhj@ShZ4PHB:SXj=RhZ:R8^>Shf<RXR8R8R6OWUhMW9`
LG9fNGYnPH5lNX2:RX5kNgj0PHB3PhF:TIJDTi:=RXZ7OWAgOh:0NGAhOGahLg5a
LG5^KG=hN7MgN7f1PX1kN7MhMfmVI6YdNgelO7n4QhN8Q821PhB4RI6BShj@THZ1
OWakPHJ5PX>9T9:CTI2AU9RJUI2>RhN1OGQaL7=dLWAlQHN2OGalN7AfNgn4Rh^:
SY:BTI:BS8F2QHR8RXb?TiRLWIRDU9FBSXV0NWj7S8b9Ph63RY:EUIBETi2AUibO
X9jKVYNCT8f:QX5jMWIgM75`L79hOX:7Rhf9PWakNgMcLWAdM7MiMW5^KFYZKFi^
M86=THn=SY2@SHZ8QhN6QXB2PGehN7j6Rhb9QXJ2OWelNGMiOhB2NgEfMgEcM7Il
OGMbLG=fNGUjOH:5QhV9Rhj=QWihNH26QH5mOH>;SXb:SI:DT8R3PXB7Qh>0PHB5
Q85mO7agLWAmRI:FV9ZMX:6PXJ2MVYVJV96<SI:BSXb<SXf6O7QhN7EcNXF=SXb9
QH>3P7ahMGEeM71_LWIgMG=`L7=gNWMaKVe/Jf]]Kg5`K6]/Kg5_K6a^LWAbKFUX
J6MYKgAdM7EgN7IbJf9MGV=XKG5_IV9WKW9`LWIfM7AfO8:5Ph1oPXJ<T92>RHF3
PhJ:SHn<SI2EVIZIW9nJU9:CU9>@Si6EVYVFV9nTYjVYXiZHWZFXZJf^/;:`Z:2M
WIVBRhV:RHF4QhZ:RXN3PH20OWUfMGQnPGeeLG9dLVi^MGejM79bMGUmOWUfN7^1
Q8B2PH60NWAfOh=mM71_L7ImOgUdMgaoOW]jO7ioNgIdMGMgMGEhNWE/IVMZKW1b
M7UnOgn1Qhb;RhN0Ng^0QHF6RXf@T92@Si6BT8b;TIRMWY^ET96CT8V4QXV8PX6:
UI^NWYnNVibOX9nLViZHVIZHTX^4OgalP8:1Oh22Ph:1O7MhNginOGioPH>1OWek
MW5^K6mcMWIcLWIjO7j0OgilNGQhN7UjNGEaLGR0OWIaLGAhOH>7QH1kN7Z0PX21
PWmkMG9bLW1aM7UoPGikOH64R8V8QHJ8S96AT9:CTi6<QXB7SY2?SHjCV9VHUiNH
Ui>?SHV5P7QbM7QiMWEfNGQdLgR1RHf?SHZ9RXnCTXn<QXB4QH9nP81kMGR2RXUn
M6m^LgMfLVmbNGemNWUjNGE`KFe]Kg=eMWUkO7ajNWUgMWEfN7^0PWn0QHV7OGIg
NWmoOWf0QXZ?T8j;R89mNWUoRY6EUY6=SXf7OGUmPH1hLgJ0QhV9QH>4QXF5PWn1
PhF6RXjAT8b8QhR8QhN8RXR6QhV9RHN9RhZ4OWeoOgamPhV:Pgf0QhjAT8f?TiFD
Ti>FVIRDTiFGUI>@RH:1QX^;QGafLFmaMWYnOgn0OgikNgn2P7YeLg9cLW1]JVY]
KVmaLgEhO7YgMgj4QXN9RhZ7R8V5P7alOWn0Q8N;T9:?RXR:Si6BTHn<QGafM79`
KFe_LG1]KFmdMWAaKVmdNgalOhF8R8F4Ph:4Q81lNh6:T9BDTYFKX9nGSi2DTH^8
RXb<R8>0OWelNgf1QhbAUibQXj6MVifNWY^GUINKW9V@RHZ>TI2;RHV:Si:CTY>H
V925OGb0PWefLW=hNWE_JVYZJ6QYKWEnQ8N6PX:8RhIkLfeYIfU]M7QfLW9eN7Ul
OH64OgE/J6]_KfeZJFUUH5]ABTY?Ee]JFUQIGVAXJFQYJFY]KgAiOH20PXN:S8b9
QhZAUibPXIfIV9VKV96?Sh^6PX62QHZ<QWmkNGQlPXR<TibSZJfYXJ2PWibJVj2X
[[6^Z:>SXj2KUi69Ph>6RXZ:Rhf9QH>3PWiiLfeZJVYZJV]^L75bLFi]Lgb0NW9`
Lg^3QH>0PH62Q8N9QhF3OgYhNgn1PX>2Ng9`LG1]K6]XIfY]KFaZJfe]L7EeLFma
MGMfMWZ0PGn0QH^<RhR:TifMUXn<S8jATXn<S8nEUi6:RHf@RX1jO826Rh^8QHF6
R8Z=TYJHVZ6XZjZWYjR/];Ri^;Re[:6ITHj=S8f;RHF3Q8B3PWmkMW5_L7AiO7aj
N7YjLfaXJ6]]KVm_Kg1hPH>0OWn2Ph>2PX61PH1oOgmmMVeYK71dN7YmPH9kM7=f
NGUgMWIfMgUkOWmlNGUmP7mlO827S92FVINCUIVHTi2>SY6EUI:>RhZ8QH>4QHF4
R8j?SH^<S8^:R8N4PWmkNWUiNGUiO827S8f>TYRLViNCTY>EUIBCTXj5NgA_JVQ^
MgQbJfQXJFY]K6YVHfIZK6a/Jfa^L6m^KFe^KVicNGj0Q8N8QX9mNWYlNgYiNGUf
LW5dMgI`KFmdNh64Qhb@THb4O7^0QXJ3PH62Q8F3OWYkOh:1OGb0QHN5QHF5PGmm
NWIdMg]oQ8J5Ph61P7n0P820P8:6QhZATi6@Shj<SHj9Q8F8S8j>RhV=UIbLVIFE
UiRHUI:CUYNBRHB2PH1oOWelOhF8Q7]gNWf0PH60OG]lOX23PX1nOGimO7j1PWmk
Ngj0P7imO7f0PGikNWb1QHJ4O7IcLWAfM71^LgUmOh63R8Z=S8N4R8f=RHN:SI6B
ShZ3O7YjO7]gM7AeM79bLgIhN7EdMWUmP8:6R8R6Q8:0PHN?U9B@SHf@UIZKViZH
UYFCS8J2P7n2Ph:0P8:4QXN7Ri2DUiNEU9NKVYRFU92=S8R6R8V<T96?S8fCTi2@
U9ZNWYVBSi:FV9>=RHF4QHB0NgMhNWM`Jf]_LgMhMgIiOGmnNgMbL71bM7EdLVi^
LGIiNG]oPGiiMg^0PWifLgAeM6iYIVAQHF=VHf1UJ6=NGV1UJVe[J6U_MWQdLW5a
LWAiNg^0R8fAU9FEUiRIVYVGU9:BTY6=R8>1OGYjNWUhNgj4Ri>HVYbNWj2SYZFP
WjB[[:NQW9RHVI^NViJEUiRFUIJHUYJCSHR8RHZ8Q8:3Ph>4PW]dKfe]Kg1`Kg1c
Lg9cMGIgMW=`L79`L79iPXAoNgYjOH:6QXB3P7]kOh>1NWEdLVaTGe]JFUiUJV]Y
JFa^KFa_M7UoPGikO7n3Q8F5Ph:3Q8J8S96DU9>CTi>CTI2@TY>BTHj;Rhb;Q7ag
MgYlNgUgMgb3R8Z=T9:BTiJHV9ZOYJVZZJNUX9^IViZGTHnATY6>RhZ:Qh5kN7Mi
NGIeMGEbKfmaLVmZIfQ]MG]mNgIdM7IhNWemOX:4PWefMGQhMgA`K6a_LWAgNh22
PXB6QGmiMWQjNWQdLW5`LWEgMgEdM79bMgb1QXfATI6BTi:DVJ2SXZ6PWinQXZ2K
UiFBShf>T9>FUiF?RHJ7R8EnMWAiP8>3OW]kOX:7SI:CTI>FVYfOXJ:TXijJUY27
Ogf1Q7mkNWf1QHJ3OGMdL6e]LGAeMgUgLFQRGeaLGUmQIF]aM7IhMgUlP8>5Q89o
Oh>5PWekO7eiLF]ZKGEjNgf0Q8F4QhZ9QGmlO7aoQX^9PWamOh60O7QhNgn0Oh24
QXJ7RXR3P7n3QHJ5QHF8S8f<RHN6QhR:RhZ9RXb;RHN5PhB6Q7ijN7UkO7emOgmn
OhF@W::RX9nNW9^MWIfLViZDRWmhNGioOW]kOGmoOW]hMWIfMWMgM79cMWQhM6m^
L7=cLFm_LgZ0P7ejNGUkOX:3PGmoP7ahNGeoOWahMgYlNWYmPXF1NgQhNW]nOgej
NGf3PGQ_K71eNWf0P7emOWioOWaiMW=`KVeaNH:7RX^9QH:2Q8N:S92CUIRLWIfL
VIF?R8:0PHB6R8V7QH9lMWEhMg=eOXVBUYJIW9jQXZ:OVINIWj:QViVLWIVCSXf>
Si6BTi:BTI2@Shj;R8N7QXN9Rhb=Shj;RXV5P7akO7elO7anPXR;R8J5Q8>2Ogal
O7aoPH5oOWn1P7afLFmaLFi/K6Y/LWMgL6IQGUiQIFU/KW1`LWIjNgYhMgMeMGQj
OX:7R8=nNgUgMgUlOGj0PXF6PGn2QXR6Q8F6QXF6R8R4P7ejN7IeN7n8TYZNWinP
X:2SYjVYZZb^[:^[ZjZXY9nIUiRETY6@Shb8QHB2PhB1NWIgNgiiLVm_LGAdLg9b
LgIjNGMeMGIdKVYZKg9dMg]mOWYcKVaYJ6Y_M7UlOh>6QXF3P7ejN7MdM7=bLFi/
JVMVJVi^JFQZKg5`L7AgNWj3QHB3Q8F3OgekNgakNWQhO7n3QXR6PX61P7n1QHR9
RHN4QHR9R8R:Rhb>TYNJWIjNViNGVYZKWjFXZJRVY::MV9BBU9BCTHf<T9BCSHAo
NgQeLFm`LgMjO7YiNg]gLW1aM7EhO827RXfBShZ7QH>2PhF8RX^9Q81lMViYJF]_
LG5cMGEdM7EeMWIcM7IgMgEfMW9aLVm/KF]YJW5gNW]kOGmoOgmoP8F;S8Z9RX^=
TYBAShn?SHb<S8^=TXj9QX:8SHf<RhjDU9FBS8f=RXf@TI:DVYbIVI^JUiBCShb<
S8b;QH61Og]gMGIcLWEhNgj0OganPX5jMGQiMGEfMW=dN7E_K6QWJg1dM7AgOGem
Oh:5QhN5PH68RhJ4OWEaKVabLFecMg^0Oh21Oh1nO822Q8N7R8V6Qh^<RhZ5PH:6
SIBETi:>SHb5OWamOh60QHf>TI>@U9NHUi>CUiJBUiZEShJ6RXAmOX:8SHb7PGYh
O7YfMGQmPXbJWYNBUYRHUi6@SHJ5Q866RX^8QH=kMGEeMGMfMGIkOWinNgf1OGAc
MgEYLHAlKG=_IfUTH69UIFefKVU/JfEUJfa[KgMjO7ejNh64PWioNWj6QH>3Qhf@
S8R6RHR2O7YlP89mNX68RhV3Q8R7QhF4Q7edM7=cL6eaN7UjPhEjMWj8QGajOX63
T9JEV9B?TI2<RhV1OX:4QXfCTY:9Q8N:RXV<U9B>UifKWYZLZ:b`/J>MWZ:YY9fI
UI>7Q8f9Rhn?UIJBSh9lP7ejP8>4NgV8UiJ@V9RGU9::PX>2NX26OhN?S8^:Qh9m
O7]oRhR5QhJ;SXb4OGUhPH9nPGmgMg=^K6UYKW1bLg1`IV1VHe]NHEUNIFUaL6QW
KFYYKVYNGF=QG65[JVU^L6e]Kfm`LWEmPGIbMWYmOH24PGn9T9:<PhB:Ph25OgIo
S9:?TIVHThnAVY^IX:>U/;Vk/j:MXI^HT8B8Si6BRhJ>ShF:RhR<U92:R8N8Rh=e
LVi^JVQbNWZ2PgYoQ89cJ71`K6ATL7AiNVmRGf1SIfeeLgj<TiNHUI>JTX9mOhN4
PH>7QX>3OgYlPH63PGZ2S8nARhEmLW^3P7ioR9JHTiNNVYF@ShV1Ph>6QhJ9TI>C
SXjAP7V4RXZ8R8Z9QXV9PXREUHj>V9bGUjFUVINHV9RGTHf9R8R:RhV:U9RCTYFJ
ViVHU8B2RG]dM7A_IfE^JVEYGe=EFEIIHF=RHVEYI69VHemNG65_L6e^KWAcK79f
LW=nPGMfMgMjQ8UkJfefN7YiM75[KWMnN6aXJg9kOgn5SI>AQGYeL6QVI5aOH6al
MGf=UiNIUY6DWJ^/Y:2JTi:AS7ilP8B3OWakMg^8R862PGb1PWegNGenPXNAV9VR
Z;Bk[:JWWZ6Z/JZNV9RGTYFJW9jHWJJSViFJWYfERhF2Q8:1OGf2MVmjRi>HU8f9
P7MfM6YTJgEiO865QHbDUiRARHVBWj6DQhR3O8=oLV]XKWUmO7mmNg]hKFedKVUX
Ifa`LgIcM7UmOGMhO7YmR8b6QXB4SYB?RHJ8RY>JU8nEUHn@U9ZERhZ9PWMaJ61R
JgIcL7=gNGehJEiPIVQaNGMnR8R9T9JFUYRFSIJTW9>DUiJ@TYfQY:j]X9F:QH>3
P7Q_JVMQHVA_Mg1THV5TJFQWIVIQAT8m>D=AG5EEEEQRHF1TI6ASIV=HGFa_LWQk
MW9dPXZ<TY^WYI^WYHj5S8IoNgf:Wl7</jJQX:FUYJ2IU8f7Q8RASH>8TXj4Ph:?
XJ^_];nmX8f?THbEZJBFW[BfThjhaJZ/]89GRmCW/UiGXLVL@A4mWOCom/F=E3aV
ZMKUhnCRgMBo^Zb@OGegFDJ:WDU4N5/Q6dU:3P005Ti@?61`CcT_8P0002LS720V
9d]GB459DTaFLHR4S:nTPH>;UYb?P:K>g=VcZknj/[WFgmgel>OilKNBX:B`^:5_
Qk>JNgN4SX^1LWQoKG20R85IBgZ@NF1GEUASPXZ0JeURHdPj?TE@HFESMHB<RHB3
R8bM`LZbYJ6RUX]jNhj?UYbETiNN[:F6OhjKWHQ_Iee;ATmTIeiC=bhg@3/m@dY5
AU5:?cPh<bdY<dDi9BPhCeE9@d0i<S`g=40j@D]=Cf9gLFaXJ7Z2PG5`OGigNGn2
U9nXZI^O/KflZIbR]L2n^[Fd^L72_[Fob/_?elfnb=7He][Lf>CWi^cTfn3/j>_i
m^KWoooooooooooomoGoo^oRgoKhkoGooooooO7akNOQg=[Fe>3[hmKHfLfiZJNT
UhR8ThafJ5Y<AeEQE4E;EDE9E3`S6aXI3PXA72/f>c<T9RdW:30/81hN7B4Z;bLR
4a0L7RDa:QL?5B</9aD<2@003Q/@0`043@hD7aD;518000000000000010005AhH
5bPa:1/I9CHk<Ri4G5Y>EfeiNWAbNG]fLgQjS[6k^;Ng`k^UZK_=dmCRj=oBclO3
c<36kOookn;Zjn[OdMGGd]3Rk^79[J6ddMK0Z:Ba^l2l[JB/_[6OYZnlb/K:e=_Q
f=7?blJld>gZf<o9^K6ZY:6CQiVZXjBVZ:VNRhb?MeEOOH9bFd<[<4=;A45;D5E7
:2Pd>C`l>S0W;T5GJGAdKWIlMWJ2Q7E/L7j@Xj2EVYN=XZfZ/Jnne<jj]ZnNVY^I
TXbATIVQVYjZ/K2LQX25R8R0M79eL75kQhn:RhelLWZ:W9b8M6m_NWmlP8^LY:6T
YJ6Z[Zj[[;:f[ZJjb[fNUJN/XjV^YJJa^;>QSXjJYIj?TIbUYiZ?U9B4MGEkKg65
OfYLHW1nS7iSIg1VGE]MIfIFC59LDTUAGVb2Pg]jOhbCUijJPfmYIFQZKWI[JG=i
O7AaNGMfIEI?@Ce3CE0m9QdP:R/c@d]1=c0I0@00100000D41Qh_AEmLB4=6?45?
BC<Q:Sa:Ce1MKH>8LVITJ7MoQGUXL7inJF1UKFe/KVEBA5=YHU9HHFIKB45;E5mW
HV=^MGZ2U91eO9>2HV:3UHj<VK>h]KZn_;jj^;c7cM_L]J>]]KRj^/OCg>CVl>WE
cM;Bdm78bl[4a/Nj[[?3a<3HiM?5blVo`m?Jbl38d]gUh<fm^lG<blg;_:VJU9VG
Y<C?aLcNinCNk?_Zc;bXUX1iQY:X_lJn^;S2_JbNSGa[GV]jJeeMF4a2>3Q>Fem^
LEm5=cm5@TDj91`[A5IJCdUCDU=KD40d<3Q9EUI:>CYJKVINJWMgMgAVFEaIB51Q
IF=FG6AQFU=JFE5:ATa>D5ePDdE?H61AADeLGf5OFUULHfEGDUmPFDmDJh>FU8jE
XJb`[:FW[kFi]KRl]ZRY`<o6`lcBclFo]JffaLZgZZnc_<G4`/:dXjg2al2`ZjFY
`]3:`/K:a[2OY;2m^KB]ThB?YKVm_KR`ZZ^b][W7i^oE/8j2PHJATiBGThZD/lJo
ZIJ5M6MWN81iJfIQGVAUJfYQIWYbEDE0@DaFDchH110bGWn1MFIOGeiMEU=DEF9L
ATABG6YlPge_J6I]PhYoM6]PET];DEINGUM;AEAQFe5>BSPX7Q@E7bHZ:2LO5R<m
?C4e=S]5?c0X9RXc=CY;FUYLJ6Y`MgUjMFi[KgAdM7YbJg:3SiF?NgJ:VI:3MFa^
L75gNgYmP7QhV[J^Vh=_LganPX1fLg>7Z[^aWJ2[[[6URXZEUY26UJBQX::S/lK9
bMKal/JSY9^2P9^bZIfS[k[<i_3T`if=T9JGTiFCOW:1S8N5Tj^e[J2OWHQoS8M`
I65KFfUmRiVXZ:6KVJVk^ZJCPG9`OYRZ/ZjX[k:nc]7=aL>k/ZRPX:RZYJZZZ:b_
[JJHRXB4NfUJF6EXGEUVLFaMCeEPHUmJG5iKHfAJEUARMGUkOgYiQi:>QHN;Rhf9
SiNCSIBRXiVAThn7Ri>DUY:7Ogj3QHB0OXFHYj>JTXF0O7IhMg5dLgF1Si>BTYRR
XIB;RHf2OH9mQ9BSYZ2TY9nY]L7Ii<fVR7YaKWnAWIN7TZV_[jZMV8ekNH>0MG9e
M7b7NFQSJH:GTXj;QGaWH6IPEDY1B5][O92TZZ2BSi>4L6M/MgeiMgf7U:>VY:2A
RYFSYZBEQi:IThj8R8J5RXQmMGR1PWATHF1OGeE8ADiFF5IFEDa:BD=4A494@D=A
F55CEEIRLGMhN8B8NVYPI75lPhV;Qh>7Thn8Si>FT8^?V9ZBS8J:TYVKSXJ7QXR:
PWUmSYR?PGI`PiJEShnHW9ZMYk6PRhb:PHFJZ:JET9bQXjk5fm[5[8b1QW]hNg9]
M7I^KWb=TIF@M61IFfASH5mCA3`m@dUIL81eECe0EEiD@cPh=S]3@4IRNgadMGQk
NW1TGE]FEeQCFFI_NhB8Q8B>UI25Ph^<PG1]KVMPIFidNWYjPXB0P7aaIeaACUAL
G5IKJ6i`JFM`KV]YI6QYI6M/JfmkP7aiQI:EU8b6QY2NWi25S9VIThZ=UYba_;R_
Z9b@UIZCS8J4RY6HVi><Qh>8ShV4PG]kP8J8QGmhNHB;PGEaMW]nRhn=TY2=S9F^
_/_Ad<B^XY1nP8bCT8Z4PHbS][RXU8=hMg]eL71[IfIXIFQYK7Z5THelMG=`LGA`
H5=@E5e[PYBMYkBdZ:J^]KZe[ZFITij_^lG=em_JfmkJb<;=c/cAd/fl/[:`]L:n
/k:b[kBm^[6XVibQW9JBS8V?TI2GUHR8RWmfM7IkOgejNH23P8:0Ng^0Ph1mN79]
JVa]JFETJg5_IVMgN6QMFf9RFeQCC59XLfiUHEiFDEAHCTM:DEaJD5EKFUaRGU1=
D51CD4iCFfa`IF]gO8BDW9bGRH1lPHIkK6IUHV1/OHZDUYF?QGacLGEhLfeZHF9b
OXfGRX27QgmhKFehOgimOgj2RXjGYZfZ[[bo^KVi/ZJLWjRa/kG4d]cKdM?LfM3@
e<k4a/Bn_kR`[Zb/[[>f/k>[ZJj/YYF7PGUeNG]cJfiiPX9hLGMiKfa_LVi[LgEg
OgioRHb4PHF;RHAnNW]kNGQgLFi_Jf]fNgIcKF]]JEmMHVEYIUY=CeUJEU=?D5IL
Ed]2@dYAE55<CTi:Ce5;A4UBDe=DGVabLgjDXZ2FR7U/HfIVGeI<CEEHGVQ_MG9U
FEIBCeEFDU9BC4UDIfe[L7QoQX9fLVm`LG9]G59GJ7fAWjBTYJF[_<>h/JnSU8b>
UYVM[L;9alS4_[Zl`<6n]ZVMVIZR/K:TV9BEVInOW9ZGV9:5PH:1PHB3NgMkNWEe
MWAaLWEkOG=^L75`K6]`MGUnQ8N8Qh1mNgMoQGebLWj5PGQlPH24Ri2?R81bKG9b
L75dLFa[Kg5^KgEdL6aSFe]KE59MJG1bLWEfMW]mMgMlNWj=Ui^Q/L;4^ZZLTXJ2
OgUdKVQXLGj6S8b4N6aRF59ACD=3BdU=FUmNGEeSJfaXHemKH6AYJfIQHFimQY>L
V9ROZ[:c[JFLU9BFUYROXZBVZKBn_K6VXZ:NWZFVTW]iPHB1NWIbL7EkO8B8RHb;
QH62PX>3P7]kOH:9SI2EV9B=S92ATHn<SI6FUYBIYk>d[jZYZZ^[ZZRPVj:UXZN[
ZZV[[:VVYjjf]kBa[j^QWYnQXIfIW9bBRXb=RhR4OX6<ShV2PhF2NW=cMgI_K79o
RX^>VZRlbKjYU7e^L7UeJFE/NGn1RiFES7a_IeE6A40i=C8Z:ci@E5IPJFQQEDe=
C4A1ADU?CDE:F6]lQY6CSi^/[ZbXX:2UXIVKYJfb][_1a;o1`[bk/jZWYInEQh23
R8R3OGQgN7j5QH1mNWA_KFmfOX1gL7ElQiBKW9FAUIJET8N3PH>8QH>:RX^CVinJ
TXb:R8F6RHQnNGYfMG]lMG1`Kfa]LWAbJ6AZKV]ZKG1cLW9gNWYdKW9cJ65TKW=^
KW9aLFm[JVQWIVMYKg9jRYVT[JNISge`IUaNGU]FEEmdS9ZKUHIfLVEHEDXo@D=2
@DMEHFaeNgYhMG1bLFMNGUeJF5QKHW24TYjSXjN//;Rk^;B^YInPY:V]^LK=d]CD
e]?=bl:e/[2UUi6CTi26O7QiP8=lN7f0OWQiOgegL6]XIf]]Lgf0PXN<Shn@TY28
PhJ<S8^>Ti^SY:BUXj>RX:6NThb9RHZ4O7]lO820O7MbMGMeLW1cMWA]J65OIFU]
Kfm/JFY]Kg1bM75bMFm/LgMiNgf0PXB2OhJ>UijX/kZiY9F>OGEaIeUBEUYNJ7Z;
T96;O6]E@S/h<RTQ7Ah]?DMCH6QXJ6ERIVQVIEeFF5QEEE]WLGR1Q8F=U9VSZjfW
W96?TYVQXj>UZk2`[jn][JjYXj2PXJ2HRh5kO7moP7mjO7ilNgUcKVm`LG1/JFUZ
JFebMWf2PXB:Si:CT8Z5PGn2RHZ8Ri>IWYfGUYZNX9jJV9JBSXnCU96<S92=QXN6
PGinOX63PGmlN7MfNh>1OGf0PH23OgMdMg]lOXB8QhR9SYFKWj2LVIfW]m;/k^CM
d[b/YIf:OWadK7>5TYfTWY27O6]VH5=7?cPd>3m4BU5HGUiLGF1OGE]JEe=DFEaN
IVmiPhN7RHjEW:2QX9jIThb:S8b9QXF3R9>JVYVHUiNGTHR0N6iRFEMDCDE4@T54
BTiCFf1RIfMRGemOGE]LHFIYKGAmPHJ=U9JCSHV8QhF7SYBHVY^V/[Fd]KB_Yj:O
WY^HUiRJWInRYZRVXj>TYZNYZJFRWYVGU96DVIZHUiJFUiBASXfBTi>DTY2EVj6Q
VYjQWJ2X/[W3e=K=c<B^VY><OGQfLgN0U::UYj>KThAcIE<o;bLV:R`a>T==FF1R
I6=TIV=OFUAABdQ;CE=JGfMcOHF=UJ:`^Kjo^[>/[;2b/JfXYJFZ/kbo_kZc[:NQ
W9J;OWEYI6MZIVEYJfQWJfe[KG5`JfQWJ6Y^Kg1bMGb3QXVAUIROXinFT8f<RX^@
TY6?Si2DV9ZJVIRFUiNDShZ3O7MdLW1`L6aYIfIWIVAUI5mKF5MJFe]IEeYQIFEU
IVISH69XIFEYIf=XLG9]JfiaLg^9Tinga/Fn]ZNFSHIiJ5aGEEi_OXN@V9RGSh5h
LFEGCTM2@TA9DeeRIV]aM7AfNX21P7ahMGAeM7EiOhF=TIFO[K_8d=?Cd<_5`;nm
]ZjZZJV[];o8c<c<c/W1^K:WVhj0LfURG5MHG61TJ6ifO7ajMW9]J6EQGEYKGfE]
LGMlQ8jEUI6@TI:?RhV9Qh>5Ri2EW9nQYJJVXifDS8IoMg5[IfMYIf=VKG5cM79/
IF9QGeeIEeIJGEYHG6AWJW5eMgIdLg=dNWekMg9gNWn7RiNOYk:l_kRfZiB5O7=T
F5YJEf9`MWb0P7ihK6=MD40`;2`U92Xa>499DE]TK79gN7QiMW9`LWEdMGMiOhN@
U9NNY[:m`lO5_kZg][B^YZ>SXZ>UYZZa]kVj^[Nd/:ZOThZ1NW9ZI69TJ6Y/KW9f
N7UiNWUhMW5`M7AcMWQkOX:8Si>FUYJHVINETXj<RXN6QhZAUi^QYJJWZJZXYInH
TX^2NgMeMWIfMWIeLg5bM7AfMG5^KW1aLgA^JFESIVadMWMkOh65RXb;SHf<TYFG
XJjmcMcPf=[C_k6[Xhj1PWM/Lgj2R9:ARh^1MG5WF4]6?c8a=C<e?T95Be9HHFY^
LGYmN7=bMGYmOGemP8N=T9FO[[Jj_Kbi];2[Xi^DSXZ4PXB8S96FW:2NViVESXIn
LV5DC4M3@D51@DA9D5MLHFAUIfY/JfUVIf]]K6iaMGUoQ8J8SYBGV9FBTYBBShj?
TYFIWZBVYjNUYJNXYjBOVI>@T9>EUYNIVIJEUiZKVYRHUiJBTI:ASX^;RXb=S8nC
TY6CV9VJVifKV9VHV9VPZkO7clg=cLFgZj2BQ7egKfabN7n8RHZ:Q7YdL6MJBS``
:2HU9BT^=3ToADiJI6U^K6IUIVQVIVU/Kg5cNH27T9ZU[kFk_kjk^[Vi]kFa[JRT
XZ2QY:R/[Zj^[ZbUW9:8OWA^JF9KEE=FFf5YKW5eNgeoPXB5QXB1PhN:S92CTi>F
VI^NWIZJViZDT8b7Q8>2OgakO7n2PhB4QHF2OGQcKVQUI61LEe5<BTaAF5UFF5aO
HF9SHf1LEe9DE5=DEEQLHFIYK6i]KW1cMGEkNgf9Uj6UXj>PU8Z5NVaOEeI@CEUR
J7=gMWE_JFITHEE:@SH`=3Tl@d]@DeURJg=jPHJ7PWj0PhN;T96BU9FIX:R`^/77
blk@d<c7`l31_KJ_ZZ^^/KBg^KVn_kfm^;:[XIJ;OWA^J6ATIfU]L7AgNGeoOh>6
QHB3PX>7R8R:RHR;SiBHVifNXJFSXZBVXinKVY^LWYnNWIjOViJBTI2>S8N0NgMf
MGAaKVYXIV=SHfEVI6AVIfQVI6EWJ6UWIFIYL7IkP7n1Q8>2PX>6QHB5RI2IYjj]
[:VOTHb6MVAOFdm:CU=HIFYZKViVHV1GAc`c:20P8R@[=Ce2AdiFH6]`MGQjOGmm
NWb0Ph>5Qh^?UIfU[K:g]kFc/[6_/;2_Zj:JU92>Rh^?UI^PYJJVYjBNUi::PGYf
LVm`LGAjOgn1QXV;SiBHWInOX:6QXj>QWYfOX9jOXZFXZZ^/[:ZYZJJRXJ2QYJNW
YJ>TXj:RX9fLUi>ATI6ASHN3PH60O7YkNgYlOWejN7MeLg=bLW=eN7b0PX>3QHN8
Rh^=TI:DUYVQ[l3=clg;_k>^Xi>1M6QKEEaOH6Y`L7=bK6MRGU97@SHZ924P8bHZ
;C<i@deGHF]cNgmnOX67RHR9R8R9R8N;Ti^S[Jn][:bYYjJPVYB>Q7YdLFiZJFYX
JFe`LG1]JVMPFEA>Ad=3ATQ9CE=GFeiQIFigOH64Qhb@T96BTI2@SXf=SXnATYBD
UYNIVYZGU9>DUYRJV9NIVIZKWI^HVINDU9BEUiRJW9ZFTi2;QXF7R8R8QXF2P85m
O7ekO7inOH63PH:7QhB7RXN6RHf<T9j[^LC3_kjcZ:BPTgmcKEmGFUIDFf9TIfIS
HV=NDdTm;bDS8B4T9bP[;S0e?dYFI6]_M7YkNh24QXV<S8b=SY:KXJR`]KNf^lO9
a<:n]ZfWXYVCUI>?SXn>SY:ETXf<Qh5mLVYWIVAVJ6ESJ7=jOhB<TYNLXjjb[k2g
]k>d];:^[[Ji/Z^Z[:bYYZFUXijJUY2>UIJ@SH^8P7egLg=]Jfm_K6e]Jf]_MWE_
JVMXJFaZIf]UG69SG5YMGUiNGf5PIVUWJ6]`L75aK6m`JfmfO8VJXYjQYYN<Qga_
IV=KCD]>B4QFGEeTHEaSJ6IMEU5<AT0n?Ci2@dE;CE=MHfilOh>:SYRSYZJ[/:n[
Z:^^/KRm`lW=c]GQinSYi]gHe<g:a/Bo]J^TXIbKX9jKWZ:JT8f9Pg]dL6e^K6MY
Kg1aMWEiPhN;T9>FWZ2OXJ>UYJ:UYjNUViBJViBBTi2@THb;Si:CShV9R8J4Q8>3
OgMdMWIaJFU]Kg5_KV]XJVe^K7=kNW5]LViVI6AWKgIhMgUnOW]jMG1cMG9fOX9o
OXR=TYbVZjncZIJAT8EbIEU@AdA4A4Y?EEUHFF1RH5iLFTm1?T51?Cdl@4A2ATa?
FVQ/JFmlRI>EVInOWIbHTYRRXYjOYJBQXZBW[k2ZYjFSYZ:IVIN=QhR8R8N9RHEn
NGA]KViZIFEYK6eXJW9dMGAmR8^4PH^IWY^JW:6SXjBRWIjPViBDW9nNViVHUYB?
R8ZDUi>BShZ8RHAoPXF3OGn2NGIiNh1kM7AlPX>1NWelO7QcMgMfM75gO81oOH66
RXf:RYBES8b?TiBEUYVNY[:h`<_<al6fZZFQS7abJEaECTA=I6EPHVIVIVULEEU@
A40o?3e0@DA3?Si9EfI[K7J1SYRLW9nUZZ^[Zj^UViRPYjFSYZZ/ZZBOXJFSUY:D
Shb8P7QeMFeQFU]NGeaFDE9CCda<CE1CEEIGGUmMH6]aKW1kQHF3RHR7SY>DUYjQ
WI>FViV>Q8>=T8V7RHV<ShR5RXZ9R8F8SHV:RHB3QHJ6R8R9QXB1R8b8R8Z<Shj>
TI6?T8QmOXV@T9JFV9bHV9VGUiVIV9RGWInKWZ2R[lGAd]?BakNb[iJ9RGm^H5aQ
IV=QHVARHVQ^KVm_GdmAEDm:ADI9BdQ5BU1GFEUMK868SYNLXZ>QYJJW[k:`/[Vm
_;Rg^;>b^[fi][6c/JjYXIbLWY^DSHJ2O7amMW5^If1UJFM[JfU[L79fQ8^8QXJ<
UI^PY:V]][fbYjba[JNTYJVYY9jNY:BJTXb9Rh^8QhN5OWIfMf]RJ6MRI6MXIVAQ
F4iBGEmQHUaDDE9EEUeTGUIJHfEPGVAVIFY_KVi_L6eZJVabKVM/M7YiOH^FUY>F
WIF7Q7i_IF5A?3Lh>CTl@4=:D4i?EUI?Ce=DDU5?BTY8?cDg@4UCF61TIF]dOXRD
W9ZMZK>f]K6[[:n_[k>`/;Jf[jnd];Fe];k5_KJc/:ZTWiVGU927Q8IoLf]XHUiV
KVa/KFUXKFeZJFYcOh:7TIROWiRDUIbNXj^_[JZ[Z:FXZJRVY:>NUYNLVIBBU9BD
UYF?QX24R89jMWMmOGQcLFi/JFITIfiaM7UkNWakNgj0Ogf1QHJ6RI6ASXf?ShZ=
TiJDSi2>RHbLZk:j`L:hZjJVVhImMfmVGEUBBDI0?TE<DUMKFU]NGV9TGUMHF4i4
@3lo@TM@FfIdO86:UYjNX:6PXZFW[KFa[:bWWiNEVIfNWIjLV9bKTYBIUI>IVYJD
T8V2MW=cJUmHE55AEUUHF5aRI6AZLgEgOHB8RHnHX:JRVIJCSXj>SiBGVYjTZ:ZW
X9ZGVIZFVInPWZ2SXYfFUYF>SI6@SY2>QGejNgf2RY2;PWn1Q8B4PWn1Oh:7QXB9
RXJ4QXfIWi^AS8nFViZIW9fPXZ>SY[:l`lc<dM_?_l2eXiJ=PWE/JVQSGUMACTTo
>d1=FF1OFf1VHUI=BdM2ADaAEeiRI6Y_LW=fPHbBU9bTYJJXZZZYYJ6MU9BJW9F>
S8^5PH1mNgUbLWQnOgagLFaVH5Y>@D55@Ce3D5QCCDa7@TI<CUEPKWZ5T9>=QH60
PXB<TI27PH>:Shf:RXV7QhZ<UIREU96@UIVFShjATi>=R8b@Shb7OgaiNGf1OW]o
RI>EUYRFThj7R92IVY:9Ri2?T92:QXJ8SX^6SIB<PGanQ8ZGZKFm`/2oaKj[X9V?
QX>1MVQNDDM7AT0j=S4gAeMKGF1LFeYEDU1:?cXk>STl@deCE5IGFfAaOX>6TIbL
XJb[Z:BOX9jNZ:^YYIjHTHb:QX:4SifZ[ZRPX9nJTHR2PGmeKfm`KFUVHU]KGEUI
GfelPhRBW:Jd^;:^/KBc/Zn/[Jj[ZZRUYZFNUiFLXjJSX::WZ:FSWYRHViF9QHV;
R81cIUeNIVadNgQeM7EnQXB3PWahNGb0PGehL6eiP7]hNWj1OgYnOWUgM6e[LWUk
O869TY^MWJ2HRhJ0NW=aKV=MFU17B4Hn>C<Z;Ca9CU9FDe=JF5ADDe9JI65KFUiW
KVYTIg1nSYBIXJN[ZZV_]KZm/jZe`/G4_kN]ZZb^ZjNUYZZ_/[>c/:n/YJ6RWYRD
SHR7QH60O7MbKfaTHVQ[KG9kQY2EVI^KVi^LX:R/ZZ6JVIVJUiNIUi:CVIVHVIFC
UifTY:6RX9^KWI^ESX^:Qh5kLFUWJFUUHFE/LWb8RXEnNGalNgalO7n1PXB3PH23
Ph24Rhn=QX60PXR7SY^Y][Zg]kV_X9bHT8InN6i[JEQ:A4=4?SDa=3a6D5IFDEEM
GEYLG5QCC4U:Be1JGEYMHfQ_MWj5RiJJVIbQZJn]YIfIVIZHUI>@Rh5iMGA`L7N3
SI>FTXf=SHf>Shj;PWYjNWAYHUYEEeQFEUUNHVAVIfafPHfDTHb;RhV8QHB2Ogin
OWaoPh9lNGf1Q8R<SI6IX:2JUiNEUIbQX9VCTi24NGIgNh62Ng9cO8B5R8f?RhV=
SHR1NW=bN7ioOh62P865Rhj>SiFHVZ2Y[[Bj_kbi^;Fb[JVUWibAQh5kMG9/H5mV
J6AMG5eJEeMLHV=PG5aLFUA=D5UOH5eHEEMOJ79kPhZAUi^NX9nSZJj]Z:JUXZBX
XiZARhN4Ph:3PX21PGn0PhF3Q8B3PX9oMf]TI6MRFEIIFeYKF5IFEeULHfigO8>9
RHAoPXV=T8n;RHV:SHZ9RXJ1PX>7QX>0PH:6S96ASY6EV9ZJVYZKWZ2LUY6@S8^9
Q820Q8R;T9>DTi6?SHnBTHj:T9fRWiRDT8R1R96DUYJIWj>UZ:^b^KN`ZJJRX9bD
SXMoOWajMViYIV9UIfUZJFMUIfYZIF9THV1NGf5LE5=CD4]9BDiDFfE^MGn6R8Z=
TIFDVJF][JZVXYjHUYNFU92=SY:DU9:FXZba];:^[:VWZ:BKUI>ASHMoNGA`K6UY
IfIYKg=gNGV1R8^?UYbMVIBDU9B@SY:FV9VIV9NETiBHWZ6PWIjSZJVRVY><R8R8
RXj>SHj:PGUcLWIgM6mYJ6QXJg5gMW5_LgAbL6eZIF5WKFe[Jfi_K6QWJW1hOhN9
RHEmNgQ`I5mSHeeFEUUHDde=D5=@BdaDGFMXIVETI6=TIfESHfEVIF5KEE9DFeeH
EUaPHfeeOH>8Si:ASXZ8QXJ;T96AT8f>TYBEUIJGUiZQYZJTYJb_Zj^][k2_[[2b
/:^UWIZGTXf>THn:R8Z5P823QXJ3PXF5Q85jLg5gOX:2P7inPXN:Rhf<Rhf@U9>=
Rh^9QhN6QhJ6QhJ5RHj>S8jBU92;QGmlNWQdKg1dMgYnOgYbKFmbLW1_Lg^0Q8R;
RXF0O7j3R8b@U9>>SHj>SI2DThf8R8N6Q8=mMgEeLg1`LG1^LWIeM7AfN7IcLW9`
KfmdO8:2OgenOGYgMWQjO7f1QXV=Shf>T92<R8R=U9VIU8f8QXN6PX20PH1mNWMi
Ngn4RXjATY6ATI:@SXj>T96CThf5PhB3Ph60PX>3Q8B4PgmoPhB2NgMjNGEcLWAh
NWUhNGYjNgYiMgQjNWYoQHN:RXN4OganPhJ:SI:EUI66O7^2RHb:Q7ahN7b0Ogak
O7YkOh:4Q8B2PX>3Q8V;RXV;T8n;RY2HWI^OY:BRWIVJWInRXj6OViRFTY:CTi>E
V9VMX:2KTXf:QhF4Q8J:S8b:QXB5RHb>RhF0OGn2QHF1OX67S8b5OWenOGalOH25
Qh=oOGelNWIfMWEdM7=`Kfe/KF]XI6AWJFUXJ6U[KVi]K6eaM7IfLFaZJVmbLWAh
N7McKVYXJW5iOX1nO7enOWilN7EeMgUgLg5aLW=aKF]YJg1eNgemOH6;UIRFTXn=
RHB2PhB4P7enPXN:QX:1PhJ5Ph>4Q8R?TXn9QXB5QHF8SI6ASHR1O7j4R8^8QHB4
QHV:R8F3PhB6QhN5QHJ5P7anPh9nNgUfM7=cMGQgM75]JVQVIfERGemTJVmbM7=a
K6YZIfM[L7ElQ8Z;QX>4R8Z7Q89oOWmlMgEjPXV:R8B2PhR;R8F2PXJ;T92=Rhf>
SXn@TI>FVIbMWIbET92CTi>IX9nJVj6VZZ^[Zj^ZZ:FRWinRXZ2QXj>TYJ>NUY2<
R8N7RHjDVZ6PVI6;RXb=Shj7OgYhNgikMW=dN7QgN7UkOGekN7QiN7EcMWQeLgEg
NGUhMgIbKV]ZIfASHF9WJfQVIF1NHFM[K6a^LWMkO7UcKVa/JfY]LgQkNWA[J6ab
Lg=bLFm^L7AgMW=aLgIeMGIdLg9aMGUjO7n2QHR8R8N9S8b<SHn@Shb<TYBATI:C
U9BEUIJGV9VJV9NHVIZNXIjJUYJGV9bOW9^IV9F@RXZ<SYBKWifKW:6TY9nHV9^M
WI^JWIjKThf9QX9mNgaoP822QHJ7RXn@ShZ6QHJ4PGmnP860OWYiMgAeN7anOGj1
QXZ:QhJ3OWYiNGn8T9>>QWmkNWb0PhJ5PH64RHb6P7]iN7YlOGamOh:3Ph:2PGij
MG5`M7QhMWEgNWYfLW9`Kfi/JfY]M7QiN7IhNWUhN7YoQXb@Shf<RhN5QXV:RHR8
Q7iiMgUlOh:1O7IeMgQeLgAfMgMgMgUlNgMdMWUiMgQiOH20P7ilNGUkOGmoO7Yj
NGMhOH:3Q8B4Ph1oOGj1Q8F2PH:5QH9oNgIbKF]]L7N0Q8B3PH1oP8>4Q8=oNWYl
OG]gM7=aLWAgNGQgMgIfN7anOgekMgQnQ8F5Qh^=S8V7QhR;Shj;SYJIUHn>SHZ9
RXf@TIBFVZ2UYZ2FSX^;S8b>TI>ASHV4P822Q85jMgYnOW]iNGUiNWYhMgQjNWf2
QhR7RHjAShf>Shb9RHb?T96@S8R4PX1mOG]iN7MhNGQhN7YjMg9_LWQmNgQgMG5a
M7EfNGUdKfi^Kg9hPHN7Q8>3Q8F6QhN6QhZ;S8j?T92=R89nOWilMg=dNGenOX27
SHj;R8N;SXj;RXV;SXj;RXR5P825RX^=T96ATYBDShN2P7elP8N:RXV6OgUkOh5o
NgYlPXF4Ph:1PGmlNg]mOWimP8>5R8b?SXb9QhR:Rhb<RhV7QX=kLfm]K6YXJ6IV
J6YZJ6QZJVEQHVI/LgUmOWemO7]lPX^ATXj;RX^@U9VLVYNCTiBDUIJETY2AU9FC
Sh^;S8Z7QXN<TI:@TIBETHf;RhjAU9BATYVNWYfLWJ2RXjN[[:VXZjnb]KNe/k2^
[:VRVYFBT8n@T92>RhV6QHV=SXb7QhV:R8J4PX1mN7=dNGejMG=cLW=fN7QfM7Ee
M7EgMWAbLWAcL6]WI6=RHVAUIFETGUIADeIGEeIIH6M/KW1`KFUTHVAZL7AfMWMg
MWIhNGUfLFm`LG=cKfmaLW5`KVUTHfMZJf][L7QkNGUlP81mO7n3Qhf@ShnCUiRD
TI2BU9BCShb<SY:DUI>@Shn?Si6DThn<RXR8R8N6QX=nMg=dNGenNgQiNgakNGUl
Oh:4QHV>Shf;S8^8QHJ7Q8:2PX5mO7]hN7YkNWYmOgmoOgmmNgUhN7MdLFe[Jf]Z
JVmdNG]jNWYjNGMeN7aoOWYhN7Z1QHR9QXB3PhJ9QhB2OgioP862PGmoPH:0Oh63
QHF3PhN;RhR6R8nDUI>BU9NIUI2>Si6EVIVGUI6?SX^7QXR8R8bEVibKVIFASXj?
T8n=S8f?TI6?Shj<SHn@Shf:RXf@THn<RXR7QXB4Q8N;SY6@RhR8QX9mNWYlOgik
OGmoOW]eL6]WIfY]KF]]LG=cMGMjOX>7QXB1OGYgMGMjPHF2OGalO7amOh1mOH6:
Shj:QXJ5PGmlNgelMWEfNG]lP8=oOGimOh:1Ogn1Ph>4QhZ<SHV7SY>8SIbDUY6=
TiFCU9JGVYjNWInWZJBKTi:BU9FFWZ6OVIJJW9ZDTX^7Rhf9Qh^AU8b;R8>0NGQh
NGaiNGmnOhB3OWmmO7anPH60O864PG]fMGAcLGEhMG=bLW9dKVU]KF]`MGEgNgYm
O7]nO7]iNGUgLW9jNgIdMG9^L7AaK6QUJFQYL7=dM7=_KgEhMG9fOGigM7AiNg]o
P7YiPHB1PXf>QhV<SiBIVi^FTXnBUHf6QH>3QXV9R8b=S8j;R8j=Q8B3OWelNgn7
S8R3NgZ0PGijO821PWijMVm/KWV1Ogn4RhZ7QhR:QhZ;QhJ8QGmmP862Ph21Ph22
RHjAQgihLGQjM7=gNg^0QHJ0LVYbMGV2P7QdLFi[JgElN7b5PGeoQH9mO7I]Kg]o
Ng9YJ75mP7YlPG]kPX5lNgQcNH>:TIB>QHZIWifIThb>T9:DSHN>UYJHWjBUZ:ZV
XZF^ZYbJVHn>U9jQViN>RY2;Ri:=QX>3PH65QH5mQ8UjNH1gL6e_LVeZJ6UZKgAd
M79^K6U^LVaVI6QaMWYmPX9oNgIfP8EkL6]eOWaiOhb9O8:9PWYnPh9nO866RhZ8
QH5nP8N6P81nPXJ0QX1nQhIoPX]mNGU_OGiaJFAeMVQZM6i/LWE`KWAjOgmgLgn5
OGMoRH5jP8:4OgQlRHf3PHJ5QHJ8RXV?Ti6>V9ZLV9ZLWjFX[KBaVhfASHf>PWmk
N7j8Shf6Ri22LWZ1QhQoOgUdPH=jKVIaMWEcOX9oO7MfKfYfO7AeOhAjLWZ3OWnA
THN5OGf6QIVPSY6IVYFAVjBLUY>AQY6JVi^HXjbSX9nT]:ZKZ:fSX:VXV9^NR82=
SHN5U9F3PhVBV9JFV8n8T8b=UHj>RXVJUHB2W:JBV9Z>RI2EY9ElPXnBUINESh:@
Vi>ITHN>RHN6OWUnPG5[I69VIg^6QH61P71PEeMCFV=<@EATIVf5PW1SHfQPFUAJ
Jf5=DeMEDdeCCTA7A45@Ede:A4]@?cQ5B3lf?5=BE5IBG71XFUiECUaSHfQgOg=g
N8bOUY>HUYNMWj2OXjFOZk6PUIj][jRUXIFGWY26TI^FS8J:V:>UVi>LYJj_Y9fM
Y[>_Y9ZNZ:JYWHN=TXV=TI:>OX6;TZ2YXiZIVj2MWIb@TX]`IW=fMgUoT9fIVYVD
W[o=Xh:5OGb3Mg1ZHVaeRZ6QXjVUWY5lGCm?KVA9?TeJG5QDFU@l:A/O?d@V82LZ
>3h]7bU3E5aZJ516FFUdLfYgKFMbMHNLWYj=TZb`Z9R>SY2JYZVZ];[9d/6VY;>]
Z:^_WY6GY[:ZZ9N7WjfV[:ZVZZ:TX::b][G5_IZSZ:FX/kJ/_<>IR8b6VYEVEVAo
Y:EmM7U[MI:KRg=XOY2:Ogj2OXfN/LcCa:9oMgM[I5mVP8nL/;>e_[NPR6i?>d9H
JVEIEEMaPgi/HfYG@CTe>3/mCEE6>2/^=cU@GeYDCEIZK5MVQ7]EEGb8T927Si1o
MFAAGFYdNGV:U8BB^KRXU8BCUXbEVI>BTi:FXkO7ajnU[Zb[Yi^KX::W[jfOYL74
^L2^U8fBTib@Mg^4SYRFRHJ?S8VASGY`If9XH61VG7:MWXEoW:NRZ/7G/7i/LGj2
TY^Z^kbj/jnTUGEWGE=ABf9VJGj7RH^6MgmiHEaM@2DiC5IYGd90>3@l?D4`=5UE
?3a9Hg9^Lh5iGfIlNG1[IV]VGF1ZOi:OWI6<V;6_UHInMgF0OG^8PXJPZiN?YJJ?
RjBST8Z:Tj^jZ[2eWi:7PgETLGmnLVU/KHFER81^MYNGRY69LfZ1Tgn0Si::Ng^1
QXN5Sj^k^mOU_IR0OXU_HhR/_Kfc_]GF_9B>Tf]9GGZ3SinIRHAfETYDFU=3?CU4
E5Q>D6Q]LFiIBeiWEeIJHF1NJgUeI6I^Lg=iP7=PEVIeLGf>TZ2e[INU[Yf1N9FX
[:NKX:VSXY^GXYR?Z:bEVjn/ZKbm[Jbh[YRR];NVUYjCTj^XVIFP[JfUX9:2O7mn
O6]ZO89kHF5mTIBJRgf:V8aZMIZU^Lo<Z7EHCe]IBe1QO822T8UmPgeO@S0hDFQk
Mg1[HEIDDTeKEcL^>ChmA5IGBdI8B4U?C3ll?3/_9CE8De5CIFYNFeMKDdA=FVih
KF]ZIfe_HeAJI5iSLH:;PXFEZZZPYYZ:TIjY_l2/Z/3?_Z6IU92OWZ2UWJ2TZJRP
Ykfg[[O;eL:cZ9ZX^[BSVZNf[J2U/k>cX8R:W[:d[kK3dN7DbNooom^jZ8EiQJC1
`LG<e>kom>G>Vg=PGVYbQJ2_/:RUYhUYK7UkKf1FEV=iUZJBLGEiJeU4<BXc>DI6
>dI<HGEVG5YGAcY9DE=MGFIlP7n5MEiSIEaMJgEaM825Uj2<N82=S8V<Ti25U[6c
XH^;V:JPQGf2OhJDVIRESWi^IWElJTi1EGIoH4eNO8R1PWiWGfEYLgf2Nh68PGN1
V9>AY;RmT5Pd:cmEKHVBOgfK]KZWRGYX@c93F6mhMh27N69UEd9;DUMA@D1;HXJ>
Ph9XE6E^K6=DBTmHFUEFMY6@VYUjIEaEGF9HEUUUNHNKWhYoNWAfN821OhNJ[;^n
/Z2MXIB;P7YkN7V1WZbEN82PXi^BPhJFXj:QWiB4MhJT/JZBNWB6XJBCSi6=UIBB
TY2>Pi2QWYbLV9BKZj^R[;fl_LGJo?6lVY:>QhjS]K[5cKj/W9>?NVQTGEEcZ/kE
^i^>TXQeK6=[Q8Z4M7AjNGj0Mf=IFE=7AE=ME4]:E76BXIJ3LV5MHeY?D5IRNiFA
Q8AkHe1BG65ZMG5hUZ:VZiZ<Ui5eJf]`P92GS7^4SiRQXiZ@QH1oPH5eKF]cPXMl
KVMSG5]WM6EAEFA[Jfa]IU]NJei7@4=6BeECEV9LGWF9T9NRX7eUJUeML8BL[;2Y
XZ:ER89iHDi?DFF7ZK^`VXJ9QV17E6ETGEmdQI>R[:jAJUaDDVN8UXijKWZ7Ti^P
VGQRGeiUKWb8S9N`/Z^XVYJJUY24PhnQ/lK<cm:o[jj]Y8imPYfea/Nn`;fi^K^k
Z9bY`M?7/j^[];VcZIV@T8b:S9BMUHjBUYRIYIMoRi^ES92CUYR?Rhj1L7^CYJRX
YIZTb=_6VW=RJGZ9X[S4^jFTZZ6BR81hMg=hR9FKXZJTTVY<AT]:Be9<C5IFFfY^
GTm?CUAGB3e2CUUPGEUBDe]JG5i@?cQ9H6ERJF]WL7MeKF9AC5UIEVIhOGZ1RXV2
MVU[LW9aLGAjQY2>OWMdI5YSMGQ/J7bBUI26OgilOW]hPX>5THj:TXU`I7F7PG=S
D5M^MgQhLW5gOh5eMGaoQIBX_<K2YGYcN6afQH6;WJN]]kRXTXQnKfmdOYk2dljh
Whn8NVYSG5iaNH2BW9bOXIEnJf]ZGEYULX1eHFj0PhbET7eVGFE_MGn2OhNFYJN@
O7=WFe1:Df9`PhJ3QH>9TXj6OWYoPh2BWYRGVInDS9>@QW]gPYRVZJRYZIf;SYVH
TXYmNXBBV9VKS8F@P6MYM7f7S8V1LgF0Q7eZGEQMKWM`JW6B^KfLOfePIG5mSYbP
YJne/:2@QGM/Jf][OYRPSgihKf9JDU1PIe9<IWf9QGmiHdQ2ATUGHUU<@T1CI5iG
G65UHUa@A59^Mgb0OH28Si64JEYIFFInTYfLWj:PWYVAPgQbJW2?Xj^e/:>PVY2=
S8nEXJJIV:N]/K>XWj>JQWelMW9jOGElQGagP9BNTHR>SXZ=TYBGUXn?TY2EW925
VJfhc>CQ^IVARI6Y]Ko6bLBj`]3Aa:nISI2HY[W:bknf[JFLU96:PW]gNhb@Q8F>
S7a[IV=TLWYmRXb2QHb?WJJJQW]kNGMhOXB7PGj6RXfFWIB9PGEhOHJP][Nc]:^L
UIB?RXfBV9ZHYjjRViN?RHN0Nh>BVibT[K2ZW8]oMFYUKGMiOhJ5Q89nO821Mf=L
Hf=SI61MHFEXIU]BDEQNGf=UJGJ?X8mVCTe7@D96DeiJE5aTH5eGBCD/;318Kh=n
L6=QFde7C5IQG4HlAE=WNWe^H5E>BdaDHG1bIeiPIVIYM7AYFeEBDE]VJ6U]L7N1
QH9iKF9LFEeXLGAcNhF7QXB2OX1nOXN6RYjZXj:VZJBCRHZ=TYBCU9F@SHV0O8:5
OWIbMX>;SYNKU8^:THj5Rhb4QXR;TXn8QWalQHB9SHb=T9NRZl;Ic:VCQW]dKgZF
Zjn[Z[BfZIF9PGUhNHJLYjf]YZFWWXahLgf0Phb?U9fUYij;Oh61PX=nNGMeL6YO
GFQ^JfYUGf9THf9ZMWf0P7YeM7R2QWIYJfagPXbJXJ6HTI2@T92AU9RGVj>PV9NI
V926Ngf<TXn;PWb3Ri6;MF=SIfIVHf5XLW9VF59IKGAWHfYaNX5nO8J=RHF1NWYo
Q8f@RXN<WJ^ON61UKGE`JgbBUINZ/:>@PG]bJFQ_P9JUZjbUWIB5MfiWJG1iPhjL
[kZcYijCSHZ3Ph60S9ZNW9^JVYZASYJHVYbIU8V5T:2WXINEThj<Si2EXJVYZ:ji
`KZYUXVCYZNHSi:JWIB4P8bESgmdMWf8T9JIT8R;S8V7R8Z4OG]bL7V3Si65OWn4
SI6;QHVFVY:;S9:GSHJ3OWMeP8^<Ph:?XJnWQg=ZIfe]K6Q_MgR0Q7U[H5Q>BTmF
I7f@U8j6Qhf3LVMRIfi`LWN3Si>7KEI>Cdi@E5IOJVeYIVQ_LFAFEfA_K61IGFYd
LFMPH6eiLF5KHgN5OgQlR9FNX9bDRHJ<THb;TiNNXIZARHjLXYZ=QhR;SYBJViN@
QGUfOHJ2O7eoOGMcO8b<O75^JfmhN71[IV1KDTe>DeUIEeIHGVI]MGMmRhYcG5=B
FVIZLgn5QhN5QXV4O7I[IfmfPiJW[JFKTH=cJg1jOgUdNX>:U9fIPfi_LfaSHfQ`
MG5^KVeYI5]DDeMMJWb0OhB:Shj>RhR<Si6DU9JLXJ:MUiFKYJJRWifLWifJX:VY
Z:V[[:VX[:ZRXZJRW:2UYJFOU8n=QH2;UiVESHR7Q822R8^;R8AoM7F7Sh=cJFYa
NWj0RI>=OW=aNXZDUH]dI6=VJFY^O8V:RY:GS89kL6IMFF5`NgUaJf=LFE58AdQ9
BT]DGf5QH5aGEEIFDe5?DEURJ6a`Lg9/JFY_KgF7SY2IXJBTXZFXVXf<TYbOVIZV
/[Vi[Z2O[Kbk[jVVXj6ITI2EV9JBRhR7RI6KXjZ/[K6b/[>h^[Jc/J^[]Kbj/jn`
[jJLU92EVifDRX^>S8V4Q8Z>TY2;TJ6YXi>7RYJNT7IVJWR7Qh:@WjFYXYN@Qh62
OFiVKX6HYZFKR7M`KVYXK75bLgAdOXbAQg9NG6adKfmeNWUeMGQjOXN4MW5eMWb<
UiF8P862P7U_J6ASJVm]L7=cKfY`P8=lL65NIFYbNgilMG9eMGEiP8N;RHN5QXnL
WiB9RXnASXV8SHj:QhJ>UHf3NWEcL6e]J6EWI5mICdY=DeA:@dM=DUaQIG1hO7UZ
FUiVIV]^MH>3Ogn2QXAmMW5[IF=]Qi><PGQcLV]NEeMKHVQ_NhJ8PgigKf=FDUEO
JFa]MhB<QgAXJFmgNGV1SYBDUIVITY:@RH:3SijWY9jHVYnOVHb0Q8^9PX6:V9nN
V9RPXYVATiRGVYfKUIFKWifGU9BCTXj4NWfAYJNAO7UkP8N5OGQcK65MJ75_JfIV
IV9KFEmYKg9mQ8J6RYRVY8mgMH>8Qh=oRiZRYZ2GUiJ=QhB8TiB@Shf7O6eWJ6EQ
GEM@D5EPLGemLVAJFFEbMFUQJGN3R8N5PGf0P7YdKgR9ShjAT8^@UY>9P821PhnP
ZJj[XIN=QhN6PWmmPi2DTI6AUInSVi>=RhjIY:FWZZ^Z[J^TX9bIVj:Y[Z^RX:Vc
/jRIRX>:U9F>Ph69SXZ0Mg9eOGimO7IkR8b8QHZ?T92>PgMhMFa]KgZ<Sh=mOh67
QWecKF]`OHjEQW9/KgAcJF1MGf]hNWj8SHb6NG9dM7N0Qh=gLGZ7SiFGTHEkNWUg
NXF>T8n>TY>;Ng9bMgb0OWf2RY:LW969QHN<TIBEUYfZ/jbOW9fHUZBb[:6QZ[:i
^K2YXijRXY:;TYFIXj^ZY:2SYjFJR7akOXJ:RX^=Qg]`JVmdL6]/KW=jOGf3RY2B
SWmTDUEVMH>6NgIlQ8J0KfIZJUiBDe]TKWEiMF]JCDeCEeMFF5aPHEaCCDU2?d56
Ad4k>T5AGEiHDDe@DU9ADE9@EV9XK6i[IFAQGUaKFEi[OHV>T9:FViZHThf=TijT
VY:FWj>TXIbIUY^X];J^Zjj]ZJJRWYZFSHJ5Ri:AQhB9Shj5Oh:8SXn<RXR7SYRH
T8V:SH^4OhB:RXbCUIJFU9F@Q7MaKfY^PIFNXIj@RH^3MFMLEei/LgR0Pg]^IFE[
L6eTHVMZL7b3PgmkN71VHF9ZMGakMWAkPhN4OWQbKVmeNX67Qh5kNWf1OW=/KgEh
OH64SijNUXn9R92FTHj;RHb?T92>SHn?S8Z7R8^;RY6KX9^?Q7ajOGmkNgn1OWb0
Ri:@S8Z7Q8:2Q8V:R8N9R8R:SI:DTXZ0NGj8RhV;TYRJTgmYH6I[JVQUIFUZJVa/
I5eJFEMEE5iaPH=kL6Y[JVa^KVm_LGAhP8^@SHZ2N71/KWIgM7R0R8Z9R8N8RHR3
PH21PXN?VIjKThV2PXN<T9FLXJ6SYjfd]kRi/ZRW[[Rn`<31a<S6_K>eaLc1^K^o
`;fh]kRg]kNe[JBOWZ>]]K6YYJRUW9JCUIJBRXB5SI2;QhV>T8^1O826Q7inQHjB
TY27N6]YKG5aKFY^KVebMWEhNWM`JVYcN75YJgAdJVMXJ6MRG5YLJWf8QWeaJVU`
NgaaHUYGDTiBFf5TIV=MGEmPGe]IGVEVIVU_M75/JF=NGVUjQH>1P7n2Q81kM71f
P8R>T96GVi^KVI>?SI2CThj=Si6ASXb>UIRET8f<RXV=Ti>BTHf;SHb6PX1oPHB8
SYBCSHZ=S8F4QXF9U9^JUIBDRGQcOXN4Lf=UM7]kN7EhP8=nM6UTIVaaL6]TG5]N
GEaGD5=FE51DGVU^JV=NGemJE4i?EEI@CDmAEf=/JVM[KVm[Jfm`Kg1dMWAcNHB8
PG]iLg5oSY2?Shb:RXb?TI:>RHJ4R8n>RH^EWYjERHF<UI^KVi^PXjFUXj6PY:NS
Wj6RXJJ^];6VVYB@RXJ@W9nLUY>FVinISH^@UY^KVZ6[ZIj?S96DT8ImP8F8RXjA
T92<PGb2RHR5PGejMgYoOGE_LG1WH69WK75eM6aVJG9cK6IRGEMDF5mXL75YHEeS
KG5ZHEmNHfMWIVAVJ6ETH5eRJVaYJFIRGV1ZMGYhLVi_LWAdL6]_LgEgOhZ=SIFO
XYfGUi^LW9jPYZVYYJ2PY:NSXJBYZj^YZZfb^;JYWiZETY2?Si:HWInHTY:ATiVT
[:FGU9fRX9J=RhnEWZ>SXZ6SXYbFTHf:QhB3R8nCTHb;T9B?QG]dLgEkOWefJfYc
OH21Og]hLVa[KgZ2QH=mNgaiMgb3Q821QhbAUI:<R8R?U8UoPHVBUiRHUHn=TING
T8N1OWf0QhV;RhZ;S9FOXIZDTiNJUI:FVYVBRH>2QHN8SiJGU8n;SiNHShAlN7Ul
NWIbKV]]Lg9cN7amOWioPHB5PWUaLgf5Q7imO7UbJVU_MgUiM6m`MWYjLf]UHfEX
He]GEeaPG5A=BdU;DUYPHF1OGEYHEe]PHVAWIEiNI6ikPh5fKFU[L79`L7IjNgj1
OgajMG1_MX:=SXZ5PhJ8R8J6RHN0OGj0P8>>VIbDR8F?VYbITi6EVIbKW9nQXj:M
UiBBTINQZJ^YYjFTWiN?SXnBVJ2SX9fIUIBDUYZIThn?TI>@Si2ATHb4OWanP861
NG5[Jg=iOX9nM71`KVaXHUUDFFE/JfQYLGUoPhJ1NGMjO7UeLgEhNGYhMgE`LGAc
MGUlP8:1OW]gLg1aL6eXHf1QJ79bJF1IF5]PJ6mbKfUTHV9SIVQ[Kg5^JVadP8J3
OWM`L7ImP81mNgf2R8V5PWilOX65R8N5QHV>UIRDSHfAU927PhVCWInKUHn:RH^=
T92@TYRMW9bMVY>AU9B?RXV?UIZLVINIW9^ESHN4PXF:SHb7QHR>T8nAU9NHUi:>
T9JIVINEUHn4NGR3TIRESXV7QhN7QhF6Qh=kM75/IF9YLgI_J6aiPH1oP7mlNgeo
P822PhF6Q7mjN7YnPH>4QXbATHn?SHZ:Si>BSHJ4Q8F:SXb4NWIjPXF6QhV<T9>G
VibJUi>CUIJFV9nY[jjZYZ2LWjJZZ:BSY:BRW9B>SHnBTi>DUYbSXi^EUYRFTiFG
T8J2Q8ZCVIRET8^9RXjBTY>DTXj>T9:?S8^9Pg]dL79mSIFDSXR4OGA]IV=ZLgQj
MVaVI6MZJfUXIfMWJFQVJ6e^JfUWHEMDEe]OHVASGU]LG5]MHFEXI5eDCU9JGfAW
I5eIGVQ`LgZ0PGf0QHN1NGAgP8F6PgijN7YmOX6;UINAS8b=RH>6SXn;QH>4Q8J7
Q85nOWenOh25QhJ4PX:1OGYkOX>6RX^9RHb>RXJ5Q8B6R8N2OX68SHf;QXB4PWmj
MGAjQ8nETXf=RhF3Q8B0NWMlPXV<RH9jM7EhN7UlP8F5Ph:2P7QbLG9aKfi_L79j
PXN<S8R1O7UhMWMjOWmlNgYmPH1nNGEgO8>8RX^>THn=RXMoMG1cNGj1QhR1NWEb
MGj6QhJ1NG=_LW5VJg1eMW=dNG]oP8F8QHR;RXZ2OX64RHZ8QX20QXV;RhV:RHV5
PH64R8N8R8R7PWUcKgAhMGEhNGEZJW5hPHR9QWikO7YlOX>=Shf8RHfBSXnCT8V:
TiVCSHR4Q8F2NgMeLg5eNGb3R8Z4P8B8R8N3QHN6Qh^BUiVJV9FCUYZIVYbSZZ^/
/:fZXibFTIJMX9nMXJV^[JVUVi6:QhR;T9:@SXn>SY:DTXj8PhF:S8fAUIRGU92D
VYJ<Q7mnPh^@THV1PH62QHR9R89kNGj5PWegLG9aL7AcN7n5S92@SHf>Shb8R8b;
RHN1N7MlP8B6QHB5QXR:R8>1Q8>5Qh9mMVYUJVe^LW=_IfIWKGAfM6iYI6IYJV]/
KW=fMgEgP8>1PH60Ngj5Q8:0P821QH=oOGI`Kg=fOHB9RHEnO7acKGAkOWakNgYh
NGIbLgAcMGEdNXB:RX>3QhAnOXB5PhB5R8F1RiBKWi^AQXF:SXn@THn<Rh^;Q7ik
N7UlNh6=T8n=RhAlMgIjNGIbLgMmPh5kN7UjNgimO7ifLW1^LG5aL6eZIVQWIfQZ
KFecP8Z;QGmkNgYiNWb5Qh5lM7QnPgYbM7Z1PXB6Q8>6R8^BU9>9QHAoOhB6Q85h
LGN2QXJ1NgIaKFmfNWeoPHJ8Q8>5PH23QhR<TiB@R8B7R8J4PWigM7=fOGelO7j6
RXR4P81nNWf1QHR6P7amOhB7QhJ2QX^6RI>IVYF?RhR:S8N;Si:9P8J9RH^@SHV6
PHV;Q7agN7=gNgYkNWUhLVQYJW=nPH>4QhN7QX1lNG1]M7]nPX9kNGE]JFMVJFia
MWQiNgY^Hf9QHF9QIVefOhB:SY:BSi2@T8j@RX:7R8V<Rhf@SXJ0QhjAUHZ4Tj2T
Xj>TVXf;R8F9TIBCTHR1P827RXn?Q825QXR;R8FBVYJFVj6TXZ>PVj2VY:6PXIfJ
Vj6OUiJJVYVJViNNXYZGTi2@SXfBV9^JUH]mNGb0PH66QH:2PGYjPhF8RHR3QH^>
R7f0RHnCUYFFUi:@RGf3SYBCTiJDSXb5O7QeM7QkNgUhOhbARGijNGMdLg5bNWii
KVe`LG9dN7YbIF5THEiSJFaaLFUTHeiKFEUIGFA/MWj1NVeXK6eZJ6=VL7UlNgE_
LGEfL6ifOhR8PGj5SY2>SY:ASHb@T8R1PHR6P7YhNGj4Q8F5Ph64Rhj@SXf@RGif
MWQmRHjCVYbCRHV<S8R5PX:6Q7ioSY>CV9FBUIVHT8Z7R8^AUYFBSh^9RhR3QHfA
TI6CTHnBUYF;Ph65Q7ilNX27RHJ4RHf8P7n0OXB7QWmfLFeaMgUhOHJ6OFmXIFQc
NH24Qh1cJfQ/KW5aL75aLWEhLFIWJF9KGFE`O7igLW1^KFUSHfESIVe]J6aaLWAe
Mg^5Rhj8Ph>5QHN:QhR9RHV5OgYhOHJ9S92BTHMlNh>0NWj0Oh:7QGmmNGAeM71b
OH1jMW=_KGAlNWMjPXjAS96LXIfMXYfCU9FCS8N8RHJ1Oh22R8b;OgUgLg5bLW1k
R8V3NFiUIFY[IVI]LWI`IfY`L6abOH>0NgI`LGAgOh21PXJ;QX=oMWV3RHV>VJ>R
U8Z4P861OWb0Ph>3QHV?UIFCRWelQHZ7SYBFThf@THjAUj6QV96:QXfEU9FKWijE
RhB1PX:2RiJMWj6NWJ2LVYZHV9>@TY>HVI>ATi66Qi:HWYjLW:2QWJ>YZ:R[/:ZJ
UI^LVijHRhV:R8R2O7b2PGf2R8R9Rh=hKfmbKVabOhVBTX^:RhZ2PHR7PX:0Ng9`
MganOGajMG5iOWIcNhAoLW>0Q89lMgIfMWAgO7YnQhIjLgEfNGehL75hNGb2Ogj3
RY2CTI6EV9ZDShf:QH60PHRBThV0OGalO8>;SHnBU8j6QXn@S8f9Q8B5RH9bKWIl
NWEeNX:5QH9mOX:6Qh=lN7UiMgQgM7IhMG1bNGUmPW]hO7eiMWUjOX=kKVIPH6U`
LGAnQXB2PWacKVm^KW5hO7Q_IfUYIVaeL5mIH69OHEmPHUiHGFM/Kg5`LWAfNX66
PX62PGijMGAiO7ekNGMjP8:0OGagMWn6RY6IV8n8QH22QGaiNgemO7MaM7MjOhJ7
PhJ9QHJ=Shf>T8R0QY>ITX^5RI6BUj:[[Jj_YYnUZ:>MVIFEVIfNV9FEUiB>SHn?
T9:=RhjCThn9P7n6SHR0Ng^0OgalPHbAShUkLFm_KV]]MWf1P7]hN7=cO7UYHVY^
JVY/LGIbKV]XJVibKfMUK6i]MGj3PX1nN7=kPh9mLVIQIVicLVaZJVQYJfadQ8V3
NW5]KFQTI6U`NXB5OGEfNgn4RiBGUYBBS8B3RY6>PX28RhN7RH^@Ti6CV9bMX::O
WZ2QXInLVifRZJVXYj>NViNGWjBOU92BTIBKVi>?UZ6UX9ZKWIN@S8b@VIjOVXf3
PhJ;TINJUXf;SXn<QhB7QhJ7Rhf7Q8B0N75ZJg5eMgEbL75eMG1eO7YiNG9YIFAW
IfESHV9RHFUcM7R0PGUdNXF?THUkL6a]KVe]Kg9iPHJ3OG]lNWMmRHnEViJ7OGn7
R85lOGmiM7QlNgaoNgAdOHF7Q8:3Ri:IWYZDTiRGTI6CUi^OVI:GWInPVXn=TYF>
R8^FXZNOUYBETHZ7QhVAW9nFQWelOX68SXZ3PXJ6OX26Qh=oOGioP862NVi]L7=g
OhN8R8Z:RH^:QH9lNGYhMgYkMg=aLFi`N7UfNGimOH21NgMlPXJ4NW9`L6i`M7=b
N7eoO7I`JVISIVQ]M7^3P7QfLg9bLWMhMG1]KgAhNgehM7QlP8F6QHB1P8:6R8^>
SXb=Si2FWIjHTi:=RHR2Ngb2P7YjP8R=SX^3P7mkN79[KW^8Shn:PgagNh65RHfA
THQmNh23PG]gKfY]KfmYJG1hNGUlP7mkMg=bN8:7PWYcKFaaMgalNGUhMGElPhN2
N7=iPH5lNGf7TI:;Q85mNWQbKW=oQh=fKfYZLGEiNGMmQ8ImL6mjP8B;S8R5QXN3
P8:2OgUdMGUoQHN6PGmnNgUlPXJ:S8R6QX=mNGI^K71bLg9hQ8IoNGf9TiRHTHN3
PhJ8Ph24S96@U9NDTI6BT92EW:2RWIFBTI2@T8b5PhJ:Rhf?SHZ4PH1nNgakNGZ2
RXnBUIBBSX^;SHj;QXJ7QXfGUHZ3QHb<RXR<UYVGUiFBTI6>R7mjPI6LWi^?OWUn
PhB3QHV;RH=mPXV>U9NHUiRHTHZ3O7]mP8R=T9BLWiRFWj6MVYVJVIZHTi:<RHV6
Ph23RH^:Ri6GThR1PXJ9RXn=P7QlOWYfNH:@VibFRWmmP89nOh:0PX9nMg1`M7Yo
NgEdLVe_M7UlO7QaJg9mPGYaMGenNGEbM7MfLgAlPh9oO7EfP8R2NGE_K6aZJg9j
OgikLFIUJg1_J6EXL7YmN6eWIVY]L7IkOX25QhJ8RhV7R8EnN7A`KW9fMWEhOhF<
SX^5OWanPHB9SHj;QXB6SHj;RXZ=TI>ETHb=T8n>RH:1PXVEViR@SYFGTXf7QhfF
WinCRHN9SHf:RXb=Shn6Mg=jPhbCUYNBR863PX:6QgabLgQjMgEgNWaiLF][K75g
NWQdLG1]JVMVHeeEEUmTJ6UWJFmjQHJ1NgQjMg1/JFQ/N8>1MViYKgQiO8>7RXb7
P821P7eoOWQbKfiaNGn0OGMaL7ImNVmZL7V3QhZ<SXZ7Ri2EThf:Q826U9bGSXZ9
R8J9Rhb;SINNVY6;S8n?RH5oQYBRY9bBSXn@RhF5SI2<Qh5kOGmoSY^KV8f5QXB1
PGmmO7b1R8^:Q8B9S8^;RX^<SHb6P8:3NgAeNWUgMW=hQ8^@THZ4QHZ>SX^:QhJ6
Ng1^LG^7S8^7O71/KW=fMWf8RXZ3NWA]KgQkMfmXIfMYL7IiMgEiPX=nOX20Phb<
RXf9Ph65SYBBS8^<UZ:MTXj?TiNBRhAnO7j<V9:0MGJ2R81dJFj4UYB=Rhb7PhN8
Qh^=Si6;PX69TYRIVi^@Pgj0QhV5P7enOH2<ShJ3Ri2=QX61QXR5QHV;RhIkN86@
VIF:Q8>6SI2;PWj5U9jJUiVESHj@T92<SYFFS8Z>RXZ>Shj>SXJ2R8J3PH65QHZE
ShV=TIBEShF1PhN6QX^8OWn7QG]iOGajLVeaO8F3PHF:Qh9kK6IXIfQYJ6APJ7=m
P7alPH=mMFaWKGV6S8R0N75bM71aN7n8QgegMWb3PhR:OW9[KFmZK7EfLgMhMGE^
JV]/KFedNGQlOWYhOHR<QGj0OgekMg^1PhV<RX=nPhZ5P8NGVi6;QWmjNGf6SY6A
THQoQHb;R8V=S8F2QXJ0N7N3RhZ2NGUnQ89lNG^2QH5kNgf4S8j>S8R4Ph^HW9B>
S8^8Q81oPH9mN7IjPXJ6SHn>TiJBQginPXR3NgQfNGn7Rhb=RhImMWEkP825RhEf
Kfi_MWUfLFYUHfMdNWI_KWEkN75/KgQkNGMeM7^7QgU_LWQlNWUmPh9mPHJ4PX:0
OWemOh>1N79eLg9dLW1[HfAYM7elM71aMWM`K7=kOGemMgImQXjAShZ6QhB1PGmk
OhJ8Rhj7OWenQ8N8Q825Si6?S8Z<U9>?UYVDRXB6RHZ3NgR3T8j;TYJ?Rhb>TiB?
TIjSX9nIUY^LViVDUiZGUYBATY23N82@WZFQU8ZAU9>DT8nFViR>QhV>Ti6:QX1l
PhUmKfibNH:1OhN?R7ajOG]eMGE_K6eaN7n5PGj5Qh9oNg9`NXB3OWn2PWn2QX=l
NH:;RHF9RhR6QXV:QGigNh:2PWYbOhf<Pg]jNgf1PgmnQ89jNhF;RhfATY>DRgYe
OH>1PXbASXb;RHR2P8R@UYVFShV:TIJEUI^RYZ68JfN0[lj]QWEeOX68QhJ:SXR5
PX62PH>;UIJ?QXB6QhV8PWj1PhJ8R8R<THj2N7Z3SHj1LgB5RX1fLW^EXY=nOH^O
ZiecC3mKLgN:S8:0LVUbL6QYKGNGYYIkK7J7ShQbIVeiMFUZPhmkHU15HifULdE1
GWf3Nf=TO8V:MfiUGWB3RiB6KFb5VIf5KV1]TYVGVGEROHIoNgASIG=QF6j:VY1l
HUY]OhQ^J7j:VYMjFen8TW]^P9InHGN>ThM_KW^@SG9bMgAjPHR;QG]kNgimMFMX
OiJ?J6QhNGB?TgQnP6EQOHb6R8elOhR:PXJEPXBES96JV8I`O8VKXhR0RI^WNUQf
UYB9RH63Ph:6SY:BTX^>SXFDZYb5OhF?PFa^MHREP6mbL7f<RHf<QGeeLWb0MgJ2
NVehN6]WLH23OGMWKX^BPGj8RHR3NgAcO7AQK9:PT7IHGWJ<U927LV]cOhR5Q81V
H6QnUXQiJfn:SGUbKg1nQh1QHHZ>PYJHR7miOHR5Q8NEVHV7QH><XJRZYGmLJ:30
[8MnTI69W:^KOgfG/JfSTWQmTInMQGIjOhJ8Ph1aHg>IZjfMPWZ1Rh^DWI>=QWV8
[ZZ<Rj:n^iUnQjR`W8bFUX:1RjFdX9J@UZ>SUhfWWIVUV8=`NiZ[WgYFLZ2`Xg=O
OJRdPV=SP9nJNF]hQXE/Li2CN5i]T9f<MgV4OHFTU79FD7:MWGQJF8^NKU]ZTkB7
=31UX;JAIU]]U[ZVO65:DW^;PFiNH65LMXb5MVUXJfEdOW5bO8^GR6mHB61ePH^0
OhJ?T7aKE69[OX9oPgY_F4mbWjR<GdYSTZV=MVA@QZjALe93HhNDYIQP<4J7Z:9g
?T=TPZB^SVQVQZVbU6MTNHJ?X;VlRUeKKYVWU8AYKIVOK5Q/V[VcTFEQNHnP^/V[
QVAXUi]iH5ebUi=]B55oTY1a@E9iRHAQL9fUTg9IIhbdYFE@FWJO/8maN8NJTgaf
MgV7VZFa^:1iHV65/:AhKFmnVZBBN6UjT9VBPGUmRHIeOH^5R8V2OGUdPiZCP7Mk
RjBPOGF6XJ^AP6mVPJ2OTH1iPX^CTWiZIGNBShJ;Uib<Ri22O9NMQW=ML9RFUIAk
L7F2P6eaNGagQYIgGFMgPXAhI6Z6QgE^N8^<QX5UE6R?]:n3FUajRX1fOhjDNU=<
GHBRXHidLWf5OGJ:SGQXJ6Y^LfeYIVU`N81dI5i`T9A`F5aRP92:TH=UBT9aUWeO
HW:>U8J7N86PXij8J6QmW/6oYifFVYnOZJZRTGioTjJc]j24NWakJfEcSIF=Qh20
S9jRXJnTOFj4Z/BfTHnSXj2QX9RGWj>XWHZ<XZJESX^BQVilOgbCUY68KVIeTYfC
Q75^Lg=ZL96WXY^MU81_HXb^[;>SYYj=UIJLW85kPH1kLVn1VZBVMde2FYJbZhma
KG9]K7J5OVmdOGYXI7EmPge_KgjIZj>;Q7mYF59gWZ6IO5]CIX^FO69DDfITBeA/
QYB:Ke56Ae1/OWYUBSa<K7YcHde8FFInRXV:OhFDTi6:O7f3UZ6<QgegRh5]MGE;
=TicTI6:Me]IGfI/JfeTGF>0TGeSEFn<RGE[M9Jc];fm[JZ`/:n`YIjGRI:HR7]`
He]PF5QVKWb0N7J5RGMhPhVEWYfBQHBK]Kj^UiNJUYfZ_LVfWI^ZZiF7Qgj4ShjI
UHF8RXV4MgN8THjG[;^]U7ijQh=jSJn/QH2BW[:VP6ieRJ2UUXn<SINDTiF<NfQj
THAbL6eiU9bDQXNBR7EYG4a6C5Y^N6QKHfIQEdU3CUiZJFilMFE]Id]3EWEgIFih
NgeeL7N6T8]mOX^AT8nBPW9/KX2=UGaGFf]cN6Q>BUAQJfa`Lgn?QGYiLVAPLXRB
UiZJXkG7^IREQgElJfInQgQVJFQVHeDo>EAeOX27PF]bUJ:U/[>][[S4/7iRIG=d
LGIhO8^IRGR2RYNNT85aK722VjR]ZJ2SZ:VXVXjDTYJLUIR/^K:_[J:BT9>4Q8Ii
NXjHTXjBU9^GQh:9X/74/Jf^[k2TUhM`MYfcY9bWZ9bMVYNKUheiH5MFE59QL5eI
JgMiMg21Z/G3]JFDQWahM71bR:2DS8R@TX5ZLWmI>TUXK6EaL5E=G7>6Nf]bRY9i
LH><WJBBPh1eKWI_GUEROGikQ8AjNG=SFd]?EUEWK65XLX>>QWYS?c51EF5RFeQ_
QHjGUI6EUHV0Q7IaU/C@b;>QSgeSFG:G^;n/WHMNC4@oHXR>RXnERH=kJ5aDB3e4
B45FMGMkUJbWWJB/^m_Ym_OTe/2m`[Bc/I^?[;6=OH60Qij3PJbPUYV<IcU5G5Pd
44QlLS/cJgIQKWMiZHUcUiJ:P9FLNf65UXnLU723fL1TIXQjN8j9ES1<Phf;OGbQ
[8]cOfQOOiZ;N7M^O7UJA4I`I6^^^ZJ]/J6OPVE/KV]XL7MmOhNQZhejMgbETGQk
K5n9UFYKJ7=]KW5YL7aiMHRBTibSYZjZPGNGWj6TQ5aUGEI=>EIXH5U;BUiVH75V
GFj6[:bDWK6c[iR2SZ^QUJ^hb=fiOfehM6UUM8n4KgadJV55@4Pm:SUFKGJ5X:VH
Y;_4[I_7jLJgl?gVhM2oc;jTZ:F;JfidJFijJE5;@TE0<45KJGAVNHU]K86:NfUW
NiJJZ<STg[Nh/Ybhak>MSHbEQFeIDWJJVYfTPf9ZUj>=NX2@ThaiK6ekQhAfJfM]
Og1]V:N3IfQYGVn6VY5ZHGR;SWAOLhb8MhV=SHZ8X::NPVaVM9bMRFQ?H7n9Gd=W
H3Y;JXb>Kg65LE]JBDaL<ahgE79QEh6UZJ>HLfbIVGj6T89eIUa`E45GBB0_GfQF
>d1>H6Ho:SiDFfYnR9:AUJng[Jb]Zij4Pi1bC3`B0000000001XL72U1F6n@TH>I
][>c`/O1^:>>U/?LeMCEf>_ooooQdmo?]YMmQ9:IS6EJJh>CU96AZK[7hmSClOog
iN?5b]S3/9ZP[[79d:fP[jbMVjVi_ZbW_/G6/I^W_L;=dKb^cOk]j_oooooom=o=
]InFZ:1gHf9>AEQFAT]4;b8]?eMEB6jPXH5oW:6ITgn<VIB7M7jMY9^HJdUVLfMK
Cd=;FUiBADM0AVII?5IhN5=HPI2?UIjZ[:JWVXF4QG=]K5]RJeQDG6QQDF=fOGY]
LWIUHFmcH4I1DgV<NWRDTH28TGMD=0l01Q4C2P00:3m:HUeAJ7n6LFQnSib?Lfab
GR/lQJbRSZ>QQgAZM7=QAR`00000000000004cPjIHZ9Yjf:Q9JXZYF?VJ2`ZhZ4
R7]cR9VIW8McLFm]Ebd901@d@S];C4M/QXZ=Sijc/j:HZ<2dT96Z]=7Ufn7SjN_Q
f;:FXjBNXjJESk>fVinWUi6P[lSF`Znh`L[?bl6`^lk</Xn8W[JiVh1gNiS1a:^C
QXn>RH>4OG=^KJ?Ch?ooooobiMc7V7APC4he4`l000/T>65hU[k9cM2ePVQWLEhi
;CaBIgB5]LNb[K_6]Z^YTX:8R6]=@c8iD4]:G6YaOiRJU9^QXJo0/Z2HU8bATWUd
PgIUM9f`XYB2RI>>S8j:NH6AS8Z>U96>Uj2XYZ:S^<Zm/Kg3_<?>bkNTV96;O6m^
LgIhNW]hNh:6UZ:QXZ2LXJBS[k;3koooo^S7Uf0h9Q<982DV6`0@3`d]=TV9^]OV
fKZTRgATET]:GX6U[kZl[[>ZQG=dM75YMGeWEDXa71LI8RdiAf:1RX>2RhZ5NF5C
HG5^I6=YK6mgNXfXYIfOWYJ8QHR3LF5OIFi_G4MAIg9fK6I[KWUlOXJFS61EJgMm
NFAYNGIXEe0k9SUFGVagNX^GUHJ:Y:FIX:nga^cooooogk6=K3/T9292EdHo;1TX
?DQGMZKKlOO/_iYnBA/G8c]^X/;8_[nj_lO2aLbkZ;>[T7UF=bDD2@PPAFJ;Zkjo
^JnQWIj@Ph5bHfAQDU=bQHVLZ::RYiQkKFANGE=<C4Pn?DmGBD]^TjZi/jfn`jV5
LfaUKX=oL7IoOGEeOXAmK5eKHgF5OFm[N8MnMGf6TIjVYjRTX/Clooo`b9aaFT4V
;41FIeT/3`h>7398I7jL/;JaWX=_G3X[AFJ4[L?8eMFjXZFa];NaWY63KDdZ5`/0
000894]/QYjb][6e_/[7]JJMX9n=NF]/OiFW^<cNg]C6][J]UGUREDY6DEE<CUQW
NHZT^lWDf=6kZZ>LV9B<Ri^ZYIF=SY2FTXj=SY67P8^IW9b=OhJDY:bc_/?El_oo
mmZjUg1HAB`P8C5EGcl^<RhjCV20UJNbZ9n@OgY_GEENMY>/^:jUZjB<NGf7TZ:Q
SXV5KD`g;2L/=4=LL7N0SIbZ^/Bk];Re/kRcXi:3LF9SI5YGG5mZO7mcLGagKG9_
K7MmMg:2VJ:VZJjfa]38a<Jm`<k9_kBFQXb7MVYZKW1[GUUMGeQCE59EHFiePIJS
Xk;>g^oooooooooUb9elJ5=5Ae17;ahI7Ra1EF^1UZfg[if=PW=UJGjGZ[Rk^Knl
[9jANGJ6PgQiLV5B>A@000dM;d9AHWj=R8^P/Kg<dL[2[Y1mMG1XGU9:E6IcOhnF
UYJDTXn6LEE2?49:D55FHg=oRibfc/k2_[bg[ZBBNGAiKE]QKVibQHUmO7ajOG]Z
GWB<SH=eK6U/L6QTM7j6[M[/g[NBMei7<1`=5C0k:b0Z:bPgBE]_Qin[YYbAQGe_
H6IfQYf][JFHS7a]JFYZHUI?CDa6>bD;1PT8424iF7B1O7^?ZKg4`<?@d/2RRW]Y
F51IK7QcHVElRX^8PX67RHIoLfYTEeAPKGEmQY2S]/37a;o0_kJRSh9_FTa9D5EH
Gf9/NgimP7mjPHb;SXf:TYR@OgZ5V:J/_];UnokT_ZZGNW9/Kg]`FT8Y4a/Y;CmA
GFj9XZRGOW]kNH22RIJPZJROVIZLUY:Q_LoAbKZWVXmgF3`Y9Bdb=dA>EV=eQ8nS
^]?concEcLJiZY5eKWf0NGf:Uj:RWjfn_[6SW9FESGE[MWUiSJg2`l?3am[XiMW=
`K2LT8]kKFUTIVY^M7=`Nh^BW:VYWY^RXIREUYNMZjjWXZFfam7B_JJQW8QdK6a[
FUASFS4M:Bm4K7YiPiRPVYR@SYFDR8ROZZ2@Nf9OK6USJGB0SYRIUXn1OhN3MFQE
B4]FGeeNIV]gR9BO/;^ob<^iWHb1NgQ^GTmCGf9KFFIbLG1gPHJ2LV1SKfm]LW^8
TYFGThR2O7Z2RhYnM6IJHFYRFeYGH7N<S8^ASXjHW9bGS8N4Ph>2NVMIIGV0SJc6
blB^RfmIAdYHETM2D4dU3210HI>h`M?TeKRIP8:6NViXLGinO7=NCCddAV9aOH^D
VinBMfMVHUUIGV1JD55HHgAmNX2?X;Fm^KFVTXV0M7AbHei^NgMiPhN@WijEX;6`
YYV8PX=eFe5OIf1FCemjR9:MXJF][jfSTXIkMX29PgmmOXjNZ;2c]KN]WiZITh9e
J61VIFU_JFekX=3Tc;6l^JFWYYNGZYYO9PP53QTV?F>=Vhf1PHjFTY6JYjbRTXbD
W9nLUiRLYJRYYJ>KQ7b2N6QTFTmGFddl<cDk@4UGHgB7U9^T[;2c];Nm_[fk_;JY
XZ:PWYR1LGAaHE=:BeILEDY;D4]5?3I6F6=dRinUXJ2PYJjYUHjCRG9/LW9`KVae
QiRY[J:ES89fKfIQIFajRYRS[lc`n^[LgLjaVhZ8VjfRL3TT:c8g>dm_Phj:MfMT
IUeRNX>2PWQbMW=dQYj/[:jg_;fdWH5fNGM^JVQVIEY>D61]KF5MJgIgN7UhLfUO
GFAbOWUaKfabNWIaMh29SIFHSXB3QhZ?SXR8Q7I^MhN>ShZ7TjVe/Z^Z[:2=QGmd
GD0^9bTg@T=@H6QdQ9>PZJng_lO=dM7:a/6dZJJic/fmZ9V<LDT`<Si;@BPD0P0A
92i7NjJk`;R`YYVBT8^9QGE/Iee<>c];G6j5UYnIS7eeN7AZIfafNW5VHVIhSIJJ
WZ:RThB=VIZDSHAmNgU_JVQZJfAVMGinO867QX^IXJ6LVIZJTh5jPXJ6S9fYZkFm
]:RY]/38cM;JdL2_VX9`GT]5Be=EEV1[LGn;UjB[[JfZZ:jnaLCFkO[ol=O1[jb^
[k_0[H]VAcDd;b]0HGj?RH5oOGn6SYBJWYZ9Lf5HG6f4TiNLVij^[9Z;RHn:PH67
PVaJD4Q9BDQCHV]aLGJ6Rh=iNX1nOGmlNWj2PX:5Q8NGXZNZY9F7QH9lO7QZGUYL
I6efOhR@SXN2NWQlPX^BUYNQZJ:JWJF/[ZZWYJNXWi>;QhIkL75iOW1LEE1CIGB<
/M3B/IRCRXJ=V[G3YG9B?RPO:dIcW[BdZ9ZDUHYiNhVAQ6I29aPH92`kEg=jMGN5
TYNR]KVXT7YTAR<C3`/D9315G6]iRij^/[K2b/:eZ9N2LVMMEDmFJg]nN7N0SifW
Z9b:NVeRDd8nAE1QK7F4Uj>U[;W9d/Vl/IIdH54k:B4M6b4eCf1ZL7N:XjjYXjRa
/:6<NVeXJFehTJfeYi:;ShfHZj9lFD@^7adJ61`hH71YJWn;SinY];nhY9F@R8B2
PXB9TiVFTi>HVj:VXI^APfU4<SY4@dM<BDM9B4eLJWN>X[;4dmGAfN7Yl_3`l^kR
bZbEQgmiLfeVGU97?2XS<41<GW>1SIVT[kc7c=?AbLW3_;J/XYF8OWMfLg=lPXN:
PG1[LWMfMgQlP7b4UZ2[`MOYnoo_dlG3`l>/MSdM4P00000D>U]aOXfU^l?8c<Jb
WH=M@SToC5YTL8>?TYRMX:JXZjjUUX9S?B4P;SY6DfV7UIFBTIVZ/ZfYZIn<NFYT
IV1OJ7R7T9BGVj:XZZNW[ZjRVYJ:Ogn7T9JDS8V9QX1mPXjIUhaoMFYSGeIBFVAY
J6ITIg1gPXnMZkFdZjVXX9^HSWaVCD5CKh>BWIZ>UZB^^YiaHe<b6`T000lK;3Y1
E7N8R9^`]kZcXi>5NFmVH61PIFmdNX64SiZPYJRTV8IaHE]B@3Y3E6YfNhJEY:n_
YYbFSX5bJVIXLH2@Vj2RW8n9RX=dIeiGDTm8@TA>Gg:9XKG5c]7Ad/o1/JFGPfeN
F5MJGFIiSIB>RXbBTHZ4Og]_HV9THV9YLgfAY:nlbmg_mN[@]Zb[]/FoX7m]HE1;
ADQUNXF4LF1XNWUaNH>3OgIRF61cQhfBY;k<blg@d=OOfLVjZY1W?2LX:b/a>DAA
G6QjSjS0blg?c<6aWXMkOGn5SY>HW:B]ZZbi`<6hYI>3LUY4>cTm@418EfMfTkSE
i^kbl^oTc[^[VXMiN7YfKW1hN7UiN7MdLFiZKgb4P7MfMVe[LXNNZ:j[WiFJZ[Fb
TfiSGDa7BDULM7YdKFUdQXV3RY:=QGeWEEEMK7f=VZR`ZYf9MgEgJeA:AChf<3Do
ADmOJFMWJ69XMh>9S8nHXZ6JVI^KW9ZGUY6:PGA[HUI=DUUGCdA0B59KJ7N?X9fF
S8B0OX20OX5nLfi]JFMRGfAVJFi`Kg9nRI6IVYFBR79TGU]KHW9mNWb5SIRY^/6d
YJNWXYf?KD4S2P002Q/hD69dQ8jVa<_:b;ZYU7aTFEYRKWZ2SYfY/;6][[S0]In2
G3TT5`h710`M;C@iBEieSinX/[Vj]k>`Xi>?UYVDSi6GX:FUZ;2e/:BDPW9[L6eP
GF5QGeaOI6U`N868Tj>]];J_ZJRYY::WXYZCRHJ:TYBFV9VPYjNX/;>_]KNQSi6J
Yk6a[jFMX[6oa[VLQWUUEUIADf9ZIe]GHGZHYK2k^;6KPW1XLh28SHf>VJV_Y9^N
YkW0]In6Kf1IBSa0Be5ADEMRKGF1SI:>PgEZIF5QIVeeP8VCY[[1aLoHe/g1[YZ9
OgQdLgIoPG]oTj6WZ:2GThAZDChZ7b<]?55WNhnNZJfd^[c1`;>UW96:SHMjO9:R
W:K3c<kJgmS7^kk3`J^6DAX0000000<I;3i;HH:S/kFdZYb=MfESJVaaN821Oh64
SibY]kZg/:26ITdk:bD_?3LX8Be4G7:5V[70`KRe/ZRMSWa_H59;AD=5A4aQLWMi
M6]RFUEGFf=bO7n1PH:8UJ:[/K:_[JZNThamK6IWIV9MHVaeMg=_Kfm[H5IHFUm^
NGanQi^]_]CMcKFeam?KekN:K65LH6E]QYFFTGm/L8N<OWAYF4D]50XG;D=KL8NO
/;Fg^ko2`K^]UGaaKV5HFV5THF9VKWQoQXjEVY>1M6m[KG9bLWQnR96CTiRV/kJ^
YZ2DQgUXGUYJHV]_M82<Si>OZKBn`<S<_JRPX::TXYNJYjJMUYBHWJ6RZL3Ac;ni
^;6MQ7j<Wk:d[j68OX:=U8=N?CLh;B`]=EA`O7f0T:O7fMkSf/ZdVXIlP8N8Pgn3
RHj6M6ifPXJ3MUa6@CTV6bDmDEQNHFEYL7j9T::b]k>XXJJa]JNDTY:>QhB<T8Uk
Mg]hKF9IE51AEEIBDeUIHWAnPXfLY:R`];:a[ZFJUYVJU8^6QHJ9QW]^IV5KFUYK
IFa^NY6^`LK<e/nYUjbnbLRPGcP_8R8U93mKHV5LEF:6UHn=PW1PDDY>G6ilQXZ;
T9VMWZRb_<BoXH5fO7e`H6=eO71NCdiCDDPo?Chl>3@c>CXjAeQUKW1`Mh^LWiVJ
WYbBQXJ8QXVDX:>TY9bMYI^8PGa/GE9<C59EDUAKJWMfMWj5PX::RhZ7PH27UIRO
/jjKWK31a]7Hd;NHU::UTV@f60/=51<G>V9gO7YnRHj4OhB4QH5eK6eiQHj@SH^E
YkBg]JnWX8iZC4Q<@C@hC6EhNg9_OiFOX:^ob/Bg[:BKRWYhQIBHUIJMYJROU8j6
OG9VH5]IHG=kOXN<TjB]ZjZjcm36a<k=`/G:aL?1`l[;cm?=_JnHMf][DcXh@DeI
HgB<YKJl`<K1`MScn]^HFd<f:bdY9dEcR8R;XL[Yi]_A_:J@N6AGDe9>@d16Cei^
NWj6V::GOG=lNFePBd99Cdm<DF5bMgAlQhAmMVmeP864Sj6`/::BTjF_[:jf^:nR
T7edKfUWJ6YWGV5dPX9nRY>:O7EdLW5`KgnCVinT[KJj^;:[X92:TY1kLGj?WYnQ
^M7Hd<6`Xjjk/YQR;1<300L60PhcDUmSJHNY][Z/UHR1MF5LLHNDSXN@WJjc/;Ji
_lBfWhimGCXM1@020000000A72Y1DeaVM821NWEhP8V?Rh>5TINHX:V][JNOVI>:
PG]hM6iYIf5EAdE=F5iJFV5YOYNY^L>n/:6ARXnBPWA^KW1_KgAkOgaiNXNF[L_L
flZaZ[BjXf`h;SXj?DIAJGf7R8:6U::NTXioJUiAB4I:EFA[JFYgTJjm_kfo_:B3
M79WFDi;EVE/K71lRiFGWZ^^YIV;PG]cJF=WKgR0PH>AX::LW:2XZYV9Q7j2TYJE
VY^NZ:ZUZ[:c]kJb]kJZZZf]^LBo]:JHV9jIT8V0P8AdHV5WKFe[MI6ff_7]eLK:
c<k7Ve/g;BX`<cQ@M9>Y/[?4gMo>^J>CPfDo91XO:S=5HHBU/kS0alNmXhA`HTX_
7ADK81l/@eefR9JZ`/NgZJ2ITgmVFf1aOhN?Wk>m]JVSXZ:HQgU^I5UDEE97>cmF
IfIaS::RU9BITi:DShjHVXn=UIjRUH^CUi6BShB1RiRGQ7J5WK;;dlNj]L39]Gdn
8AH600006T9MH5YTPZJg]:fRTH9bED57FFEZL7Z5Uj^kaLcCcKBKSGME=B4I3`@0
0PhL;3PoBeaRH6MbLVMOI6ecMg^0PhnQ[KJg];6]XiVBRhAmNW]jL720PgITDe9I
DCde=cY9F5m_OhB9TYjTXinKWijEShZ2OX><T92K]m7Vo_o[fM[Sgl2<E3@[9B8G
3b4oF6UhR9R^_[beZYV8N6EEE69cPhjEX:joblc8a/2]VY1kHeUABD=0@TYJKGn=
T9FFT9>HUI6?SHJ1R9JV[jn[[K>dZj:RY9nKWijDTYRFRX:7T8b0NG9[KgQnQXN:
Uj6_`m3JhNGRf<k4_;>NSHEiJ5YJF4Q6EV^5Xl7?akBcalFXPEHk9a`N620lGh>L
[KC0d]GIf<BZSVi>>SHe>CloB5=QN8REXJNNRGY^G4e2>SDc<SDoCfR4V:Rka/g=
blW6]Yb2LFifOg]aKWAlO7IaMh60OH:9SYJOW924N6eYJ6ahOGn5RHV>VZ>V[KJl
_;^j[YfDShV6OW=aJemSK6]]MHBL]L_KeKfe_KfaS5Pg7PlE5a<Q@5maNW^6XZn^
YHacGddi:RdjATQ7Bef0Wjji`;jcX8mnJEiKE4Tn=S4b>TEAEe]RIFETHF=TG51D
IGV8R8B0PHb?S8V:Ti>>ShnBUYF>QGidH59>D5AGGVM[K6QQIgEiMgAfOX9oOhB3
P7ikP92LViZS[:ZV[L;Kl?kkhl_5c<^`ND4U6Q/P7B@mHX26PH6B/<32^J27M65;
A5YhRY>HWk?El?Ocj][7/IUlHE98>R/U:SI2CUUOIG1lPh5kNX27QXB=Wk:h]:f/
]lO<bLK4_[6QU8Z6QHN5OginP8fGUi:@Ti:>RHN:RhR2OHJAUj6]^LG:blW:c<G1
_JjPSh>;VjZd^kFJQX::SG0o6@H01QLI8DMbU:Ze_/ODelfjWXEeGdPj>D9BGUmQ
LHFDWif@QWe`Fd8^9bHR82/nDFEfOhRI[KZi/:>FS8AmMWEjQ8b:P7IhPhR:Si6B
TXYmLfaYKgIcM7QfMgf5R8V=T92CUYRMYZZXZjZSV8j>U9>?RhF0OX>7Ogb1QiBZ
`MSTfl:`[:jVQU0X4P000002:eioSIBLZKFl^Z^GRWYUCSm1CUeVJgR;VjJ/YiJ4
MVE9:aPF724S9bhlDfUmSYj__/2fZ9b?O6QMEDmAF6=/KG>0QhR8SiZNViB9P7Uf
L5m<>C0d?deFGfinSIFQ[kFe/Jj[VhMiLVicOGn4T9>AU9RNY:6M[LCCgn7<ZIBD
V8e[B3Tb;3Dm>TYaUjZ][k6jbM7B_ij3LfIIFf]cOhnMZ[K5clk3[Y^<Og1LBT98
CU5MJ6egR92?TYVKUXf8RHInOH:5SiNKX:>QY:^XX9^DS8F3QhV<UIZHUY69PX>4
P8JCWZ>TXj:KU9>HWJ:VY:2RXifQXibIUI:8NWIkRIRZaMkgoo[ZfLJkYgHl5P<0
00886CmYSIjNVj2^]KFXQf=:>RdV;3Q5EVIiSjW1c/c0[9J3KEI4>ca1A4A1A59W
N8JCVY^CQGn3Pg]dJf1MHFI`NGf6U9jV[jnTVi>8OWIdP8^:QHF=UYfNWj6PWinK
UY>?R8V6OGemOXNAU9>HVI:=R89lNXJCW[G<fn;TflRi]KBWMS`P40<841DVAVQj
O7n9V:2PWheaG59>CE9NIfa_Lg^6UjJ[YIR9N6IICT<m>cPa:2P`=d19E69_Ngeh
O81hK6M[KWN3S9f//KFk^KJf[In@NV1?@cPf=BPS:B`jDF9XJ6Q_MGMjP8F6Q8F9
SY2FXZFY/JnYZ:JHS8f:SYNDVJo4e=S;/ifKY9MY<@L000DI8Be6Ih>>Tj>kcm[P
e;f^YYb@RHbAShZ5PhN@VZF/ZjRSXIf9KEM@DU5>DEEEGFYfQifXZjFNVHioMGAf
O8ZDV9nUY[:o_KVgZ9R>Qh9mNX6AThN7TYFNYjNY[[2WWijLW9bOYZBMWJ:UX9^G
UIJ<OgajOXB;X;C1bMKeooCSbK>c/hm@9QXH:DEFIWnHYj^QT96HUY:5ITa0=BXZ
=3e3BTmDGgF?XjRRV8IbIUi?@SdnBU]ZM7Z2SiZPWiVCR7ifJemBCEANKGj9SiBF
VJ:SVi63LF=GCTmFGFMaOXV@UIVPZjn][[Fg[ZN//[6/Z:Za/JRRXYR8P7MVGE]M
I6]ePiFY]]Kgl]k7][Bg/Y1G;1096B8T<4MTOXnBU9jY[ZbNPf]LCTA2BeacPhR;
T9j_]:VCMea:?c@V7AXO:SI2DEi/OHR;SI:ARHEnKUe>ATA:FfiiPhjJXjV_/kVo
`;NVUH=bK6EHD4]3=cQ;EU=BFfAQIg=hNWYgJV1UKg9^KWEjPH^?T96GWZ>PY;>i
e?ooooKG_kReZXED;A881@D=6Bm<H6a^LGj=W:JRTHZ;RhnGY;2a/;2//;g7cLZo
/ZVRVXenKV5LF5MMHfE[LgYnQHnHWinAOW1XJWB2TYfOWInV/;k7a[f`YIbETi>G
VI24PGmkOHNATXnBVifGV:2UYJbf^[bo^:NITHV1NWMeKVQ/L7B2U:Bcb^;ZiMg9
]kW4`YAB;bDN92liBUimVJBWZ:bZXIJ0Gdi=Bd<n?T10B5UTK7nCWijAPg=MBcTU
61DH82e1FFj2VZZ^YjFXYIN8O6mRFE1AGg:0RY>IXjf]Yj>KShQkJUmJFEQCD51E
Gf]eNW^7U9^S[K6a][Ze]KZn`Kfj_[fi^[bcXIB9NV]_NG1bRibU[kV`W:Bj`j]/
=1P63BTb:Ri8I79kRYf__<6cTFiPGEUIHFUbOHV@TYNQZ:NPTX1WD3dW5a4A3`hO
>DYIK7^4QhZBV9RCRGmgLViVKGn7QhJ9TI^X[jbVZ[:aYj6MSWIRE4]7B4Y<DeUO
KXFFW9J:QHEoMgEaJf]/KG9eMh29Pgn9RWn2TIVV]Kc<f]W@_k6`^lJXKTLe:blg
=30hCVIdLVeiSYB>PFE>Be1BFVj7W:V`/[O4e=gMf=74[I=oMgE^IVEYLG^1P8:<
SXEmN75XHfM_L6QWL86CVI^QZK2`/KZn]j^NU92>T9JMYJVXYjRZ[ZnZXiZ>QX>5
SIVRW9bTY:V`/[Vn]jFAQW]^IEmIFV9YNYRgd>conNGJc]3AY60h9ad_A4MBJXNR
/ko7eMg=]IMV=QX:00036B]5HGF?[LGCdlNfWGUC?BdK30802A/iF6n6VjVf`<>h
YY1cFdXj<cY7EFIfPiJY/kNj/Z:?P75J@3<_=D9DJ7R2SifVY9jLUi26NWR0QhF2
R9JSZk;2e=kOeLg8^JRHQ7QhMg9gPI6ab<ZlWiJRZjIe=AP82A`L61`^D6]iPi>Z
^/?6]iR1MFEQIVI/L7J0PXbMZkNm^[BVT7MK?bXG000000TH9CmPMXVLXYbET8Uo
MFi/KGZ>UYZV]L35alFm/ZbWW8n6QH9hKF1AAD16AdA9DUQMHVAXMH>AW9jKWZFR
Uhn8P7YfLgMnQY>MWJ:][JFX^LO4_[BRV:6_Ve`]92<^=30d?59dPWemTZZ/XiIf
DdQ=D5AKJGR1Sinbcn[glnCGc;VRTXA`FTLk@4mPKgAhRiN>QhJ8SHn;QHF9Ri2F
WZR[XYnX[k>aZJ6KT8J2PXJ:S9NTYjJVZk6a[jn_[ZBGTI6FUI6@TYFJWIV@T9>@
Rhf;OgEbLg=YJh2;Ri:_f>GShLoAhMJ`K3<W9S4k=TEMNj[2b<g<a[:BKS/<0000
000F=4YMLHRS]l;6`K^bX8Q_ET4`928Y=D9AHgJ?WYVHVI:<PgA^KV5>ATI;FfAT
J71cMWn;TY>:NF]UHF=ZLgf0OWUoTZ2W/[Zj/j^OTI:KViF=RHV9SI>MXj6NW9ZG
T8EnOWikO7^3Uk?Lln;>b<_8XUhP00037BP]@F1kRYFKXZVVWY5eGeYMGUYLIFmc
MWj<Z<3;d<_3^J:7Kee?@c@M20474AHN=eMVKWb8SI2?SY>FVYjITYRQWZ2__/74
bLW4_[^`VWiRCCl^7b0]=3a<Ef=bOH:1NgZ0R8b>Si:EUI>CV9fGTYJMWYNFV9RQ
ZJJUZZnb^l2j/IbEXYeiAal@4R@`92DeBEiTI7:1TYnRVX^3R8R1Ngb5S8Z5QYZi
cmgQh^OL_Yj;OgAXFDa6?c`n?3]<H6eoTIfWZZNXZZJOWI^IWjFSZkc7a/2h[ZBL
TXEhLG1dO8:5R8R<U9NGVZ>YZ:JX/[nn]:nYYZ6IUI>?RXJ:TYB<Rhf9QG]kP8FD
Wk;FgmO<_<CHe:mfDD8k@S/`@5MaRiROYJZSTXZ4KUU9=c4d>SXc=d1:HG^<Ti:?
S81fL6QPFEMDDU5AF5YFGVmgMGZ4RHV5Ph1jLFi_L7=bK6U/LG9/HU]HGFM]Kg5b
MGUoOWUgNH6>TiJNY:^c][Fc/j^HQX24Qh5cLGf6Q7]dM6m]N7YdN8BEXJg4h_C_
fLW3aL:MId8Z92XP4aHT?eedPhZAUifUX8f0MFYOEUMOJ6m`LhFJZ;6f]kRbVge[
IEmGBcXa;c@j>Se<GFAWK7R5S8R4R8f?S8B2SIVKVZ:ZZZRVYjFOWIVBSXIgKFQI
BdI=FV=WK75hOGagMGAdLVmbNWn1RYRNXZZ^/;Fe]kFTW9ZHV9:FYJjmbL6cZjna
VW19:@/22`X621TiD5m`Oi6MYK:ZWj6NUhj9TIJIVYNIXJN`^;o7a[RYX9Z<MV9C
B44k>3Lc=D=AGW63TIZOYk:j_l30_Kg3`KRh_lK9`[>XY9nGSXAoNW9/JVUWI6Yc
MgYoQX^>TI:DVYjLVifTZjf]/;2[YZ:NV928Ph:7RH^CVZO1g?7dhlZm^:Z;H3`S
40d:0`PF<51VNi2S^/G2_JfRVhYiK6MUGeE@EFMgOhB6QhN2NW5[IEM3<RDP8RXh
B5ETN8JBVj6]]K6YX9J>QWQ/IEeEE5YSK71/JFihO7Q^JFa^JfUYJ71oSINNYJng
^[Vi^KNe[Z6NW9^LSh5hKfi/IfAPIVmcNXB@Vij`dN3Ti]_@c/foUfM>@T57?3Df
=TQMJGV6UIfHU8YoP7]^H5EFFeYHEUa`PHbBUIZSY9nHT8IiJ5U>@SH]:BP/>DQC
IGR3SYFLZ[Bc[:>FQgijNGb3QH>3P8>?UI6:PhJCVIVIV9B9NfiTHV=PGUiQI6EY
L7=gP8VAU8j8QhN;SXV1OGn5S9^_];2e`M3QjN7A_k>XSfU29a<70`0000DP=41E
Jg^4RI2DUIjRWYF?UYbJUi2BVjB^]KRm`;ff/JjUVH]gI5A5?C`oB55BEEaUM8:>
VJ6W[;2c/[2]Z:FSXZBWZ:FV[K>e][F_[Jn_[:FKT8N0NGEbM7=^KgEoRI2CTY6F
WZBUWiZGUYBGWjJ][jja][g5cM_Xj>3EcL_6]iMdH4m2=R@K4Q4O;3M1C5a[N8RE
Y;:f^kno_[R/WXekKfMPF4e8Be=MIFQZJVUZK6m/HeY@Ad@n>3PnAe9JIW^?W:J]
/K>c/JbTUhMhJUaBBdQ5@T96Be9IHVihOh:5R8Z=RhR8RXnCV9bOY:NXY9ZCSh^8
PW]jOh>0NWV3S8j>Tin]/k>^ZZb^ZiZ9P7UhLfIHBdQAFEaOHfYaMGIdM7QhMg5`
NGn0OGEaLg9`Kg1eMgAaKW1dMGEiOGmmNWb2QXF0NWMfM6mUHVEYKFeYIVUcO8>7
Ri6ETXj;RX^;QX:2Q8F5QHF6RI2FVYnTZ:NSWYZHV9F>QGYaJ61NHFEVHf=ZM8>=
TI:CU9NJX:JXZZ^/[k:b[jNPW9NAQW5JBT52@D10@TUAEUQIGF9VJFY^MX::RXV<
U9VIU8j=T9:FVijSYZNUXInJUYNCRWmjNGYmP7ikNgf1QHJ6Q81oOh20OWj1Q8N;
TIVPYjb_/kNh]ZjWZ:b`/[2][:NQWijJU8j7OWUfM7=cLFm_M7^4Ri:EUYZNXJ>V
Zk6c/k6_/;:d/Z^QVY65OGA^KG1eLfaUHFI^LG1`Lg^1OgMbLg^4R8V8QH5mNGIe
N7QdKf]ZKFm_KFYXIfIXIf=NG61WK6YSGf1SHf5QIFifNGUiOhR@UYB>RHR;RX=h
KfIJCDE7CeIIFV1ZM7YjNGUjNgalOGaiMgV2SYJHV9VLX9jJUYFEUYFCTHj=SXb7
P7j0P7efKVeaMWQgMGEiOhJ=TiJIW9bLVYRIVYNEUYVJUHj:Qh=lMWAcLFaWIfIP
FUIEFV5YK6icMG=bM7^6SY:BTIJLWYZEShZ9S8j:Q865RhR3OWj2Q81jMFm]KFe]
KW9fNh24QhJ5Q8>0OWaoPh>4RHb=ShV2PHB8RHZ:RHnFUi>CTi6@TI:?SHR3Qi2E
TX^5QXb>RWe`K6abMg]oPhF7R8N8RXfBUI>BT8n?SXb8PWmkN7IeN7]jMWEfNG]i
M6a/M7IcKVa/JVacO8:5Q8:0O7]oPGekNgUkPXN9QX>8SXn;Qh^CUiFBTHnBVI^J
U9JIUYJFTY6CTXn>SHf=S8^6OWYhNh66SI>GW9nOWY^MWIfQWijNWj>UYJFWZZb[
[K>aYYbFU9BETHj;Ri2=RY6NYJBMT8F0PH1lMFeRFeeSIVERGUeNGEQDEeiVIfQ]
KW9iNW9XH5mTIfIPG5aMFeQIFEUKGf5NGV5SI6ATIfUYJVe^KgEjOX22OgQlRHn@
ShInQHj7QH9mNWF1S8b=UIJDTiBET9JOVI69OWYiN7UmQH=nP8:5S8N0PhB4RXZ5
OGAfQ8nCTY2DWJJXWHn7R8UmN7j0OWmnOh20NW9[IW9kLVALFUeRHf9SJg=gOX1l
PX^7QHf8Ogn4Q8>0NG=iO7anOGn7TiR=O7MeNH1kN7b0PX5oPhN5QhJ3OGb4QhN9
QGikNX20N7Z0QHf?RY6ESXV>TXb4PXV7SI27R8^?U9BAV9bIT8:1Q8BCWiN3OXB6
RY6>Pgn0PGmoPWalRY2DTHnLX:6V[:BHVYN7OgYcN7EZIUiFFfA[M7YnOGb3SXYl
MgAdMfmVJG1cNWU`KW=gMG1gPX:0S966OX6>TH>0Og5]NXb5MWAlPhVIXijGWJ2T
Z:B^^jJKXJF]Y96@SX^CTiFIXJj`/KFe/[>][;Jg/J^X[ko3]k>o`;Bc]JbJSiBA
PGf5QGj2Q8J;RXAfQIV?R7ihOg]oOFQRKW1`HEecKEmPJ7I^G61QJ6UNH5mULfE9
DfAWGdm9D5QVE3LiA5ASJFaXJgAlOh1bJX6:M6=[LFIBEVUNDVIkOGj9SXnGUXMl
Kg1lJU5<Ff=GF5aKN8aiKH2OZIREVh^3QWU/Mh:4P7f6TIJLVhefOI1lFeiaMf]U
O8EnS9N?TifLRhbATH^2NGJ2PG1[Jg1aJfajTIB6P96OWiB4T9BJU7j5RH:=QgMk
RIJ@QhInKfQjO7IgO8n5MX:AVIFRYhnH^/>eUhN3SjR@JF=iSY20O8N5NH5/HHY`
CF=`Lh9oKgVCY9bEY;ZeZY^N]hMhW961Q8:CUgj8WJFOLVYjMXZZZifOX8F1UHN7
Wj:4RXf2YIR3WY5iHD]ZPViHCdmCF5mCIfeMK5M?M6]NM7e[Hei=IG=[KVQXN7b5
P6Q`MgYbJVe/DV]nKX2HTWR3YJ1nOIFKWIn?KgBSbKVMZ:nUZZJT_<bmWYF/[k[7
/8^8YZFOYJ:NYHYbXlNXRWb<Z9nOZijPZZNXWhV0[;jBSiZAVY^JR82>RiJ5OHb3
QWacIf^8K5APJG1[EEihE4Y<Be]fPWITDEMXPViCHV=?HDaJOW5UAcAIKVEHBTmB
Jf]QPjB<Q8BJ_:Z<NhfDN7EYLgaZNg5TE6V9JFIjO7UQFFmTLYAiEEiiTHf4PXj`
ZIBETHfHV8ehSi=cLGV3SX^4PiJWRFeSKVEcTH1]G61/P8QoVJ:IQ6b1U9>5L7F7
R9^MPFmcNhfKRGM[NY6FRG5aO::RM6YbPhZ6S7jH_9ATIgF2P6aLIW9VHVUaLEmQ
S8b;THnBOHnb[YUdN9EhEV^?SW]kQ8BGUW1lOEiaPFb4UXj7NH>HW[B`YjZ?VJ:K
`=jn[j>JYjBd_J29]Kfa`K:X[96@U8JSXIJQPWbccKjUWZZ?QHmbQh]oV:2CIEb2
Q6mcK5AGKei3D5IGGfAWI6Y^KVU/PHB9JUM]N5e<G5IBGVaDBE]cJUeVKh5dFFMh
NHEcHfj0OFUQKGZCTW1dMHJ6PifJW;BiWiZk]Y^ZWGf?Z9J4Sh5hUJ:<SYEdNJg:
_l_^b;K4[9nHWiMPBX22M8ALG7YfMX6<RhBCUGaoPX>CWIV=PX>GR7b0Q8QLG:6U
Jg61Hf=bRXaDBea@II6HPW]gN8^;KVY`IgF8PgV0OViDGWYnPgR4VX22ZXeHOk6;
GFIXDeecOHF6OHF5RJFCQGmbQJ>=O9B5L6Q`LFN>RfmfQH9kTYFBZ;^_]:j8UZBD
Q6YLHeiXMEDk@Ta9CUmGAU5LJ5I=LgY^JgQdHG^DQ7f>Y8AZKg64LeikRWMcQ9VN
SH]oPY2=R6Y]PW1PKH:0M61TKeigUhIHE6adKG5cFe]jRWZ9SW5hKe=TRWiiX:F>
U;F]UhbJTWZ2R8fIT96/VX24SYBDRH5jPIRNUK:kWjBabLgLj>;Se^WmiJZRZ9FI
WHb3NWeaIG=cPI:=NgehI5YiS6iVLf=LLh5bEEUFB5ijMWR=Ng1ZLJ;8_IF2NWb;
VW]^LfUO@3aHCc`L8V1aFeaSGFAmSXA]NhmmO8AiKfYlXk6SVIjMVJBf/jg2`j>>
S8Z9RgMhVjjHOgEoSj:hWYJe]JjTS8R3Xl[Ig]K5b][Un^:[TH^2KEEE?BH`;caI
LfQBGeiFM8n7OWV2PX9oLFALFeI/SH=cM7FM^jnUWif_/IQmIGN1MVeNHUe?>cA7
C4ESP71lXY]kKGA`PIJAPf=dShR7PgjKTgNAUHJ1R:6SX:NQYJ^?QHYmGCe4C5Ag
NdM6GVZG_kZGTJ6`ZY:@Ui^W]/G:]ZbhY8NDTFmWHDI0@RdZ<d54@4a3;d=EEgJ9
Pf=VUI5fI5]gR7AhQH63P7Z1SJfiWYVHPH>UY7agOE]RMVUIBd18JXF<LFj:PXbH
LfAjOVmVHEiTJ6MdSY^FUXabL8RHUiBKWIj_V8AoKG2AX7a@FWj4QX>9TXV=XkNj
Z:[6`l7GcLOKdlWEfmOGc[FTY:2@MGIlLGn7LFQkR8=dLg5cP8^5M6UYJ5M7>4QP
HgN4RJ6WUX:0VJZQWiJ1M6aaM7UIBU]GD5e/EU5PI7B9Q6YC?d=EDD]HGU=AIG]^
N8R2V[N_Y8ilSYf[WI6BW9^?U9>?Y<2ZVZ:@PhR<S8:9SH:5UYN7QYFPXjRef^oI
^ZJig?3XZG9cQ7YDAC/nCdiHK6AMMg5JIGYlG4]@@CU2CUY;C6aeOW]lS9JX_LBm
^[BaYIF4PY2;NF11?4UADdeJMgQkV8ibMGUiOG]`LGUmRg]iW;>nZ8RTa;Nc^L2[
TIbPTXQhIVA^OWn=VHR0QhVAW8elNhJCX:>8Pin[Yi>@VY^gcMORg<[@loW<W85e
JeLn:@P04a8M<C@k=RhlDF]iJeDc=5=QDbleEVMaKGFQ/::V[kRnb/>RS9>DOV=?
C4Do=c=2Ce=TL7B:QfUHJGYiMV5MKG]lKFU`PJ[1XH>9SI2EUYJCUHmlMgU]HVYj
Kfb2QGeaG5]YL6]SJV5NN8n=PXbGVjN/XYjZ]<cTl?[oomN]VXf1RWQFBUUYIVa^
PJR_UXb2R:>QQUaEGUYNGTHi@5]gSJVX[;FWWJ:TX9^?NV5[NfQMEe=/SYnUX9ZH
Y;g1ZIR=HdYHD3a1E58nBg=oNgY/LXR;V9j7LVegPh>1OX2?TIVVY:g4c;:@T9JH
W9B9OhVEVZ>[ZkBdV9b_^L7Bhm6od>CWdimaH65TF4U1>Dm^M79aNgQmR8b@R7]a
I6imKV5A@dmFHh6DXJ^fb/:ZZjZJQWYWF61UGEmKB4IBFf=bMGAiJEaUL71YG5Q:
>DAQNGE/OiRU]lK0]LKQf/6jZ96LXhiiNhRBV:>LTI20K79mLfiPE5ACHg^5Q9RS
Z;^kZj>S[m3co_kahNcciknJUhE_IEUBB49BH5iSI5i182DlCE]E=2`d=B`F4R@j
FFMWKgZ2S96<Si5lIVMiPGmeKG=iR9Z8KF]/K86CUHQ[FUiZIDm3D598CUIMJ7F6
RXN1NY:GRX^8OWE`L79cMGJ3TI6P/:nRSH:1RiRAR8>4TinMVY>3Pi6AR8R9QhbH
/lK3/99dI7>6PFE;@TiIGgAoOXbPZZRBRY>GVY>1Oh25T7YXJ7:>YK6aYYF6Pge_
O928M5iEI7R5QGIYM85iMg=_N821RIVJP6=SL8BCR8>J[[Nl_KJEQIZSVXIbIEaU
OXAnNh6J[k6ZVhjAVYV0IE]LHEmSMi6Y][Jd^KjgXYVRXYbRZj6LZ;2jal^eTXZA
VYj6KgV1P7QcMF=LLGMbLVMNEeIUJE]:@d18DE=FF5YfU8aoMgAjPYFb/YJ7QHV8
PG]dKGjJWIJLYJBCP7edGT`l;b`cBEU?CEibP89jK6inPH>:P7Z;UY2=T9BOZJb`
]jZITI:KXZBEOGElPhnCPWAgOHRIUXnAV:Ve][>XX9j6Nh^HVXj4Ogb:VYFFXJjo
]J6QVHN9T8IXBTM@EfMUDdiLKWf1M61JLHJ4Q89[F5MECUIRFe=DH75iNG]jPYRU
Xh]ZEeAKJFMMGFR1UYVASIVRVHn9P7f4OWN1T9JASY>ARGmbJ6APKX1kJ5YFGWR6
NfACDf1]NGUhRijITYNIUhMmS9F?RXN1PY:^^K6SW:c4_jVRTWU`MhR;QHJ6RIbc
^[:/Zj2FTHAoRH^6QX9lNh63PX=lM6UKHgN3QGYWHff0RWETJ6UVL7QbKW5gN8>D
SXB6PhZ<N6UVHVQiQHfEWibQ^lBaVGiYIVAPFU5@HWR1PWioRhb9TIRMWiR8QY>O
WYB>SX^9Qh:4QhbO/JnQU8bEY:nVRh60PH=`IGfLXHn?/[bWWibJY:j/X8^7VIn@
O6eeRY^IQGE^JVQ[JFMWHEMKLh1iNgI[JFENGV=XGU5KIVY]KgAfMg1NDe=QPHag
KG5cPIV_/9f8O7IcK6YcNGQmRHZ5Q8R<Qh>3OgEaL6idOH1jKfeoS7i^J6aiQH^2
P8nFSY6FVjJJRXVCY;2l_:NTZiZDXZN/ZYnFRX>5RHZ7PXB5O8ZUW81bKF9MFUUM
HfADC5miRH]kKGVGXIZ>O7EdKVEOHVa`J6QePWicL71cJUeIEemhOVmZJV]`LGR3
PW^3U9VCSiNFSY:5I5YKF5]KE5ETKfi`MgUmOgY`IF=ULXF4LG5oRYNRXiVAUj:V
Wi6EWifFTX^9T9RMV925P9BYYj^bWi6CVjfi`Lg:b=7EgN3?^JNKTY:DTXf:OWEh
OXJ9S81XHFERHfY]KfYKDDPf<4ERHeMQL79gMG9aLGQkKVENI7UiNXnFUYjMUY2B
UXn=RgU_L6AEDUaSIWAmNFi[NXjFTHV0OXNGWYJ9OWUjQ8V:SIBNY:JQVIfYYJ:O
THEgMX>?WjBOXYZ=TiR?RiBMSh:@X:6KVIZHTH^:QGQfPXImLFQZM7edI6MaL7nG
Wi:1Ngj7RWmhLVAJG6EWIfeUFEUBBDY=EUiPF4I9HgR9ThahK6meNWj5Si6ATiJK
W9^RW8R2P8B5NG9jSYnMUXajMHB?R7mjNXZSXI6@SXN2QHb5Ph9mQiNETHf5RiRO
VI>IW9NIVIFMZZBCPgN0Si:?UZ>ORh5gK7AnNFUIEUUIFUUWNgekPhjESGidLWn5
MVUTIV]ZLGYgLf]YMgE/JV5LJWn2LVYdN7YkNGb5RXN1OHNGVHMiO7idLW=/KgA]
HeYKHVISFeaYJemSMhV;QhF3SYfNWjBSY9fGXJFRX9^NXifNV8R5SYF<PHnW/:ne
_;be[Z2?SIbTXJ:`bMK?b/k<b;jd[jFITXb0OHF9Qh=lNWYkOWj2T9B7NFMPH5]I
FE=?CDU@EeQNFe9FJWUgLW9`KWR8T92;QH5iLgMeLg^2P7QdOgm[GEiPFeQLH65T
LGn9TiBDW9f@PgE]M7aiMG^>VY:=RhnHVYJ>PgikMWn@VYV@T9RKU9VUZ:BOX9bA
T9JMYJf/WX^8TIB?Qh62QX^8PGafNGiiMW5`MgMcLg=jS9FAS8Z4N7^7Q7igIf5S
GE=ADe9<CE=II6QSHfadL6M[LFQOGV=bOH21PX>9S92?QX>1QI2HVY>=RX>1Q7QT
FEaXL7B1TIjPVIBARhEnMgQgNX:6QX=nMfigRi>@S8J6SYFGUYJIT8>4QHR?S8J>
S8B8T96>Si2>RGihNh23OWUgKfY`Mgn:RH:2RiFGVJ6OUHaoNWiiLVUYKFEMG69[
K6EQGEQLHfaiO7j=UHn<QX61Ng=ZG5AMHe]EFfA^KFASGUQHH6UYH65]L7IlOHNH
YJVUXIfEUY>>V:BZ[:nc[ZVPTIFUYiV?SiJU/KRg/;6e[Z^`]ko0_Kfl_[k6cKn]
Yk71b/_3[9JBVZ6HR8:0O7ejNhNDVi>4O7EaL6]]LFaYIfMPDTTk;3E5@Cm:E69c
OHN<SY><QH1fLW1/M7]bJFYaL6UVJFY[LWI_HUeTMHB8QWY[Jg=dLWJ7ThUoPhfD
U9FERg]_KgUlMV]MFfYjOh>:SY>BT9:CUi^FQgYlSYZQ[:fJTI^MUYBBRH5hNX:5
Q7n3T923Q8^FYZFER8R<RhbCUYB;Ng9dNh1oNWE_HUIDIGUiKVYXJVa_NGM/KGAc
KFYbNg]lPh>0OGilMFeUK7b5QhN2PXfLX9>5OGAfQ8EkOhn@R8N9QXV9PHNEUi:?
S8F2QhAlPhV5QHV5PGemQh^5OgmnOH:<TYNOW968S9>ARGMYLX>AW9Z@Ri:MY:FO
UHnIX9Z?TJ2/Xi24QY>?OgMaL7QoPh=oMFUWLgQbLg1WHeeLIg=eMgYgLWN0NVeU
GU5?G6=QET]BH6IVIVMWK7QjKEmAC5EQHUYFF6IeOX:0PX:0QXb8QXF7TINFU9>B
ShbEY:f`[Zjf/Z6HW:>SXZ:SZK2d];>e][Jf/Jjc/ZVPW9RBSXjASXf?SI2DUIBF
WJ^`YY>0O7emOgmhM71ZJVIRGEEBFfU^IEQHFf=bN7MmQWicKVmeO7agLgIdJF5G
C4mOKgMdK6Y/LGIhMW9_Kg5dNGUjPhV=T9>IXZ2CRHR>TYFETXb6MVEYMgikMWIc
L7V6Qh1lOH23RHf=T9^YZYbEVY^>QHV>RhN5Oh>:SI2ASHbEXZRUX9RGYk:`YijF
Thb2O7b1PWU^IFEYHf1YKf]YJg5eMgj5PgelQXj:RiBERhN=RhAoN6m_NW]_JFib
MWQeMgYdJVEXJfidL6YdPWiaJfafPhR0NWUnQ8^<RHj;NW=mQ7mhMGUoR8V4PX:6
SY2@TiJEUZ6ZXiN=QX9oNGMfN7Z0QHB:TiB>UJ6MT9BSYj:QWj6VXYNJXYfCRhJ3
QXV0MWM]GEm[L6YSH69XKVi]KFmhP7MYIVQRH6=KCDA6Acda<3Y3A4YIIF9NH6=/
NWibIf=WJVmiQ8^5NWj@TH>0QHV9Qh9lPhA]F5YZNXJ<SiNPYZV[ZZ^f_knl]k:c
_lO5`Knoa/_6_Kbm^KBa[:BPWibKWI^IUYJHW:2PWI^JVj2PV9FFUYBBShAlPXb>
R7eiNG9^N8B5Ph>0MW=oQhJ0Mg1bO7mhKVENH6AOFEMHGFA/L6iZIfQ/J6QXHfAY
JVITJWUkNH><S8J0PHN:RH9kNWanNW9bMgZ0RHj<R8J7R8Z:Pgn0P7ejNgn3Ph63
QX>0P7aiO8B;Q7YdN8FCU8b5R9FQXijKWJBTX9bBRhR2OW]hMW=bLG9eM7V3PGYn
RX^3NGMfN8B=TY27QHbGViB:Q8J;QWM_Kg5]I6EaNGAUG5mUJF]XJW=mO79[Jg5g
OGmkNgelO7]nOGMiP7mbI6IfOh>;TiBDSXB0RY^TXiVBU9ZNV8^2PX^ET8fASXV;
TiVGUYRIUiBEVi^BRhfAU9FHUX^6T9ZIU8j=ShnDVi^QZ:B@OWn6Pg]lOWQ`KW9f
N7UkNgA^IV1XLF]JAd91<bXZ:c4i@40n?D16Ce=EE51@FFMZJW9nPGj2RHfBThYn
NWj4NV]YLWIdL79eMH6GWYZHWJBTXjN][:N[/;2ZYjNRWj:UZkFj/jJOY:NPThR5
R8Z;SY:JXYj>PH6:U9^OWIbT[:jWV8f@UibPYJFMThb2NhB?THf3MW9kR9JLUi6>
Rhb:PGimO7aeJVMYJfmdM7=cL6eWHF5VIf1MIFa_JfAXMh:6P7MeLg=_IFAXIF1O
JG9^KG=eM7^6U9jNUY>GVIN=PGaiNhB3O7elPHR2NWMgN7E^IF=XLgYnPhVCVj:/
/[c9b[ZLMF9PGFUeP9>MVXU]HFUlSIBCUZ6UVXanLVYUJgR1S9RLWi^CTiFCShIn
OX>0MFYSI6UbMfiQH6YeMFm]L7=bKFUWJ79lOhJ@UYRJViF6O7n2Ng5aNGUZFeUL
I7EnOGj3TIjRZ;>j^J^GSHnDVj6KTH^9RHZAVYVJWibGTHf7P8FEZ[o@hNCOf]WO
g<^jXHj9P7E]L7alKVM_NGEVIFa^Kg1YG4Tl>Ci8DEAJJgf<UiVETXYeH5AAEEeQ
FDa8B4I6BDe<Ce]WK71fMFiNCDU;Ce1@DUYZLg5/If1LFeiVJF9RJfiWIVecLgF0
S9JW_/_?c/6cYIVLYZfia<>fZ:V^Z9fDTi^T[:nZZK2e]:VY^Kbh^lkQg<^gYIN1
M6QNH6MdLfihOWidJfe^KVUNFeeSHeUGGFUiQXnIZkfo]JZWXI6=Si6BTY2>RXN7
Rh^6R96FVIVBR7mkMVeUHf=SH5aOGE5=E5I=Be5IGUQBG6Q^LViVHfM^JfagR9RR
XIVHVi^GU9:@UIbOYjfQThj8QH>4SHMkP92PXZJmcL:d_LS8/X]lKD/k;1`G73Hj
<DUVO81]GEAACdM0?3m5AT0g?UM`P8NCZk^n^[F`Z:>OU8V1NgQbLh25OGf5SHj?
TXn6PGigK6IXJfe]JfecNGYmPXF9Ti^KUiVMU8=kOhJ8PhFCXJk0cLbn]K6[W9:A
ShjATYFRY:6PVZNj^[[0^Zjld=KPlooig=gMc[NGS8QlO6iICdQEFTi>G7QmIe12
BDm7@CXa;BTX9c9ALX^DUj:YZ9j<RHj?ThQjMgA[HV1^NWb1Nfm_LgIaGeI@@cDX
9BLY;C4g@U5CBdaEFemXMWYcLgAfNWn>VjB//[bo_lO9a;jcYiZ>QhF1OhJ>U964
OWakOhbFTXn=Q86=[L[Bc;Fec<BMO7]kNh=bH5aTKemIHg:@U8=bIVebLFUJFUU?
BdU?H86/amSOe<_>a[Nd/Z^RUXb1MF]ZOHf9Qi>PZ:f`/:jWWX]_DTA7BTYAHg5h
O7ikOHF9Rh^8QG]]I5aHGF9^P8jHWIfT];^m^JVKRgiiKg1mR8^5OW^2SIBKZ;6_
Zjfa^/KHgLZnc>ST/Gi`MGQ]D2lR=d@Z4``K?4Di:A`N8bTX71lZ>dY3?3a<LIFa
`<??fm[>`;BZYZFLQ6YKFfEUFea/PXb0M7R1Q7i[Cc`c:R<Z>DQGGfQcO8J9RXnI
YJjd^;2VWI>9QHbIWjF^^/?7alK5^jjPSHF9U9>3NWb5TiZIW:F_^;FfaM[gonkB
b=oceiecJgJ9S7=LGWbARgURI7EfJTm3BU1LDC/a<DMDDEAIK8ZLXZ6Q[K6UViVL
WiV?PW5VHfE]Lg9hQ8^4L5i@BdiCD4E0@3hoAe5MJW5cNX1mLV]/KGEoO7UlOh>:
Si6>TYjSY[2h^KN^WXUiKfIQIW>0RXnJZZj[WY>IWIJ?V:g4i?KQ^k?Ah[mnFUee
S89N=RY5ETlj:cQ5DEI5?DABG4dn=CE3AdQGKhbW^lC8cmC8]kW7d<g2]Z^RV9:D
UHj5PH>4P7MaKVMOG5iNH65OIFUUH5iPIg:1SYROZ;2a[J:AQX1lNgn5Ri6HViVM
W9BETh=jN7=_LWb7Rhb@W:nn_l31^kB/ZkC3f^cZe/74e;n6FDaKIUTl5`HH;Slh
92i3E5UBE5ILI5<k;RHZ<34iDGRHZk>_[ZjXVi:LZjVRViFFU8YmLfAFCdeCDDm@
Ce]THUiBBD@oA4]<CEAVPI>JXk2k`/G;c<:hZIfGU92;Ri2GW:>QUX^1N6QHCd<j
?4YNKgAgQINV/kc1aLK1^kk:iOoolm_SoooBTG^>YK:FJ4aCMhMoLVilP7QP?3E3
Eea3<352DDa7E76?X:2GSY6DR7f5Xkc0_Knj]K2VWI:4Nh2;SHEnOGM]IF1GBSHR
8Bdk@45:DEUVL7=jPXF8RHF<ShN9T9RRYJjf^lS9_[:SWI:2Og=VI6=/N8:8Ri6A
SIJKTI>ETIJU^<KCf<>QWK2XN40W;dUSDR/P;TQKDdU=GFeYET0kADiGEEEVQI65
O8j/_/[5]kg6`K6UYZVWWI>1HDa;EV=QGVUcNFiOFemQEda1>3Ld;cM8H7Z?WJ^h
`/WBg>3Le]3=c/NgYZF`][2WXIfERGi`FTi8>cM4DUEJHV=RJWB1TIZ[`L_:cMGN
koooooogk?ckbiB8RXbAN50c>e5;?BXO9bTN2P@H;daHASm2AD<d;SUNSJZnc=7N
jM_?enCWd[VWU8Z0Lg=eM7MgKfYVFe=BCTDg9A@600PK:SM7DUEKHVIaOhnQ/Kk5
b/W3a<Bm];:`Y9fIT8^8SYVGTXamN8>9RhYoL6M`OH62P8^HU96?V;KIk=bdW:C5
aHQIDF5jLThO4SEAFe=8FGF:SH:7WKBeV7UZJFiUFEagW[S0`<32akZMR8bFRW=Q
F5ADFEmTJg5gN7E_JFIPFU]KEU=ACDeHIFa_Lg^5S8V2PHB?W::VZ:FPWIbGTIBG
TXnFVY69RXnCSh=_HV5WL7YlMWR6VkG9fNOVelBaZKCBk>gI`LORfjQmLgEgGb/0
00@R:B0G9CI0@2l]?51FBclh?dmBEV9oZl[NkOOooo_K`lKAbkV[XibEShb9Q8R=
PWMfNgidGd`o<R<E30T<4a/W=D=BFF9`Q9JR/l?=em?6`Kjh[jRY[kJk`LO1]JjS
Rg5KA3<Y9BTgBeEHHWB5SYZOWJ:QV:74j_ooonkdoooMZiR?SWm@6`DXB4Dn=cY2
?c<K5BHi@3`k?4ABFeaLMj:j`LO;dmoLb[Jga;n]WYZFQgQ^Jg9jNWUgNh5nMfaX
J5iEBcLX:2he>3TnBEQXLGf@XK6k_[NWUhn;PgelOhVEW9bMYZZRUH9_J6ISGf5[
NHF8QXjMWINPW9JJW:>]a>WooogOf^OJZW=ED5mUCbL@9d14@CToDUUICdIBJWMc
JF1SLgemOHj_c=oPe]SOf/2QVJ:NRW5TH5eGDeIOIW1gNGf5RXV5Q8J0K5]>A4=<
EV5]MGZ2S9BFW9jHUiF;OFeRGV5[N82;VZ>VZ:ZXXZ6RW96;RHb?Si>OYZVXXZ:R
Z[F_XIbGUjNec=kGbK[6hLnNO75lR7=<70ddAC<[:SI6Ad4h>4QIFDi4?D0m>Sa0
GXBGWj2V_<o<^K31e]O4[jVYY9N4N7YmP8F:U9jJRg]aKVEC@2XO8bXc?4I<CUEN
IFehQH^AUYZQYk2nc]SGe=?Gg=W?`KJ_XiAoIU50;bP[<3Hl@daLKgZ7S8:1PG^1
Ul3Oi^OLj?oojKFV//35[7mFFW9VE4U0?34U4`<>9BhW8R8Z=3@a;d9[QHnFYKgE
f/Vi`]W[i]C9a[fZU8V>U91lIf=YK6YPF5IAAT4l<cM7DUUQJfm_LWZ5V:>OXkG3
b<:bYYnMVi:=SY6AR861PXR9Pg5JD4Q0A4mNIV]`M7f=Uj>_^;^b/KkOooooon7K
i]VXLF1TKFM25@4RA40e;cDnB5I@AU1JET]3@DeMH69WPK7Ci_;jooook=76blF_
SgAWGUA9?T9>Cd@jA5QUJUmGGEiLF55;BTmFHfilR96MYJff]KBj`L2iYHamO8B3
NW9/K71cNX:6RXUnLFUVHf9VMHF=TIFFX[K2b/W6_:VR[LOUn?g^e=7XiKAmIFEc
LU<Z42@l<BHT;d9>ETi=HgUoMFIJEeaEAT5@MIJTX9^Z^l6dXJ>e`[fXWIjIS7=K
FV=XHei[PY6FT8bBUhejIU=6@D55BDeFG61PIGN9UYnV[kVdXiRHViR?RY6IXJNZ
/K>]Y9bITGe^IEYHFUE@CTeAFFE]K7V8SINMZ/CNn?ocj_OjfJB9QHR<Md`Y=5QL
DDe>Bc`_91/Q;SDb;1lG7bT]<3eMPif]^];`ooKHbMGSiMW:a;jeY8aoP89nLFQW
Jg1_IEiGBd0e:bL[<CY3CeiXKg9kRI>IX:jnb/Vm/k6e][Ff_LK:a[^aZinCR7EX
G4Ti:bPf@daDDe5MKhBDVI^JV9jY`^Kooo_Qi?C]a9b>SiF4FS@]B512=S4d=d56
@49=FF1OFeURK6UTJX>Y`<[@enSck]c;c=??_:6AS8YmIEQJGUY<?Ca?JFiWJ6a`
KV]TFUYLHFQ^Mh67R8F6SiRLX:Va/Z^LRh1kMFeVI6ETHF9WK6i`LWMiLFY[LGj:
T9>FWZN^/kJj^[Zl`LoRm_ooon[Ul>>hQFAJI64l5@<>6@`51P/H9Bd[:CI7CU5D
E5e^NWj6XLCMjnk^n?ook]C8a[n[Th=kMfaGB4YEFU=<C5ALFE1=Ce1=B40m?ce5
FVenSiZIUif[^L;7bLW3]9nATi^MUh^6SY^OVI:CShAnN6eTHEa@DF1XJW1bLG5g
NGIfOX:8U:Ble_?ol>[koMndUXV@UgmI@4eRGE1:B4A2BDHn@Da=@c/`:bh]:RD]
Af9bN8:Pa=?8]kK1blJbZ:Z]X8A]KH6AT8J3RI:FSHN7QGYUBC4X9RXa=3]8DUQO
JgV:WJV^/[NcYinLW9fLVIZPY:>KTHb>TYJJViR?PGEhQXIdIEaIHFUXJg9kR8jE
XkOAjocdh^KYaIEoOhR<L40Q;TU9?Sm4A455A3LjDEiOHV5NI6e/J7RFZkW6e^oo
oo7Kd]?Ebk6JTXj2KEIDJGA]GeYOIfIGCeEGBcTZ8bXf?diOKh:BUiVNXJF_^;o8
dM32/Zf^[:>HUYRDRh1eL6iYI5U;@Sdl>3U5D5UXLGF2UZV`[k2c]kk;g?3mnN[Z
mNVoW9JJUh1D;R@^:ADA6b8M6b8R:3]>DeAJG6A]Ie]RP:2gc=k_oooom^OThmc4
XHb:RgmRCeIXIeE7B59LG5III6AIC490AD]BFVQgPhjBTiNO[K[2b/o9^jZLU9>?
QGb3SiFKWIVGV9B9PWIWFdi6C5YOH6MbPiFRYjb/Z:J^_mGWlNS>aM3?/XE[J7Ul
FSHT=4]8@413?T1:AD5;EeM?CDM5BDI1AfRAZ;G4e>;ZjM_<alW7^9b6OX62LVAV
LG5RDe5LH5M=DUiSGeE9A492B55GFfE]JfM[M82;U9^TZ:6IUYNPZJ^XZkBk`/Bn
[Z:QXY^;N6=BC55IFUiSHVQoV9^GU92<VK[Ein[?]KWHhJigI6UjMEDh=4]GDE9M
HUaPJ6=MHVaRE4/k>3/g=41VTZnoa]K`ooolloCek]FeXIVAO6=LJWE]Ge]TLg]f
LWQkKeiAAShf<3M1BE=PJfigRIRU/K_4alJm/JRQViJ>QH>:TifTYInITXQnM6EE
ACi2ATQ6BE9NMHjMZ[FmaMC[oooom^3RjMJWMe]GFdP]8RTi=C0d<b/Q:2TK5b<_
9QdG4b4_=ciCO:2jdN3_oooonoWno?7Ja[ZaXHQhNGifHeUDDeE?C4a>B3/k?chm
?T9:EVI`LGJ1T:2ZZZZa^[nl^;Rf[jJISXZ;SHn>R8N:RGmaI5mOHfM]LgQjNWf4
S8f9R8ZAY/cdooo_jOOnhK6FS8n6GCT/=3/f>3]0?3Pn?CLlDUiIEdmBFEE:A5Yn
VZbf`mGSi]WBgNGRe[ne/jN>LFM/JUU9ADQAE5=@DUQGDdi6?d9?GfQeR9FHVj2^
`/[;b/>gYiJ3MW9_Jf5ED5=EFfI[KG5eLVi_KVa[LX2:S8Z;UJFZXYRNZkS9ho[l
j=3>gm^eQVe[JE@`8BH_<c<nC4U0@DY=CUQQHUiNFeeQFU1CJXNK[kg8eM[DcM;K
f]2m[jj[V7idO81aFTmGHfITIFadL6=LFEA=C4m>DfEeOhJ8TJFb^L34a/JmZZ2P
VXalLgEkO7AZJ6e_L7EgM6eVKGj4OGMhPY>LX:2IT9F^doGooNWLinO8VWIRGV14
91h^?Ca2DUmPEeUMH6akP75SEde8>bdZ?f5jS9Z]aMOLeMCMgmC4^;>[UWe/K7=_
If9PHfU^M7MgM6QMEDY1?chf<T1@FFEeQIV[]Kg9c/[8bLW5_:bNVIFDU8aoNgem
OG=ND4mACU=OIf]/L7n?U9NSZJk0f_?nn>7;c/FDI51EHE<h:Ri5De=LKG=[IVQW
IFenP7=]JfiaJUaLN8nFW:2W[ZnWX:JZXIR=RHf9OWImRHZ3NgAcKVQZLFmZHeUA
CDU9De]NK828Pgj2SYZOX:BZ[:f`][bm]j^RX:>VWhelLfUKC3/d<SA0D5UPJFmm
U:BYYjBQY;KGmO_^h=kWg[>6L71gIC`P8C@j<c@g<b/Y:R/dA5EIEEYNIfiXHVMh
SIZR[Kk@eM?GhncZhmO@bKFJRHAnL65@AD0nAUMQHVAUI6MZIf9NE4Q5@Ce0BUEP
Kgf;W[;5f>O^l>gUel_7_ZZFRHN5OGMbK6acN7j6RHR:VZNMSHAjLWAoVkg>`:V`
dN?2TGejOW1;=3<n>c8iA4Y@HFm_MX6:RgibJFY[ET53FG>4Sj6eaM7Ig>3Uh=2d
VH]jHD/k<bla=CLkAUU^MgYnPhR7O79]JVU/KW1fQ8nAU9ZS/kNa/kFe[9Z:OWE^
J65FE69]MGeoOh:2PH65Q7YfO8B<ShR1Pi[6jOooj^Cakm6RP7AeJ3XF428_:C95
Ee]HFUQKJ7YkIU]JFe]<=SE>KGb2SI^a`L6l`/kCdm;:_kBUWYV>OFeVHf1MGVU/
I5]GEU=;?CU2ATUDHFebM7j<V9nOXJfe][^j/jfTWZB[XiNCTiB=PGMdMgEgRiRE
RXfW^kji/jfY]LoXlMZdX:jjUUPg?EAJ<@`;8Si2BUaVJVAQGV9gRXiiIfEXM6mM
H7VL];^o`/G=dLc1/jRPTGibJFEZIU=?Ee=8@deKJ6aXI6IVFDU7Ce5:Ae9LI6ag
RIn`][S0a/cFh^KIc;je[ZFIQ7IaHDTf;2dc@4iGGV=YNYBPW9RS]LOUoooVb=;a
mLnKOWn?O4df@517>dE<BTE6B4=>H6aYEeEMKG9PEVAlT9JJY[G1bm3>cM3AbkZX
XZ2KRVmTIV1DB4E:DE9@D5IMGUMEF5aNHF9SJ6a_MWYmPhjO[k>b_<Bl/kNk]jfQ
U92DSHElMWEeO7mnN6e^PiFDTI>DW:Blj?WSa/CIfkF<NWR1M4T/:S4e>dMAE55A
DE1KK7f2MF=KG5Q;@TYOMHBAX;79fnG[ko[olmg7^[:QRfmE?blT7BHj?T5@D55D
D55?C4Lj>3i2BUQWLGjEZ[K1c<kDg=:l^KV`YY^ASHZ2LFATH5]WNXB8QWakRIF>
RI6MZ/7UlN7<bM_J[7aUKWaI:1TX<B@W>DePJG1eO9FW[:B=OGUcJU]@DEmbNhB@
VZk3cLS1alg8]ibATXYhIU]LKFmSI6MZK6QXJfQGA4=0;R</=dQFFVAePi:MXZVi
al[4`;6QWib@P7McLW=/IVifO8B@T8=hOHb?RHVDV92M`n3UfM3LjMb^R8Z>Of<n
;b/_=3@d=S`m@D4nBf9aJEaHFf=QF69fS:Jc^<CJkNoSfmGFdk^LPgQlMee4>C]1
AE1LGf=WJWV3NFmZH5ICCdaII65_PhjR_<K5bm[Xh<F_Yj6JR79QF5UPGUUNK7J9
WZ>KSi>FVJNUVYRH[MGbkL^bbNG=WHF6RWmH=Bhm?Bdb@dM4DU]GHh6GU81_IFil
HS`_>55VLg^3UkWBdm?Skn[@/j^/W7M?@4Q=C4]@FUUCEV9YHU9=BDA0>T9LLG9m
TIb_`LgToooonLZX[]3/j/B2BRlZ?UAXOY6QZjZSUH5eLgj@WY^CUk;<`IIkQiN=
JdY3C4DU000000086bdoC4e9D55=CDI2@D9;BdMFLXF=W;C@h_?oooOYfl^fX9VM
UhUjMHFARHRJZZnc^;Vm^ZB>RHYnJ61XM7AVIfmlSYFGZ/STloCajn7A]IRDV9F9
M6=QK7QoRYjf^:ZUXZ:FQH:D/m?J_k:o`JE_CV5oLSlH7C0];SToBDm=B3i9LH=m
IUUIGEi:>CY?IFY]Jf9]QibJR7n5QWeWFEmLDCdP7RdW6a8@7bX]<3Q5A38/=SD`
;cI3EEeMJWf<VZBX[[o0/;G0_kBLQ7n=TXEhKfUUL8NGUXnH[K_?mOooooSooogS
e=OPeZZ:R96AM5eLGfEZJWB5T9^XZjnd^LK3`<W7alg@f]kTjoOoooghoooonNST
hm[KgmO6/ZRXZJNNVIfMXZ>JUiVLU8IkLG=cJF5PHF]XFVYnSI6CUXeiLWb0O7IX
FEeQCCL[61HS;cDe<S4h>CDe;S51E6EMAcLf@3`Z4`000000000000002a8A3P<0
00871P8;4aTG0`@G:CM3BdmEG6]aMX>7QG1HHGalJVIQGVMRGfecJfYgQhf=ShQd
M7MbNg]jP8>=UZZc/kJjdNGXjoOoooobflkCd<6b[;;6fN;Ph>kooooooooooooo
ooooooolg:nCQ7egK6Y]LgAfQiJY_l:fYJRh][2aZJJZZZ:BTjk5`[Vc/ko=`:RW
[:bYXI67OV]MG69`LVQJD4i=BDM4AdE6DDU>CSXP8T=NFdPo@e1JEf=hOWYnRiVS
V81eP8AbGU5=EE]LI6ibKVUdPh>5UjBT[kRbX9BFTg5>?3<j@BdP;cTW8SY7@d=<
CU1SK6]_I5eYLG5/KWR9WZ^a]<KPkNS?]KFh/Z:@Rh^@QW5`N7EYGf5QGVYhMGR5
Rh>5RHfGVj:XZJZWXZ:VZk[6alK8aKjj];:/ZZ^VWiF1LVaVK7R2RhjM/KFb^L[K
iNW_k=Bo_JemEeeREClX:D=?CEMPKWakOW9RMi29Mg9cLV=<D6=nQ8=lNgN3S8Yl
JEUHJFMPHU`o;CHn?cLa<Sa3>2hf@De>>c<f:a@52A8N:C<iB5ICBTQ3?DeLFUm]
L6YJBD];@Shd:c=8BTE;EfQbOY2LWIj`_]?Oe<_?b;>=J65HBUA;:RXkAUQZP8n7
Qh]gMHnHV964TZJYZjFS]m3Jf=khooooooo_img8]jfTXYV5Mh>EUHjJ[kB/YJ_3
c[^VXZV/Y[;<bkVc^<7Ae]WZjnSSfMoVeLS=a;o;h>[J^JBRXIjKVJO1d];@dmKF
hO[ooocVa/G=[Fa1A4P`2`09:S<cA4iAFV9_L6EYL6]UGUeLGfQ_Mh6:SiB=S9JH
TI2=NGJ2NFQMFUQ3:Rdn@SDe?dM?C3he=T13?CTmAdQ9C4m@F65TJg>0QH25S8V0
Oh9nMV]FCE]RFeUMGf=VI6A/N86<TI6L]l;1e^7Fd=7DcK:1FeMHC3<W>TQBHV]e
OWiiMfI@Fg5hN7=dNGf4PHBM^lc8]:Vb`<VkWXb?TH9hR8UjNG=RH6]]IfM_LVaU
JG=nNf]PGfimP7ihN7YjPY:PXifGT9NQX9bER7n5Shn>Qf]@?T9LK6ieQY^a_kZl
`<GGiNochlBXVij@H2X@5B/V0P005bdg=ca?HVYVGFF2Th9PD5MQIUiJKHVJXJ2W
_Lc8^ZRCO7^2MViXGUQ?BTa9@T11>CU:DdLk?DI4@4aFD4UAIWQiL729Vhj2PXfO
/[baYJZh]J:FTXn6M65MJ6iWJ6mbO9S0em70anKooooooo7YdjQoMWM^E2/F6ba4
DfYhKG:1PH6>VjBb]ZJBRhj=Sj:fa]WPemGRjnKIdm_Rf<Jo`;BJOVigRXf0MWA^
K7B3SI2@T8EcKGIlO863P7mnNX:AUiVHQh:AWjni]K2RSHJ8PGASDDTh:B`kB4]H
NI:FT8fCVJVj`Kb/Uh^6L4d_9S4h8`0000<P;3a0=cPo>c@lCEYIDE1@GVIFB4iS
N8R<T9JJY::IUYBFV9^KUH^1LfI]NgELCV=eL71hPGmfMgj5PWA[MXF7QhJ=UiZQ
YJjma/:ncM;:_[Ji^Kk7_[FbXY:>RhbHZJ^Z/Kk;dMOPko_imoSel??dhKF8OXJ<
R6Y@DeIOKW^8T92FUhjDY;K8^ijR]KjcViNS[;S1]JZ`a]O@^:BLVI:BU8UhJf=H
FU]DB4=AEeQMHF1NI6aYHV5NGF=aN7b5RI6N[[NaZJNXYifDUXeeETI;B3X];CLf
:B@]@EUXJVMWLWekMXFY`L6VR96V[I]`CT59Cbd100LK8R8V<4=GEcdY=DYFDDIA
ETm?Ce5UQINLWIjU[kW3`kN/WH5`KVQA>30b;Rla;2dn@cD^<CHl@4I8AClg>DIC
IG9fOhfO]L?@e=?OgM3Afm>kZIZ;QX5mLem>BU9EEUmULX:=V9j[/:Fbj_oom]oN
g<^WOVI]NUlc92D`BF1dNVi^L6ERJ7AmMVIKFEmUI6I/OZBl_L7>fN7Vi^CKcKf[
XZJKQ79UGeaFEUUEBD58Cde9DV=OEEIIGF9TMI6GUINIXJjh_LSAbkZ_]LG0[jNK
Shj=PVY@Bde?EE]OHFn<V9NJWYVDZ=7dmmg1]kb/P6ERIElj2`0=7R@eATU4B40/
?VEoR8V7Q8NJYYbQ]lgRj=oHiOkjh]OGd/Ro_[fcW7iaJEmC?SHe;b/Z>D]DGfU[
KG5eOXfOZ:V/Zjnoc]CGf]WBblK7c<W1]JZQTH=hITdk>CPnATUFI721V::PZ;2c
^/kYmo3Kb<gA^HihOGQZDc0M7B4U;3Hf;b/R5Aa0G6=VJg9aL6mRI86LYJRW[;O8
eMWMf/o4^:ZUWi5hGEAJGU8n;Rhg>3Hi@DI0>C]1AD<nAEMRIf9VOY6GVj2Z/jfV
XiF8Ph><WIb9Qh^4OWanQiFIU9:CVj:_`/[7_[>hcN_mm^;Df<fJLFaaNVTe2`PK
;CY;Eei^OgagPI6Z_[jcYI^CQhNK/;Vf[k?4fnWRg=oJc[ZWWj:GN6ENHFeYGeYE
E5AJHFEZLFmSGF9ZMHB<UZBWXjJ][Zfc`/k7/J2PZ:bXX9JAS8N0Ng]hLFmbL75l
PH>>V9FGYJ^UXZF`_KVWWJRYNcdW?UQB;@@04A`L:D9<@T51>Sm?HFmfKfYfM5eB
EFMjO7YjNhN@SYRUXYZ>NG20RWeTC412Ad@g;c4[92`c=d5:CU1>C4iEGfabKfAF
Gg1iPHbDUiVKXZbb/ZVMThb1Lf]]K69DATURLgb2R9BMY:fZXjVkc^Sll^KZk^:j
Si2PW8=>:3E8A45;EUICF5IBHGV9TXb2PX5fIF1[NHbS[:nhb^KiooooooofhmkE
`JjHO6UMEE1<CT]1A51HF51<Cdm:A4M@H6e^M7f:V:B`_]7KeM3AcLBdZk>ZU8Z0
M6aTEde8@Cm6De]@CFMoPgekQiZ`c>SjnNWQeJYiLh5oJCdF2a4M9S12ACXi>30k
EfebIf5TKG=ZHFj8VIfQ]m?Xl^_Sin;Hb:jOWZ2KRg5LEUA@CDPl;b/Y;CXo?T99
BTU;EFIjSIjW[KW4b<g@d<o6^[^n^K>/Y9Z;Ng=_GTH`92HY:Blg?TUGIGRD[KZi
]KoHn?ooim3=d;RDNWEoM4l`8B0S92Ta:R0N61HV=Sm:Ce1LLX>3Nh6G]lg8`<WK
hmkMgmW@`k2UZ:JDNf1?DeI9<RH/=dA?Df1_Mgb2QXR9SIBLYjZX[K:e]kRi^;Ng
^kc2bl6aZij@QgieKFMPFem[MWf;U9JV^L76b]3Ff^;`ooooooofe:FATXYcBBDS
:B0N:SQ2A4A5CV9nSi>FUYVMV8n6RIZX[:bda=[_l_3_i=G;]j2CQG5G?RdR5aDD
4A@L92ljAUYZMgn5QGafMGn=V9jOWj2PX::SX9ZGT8b@Rg]`JVEOG6I]J5eBCE1J
HfQ]L79jRif[]kc0`lCAk_kcg/bgSF5DDe17:@d<3@`H<daEF5mKCeAXN7mnNGAc
KfIWNHN<TIBFX;:h/:j_Z9^FSX9nNg=WEdm=BDQ<DEQGCdeAFfE[KVi_KF]]KgAn
Qh^<SHV7Rh^@UiB?S8f@TY:?Qh1nOH69PfiQGV=WJW9lPh21T:>^[Jfd^Kg;e]SF
e=OB/85[KGQ`CBh[;c0^:cU5Adm?AT]TOXjCSHjIVhYlOhbFXjb_/kg1^l7Be]?9
/jJXZJ>HRWUVFUUNHFIPE5ELJWQmP8>4PWaiNgj8TYFIVY:BW::WYZBZ/kNf[J>M
UiBFV9RBRhEkMW9`MG=WI6n1Si:@SHV>UjC9j^k[inWV_hn4RXj0DS<e<cI8F6QX
G5iMF65bP8b>QWeiMfmYKgZ4QX29Vjbl_l3:b;b`WifWXYF4K69PDdDk=CH`8QlW
?EAFEeiOGV5YN8B:SHjBUi24OgakNGb5QGijM71^HeI<Ad4f<2hR61@I9cDh?U1Q
KgV9W:RY[;G;kOSVdm3Hcj^1K6Y/FSHL5A<A4QPJ4a<D41DX@UQUI69/N7QaM7n?
W:2PY;32dM[Qjo3]hMCAclJfXH]hKFEME4To=SQ0C5aTIVMYJf]/LG^5TIRM[Kbn
`m?Xn?S]iN7Vi]K6^ZJ?P7YfKF9PHVEXJg>1SIBL//K6_[fl`MCaooooo?ooo<fY
Y:JMOe@e;2TT9C4i=STn?TYPM7eoQ8N:Rh1cLgf?WZFX/L7Be<_>dl^lZ9J<QGAK
B4=5AD=1@4I<B4I<EfA/KFi`KFMWKWR3S96HX9jHVj2UYIb>QXV=RGacKf]VHUmI
CdY9BTU6ADmMJ6eeRj6]/[[8d=?VoooolN?RdZb8MG1W@adC51/S9S=1?dA4>S]3
CUULFeQFEU5=EV=eRiRQ[;O2b<O;d<[1^[Bb[In?Og1WHU]@@clo=c8d?UARH5mT
J6QZMHF=S8b@V9^IW:6V[K:^ZjZ/Zj>LThQkKVIRG5=ACTiGHfmlQXjI[<OEc/K2
_LKKk?Shk^c`h;B@R8f7Jd0W9RDU9cE8BDI9ATMJLhNCTXf>RX1gMH:BW9nPYKG9
dmo_m_?Xe<S7`[BOQfeJDTa2?TA7@T58E6=[KF]WHUU@DeaXLgb3TJ2[_<gDe]CA
blBl[Z6JT81[FEALGUA6>SPo@3i2C5UNHVmoR8^H[LGPn_oooooooo;4XIB@OEDc
:BX[;2T/;2Xa=3E4EEiMEeAJHf=JDeabS9jV/LCGi>SUhmkA_ZNHTHYnKF=NFe=;
AdI9BDI6ADYFGf9RGUUFDeUXM7^0Q8^?TYbRWI>:QXN3OG]mO7AVEe5CCd@h=C]6
C4eFJX6AUZ2ibLK3am3TmoKZelS9aJ1gF4]@?Q0000TB4aDM7RD_:RXiBeQNGUmX
N7miNh^Vam??dMc/m_?`knOKbK:UVHIcFdDg;bXV8bDZ;C<jA5ESJG5kQXb>TYbR
Y:NX[K:d`=3Bd=3>b/O;b/2f[9V7MVYWIF9LE59FH720RI:MZ[[6dmoQiOGooooo
o?ooi:MmLW1UAB8F61XO;45?E69ZHfMoVZNXX8n3P7MZJ7F7UYRIY[_:b<G=c/6a
X9RITXMkJ5]IG61NFV9ZJfYYL7f2P7n2OFiVJ6QTIFERH5iOJWIlOWahMg]nNgQj
O7]gMWUcIf5RHF5PG5mXKWN1T9^T/KRg`=7OjnKAb<c;/X1IAclj;A<62a<M8R/f
=d12=SY<Ff5TIVQ`LfUKGg63TIJHWJRc^;Jh_;Ja/:na[Ij:OgYdKVELEU99?SPi
@Ta@E61ZJ61OIFY^LW5_Kf][M86=UibT/Kc2a<O8aL>i[ZFNVi66OGEbLgQnQ8=n
PXjNXj>]_]CRgLc6dmg7WXV3Ph=_EU1ADUIKGf5UMGadMX6=UiJ8OWmkJEQIIG>0
PhJFZ[[6d=_TiN7HdmC>_jZCOFiUF4a8BDQ2@TI?GFI/KfeXHf5WKFiaMhBEX:F`
`Lg@cLc;b<Bi/:VJRG]cKfAJE4e7B4mIHFAZLG^4QY2OYZo>n_ooooooon^oZZ>A
JSTN6AXN9cM7CU5DD4aCIG5cL6YVIV5GCeIXO8^GXk;:fn3VkN[QdlBj/jbPSGYX
G5E;@Cdj;R4J7RP]<Se3ATM<DeeWLGUmQ8N4QXb?UIRETiBEShF0OWaiLVYPE4Hf
;Rl];SLk?DABJH:CX[O6f>gkooo]hn?I]XieKFI@=BDT7A<B6RLV8BHS7R@`@4eE
GVUeOh:8V[KAgnGYkO;gn?C_i=C;aKfeZiUoIDhg8A<<20800P`L;Sa7EfUgOhF=
VZVd][Bkb<oAdmKLhnCQfmG:_[FZVH=`I5Y=?2l_>D=DK7f9VJVlc]KOinc^m_oo
m>?UjMfjU7ieM6E?A44e:B/`>3e5CDQ8D5YWLG=fOh9gK6UbQYVPX:>]_/gGgMkJ
dLVl[jJIQW5NCD4k=C<e=CHlBEMRJW9iOG]bKG9hNg]iNH22QY:IX:V[Z:>LUI>>
PgAWHEmIDTi=CU9FIGMoP8NGY:R[];o7d^?foNgAa/o>ZgMCAc/P0000000000TG
93U8EVQkR8^8RHZ=S7iaM8FIYZNX//3;clg<aKNZW8j7NfYIC4@j<b`[<c/o@DIB
Hg9kPH^?SHV9SYBFTX^8R8AoOh>3PH23SIBGV9^OWYR@SHb6OgUfLfmcOhVATI2L
[;Jj_<OMk_Kfj=kSg;Z;KFAQFTXe;cHk@4]OKG>1Q7QgPhfCUYRHVIJ>Qh^IZ:f/
YZVc]kNg^K^i][>`/:nVUHMmKfAJCdY9Ad4m@TaHHfQ^NX60PXR=T96?RXJ1OWen
PX61QXbBUIVLViJ=PgegLViZIfY_MX>=UYnTZJjd^[^od^gklmc:c]FoUGIWHUU0
9b<V9b/d?T4oAdi>EVIeP8F4PhV9Og5ZLGb1PH:7VJbc/;2f^[jl^Kfo]::@Pg]f
KF1FD4U3ADaCF5iOG5I>AT=3@dE7ATYEFf5]N8B?Ui^PZ;2c/kBaZj2CRH1fJf=N
HF]dMG=gOhbASiNR/<3:cm;;`/[<[hAUEe949a0=61hJ9Sa6DFI_KgEjOH20P81m
LEeFHGF6SY>JYKcCgN3Qh=cEa;>]YYJ1K5mDBT<m?T90?T58E65/KVa/JfU[L7In
PGf0S9BGW:BZZZRXZk:h]K2`ZIjGTheoKfMWHf9YL75aNXJ>Uj>ba][^ooooo__l
ikVBPgicEST`<S<f@E5LG65ZIfYeNGUjN79/HE57AeAYMg]mR9ffaLkGgn?OeLk;
bL:h[JJMSWa_KfiRD4E2@D51A4M:BTU:C51FFeaKH6E]N8B@W:BQXZZa^Kno^k6V
VXf1MFIGCE5JGf=[N8ZLZ;>k`<gIjoookMkHdKRFO6eN@Q`2000000hO:SDk=cQ6
EFAcNGEbL6MLFF9bPHV=T9ba`lcAe]K?al2m^k2JPFaKBc`^91lM7R0W=D=EHVEZ
L79bMGMhNgYdL7=iOH>>W:N]/KFl_[^j^:nSV8alJeQ8ADiHGF5[NhnPY:Jb`m?X
oOoomo7^g;RLRh5_B28A3@P43AdZ<d99BEM]PY:IVINHTX1bLGV2QX9oR9ne`<gM
jO3_j^KVi=JoZiZ8MfMFBT0f;2LZ<cm?G69XKW9fO8>9Si2@U9JGVIbRYJ>QXj:M
UXn=RhElLf]TFU1<DeeUK7AoRiJP/LOHiOOooooooooomm>bVhQ/A28E5@l=628R
:38e?4eNL8BBTXj=RGe`KGJ4RXV8U:^j`<S@eMWHd/_6_:fOUX^0N71XHUaAB4Q;
CE=IGEeGCTQ7ATE3?d1:EUmWKgIlPXJ7R8^>TI:CT8^5OWEYFe5;D5iXJfmjQiBO
ZKS>gn[enO;VhM[2X8IaG4PX1`0000002a/^?TI<EV9^O8^@SHb6MfYUJWIoPXBB
Z[g4bmGOi>7Hdm76/I^:N6QKC3hd;BTW:S8mBEAJGfAYLGf6RXnCUIVLW9bOYjf_
[:RUXZ>UYjV/ZJ2FSGm/G5UPI6EVJWJ5UJNldnCfooooooooonO1XHagFSDH2PP4
1A8S=TIDG6EdPHfIWIZHUi>;NgElOg]bKWN7Si>OYjfc]K:a]K6VViB<QH1kMg1V
GEYIEeUPJ6YZJ6IZKFmeO7inNgE_JfebNX62P7enPhV>Shf;RXR5P7]fL6m`KVY^
NXF@Uif/a=ogoooooOSXbjjIQgEG;aD?40X?6bD]=3Ph@E9UMX64QXZ9OW5XJG9l
PH22TZ>XZ[6malW6a/[<a;N^Y9F:PgIYG4dn=C<d>DA<CeEKH6M/KW=jNWQgNgin
P822QHB5SYVKW:6WZJFRW9>7MVUWKG9aK7:5UYjS//[LjOWooo[^iM>bUX1^FSLC
000000DG9350ADMGJgZ7TifRYZJLTXn>RhV3OXBCX9jIW:BYZZZ`^/6n]:^VX9N?
Qge^FD@i=C@g@4U?EemYM7UiOX9oNgioOGb0Ph>4QXfHWYjOXjFUXinJSWa^HEQK
GeiQJgAmQI2O/lKNm_okl_?_eKNUUhU_B2XM610:4Q`S<ShoAEI[Oh^BVYnSWY68
QXN;QW]lRibPVIbY];Zg];Jj]k2[YIb@Qgm`H554>S4];cU3BeAOJFeaN829RhJ4
PX1kN7UlNGUoR92CTHn?THf5OWYbIeeEEUeRJ7>3UJ6/];kCiO_oooS/kn_@[iF0
Ke@X0`0000023aLU;cE2FW:6U9bTZZn[VHb8RHUmKgF8VIZGX:ji`l[=dmgLdlVn
/ZRKQg1UFdTj<bh/;Rl_>DI8BeIRK7AgNhB8Q8><TXn;SiNNWYbQZJfWWYZLV8^0
OGj2QH:0QiNQW9JQ[[_8f>[`in3Ui<ZYUi66IT0X7AH;1PdE7BP_=dEEJ7Z<W:fh
^;6XXIfMW967RiVSXZ:/_<>l]KFk_kV_[:JHQgU]H594=Rl^;S<oBU=QJ6Q^N8:9
SYBJWI^GWJRZXj6QX9nIUYVLViB?S8V2NGA`LG5]KWJ2SYBGX:^b]l?IkO;UfMWB
^in;Og5H>1`=1`@:7BL[<cU1DF5aRJ:_[JBOV8QlMgMfJ5YNLGj0Q9:S[Jb[[KBm
_[VcZif@PgIYFdXi;RLS92X_<cTo@TE<E5aRIFYcNgenQi6DU9BEV9bLWZ:TXY^H
V968OgeoPh5jMgV6TYBDVJ2V[[gFj>ORh^GLa:fRUH=YB2lL3@@63A0B6B4[>4QI
KGf:U9^PW8n7RHf=Ph68Si6>TZFe_<36c]CEd<c8`KBWW8n1MVICA3dl>cXl@4A7
Be9MI6YaLgIkOh22Ri>FUYJIWjFZ[[>d/kBe/:JNV9JIVIJCTiVMVYB?SY:ATIn_
^;F`/[BZU7ibJEXo:1dG51<M;30b?4YJIgB6W:ff_/G9b;jf/ZnTUI2DVYZHVijO
W9ZOYZ^^/;6`Z9fGTXYoLfADB48o@4=6B4Y:BDY>E5iYKVmcNH>?UYVKWJ2PX::U
YJ:OWYfJTXImNgYgLW1bMWf4QhN7QHB;U:6c_kZa/[JbVhAgL6iL?BTH3PhB6AlR
:30iAUEUN8VEXJV^[J>NWIbERXB0OWYdMg]hMWZ0RYBLX:6PW9><Qh1jM6aXHUeL
Gf9RGeaIEeEDEUaPI6U[Kg=kQ8N8RXb@UYZNY:VZ[K2_ZJ>MU9:BShjCW:2TZZjb
]KFb]K_7g>SWh=SJf<NeY9J<N6=CA3Td<cPj?457CUENK7^8TifX[ZfUViJET8f=
RXR7R8nEVYfNXJFY[kBe/jjZ[:nZWi:9PGEXGEM@ASlm?Cdl>d9=DUILI6a_M7j4
QXN:SYFJVIVNXjFTXj:PW9JASHR1OGU`JVabN7]kOHF;TYfV/;2YZJfaZI>5NfmT
D3``:2@Y<CPoAU5NJ7EmPhN<UInRWiVBShn:Og=]K71aM7^0QHVBWZFWYZZa/Zn]
[:bWWYB;PGM/IEiJF5A?DEMKGemQI6Q`NWn4QXR9Ri2FVj2RYJZXXijJUiB>Qh1h
Lg=dMG=bMgb1QHF6QXF6RiNT/KNe^/34_JVHT8Z4NF]QG5]IEUA@Bd]>DE5DG6=[
MGn:SHR3PWieJEmMGV=UIFMVHfEZMGf0PhR>UYZIVIbMViJ>QX1mO7akM79dMgUg
M7IgN7YoQXb=RXJ5QXF2O7EbM7UjNgj2Qhf?SH^:RHR5Q8R<S8R5R8Z6PhB5R8^B
X:V`^;g0`Kfm^[6ZY9fITXZ4O7A/IfETJ6e`Mh:<U9ROZ[>e[J6IUY>:OG=_KFi]
JfY/L7IkPH>4QhV;SY2>SHV5QHB1NgE`K6icMWAdNX>:SY2?T9:?RhV6PGimOWio
OWeoP7imOGUeL6m^JfUXJ6MXJFQXJFUZKG1cLg1_L7=gN7V2SY:DUIFJW9VBRHN7
QH=mMgEcLg=^JVQVIVASJG5dM7QnPX>1NWAcL6USHF=WJFITIV]bNH:5QHN<TYJD
THf:QhB2P7I^KFi^KFibM7AhO7anPHJ?U9RNY:V][jn]ZJ:MVY>9Ph1mNWUjNgeo
PXV=SY2ATiFFUIFFV9^JUYJFUi^JV9VHVifT[:fYYJBWZjRTW9JETXb3OWmoOWae
K6Q^MGb0PhJ6Qh^DWZ>QVYNFU8]oMg9/If=SI6ATIfmgNGUmPXR9QH>3PGeeLFm]
K6a`Mgb3RHjGW9RCTiBCUIRHU8n:QX1jMG=dMWIbL6maMGIdMGMgM79eN7IbM7Mn
PX>7RXb>TYRESX^:RXb:QXB4QXN6R8f?Si2=R89oOgagLg9eMFmYIfYaM7MmPXJ9
S8f;QX:2PX:0OWajOH22P7UfN7UeLgAbL6m`MGMbLWIjO7j0P8>5QH9mNGEbLFiZ
IV9RI6IWK7=hO7j3RH^<SXj@U9FBSY2BSHV:S8Z7Qh=nNgEdMGIgM7MkO823Q8ZB
V9VHUHj<R8>1NWEaLgMiO7j3RH^;SHf<Rhf?TIFKWYfKVIRHVYVIVi^HT8Z:RHJ5
Q85mMg5^KW5dMGIfO863Qh^9R8Z8PWinO7UfMWMfMG=`KVm`L7=gN7UlOWekO7n3
QXV>T9>GVYVGVIVIVINBS8F1OWn2Q85nQY6CUIbIVjJTWINGVYBAUiVFTi63NGYi
N8:1PXN0P8>5Rhn:RXB6RHJ3P821PH5lNWQjPHN6R8b=SI2@T9BHVYVKW9^HUYJD
THb4OWQ^IEmJFEYLFeULGUiNHF=VJFUXIVQ[KgEfMW9[IF5TI5mJGF9WJ6]aMGIg
MWEiNh27RXb:RXV5Ph:0OgUaJF=UI6=UHemKG6AVI6EVKG5bMG1`LWInPhN7PhB4
QhZ<T9>DUIB@S8F1Oh60Ogj2PhRDWJBY[:RX[:VSW92=RXJ0O7]nQ8R8R8>2PhN;
T9>KXZ6SXj:SWinQXJ>RWifMWijMVYF@RhF1OWioPH:3QHV<TI6=SHj;QhF6QhR3
OWYjNWAdM79aLWIkPHB4RHb:Q7j0Q8Z?TY:@SX^9RXAoNGAbK6QXIFEXK71bM7Eg
OH64QXR;S8b<SHb7PhJ0OgmnP8J8R8InOGamOWYiN7YlO7]mPhR;SI2@SXb;S8nB
SXR7QXN8R8R7R8V7QHB4RiFJW9>AThn8Q81jMW=_L79gMgYmOh64Q8R:RXZ<RHN6
Q8B7R8J4QXV;QhB0P7mjNGemNWQeMgUeLW9iO7ejN7Z0Q8J1PWYiMWYkNWEeLWAa
LG9^KFa_MgIfMGIiOhF6RXn<Rhb;R8b?Si:ARXB3PXJ5Q8:4QHJ5Rh^>RXB1PGei
MWEeN7=dMW]oOGA`K6iaLVi/K6mbMg^2R9:HVYfLWJ6QWinQXYnOWibJUI:<RHF3
OgmoOh60OG]eLW1^KVa[JVAWJVY_M7EhMGA]If=OHfUZJ6EVJ6UYJFijQX^BV9bO
XjV`/K2]YYjKVINGUY6=SHf9R8V:QXF0Ph:2PX1oO7j1NgQhNWadLFabNX62PHF8
QHR=Rhb;SHf?Rhj@TY6>TIFLWYnKVibHVIJFVI>:PX>3OgajOhF9QhJ5P822OW]k
NWMeN7]kNgUdLg5aL71`LgenP7imPHB6PWmnOh1mNWj2P8:6RHR9Q8=oNgMcKfma
KVe[K6acMgYhMGIgN7QjNh22PWihLfi]J6aXJfU^Kg5eMh1nPHN3Og]fLg=dMgId
LgQkN7QeMWQoOX25QhV<SHb=QhEmNW5]KW5fMGQfMgEjO7]oPhAoOWj0PhN:RhnF
U9>DUYNHWZ:VY:JXZZ^ZYjBQViVHUi6=RXF8SHN0OH63QXZ:RHZ;SI2BThf9RHZ7
QH:5QhZ=QXJ3PgmjMGElPHN:TI6FUYFCVI:DV9naZZVV[ZjYY:2JShEfKVQZIEaM
I6=SH69RIFUYIf]^LgElP8N:RH^:RX^<RHf<SI2CU8V4P7mkLFmhOX>8S8R;UINH
Thj7PGimNgQgM79bKfUTI6QVIF9WLGEnPHF4R8b:RXN7PgefLGAiNWUjN7YlNGUk
PH>9SHj@U9FGV9BDTi6;RhIoNWUjMG=`KfYWIVUZJVaZIFQ^KG9dO8:6Q8>3S92A
T9BBSHj?SHb=SXf=R8>0PhB8SXV?Thb7PX:8S8>0Oh:7QX>5P7U`LW=oK5QmRg1f
QGQhQhYoPHV4NgZ4OgJ5R7n5QX21P7ikO7j0QXj?TIJEUiRGUY6CUYJKW9R=QhF8
R8AlMG=gMW1_L6m_KFe]KFmaL7EmPH22PX>4Q8>1OGahMG=cLgInPXB4Ph:7S9JQ
Y:>PX9nUYJ6MVYB?T92?SHb9QX1oO7MiNGQhN7anP85nPhN9RHR5Q8:0PGmjNWUe
LgEdL71fN825QXfBUiNHUYBCTIBHVYVDUIJCSX^:SXj@U9FCSXJ3P81oNgUfLfm^
LGEgN7YfLW1_MgenO7QfMWIeMgb0P862Q8J7Rhj7Ph:2PH22QhF7QgmhO7elO7Uf
M79^K6]`NW]iNg]iMgUoQHF6OW^8P7AnMf]bLFa_Kg5kNgenP8V2R9B1QHmdMH5^
MGafNWelMg=fMg^3Ph>3P7n1Q8F6QXEoO7]kOGb1Q8B2P8B2PH>7SI2DU9>FTi6@
TIVMWIZETHn>Si2>SHj;RXJ0PhJ9Qh9nNg]kN7V0OW]oPXB6Ri2?SXn>Si:DUYVK
Ui:<QGigMG1[IVIYKFa/K6Y_M7^0PhV<TIRGUiF@RH5lN7YiMG5_LFmdMG=dM7Ef
NG]nQ820PHF7QXB1OG]kNGIhNh25QH:2OWQfLW1aNGn6RhZ7QhZ:RHZ<S8R5QhV=
T9:GVINDU9:ATHj:QhJ3PhJ8RX^?T8n>TYBCShb9RHb<RXB1NWAbL6m^Kg=gNGMi
OGn5RXnDUI:DV9VMViJCTHj>TY>ETXf8QHF2NgYhMWIgMgQhNG]gM7IeM79cM7Eg
N7YmQ8Z9Rhj:R8N7SIBBT8n;RHF0O7]jMg=cMGMfMgb3QHJ4Ogj3Q8J5OWQdKFUU
I6ERHV=TIfQ/LgIdLWAgN7]oQ8R8RX^:S8b8R8b@U9>DUIJFTh^5P7ilNgMbL71d
NWYgMGMgLg9dNGf1Ogj2PhJ7PWinOgikN7EdN7]kOWb1QX^>RXZ9RYBHUibOW9RE
TI6<S8b7P7inPX:5QHV?TIRIWIjLVifTXIRFThj>Shn>RhR5R8V<ShV5PgaiN7Me
LgAaKg9cL6maLgMjOGmnOGn4SXj<RhJ6RXf<T9FFW:6QXZ:OVYB@TI2;PWeiMG=`
LfaYLgQiMFm]KFY/KFabLg5/JVUZJfeaKfi]KW=eLgIkPXJ6Q8F;SY>KW9ZKUYNF
SXN0NGQcKFEQIf]]L7AiNgmjNGn3PgmnPX63QhR:PgenPHAmMG9bMG5/J65OGf5W
L7MkQ8nGV9NIVINMXZ2QX:2HUIJCSXf>R8B4PH5kL75jNWQgKW9fNgn5RYFMW9nP
YjFLV9VJU9:=R8V2P8N=Si28RI>@R8N7QXEjNGUdO7]gNgEkQWmgKg:0S8bATXjE
Vi2<U9VERHbHViJAUiV<Sh]fKfebKfU/KfaSJW5[J6aYHFU^JF]/K7=cLGR5S8N3
Qh^=VI:5QHj?Qgn2PX27QH:2Qhb5Q8^7QhR0Ng]eLW9ZJVecOWUcMgf0PH^ATI:G
UiBEV9RGW9N>T8b6PWAeQY>3IfQ[KGAmNG]hOI2?OX>6Qi66U9MmMGMkLW9iMFM/
Oh1lMGZ0RY1oMWMlSHUkNh:4NGA[L7AfOgI_O7]kN71jPWaiKfUbM7YiPI^PT7b1
U9R?RIJGSHR0QhEmPGMZKFYYL6UZNGQkPhbER7^ASHJHQhNPYiF:RhUkR8UbMGAi
LVa_QX5UMH=nLF]iP8j;NH^PWYZAPhbLUH^4RY><Q8JGWi1/OiFFT6UhVYZ1L7Qo
PHMmQXYlQIN9R8R2NgJ:Kdi9QWi^QeaLUYUaNf=_UI^HNYNIR::?I8FNPWnDT7ih
OjBEOXj8Rhf9SiB=QZJ9JHJJUWUoOYBIMGJ7ShZ5JFbJSfR1OH>5QY5dOIfRSH:C
WjFCN8fRPHJSN769VjN=J8ZGNH>@NfijZkbHWiN?WhnJRWY^Q7inWG1nSG9aKFej
NWZ7R:FKLhN;Uh5FL8IbQWmWL7b>NdeIPWF5O5n;RXjXQi:=S;2`PgjNRg6EYHmT
E75hTGAADEikKVUOGWj1HFYdFhNEGhNEKi24LX=[HXjIOF]PFfa]FVehG69iKFEj
P8=eIH>4IVieQIV0OhEbOI:=LeY`Zij5UfQSX[RHIgn=R9ZUZ:F7QI^TQg6FRe]/
RX]gHfI`Qh=nWh5_ZKV9PJ6`QXVMRY^VQi:EO7J6T7EJJWU`KfeUFG^VSgiKEHJY
[7Y_/kZ9PiFJ^jJ0W75PVhn@S6n9S6nLYV]SMi^=MG:9Nf9gS851@HJ0LhAcM7V5
REeRSHAmMgEgHG2XYh1fRkBNQj^OVZ6BTWaGJG]bKgV<N6^9UiRJVhjCV:6eVhRH
ZZ9aKWE]PgIIEeeeSXQ[OI21P8YlMiJLJI2]LEf6SiF5LGEdEGZT_;QkKHRW]jBJ
ShJHT81/LWQ]L5eSIU9OO7YUJY>NQVQTRX]_KGEEMHARHVEQKVQYSWIKNhfDWIN9
Rj>HTZFIQXQSIfelPVaIIHZ3O7n1T:J;KG>E[J9eHgNLTgJ0ESIQLViW?e:DU75^
PgeNPjN:PH9oMH5dJFm>Fg=[LGAmQh:5RY>TXH:AYi^[XHVLZiMkOfI[Qg^6QHJ?
MVNV^I6OXWn3VXUhSgUWQ7]OGW5WDGb=LVZ1Yij:Ti6MUGM_M8>CTiV8N8jh/9FX
X9Nlf/RXV/34[[F]U8ZDWX:1SiBFLVYiTXmmQ9n7MXj^ReE[Ph1nL5EVOYNMMF5S
PI:0Qj^TKW>>NH2FR6ehWYe^K9NCKgV3HeA]RhA[BdEbTiF9J6f6PhYlJWn4N9R;
MFb:WGAmPf>3Z8ihIFN5OG=VDfmT@5f:OW65NgB1NH>@PHJBT7QnSH=lRHijH6R6
QHR?OXIoHi2MM8JGLfElUhYhUI9WIH^IW8InRIN>KhRNSGB2UHR5RY2EO8ZBK6ii
K51KO7]iS9R<NG9TQYR<Rin]U9JKPXbWVjVPN8bUZKniUh:7XjVaYGAaWZU_IXnA
NX29GfNMUgnASFUbX9I`PYVBShe^FfanRgIiSG>1T6U`Qgf6MFb5JE]LHgi]DU]S
Nh1lKeINLW=aKeabTJ2@MH61PYF4L7UeJfaRIG]TGh5nFeUjPGF0S6]HJWUoRH5j
QhARKII_CW^LP7N0RgmbWjAbKG9/N7QaIGRJMf^;QX^QXi62R[beWjnRSWQfOh9h
MFYVP8jLYY>>XI6;Z9=_V[RDVjb9SJjNR8n?VIR:Wk6`XYRPVhV[aHm_OgnIZYN>
O7N7X:^ZV8:<UYVOYj2:Q8>3RH]oN85nJ5]GCU]/I4Pi<Bi8FfeSGg5fNhfIQgij
NfIEM7Q_JDiELhAnJf9^QX1VDe9RK6iKDF]SDgV3Gf]aAeJFZgaVOhB6Ti63LUi;
FibXQhF6LWF?Z:=lQ8f2ZK:@RhInTYJNXHF5SXNY/hanOYFj_IZDY9VN`/^/ThnE
YJjlZVYHIVAiPUHi@e5YNhN7J7^DUZ:JQFY@FW1gQi9oJGBNWX:BTh:CY[2aY9N=
TZ^^VXY/Ehc0/HmlN7BI`KZJTYbCRYRSVI1jGg2FVHiiEUQZNHEoKW5gM7a^I5=5
DfQeK69SJgjM/ZNOZ::QaMFeVXbCYiR>UgmZKg5LB3//;BDTA5UEDDiHN8RFWYbH
TZG6^9>BWj2KUX9VG6N3TGmbO863UjjaT7amLgnRW7n0NG5oPW1PIGj7N7AjOH62
Qhn;O7R3QXJ<Pf]]JW>RXWmiLgnEPGAYGeYKPiYgGgAjKg^;NVMdQ8nQ^/ZbVkG4
^kJZVXekKWb0JdT^?eUID48f>4igWibDV9jfb<WEdZFC/m35/JRBOXJDZ;><JX>Q
WI>FUYNHTY^QRX1^FF9^LUdo=EJ4Qg=WGV5eOX^QW7^3XZ:FTHilO7j=UH5VFeaE
G75jL6A?GHbALV]/GfZ=UHF9SIBY]/2_TY6EVZjWOVaQI7MfITHX;415BdPfAE<n
E8:;Qh9aN8F9VIN6T:VDPHn:K6=bRi:5PHFB[KJVZ:c3`Zbf]i^5O7f:PFYPMHYf
IFARFUASKFn3W91jRYnQVI>DVj:UZ[BUXKBh/:RLRWI`R9N<NfEYQXnSYWU_UInQ
/K>l^[?0]JNYW927P7=THFURCT4h@dHi>daOIU=<GW5^L9JMLFn=PW^3NFYJEFEZ
MGiVEfF1PgEcKVQnUhYoPh^<P75bPXE_E5acKf1RJ6IcTI^3Lg9[IWnFRgYgQi>J
ViBHS8bW]L2_SibXW9^Z/YA^NHA_LgATJgU/G7^GQWIfLWbJYYV1SK:h^[>PUHYo
MgYgM7AhQ89iNX5lOIJgXGMkPGA^N89hGfElOhR2KVaLFG>GYinQ[KRdXJ>^VHf<
V:^HMWV;ShEbL7MkUI^BXJBFS8fT/9QoMWagL7N5QGQ]I6IlP6YQDTaILWYUJ7Yi
K82:NG^2PGf1RWm[K8ZQXJfWUJ>NUYYlIFikMG=fNWegOiJGOg1iPhR?S81kQhM_
JW9aJeiUNH1/EfIcMW^1PH>0SYfETI6HX:b`XI:4M6IYLVm/I69NEeYVK6AFEfE_
JfI_OHJ@/;^RUYb@R89eOWMMEFEXIVicKfIXLfA;BeISKFAGHFA^OH>I[9:BVHjG
Yk6QRhfOXj>RUHEaL9VdXX22Z;6JRX^AV:F[[/>o/KS<clW5ZhEnUjV`[Yn8QHfI
YjJNV85oTH]jMWE[KGZ;R7QbLWb4MfU/NX29V9RJVHjAZ[b`RWn7LU=IMG]YFV5c
P7MQGUiEJhR9Je]SJF1SN75IEVAeQWITKgE_LGQnNWAoTI:DXjFQV92M[J20M8:@
UHI`JfelR8N3OF]VHV5ZLFIWMXFDRW^5TXj=SijSTX>2RHnBTH^:SXEoPg]kSX9Y
Jh23M79oQH9oLFj1T9^]WGb6WHn4Rh^1NW]kIU]fN5iHHW2<SGIiPXB3Rj>SV[6n
[8ilO7n6UiJ<PW5cM7MlMWE`JGZ1KVATJWV:Rg=MIgikM7R4SX9]HVV3W9V@SY:J
TWUdQIRHQi6LQgZ>THF5QX1^JhBHUH1YKX27P7mnIUMJHFilPWaeLW5cNWmhMH6B
Y;2aYJc2a;bgXXJ9WjJHP6]NFeAIIEi@ATA>DeAEDVJ0UYN:Q8:0PH>9Q7=`Lg=b
OI6ENFejP8V7Mg9iLVUbM6]TKg=NGW=`HfMgRIBRZjFZ_lO5_k2PWZRVWJ:ORHbQ
Vhf=SIJRXZBX[JJIVIbTZI^2KGBASFiZMGEkNGJ3Rh5cL7UmN7^3S9jKP7AkOhJ9
RhUcIG1eL7n>QhBFV8R:TYVLW9FGX9N;V9jASIJKS75_Qhf9QX9nNGIbJ6UREfE[
F5aTFEIRM7i^F6AgQY:CTINLUYV//9b>PW^1Q8R?SHElNWMWFUMHHfePG5aEIW]h
MFmIBUI]LVeZFeMRHFAcMWAeLg1XGV=/JficLG5fOGafNG^3RWQ^PI6;RI>HWJJ]
/kBVVIZLW:2Y[JNIUjFOT9NMT8nMYYjCT92CVZFSVHn4RinSWI67QHB=ThIhPXZ7
RhMjPYRMUI^YVX5oQXb6Mg^2OGn:UIN:OG]iMh21NGA]IF5SJfEJH7=oN6MGFfmi
PX^7R9FBRHR9SXI/FeiWKVELGeiPIUmQJVemRiFJUINOYJ^SUY27PHZLXhmcLGam
OGIPFfAQGF5^O8N@UI:?T8f<UIV?TI63OhB;UiJ?UIRNZZ2DUI2AUX^5Q8>5Ogn0
OH5jJfiiPh>2TinEQWj4SXV7RWe^LGf5Mem]RI2;Qi6SYjN/[:VOVZ>SThEeJFIY
OHf8N6]XJFf1S7ieMWV0PWj3SiNCSGmZIfmcLVe]IE5DKWQnRH9gOH^?R8B7QH=o
MGF2PgiiLGJ0PgmnQHfDVY:8Q828TXb0MfiWHV9WIFEUIfUSJGQbL7n@YJJMWYN=
TY^PSgR2Rh^HVHn=QXBDUheoJFYnRXMaGfEhQXAbHVEeQ7adPXV8RHb@VZJRUINI
R8>8OFUOI6MJD4mPLFi/L6]YKW>?ZjfRU8jKZ:ZTUhanMGQoR8nGWibAT9^[];B_
]LO=^9nPXinJPFU[L7UmKFMVHfM]LG9[FdmGJW9cNXF9Rhb>Si>=PI2XXYRESH^9
RibPUHb;RhV3OGimNh65NfaUJ6aeN7EiN7QoPh62RhegHV]dLgakJFA/NX9aIfma
MWenPH^9S9ZFRWijQHV>UHj1NgR1VJ>ETHmoMG=mSHE`Kgb=UhQiN7MeMW9XD4QQ
Jf=HB494DVQNAe=bOG5aNgmeLgn6Q7EaN75ZK7F1PhB8RHZAWZFITInZZZ>FRh1i
OX^IU8J=THF4Ph27RiRQWJ6VYjnf_<K4/j6HW:2PYJ:DSHV<RGQ^MhnNWYbDRH^>
SI:3KFa^KFi[LWQcOHZ>TY:FUhN0RXn<QGmhM6eNEeQ?C5IHE4Q5FFMbRHb6Rhb<
T8j=QG9]KfigL6Y`HUUYNh1lL7F:Vij=PHVCUYNLW8^1S9>ARG]eM75cNGaeJ765
Si2<RHZ<TINGSgn0Q7j5UYAnKG:8TIFIRWMnSY2>QXbMVY67NgQaLG^4T9>0LgYo
QYVXYYnMWIRBS8AcIFU^LG5SFVEbQiNDRX6D][f[W9^X/JVLSh9dLgf9T9JFQ75/
L71_L79cOHnDShR6QH5jM6QOFU]XLWIiLF]nSY2:P8NDW:2EPGN1THekM7=aIf1]
P8N4NgQgMhJFV8YjMgZ2S8IiKVe_KFmfMG9hPH5jMgN8V9B5L6M]KW>3QXAnOXZA
U:6/Z:2<QIBLUhR2QhbATXIcIgR6Q8V3NGMcJV9KEEERLgE`Kg9bMgQhNGEdLG9g
LVmhNW5lTIR9MgMkOYF]/JbIRiNV[ZN@Ogn<U8AiPhV5QXZ:QX9mOXRBVIZHSX67
U9:=Si2EY:bWVi23O825QWASHVmmP7ejMgn=UYR=PGikPI:IUiREQWZ4UIJBSi:I
VIFIWYZEUYR:KVMgRIF<MVUWJ6igNgUbMHBAUI6:R8Z:R8Z<OW9^IFA`OXZARWin
R8b4PhV=Ti65NGR3S8f@RgU_LGEdLg=/JW5aKW5aL7IeLgn;R7MWHEeOKGM^FTeA
EU5CHg5hOGAVHVUbNh5nMV]TKGQdJ6=TK7b8Ph>:S8Z:SI6BTiVFQGUlPX5gKWB0
PgafOiJVZJVZ[Zj^/[Bl^:FJVZ2OV9J;QH^:Qhb@RXV=TYZQWIBGUi2>SHEbFTa@
FUiFCDmROH9hOXbCVZ2PVi^HS8EkLF]NGFMZIfEQGf5SIg5iM6a`OX^9Qhb4L69W
NGYZH6IhQXV5PGYkQhjAV9bARH^9QHMoNX23PWioOWIfP96MV8n>T9BHW9R:PXRN
[:6>N6YbPhb;PGE^MX::T9BFW9f@RYFKVI>:QHAmM6ibNGioOH6:TYbZ/::FVj>V
XYfKSWimQh^0KfISJ6QSKWYnPhb<QXVCUYNIU96BU9JETiBCR7mgMXJEViRARXND
WiF:QX5mPG]YHV=OG65[LViXIfieMgf4RXnEWInDQgj1RHR:SGe/L7j=SX9kMW=f
NgiaHfQcNWUfLVUSJ7AeK6UbQH^9S92ASHjARhB1OGA_Ni6JSG]gNX2:SXV0P8J8
SHYoNgMiOh1nMWAiO85mL6agNVm^MgigJ6A]NH:6QgigOXN?SX=lO7n5R7aYHg1g
LW5gMg9gQI6@QX27Uj2RZ::=PHZHS7QeO8>7QhR;R8F6QHB7Rh=fLGb=U8b:V:>U
YjJLUI:FWI^@QXbFTXbDU8AiNhZDT8MlKFM_N7YbIFAdP7UeP8Z:QXJ?UIFLZ;6[
YJNOT8b@UYbMTWaZLHR>PGEeOX:4RH]oJFQoQg1MFV5YKg9jPWmoPXZ<PgYgOGmo
QXj?Rh60QX^=OfmYLH67OWMjNGV2R7a]IgF4RHZ5Lf9XNGU/I69/LfeXKgUgMh69
PGAaLgAeNX20NWIcLG=cLFMIEfElPWaoQY>QYJ:QX::VXYJ9PXF<SI2HV96:R96F
TiB?RXbDXZn[X:BZZ:>MUY2>SYBJUi>GUIBKXjVRS7n4Rh9aKVYTIVUSDdI5EVM[
LH:>RhB:V9bEQ7IhPXR3MW=hMW5aL6iYHV=YKfeYL7EeM75dMgI]Hf1MEE1@F6]h
P89kMgb4RXn>SHj8QHV>RX:4R8Z>Rh:2PGakOXRBUI6<RhZ7OWUnR8QoO7ikMG5^
JFM/KVibMX6;Ri:LWZ:OTi2ATYFESXJ4OWMlPhJ7R8V9RXAjNHB:SI2EWIb=PhN5
Q8B0PHB5RHb5Ngn>U9><Q820P7j6SHMnOXJ>TIJBR8ZAVinITHb9SiJKVi><Rhj:
Q8F1MW=jNW=]JfaTGFIaN7j4S9RRW8f6R8F0OX68RhB3RhQnLF9HFV=`Oh5kMh:D
WijARXR4OWelMWV4QXF0Mg1aKVIWKgQlNG^5T9JBS8V8UJ6JQganQH^=UIZ@OgQi
Mg9]Jg1fPH>1Ph>4N69DF5]OJg1hPhZ<RXJ5SiNGTXV7R8Z9PgadKG1fLFi/K7N1
S9>?SIJPXj6JUI:;P7UhNGb3QH:3QH9kO8N:Ri6FUiNN[;6/XXilPH^7NW5_MGn6
SIBDSXj;PGUmT9^JWZ>UXYRBShAjLViTF5URK79iPhfEWYjHTi2?SiJPWYJ@Tj2[
YIN6NWQdL6a[M7n:TiJDSX=jM6e[Kg1XGUURNXAlNXZHS79A<BDaC6j<VZ6NTi>F
TXEcIVI]M7YlQ9BRY9jHUX]cHf1SIfe/HEQMJVYIASTg@4iIHfE/PIJNVibPYZ:E
SXF1OgIfN7InR8F0PgedJF1YNHRGYJFNWIJ=RXJ9RXR>UIZITH^5Oh69RXbCW:^j
^[Fc[JJMThf7QHjP/k^j][6`[:NOUhUdJWNF[;BaXi9dFTXoAEIWM7^;WJ>VXIN;
MUi?ACm6EVA_MW^6S8N3Nf]SGEmbPX^FW:6KOei9@dmKHW1jPXZ@VYnKSGifKFES
JWR2R8V:SXj1J5QJJgQeJV=OIWR8S8V8QhAiKg5cNXR?ShV1Mg1fR9JIThf>SWm/
IV9PHVYhRIRMX9nERHJ9Qh:3R8^<TI>=PG]fJUM;FF]oSYROWIJ8OgQ`KFMYMWUn
SIbMTXV:T8n6Q7ifMWn:RY6JVIRJXZJKT92EUY:GYjRPUi2@S85kOhRDVI^PUhR5
R8UnIUI@Ce1AG6YmPh>EY;G4aKbe/9j4KFQ`K6]iQH=cIfedJU]SQJ2Y]L36`j^;
LF=OGfEXNX^5NfeODCljBe]LGgFF[JZVYYZBS8R7QhV;UIbQ[:ZPTh9mMg=iPHVB
T96@QG]bJEa:@4A;EVQ`M7ekMG9ePX^9Ph27U9>=QGaiLf]ZKVaSGUiVO9:NXYfH
U8j:Pgb1PGb0QH^8PXN9PGIfN7j8S92@S8bATY:BQGn6RI2AQGmoQ8^>Pg=]Mh>8
SY6GWj2PYjj]WHUoPXR8Qh9`J71oPH66QGYdPHfCUXn=W;2gZ9^LW9F8PH>3P7Yl
QHEgJVimRH^5OgUbKW1fP8AiKGN:Uib@P7IcNX60OG]lQX^7Ph1eJ6A^NWE^LGZ8
T9>?OgM_JFIZN81nNGAbLFQNFUULHfMXHeaNJ7B0QHN;SIBOWI>4OXF:SXf@UHUo
O7E^JVIKG7:8TI6@SXb@T8R0Q8EnMgN4RHN;SiJFRGU`NHJ=SY:KWZ6NUYbPW9>D
XZJSXJ6VZJZa[jNPU92FWIfET9>HUi2:RX^<RXV7NF][KFITJW=bGUANIFARJgj?
TXf;QG]fOHF6QHN5OGUgLV=HF5eZOX=mOhF7Og=/IfATKGf5QGmmPXV=S8EfJ6AV
IVY`KFa^KgEhLg9fPY2BQGj1P8:5QXV7Ogj9V9nOV8MlP8R6NFm^IUmSK79XGFQm
QHB4P868XK^k[j2IWIj?NgQjLF]/KgAgO823PH23OGMgO82;VYnNWj>MUYN;M6M_
NgaiMGJ4T8f5QXB2R8^6PHN=V:N^[::FSHN3PH>3RI:AQh:=Wj2FRX1nM6MRIF]c
OXfJViB8R96?Q8FBX:ZZYjRXYIbAQ7=_LViRIGInPXf?RH9nO7MaL71]Kh>BRh>1
OGYfKf=VLGF1SibKTHj:P824QHR7PGakPHZ>ShImMfUQIgEiMgb4QX1mMW1/HEM<
AT]0=3i?FUiPJW1WGUUFEUaaPHN?W:BSVY68OGMdL6m^L7b5Qh^>UIZLVHf3PGeg
OXfETiNSZ:^/XYNCThb6TI^NVYFHWIV=QX>3Pgn2T9F=T9^JPg1hQI:V[;K5gOWn
k]G5/7i4;SaBEE9HJGn8RXN5Pf]6;AdD51hhHHFEWZZb[Yn=OW9LCDiMLh:=U:2/
[:JLUY:;PWQbLg5ZIFj6WJZPSi2GV8imN7YaI5iIHW5eOY2RZJRVY:2LTH1iNWf4
RI2OZJj_[ZfYWXioMFmaLVm]L7Z4SYRNUhN0NgUaIFj>]>7oooooj/9g8@4@:RHX
CVAdU::R[Zj;E2<0000001<cCGVXbm[<[8YYE4DlBVAgR96GX:^`][o4a/6g[j>?
MEHl>TI@H7F5ThadI69XJF1BBTDm?TmUQ:_6cLViW7iREEIJGVb3UZc2clo4^[2P
UY27RXb9SXj;SYNPWYjRWI67P828TIVNViZU`O;ooookfKfJJ3XcC518A49KR::O
WZNVOd@L2`00004TCgnRa=oTg/^^Tg]TEUANIfmnS9NKV9^T[ZnQSX9`ESlc9AXP
?F1cO8J>UhUZFe]ICSlf=3]6DFB7/<cEe]G4Z8efHeIGI7R<UiZQYIfKWiZBR8>5
RXb7QY:OXjFTWi>7RIFGSWigPHR?X[SLooood;RgZ8A[JgAXD3T_BGV:Q865Pe/X
4A4A3A4M;D]XNHRFXZRVVi67MFINHFUaNHbKWInSZJNLSh1cLFeSDdA2BTe;DF9h
R96@Ri2>PVmKEE]XM7b=XZk0cmOKe<NeVhEeL7Z2RXnGXZ>UYib@R7U^I5QMJ6me
NGQjO7mhJ6UkQhF<U9NOYjZed_oooooScK:3ET9<HEiBD5]jWYj8QHQgFS8>008<
62a3IHjQYJnb/ZVBOViVJVmaNX^MZJn/ZZfh_JnHQ7I`JemFDE5DFV9ZMX66QhN6
QXAmN7]oOH>6Ph:3RiB?SY>>P7Z0QHN6PH:8RXV7R8V<RhN3Ph1jNGf3PH>=U968
QhR6PgemNW]nNgYnPY>jjoool<beUFa59BLn@cXY:4]lTiFN[ZN1CbDF6Q/R=4ej
X:bmd=gSe/>`VhanJ5E;BDeCDE9LJg^2PGafKf1:=B<O;Se1BF1bO8F9S9VTYZ6H
RX21P7YmRINZ`<c;`kfi[9=kL75bKViaMH2>UI>IZ;Bg[jJSWi^KXZjc];Rk][2Y
XifFVJB__<cXoookekbWR5lm<CQ2@3Pc?UaiQHV@UHY/C3Xe=3]8EFR3TIBHW9bF
ShUnLFeZHUU=@Ca0BUmjRI2@QWMdN71RETQ1@T93CF1hSYRPZJVSViJ?Pg]jO7en
Oh>?VYRFWJFWYJ2KUiZPY:BISX^:S8nAVZFQV9B@Rh^?Ti2@TXZ3PW]hOWecJVag
Pi[2jocXaJnNPf=3;c8k?cXb@6=iP8JEXIQoH4@i=S0a=dIVO8JEY[>h^KJ/WiVF
RWEODE5CE5e]O8F9RhZBWJ6MTX9aHEIIKXVMZjn]ZJ6KV9NFT8R2O7UiNh>;TI:B
TI2@Qh>6SinWWHj6PGimOhB8RHV6PGemOX64PWioPHB5PH64P820Oh6:Wl?^ooo`
dKFLOUe7@Te>@CTlCFZ1S9Z[/jJ6IDXj<RhhBVJ9XJb^[kFi/Z6ETH=`Fd<c<c]1
AUMcPhEiI5QGETi:BTE8D5U^RIbUYZJSUX9aJVQRFE5FHW:5UZ:SY:FMThEjLFEJ
EUUWLgIgNX29Si:HVYVKVYZU[K6b[:Z[YjFX[JZTXJ2GS8fK[/geoo_L`Zf?Je=;
C4m@Bd=9HW9aNI:Y/:>9KUiJFEULIH6N[;>ib=KBa;>QVi9nIeM?ASe5Ffj1TY:;
PWMgMfiUETLm=Sa:EfMhQI2IVi63Q8^9OW9bNGQgMgV2S928PhN7O6E>C5MNGfAa
Ngf2QX^CUI:CTi2AShj@U9>:OgMjQHj?SI2KYJBW_^?iiJn4NG5MA30hFFQVH69j
ShUmOi:SVWUC?d10<bm4KY^e`/gCg^3=/inESG]YFU5CEeeXMXfU[jRFRH9lM6MJ
CdQ3?dILLhB?X:jbZI>6PWabJfeiQXjFXJjf][:[WXf4P7YfOXfGW9R;PGUbJf1N
HfU`Oi6Q[kVm]Z6;N6URIFigPi:IXKK@looooM_0]9Q`BSHk@d4b935AJ6e^MhV>
OEXh;SLh=C]DP::a^Kk6c<FeYIZITgYKACi0@e1[Qj:bZYR@TiJ<OFaIACD^=4IR
PI^]];>XTgeaK69IE5UVLWf<X;Bl^kVd/JNAOG5^Kg9cKFQWKGZ5QX62Q8AoMfmW
J6ibNGekP8N<U9NFTXjDW:kGoooomm:o/95ZBD56@cHW:TYZMWj=Z/6oZHilN79V
FUeeTYfLVJ6`]:n_[jbYVGiR@b`M620Y?5UaQYR]`/VmWgMGAC8R7RY2FW6<ZL?>
c<S7`[>KQGYfKVMUJFeiQi2EUiJARXJ1N75]JVISIgB2S9JGU9ZOViF>PgEZIV=X
NXjQ][nf[:fc`]_eoooV_Z6?N5/n=Sm7@S<]?UEKDTmJIFEC=bHY<cDe?Uj9Y;2e
_<cHelfi[JZMRG=PEDa9CeYYMWUbK6icM6]NEE1>CT];EVA/KW5oTj6VZ:ZZY9b?
QH5oNWf1PhB=WZfh`/W:ak^^Y9jHTXMkMG1`MWMcLWAgNh24RHUmKVM/O8B7SiBG
VZC0g_WooooI]9n4ERXN;D57>cE;LHf<Q8bOYI1/BSH]8A@>7TIaRiJT^/c@a[J[
XiAmIeaIFEMEG6aoRi2<QXR=PW1TGeUCCTaGJgQnQIFTYjJY[Jn[VhQiL6e]L7Um
NGUlP8J8RHV4OgU_I69/NhJ<U:>/[:fd`/k>`[Zj/jFEPWAcNHRBTiFDTiNT^mge
l<fVShMiF34L8R<E104JAfE[L8RZ]ZJ2HeeSFd]8H8fcaL[>gNk/f/No_Zj8HDTl
<RPQ9R/gBTm?GG9jKV9OF5=CDe]bQhj<V;2l_Ko1`;JTU8^7R8Z;SiBFV9NDUiVH
U9>AQWETE4i<CeAKJW^7T9RPYJ:GQWelNGA/HfE_O8^BV:B^]Ko>hOOolm:j[ZJA
KEINJV5;>C]IMGQ`Lh69Nei6>3Hl>c8eCVYcKg67Y[>YV8nFVXacIVU^K6YYLh^S
[k2a^KVYTX1_FDTm>dQGGeeJI7J6RhnIWYV;NgA[Hf9SIVUcOhJ8T9fTZ:n`Y9J;
Ng=gO8:;TYNNZ;2mc]?=`[R`XY5oLfiWGUYLHV]cP9Zdd_3kk<jm_Jf2Dcdk@Cd[
9d1]Rh5fQYn]XH=ZHfIOBcm=KXbLWj[1dLnn[:RWUWAA@chh=Bh^@59JGf=ZMGE/
IVEVIF=PHg5oQ8N:U::UXZRk`[>UY:BPViVGU8n9QGmkO7QhNg]gKFAPH65THUaL
GeeOJgf:T9FIVIRJX:J[[:^_];BZZ;O<ho?nooo`cK6RSV/m6a0B40<042m?HFA/
PibEMV9MHEe>@de[R9RNZ/;IgmcGe=K@^Yj8OGUbJFEWLWMdNhF=RGEPETho;R@S
;Ca6BDmPMHRHYKBh[jFGSh^1M6IQIV]^L75lSINIWZ:MUi26OGQhMFm/LGUiMGV5
T9B@SY:FU8YoOGmmOX62PhNDZkoFl_kYb[R^VFm2;Rd_;b`_AFf?VInedMgB^JJH
QW9JB4]LKWUlQ9FTY9VBUYjGOV1>AC/b=3i@GV1OJ7^AVIJGWIfBR8B9V:6UZZZZ
ZjZVYjjaYHYZDdQ3>2PT;3U5CUMUN8N=UIjLTXZ0M6YTHF=]OHN<UZB`^;g0_kfi
[i^9QXjBRhVFXYnLYk[>h=RbR7AeJdHQ5b@b>3PmEGR=Si:Va<jgUX5iM6YJDEij
TiRATjFi_k^f^[f`T6mME4Pj;Rdi@dQAI7^<S8R=U964LVENGV1NGFIhR8nH[;o8
akfaYiR4LFAWLgUkPH^IYJjc]kJZUh9^GDm7Ae9PJg5gQIBIUiB>QGYbJfMWKgn<
TifX/K[9g??oooo/c;bbV7MXKFiPB2lT;ci3?dQSNh5cH5EACDDl?4aWN7]hOY6N
WijPZkF^UWi_HeE9C5]YK6elUjbg]kBe[if:N6aPCc`];3A6GgVBZ[_2^ZbQV9:8
N6aYIEiPJ75nS9NT/K>XXZ2GR7Q[IfijRHn@TYBEUIJAR8B5QGmiOH^IWIVFTY:J
YkkKl>S3WXj9MDlb;C4b:A`N=eYZJGFG_LVhYj2OVXYcJ7JBWifNZkRm]k2ZYjFH
NEiAASL[9B8L7R/nEW1mNh2?VIF=RH=lNGIgOhfT]Kc6cM7Hfm[C`k2FMEa@BT0d
;BljC5iWK6mbO8J8QHB3P866S8R9TIbTYjFTZk>aYIZMZ[:]Xj>[[:V``MW/l=^k
X8YW<@000000000;;EA[NXjY^JjKTHj8PGMTGWB?VIBAUY^NWJ2X[JN@LV5GBclf
<S8f=cU1Cf9aNXJEXJ>PW9VFRgiaJVmjPHJAWJRb];:cZYJ0JUaHFUaPIg9oRYBP
Zk>i^kZg/ZbWXi^@QGYhOXJ@WjV[YYnDQ7I]J69JF69aO8JP`^7elm[0/:JELeEB
FEE;?cHnGG^9V;K?dKRIQW]`IE=1@TiEDTY;EUePIgB4UIR;MV]YH4m3ADY:BU=U
OIBRZKFo^k:[YZR[YI^CSY:CRWmhMg9YGUUNIVEPH65SI6AYLWQeM7b=W:>]/;:e
/JZYZjRLT8AoP861P8B=TY><Ph>4O6eXJFQ[OI2SbO3om]k;a;NNMe0m?Sd`8R<i
FVmfOIBb]j22Kfe_I4/nD6mnPXRF[/;8b]7Ge<:SQGIUCSXa=S`n?d=;E5YKGFE]
JVE]O8^EVijRZ;2_Z:R/Z9nKUi>DUI2=T96=Qh5lOXF6PhB8R8B3Og5PFUeQHf5N
HF=PH6QcOhZBTiNIUiVIThj:R8N8Sj;3ioooonSAaKRQQFUICSPJ00003R4`BG2B
XIV>Si>GT7icM7UjMG9oUJBZ[[BbZ9^8LFAKDDQ6C55CFF1XM7MaKWAiMW9dNX63
Q8>5SIJIUiBCTiB@PgMaLFi/Jfe^Kg1cNH:;SY6MZk6c]KJd/k6_[:^[ZJJTXZ2Q
XZ6SXiZ=PgagMG=[GU98B5Io]M[Wg/o=e]:`PfYTGU50=D1NMgaoT[;4^Z:BRhAb
ESi0H7n5N75mS9BLYK:j]9MdJ65==2<O92`a<d5HLGn5SYFHU8Z8S8n9OW^4UInI
UIn//K6[WHakJEQ?CTm:@d54CEAKHfihNgQlQHjJZKFi]k6SU8^3NGEjN7=hPhF0
PHR<UYVCRhF6RY:P/LK;]j:NYZ:3GTe?Ddm3=SiIIUaHM9jf/::OXZ2DMe]GIgAc
KWVAZ;FlamKRglV/V8Q]BblS7aXJ93QGNI2NZK:`Y9F:Q7]ZFE5EHFebN8FFYZj^
[kFi/jZQTX1gL71eNh>8QH>4QHF7R8Z=U9bU[:ROV9RIUiB>RXAiKf=FC4M5@d]F
FVEjT[;Ak?oomNGHbkRLMemQJ6aUFEYVHDm9DVAfNGAbLg1RCT=1?chj<C=1F726
VZo4clS2`kbYT7EOCT<k=3E:H6I`Q9FMWZ2KT8IgJEY@CdU4B5IZOH^EW:6PWYnP
X9V?QXF3P8B:SHnBUiNIXJBU[KJh/:NLSH9oPHF9SI>IU8MlMG9dNh:0Q92N[;kE
lOoef/Bl/YI/DTi=BCdX9CYAF5EQQ:Rk^[Jg]:NALEUMJfYKE5aYLg^1SJFh]JNQ
YJ>;KemKFe8m:BTmA3i1D6=TG61ZNWmhMg^5TYFDVZRf_;bn`KjeYi^HU8E^Fde1
=cQ0CEiZLGIlPH9mO7UdLW9kQhfIY:ne];Nn`<6l[ZJWWhj:S8^AVZRca]>iTgn0
PFU6<C52AcHN62/l>SU:LIFOUhf;TI26O7f@WiF5OhJHXJBV[l34]Z2LXI^8M6QP
F4hl<C0h?CPoG7Z5RYFOZJVRVY2>Rh=lOHV>SY2>TYZLViRFU8n8Q89oPHN=TiJH
VI^OYJb_[:RXXIbMVH]mMgIdM7V2SiJCTINNUhj=QG=_NhbTa=;4ZINEUH5TEe]K
E4T_8SIBHVYnXknmZ9R8N6]G@SLmAdI3@dYIJG5dP9BLTX9oPWY[GEaSJg1aLgEl
PWn3Vjf]XINET8QkKfiZHeaCF6E[KF]XLganQ8fEVHn3OWQ`J6EYKWZ5Qi>U/<?B
f>7TgmSAblO6`KR/Wi21MgA]IfYYG5MTJFYiSJS8hnO?/jNTVWaPEeYODd<j@5M[
JFj?]<c>^jb]Z9AbFUQQH557CF1aNGn>Z<30[ib>PfiB>S0_;c4b?T]CFf=lXKB`
Zjjd]Jj/Zj:EQGeiNG]cJ6M/Kg1]L7Z1OG9]JVIQHVITHfEZLgb5Si:@TIRIUI^M
Uhj8P7YoPgeiMgAeO8B5RY6ASHZAX[gKjNgYi>kW^8=RF5]D?b`R8b<J5c9TUJb^
]JfHPEhk<Ca<DE1>FFajQ9:^dNSZh=cRekjTS7ijLfYSHFEREe9GGeiKHVQ[JeiE
EeUKGEmYNXV5QINQZ[Jj`;ni]jjKUi^FSHV:QWioQ8R?UI:7P8>8SXnESh66P7=a
LWMcKgIhNganOHRHUXnE[m3XloKPf^WL^HmbNGebI4`h;BHK3Aa5FeM>EFQ^IeY6
@e5KHV5IHFY/MH:F/L;2]JRQT75@>3<j>SDc>DeJHG69V9bIUinPW9J:OWE`I5MN
JG9kPXjPZZ^ZZjbXY:6FSXMeJ6AFBdU=HGR7TIfZ[Z^_]:n/ZJV^[jf/Z:VRV9NN
[;Vm/Z^UVIJS/;c=dkRGQX9fFd=1AD8l=2HR<dQAH8Fce^OVhM_A`JR7NWemN6aU
KGQhLg^@YZnXW9N?OFeJFe];?2i0CEMOH6emPg]hR8ZJUWf0RHImLW:6W8ieR9nP
Xk^e[;>VTH5dH5I:>SPd9A8=4`dD<4aTOjNi/kc0/IVATXAnOWicK7V2R929NhJU
ZjVohocoomc:clBFHTQ4?cho:A<A5QXK<EN5ZJV]cn7K`Z>HX:jYT867SHZ0PiBW
/Z^Z]lc;]9j:R8AXDTQBHFmjQ8fCT8bDWibHW9bITI6BTYbQW8f4QH21RiNLTY^Q
ThjKVHUoMW=hMVQYMX29S8JCW8n5RXZ5R92:MWN2QH1hMGEfOHN0PXB3QX6;XKC<
aJZ]]Jb9H4]2BeE4<2`]<R``BfF4UiBCTiNFR6aIGf5C>B8L:SDb=TMWOgQTEe14
=2/[;SDg=cDjAdY?CU=UI65_OHB3NWMlP7=]NH69THanOh^?R7f5QW]aI5aNGEIH
FVAWJgN1V;73c]7Eh]gBdLo9^[6]XYJAR7U_LWEiOXJ=TZ2]XJS8hO3el^CKgmNj
W8Z1O7=F>T5DF5YWQ:kAhM_Hgn;F/8EhOWUSFF1VIF9UL8NR_<c2`]CB^jFLWIj<
M6aYJWEiNXnOTX^GW9ROXiVAShamMh>BSXbFVJ2QVIjOWjZXWijOYJjYZJJGQGUj
O7iiPiBDUiZCT8j5O7E/K6iWGVASF5IHI7EiN7]mQXbN`M[QdKRV[Zf?LUi?Ac`L
0@073`hA;51YL6ihTYZ?Q79TJg9^FDiFDe5FIWZDZ;2ib]_Ec/>dYY=iGTi0<B8L
7R8W:2/nFV=VJfilSi^MVY65OgaiLVi[M7j8SXj:QH:0Og9_M6iWHFY`JFEWL7Uj
KfYeM6QOG5EEEUUUK6icOHB?VZBUW9ZLWK3=g^ONd<2YXin5J4U1@RlC00000PhN
@FV=Ui>N[K6[W8f:ShafFd]?E4iGI7:<Win?V:ba[jZRVi:4Je]KGUM7>S]6ATUH
IW=kOX1oR9RNW:>/ZJ:ESHN2P8VASHj?SHV8T8j:RhF3QHJDW96?Vjbg/kW6cM39
_JfPVIFDSHB7RhfM]<SAb[nj_<SMl?gli<c5^jZFMEiGDe8l7QTT;cU?L9[3e]GI
h]gFbjnKXj6>OG1/Kgj3RIV/_LBhZYZ9NF]XGDi;CDeDDU=KF6AgNX>K[;6e]KJm
a/c?c[bc/jZER8J0NGIjNWb3Q81gMh:6QG]/K75dLfeYLWUgPHb<Ti^FV9bOXI^C
TI>?RXnDU9F?PX21PHbS]/SFbKBXVh=P>AlD4Ph0000000LB:eN0U9jX[:bb/ij:
UYj9Mg1]KFYVK8NT/kB]/;RcXheoLem>@ST];2XQ9cE7DV=kRYFOXjZ`[ZJIU9F=
QXAnMW5]IUeEDTa;F6U^JFifOHR:QGioPX:2PXB5QXR7QHIoN89oNhJ8QXZ:RX^?
UYRERg]dN8B?V[K=akZb/KB[TWenPW5MAcDc=30dCgNDX:6QZ[:[W8YoMfYHB3Tj
@S/oDfIlT9NEW:>SXi^:O6mSFeA9@3`l@U9MHV]oUJ2[^[jl`KZQV9:5MVILF4i2
=c4i@dU=DUaQIW5hNgn8RXV<SHb>VJJb]:ZMSXB2OgaoP7]lOh5nQiVTZ:RSV9BG
VJ6_^lgLd/>j]:1gFEMJGem??c]2BTUENYRW/;>e^kR_VH:2R8f?QgelLEaLJ7B5
UYjOWZJQThj9P7emLF1JEDY5B4U<DV1fQI>X[[73dL^k/JbRVYJ8N6YKFfE[L7Il
QHfBVJbl_l2o/JFQThQmJf5PGUUHHVadPhbBVIZDUYVBT9BCRhR=Q869Rj7:j_[h
k^;>`/FZNfID@3HQ3@P52a@Q@f^4TIBFV9RNU823SHb8P7E`KVikR9RZ[JNW[K:]
XINCSX9_GUUFEUiLG6Q]JG63SY:LVYBPY9^DSY6HUXYkLGMkKVQaMG5bOHF;W:BF
UZ6UYjV/Zj:IU8j4NW=`L6eYL7elNH6;UYjV/[Rg]:fOTXnK/;oAk_oom_?dl=bf
TWiaFSlR3PP22aLN=V20RYJ__/;4_KRo`;JXUXEiLW=`Jg9iN7=cMgQiMVmbLF5A
E5eID4a:C55FF6AbOXbEUIZT[k6XXJJSUhn6Pg]^KFm/JW=oP7M_JfiaLWQoOh27
S8J1Q81_IVITIVIPGfA^LGF1RXV6RiJPYZJOUIFJWIjZb^W]elC5akNDLfAVIE8i
:AhJ7ALD:Ta]OGb4Uj^g][Jl_KN]W92@Rg]`LWZ1OW9/K6MLE5=:ADi@AD0m=S@h
@DQ@GFQbRYnOWjVa[ZJW[:FITY25NgA]JVMUJGAiNWn4S8QoOGaiKVUdN6iXI61S
K7R3PW^0QhF1NFe]JeiGG6AWK7ImOWQgPYN^_lRnYYZGTXI]I6]MAS@F0000000;
=eMVLWAkSIbRXjk3clZnZiB8PWQcMWQcJU]CDDa9AD=;F6Q]Kg=bJF9WIEIDH6]f
OWmmOhfMYk2f/ZJJU9::OW]dJ5YIGeeMIVabP8bBVIVCShj;QX>7SIFIVin[^Kfg
]kR`[kBg]ZbPV96AUI>=RY:R/L3Koooooogkk<ZTTHIhJTh[724Y9RaAOif^^/?:
clo6_l7;d<ViZZ6FQWUaKg9cLgImQ8J7R8V:Qh^?S8J3Q8F8QgmmPH1oPH64RXJ7
SiVSY9fJWIjLW9nRXIB2MVe[KW5cNh68TiVOYjf`[ZRRWIjPVHn:P7MgOX61QX^8
QHF7Rh^<R8F3OG^8VJ_:i>SOeM;B`ZR:NWASD30>1@D0000D=D]EGWRK/kc6cm;J
gLnjYiZ;MFANG5UDCdmLKGInPgmmPG]cJEiGEUMGFEaOIFidMgUmPXVBV9bHS85i
NGenQ8N9S8Z<RhJ8RhV8QH65Shn:R8V9R8^8PhZAS8F8Sh]oM6aUGUQDC4=2A55T
Lh24PhfO[/?NlOK/elg6/8ebJ5e>?R<=1PD300@K<TEGJXNR];fm_lWCem?4]ZnX
VXQkM6eOC4I=CTiDEfAhQ8J9TYVCPgQ`J5iEEUaMEe9IKGQlR9BIThf;QGidK6YU
H5Q?CUQRIfa`N7n6TiZLX9jHRhB9RhB1PhF3PXVAUIRJUYB@RX9nR92=SHf8SIRW
`Mkioooon_CWaiYgHdX]4`0000000b5<KXBGZKG0b<Bm_/:n]JbRWIfITHf@Thn0
Lg5^IF1MFU]JEU=DFeeFD4e>Ce=OJVe/JVYbOHF:TYn[[:^b^KRc/[:YTWQQBT4o
=S@i?TMDHg>1U:BY/;Zl]ZfQTXIkK5eIGV9XM7anQY>NZ;Bo_kJYXjbe^lG=f=S7
_lG5]IZ5Mf5A?1`10000000H<DEHKX:F[;g:e]kKcKNQU8IeJVUXIfQYK7N2QHZC
UXeoN7=^J61ECTm?CE5PKG9mSINR[KFe[JJPUHj:P7AaMgUkO7YhNGf1QHfDUi67
QHJ4QhjEW::Y[k6_ZJFOT81kMVeXHUQEF5aRMXb@SiJOYjfc`m;DcKBNW9fCNf1C
CTPl;2@T92H/=DILKWEhPI>S[;Bj_l?3`KJWWifGTHEhKf9EEUIFGVM/JfQWJG9l
PGmgLFeUFUMPJFQYKgb>W:Rf`<O4^:jXWY:8P7=TETe7ADA1@D]FFF1[MWanP861
RXn;Rhb@Ti6DV9VJViZGVIjNXJFTXJ6PUXnFY:noeNOam_;[hmBnXHAdI4dd6a8@
2@/C:4QUO9>[_L_Ac/c<clk4^ZnQVY21O7]jMfi]LgAdMgQcIUeOHV=WIfIYK6UX
L7b0OX:=TiFFVInTYjRXZZZTW9ZMWiZCRG]]HEM@CeAMJ7J5SI:MYJ^e^kZg/:NL
S81fK6QVIfa`MWf1RYZX[jfZ[:RSZkK2e>?Vh=KGfLN[Ui2=PG5NB3L]7a0D:3m<
F76:V:>XZ[?2aKb`XHenLF5CC4e=CeEHGVEYKG=mR8f9Q7mcJ5eGDe9CEEaTKGR1
R92IWIjRYZJTWI27Q85nOWahLfi_LG1aMGYoQhf>S8f@TIBFVIfOW9J<QXIiIUeE
BTU?DeMQJ6agR96ATIJP[l3Ag=[=`;bl/9EmMW1RCS<M50h810XK;Se6CeeXLgj8
T:2c_K^`YInEQgeoQhN1Oh9oMW1`KVMUIf]`LVi/KFYSFDm<DUIHG65TKWf9TIfZ
/[Vo_;NbYI>1L69FDEEGDDa>EV9^MGV0P7MeOHJ=UIFAUYN?RXF2PGj0PX20Oh23
Qhb@TY:9Q8jQ]L[Ig<nl]kFTRGIbKfIF>RHM4@H22AhgBeY]S:Jea];Fh>_Zgm2n
[Ij<NVm[J65FDEIGDU1@DeIHFUmVIUmOIV]`KfecNGQgOHF:SI2GYkJh]KZn_;bm
^;:[X961N6aMEE9<BDY<D5a_NhFEXjJW[KRo_kbg/:NSXIZBRX9jN7^1Qi6KWI^M
YJo3iOoooo?Th]k<]JJNTGiUBcPV4`T94BI1E5URMhjP[[c=fmoF`[6VT7Q]JVU/
J65SLGf5UjN//;:^Z:>IQgAUEdDc9bDV:B/_=T9>EV1ZMX>=UYnTZ:ZTVIB?Rh^8
QWmfM71ZJVicMGV7TIZZ/k:`];VeZjJNSWaYFDi4=b/R7ahL9SM2DFEcP9>^bMcW
i=?:c/fjVhQmK5]4<2@J40L:7S=3CEARMHFCWJF_^Kfk^:nPTH5dKfmZI61PIFQ/
Lgf6Q828TI6=S8QkK65FBTeCDEMXMGj?XZbd`/_>dM?AblBk/ZZOTH9fJU]?BDA4
AdaEGVEXJ6miQ92LY:JWZJNUYjbc^[^j]k2YY:>WZjZVXjBX[;S6cmGGdL:m_:jE
Mei=?30K1`0000005C57FVj4W;G9e]kQi^_]j]c<`K>TUXj9P7QfL6MVJ6YZJVa_
L79^I5U@BT<n@TE4@3m3BeENIg:2TYn^a]_TiNcdmNoPb[JTRg9PF59:B4Y=DUYS
JgJ8VjZb]kVg/jjRV9B@RH>1PH1oPH:6SY:@T9BN/<KHi_Cjnoooon[?_ZnNSG5F
?B0=00004b<cAUabQIJQZ;_DgM[B`[6HN61GF5]FEEeXKFmgQYBOYjRSVi>8O75Y
HUY@Ad8m>S/oB59JHFI/Lg^5SYBDTXn?TY>?RH5gK61AAT0l>3Tm@TQ@G6UiRYZY
];Zf[jbWVH^4O71UGUQHGUmPJG9dMW^4TJ6fa/_6^:VOT7YRDTe8>RXJ3@D20@D@
8C<nAUAVNH^L[/;DgnGTg]G8]jNOV8aoKemECdeFIGN8T9NQZJNLU8ejGd`o=c</
9bhnCU]/Q9^^`M3Pk_;]in3IdlRk/:FHQW5PE4e:B4U;C4iBE5UULWb2R8jEVibL
Xjjh^kbm^[FaZjJMTX^6P7f4TJ6ebMKKfMKCc;NIPW9LA2T8000000089d=JKH2E
Yk:i_LC;c/o:`;NZW929QX=mM6QJDDiAEUaQHVAXJfe^KVi[IV5NFeYHEUMJGF1Q
I6UaOXnP[KNm`<WCf=71/9j=Mee<@cP^:2Xe@TmMK7b>X[G1aLK3^ZbRViRJUi>@
Rh^@UYfRYjZXXifDUJ:`_/[<b/kAajfT[:fWUWm]FD@`7Q`Y>dUEIW^;U9fY^loQ
k>SJb[RNPfmRF59?BTE;F6MfQYNS[KRm^;>ZVhQeIUY>AdE5AdY?DeMNIF]bMgf4
RHnBTiNLXZNZ[:bYYIfBRhN0MfiUGUQFF5]OIg5mRIFOY:JYYinHThUeHUM<?S<a
=dIII6n1T:2icMKJg^?NaJF@QX1dH4lm;1d;0@894aPK9C8nATiIKHJN/;c3a/Bm
/J>IU8n5M6MRGeiPIg=oQi6IXZ^b]KF_W8MgJea?BD8i=34d@eadRZ6gam;OjNoa
l>SKbkb/Vhf0MFUNEe1;C51CEEUOJ7AoQhjBUIZQZK2h_l;2_;Nf];2[XiV=QhF8
UZ^ncMKMi^kVck^]VXI_DC<G0`0000002AdbBfElSj6ie_7oooo`gljkZI^FTh]l
Kf][JFAQIg5eM7AeMG1VG5EBCdQ3@d=4ADI:CEAQK75fNhB@W:Rc^lG>e=WKfL^_
U8AeH4m3=RXR82<`A5MXNHNAW:R^/:j[Z::LV9FCSX^<SY2BV9nRXZBY/[o:blG1
a<6[T8N9S8b6Og9QCcX];3I6D5=IHfmjP8NCYKcCfmSIf/baWIRAQWe]G5A>AdMA
HgZ>VYjSZJbYXIB6NFEAAD10@413BE=LIG5kPXN?UifOWIbLUX^5Q8F3PX60OWek
MgIfLFYRGV9YLW]nPHB8SIBLYJfc[ij<QX5cJ69LD4A0AEAWNY>TYjZgal>^X9VA
QW=NBCLW4`H73aTP9RliA51HFVAhSZ2WY9nLUXj8RHjFVYJ>RHJ3OWUiO7moO7Yl
Oh20OWf3S8f2KUiGD4@n@DQ<B4E<HGZ:VjnlaM7Mi^OUhm_>^jRKTXUnM6USGEME
FVAZL7AhO7emOWn0Q8jIWZ6UY:6PXjNYZ:BSYjje`]3HfmoRe;^`[jbWWXmeEdDb
6@P;51H>3AP]@e9MMI:[_LO:blW2^:bRWYnUXiJ<SI6=QHNIZZjYYJ6JTH5_HUI8
>c8/:Rhe>3U0CeiZM8>AW:2MViZPZJb/[:b/[JbZYIV;PH1jKfYWGE12?4AAG6=]
MWQjOhVBUi^LViVFUIVLW9jOY:V[]LCFgmgLg]g:[IZAQW]`IUmIDdHj>4=BFUmT
KWQoP7j3SifVZ:FW[[2/ZZjd][6]Z::LUi>8OGb4Rhb<Ri2AQgYaLG=bKfe^Jf9F
D55FG6=ZLWZ2RY2ASi2EV9F@TI6<QX61QhfAU9NFShJ1P81oNW=]IV1MHFAVJ6U_
NHJEXJFRWiVCTHj9QGmhLWZ;V:>`_KfYTHbATXUkLFMIAC8U8B<S71HG7RLa>D5<
GW=nP8>:S85cKW1dNX66SIBIVIFDVjN^[:JSWi^APgI]J6ANFEYNGEI<ADA8BTQ8
Bde?DE=JJGj>VZFa_LO=d]SLelZj/JbUVHn<RhIoOGn1P7eiMgA]IfQ^Kf]ZJVY_
Mgn;TiFLY[?5enCVh^?Uf/:`YYjGSHB0Q8^5M6ING5aGD59JGUUAC4iKK75_MHB>
SHN6T9RKVibPYJ:JTY2GXJZ`]KRg/Z^RUXR0NfmQF5MHEUAEFEmSHf9SJW=hNGMf
N7YjMWIjO7]iOHRFXZN[/K6WWYRCSXAhKVYYJVmgOX:7S8j@T96DUI>@Si6BShb<
SHj>T9FJWZ>VYIfARXN4NVeVIVIUHV9WKgMlOX>=UibJUiVMX:6PXJBRVHj:S8j=
SHf:OgA`Kf]TG5EAC4M9DUYMHfihPHZBV9^KViZGTXb9RXb<R8B4QH5lNgakN7Ed
Lg9bM7EaKVi`L6i_LWIhN7^2Ri2AT8f:Pg]eM7EeM7EfMWQnQ8=lNGj2O7IeMG=_
JVU^Lg9bN7n4QHB8SY6=Q7ehLfm/JFETI6EWJg1cLW1_Kg1dNX23Q89mNGb1Q8J6
QXR9RXb@UYVGShEnN7=aLWAhOh:3PhB5PgaeLfmXHUeGDTi9B4iHHg5nR9:OZ[6e
^l;8al:l^;J`YYbIW9bFT8j:QH1jLfi]JfIPGEaKFEe[NH::TYNNYZZZZZf[Z:RZ
[:ja/:n_/[>a/K6]XiZDSHEoNWE`JF5OI6iiQ8jCUifSYZNVYjRRUXb9QX5mN7Ei
OGakNW]mOGajNgf0Q8B1P7mlN7QjOGemOGafKfMQFE5?DEILGf=[Lg^0R9>JViF9
PX1kMG9dMWEbLG=iOWn2R8f@TYBJWY^DShb9RHZ<S8b:RHV6QX^ATY>BShf<RHJ5
P7UeMg]oPhN;T9>GWZBWZ:Z[[K6d]KB_ZJJVYJ:NWZ6QUhV0OGEYGEEDEU9=D5YP
HfQ^M7b4RXnBTi:@S8V8RHV9Q7]dKVISIfebMGEbL6e[JVYXJFeaLW9bLWEgN7Z0
QHJ6Q7mjMFiXIF9PHF=VJ6UZL7EdLWIkO7anOWalNWIiP861QXb?U9^NWYV@QGU]
HeeJF5ECDeIIGFE_N827RXb>T8j9QXF4QHB1OGb0QXV;TijUYjBMUHf7P7UgMgIf
MWQjOXB8RHV6QhN0M6eXHUaFEUeWKG1fOXN@U9RPZK2f]kJc[ZFKT8InNgYhNGYg
LFi[J6IVI5iIEeADFVA/LWR0QhbFX:R/[:na[jf/[Jn^ZJFVZ:RVZJnc[J>KTH1a
J6=QGeiQK7V1R9>NZ;6g^kbi];2XWiREUI6;QXB8RHJ7RXZ7QHB5RHb?TY6@T92<
Qh=oP8>5Q8:0Ng=ZIfUZIfMZKFe/JfaaNX>:T8n9QXJ3OgekN7MbKF]]K6]^LgMo
QHR8QX9oNgIbLWEdL6e[KG5dN7n5QhN:S8^9QX>2OgalO7ajNW]nP865RXf@TiRM
XZV^[jj][:RSXZ>UYJ>KSX9kLfMLF5ICD55EG6=VIfaeOH>9TIVLVibKUXj>T8f5
OGMcKfiaNH67R8J5QX=kM71^L7=cL71`L75cMWb4Rhj>RhR4OgYgM79_JfY[KW=g
NW]iN7QcKFYWHf1MG69/LGEmQHN6QhN:RhR2OGQcKf]WI6=SIFAQGf1SJ6aaN826
RX^:RHV9RHZ8QHB5QhbCVZ>[/K:^Z:6LV9><QhF6QXF7Rhn@RhV9Q7agLfaRF55@
E5UPJgR4SiZV/[_1a/S7a<6o^k>[Z:RWXj6OW9F;OgA/IE]CD4a6@T=4AdiHH6I]
LWN0RiBKXj^_[Zb][ZZWYjNVZ:f^ZJFQWIB8OGE]HUE9ATY>DeURJG5iPhbAUIRH
UIBFU8n8P7]kO7aoQXb?T96CU96=S8^9QH5mO7enOX62P7moOGMbKfe[Jfe`LG1a
M7IiOXJ@VIfIU9>?QX60PGmiMGAeLg5dNWj3R8jGWZ2OWijNWj6QWINBSXV3P862
P7ilNg]lOX:8SHf>Shn=RhV6PWimPHF8RHb?TYNLX::RXjBVZJ^[[:ZUW9RFSXJ0
Mg1/J6EYKW5bLg=`K6a^M7b3QH>1P820PhB4Ph5lLfYXJV]ZJfi^JfMWJW1fOHB:
Si:BTHj9QHB2Og]hMW5]KW1aLWAeM79dN7YlOGelOG]hNW]iMW=_KVi]L7MjNGUj
OH63PH:5QhR6QXAkM7=`K6QUHE]GEeMJHFMYKWR3RHbBUYFBShf9QhJ4P823QXR:
S8f<SY2?SHjBUIJGThZ2O7E^K6aXI69OFeUIFU]MGV5WKWR3RY6HX:J[[Zn^ZZJR
WY^GThn<Qh1iM6mYI61KEEAFF5aUKW=fNgioP8>8SYBFU92?TI:EVIbLVYNFUIJJ
WYbHUYJ@QW]bKFe]JVU]LgUmQHjJYJja/:f/[:^YYZ6KUXn6P7ioOh>6QhN8RHZ:
R8N8Rhf=SHn@S8N5QXR:RXN3OGQgMWEeMgQjOX>4QXf@SY2CTXj>RX9kMg5ZJFa^
LG=eNGn6SI6DUIJET8^9QGeiN7MiNgamP8F6QHF6R8R8QX9oP8:1Oh63Ph61PH>6
QX:0PHB6PgimP8:5RHfDWZFVY::PWYVCSXR2OG=WH61OGVE`MGUmOgn0QH^?U9RG
Ti6@SX^9QX1kO7moOWenOGamOGUcKVYVIVY^LGMoQ8N;SHb:RXZ7Q89nMg=bL71c
MGAeNW]jNg]iN7QgMWA_JfaaN7n4R8Z<SHnAT8^7QXB0Oh1nN79_K6YYJ6MYJfYS
GEaMG5iQHfM_N7]nPXJ8RXZ=T9>CShR7S92@SHb=T9>DTHn@U9NET8b4O7QdLG9d
LFe]L7=fNGUjO826Rhj?SHf?TiNJW9fLViZIUiFCU9BBSh^7PgegLg=cLFm_L6i[
KG9dMG^1PhR=Si>JWijMWYjMWZ6QWinPXInLV9BASHR7QXF1NgEdMgYkOGinOh20
PXJ:T9JKWjBWYj>MUi:<Q7ahMWAdMGQnPX=oNGEcMW^0PhB2OgamP8B6QhJ7R8F1
OG]iMWEdLG1bLW1aLg9cMWMhNgenOginPH>3PX9oOGimOhB:S8b=Si2?SHV3O7Ib
L7AjOX21PhB7RH^;RXZ;RhV9Rhb<SXn?TI>EUiNEUIRJViVDSXj?SHb=S8b<RXV9
S8j>RhN4PX1lMFm]Kg5cMWb3R8b>SXnBUIJEU9>ASXV0N7AcLgAgNWelNGQiNW]l
NWEcKVUXJVidN7]mOX24QXF5QXB2Ph:0OGMbKfYUHUmNGUeKFeeMGUmNGEiPIFY_
MWf1Q8V?U9RIUY6<Qh9mNWIaJVMXIfIXK6i_KV]VI6EUI6M[KFi`MGYmPXJ6QHF8
S8j@TI6CUIRIV9NDShb;R8>0OginOgikMW1YIFATIFM/LgIfNWj3R8jEVYjQXJ2M
ViVIVijOWYfIUYFEUiVIU8j7OG9^K6URFeIDE5AFG6AZK6iaMGZ1RY6GVYbMWI^J
WJ:VYjFRX9fIUiVLViREShEmNWf2QH=nNGMhNWj5Rh^9R8N7Ri>LX::TYJ>MUiBC
U9BCTY6@S8N4PX>6RXb9Q81nO7]lOGioOh24QhR6Q8B5Q8>2Ogj0QHV:RhV6QHF5
QH9oOGYjO7n2R8jAT8^7Q81lO7f1QHF1Ogn2Q8B5R8^=T9:BTi>CTHj?T92=S8f>
Si2>S8Z7PWmmOh:5QHN8RXR6QHN<TI>DUIJETi6?Shn@SHInMgAbKf]YJVi`LWEj
PH:0OG]jNWUhN7MeLFaZK79hOhF:S8f<S8^=Shf8Q85oOgilNWQgMgIhNGQfMGEe
MWMgN7YlO7amO7UcKF]ZJVa]KVm^K6Y[Kg=iP8F:T9FHVYVIVIF<PWeiN7IcL6aZ
IV5PHfIZKWAiNgQdL6e]L7AfMgEdMgj7TIZPXI^DTI:BT8b:RhV6QXN:RhN0OX1o
NgMcL6i[IF1MGEePHfUcOHB7RX^>TiRJVYVFT8Z4O7IdM7IjP8F:SHnDV9ZJVYVF
THb6P7YbJF9RHV9QHVIZK6mcMGIjPHJ;T9BEUYZLWZ:TXZ2PXJ6OW9VFU9BCTHn=
Rhb<SHb9QhN7Q85mNWMgN7UlP8B7Ri2GVYZIUY:@Shj=Shn<QX1kMg=bLgMmPhB4
Q8:1P7n0PXF4Ph5mNWMgN7YjN7QhNgalNg]iMgIgMgA_K6Y[L7EjOX>5QXV:RHN3
Oh22P7ahLg9eNGf1QHN9S92BT8n?T8n>S8Z6Ph61PXF8RhjBUINHVIJDU9FEU92:
R8V;S92FVIVGUYJIVibNX:2NVI:;R8R:RHV;T96;PW]gMGIgMgEcL6URHVQ_M7Mh
NhF?TY:EVYnMUi:@SX^8QhJ7QH1lOGmnNG=]JVMUHf=TI6=QHFEYJfUWJFaaLW1]
JVIRGeiOHVAWK71cMW^0PhF7RHR5P7n1Q8=nMW1[J6Q[KW5`KVaZIfIWJ6UZK6]Z
K75eMg]nOh:6R8Z<S8V6QhV:S8j?Si6EUiVKWj2OW9VET8Z4Og]fLVi/KG5dMgf4
RXjBUYVMWYfKVIRCShf<SHn@SXf=SH^7QXN9Rhb>TI6=QGiiNGYjNW]nP862PX:1
P7inOh>6RHZ9R8R8QhV;S8jBUIFASHV6Ph1mNg]kO7j1Ph=oOX21PX:2PH61PH1o
OWn1Q8J7QhJ6RHjDVI^JVINCShb<RhN2Ogn0P7mmOX20PH>7SI>HUi6=S8b>TYRM
XZJZ[JbWX9ZFTH^4P7aeL6i_LWIjO7j3RXj=RHJ6R8Z8PgaiNgeoP8>4QhZ?TiRO
Y:>PWIbKUH^4PX:1OGYkOH21PX>3PX1lNGMeKfUUIFU/K6]/L7EjOhB9S8f<RXJ0
NgQdLW9eN7YkOGn0P7mnP860OgejMgA`K6QVIfY_M7UmPH>4QX^?T92?SXf<RXR6
Ph:4QhN5PWmnOWimNgM`K6a]L75`LG=eMgQhMWEcLFi/Jf]/K6ebMg]lNgj3R8f>
SHf=SHZ7Q81lNWMeMWYnOWioPXF4PG]hNGUgM7AfMgEbLgEiO7j0P861OWYjNGId
M7IgMgA_JfY/Kg9dLg=cLW5`LWEeMWMjO7inNgYmQHb@TY>EUiRHUI6<QhB1Ogeh
LVeZJFU[L7AjPHN<SHb9QXN:SHj<Rh^<TIBFV9^LViRDTY:BTY6ATiNJW9bOXZFU
XYfKW9fLVYVLWj:SXj6OW9NDTY2?T9FKWYfKVYVGUYFCSXR0NWUiNWYkO7]iM6m^
KVi^KFi^KFQTHV1OGE]MGf=VJ6YZIf1NHFAVJFecN7j2Q8B2OginOWagLVm^KVmb
Mg]mOh22PhB5R8^@U9JDTi:@Shj=S8V6Q8F9S8j?Shf<S8jBV9fOXJ6PWIbOY:RX
Z:NVXinNWYnNVI>>RhZ8R8V;SHf=T9FKX:>RX9jKUY:=RhbAUYRHV9^LViVHVYbH
T8Z9R8AkM7=dL6QTIFMVH5aNI6U/L7IjNWMdLVm/JFU]L71_Kg1_K6QVIVMWJ6a`
LG1/JV]^L75aLG5`K6MUIVY]KfmaMGUhMWIiOX20P8>7S8j=RXN5QHB2P7moP821
PH1oOWakNgYhMgIhNGYmPHB6R8R8R8R:S8b:R8J6QXN8RX^:RHN4PX>9SY2?RH=n
O7YiNh26QX9kMgMiNGUkP8:1O7aoPWiiMWMgM6m/KFeWGUQGF5QHFf5UIfIVIfY]
KW1dN7UjNGQlOh64RHnAShb;SI6DUIFEUYB@T96BTI6CUIRJW9nSYJNWYZBRXJ6R
XjBSXj:QXJ6RY:FWZJVUX9bIUY:>RXV9RXZ:RX^<S8Z9RH^<SXn=R8=mNGYoQXjE
VIVGU9:CV9jRY:6NWYnMV9BEV9RBS8R6Q7mhMWUkNGAcLg9_JfYZK6e]L7=gMgEd
Lg5[IF9SIVUYJFY/K6a`MWb1Q8N8R8R7QhV:RHF1OginOWn1PH1kMgIfMgIgNWn4
QhN8RhnATHn>SHb9QXB2PGmnOGj0PX:1PX>3QHN7QhJ5PgiiMgIgMgMfM7=aKfi_
LgZ2Qh^>Shj=SY6EVYnOW9J>QgmiMGAcLG1aN7j2Q8R;RXEoNgYhM71^Kg1^JVU[
KVi^L71_K6Y^M7QeKVUVI61KEUEFE51=CU1ADE=FFemQHV9RI6M[LGMlO7YkOXB8
Rhj>S8R4PX20PH:3QHR=TI>BTYFGV9RHUiB?RHB1PH>6Ri2DUiZLWInQXj:PWibK
Vi^KVIJDTi:?RXJ2P7agMGEgN7UjNganPhR?UifPXjFVYJ>RXj2ITHb<Si:AT9:F
VIZJVINDShZ7QXF1NWIdLVm[JVY/KFe`MW]lNGUkNWIaL71dMWAaL75`KViaMgao
OGYfMGAdMgUiLfe[K79jPXR:RHJ1OgalOX23Q8F4Q8J7RHZ=TiRIUiFEUYBASi6D
UYRGUiVKW9bLVYRDTHn>Si6CUIJFUIBCU9FCTi:BT8j?TiJGUY>AShf<Rhb?TYJJ
W9fNWj:SWiVFUiZKUHf7Q89oO7]lP7mkNG]nOgimOGaiMGAfN7QeLg9cLFYVIVa_
KVa[K6i_L7AkPhJ5Ph60OGQbKVa[JVa^L71_L7=iOGn1PX:3Q8F6QXN:S8b:R8F3
P7agLg9dMWUlPHJ8Q85oPH>2P7mnO7QdL71`KVa]LWMiNgj0P864R8^>Shb8Q81m
NWUiNWYiNGUjNGQhNWj1PhF6QH>2QHN6PG]kP8:3QHF6Q85nO7UfLW1aMWUlO7j0
OWenPXR;R7mdK6EMEUAIGUeHEEQMHVI/M7YlO7eoP7mmNgamO7QeMGMfLVaZK6ma
LWEkOWekN7MnOX64Qhj@TI:BT8j>SXf>Si6GWInOWj>Y/;Ji^KVh][Ba[JZVWYVE
TI2=S8^9QhF7SI6BTI2BUINHViZGTi6BUIVJViZIVijSZ:^ZZ:NWYZ6ISXN7Rhf:
Q863PGUbKVi^JfITI6ATI6EXK6m`M7QkO7UeLW5_JfQWJ6UWIVEVJ6QVIVQ[JfYZ
JVQXJg5gNGYjNgemNGE`KFmaLgEgNgalOXB=UIVKViZHUYJHV9B@SHb<RXR7R8V7
Q8:2PX61PH>6S9:HW9jOWijLVIJCT8j;QX:2Q8V<SXn?TiBDU9JNXInKVYVCSXV4
Q8F6R8b=RhR7R8^=SHnBUYRESXb<SXj:QH1kMW1]KFaZIV9QGU]JFV1UHf1OGf9T
IfQXJfeZIF1OH65PGEYHF5aPIFaeOXF;S8R3OGalNGA]J6ISH69VK7=eMg]oPhJ;
SY>IWIfMWYfLV9NFU9>DTHn@SXf>TY6DUi6;RHZ7RHjATiBFUYBASXZ;RXJ6PGim
Ng]lOX:9TYRHVYfKW9bGTHf9QX5iMGIdKfm_KG5cLW=[J75eL6aYHf=/L6YZKfaV
IV]bNGQgNWQcJ6=YKG9cKgQnPH=nPHB4PhN;RH=nPX5mO7IbMg]nPHF5Q8RDUHb>
ShV7QHB6QX=mNG]mP8:6S8jAV9NEUYBEUIRNX:>PUXnBUiZFT9BDT9>ATI>;RHfB
UHnCVIFHWinGShnFVi^IVYVESXZ5OGemQXV7SYFBTYJHUiVTYj>RVYJBSHj@SXV9
SYBBPgn=V9ZNXI^FXJNSX9VFVYZOWY^KS8B4OWE_KVi[HVmmJfI`K6m`L79`KVm^
LVe[KVAHFFE[HfeeMG]]M8AfMHjDRhR9TheiLFINHEmWMWI_LGMbLWn7QHNCT8fG
VYJ?QhZ:R8V3OgUjQhAjNGAeOFiUL6iWI6IfNg=cLW60OgV1MW1eJV=QJ6UREeYP
JGAYLX29R9B<QYF@VYN>SH=lOVmUM75RJg]dKW><Uh29UYBGRhf6P7UoUhQdNgZ0
OgQlNWmjPXB0NW=jLfIlUh1bNWn<Og1^L7anJfM_JfmVKHN8Ph>1PHRJW9^NUi:A
PhV@OFaJJX]cHW5gLW^2QHIlNgebNiNIQHAoOinRPgM^PJZYUGj2OW^EYYJ:RiNS
[:nTVGnAZZJFUI:;P7N3UHAaLW1hQH1bKWF8UY>8S92DUYZNU9JCO8:FUiZOTi6C
X;6WRgf1SjBGR8IoK71hJFYaIVUeMgIRMgmOIgQiN71mSW]nPh>2Oh:9Q79ePH9o
OgmfN6UFIFaQD59FFEeeO7=kOhjLWI:>UH]gPhR0Nh66NHFEYJF?V[Rn]KNfVi>Q
YIZEYhAbRh=lKfn5L8><KVj:SXF;YIejQHMkV8=YPHjAU9FHSg^?UH2>TWAcNg9h
N81mKGj?PgV7QgAoPFn5SX1aLGUmM7JDSGf>TijbYIN8NhB@QX5fKV]mO7EeMfiP
KX1eK7AhKFn>J5InQgIbLG5VIWj;JEEHF6Y^H6=NCU]]Ig9gKhB;NH>CWXMgPXMm
JViQBVRHSW9bMH6AUX:5Y:FCWJVRY[B^T9nnZ9bZUXfPUJ>h]YF2Y;JBPI2LX[R/
P7j@U9VNWIfKR8J>QY6IR8RDUXAnS8=kOX9lOY:FN7Z5PWEmQgEaM7MgPhaXGGeo
O99lG6>4R7anJeI^MD]8B3d/<deCDE99BXb@IWB1Wj^;PHn=Kc=4LFUKBTQ8B4eU
HCY3CU5JBeM`L7QdJHEnMW1QMhZ>PWf4Lf9cQh1kNg23Yj:5TK2cZIfQ`<FUU9:U
/[2JR9be_jJJUIJmZ9ZXVk2g^[NhbKBPTJ>YX[>gXibZ_[b`]jJB[KnWShb<OY6X
ZJN]WiBTZIV0KVa^Sk68IFmfV:FZX8F=]KnRQXbWUHMnKfI>E5EKI5I`N6QXPHUj
KH:DQgf1SWANJgY_GW6;Qf1?GgQeGfIIEgZ;M5UHFVQjKEQ>G6YWG65XPi27MW=`
J5a9I8B;T9^SVhZHYYYlIFN1RGQiR9RLUh64Qh>DNf]YKhn7MfY[MFYbN7]eJVml
S7]lO6m_QYR3N8VQUiB[XH6<[JVISib:MXR:PX=jEFf;R79jWi9[Kg9kZJ6BUhVG
XY^FOWB4U8UkMFMbQI:UW8^=[9V2O6YNHWb?W8Z0OWAfR9fALfMWHVU]K69UIGR2
LFIRM6QAGV]ZNFEZM6EbPW9kTH=gMH1hO8EaN89eHUMPKWAdLEAQRHQaK6E=EV5J
EDdoEW1nSHQoNgVAY8=ODF1nSH>5O6YQNHmbGVakNGf9TY6>VJ6MUiN@TheaOi6=
U9RLXIRCVJZ`ZibHWY^NWYVCY;2TUgicTZFSXYRFWK6^VXn0OhZ1S9ZBVXf:ZZZI
Ui=mK8JBNVMhRhbLXYVDUZZj/I:BVHinOXV0O6elWIj:VK:?KWikOGimW9Z;RYJ[
[ZBU/ZZ@VYUgMYf_Ug5lQGE`JFa^Jgj=TIQiJ725YZ^OO6b5Shf7TYJ6MgF0Pf][
PY6LTi>ATXQeSi5gL7=RBFBFWX>5PiVWWIB9RG9^MWn9RYZMSGj3V9MTCV5SF5ag
OVYXMgeiIfM`O8=fLVQDDFioIE=3>eAUGV9SEe=OIW1hIFA]MX:;SHn?SIBOY:6E
IF:0O8V3LVIeNeMAIgeaLh9kKW=`DF^CVIR<PFAaUijISI6@SI27RhV<U9VSYZFA
L6]jKWR?R7ilOH2:R7Q`N9FBRJ69LiJCR9ZTX8j7PIR`SV5YP96HSX:2Q82:WJ>Y
YjRg[K>m]Ib?W9F=TGIJHV]aPgibL8N9If9WEeR2Rhn=J5]`T:^OPg9OGVYbN8Z@
N5=;LXUdFEegOgVBZ8Q_OY6PTG1MJ7M/KWASDFn;NFUfQ7EhOG^DWYjEQW^6T:6/
TX28RHJ;ShN4TYfcXiB@Lf5UP7=OJ7MkLgQbJfAcKf1MAdM>I6aWIg:1Q7n8U9^L
T821SI26HU5XOH:IXXIdKG5nRH^@X9JDViNER8jUZZ^VSh:1PH:FV8^8PGV2QhQl
J8fk[hamS8^0RYB?RXjJUhf5U:>GShZHU8bN/;6^/[:k]ZFW/jnAKV>8R7jJYYan
NWefTKJjWg]kRHJR[Y1oQIRX_[>4GfYmMG:5QWMkOX9kMW=[N822OFMMI7alIea8
:bm;KG1[JEiVJFY`IFeaHfIeR7a/PI6NYiN=PWMjPGikOgYYKGmgLW=^HFMiI5iA
CUQWSINCLUUWMgYkHdmJLHR4PgmbPIf_YifDRhF3MG5cPiF8Q866T8amKFm`NYVG
OG5hTHYeN7emRiRDU923OHfMX9F=PFanU9nUSi>WXJ:Y/ZZJUiNKW95[IHVHTYB@
RXZ4PF]>BEU]OX9UEEm[MX5cLga]JG67PGAbK75bOX5mMU=1J8AhIfAYN8Z9P81d
KWf0LfYaL6QdPHJ8ShQdLXfKWJ:RWI^NXianIFUaO8AhLGMbN9^/V8=kRi1ZI7b2
QHnAU9bUW822RXIiKW=kOH><VJ6<T;2^WZV^YjNQXIVDRG1]SJbTVhiiOXjRYiV<
SYZRWYfPV9fLWjn[Whj;VZFNSHAnOX1mLgElLg9mPg=PKh1lKgfHVG]bUi^>Vj2<
JFAlRh^3O7alOIR//:bUXi:6OGUaK7Z0RHN2QWajOhbQW7mbPXZ4P7e^LHbOVXAW
EeaZN71TIfiTEE=HHEMNLV=MIfUQHg=bIDe5AS/kCVQRDUIKIgf9KeUSM7Q/KWAk
NWnATiVGRX>BZ9J0RhioNXVBV9jDR7mfNXAnLG>7UIbUXYJMXYfJSXZ5QiN=O8BG
W9RJX:>JXk6b[jb_ZIVARiFYYiV:OH>GUiNUXYRKWIB7OHF9SIfNViB1SY9jLGj1
Mgf1PHR>PWjGYJ:LRgAhU9J2KF=THf1OJWMlL6Y^If5SIfi]IV5TK6a/LFQIGG1k
JfQhP7ISGff4OF9NI5mJG6=XJ69FCV5WHVU/I5eJFV5PFf5SGV5UKW9]JVabMGF1
WJJHV9j=NGJ6S8:3T9B@TH]hLh24QW]YJ6eSGfQkRZ2e/YZ6Rhf4KeeSLg1^Q9V?
Q8jNY9jEXk2c/:RQXJN]ZYJAWZNVYZba/;BgZjBWZj6;QY>KVXMnW:J=PXB<R8RK
Yj2>R92W[If?Q7M`LX6:PGZ:WiJ8VZRIThj3PhZAUibLU9NMVi^XYI^RYJJMUI62
LVM]Q89kPgimO79iSI2:S8f5NGMjNh:0O7j2S9>1KWMkL6adLUmFJG=TEDm;B4mU
Je]KI61MEeMQIEY;D6UdKVU]NWE`MgA/IfQfQ8^:O7A`Kgf3NW5iO71`OhnBU9BB
UIB2LV]WJ6][KgAfP7edLVQZNXN;Q7n9U9fOXjRBNGJ2U9F@UYnTX9J<QXJ5LfUk
SHMnNh:?SgioPGQfLG1lOWb4T9RMXIV:Ph5fOHN5RY6:Q8bLWi29S9fVWIfMTh>1
U9J5Ng^6Rhb<NW5nPgERFU=JJfUKH6]bM7=aN8nBR7n7UYVARX^@UjJZVXV<RGMn
RXIlKVafLFIOHG1aHVI^KfifPgQfQ8=eLGj5S96AV::RUXn@QGV1RiNPUI6AShj@
WIb8Oh1gLWN0RHn?T9>LUgihMf]`NWZ8Th]kO8bAShR9UZF/XIjPWZ:OT8R7QXbA
Tj6YVI6T/k2PR8^CSHfAVYRCSH:3SH5aNhN?THI/JhF?QH60N71[H6A_LWMkNgMn
SXUfKFmfOGidLgn:R8>>S7QlQ7n2PW^2PgebJFYRG5aDDUiYL75YIWF4P7n1T9In
KgJ7SYBIWIbCPH2=Shb:PgIfN7IhN75/KUmIKGAPEeeKFEYNGUmRHfU`MHNEUY6E
WIN@TibY[ZROUYRQUXf<QGemNg^5Q7QjPhJ9SiF5NGUeL7AiP8J0PXB2OVidS9J<
PX67TJ>WVIJHV:6RU96R[Z6IW9nRUgi_L6][LW5lQGn1Q7emOH62O81iHfN0Qgmi
O8F3O7Y^KGAcKWR:THMkLV]hNG9iN7UjO7idKfaRGVE^JfQ_K6]cOXB5OFMIGUiK
GEYNIFMVFe]KH7V7MfabMGj@U9^UXYjLWZ:VW9NKUXf<QGanPXIkJFa[JVY]OXIk
M7j>TXYjN8^JWZNb]ZfPUIJVZJ:PUI>RXiF5R96ASi6>RXf3KG:5QX>6QGelNg=_
L71bMH64Ng]kN8R@QWaoU:6OV9NBRiFESY>DTYbPY;;4a:jOUHn1MX>:RXV?Ui>1
MfmaR8f3Oh9mP8bCThV<UYF9MgUkJg>@X9f;NWUnPWi`K7UlO8RDUiJARY2PZib5
Q9J/];BVV:6OTHAaK75ZKX68QGMXNi2AUiN:Q8F1QY2KWI:FXJRVXYb;OGE_Kf]X
JF=LF5ULGEE@DeMMH5=<EEmEA3i0@UAWLgIWGV=WMWehMWIeMgmhJ6=UJfaaP8V4
M6UaPXAcJ7F2PgARI69KKGinMf9GGUmUL6eLG6MdNgb7T92;R8fDT8=kPibg^jbO
Wi^ERX63Q7n4TIZJSGUdQ9RVY9bLYJZOTXjBWJFQV96>Rh1nT9nQWIRESXN6QhV;
SiFS[ZJKTXjCU8QlLVYaPHV=RHJ?S7QaKfQWHfAdPWmeKFY[KWImOGUdM82:SX^4
Q8nRY9>7QH^CSh:1PGekMGb;PVALKWaoPhJ7Ph63OWamN6ieS9R@PW]kQ9>MTH63
PX21PH1nNgIfNWUiNgb2Q7eeLgZ3OgUmOGUfK6]gOgacIV=_P8InO7f4RHJ1PHJ4
OGAlR8QkKW>3SYJNVYF=PXV<O79lUZ>QW9B1M7J5T8V6RhEfMH:AViB;RHf8MVa_
OY2QZ:RRW9F@SHf:Ph6:UYRHVinLWjBPUiRKUINNYj^TWINJY9j4Mg^9ShbEWiN8
Q8N6S8^3Q9>OViBCU9N@U:RZW9:;QgikQhUoLf]ZJf9IFF1RH61ZLFEHFfYcKV=I
G6]jQGQQIWj=SHN7Rh^1NWUmOgEXJ6maLG5_J65QJgUbIfMZMWmaGemePWY`J5eF
GFMRGfIZHUEDIG9fPGm`KWQiNgmmP8^OZj2EU9JAR7mgNGeoPHB0NGQnOGYnQXb9
R8V6Rhn<TINHVHn9RXZ:TjJ^Zj6CSi6FUYBBTiNHV9B>RXN0OhB8PWA]Lh6?ShR3
QH5cIEmQHf1YMGQdJf=MI75eLVm_OHAjMX2<TI6@U9bJThb6Q8=nMG9bJV9OH5aB
CE]_LFQUJVIXL7R0Q8Z=RH9mP8RATY:LYjBAPX^EVYnHQh:3PWijNgUeMWeoNgE^
L7^5S8^5PXF3MViaMGUcK7B4RWY^MGmoN7b?V92?Uj2LT8bDXZne/JROWJ>PUY>J
XJ2HRhB3PGenQ8b>Qgj3SINSYjJTVi:BTHj6Q9RSXjBIR868Si:8PhnKUX^;UJ6R
UiBLYJ>KTi2@TIFJV9BASh^8NF=NIG9hMW1aMWIeMGN3RHjHUXj;QhN5Qi^^YY^C
TYVNVYNGT8MmMWUiLFMQHfMWH5]DDf9XHfAVHUQFH6m`K71mT9F8Mg5iP7YbM7Il
Oh29QGE/Kgf;SX^5OWj6RX^9QHZ@S8R3NWA_JW1kPGU^IVAZMhF:TIR@R8bCUiRG
V9bPYZ6NW:2QX:2UY9:7RY6FThZ2R9NKT81eMWj1P7n2P7f;VI61OHRHXinJUHnB
V9JARh^AThZ1OWabK6U]O8AjKfa[KGN2QXN3MVUXJfAGDUQRG556?Si6D4m@G65K
G6McNG1YKGEoQ7ihMFaVIFM_KVIVKg1SDdU8CUYSHeUFFf5RGEMOJW1`JEiQKgEc
N8JASh^5Oh25RHjETXF1TYb;NW=iRI>@OW1dQ8Z;U9^JShZ@Ui^FSY2MXib@QWmf
KFY`M79dOHV=Q7YgOHZEVIVIW9nSYJVZ[K6^ZJRUWiR<RIJSYYZ=R8^GY:FSYYj@
RiBJVI>AU9RIUXj;TiFCUIVMUhn=U9^IRXB;TYRCS8^AUiZGVJ>TWj>ZYjBQWibE
Thn9PgmkO7emOG]hM7=gO7aeLGN2SiF?Si2>U9ZLW9V9OGf4PFmMFf1THEE8B4]8
ADmKFE5=Df=_LW9eOhJ2N7EiNW5XIVUYJ6Q`N7YaIUiOJgIiNWihMWf0Q8RAUY::
S8b6Q7mgMWYhLFQSIFEUKWf3OWZ1S8f7Qi2GX9nESI2EUINR/KJdZj>VXHioOhN<
TYJIUXn7PXB9RhAnQ8b?SY6FVYjQXj2KViVDTI:FVYREVIJ9QhQoNXB>Sh=lN71b
OHR>SH9iN7QbKW5iMfiUFe=CC3m1DEmPFe]TKWIkOWn4Qh:0PHB6Ph67RhF0PHF4
OG=WG5MKI6=NHfQZKG1bMGamNWV0R8N1O7j6Si>GVj2RW9FAT8j5PH>7QhB5QX5n
NWIhO7EcOXfDS8B6R8b@Si6JWYfLVibGRW]^J69OGfQbNWakNgf1PhN@TXf>THj=
S8^>TiVNV8YiK6U_N864Q8F2N7AhPHF3NgMlP7n2Ri:BRhF1PXB0N7^3QhR;RXZ9
P7IlR8b:SYFKWY^IVZ2UWYFCTHj8PH22RY>DSHN2O7EZIFUePHZ<QX:1OhB>TIFH
TXf@T8b=U9fPX:2PVHn7QXb;Q7efKVQUGUUSL75XH5eJFf1SJgAjOHB8RH^;RHV8
OG9fPh^8PGelPXZ:QhV;SIBGUIBDShR6RXj;QH:2PhR9Q7inPge/H65VIFQ/JFY[
LhB@UiJ:PX:4QH1iOXJ=TifY/JnVV96@SH^>TIJLWiV9NVePHfmbKV]XJg5cNhB7
QHN=T8b5PXNDXJJOT8V3NgYjN7EdNGYcLWUlO7n3QH=mNGMhNgeoNgE_J5]?CUAD
DUQNHV=KE5MTNXV5OW]mP7YhNWA^Kg^;S8InMWAjPhR6PX>4PG]cKFUYKgAdLfi[
KgJ0RXR0OH64PH>:SY2CU9FFThZ7S9VQW9:4NGAiQI6IW9fOWijUYj2QZ[2_[jbU
X9nNW91jJfIVJ6a[IVE]MWb4PgYlRIBFShR7SijZ[kB`XI:7PH25RX^>T8n?SXAk
N7R0PWadLGAfMWEbKfeaMWEgNW]mQ8nGUHIjOH>4Ph>0OhB=SI2ESH>6TIVKUhj7
QHN:TIJJVYF>Q7I[HEQNJW9dKfANGFYhNWUhNWYeMG]nP8J?UiB<QGmlOX64P7Ib
LVi_NX60N7AdLg=^IVI]MWf4R8R5RI2@R7ifMGMhNWM_JFM/LgQhMgb2Q8ZCVIZG
UYZNWinGShfBUiRGVIFDVYjIS7ehN7EbKVUUJgMlOH20NgIhPhnFUYNKXZ^_[:JR
WIJ@T9BGU9NU[jVHRXF3Q8R=SX^7S9BGV9ZPXj>QWIB<RXb?UYbOV9:BShV6QXN6
QXR8SI6@SHV;TI2;Q7f1RXf8PGQ_JFEUGEA>BT]BEUYRJ6IQIWElO7QeMWI_I5mO
H6I`M6mVGeYMI6Y]KG9gNGMbKFUVJ6e`M7A^IfE[MGQeKVY_NWUaLGMjNWQaK6me
NWinP85mMVi^N8:9RhV9SHb7PhR;Ri6FU8j>TIFARhN1NWI`MH23QHJ2OGf1R8b7
OgYlP862QXjLZZ^SWIRBSh^2NgakOhJ;T92;RHR7QHF9RhZ?TXb5Q85nOX>5P7j4
QhZ;T9NGTi2@T8j<SY6BTY6>SHf<Ri6GUI:GWJ:X[:^[/K>WVY26P7mnP8J<S8J2
Oh23QXV=SXj@TI2EVYjQY:FRWYjLUXb8RXAiMgf1PH20O7QkNgA^JfYVIF]aKW1e
N7MdLg=^K6icLfaWJ6U[KgIjNWYmO7QdMGj9SXn<QGilOWaeLWAdLg=fMW=gO7E]
J6ITHV1QHfQ_LgAbJfIYKg=eMgb3Q8F>UYBBTiNFSHN<TYBDSXF0NgYkNG1XJ71e
MWQjOH:7RHN7S96AS8Z>SHV;RH9lMW1/JfmhOWilNWaoQXIoMgIjOh20PhZBSH1k
Oh>1MfeVHfEYJF][IfI[Kfi/MhN?RhAkMG=jQ8Z:R8V<SHnFV9NMYZNPUHj9R8f@
TI2;QX>2P7ikOH21PhF5Qh^?ShnBTHb7P7n4RXb7PWeeMWYgM7InRiFETi:EV9^Q
YjR//K:]ZJFOTHAkMG=`KFYXJg5fN7MdN7eoOWYdL79hP8F9S8b=S8Z:QGmjNWal
NgQfNh20O7YiNGQiP8Z>S8=dJVadLg1aL7=hP8V9R8bAUI:7Ogf0QHR7QH>1PHN@
U9>BTiBJX::TYjjd/Z^QUhf3PXF9RhN1P81lO7ilM79lQhZ6Q8V@TI>DT9>LW9bM
XJ:FQWn0PX5oOGYfMW]nO7McMGb1OgYjNgeoPGmgLgMkP8:2Ph5oOGMbKFeeNgak
OX5nNgj;V:2NUi6<RHZ=RhR;TYNFU9:ATI6;PGUhLfe`NH1oLF9NH6Q^L75cNXF<
SHb9S9BGUI2?TI:FViZDRH:2PX:5RH^7OgamPHB:TYB>RhZ3OGn3QXN6PWelNW=^
K6QUHV=[Kg9fN7QiN7UkMfiXJgZ8QgU]KVm_KF][JfUUHEeJFEmZKVi]KgAfNGn2
P7ekNWMcLgIeLVm`L6iePHZ=SHn@RX9mNWb2R8EnMF]UJ6e]KWInOg]hN7^1Q8:2
PGijN7f;U8n2MFi/Kg=fN7QeKfibM7MoQXN9T9NOY:JUX9ZFTXn;QHF4PX>6QhAn
O8>8Qh9oOh1oOGj3RiFJV9BDUYJDTI6FVYNASHR9R8>2QhV6PWmoQ8Z;Rhj?R862
PhB5QXR;SI2CV9ZGUYZMWYnJUIJIVIF@S8R6Q8>6R8J6S9NRZ:^ZZ:2ES8N6RH^9
QXB3PWeeL71hR8^0N7b6Si:ASHb=RhJ5SIZMUhn9QH1mOG]fMWMfM7=cN7]fJfEY
LWYmMF]UIFMVIV]aMG=`Kfi/JfYZKG1dMGEdL6idNWQeMWb1Qhf;PWj2RHj<RHAo
Q8j@RXB4Q8:0PXF4PGmoO7McLG5dNhB8QhB5QhZBV9^NXZBUYj^b]K:ZXYZBS8R8
QHF5OgA/KGZ9TYF@QGj0QH^AVZ:TY:2JT8N2P8::SHN0OhB7Q7igLViZJFY`MGQi
OX:2P7eiMW=aL6m/J6M/K6MQH5mOHV]aKf][LGV2S8j9Q85mN7AbLFmePXV:QX:0
OgekNWYkOH64P7M[I6UePH=kLG1fNGMjPhV7O7=dNX64PGeiM6i^KVeaNX62OgM`
MGn5QhN<UJ2VYjJUXIfIU8b4OWejMWIfKfQXKWImOgU]KGN1QXN8QXN=TiJBS8V9
SYFHV9^KUi28PX5oNG=bN8:5PGinOWYiMg5YI6M]LWEgNX::RhN6QHF8S8j?TiBC
UYbNVi::QhN9R8F4Qi6MYZRXZJZTWIRHVYnRYJJNT89jNWn4QhF4Q8F9SiRNVi:<
SI>IWj6LTH^:S8^6PhB5QHB0O7YoPGimOWemPHJ9Qh9iLgAjOGf0P7]gMG9^L7Ei
OH1nN7=cLg9`LGEeLgEhNGQjP8B3P7akP8J3OGUlPH5nOX69Shj9PG]eLFmYH5aQ
KWMhMG5dNginP8>4QXN9RHV<SXn@Shb8QXF0O7]mOh:3Q8R;RHV:RXR9TIZOXjBR
WYV@Qh1oPhF6RXn@SHV8RXZ3N6m]LGV1PgefLW9dMgQjMg=bM7=fP8N6PX20Ogf1
Q85kMgEbL71dO8:2OWYeLfmbNXB9RhnHVYRETY6EVI^KVIF>Q7ikNWI`L7EkNg9Z
Jg=kO7j1PX:1O7UkOWinO7UgMGUjN7EbLW9_JVQ]MWf2QXJ7RHf@ShQlMWf8RhJ5
QXAoOX>:RhIoO7UcKFa_LW5aM7YmO7UeN865PX::THn7OgenOWaeLG=fNWeoOgQ^
I65RIfebLg9`LWR2RXZ6QX^@TiJFT8fAUIB?RhZ;RhF1NgMhNWj3QhZ:S9:GVIF@
RXR9SYVTZ:6DS8f?Sh^9RXb<QhB4QHJ7RI2IVYRFUYBDU9BDU9>@SXb9QHF8S8f;
R8N9RHZ;QGagN7]jLfi^LgZ0QXb;P7IeNh>9RhV:RXF2P7ejMGAgNgejLg9kPXAo
Ngj2OWMbLgAeO8B9RhZ9RXZ9QH5lLfaYJW5eKfMYLWf3Q8>3QHN8T9RIVYbMVIFC
U9FCS8N7R8=kNX25Q7mhLgAfNX1oNWb6Tj6ZYiR>SHn>RhbBUY>?TIBDT8^7Q8:1
P862PWihMG=cM7MjO7M_KG1dMgYiMW=fO85oLfUZKg=fMWIiOX>9TINAQGejNW]o
PhF7QhJ6PgijN7Z4S8Z2P8B5P7]gM7EgMgQhMWMkOh>;TY:>R8:1PhR:Qh>6RXV3
O7UhMG=cMGMeMgj6SI2BUi^JThf;RhR3PhR9PGYlQ8nGV9FASX^9RHR2O7QlQhj8
OgamO7UjP8N9Q7inP85nOWilNgamOWimOGafKVMWJg1eMW=_L79cM7IeL6ecOXJ8
R8fBUI>CUiRCS8J5QH9oOh67SY:EV9ZIUI:@S8J2PX^>Qh22RHj<QhF7RHR6QhV8
QXB1Oh>:Si6?S8V<T9>BShn@SXMnNWYhMg]nOGf1QHR9R8J4PGahMG=`K6]/Kg1]
J6MXK79gNgn1PH:2P7]bJfacMgEbMgYgLgEnQHV7Q85mNWf1PX>5QhR7QhB0P8>3
Ph61PX>0O7MaJV]cNGQeMGb3R8fFXJRTWIVFUYBCTY6@T96CUIFDU96=RH=lMgAb
Kg=oSI:=RHb<QX22RY:FUI6AU9NKW9N>RX^@Ti:<QXF5PWmkNgikM71bMGIfMg9^
KW1dMW=_KG5dLW1bMgMdLgAfMgUkOWikNgioQ8^@SXZ6PG]jOH1oNgZ0Ph1hMGQk
O7]dK6Y]LWIeMGIeMGMjNGMgNWYlP8N>T8n<R85iMGIeLG1bMGA_K79nQXF2Ogal
OhB4Ph:1Ogn0OWinOH23Q8J8Qh5kOXF7Q7mmNgA]KgEmQi>LWI^JV9FAS8J1P8:5
QXAnN79]KG9hNGIcM7UoPhF5OgIdMW]nP8F?VZ2QXJ>RWYbKVYJ@SY6FUi6<RhnH
WIfMWY^DTYZTZJJPW9^IUI>BTY:EVYbLViVHU8n:QhF5QXR;T9JJVibNXZFRVi>;
QH>2Og]kPHR;R89oPXR9QGegMGMlOGalNG=_Kg=eMWUkNWf4RXb6OWQgM6iUH65T
IFAVJFebNGn2Q8AoNGEaKg5dMWQkOGmlLVQVJfmdNGYgLW9eN7IaL7=hNWb0Q8Z?
U9VJUXf8QhR6Q8>6SI6@SHV5PX60OWinNG9`Mh66RHZ7P7UfNGYlP8B8RX^>SXb9
QhN9Rhj?SXnCThf4Q8Z<RHJ1NgIfNX63OWMhOX1lN7EeMgMgN7IbLWMiNG]mO7Ug
NGj6Rh^9QhN<S8J1PhV:RXZ:RHN6Ph60OgmmN7IfMWAbM7QjO7ilMW=dMWIcL6i`
Mgj3QHJ7QhJ6Q81mP8F6QHF7QhJ3P821PH:4Q8B8S8f=SXb:R8F0OH24QhZ9Q8:2
Q8N8Q7afMWQkOX64QhR:Rhf=RXJ2P824R8^=S8R2NW5YIVATIFMXJ6aeOX5mNg]i
M6m^L7AiNgj1QHV:RHV8RH^=S8R3Q8Z?Shf>TiFBSHZ<Shn@UI^KUXn:QXF5RHb>
T9BHUY6=SHf>Shb7Ph:2PX>8SHj:RHb>S8V8RXf>T9>FV9NEU9BARX5lO7emO7am
P7mjM6eUH61TJW5eNX66QhN8RHR3OWajMFiZJ6Q^MWf0OGUhNWemNWE`L7EhNgio
OGYhMWEdMgb0PX>2P7mnOG]iMgEfMg]oQHZ;S8b>TIFDSXZ9Rhb<SY6CUIBAShj=
RXB0Oh1oOX24R8b>SHZ7RHnEUiJEUYZNWYR@Rh^>SXf;Qh60PhR8Ph1oOW]gM7Af
MgYoQhjAT8Z6PX63QHJ7Q81mNGA_JVYZJFMTIFadNhF?U928PGilN7MlPhR;RhN4
PX:3Ph9nN7AeMgQdKfmcM75_Kg1/JFU/Kg9dN7QhN7QkOGekNW]mOG]kOX>;SHZ4
OgaoQ8J4PGmnP8>7R8R7QHJ;TI>ASHb=SXf<RHN7R8N3O7YnPhF3PH63QhR7QhR9
RXV:S8f=S8V2NW=^JFIWJ6Y]LGEfMgYnPXJ8QX1oPhV=Si>JXZNUWYNAS8V6PhB7
QhJ:U9ZGTHb;S8f>TIBGVYjPWYVBRXR9RX^<TYRLViVHUI:?SXj<RHF3QHN:SI:C
ShZ7QXR9RXb=SHf>Shf;S8f<RXV5PhF:SH^6P7]eL6a/JfYWIfabMWUjNgaiMG=d
M7EdLF]UI6IZKgAgN7IcMGMiNginNgUjNWQbK6QVIfU/Kg5cM7QlOWimNgQhN7Ia
KgEkP8F:Rhb=SHf>Shf9QXJ8S92BTYBFUiNCShf;R8J7QH5nO7]gLgAeMWIhO8B=
U9JDTi:@Si2@Shn@TY:?SiBIVI>=Qh>2PX5oOWn1Ph:0NgUgM7=aLGAkPX=nNGIa
JfEQH6E[KFicNhF<T9>?RXF3Q8J7RH^8QH>1P7mkMgEgNgekNG^0PX1lNGEaKF]X
IF9PHVM`NGioPH:2PhF5Q8B4PGinPXJ7QXF4PGmmNgUiNgaiMWQkO7YkOX>6RHfA
U9BCTiBCTHn:PgmoP81oPH61PX>3PX1oOh23QXV:RHR:RhZ:QhB2P7eiMGAdNH65
Q7mlNWUjO7eiM79eO8>9RXZ:SHj;QhF4Ph>5R8jCVIbLVYFASi6CUINJWI^HUYJG
UiB@SHb=T9BIVYRETHf:RH=nNWQgMgIfMgUlOh62P7n1QX^ATiFFUiRHV9JBSXj@
SXV3Q8^?S8J0NgE^JFIVIFAVJFe`L6m^KW1dNG]hM79`L71_KFa`M7IhN7QhNX27
S8f9QH:0OGYhMWEhNgf1PWmmNgamOW]dKFe_LWAdLgEhNh23Q8J9SI2BUIRHV9VL
XZJWYZBPViRFTXf<SY2<QX5mNgf2PgmkNh26S8n=RhR8SI>FThj=SXf;Rh^;SI6E
UI6=Rh^:Ri2BSXZ9Rhb9PWimOh63QHF5PgeeL6i[IV9VKgIiN7QgMgUlOWahN7b1
Q8F3PH62Ph>4PWijNG]lNGQiO822P7]eLVm^L79aKFUYKG5cL6i_LWAeMgQkOX:6
QhEoNWYlOWalOGekNgf1PH20PhN<T96@Shn@TI6<QH61QHN4OGIeOHB6QH5kMWAh
OWmmNgf1QhZ;RhN2PHB8RHV7Q8:3Q8:0P8F=Ti6:Ph20PhN6P7]lOgmmOWilN7Ih
NgemOGj0QHfASh^9RXZ8QhV?UIZOYJRUWYZJVINFTi>DUYRKWI^GUiRHUY26P8>:
SHQnMW5_L79bL71eO8B:RXV8S9:HVIB>SHj@TY>DTXnAUiR?Q7]hMgQjO7ekMgEf
MG5/J6IXJfiaM7=cM7=`JfEQI6adN7]mOGioP85nNGAcMWEcLW9eN7amOG]hMGIi
O7UaJfedN7McLG1_L7=hNgYfMG^3R8b<RhjDVIfOWY^JVi^IThn>TYFESXEoNgUh
NgmoOGj2QXR7Q8:3Qhb>SH^;SI6CTH^5PX>7RHZ8QhN8RHV9R8J4Q89oOX21PH62
QHN6Q8:2P7YdKVY/MH6:S8N3P7aiMgEdM7UoPWikNGQgMgUiMWAfNGn4QhV8QhR:
R85gLG1bMWMfLg1^KG1bLG1bM7IhNGUkP8B5PX1nNG=`M7]oP7n0OgelOX1oOh:9
T9FIVibOXInLVIJCTHj:QH1mOhF9R89mNgUgMgMgN7YlPHF8QhN9RXV6Ph:3QHJ8
RHV9R8N7QhF2PH1mN7EhNgenPHF7QXB2PH62QXV9RHR9S92AT8^6QhZ<S8b<S8f=
S8b;R8J8RhjBUi^NWY^IUI:BU9NDSHN2OWj1PX1nOGagLFmbMgj6S8n?T9BFTXj>
TI6=RXZ=T9>DTHj=SHb7P7UeMWMiOGmnNgUhMgQgMG=bLG1`LWAfN7IcKfaZJ6ee
OH:3Ph>1O7UhN7QhMWEfNGamOhB7QhF7QhB0NgYmOGYgN7YkN7AeN7]kNgioOgn2
QXV:S8j@THj<S8nEVinSYJFPVI6<RXN5Ph:1P864QhV;SHb8QH>3PX:3QXR9RXR4
P7eiMGEhOH>7RHZ9QXF5QhEmN7Z0QHN9SI2?SHb;RhV5P7]fLW1]K71fNWenNg=[
JFa_LW=fNGYhMgQiN7IfMWMkOh:3Q8V;RHJ1O7QdM7EeMWEeM79bLg=dMWMgMgEb
LgEdLW9eMgIcLW1aMW^1QHF4PWikNGQjOH66Ri:HV9NFUIFIW9bHTXj;R8R9RXR6
Rhj<RHF5OgUhNgioOGanPXJ9R8J1O7]mPhV=TYNJUi6:QhZ>THn<SHZ5PH23QhZ7
Q8B1O7]kNWj4R8V8QH>4Q8B5R8R5RXf<Si>DTXn@SXV:R8RBV9VKW9JDU96@T8j=
SXf9QX>1PgmfMWMbKfi[KgIhO865Rh^6QXF3PhB7RXfDV9VNXInKU8V4Q8B9RhR7
Ph1mO7YcKV]YJFY[LG=aLgEeMg]kN7IcL6i/KG=iNWakMW1/L6iZJfiaLG5dMWYo
Qh^:QhF:RhR4P85oNgejMGAbLGAhNWYkNgUfLgImPXB4PWmnOWenPh^BUIFCSHJ4
Ph>4R8Z8QHB7SYBCS8B3R8R4P8F:PXJHUHf;Q823PX1nOX22PH22QhEoNWQcL79h
O7b0QhfAUIJCTY29R8N4QHF8QhB2NgEhNGIbKfm/KWQnOWemMG1cLg1aMWf0QHf@
Sh^8RhZ3OGUgNGaoP7amO7YiM7IdKVm`LgUiNWakNWYkNgaoOg]jPH5hN7f1Pgih
NGYnPWn3SI6?SXn@TY>CUiZLW9bMX9fLViJCT8b:QXN:QhJ6Q8>6RHZ8QXJ8RhR5
R8Z9S8^CX9bKWIFGUHV3QHV7PhZ6PXJ;TI2?SHV5PH=oN7f<ShjAT92?QWYiP89o
OGf4RXf<Shf3PX5nPH:3R8V>TYBGTXR5Q89oOX>6Rhb1NWM]I6acKfa[K7AiP7mf
N7QfLVIUJfmaL7b;Si6>SXb5Ph1jNGj1NgV1QXB1Q8>3Pgn4PGf:RXN4OX:3PhJ6
OWR1Rh5lSHZ0Oh68PWn4Ng^5PX5oNgejOHV<S8nATiFATY:>SHb<Qh20Ph63P7b3
Q8>6P7QhOX9jMX64Ph5mPHF6RhV3S9>DSXN5Q8:4QHF6PhJ<RXb>Ph>6NGQgLG=e
MGIiOWmkMg9aLVi_LG5`LWMiO7YiOGE]KG=hOXB5R8Z>ThEePXUlLgAkPH1jOH>5
OWnAZIa_FE=QJ5QNIf9LE4a@GVEXJ6]YGEUGH6a/JW=kOGf6TXMkSj:GPX>D]<Vn
YibKZ[k<dLNl/9NDYI=^FfJ5WZ:IR8:>V9b=O7EKBf60W;NgXYfIRHRGU7]ZJWnD
VH]`EEAiN5A3<Ra1G6UYEdA4?2db@T]@BSa0AdM:AdI:EV]]N9JNVIB>VJfh]Jb_
^/WAdLc2bM7Di^GLkoc^i?GoomSUjn?Sg>WU`/WJg]c4W9^NPGVD^KJY]kZXWZ6D
Pgb@Y::RSG^6SH5]I5mTJ6U[IVE`LG1aLH:0J6=NCT4d=4MEB457DDa7Cd]?D4=5
@Cm7@TMACda6?DMFARhc?cde<351Ad]IFU]IBc@V>TQ5?cXb=STK0008200021X]
@TmBHEmFFVQcKV]eM6e_I6YjKFmjL6n0Ri^VWYB:T9BHZ[:YYZVa]KBe/K2ha=3F
g]_Ae<R]WZJe^;g5d>7RgMoOfMWHgN3NfLoFi?;_fmKJe]CCe=77amCdoo3Vj^SV
elS=a[B_Zk?8gO;ooooooncJc/g>blkBc/:l^kRgZZ6OVI2>RX65OVYECUQJDE5C
D5A@ACHe?STo<Q@@6B0L3PdG6Q0900/L3000000300002APF2P0000080@052@XE
6QLF3a<K8B4J3QTb>C/o@S`X<3Xc9cU8?4MQIVQZIfI_M7=_MhJ:RHnIWIFASI2V
XYJFWZJ/[jZ/Z:2ZaL2jb<S5`/O:a[fodmg[mooooooooooooooooooooooooooo
oooon___gM?Bf=;:aM3Ldl[<c/o4`<2a^/c3^kFe]KkGhM_D`:>MZZjXYj>NV8f9
SIVDS8V6ShaoMVaWJUmPKGMdH5aKDU5;@T0i@4Pn=3a4BTXd81XG41L_=RTR9BH]
>C<Y:B0M9bLc?CTg?Sdo=B@M9BlX;Bdc>ce3B48h@3/`<c`l>49:CT]1>T17B4<e
>4iDA3]6EEiE@Se4BD96HFUYLgAYGeaYOH1oPX62SI^NU8Z1RY^ETYnQThnL/l2i
[:bXXjj`]lO@b/_KiMK7ho;Qbl;3a<>n`]CMgmFo^[[1`[bka=7=_KC0d^GUa[Bg
a<o;e=O0]K>b^l2l^;Vf_<>fZ:NXXJ>^ZjZ^ZZ:LUHb8SJBg]JVSXYNAShj@Si24
N79bNWQ_K71_IEMAGea6<S59HVIKC4YOJ5M1?e1KG5aHDdhl=TeBBEQKDE=FEEIQ
GE1?D4iAF5QHGEmJDDHo@DmJCTE<EE9BEdTk@eidM6=DIGE`Kg^9PgQoRI:X/k_0
/9Z<T::QXK:WUXnDWiZHVIJ>W:N?QiJY/[B/WJ:d/J:QX:J`WiV/[9B=Ogj?SHZ;
XKBjYHR0O8nTViZ`^YZ1Uk>YUYZRYZRLU::d[j2CSHjLXX^4W[k3XH26XK:/VY29
SHn8SYB8PHb<QWMXJ6iYIFUeMg5_JEiMJVMZKF9NI6i^I65PFeUMFeY;@E1_OFeG
?SU5AchlA4ABKf9?C4iSIeM9>SQDJV=OD3P_=cXnACTd?cm7EUMIC3]7DemTE4Do
DGJ0IUAQI6QeKf1NIW5[JGQgGE5[RHn3MGYeIVmjQhN:Shf=TYREV:J`/ZVX_/bi
WhjM`L:f[Jjmc=3AaK>TXkc0/kBn_JbDUk36c<6j][Vk]JFFUYnQX9^GY[>^WYBH
VjFfZiNV/k>ZXJFa_<71^:FLUHZ<UjJVY:JPYJjXYJJPVYVQ/KJMMgREXY5iPIBG
S8V>TYNGRh^HVibNRh2BWXn0NW^9SWmcR:2LTX^5QYBTUg9TKWN3RH=nN6UQJgYh
O8=jLGAaO8=]I5]EK7YcLVYMIGMdHUe]LVAACDiGI5Y2=4A]Ke5AIgMfIVQkME]6
?3eAJWb:SHj<RiFLWHa`J71fOX20QhInP8jCShEfNHF:TJ:KQHF4NWf?TXJ7RhJK
^jV6QiZ@QXB1PhZ8PXnLXij=QHnTZ::NU8V3Q8ZHWiB<WkF/WijPZkZa[kBUVinX
/:^CQ96GWI^MYIF2R92@RhR7LWB;RY>VVGaoPG9SD4eNI5aQLG]aGeeMJh1mNG9P
FV5XIeA;FeeBD5MKDST[>DY>Ef5@?TIBCTY>DeIKHE8k<C4fBF5OASiAHDlg;CY?
BDiPH5aFFVAOIVeLC4Q>DdQ2Ce5DJH6:OGIbKGA]IV]PHVaWIg5/GF1mR7f1PgQc
LgN0QGejPHV:Qi2=O7EnRXUjLg=^LWf7R7I_MhVOWIF9NGf<SHb?RH21Si>:T::U
Uhb8SiVQVG]jWkR_Uijl_:2AWJBERHfBUY:BWJB^/Jf[ZJfg_kZa^/k@_kJZXJBU
Xj:`_Knf_Lg6_;bj_lc5[IbQ];bl_;Vi_;Ze^/Jm]KN[UI>MXj:NWJ>Y[jnVWYZK
VIVLXYf9P8jOV8j<RWaiPWU`JfQ^NXR>OgAkPH>1Ngf8R8::Rh^>OgEnP8N=PX1b
IG^?QVYIIX>AQFMDFFUcLGAlQgmcOX=oNWYdKh>?PgE_JUiPMhN3P8:2Qi6MX92:
T8^6QHVDUhnBW:6LTHj?RhfISgEdT:FRW9VMWIZGP7J9Y9^>VYFDXJBHUZBVVXj8
SI>8Ngf2PX>AY9Q]GFibNgihP8VEUiVMTHjASXZ2OH21Mg=cMG5YNXZ9P7UlPHfE
ThUiL7J0PGYcJVM[KfaRGW1iOX1[GVMcMfQKIF]UK7UbIg^8OGicGV5aMf]KG7J6
OFiWJfAVLgUhLGEjLF9XNg]aHe5AJGI_FU1ACe]UHEE<DUMYOG9OE5EKGEa=@TE<
De=9@TU>C51KGUM;CeQAC59CC48k>D=DHFMPDe1KGeYGFEAAFVMaL69HIGMcM81k
KEiMK75`Nh>6QX6>UX^9UibBVJ6TY8n1RYB>QHF9T9:4QinQWYj>Oh6CXj2?QiV[
[jZITIbSWifER8fT/:j_YiZP[kRj]JVGTJ6`YiRCW:NZ[j^LSYZb]Yn8SIJ>QY>Y
]:J@RhB1VJ>HTXb2RIjYYY^?V:2AQhV9QGmgM7QfM7I`KgAfLgZ1Mf][LgAaKEM>
HVQSI6]_KF]bNWQ[J7b7PX65SY:>TYRAPWEcPIBKS8B1PHN3O7j8RXMnN8B8Ph^E
TXf8RYBCS8^>RGj5W:2BTIRQYjVSY:^QUinWYZ2IU9JHW:6X/J2>Uif<OH:?W9bF
Wj6=P8JCVZ>XWi6AVIjNWJ>YXibJXJn/WYfV/;J_WYbJTiVSY9JBWI^CUj:RViRJ
W9fLT860Pgf4UJ:UUHRARgE[L8:?SXN1OWUjO7n9T8V8SH5gP85mR9F@QGYaLgQe
KfYSGFIbLFi^J61LH6Y[H5]LHF]YH5YQKVaOCT=7CU9FFEYFD4]0>D98D5U:=CQ4
BU1@B4U5?Sm3BTi3>d0n?DA8CEMEB55THeYKHV5SK6]WJ6AXMGijKFQdPXbDTXj9
QH22TYBBThbBXY^=S9FPYjVZYY^PZjZWXZ2KVZ://K6a[:RPV9nY^<:m/:Vib/Zj
ZjN``/C3al32c]3;`kfn_[B[ZZj]ZK>k^K>Y[KNc/;B^Y:6TYZV[Z9^DWZRXWiRS
ZjNNVYNFUi:;PgehN7emOWj1R8j<QXEoNGI`JfY]M7]iN7eoOGQfMVeTKGQcKgAi
OX>8Qh:3QGa]JG9eLGAjMFiXIfa]IfI_Mg1UJFa[LG5YIVIUHEiVJF=VK6eWI6eb
JF1PHV9PHfQXJfaSIVmdL6EOF5EMIF=NEUAPJWEjK5eNKW5SH6Y^If1NJGA`JfQ/
M7Z2P7AcMWZ4SI2<R81eLG5eP81iNWIbNgedLWQjL6UUK8:<QX:4Q7afOHN:QGmm
PHB2R8j:QhN1OgefMX28QhJ;UIZGSGicLgA`LGV3R89fLGQoOGE_Kfi[K7V6PWUl
Q8R6Ng=`KfaRHG1hMgMjNWIeMGA]GU]QJfm/I5iTKgYlKVEWHE]NIFUYLWYdJVee
M6e/LFe[Kfi_M7IgMG9cO85hM7Z2R8R6R8Z8RHV5PXF@U8n:QXfMWIRFU9F?RI:I
THZ:T9^RWYNETY:@R8NDYJJOUif^]Jn/ZJ:VZJBLV9bNW9RCV:6W[JfYYjf_[k2^
Z:2JW:N`[ZJSY:F[ZJFWXj2S[:nYZZZY[:JOW:6^/ZJLVj>YV8V>UibBSYBHWjBR
ViVLU8V?UiVHShV:SIJKW9nQWIJCVZ:RWI>8RYFQY::QUi:KX9fLW9N>QXJ9R85n
Q8J8Qh>>UI:=RX^CUHn:Og=iR8b6OgQjOWaeL71aLW9_KWAnQhN1Mfi_LgIfKfMZ
LG=cJf9QI65MH6ITFe=BG6MaLViZHeeOHfEVIfY[JFUZIf9WKW5fJeMEHVQUGEYQ
JVi`L6]WK6i`L6][LG]nOg]dLG1^JfmlPhAoNg]nPHF8RXb;R8V:RhN2QXnFT8^A
UYRFRX22R8^;Rh^;SHQmOXR8O7MmOWenPH:3PXB9PgYgMGIdLG9gO7eoNG=hOW]e
LVmbN7YiMgAgOGUbK6YZIVIUIFYZJWAmP7MXIg=oP7QaLW^0O7IiOWmoOh66QXB6
RHV6PWmlOhJ:SHf4PhZ;S9:CS8Z;SI2BTiBEShF3PhJ7QH=nN7MkOWmnQHV4Q8b?
RXN:UYR>S8nASh^:R8ZDWj2CS92FVYjNWIZASI2DV9F<S9NQXI^IVIRBSiFDSi6D
Ti6<QXJ<TI:BShb>T92?THb6QXN;Shf:SY6;Qhb@T8Z6QHV;QH:0OXJ>SHN6RXN3
QH9oQ8V;SHj@TI:DT8Z:SYFFU9:<QhB7RhIkMgj8R7iiP8^ARh>1P820Oh23Og]g
M7EcLGAgMVmXIFEVJg1dMgMcL71aLFm/JFU_Lg1ZHf1TIemGFE]KHfQTHfQ/LW9]
J65GE5MIGFAXJFMSGV1WL79/IFETIFUXHfAYKFaYI5iKFeeVL6eWKG5_LGMjNWEd
N7amOhB4P7eoPhR>TXn5OWj3R8Z8RHV5S9>ET8N4R8V4Ogn3Q8F5P825RHb;Rhf>
RhV;Shj>SHf>RXN5Q8J7QhF5RH^9RXj@SXMoNW]nNW1]LWAdMWQjMfi[LW9`Lg=d
O8B;R8:2PX>9T92;QWmjOH>5QHJ1MFmcNWYjPXb>QWanQh^:QH24RXR8Rh^=T8j:
RXV8RHbCUY2;SHn@Sh^:SI29PH:7RXjFW9VCTY:EVINBSH^9R8N=T8j;S9:DShV9
TiVGTXn=SI2@U9fPWI^NXJ6QX9bMWY^FU9BCTi>ASXjAU9JETY6DThb7R8V9Ri2B
T96DUYJFUXn8RY6FT8R2OhN@T8b;T9ZUZ:2IUI2BVYnOViFCVIfMVYFCTHj<RXjD
TI:CSHJ5RXn?R8J<TI:DUiNGUY2;R8V9Rhj<QhF6QHF5PWahNGYlPhV7RHn?SXb:
Qh5jMWV0PWmoPX>2OWIaLG9bLgIhMWIhMW9bMgMcKVQVJFiaM7MhMgMiNGQeM7Mg
MWMeMGMcKFY/KV]RG5iUK71cMG=bLFi]KFe^Kg=iOgmmNWQjPXR9RXZ7Q8>5QhV8
QXB6RXR2NgQlOginO7YjNgYhN7MbMGUgM7MmOWYiNWUgN7UgMgQiN71ZJVY/KFYU
IVebMG=/I5mMGV9UIV5NGf9SGe]KFUUHFV1TI6EWKG=cL6mfOGilNGIeNGYiMg=`
KFYZKW1aLgMkOhN;R8AoOX>8QhB5RXn@Shb9R8J4PX61QXnETY2ATHf8QH:1QXN1
PX^ATiBFUIJIVYRIVYJCTiJIVYVHUI6ATYNKVIJEVIbNXJFUXInNWInTXj6UZJ^[
Yj:PY:>LV9^IU9NJVYbLW9fKUY>=QX>5R8b=S8b=Shn<Rhb=RHB5R8J3PGimP81m
OH64QX^;QhN:QhF7QhJ7RHR7R8R8QhF3PhJ8QhJ4QXR6PWeoQXZ7Q8B5Q8:4R8Z7
Q8:1P820PH1nNWMcKg5cL6mbM7IiNgf2RH^6OWQgNWj0OG]hM7AfMgEaJfMUI6Q_
MGQkNgUfLVm[IfIVHf9SHV9XK6e]LWIgMWIiO7aeL7=hNGA^JVMUHUiMHFM/K6YV
JFe[JFieN7MfN7YmPH:4QXJ4P7MbMg]hM79dNH:7QX5nOGalO7]kP8F4P7ioPH5l
MgIiOH21PXB5PX61OgakO7n0P8:4PWeiN7]mNgEcMGUiMFm[JF][JVYYIfM[LW9^
JfecN7QdLW5aL6e^LgQlOGenPhZ>SXb7Q85oPH1lMg=aM7IjPHJ6QXZ@Ti2=SI2B
SHV;SHjAUYNCShZ8RhjDVinMUY2=T9BFUiNJWj6NWZBZZZNVYjFOVINIW9bJVYfQ
XIfJVYbNX::QWYjTYjJRViZOYj^/ZZJTYjZ[[:RSXJ2QY:JXYJ6QYZVXY::QXIbE
SXZ<SHb:Rh^<S8bAUI>?SiBFU96@TYJCSHJ2Q8F1P8F:Si2@Shf:RHZ?TXj;SY:B
SX^:R8N5Q8N9R8N5Q8F3P7ilP8F4P7alOhF9QX60OWYhMWEfMg=[Ifa`KfYYKgIh
NWYjOGahNX21OWYgMWIgMgIfMWEcKf]WI6IZKW5aLgQjNGE`Kg5_KVm[IV1MH6AW
JFmeMG5`M7UjN7IbLG=aK6AOH6AVIfERIFY[JFUZKW5aLG=dMg]nPXV>T8f6PhN;
RXR6QhZ=S8V5QHB5RH^7PH1oP8>5QXAnN7AdN7anOGakOhB3OginOh20O7QhOH61
OWaiMG9aMGYjMFmaMWQdKfaYJFUVIFQYIV=UJ6UZJVUZJf]WHfEXK6e[Jfa/KG9g
NGYkOh9oNWIaJfUZK6a/KFmbN7n2Q8J7QXJ7QhR8RHV9S8j<QhR<Si2BTi6?Shb7
PGinPHB6RHf>S8Z<U9jTXj2OX:2QWinQWifLW9VETiFHVijOWYjPXZ6QXZ>RX:6T
YZFSY:JUY:>PVYBCTi6=SHnCUibOWinQXIjLVYF>RHV:RXV;S8V3Ogn3QHB3PhF9
S8f=RhV9RHZ9R8V:R8B2PH20P861PH>9RhV8R8N4OganP863QHB1OGYjNWQhNGYh
M7=fNWanOh22PWmmOgmmNGIgMG9`KFUXJfi_Kfi/JFY]Kg1_L79dMGEgNGUkO7]h
Lg5aLWAcLWAfMWIgNGUfLg9aLW=aKV]ZJVY]L7=eMgUjNWUjO7n1OW]kNgMbL7=g
MgIeMWAaLWImP861P7n0P863QHR<Si2?SXf<S92DV9VHU8f8RXj@ShnBU9>AShn@
TY6?SHf>SXb:S8j?SHZ7Q8>6R8EoO7j1PhB6RHZ:R8R9RHR9S8f;QhB3Q89lMWIg
M6iYJfiaMGUlOGemOWmoOWimNWIdMG]oOW]lOh61PhB4PGeiN7MfMGEfN7UhNGan
OhB9RHAoOWinOWilO7j3QXF3PhF6Ri:GUiBAT8j=S8^<RhV6QHF4Q8R<SXj?T96>
SHjBUI:;QhR:Rh^:RhjATi:?SHf=SY>IVYRGVj6TYZBOVYNIW9^HThj;RXb?TI6C
U9>DUIFBSH^<R8=nO7]kOWioPH1mNWf3QhR7QHB4Q8>0OGeoPhF5PH22QhR7QhJ5
Q8F:T92?ShnAT8n@TYFEU9>AShb8Ph60OWinOWejNGUiN7IhOhB4OgYjOGn0PH20
OGMcLgEgM75`LWAeMgUkOGn1Og]jOH:4P7]jNgilMW=bLFm_Kg1`L6m_LWIiNGQi
N7IeMG=_Kg5eNgn0OWemNg]nOWQaKFa]JfMUIfUXJFUYJFY_LW9dLg5bMGEdLgEe
NGn3Ph:2Q8Z?U9>AT8f:R8V<RhR7R8R8QhB2PH61Ph>3Ph:1PhR;S8^:R8J4Ph5o
OGenOgijMGInQ8J5PhB7RhnBShZ4Og]iMW=bLFiZJ6QYJ6MVIFEUIFMYJVYXIfQ/
KFe/KFm_KW1bMGUjNGQhN7MfMGEfN7]mO7amOh:5QhN4PGejO820O7UjOWmmNGQk
PHF6QhV9R8V9RHR4PGn1QHR9R8J7Ri6DUYNFUIFFTi:BTHn<Rh^<Si6@T92@SHZ8
RHb?Si6DV9ZMXZNWYJ>RY:>QWINCT8nATi>EVYjPXJ:SXZ6NWI^IUI2<RXR8RHN7
RXb=SiBIViN@SXn>RhV:RhV6Q861PhJ7QXR8QhR9S8n;RXnBSHfBTY>IVIJKViND
SH^:Qh>3PWj1QXB0Oh24QH>2QXJ3QHJ4QhN1OgmkNGQcLGAhMgIjO7ioOX22PHB5
QHJ2P862OWj3PX63OGIcLF]YJVa^LG=aL7=eMgUjNWEaM7=`KVm`Kg5cL6maMGUh
N7IbLFm]KFi/K6e/L75`LW9bMg]lNgUiNGUlOG]kOWn0P8>7Q8F9RHZ<SHn=RXb>
QhF=THf=RhZ7Q8:2PhB3PGj1QXB4PX61PH1jNgioO7EaLWMeLg=gNganOWeoQhN6
PWimOh62PWihLWEfM7MgMWEhMWEkNgaiMgIhOGUbLGAdK75gMWAaMW]nNgQeLWAe
MWUjOGj8RhZ?QGUkQH5oQGelQ8:0O7UhNWb0QhJ8QhR;Ti^CT9>DSXR6O7n3QHJ4
R8V<S8f=TiZES8N7SYJFSX^@ShjAUY>AShjBTHn<S8j;SiFKW9bUXInU[JBBTiRK
VY6>SXnAThj7QHFAUI69R8^<TXj5Ph>7PWmoOX>7S8Z;SI:CTi>:QXf>QGehO8J1
MWAgOWanQHZ>R8J:RHJ2Qhb?SHfJVIRGS8J=ViZ<Ph67S8IoPH:9T8f:O7=aNX1l
PH5nPH20O7]mP8F3O7AhN7InPWajQ8QiLh6<RhInO8F<QganOWajNXB4MW1aM71/
IfUgNWAbLW=cKfU/OXV8PGIeO7ajMFmdMgj3Q89hOWmeKfMWJg1bMGAaMGYjMFa_
N7enNGYlQ8j7LfehP85gL7R5RhF5QXf<OGb5S85iO7j3OWEhNGIgPHN6RH=hNhN>
ShEkQHb>RX1iMh9oNgQ[HfIdMW=dLgAeOX=oOgj2PWQ`JVmgO7]eL7N3NFUTKgE`
KF9VKWE^H6ERETY8F5U@AD]OI5aIIFQQIViaLW9YI6imS8AhLWEoP7edM7UgOHJ;
OgElQ8V<UI^KW9RFUIJMX9f>PhVDUYFHTYN]/9f=R8R?SXZ;SYnMUYFJYYN>WZFL
Ti6;SH^8TYRHViVFW:>MT8fN/[F^YZJY[JfRWIJFW:>TU8f:T9jQW9NJUi2GWIjQ
X9^@Qh>6QHZESXF:X:NHRi2NVYfGQh>:ThR7TXeoOHN?Shn=U9N;RhnHVI25QiFF
TXV7TInVWXj1RXb2OWYhOi2KUH^6PX:0MFI]LFifOGadNhN;RH=lLWN0N6UUL7n5
L6A/Mh5jKfUaQH=kQI23LGV4RhUoOH64O7AeMg9ZK79fMfmSHVijSI25OW9TEUIL
FU]XN7UbLWEoQ7]eLg1/KViVIgB1P7eeG5EWNGMfN86?Rh9kOH9oNGIkOH1nOXnB
PWQiPh5dL7F4Rh>1TifBS8f;R8MnMgV2Rhn=QHJ7QXJ3OW=`R9:<R7ilP8B3OhF:
RhnIU8jEW:>RSWUmSYNFShfAVYAlLW]oN6icOhV7OH:5PgY_KF9FCDaKKW=THg5e
KFeaN7YfLfU_NG^0OgmmM6eWJF9HI7b7PgifL7InP7f0PXNLZin>SHn?T8IeLGn8
OW^6VZJMQG^5P6mYJgMnP8:;WYV6PXN6P7mnQi:=NgQoP7UiOgUgMg5eQ9:EU9RH
UiJ?SXj8PhfOWi^DSXZ:RH>1Q8>7VZ6CR96PZ:ZNQ7Z5RX:2SY>CRWMiRiVCRXnB
ShZ9V:BGOh2?T8Z8RYFPYIbFXYjDVY^JWZ>QVj2SXJ>PUi:BS8^:OGZ6VI^?Qh5m
OWifLFm]Lh:6O7MmPH1oLFE/OX1jOX24OgI/K7YlL6YbMgIfNh5oLfQ]N7]_KGZ7
UI:3PH9gIVQaMGanNgMnRH^=RX1iM71^JV5PJgYnNgQaJVY`KV]^L7QnOW=YLWao
NFUNIFaWGVIdO7mhJ6^0Qh>2QX5iO8>;RH1iO8N2LVaeQ8R6PH25Ph>3RXf:SXAj
P8V>T8n8PX>>TXYlLgn@U8f2MfmeOH>0P8R@V9J7PXVASXF4Q8VCShJ9Si2=PgYj
OGaeOXN4OX>:R8=eIVM_KfAOGemTJ6YWIfEKGFIZMH21O7]oOh23OGAiOgY`J6Q]
N81oLfIQIgR3PH:=WZ^_YYNBTHj8QHN9SXf;U9jOViJ;Ph63SI>>OWJ2U9jPWI>A
UY>@U9^MV9ZDRXMnM7IoPXV?PWZ3S9:JVHf<WJRRUi2>Ti^MW9fOW9bOVH^:WZ^/
YifHW:BSXZ:OX9nGSI:JV8j6QX^>SiBHUH^7T9FCShF0Q8^ATI>@RXfDUI:ARGj1
SZ2_/jZRWYnUZJ6?S9RLUY:>R8jGUY>=PGQnR89hNX23PWmgKgAnNg9^KgMoOG]m
OgM_JVAPJg]oPGebLWAcKFEOG5mRHVMaOXB9RWmgLFaXJVieOGmiLgR5S8aoL6aa
MWA/H5eQJW5bKF9QJ6QUIG1jOGehL6mhN75]KFaXHEEDGfQWI6=NGFA[NH1lLgAn
PXJ9QhB5RXN1OWQfOH=nOGmmMgV4RXf:OgA`M7UiMGF0SHaoMWA`Lgb3Nf]XL7am
Nh2:Shj;R8>2QXJ4QXZAUI6<SiBAS8b:Q8:<TiBARHF6QX>0OWQcMG=[Jg1bLg9^
IfY^IEaULgf2PG]dN8:3OWYhNX>5PX1iKFQ^KVEOH6AZKg5fQiNMXZ:MVYVDS8bA
TX^7QHZDVYJ>Qh60R9:CRX1oQhn?SHf@T96DTX^9SHnBTi6?RGmlPHF3QXb7P8>:
RH^>SI6DTi:CShV<UIVFU9RNX9fFU9VGTHf;RY2IV9>GWYfIU8b;SHN0OWijO8VB
Thj7PhB6Q8F5Ph>:TY:>RHN6RHb7Q7mjOXbGW9fMVYZPY:FSVY6FWIfJU8b8RHZ7
OX26R8IoO7enOGejLg=iNgAbO81kMg=`MGelMg=]JW60RHj:O79aL6]YJfUQGEiM
IgAiOX1oNWYgKVQ`NX:;RX:0RI6BSHJ9TI:=Q7]fM7n;R81iNGA_L7=jOh:7RHJ3
QHEoO7ekMW5VGVAXJ6UYGE9GJ79aL6abOXF6QHR6QhZ:QHB5P7UkP8B8Qh:2R8jC
VI>1N7b3QH:1Q8RAUYNAQ8:8QgefN7YoPh1gLW^7S8V0OH20OGj3Q8F4PX:8Si2A
SXJ1QY2DTHb5PH5oO8:4P7elO7MfLfe_Lg=^KVYRHVQ^MWejKfahPX9oMg9jR8n;
PWUfNg]fLG9`KFm^KgV7TINKV9FGUiBBU929Qh^BUYFBTYFDTYJJUi>AS8V;TiRF
U8f=UIB?SXnAUYfMUi6<QX1nPHN8O75fOh1nOWelOX1mNWb2RY:DT9NLW9jPVY2B
VYbKViRFV9ZIW:2KUI>ASXZ:RXb;Q7j0PhB3Q85kNWQfNgemO7aiNGn5R8^>RX=n
NWEiQHb=RHF8TIbNW9REUIRITH^9RXj@R8>3QHVATH5dN862OWUbKgIiNWioMVe/
L7ImOgUcK6EVMH>2P7igLW1`KFeXHV5OG5aPHVIbOWikOgmhKVY_NXB5QXR9Ph24
PhB;SHAdJFYaMWEcMgYkOGU]Ig60RHb<RXZ6P7YkNg9/KFi`Kfi/J69HEeiLEeQL
GVEeOh60OX25R85hMWAfPhf9Ph>1Ngn:T92:OgQmPh>4Q860Ph5lOH:5QH9mNGb0
OW]gKfecN7f1QH5jNW]mPX=mN7^1QhfAU9RAQhJ?UIFBSHV:S8f>SX^7QhR1O7Ud
LWR0OWamNgQlQHJ1NG9gPXEoNWYfNXF=SXZ7PGb2QhF4OWA`KVa]LgenP8J9SYJH
U96=QXN<SXf@VI^CQhB<V9jNVY6:S9>GUIJDTY>FUiB?RHnQ[[6/YYR=TYfSXI^G
UYFAShf7PX64OW9]KW1hPhZ?TYNIW:2JTI2@TIJOY:BPVYJHWIfJUhj3Q8nDSH9k
NGj6R8N5OgUkPXB0OGYjNG=_K6edOhR8QGidKG5mQ89nOXB<TIBFUYFGVi^ET8^5
Q8N=UIjNUi6=RHB4QXB2PGafLG=iPH=mM6aUHFf0Q7U[I6QdOhJ6PGQbN7ikLfYU
HVEXIF5NGVA]NGakMW1bNGakOhF6Ph:2Ph>1PHB6RHR4O7MjOhB8R8B3Ph9nOH24
RY>GUiF>Qh>5QhB0MFidOGacIf9SI6ALEeABEf=_MGUlOX>7Qh=nO7b3TIRERGeg
OHR>RhV:R8J8S8b8Pgn1QXR5P7YhNX2;TI:;PgilMWAgNh:4PgmkNgUjOX1mMFY]
O8fBS8V:RX^<SXn8Og]nPXR?ShR0OWYbKfa^LGMiMg=^KgV0Ng=`L6m_LgIdL6a_
MWYkNGMdLGAkP7ilN7EfM71/KgAhOX63QXN5PH:9RX9iNhVCTH^6QXJ:UIfOVI:?
SXf;RXZ6QXV;RXV8R8jJXjBLT8Z>TI6BUiRFU9>DUYJBS8R3OGYhMG9cNhJAU9JJ
WIN=RHbAUYbNWYnSY:2RY:2CRXbGXj>LUHj;SIBMWIB9PhB6RHb=RXN5PWadL7=o
SIB@QWimP81kN7f4Q8:3QhjDUYRHUi>@SHAlNh>AW:6OVI69Ph62Q8B0NgMiO7Uf
N7]eJVAVKgIfLFmbM7IkOGajNWUhN7IdL6a[JfUUGUMEFfQcLFMTJ6eaLWMmPGik
Ng]hNWemOWimOGekM6m`LG9eMgQgMWEcMgn4R8b@T8f6PH>4OgIfOH>6Pg]cK6IT
IVEOG5iPH6=WKGImP7igL6icOXVCUXj8Ri2@RhN:S92@T9JHUiNHVINHVIF?QWin
QXf>TI69PGYeLG=jOGimO7emOH66R7e_KgR1RY:CShZ:T9RJThf<RXZ?TiBDUYZJ
ThMnNWb2RHR0OhF<QgijNh:7Qh9iKV]cP8N4PH20P7mmP8N7QHB5QHF7PGMdMgQg
MWQgMG=fOX1mN7YoPhJ6PWajOXB>U9BDUIBCTi:;Q821Q8=mMWAlS9RKTXR6Q8B4
QhfEVibMW9RDUYZFSHF3PGaaJVU/L7R4RhV5Ph>5RY>HVYRASHZ@VJ2MSX1mPXZB
UXn4OGj5RXV7RXj=S8f>S8N8RXV2MVUTJgMoOW]jNgYeLW9cLW9gNg]lP8N<SHnD
UY:8PH66SYBKXZFRW9RDTI2<RHV<RhF4RXn;PgegM79fO7U^HV9]NGmmNGIgNWj1
OGA_LgUoO79WI6aaL6YVJFY[K71gNgj2QXEnNW]nP7ilPh^<Qh:0OW]iMgUjOhF5
Ph65SIJLVY:7PhR=T8j8Q862QXjCRg]dMWMdLWAbK6ETJfe[Jg9jOGY`IfQbOhF3
P7moOGaoPX>4R8j?SHb@UiVEUIRITHR4PhF<U9JBTHj;R8AoOhB:SHb4Oh69TI69
O75/L7^5Q7YaMGj6RX^<S8V6Qh^?SHZ;SY6@R7imOginOgmnNg]nPX>0OWmmN75^
L79bLWMnOWQ`KFa/KW5fNgalO7ikM75dMg]jKFY^LgYlOGYdKG5jPX9iLg9hP8J=
T8j<S8n;PgUiP8N:QGQaM7j5QhR8PgedLWb5S96DUI:@TiFBRHJ;T8b0N79^KG5f
N7UkOGajMgV1Ri:BRhF7SiFDTI6?RHF8T9JCRhN;TI>IWI^GTi6DUY>>SI2GVY>8
PhF;SXn<R8B3Q8B1OWj2QXF1P8F;SHf=TIJGThb2OX>=UibLVYbOW9>;S9:EThb9
Ri:IWZ2NUHQnOH>5PW]lPHF3P8:4QH>1PH9nNWQmPGikMgAgN7QeLViYIfY]Kg=i
OH1lMgQjNgUeN7eoOGf1PGikNWUgN7YlOGemNWYnPX1lMW9aLgUlNg5ZJgN2Pgeg
MGIdLW5aLg=bL6aZJF]^LWAbKFa^LG9aM7UkNGMhLg1dNh>8R8N:S8Z8RY6GV9NC
S8J2PH>7SY>CTXj8PH28SXZ3OgioPXB3QXEnMWAiOX1lNGUiNWenOGalOh:3QHJ8
SYJGTHZ6QHV>T92=S8b;R8B4RHj?Rh9iNh20PHN7QXV;RHJ2O7b0Q8F5RH^8Ph22
Ri2=Qh1kNGYlOX5oMFm`LgAdLFmbMGIgNX23RHf@SX^4OX26SHn;Q863QXF2PhJ8
RHN1OGb3Ri6CUIJETHn?T8j;Rhb:Q7aiNWelO7elMW9cMh26RHZ;T9JHUYNIU8j;
SY>EThf8QXJ7Ri>GUiJIVYF>QX>6SY2<R8:6SI:DTi6?SHR6Ph66R8J0O7f0PHB9
SHj=RXF4QHF2PXF8S9>GUHj6Q8N<Si6CU9B>Ri6JWI^FTI2>SHV4P7elP8B6Q81n
OhAoL6iaM7ioMg5cM7anPGmmPH5mMFYXK71bJV]`K6a]KGMnNW]mOGYgNWioOGYk
O7eiN7QmS9BAR89lOH23PgigLG5dOGmoPGedKgAgN7]dMWI/JFIOI6USIVURGf1T
Jf]ZJfieLgAcLWAfOHAnNgajM6mcNhB4RI>CS8ElN7j4RY>BQX5jMGV7SH^9Pgin
QXb9Ph1nPh=lNginNWQmOgYhNWYhOWikMGN3SXn7OGj2Q8R<SY2=RHN6QhN9SHJ0
QHInMgIgN7^4QX5oNW]iMgQjPHf?Rhf8Ph65RY28QHUnOX5oP8Z9LF5bQHZ0Jdim
QGN=NY:CPH6?K4BY]Gf[^hIUGgJKKh>gMe]kXXEWKg5XMiYhHI^iRV^@Yh]mOWin
QiF3Jgf7NWn2PWAUHFf;UZ2IN82IVZVm]gn;[jFSY9Z7UJFIWIVEWJ2SSiFOWiR;
OWF;X8U_RYAoQjFMNh2?HFNeYGJ5XHEhV9=kSHQZNj65J8B=S7=bVYf;Q8=oN8N4
Q9^@T7eVNXV?TiB:OXn;R8aoQhUhQI1nKhJLShN9OfYkVYbBNF^3S8eoQXnASXRN
PV^@YFmCOI]gHFeKO8ecKhEhKWZ3RVQSUYedOXQoOH^9NYBTMhBOKDmdUhYjMWJ9
OGMiTHMlPVUnRG^BUVULNGEYHeIRNViABhbCAdAhJUAdLdm=O85YJW]kL81jQY^9
HE::YWagNF=PQGEBNGA_M7ilJhV:SXn2NYRSOFUbR9ROP6m_PH1mMX>7JeY`RXil
KW]aMX>?QhB?TJ>BJXbFL7:Z]i9[IiNTVHMfOXbUW92CJf^>YZ9^JWN4V8fGQgRF
S6j8Ti21N8F;PI>CMVaQN[fgNFAlV8fK[8IAHg>7RGj1RXj8OIBUSfYdQhRHVGIA
QINCYIA^DG2b_Y=jVkbOPYZPXh1YQjBl[hmiIh^KVHaaLWfE_ZM[U;:DSiBDRXJB
ShZ7WIFF]I=mOGInRh=aKVb6QfEhTi2>L5j0V8AhK6J;R7j0NGE]RX1FFgj8I4QM
TXeQKgmZIh>9PFA^RVIjZHifRGF0S7EUGW9jK7:0IgEiKgN4UX1SLFaWQHUXJXF1
LFIREUMkWkk6XHV2U9InOWacP8UmSJZLPVn6ZK>M[9mfTZ2OZ::MMeicU8EkPfec
Tjn9NHY/E6nKWWiLI8:3RgaTNZF9JH^YWH:0P8F:ThIeMFB?b91EO9RBK6edAdiU
KXEfIgZ@SW>0OFj0THUiJFmQFXfJOWISJfmbTH^9K7>:LX:NR7^3U8eiNHb9PGEQ
T/FBEUb;W8^;QFUUQXN@UXM^AfRKL6f0EgFISI^HQi^TOXb[YFThIhmVKgibOFia
K7>@NFN8U75]SIQmTi1[O7E^H6InQGeoJdee]:QQIga^PIRAL6]kTIN[RgZ<NG:M
^Ha/MXQiMiZ8JX66NGZ1Qg1MGFMjTG58K7iQI7YTEF:E/7=UV:6EWhF1R8ZUVIB<
MgbWWWF2TJf9IgVJX9EoP8R5QIFDTX2@_J:9SF=dYXn9V9V?ZZjFMhbNQfJ7]L2G
Tj2D^;>2O9bJLWJ2V8ioS9JHO9FSPHfLJ72`]IEiM8V>LHfWUH9dQ7f=]KJW]jV7
UJZ/OFf<SGfJUW9bTjJ0HG]iP7EJLGf1MfaeLgf>Ng:;LG2CTX:2SYB?K6IZSL2U
ThAbRjNM[kRX[j>WTY6HXYJ2W9NFYYj;JWV?WJ1hDf>?WhR:SgAiOhj@Q7IMHgUl
MXV@O71bLVb0RX9_FgjCIF^@QfQIKGMmKB]0L61NGe4kDW>0KUE6C6AMF6IAF65S
M7YMLW]YMGn7L5U@I7YgFUUaN7YdJg5OC76ARGaaJfIoVWeLLGaCI7mnNeM9CeIh
Pf1IHU=AIX6DT8nETZnVQGi_JXRURW^7Ngn1Q8J=Th65Q8V@SYF7PXVX[i^FMG9e
OI>OUXb2SjN5SZB`[8=hSJNSYXekTLo4M7VXZ96:SXElU:B<N7UXNh=oWXUhOh>E
QX68N7UeMgA[P6m:FYZ^OGN7PXVSSH2QXiV6QIjaWgQhRXBOSg:2MGb?U71`QXEl
KHZ:KHBDY9QbQ8i/JXBGVj>EN8>P[iJ7PXnS]<B_QHFGZHeTKf]bRhFMUVYWLgnE
RX>GVX63W8UiMg1=Hj2=FUUMK8R?PgeiOjViSgjAO6IkTHEaO966TJJUOFUjJFj9
WW]FFUR2VhedIeATY8]_N6IkUXemPXQ[E8>BNXVCP8BRXj6IUZ^XQ7J4TG65XiVK
V9FFXI1fK769W966S8V7XIAFIK6`SI2KQfaIOJ^GR7MQL8:GPVf7Ph:6T9B@Qh:J
V99bDUI`TVM?BTi_KfANPX=<B69[J6eXIV1=IXB<Mf^0Ph>RQfQ/MHfEQWilMG^4
Sh60PWeiT8n7UHAaNYZ?O8UhKh9mPWaSN7mfK6N0OW1LJi:?FF^VWhb6Uh=/KVn0
PGEnS8=nLFe[JgEkU89oU7mgPi^MLf@n;HJ[L4Q;KWQkUI9TAej5VYAgJfe[RIJJ
QVMlTX6=XHUmKEE/Qif;KfANPIR@L5iSPJZCKh]iLX2@UhZ?OG5oR8jCP9>Z]K27
OZVWRIo3^jJWX8b<Zk:MVi6C_:NFV8^7T9Z_WXFDQ86S/ib3N829UjB?MGfLYkBb
S7mmVL35^JfTUK78ZHj4SHj1TI^KTX]jLGB=]j:0RjJh]9EoOGfBZIYiH5UYJfjB
R7IbM96MR7j8OgF2XHM8HjbSLVE^FfRDO6=XJ6IUO6YMG5ECH6mLIfe/M5EDMG=X
Ge=DJgf7JTa^SH>7V9EdNZK1_8elNhEmR:69PX5kR9b4GVR=R8>eX7=PKHN:QHB7
O8:1TZ5/Fh1iKW1bOGYeQFaJQIBITWI`QIfALFb2RHa`@TaYKW1XHWIcK71OGgF9
IEAgMfAMKVQCFY2EJEelPgJIVGYaQiJFTY::RWMCKj^nZWieNXN[WXZ8NW68YHUP
K8=kLiNIIUUUEfj3TIaoME^6`Y]REgZ2TYn?OgegN8F0Q8:1SWiaTYJZY9FAUj5l
L8b>MgefIEZ?UW=`N8eoS9fISXBDUJ>eVg1QQYNIQ867Qi=eMXR6MViiOXFCR6mT
OXYfQga[EUioO6AhPFI^MWMoP89eKX2<XY=nNg9YJ9BFQH^7PWYnR8V:WZ65LWN>
V9^5P81jK6F:PWQbGf5gQg=YLG]mPXN1NWQlTi]nP9>7PYn][IR6QHIoP9fGNWbS
W9FFJGJBZk^YZJB@QIfPUZ6HO6eoNf5EJGEdQWiiQh1oTgi_M8NLRhB3Qi=eM9nK
Mf5aIfBGWH5SK8YeF69]IV1XPgIhPHn7MGJ:RgElMVYaPYRQVG9VTKjhViFEXJJ;
ZKB;T9RIYZFbYHb6R:JfV8RRVH:EUgR5YZJ;PYVOYJR<LX6=TiJJRg9dSI>;WXIV
P9>3SifZYYZFQh29QgMSEEe/NXUjHUAULW24NUIVMU]ZQG9IGfmaMWIdHf9gPGaa
N6maOG9kOX6AQ8>8NY^eUW1ZNgj>TgAWJGb1VHQUM7b7MFj8SViTNhZ0QJBROf5d
UJ6=Q:6IQXR2NHJ>NGEhPX]cP9N;NXRXSVQaUXY_LWn5OfaoT8IkQ9AaGhfFUib;
RgYeRXnCSGf5Kf9nVIb@RX>6Ph^FRgMTIWb@W:61JEIJO8aeFE9ePG:0QfiAH9B@
PXJAUGY`QIF?RiRDOWAoOFZ>U8NCMW2ATH9nRZ2:NhN9Ng>3QX9lLEaMJg24THQg
KVQLKH60SVa1G8ZCTH=TIhFUUHQnK7V6QYF@OVmWRYZCTG=]PY:FVXbQWfegQGYc
MWIMAD]KNYJ1MGUdGfB:P6QdQgMRG7AnMgYSCdA@LGYiK5MBJWUgID]QQgU[JFUh
OHV9OHUoGUESQJ2BK5YRNYJORH:JWJ2NUZ:LUInU_<ffXY>@Z;feWZ:la[fcW8J1
Uk2^VifGRIZNX;:PTZFb^:>7P8^b^Z^DQWmiSJFeXXfDUi^i/I^5LgEnSi1gGV1m
UXZ2SgAKLg^2Qg]_HfIhV8m_Dej8SWU/JWJ;Q7YlPHjPU8F>R9NMUI5nP96JSgYY
N81eN7f1RHYkKg1]N8V>Og=OBVj:Q7A`LW9YMi:>TX]fLh^/Y8eUD72JSW1MDFF0
SgE`TH5YLX6;NfU>EGJ8THioG6QlJhVOQW]aTIB3XYMhOG^9RGIiJF6?[iYdHfei
PhR0L5mbR9^SO75/JGEeMWMaJF9[RHmaGFYiO8NAOeYXT9NAP7QnN864N6UNOZZh
_L2aV89XLj[4/Y1VFWNHXZ:FMff8W8Z3RWI`SIN6P89VJ8Z9PhR9OX27S9:6OhB=
Si6=KgEgLgf?WiV9OWbAW96_/8fGVi69R8n=QW^;QfUJEg:?QY21N8QhOIj?JV9n
UY6?NFU]KhF8JUQMLVmfPWATDdiZMgEH>DMRMX65Pg=OFVAoRhMMDgR6UHEHF6fE
[iImKV5YOinKSIN4OIbSSh9eOYNna:B6QYB>UYN@QW=[NH^FVWAXRI6>QgE[LFmk
SY:8OGIfNGIlP9:MY;bPPI>7S:6DQGYkLg>9RgEXOYZ>LgQmK6mgNG9gNWUmM7:<
TW5XM8F>P79aRIfDWX]TLXj<S9NFVYB6SHnFQHFKTI>HSYNNR7]lU:BEOgaoRWe/
L7^FXiB5Q89mT9^PWI6SZi>3T8Z4Q9VYVWQWOi2AR7f3QXR@NFidK7^2NG^2QgIf
Qhj;R8jDSXAlOGn<RHB=O7R0K5MVNXZARhMcJ69TOG=/O8nFRhE]I79lQGUIBEac
NGF1MUmkN7B0MWeoRi>=Q75hQXajL8F<TiMlH7NGXI:;Rgb0VIV7N7ehKGQbNIVT
QVY^Nh^9QI65PI:RVHN<OV]aKVQlRh1dOH62U8egP8b;Tj^bWiVVYJBNTjJeYibY
WiJ3Pj6TZIZ6LGB?QgYiOHJ@WZ:3MhB0LX>MU6iVPX9hP8EnP7IEF69NIg5kM6eQ
GVYQG65SK7>6RfUdRGIfKf5TNGYWHfMbL5iWPi6EQGQ^MYZIQhZ=WZFER8>?YjNM
XZNUU96ET8^>S7UcMh9nO8V<PgJ0TYFAVHMcRI1lNGR0Nf5ZRI9dH7::S8n;OGf2
MWMfIfUiL6Q/L7YhKfMSGfMRGFMSFUaLHFiiIeeQG5]EFUmOLhI^H7B?XHm/J79i
S9B=PgEoTjFLMUaLLHV3O79_Qh:<Uh9gKV]]PH9fPX=nQIJ5NhnJUiVRU8MoOY^e
YYj6K7R;W8mfL7F1OHRRXHEhQHjJXj6;M7ZCXj68LWnGYJ>?OWb8WjJJT860OX>B
UYNISGnFW8B6PG=nTijYSfQiVj2:Q7A^NGUnP7^4S7AhO8bCNVUnZ:JWUhf;P8jN
Wi^AQH1oRhnGTH6AYIJ=UGf4UiFCSHZ9RhJ=UYN@MFmfNXR@ShV6UYF4NgMgIfEa
Mg9^MH>?WY^FQ7:2SIRNXJ6HNgVDUiVLTXj8S9R7PX^4Q8j=PGQ/HfmnOX67OWUm
TIZAPW9^LGb<Lea]R8fBSViNIFa[JV=QIG9iN6YKFUQZQ7A_OgIdKGB2NgMdK6EM
JGEXFeadQiVCN7]oT9fDSHejMH>HYYV5PZ2a][>;NYJc_J6APFj>V8imKG9cQJ6[
U8J?SiJTX9BET9J;QIVIOG:CTh^GT8NEUHnQWhe`IGZDSX9iJg63RhB2IdmNN7YW
LW1SLX6?RGE/I6YYJF1XGeQjTiR:MWZ1OGfFUhF=RYJTWYZGS867SGYhNfm]KgV<
QG9oKeQPKVM]LgMnNX1lMGn@OgAoOW1lVYjQUH]oS91`EfV2MFmdLf5YQGU`NGM]
IFaaLW5fN6QbS8YdKgmeMFiPIG^3NVmPKgQZM7U`MfA/S7mfQXn1L75VK9:AMGA_
LHN9LUiLEW=aG5iYJG5cM8>>S7Z7UjFLR9:FU9J<N8:GSGR2THF8V9:3QXn8SHn9
RHnBR8Z<Q8R<VWaOLXjGWibIThNJX8]iK5aQOWe`NiBLPX>?TI^0MijTU96T/Z:L
XZNYZHb=XIZ<Ti^X/9FKY9R;P7iiPI6ES9BAT9JYUgehPhYnPhElNXnGSGf1MfEg
RG=iNVMXOXb0L6IeJeabNFakQXZ:Qh^0N6aOIG1`HFahMgIcRI>7JUb>ZhYgQhb8
SJ6VV8n6TJZ_Y9bEVj2JWZB5NHV;SHb7QWYgOGR5UhN=UY2;NX>DVHj?TY2;PXV>
RiRRYIf8Q9FSV7QYNY2QUHJ0MGIoOX5bEEilL61hOWmiL71YIV1PGEUWMWijPgY`
PH^3K6QoPX>JXjROUiBFW9ZAPWf2RXN2NhRCX;^OIF^2Ph5aJX21PIF9RXZ2Q7Yj
THZ5TYZ[Yi>>RXB:UIJ4IfeeLhnERXV:O7^3Sh9YK8>DVIVGPfY`RJVSL5MXO92;
KV9[OHZ@SX1dMWelRiB9SXelMgn6P7EXN89mMfQNEV5aJEmKIVYPG6M`L7QbIVeo
NG1bQ8ejO85[H7=kJ5iZKFihOVmaNWAbOI6DLVb4SXn4IF=/JW=_JFY_NWn:Qh27
NfeVKG1[GEM`KG64MfUZNXf9NH1kOY6ES96VU7j4TYR;TXeeP:N`VX^1NGjAXiZ9
OWF:ZIn=TiBEUinOOWElO96GRXJ1NgYiL7alLVmXKGaoRYAmLGR0OV]SJgF4Thf3
QY><OXJEO6YgQhIoNGV9Rhn?V9b>RH>@VXj;UYfIWJVOS8FP`ZjEWjZSY:VHUYRF
Thb8RhF1PG]oU:RVS8JDXj6DUGimR8F>ThQePj2_[hifP8:2SY>=PH6=YZbBKVin
QWj4TXI`I7j?SGmRGfEYLW5VEDIILF]ZKFEQHVUlR7AHGGN:Wj6CRhN@Ui29SH1/
OHF2PGf4Q8fEQgY[IW9iO85lLGN<WHemOX>1QhN9TY2LYYfKV9:ARH=_L7n0NWIk
SYB9R9>3M7R3UiF4N8^HQGf:PGZ8PXB9Q7f3NfejPgj7NgV6QWemUIJAT8Z6RXf=
TXUlLfmmQGAbNWa[J6M^PG=PG6=SKGn1L6acMhZGSXInQI28Rh]mJ72<VhmWHGAf
MHZAPG5^MY:KQ7EjMFY]LFUULFi]OH65S7MYMHR2OWMYGfF5RVaVHfMnPG5MHWYd
Kh>9OGF3VHImPGinRYF5N82=R8ZEUHj5OG=iTXAbMgilU9Z1Lg1hR:BANH9hLh2D
V7eVLWIeL6i`KFaYHGV>MEQKH65bNWARJhB:Qh=lMWYmMg9cL6edKG22RH]mLWQk
PhF0MX:MWiNKQXBNWiVU[ijO[Zn_Z:je/J>NZjZAQXb;UjJHTYbCU:Ve]j^KUhf:
VZ>VVYRNVJJWTYROW9ZBSHf>TZ2RWIfFRXZPW8>9SXUiNX^>ThelNWYcLgMZIfY`
M7AeKW=nN6IXM6]QKWF2QHV:RY2DSGfAXhj0OH20O8EmQYN7N7J7SH9hMGUiP8n6
OGIfL6ecQHimMHFASYjMRh=lOgmiNFe_S9N?QgIdPG]kOg:0Th1^MXb9MgMeMhR?
PGj0N7B4RXj6LWQnOXB6SiB5N8:>U9B6OWJBXhahNGE^NX:4PGMfNgEiMGb1KUmE
JH67L6AdSH]dNgYiLG:9R7QlQH9mNgB0P7YfO927PWigRZB:Lg9[OhM`HVA^MWb6
Q79dQXAmRHf6Q8AlK6b1QWB1QW1`M7emLgN;Sh6;VJ2NSX9mOhZHW89iTif<RXj?
S8V8S8R4N7^?SY:KTHIhM9:IR7]dO8B4OgehNH><RWEjLVb=T7ecJGQkHUm_LfYW
HV9^M71_Lh=lKgUhM6eSMh5/KVmiQW=UJ6a[N7QbJFIdMgF5T8U]IHJERhJ<QXNF
X:BFPH:8Q7j5RWQdPhF5SX:3S96=S9>CSG]lR8n3Q8J7S8f3QIjJQ8>GVHZ4RYB>
TjVWTX=mNHRMR7J6T9RFR7UbLWUfOh=aLgAhM7AjOWQZH6UhNGAbOHF8QgeoRXVE
U9>APXNVUWMkR9N=MgZ5RXQmNh6>SiBAOg^@UWYTLH^0PYBAPX^KX9f>Q9>QV8V3
O8JHVY27RXUlM7^4V:2GOVR8YYF3R89iN7n2O7f=QGUkNHRAN6ilPHR9VIIiKhnT
TX28UY:@UjbKMfmjRX^<Th^0RXN0PgieQ8YiL7]^JW9iQ8=hLWUhO8b@QH24SIB4
NHbANg20V965RHjFTX^7RH=dMgenNf]`QgYUNGe_OhJ6Q7IfT8mlN7YgJVb7RGYY
JWiiKgfDOWRAV8j7PXV?QH2>THbEW9FDT8B:SXN5QhJ8SiBAVIR4PGenQijLQ7V9
V9V8MX9kMHR8L7:CUgYdOHjDRGekK5]`LVMbP81mKGR=QHF:PG]dNX>7QgYZLh^2
K6YgN7IgNGN3Nf]hP7V0SX]nLgF>R7bIX9ZY[J2OXj^HNWB1QhR8R8EhN8R2OXZ<
OX2:Ogj9ShR1O7QhPHZ8Ng^5QWmlOX24S9:9SHUjQX=cNFYQO8b3PW=[NV]JIG1Z
FU9PJV]TGeiLH6iUE5UWI5MPKg9/I6AYLWIkMW9hOHR>Qg]kQGmhMfaZNGQgP7ek
OHRGRgUaHfI_M8A`I7V1Phn>RH>4QXjCT8^DVXV4TYFIT7V1QWQ]MHR@RXB3QhZ9
T:2GPGMhP8^CU8acNi2HUGmnQ8F<QhZBTI:8QI^YUhbASifPV8IkV:FMTX^BShbF
WIJ8RXQnRIf9KgN3RHIiLWB0NFEeT9RLT7n:S8b<Oi2ITI^LViFBShR1OhV>RgUe
OWYoR8E_JX6?QH2=SHj<RYN2LhnANgN2PhElMh>6PWV0TXMmTHn;R75cS9NESi2?
Rhn?SHUmPY1lM8^JT7j0UiV2NGf<U8F3TI27OXN=P7R5Uh9[LgImPgJ1S8F:SWi`
MGUhNVYLKGaYIWefJ71jNg=gPX1[J7J4R7Y_LGEkKg=nMg1/LWj4NH27OG1^OhUn
PXN3SYJQY8]hRYnQV8F9UYZCPhF8UJ:9IgRHVXf1QXfHTGR2Ui22QgigQ9BHUhfB
WYBBT8V=UXf;SH>5RhFBSGR2OgEiQ8UjO8IbIVImQVePKhN9NfIJFVEhLVQcNGIb
M6]TJWMbIG=nPi6MTHV6L7IlLWIhN79_Mh>@OgAoO79aOG=XHFF1NEeYO7eeMgb0
QW]dPiRBPWN8QgEfQHQcI7imLgIjNW5mQgicJFV0PV]/OgihNW^6PH>7NGAePXAe
K6emUi9kP8nASI29OHB7SinER92PUWilT9J<OX25NGn?S7I_OHb9Lg9iLgUoR8B7
Rgn2TIR8N7ecJX^OTXJ4PH::Y:f:LX6CU8QlQ8bASHAcK8JDQg^0UZ2ATYfGVYVB
V8UiPhJ:PGZ:V:2GUI2@U8nFUifJSZRcW8bOXi>EUY^LT9JCRhnDUHR<WYR8PGn=
VHj>Qgf2RiJGRhMlO8N:QhF1PWf1TiJ6M7=nM7=iNF]LIgMiKFejO7IYLginNg=g
NhJ6L6mfL79[IFUTKW=WNGe[KViYKWMeIfY^KGZAThN0S966QiNLSXV?ShB7Sh^?
Q8J<NGV>R7AhQhZFUhZ6P8Z<Pg]lRhbCRH6=S9RLSH:5VZ2>OGn9TYNHSY6HXZ:@
QXB9QXRERWb0Oh::SGiYI6EeMfIUKWUfMGe`J6ePJh>2PWU`R9jAOXF7OgijNgUa
NWmfMh5nLg9`NGemNFMcO7QfL6AMJ7UiMg=fOWB0YZMnLXRBUHj4PXJ5QH1hM71c
P8Z6NWIdIVj9RWAVKGEmQh5lPXF0Ogb2O75cPWYgOXfGSGj;UY:<P7j4Uin8PIV>
MX66OgV0Ng:0T8QeJgV<Pfi]L6ETJW1nQga]MWUeMh1oP823PGEhNW=cNHF2L7>4
QGaoOhJ3MWR2QH:0IemlRXj9P7V9WJFZVH64S8b;QGIZKGF6ShMiNXZ?QGUhOXF;
QXnFRH^SVG^7TXf=Ogn6PHJ3LgB4Q8J=RH24SYJER8>MY8R6QgF1UHAhPXMiOHF4
S9FDS8J<Shb?RX5lQIF9JFF6UhQoNgN9Vi23KW6>RWAaMFahThafKVYQL8>5N6il
ShYlNgj8PG^0NgZ2PX>;TXnAV9>FV8bDXijBQ8ZWZ9:?SY6KZZRKVi^<QY6ASH1]
OY2;Si6=RIFST82<Th:2TIJ<SIBMXinIXI9kPh^8O7b2OH:?O6EZM6eUKg9_M75d
P7ehNgI^K79aMWi]IgR6R7=YMWV9U8Z9SWf1V9F2PY>BNh2@S8ElQXn8U9J9OGIn
PWmnKfifQ967P8bBShb4RXb6RHZ4QXAhJg29SY63MGicLXB9P7YXJgiiOGimQ8R1
O7UiOHMoMX60PI2GQgn:TXn5R9fLRhZ9TY2=ShMbLYBDPWMmWIfATH^8U9f?PHJ7
Ogn8QWQjSHUWHgQjL7UhKfi_N7]hKfUcOX>;PGMeMHB?R7I_NgamP85fL8>3L7Qn
MGQlR8ilIgYoKGZ:QhJ4Rh^:WIAnLW>1OX6=QW5hOFUWNGIZKG5`KW64Sg]]JfIT
LGQ_Nh9fKGEfPXn2M6MSI6n3Lf5hQ7aeKVe/M7f=RG1[OhYiJgF5RWmgKE9DIfQQ
I71eJf5MIGEhPHYhM8fEQGj=P7^9OH:9NhB0JF1]MgEgNGQfO7mkLWf;T8=kRHVH
Y92DWI:7TIV9QXR=UiJCX9f=Uj^WSXZEUXb4RHf@VZF_Zj6TWi6KVI>KVYFJZZFG
W9V>T9N@TIJBT9FXZIV<SYF4PY:2I6Z?VHEoOgUZJh>4JV=hNfY`NXJ>OX2:RX^7
Qhj<Pgj5T8=jQHEdKWf;RXAjO7]eP862OG5jQh9kP8j>Q7n:T8jJWHYkPi2?QX27
PG>7U8R;THV0MWF0QH:6QGn1PWa^MHN8Ogb1OgnAUHR2QhnDTYZPSHB=U9VGW9nN
Tgb3T8V7RX>7SXnAQg]gQ9:6N7b6QhAoNGYnRXAhMg5bMW]fLWQgK6IbOGQ`N7mf
LGMhK6I_NWj2S8anOhR1PhB1PGj5SH=dMh28QhF6OWJ0ShQlPhAlNW^9UY:4K6^9
Wj2:LgnIX9nFPgYoPhR0KfYbPX^;QgeeMWamMgihJW1oRHf=PhN1NXV@PGA/LWii
Ohf0Ohn:PHN6NgYnSXioPY28N7ImNf]bP6iNL8EoM7QhL75^KV]YKV]VEDeLIfM^
KfabMgAWFV5VJWE]FeeSHeaGHFUZGEQVMg]nNWf5TjBDOgQmRXV:X:2DW:FNVYNH
RXZFSX5fPH=lNWn8Og^?V8j:VJ>ERiNOX9jLXYjLZ:RMWYj?QXB2QhB6Qh1hLWZ2
OWEgQH^:QHN:QX9nOW]oQGYiOGf0QXb8OGV5SHZ<U8anQHnDT8b7QY6CSi6AT8b@
TijYW8f8R8^<Rg=VNXJ9SH^5P7V9VY>?SY><Q8jLW9FCT8^3OG]lNGMmQhf7RH=c
LWamNh5kPHR>SHfPYYZ;R8N5QhR>TY2?TiF=RXJ5RX=kRif:O8N<S8jBU9NKX::I
RXZ>QhJ;PFaWMX9jJ5eNIX29MV]YJg1jOg9_OWANEf9/NW]YJW^6R7efL71kPhIn
LW5hLh2AQGaoNGImM7AlMgf8PWj2RGmiQHenNhB3PhB9PgAlT8QjMg]iMWagLGN2
R8QoNG^1QhYlIfQhNWf6SXJ6T8b:R8J<Qgn4SI2>PgUjPh^BT8V3QhjEViV;P7Ea
Oh9mMfe/JW5jNgYmO7n=T8V6P864NGZ;Q7V3QWQhPX9hM8B=PWE^L7EfNGAWIfia
LGMjPHUnNX66RHInOH68RhV;TY6>SXAlP8^:QGmjO868Qh24R8R5QXJ4QHF6QXB0
OGf6QgmlNgekO81fN8RAV91oR929Rhf6N7YoNWb7Rg9YN7ahMfe_OXEiJFQ`OWmj
O7AeQ96>PhZCRHB7SI2<ThihLgIeMWEYKGn8RXQmP8EeP8j2OX:7QH21R8YnMH:5
QXMnNWmnNGinLg1hQ8AlOH^=Q7j1OH6CUXQcLXJ@SXUiN8B8Shf2PWeoQgmkQXR2
PXfVW8J5TY6DU9BNUHb?T9:HShB@ViNBThf1QHb>Qgn1Ogj0PhZ8PX5iL7ElMgIg
Nh63NW=fOgIXNhf8QXJ;T92@S8ZATIZQThbDXjRLSHR;THb0PXF:RX^?PWV0Ph>8
P7UnOX::U9RAQXJ=U9F6O7QhRhZ2Q8>4NW=gQ8>2Ng9nQ7b0Q7R3RGafMGn;QH2>
UHf5T9bKV8ZAVZ2OV8n5QHjLWiFFV9B@QXZBT89jNX9nNHB@Tge^MgAiQX=kL6ea
PH5bL7YiLG9iP7E/N7UcMGamM6e_M7j0MVYUHVYlRHZ5QhJ7S8N6PG5cRiRCSh^<
TI6GX9^>Qh:5Th^3O866NgenMGJ2P8N@Shn4P9BIUY:BSh^>SYRFShf=RY6DRHZ9
Pgf3S8V9R7edN7mmL6]]LWQbLGQgM7Y_H6j0NFibKFM`O7UdMW=YGVMjNgeiKVm`
M7V7S8=jKWF7S8EjLgMmPgiZIW=^K79]KW1`LWQiLF]XJgV0MFU]L6]YKFmZLW]h
JV1WJeeZM7=dLWIaJGR6OX>2O7UfN7j2Q7]aMX1kM7I`HFEbMg=`LGj<S8V5QX^G
XI9oQi>HWZRLRHZ;Rhj@QFiYM79bO7ifMWn1OXB1Mg5_K7AnOGMhPhF4PWf2RX9i
OhZ;TIVGUHf7T9F?QgehP9BLVI69QhnASI2DV9FATiB>QHR:RI:JW9J=PHFBThj:
RYBDVInGTHfFWiZFTXR<VIB6Qi:CPH27QHZIXZ:GU9RHVZ2QVI2AXJ>JWJBOV9JH
WIR>QH:4PgalQ85lOgn0OgZ4RH:3SI28QhB1Q8f9MFU[LW=mP7IfQHV:Q8N9PX5n
OW]eJW:2Ngf1PWekOHF5P85nOHB9SHV9TY67P8B<S8R8R8>3QH>7R8J:SHEkN7]n
OX><QWinR8j1Nh>8P8>8NWV4QGj2RHj@RhR6QHZ?Si6?T9><Qh^2MGJ0PGYoPGam
QX=kPHEjNGUfNhB8QHJ?T8n;OgenMVabKgEgLFIUMH22PWYdLgj4OhF;R8RCUI21
O7ikNGQhNgQeO7n2QGM/MgabK71hNWImOgn4QgidMH2;Qh:2OGMnQ7elNgZ4QH5f
KgMfN7egLG5jNgUdLX>AU8QfNH68U8YnPX5gO8J7Q8N;OWf>ThMoNgQgLFeeL6aZ
JfATKg>0O6mXI69UI6U^KVmeLFeZKWUhJfIkSHF3Ti2@UibNThEmOGn0Q7agMGAg
NGYjOWYbKFiiRHAiP8^EVY6>RI2@PW]jNXJ:PX9nO8R<N7N3SHj7Ng1ePXF2RHIf
Kgf8OGEjPHF8UiZ?T9:>SYBGShJ=XJJSW9BIVIVGRXVBVIV;RIN@SiV=PHR>QXR@
S8J:S7YnRh:2OWQdO8ElLfiaQ8Z2OW^0R8EoOGmkMgN1T8YgNginQH5lMgn8R9NG
SI>FVIn@QiNQUXZ<RgejRY:;RhJ0PGemQXB3RXj2OX^CVIFAUI^KT8J5QGb2RXj@
PW^5QXR>ShMoPHJ7Q8R7PgYfP7ibMH24Og=kRXAhNgIaKgEmN7n1OHF7Q8ElN7Yi
MgQkNGQnNgYnQH9kOWj8R8:;RX2;U968OGQgMgMeL7b3OGenOX1mOWY_LhEoM7Ad
OXZ4NGUkOXf;OGMnPWIeOGUgO8B;Rh^ASGmmQXj;Ph27S8IoNG^0PWejM7MhOHF:
Si6>TI:BU9JKWjBGTIVNVi:<SI6DRgn0NgUlOHJ<PWR0P7Y`LWMkNg5eMWAcLGj3
L6aeNWj2NWj6PhR<Q7f:UHEdMGYnPgigO7n3P7YdLVidN6e/LWj5O6mdPG=_OWih
NWimNG]iN7=iQX^8PGEaN7QaMGenNg^3QXIkNWaeMWMoQhMiNHJ=TY6=R8J;THnD
SX67QXR?P75/Mh21Ng=hOgiaL829PgV3RHN0O8ImNG]fO8=nL6QXL7]hJg1eLW9d
NWj8SHV0NWj0QX9kPXN>RGinOWaoQWZ5ShF8Si:FVYRHThb>RhF7S8n>Qi:AQhVB
THIoQIFCRhn?RHb8R8Z?T9B@QXB5Ti:8Q8F4QXJ4QXAnQiFBSX60RXEnQiFDSi2=
PhFJXY^BUIF6SI::SIZHTHn?SXMmQ8ImQXQkMgakL79eNXF1Nh64QXV:S8R1TZ2C
S9:GShnBQhF6OWmoMF]/Mh64MWJ5OGN3QGIbO7UcLWYjNGalOXR7PHR1Nh:3S9>4
PhR<Sh5bNiB9KgF:SXj7PhR:Q7Z2OXFFShB3Q8B9RXf=OG:6UiVGSXF9S8n9S9J;
MgJ8QX5jLW1mNgE_J6UVL8N1JgAnLfa`L7UgJFajQH>1P7j8SXj@SHj>SY:=QhZ8
PGMdO7egLfmaOHF5O7b9S8nDRXF7Si:8T9B7OX21OGMmOFiaN7YgMGAeNWYhMgUg
N7YkMgYlMW=fNh61OWagNH^ERh1iOhEnNGN4Sgb4R7]mPHN8RHB6Ri27P7n1PWYk
PgmiPHR1O7alNGIdOX:3M6eeLW5]LhEgKfmbNh:5RWe/KG9kQ8UnLfabMg5_M7Mg
LW1mSHenNX>EVi1oN8>7Q7n4OgIeLGMjOX1iLGV7Qh>7QXJ<Rh^BS8=hR::BOX24
QXV@Rgf2R7imQXZ>THalOhR:PgUaK7=jO8F<Q7^4SXb<SHV>RHB;Rh^3OXN7PX9k
OGeoRhIjOHZ7PGioQ7ifM7EhOgf0Q8N4PXR:SI2<QhfERhV>RXN:R8J8S8EgNHF7
QgibM7R2S7mmOgQiOH62OWb4SIJBQX64Rhf8Ri>BSHV3RYBDTHQoPI29NgAoRhIo
Mh:BT89nRhn=R86:PhJCT8j6RYJKTi>HUIjLUIBATI:ARGmnR8j3Ogj2QhF1Ngn6
QH27Qg5^OGi/K865OWamOh>>UHinQhn2PHZ@U8f3Q8B3NW5kPH64R8Z2OXB>U8Un
PXf;Q8B6PHFARh:2R8N2QX>3RHB1R9JHQHN;PH26T8f;PGZ3SI22PHJ>UXf:TIJH
ThnFXJ6DPX25QXF3OW]oOgj0NGUnMWN1OGMmR8j@TXn0NGmoNgb6QgaaKgMkLFM/
KGEhLgUhL6e]LW1XJg=fMgV2P75/MgU[KWA/Jg5gOWmlNgn3QX5kNgf5QHQjMGal
OGZ8QGEdNGIdJfQ_MGAfPXF2Ng5eOGIeKg9hLW1cO7MbP7mgQI2?PGYnP7aiLf][
IFUXL7A_LX:AShAnQIBMVIFFVY^LUiB=SH]nLWf8PGUkOgn6LVQgOWEbLgElQ8=m
Q8f8SI25R8b:PWn<RX:3QXR=RXR<U966P81eJWAoOW9_LGYnOgUaLhJ<QhR:UHf2
PX^=QWmjPHR>ShV8RXj@TYB6Q8nHWinJT8B3T928SY>CT96KVY66PH9iLW^9RXb?
T9FJUXmoO8J<RH:2RHImLG=fL7AaKh29Qh>6R866ShQhMX25QX^=R8nITi:HWIf=
Ph9jLg9XGfUcOX1gLgF2P7n7QhN:Ti^BQXjBPh64RYJ=OhR?RXfGR7F5Rh1jMWIl
OWQmQ824Pg=_N7ikLfeWI6i^Hfn4R8jHVHn@VHn2MgAjM71`KVe/LGIgMGn7Oh27
Q8R=QWj4RhZ<R7^5TI>JUHjEUY29NFQaLFa]MX5dJW1nOW=ZJ6ecNH=kLfePGfef
OGmoOH:;Q8:9S8Z1PGAWO8J;Y89GNIFGLVfOZi6IUhR5MFIXIGF=WJNKVXn;WjNY
ZJj^Z9n<MfmRJX9VEgjKXIfGX[2QLgBFRgN3S9JTZ9F;VJ>NThf<TI^MVY>6TiZ;
PHbSZ;6jYifLUhjLZIfGVInRY:>CSXajPhj5PX64P7aiLh:1KfI/LVIMH65_LF1Q
JV9EE5Y/JEMCEfMTIVI@AdaLEdmPJFaaN6mJGfIIFg1fJVMYIV]]IVihNGQcLgeg
KHZ5JgU`KFi[LgIeOhB8UHemP8f=Ng5mQ8B>QgeiQiF7PXF3RiIjJgU^LW]gOG^5
U8YhPH9jPhA_J7N1OGYlN7E`IWFJXY2M[Ib@SYNTXIZ=QiZQY:BEVJV`[:NVYIF1
NiVaZY2:XZjOT8f2NhnIVZ^cXI6GXYn<Mgf=TYbW[JREUY^P];RWVjJk^:^XW8nQ
/JfWW[>o/jRUZJNFUY67PGjDXHn4R8B:T8AmP7n1N7EfJ6]kMF9VJVQ]LW5`Lgim
N7ejK5]GDDU@D6B5THjBWY1kK6AJATQFGf9NFemWIUA5ATiHJEiFHf9XHd]3C5UV
Jg1`Mh5gIFQQAd54BE=SGD8lADeBFVM^J5Y]TYF5OX1oPWa^MGabMVmYPI:7QH1h
MfUPHf9VJ6YXIW^4Lff0P7QiO92@T9>FYYJ1RHbBVY^Q[kB]YIfHSHj<PXjBS9FJ
TXB1Ri:BW9j>TjNVViFLYJBQVZ6^ZInSW9n_YjfXWJBMUj6/YijUZIjEUiF?TXV6
Uj:QSX28TXIlSZJOSXn?Si>1LGb5RHfGThN>TX9hOGacIVImVZZNS9V]XXfDUhb>
T8nDWIJ=TINETIVQX9^DVYjEOgJ8QX>:PGR1SHV4SI29RiJFUJR`YIZEU96;R7]j
PXZARhInN7E^KFQHF69/NG]dNWibLhbISGM/KW^3N6QYIE]RLg=/KgR7RGmnQ7ig
NWieLWajKVUcP7adJfIjRHIjKFekOWMXGfZ2SH=nNh2;THikJF=_MVmXH61`KFae
LG>4P7N3SiF>PWUgOXYnIf=]O7I`P7QOGfMSHFA[JFIVI61EEF1OFf9ZJfARHeiN
GEMJHfMYKVibNG9/L7j3OWUdJfUkP61:EEe9Af1WGUmVIVYaM7E]J6UXIfAPG55=
H7AgKG>5RHVGUXj4P9FKRH>>U8Z1OXfQYJVPX:BOXjZWY:2BUj:CSX]nOHJ@SXV<
S8j9N75eM79aOYRNX:J/[jfUVXb3Oh6:T9VXX8V:VYfKW9nUX:6NT9>ISH5^Ig1[
K7]oO7amRYZGSXf3PHjIThJ4O7UmQHZ?V9RESi2ET8Z9QX5jNgj0Oh:;RY6=Ph1h
KgF2RY>KWZ2RXj:OWiF:V:j]WYREShN6QWMhP8>5Q8F6S8AoRYBQWYJKXZjl/JZ_
YifKZ[Ng^;>d^[f`WiZDVjj[Y[:c][R/X:F_[Zf^^/S:^j^d_[R^WYnj`[Nla/6d
/k^l^[Rc[[6f]:NLY::HW9nLVZ:/Wj:`/:fSXJVQUYJ9OX60LVYcPhV4OW=jQgMY
K6efMW5dNWMkQHF9R7MaN7YiKVQWIF][IVUeNFiFC5ALFUEKEeaIAclk>d93<cUF
GeiSI61PGE56CUU8ATi9BDI5AdQ7BT4f?dM6>bd^:b/[8c10?3a2A4Q5?CHd>d18
ASXmBTm1=Si?ETToAeIIETXh>d0m?cToAd18D4e=D55?FEiKGV5SH6UZFeQNGUm[
L6EZLFecLg9aJVUVHFeiOhJ8TiV8PXZ;Shf:T9NCTYNCQGn;SXfBTYbX[:n]Yj6F
Q7nBXJFXZJ^WW9fVYYNAW:6V];Jd_KFIS8^@WJBIT9b//JfWZkJi/Jj][[6TWjJ[
XiJIW9FJXZ2NWYbMWYfNX9nFTIZUYj>UZ:BVYIB=TXnAV9bNW9bHW[6f^/:m];Bi
^kZi/ZNFRh^CVi^DSiBGUI^LThf2O7n7SXMmPHAmM6mfRHf:QhNEUhJ2TIJ>RiVP
W:6PS820QhZ2PgmgNg=ZMGQeLVibNH>8QHJ7RHAkLFA/N7]kOXN<S8Z;T91nN8J7
QXMmNGU`Jg9iOgY_KFi_L7EkMfmdOH:5O7IcKgJ5ThQhNW]jNGIoQWa^KV]ZLGIe
L6mdOH>2NW]lL75jQi2=RhF2Ph>2NgQfO8REU9FSXIjOWYN?RXB9VIjMUhj=Ti>D
UY:?TIRT/kZSSHjFVYFFW9N?W:^/ZJJNTI>PY:VWVIRIUYjUXIVGVInY[j^WYY^C
THN5QhJ3QX^=SXf4NgQfMG9`MX:3O7YjMh:?SiBJUiRKUHf4OhF8Qh9oOWn3QH:3
PGUnP7QaJ69[LG1_KVm[I65[MWA/M7aeLWQfJEaLHEYGHGEjKVU[J6UXIVESHf5S
HEYHEDe7@dIEH69MEEMMGUQIG5aLI6AKI6QOFEeZLg1]JV]WFEUNHV5KF5YPK7Aa
J6IPGV9SFDa>EEQPG5EIEUYUIfQ^L6mdNWYeLViYLGI`IEYLJGMnQXIkNXF6P7mo
NWZ5SHR2MWAjMWZ4RHQoP8N5QHZBT8b:Rh=jO8FBUI:?SX^2O7f3Qh20QHV8PGaa
KWF1TYF;RHf7Lf]]J6YcMgf5RY2BSY2EUIVMVYVEShnBU8f4PX>7RHb?SXR1Pgii
QY6AS8Z@UIZNViZGVjR`/[B_XYbRY9jIVj:RZKFg/JBJUYNJWYB4Ngb8R7f4S8J2
P8B5PH:0PXbATiF4OXV4P8fBTY6>TI>GU8QoO7Z2Q860Oh26Qh>0OGamNgf8SXb5
OG]jN7MgOHF5SYZKViJ9OG]jLgR2PX5mN7EhOGEdNGMkR9BFU8f2P81oNWEkPHVH
VXb4OWIdP8Z:RHR7Rhf6OWejNh5nNWYoPXZ@R8B?UIBDUXn<S8b7Q8^<QXB=VZ2L
W:2RWYjOViBCUiNJXZ2EUj2UYJNTX9ZGW:BWXJ>QUiFMWYVETI:GX:>JSXF3QHV=
S92IVYFHWIJBTXjBUiVFTHIlMW5cMGMkPHfARHAmMWA^H5UHG5aKGf=SI6UbNG]d
L7F3SXj:OW=]JVU[KgAjP8>4PGYaL6m/L79aLG1_LGQgKFIXIf]aL6aWHeiQJG1^
IVI]NHRDTXZ6PWinNW1XIVM]L6aYK75^KgIhN7]mN7^2P7mfI5MIGfE/L7AiPHV=
RhQoL6a^L7V9U9JDT8MkN7QhO8::SHR9RXJ2OgUaLGAeMWYoQHInLfaZLh:=S8R3
PHJ<RX5kN8RHU92EVYZIUI2:P8>=U9NIX9jGV::RXJBOVIVRZZZUViBFUY>@Shb;
TINKWZ2FSiFHVIFDT92EU9:@SHb>UIJ@Si>BS8N5RHZ6Q8F5QXfEV9^LUY>?Si6<
RXZ<SXZ1MWAjOgimOhZCShR6PgQaKVa^MGioOh:5RX^>TXf2PH^@Si>DRh9kMgEi
P85oPH=oO79XIf=QJ79aLGMkMWAeJUiPIF5QJ6MOFUmRHFE[LgIbKVeaM7QkN6eS
GeM>CeaTJ6eXHEmQI6MYJfa]M7]mMfeWGUIEEeUKGfAYLWIcKVIRFEIIGV9WJ6Y]
JFQXIf=SL7ioNG=^K6][I5YJIF]WHF5TIF=QGE]QIf]bLfURJ79`JfY/L71fNgaj
N7]nOWE^KW9hPH^8QhR5PhZFVI67PG]lRI29PXNBV9RP[[:XXjV_/[:]ZJZYZZVZ
Z:2PX9jSZZb_];Rg]kZbXIVLXjR/[JFOXj^`][fn]:ZW[KJdZj>PY:2HUY:=U9ZJ
W9ZJViVGThImOh>7Ri2FWIjGSh^;SY:@RXN8RHb?Shb7QHZEVIbTZZ>DSH]oLWAk
OX2;T8^8RXIoNWIbM7n6QH20O7A^JV]`NH21O7^3RHV7Q81kLVY/LWEiNGQiN7Id
NhB7QGeiNGEdMW=ZGeIKIgJ1PGf2RXR2OgafNgmkNX27RHB6RXfBTHR4Qi2GTHUm
LG5cLGEkOGj2RHn>RhAiNGegLGR2Q7]eN7f2R8B0Qhf<RHR8R8R<RhR8QhJ>W:FV
WY^LVIVKW9N@Qh23QXR;SXj>TiZSYjNUUh^6Ph>4Q7ikPh^7PGakP8J6R8N5QhbA
SXf=PWMiOh>9RhV7R8V<T9BIU8j<S8V6PhB8Q7mnOgijNh23QXR4PhJ7RHJ2Ogj3
Ri:GUI2<Qh^CShN9T9:CTi:EUI>DTXV:TIROVi>=QgmgJVYdOH1oPH:2PhV<SXMl
NWilNh1lLW9iMfebP8B0OgYhN7MiMg=eMW9aKfYZLGYoOgeoQXf=RhAkMg5[JFUS
H65QIVY^Kg9_IfIZJfi]IfIZKVeYJVi/LG^0O75^LW9dMW9^JVabMWYjLfQTIFQY
JVYTGEYJFEYNH5mLGFM]KWF0PWM_Kg5_K6MZLgUhLFi`LG5gO7moO827RHQoLVid
NWYiPHF5RY2AShn=Q7]iNX6=UIJFThj7PX64RY6DUiZFTY2?TY2;QXF;U9fSYZBL
T8B2Ri2BShnASH^;QgeeLWAkPh^<RY:GTH9dK6iaN7n2QHJ9TIBBSH=iMgn2O7j6
RHV:RH:0Q8V<TYBAU96>SH^6O71[K79kPHJ=Rh>0PH:0O7UcL7EjNWYhLg5cNGj5
Si><R8EnLVY/LG1`MWb1Ph>3Q8J8P7=ZJg9cLgMbJFMXKWIfLfe/MWakO862Og]n
PXB5PWmnOXB=SHR4PX:2OgI`M7f6T9RIThf?UYZDRh1dLWIjN6mYJ6Y^MH29S8f?
SXnDUYZJTh^6RY6@RhN<TYBBTY>EVZ2X[:RSXIfOYJBISHR5QXZ;S8f;RXb>SXf>
Shb>SXf>ShnAShV2OGn6RhnDUYJEThj>SXf9R8V:Si>DThb5P7imPHR?Shb9QH1o
OgajMgZ2R8j?R8B6Q7ebKG9iPi6FThb8RXZ=TXj:Ri:HUY2<RhZ9SHn>SY>HUHj6
PH20Ogn2Ph:5QhR=UIJARh9lP8bBTY2:OgZ1QhAmNg]mPXN:RhZ4OGYgNGinOX23
RHf=R81nQXb>S8Z=SX^<RH9mNGQiPH^<PgajMgAcMWE`MGb0PhB7Qh5mNgUmPhB4
RY:BRhAmMgIlP820OX23Ph:0NFeQH6M^LFeWHfEYJfa]K6]aN7YlPHJ4OWYjMgEe
N7YhNgehN7YgMgZ6T92;QH:8SXf6Oh:7RXf?Si:CTIBGU9:AShnBTi:BTiJKW9VF
UYBDVZ2TY9fDTi>DUYNETYFMYJRTVY>=QhR6Q8Z@U9FCSHR6QH>0OGj4Q7aiMG=g
MgEcLG=kQ8b;RHAgKW=eLFYUIV]^L71_LG9eNGeoO7UjNg]eJfETHfI[If9TJFmb
M7E`JfUXIfQYJf]XIVMZJVEQHUiKH6M[Jfa^KVe]L7IiMgEdMG=/IeiGEUQNHF5S
I6=XL7MkMW1`MWQfKVMUJ6QQGf1PIFedNh26RhV2OGYlPXZ?T8f<S8R2P8:3P7n3
QhJ7RHb=RX1iNh>8RHIoNWMfMGEiOXB:T9BEUIJFTXnATiJFU9JIWInPWIfNX9jO
ZJjZXYfNW9JCTI6CV9ZJV9JCShf@ShZ6QhN7R8b@TIFIViN@SHjBW:JYXiVCUING
W::PVIFIWYjJTHV8RhfAU9RLWY^DRhF3PXF7RHR:RhV5PGalP8F6RHb@TiVOWYB9
QHZ@SXZ8RHb=Rh^6P7ioPH:1QHV:Qh:2OgUhOGj0Ph5mNWUmP7ijMWAcM7UoPGie
Kfe]KFaZJfYUHF5RIFY]JFEWJVmbLW9dMgUhM6m^KgEhMgMfMWAcMg]hKfEQIFUY
JF]ZJ6QUGemUJ6U/Kg=aKFmbLWAgNgioQ8V8P7I^K6icMgEeNWM_KFmbL6YUIFEX
K6YWIFQ]KVeaMWYoPGmjMg=aJfUZKG5dMGUnPH>8Rh^:Rhb@UYRCSHZ<T8b7Ph>8
SHb:Rhj?T9BEUIRLW9^LWYfNWIZJVY^JUI:FVinSY:JXZk6h_Kfi/J^XZ:FOVIJE
U9>EVIjUZJVSWIjQWYZHUYBFUiFAShnATI2ATYFEUYZOX9bFV9fOX:6OVYJARhN5
PGn2R8jATI6ATY:ATiFEUIRIUXn5OGQhOGikNGYkNgn6QhB0OgioPXJ6Ph60NgEc
Lg=dLg1^JVYYIfQ]M7UiMGAfNWn0OGUcKVQTIFUZIEmNH69RHF9UIFMYJfe`MWYl
NWMfN7YkNg]jNGMhNgn3PGekNh24R8R3OgejN7YmOWUbKFi_KFe^KVmbMGIiOXB5
PX62OgemOX:8SHb8QHN;SHjBUiRGUYNHVY^GShV6QHB4QHB2P7ehLg1_LGMnPhR:
RHJ3PGilNWQjP8F7QH20PXF6QXN;SHb=TiJDShZ4PXF5PWilOGelNgUgMgYjMW=`
Kfi^M7YlOX21PH21Q8J9S8N1P8B8Qh>3QHN;Si2<QhJ3OGUhNH27RHZ9R8R8QhF4
QHJ7QXV<SHV3OW]nPh>3PX:2Q89oO7MbKfiaLg=dMGQhN7EbM7b1P821P7moOgmo
Oh:4P7n1PXB7R8EoOGj0PhR7PW]gMG5/Jfa/JfeaLg5aM7MjOH>8RXf?Shj7NF]W
If]bMGEdMGUlNgUeLW9aLGAhNgUdL6mbLVm[J6QXJg1cLg=cLW9cMGMkPHJ:T92=
R81iMG=fO8:8RHfFVYNCSHJ2Q8^?TYBDT8Z1NgUjOXF;T9>EU96>S8R5QXZAVZ:W
Z:BOW9fOWYfPXZ2PX9nJV9VJWZ:QWijNWYZDS8>0PXB4Q8:3QXZ:RXf?T92?Shj<
T9JIV9B@S8N4Qh^<Rh^<RXR8QhJ:RhJ3Qh^>TYRITXZ7QXJ4P7ejNX27RXR3OWf2
Ri:AT92=Rhf<QWmkNGYnP7imNgMbLG=dMW]nPHF5Q89nNGEfMgIiOGagLVeZJ6MV
I6EYKG1bLg1[Jfm`JfESIFQ[L75/JFe`LGIkOX24QX9mNGEdM7MiMWEeM7AfMgMf
LVm`M7YkO7]gMWIfMWAcLW1^K6mfN7IgN7MfNH27Ri2DUYJDT8^8RhnBUYVLWYfL
ViJDTXn<RhbAU9JFTX^6QHV=Si6EUI>@SXb5PH1mOXJCW9nNW9VIW9^LWjBYZj^[
ZJJQW9RCSh^:S8f=SXf:QX60Q8VBV9RDShb<RXV6Ph>6QXR>T96CTi2>Si6DVI^F
THf<RH9nOh:3PX1nOh62Ph>3P7j1QXZ:RHV8PW]iN7IbKfm_L7IiMW5/JVY/KVaY
KG9cLFaWH5UFF5eRJ75gNWalNgUfLW5eOH:4QhAnNgYgLg=dMGAcLW=eM6iYJ6]_
LgIiOGimO7afKficN7]lO7]iNGUgM7=fNWn5RXZ:RhR1Mg1_Kg5gNgeoPH5lMFmZ
JVe^Kg9eMWQlOWakNWMfMWYnPHF8R8R8QXF7RY2HWJ2PVY>=RhV2OGinOX65RH^<
RhImMgEhO822PhB7R8R8QH:0P8N?UYVIVYZGUYJIW9fNYJRWYJ:OV92=RXJ5PWmm
OX1oP8B7Qh^>Shj;QhB0OWeoP7YdMG^2QH>2PXB8Rhb=S8V7QXJ4PX62Q8J2O7Qd
M7IiO7elO7inOhB:RhJ3Q8>2P7elN7IgMgIgMW=aLgMjOX:4QH:0PX:0OGMbLGAh
NGIhNg]jNGYiMgQiN7MfLVeYJ6MWK7=hNGEaKfm`L6aXJFeaN7j1PX9nN7EgNG]o
PhJ8RH^>SHV5PX60PXV>TI>BShZ3OWUhNgn6SHn;PgelNGEcLG5cMgaoOgmnOh>7
RHZ;T9JIV9NDTi:?SHnCUiVJVYZJViJAT96BTI:DTXf9QhJ2OGI`JVU/Lg^0PhB4
QHZAUIFCTYBIViVHUI>CUYZLW9ZHV9VIU8f8QX>1PXF:RhZ5Og]jOX22PXB6QHF5
PhB8S8b>TiNFUYVJUi>CU9:?SXn>SXb9RHV<TI>CTi:>SH^8QHJ8RHR9Rhf>SXf<
SHb9QH5mOX65QX5mO7eoP7ilNWUlOh1nNgQdM7QjO7ioOWamOgilO7aiM7AfNGUi
NW]iMW=dMGEfMWMlPH>2OGYgMgMfL6e[Jg1eMW=_KFa/Kg5bLgEfM79dMgMeL6ma
LgIjNgYiN7EbL6i]LGIjNgUfM79aL6m_Kg1aLFi^KFaZJVmdN7f2PX5oOh>5PX20
PXF7QhN5QHN8RXf=S8Z;S8Z9S8f8PGioOgikMgAaLgYoPXF8RXjBTi:BU9FEUIJG
UI>CTi>DUiVJUiJGVIVJWYnKV9NFU8n8QHB3PhF8R8J1OGQeMWIgO8B=TiRGUI6=
RHN7RHZ;SHj?SXZ6QXN8R8Z=T9>@RXB0Ogn0PX>7SIBHV9JCSh^9QhF3PH20PX>4
Ph:1Oh66Rhb;RXnBShR2OGUiNWUjOGmoOW]jMgAdMGEeMWYmOG]hLF][LGEeMGIg
N7MbKV]ZJ6U]LG=dMGEgNWUfLVm_LgQkNgamOGakO7inOGn5RHR8QhF0NWMeLg1_
L7=gNGQhN7IaJfY[KW5bLW9dMGEeM7MmPhN9RXV8QhN9SI6ATI>EUYNIVYZJViZH
UiNDSXMoO7akNg]mOgmkNW]lNW]mP8:4QhV;RhV8RXZ9RhnDUiVKW9fJThf:RXZ8
QHB6RXj=RHN5PX1nNGMiNgamPHB2O7QfLg9gO825RX^9QhJ5Q8B5QhV;RHJ3Ph>1
O7YnPH60QHb>RhEmMgMiNganPXN:RhZ2Mg9cLg9eMgIdM7AdM7EdM7EiP8N9RX^<
RH5jN7QhNWj0PhF3OgemO7]mPHF8RXV7QH>3PGaiO8:8QhB3PX1mNGIfMgMiOhF7
RH^<RXF0NWMhNgakNgf1Ph>3Q8B8SY:CTiBBS8J2NgEeMWEfN7aoPX:2Q8J6Pgmo
PX>1O7QdLVi]KgAjQ8b>S8V9Rhf>Si:BTY2@Sh^5PhF7QX:0PhJ8QX>0OWekO8:7
RHR7QH:2Q89lNh25R8fATHn?T96CUIRIV9ZOXZ>SX9ZGUYNETY:DU9>CUI>=RHF1
P8B6Ph1mOWmoOGYgMgYnPhR>TI6>RhV8QhJ6RHf?T92>RXN4PhF9S8f<S8n>RX9j
MgYnP8B:SY2>RhN2OgakNWUhN7UjNG]oQ8N7R8V<SXn>S8R2NgMeM7MjNWQhNgin
NgQgLg1`LG5bLFi^LWAcKV][KW=fMWAdM75/JFY^LgEgNgioOginOgmmNgUkOh1o
NgUkOGn1PH:3QXV9R8J1NW=bMW]nPH:1OgilN79aLg=bL6m^L79bL7=hO7YiOH:6
RXb:QX>3Q8J:SiBFUIFGV9:<RHV:RHN7QXN5PX60OG]jOH63Ph:1P821PX60PH:5
RXj@THn<R8F7RXb?TiBDU9>?RHJ4QHR;S8f<RhV5Q8>4Ph>1PH:4Q8=oNgYlOGio
PHF9SiJJVI>;QXF6Q8>4QhV7QHB3Q8B4QXV;SY2@S8R7Q7acLGEjO824QH>0O7Yg
MWIhNgioOWajNGMhNGYkOH21P7ikNWQfMWEfN7^0PH1nOWijM6i/K6e`MGYoPGmn
Oh>3P7amP85oO7UeL6]ZJVaaMgb0Q8F3PH1oOgilN7EgNWUeLgAfNGaoP8:6RXb<
RXN3Ogj1Q8J8QhJ4Ph1nOWekNW]mOGalOh61P7n1Qhb<RXV;RhZ6Ph1lNWj4QhN5
Q8N<TI2;R8R9S92ATI6@S8J3PX1nP8:4Q8B1OWenPH>5QhR:SHn=RXZ:Rhf@Ti:@
TYJGUYNGU9:BT92ATiBDTi:=Qh>5R8F0O7akMW9`L7ImPX>5QhR8RhnBT8^5PXB8
RHZ=SXj=SHjATi:ATI:ASXb:R8J4QHJ7RhnASXb<RHB2PH63QHN7R8Z<RXV;S8^;
SHn?RhN4PGmkNGYnPhR;S8^;Qh5mOWmnNgIeNGenO7YfLFe]LGAcKVUYKFm/JFMW
JFedNG]lNWYhMW=_K6a_LgUlO7YiMgIfMgQiO864QHN5PX22PWikNW]mP85oO7Qa
JfQYKG5fNGanO7UeMGMfLg=gOXF7QH>2PhB6R8b<S8jCV9NBSH^9QhJ6QXR:SHn>
S8V3PH21PhN:SHj=SH^7Ph:2PGn1Q8J9Rhb;RX^=Si>FUYFCTY2=R8B1P862PhF8
S8nBUIJCSHR9S8f:QX>3PGeiMgMgN7b1Ph:2Q8N8QhB2Q8Z=SHf>SHf<RhR5QXN7
QHB4PhF9S8f<RHR7RXf=RXEoNWIcLg=eN7YmPHJ:RhZ<SXn?Shj>RhEnO7f0PH22
PXB6RHb;R8B3QX^:Q7elP8B5PWmkN7IgN7MfLfm^LGEgNG]oPXN:RXR5PWmmO7Yf
LW1`LG=eM79bM7IkP8:3PhB5Q8>2OWYhN7QeM7AbKV]/L79cLgAgNginOGioO7Ib
LgEeM7=cLW=dLFi[JfaaNX63PH62QXN4P7j1QHR:S8Z6PWmlNgYjNganOh21Ph>0
OGekNGQjOGn0PhB3Q8J8RXb@UifQWi^FTXn;R8R<SY2ATi:?S8Z9RHR4OWf2QhZ8
PWimOWejNWj3QXV;R8>0P8>5QhR;TIVLW9RETHj;Rhb;Rhb?TI:BSXZ7R8^=SHf>
SXn>RhF0NgYmPHJ8RHV:RHJ1OG]iNGYnQHb?SXZ6QHF7QhR;SXn>SHb8PWajNW]m
OGenOgikMG1/JVY/LGEgMgEcLG1`LW9dMgYlOGinOWemO7alO7j0PXB2PH1nOWam
P8>3PX62Q8J6QH>0OWimOWn0OWYfMGEcLW9cMGMiO7n0OgelP8J:Rhb=Shf9QX>0
Oh24R8^<RhZ:S8f;RHN8Ri2ASh^7Q8:0Ogn0P8>7RHR7QhN:S8b=SHb<S8j?SH^;
RHR8R8N8RhjAT8f:R8J6R8b@TY>DUINIUY2:QH:1P8:3Ph:0OG]kOH20P81oPH>4
PgijNW]nP7mnP8J=Shf9QXJ5QHJ7QhJ6QhJ4PWmlNGUjNGMfMG=cLgAeMgUkOX62
Ph>2PX5mNGMhMgQkP8>5QHB2P7n2RHjATHn:R8R5OgYfLgAfN7QiNWUjOGaiMgMj
P8N9QX9mNWMeMgYkOGinOX23Ph1mOX22Q8N9RXZ9R8J6R8Z:R8N7R8V8QhF4QXV;
Rh^;S8f;QhB3Ph>3PX:3Q8F5Q8B5QHF5QHJ6QhN7QH5lMgMiNWb1R8^;RhR5Ph:0
Ogn0PX9oOGajN7QhNGb0PX>2OWYfMGEeM7EgNGYlOGj0PX:0Oh21PH>4Q8>2PX>1
OgakOhB8QhB2P820OgekO7enPHJ;RhImMWAeMgUkNg]mP8B7R8N6R8jBU9JETi2>
S8Z7QXJ7RhnCU9>BTI:CTi>CTiBEUIBCShZ8QH61PX>3QHR8QXB3PX>6R8^>TY>B
TY:@Shb9QH>3Qhb=RhR6QXF4PGikNWYkNgYfLVeXIfMXJ6ITIVQXIVASIfeaM7Mj
NgakNGMcLG1_KVe^LGEgNGQeMGIgNWenO7YkNWUgMG=`L75bLgAfMgMfMWIfMgMe
M7AeMgUjNWQgMWEfN7anOWn1PH1mOGn2QXZ=Si2?SHb;RHF1OW]iN7QiNgj1PH63
QhZ=T9:CTY6=RHJ8RXb<Rh^;RHV<SXn>SY2@Shj<S8j>Shn>RXF3PhJ:Si6AShb:
RHV9R8V;SHj>SHZ6PX1oOG]kNgUjOH:7RHV6QHN;Si6ATHj<SHj;R8N7RH^>T9:@
SXf>T96ATI6@SHZ8QXB1OgioPH>4QHF6QXJ7RH^?TY6=RhZ:RHV:Rhb;S8j>SXf<
RXJ4QHR<Si2ATI2>S8^9QX>3PhB4PGilNgUfMGEgNWanP8:5QhN4PH1oOGf1QHN8
QhJ5Q8F5QHF7QhN5PGilNgf0PhF7QhJ6R8V8Q7miLg9dN7b1Q8B5QhR9RHN5PX>6
R8R6PWmnOGaoPX>4QHJ9RXR1NgMfMg]oPhJ8RHR7Q85nOGj1PX>4Ph:1OW]hMgQk
Oh:2Ogn1PGmnOh21P822QHJ4P7imOWn0Og]iNWakNg]iN7MgMWEeMGAbLWAhNgam
OgmoOgmnO7]iMWIhN7IfMgMgN7QhNW]kNganPXB4Q8F7Rhf>S8Z7Q89oOWemOGek
MgAeMgYmOgilOGejN7MhNWj3R8Z:R8R9RHN7RHZ;RhnATXn:QhB1PhJ8RHV8Q81l
Mg=cM7=bM7EdM7A`K6a/KFmdN7YlOGUfMWEcLgIhNGYmOh:4Ph61OginOWenP7ii
N7UjNWUjOH25RXf<RHJ4P7aeL6m_LWMjO7akNgf0PhJ8R8Z>TYBDTH^6Q8B4QXV:
S8j?S8R5PGemP8:3QHJ6R8Z8QH>3PX>8SY:EV9VIVIRFUIFEV9ZJV9FBSXR6R8^<
SY6CU9:?S8Z;SI2GVYVFU96>SHZ4P864QXN8RHR7R8R8QhB3Q8B1OG]hMGEfMgUk
Oh:5QhJ5QXN7QhN8QXB4QhV9RHR7QXF4PX61OgekNGQhNGUkOh:4QX^@T8^7Ph61
P7inP81oPXJ5OgemOGaoPH62Ph:2PH1oOh64RHjBUI>AS8N4PWmlN7EeM79aLFm[
JV]]LWMkOh:4Q8:2PX61Q8R<T92?S8R4PGiiMG=cMGMkO7]lO7alNgUkOh60PHB2
OgekNgamOX22PhF6PgiiMgQhNWamOh64QXJ7R8V9QhJ8RHV9R8J3P7imNgYjNWf0
PX62PWn1PGj1QHN;SH^6PGikNWUiOXB8RXb<RHJ5Ph22Q8B3Q8F4QHB1OgioQ8^A
Ti6>S8Z7QhN5Q8F8Rhb;RXJ3PhF7R8Z;RXN6Q8:0OGUjOhB7RHb=SHb;RhR4QH^@
TYBFUiRDT8nATY6?SXj;R8J5PWahNGYkO7n1PH>4QHJ5Q8F5QHN9RX^=Shj<R8J3
PH:6RHV9RHR6Q8B3PXB7RXjBShZ4PGefLW=dLFm`LW5aLfmZJ6QWJ6icLg=eM75`
Lfm[KG9dMWYmNWEeN7MgNgn0PXB5QHB2OGQfMWAdNGakN7QfLG5eN7YiN7UhMWMh
N7^0QHV:RXV6QHF4PhN:S8^;RXV6PX1jLVaXIFATIFY^Kg9fNgn2Q8J9Rhb<S8f?
SXZ6Q81jMg^0PH:5R8^?TI2>SXnBTiBCShb:RHN8RHR3PXB5Ph:3PWmnPHN>TYBG
UYBARXAnMW=eNG]lO7YgM7=dM7MmQXjCUYJASHR2OGj2QHR:RhZ9Rhb;Rhb;RHV:
RhZ9S96CU9:=RXN4PhB3P7n0OgmmO825RHjATi2;Rhb:QhJ1O7aoPhF7SY>ATY>>
RHV:RHR6PG]hMGAdMWb0Q8Z;R89lNGMcLgEgNWanPhJ5QHN5QH>0P8B9RXb7Ogai
NGemOh61PX>1O7IeN7QiNGIgNGUjO7n2QHR6Q8J5P7j0PWmmOWelP8>4Q8B4P7am
OWmnPHN;Rh^=T8f7QXN5QXV<RXF4P7f0QXN6RXf>TIBDSHF6QXB2PH>1OhB:R8>2
QXR5R8n>RH^?SHZ7Q8:6R8V9RXZ5Ph5lNWQeLG1_KW1cMWanPX>0OWYhNG]lOX23
PGYgLFmbM7MiOXJ9Pgj2PGYkPX9oPXZ@TIFFShf@SXb=SHb@TXb7R8R9Rhb:R8J6
R8V4QX^9RHR?Thf;SHj@TI2>RhR3PX>6RXjBTi6;R8=lNW]mPH:4QXN3OWeoP7mo
PX1iMg=/J6IUGeePHF9SI6ESHfIYIVI]LgAeNWYhN7MdKVMVIVYaMG9`LW=fNgak
NGIcKg9bJFQYJ6Y^L7EiNGanO7b0QHB1PXJ8QXJ5PWmmNg]mOH25RXnBTXb6PG]e
LWQmOh:4QHN:R8F5QXR9RHJ3Og]kOXNDX:6OXInMWYbMWINDTi>CUIJIVIVPYZ:P
Y::LV9RFTi>FVIFCUIJFUINETHf=T8^6Q8:1O7f4QXJ;TIBFU96=PgQgNGb0PhN7
PGilO7alPH^?T9>ASXj:PWemPXB6RHb;R8b=S8N6R8Z>SHb;RHEnOGUaKVibMgIf
NgeiMWEgOhB:T9:DTY:@QWmlMFm]KG5eN7]mPhJ8SXj>T8n=R8J<S89iM79cLfm]
L79^L7QiNGj3QXV:RhR8RhV8R8V8PGemOH:4OWQhMW1_L6e/K6igNGYnPh1iM7=_
KFebMWb0OGimO7amPhV9RHJ1P7ijNgUeMgYkPhb=RXN3OG]nP7ilOX23QH=kMWQg
NX5kM7IjOh21NgEiMg=bMWQeMWYiLW9jPXF4PXNAUIBHVI>=Qh5jM79aL79`IfIU
IfijQXb?T96ASXf:Pg]iNWIdOHElLW=aK79nPH66R8B7RXR:S8jARhJ6QhjBUIjV
XI6:QXB6R8^CTi6AS8f?SH^9QH>7S9JJS7f1PX>=TXf?UYBBU96<RXR8R8R7SYJD
S8fCUiB9SiZKUYRKVI68QHN8RH^>SXn?R8J2Q8J2NgUcLWQgNWihMgMZHV1RI6Q^
KFa^KWAjNWekN7n9TY:8QGmdLg1XJfYVIfI_Kf=VJFEZO81jOHV7QHb;R8R3NGAa
K7J4Ph9kMG]oQhf9QXB:SHR9RgmmP7QgLG=nN7UlMWUkMG]mNhJ=SYJJWIN=R8>3
Oh:@QgUoP7YoQ8>5S9fZ[k>d[jBPW966OX69QH62PHF1NX25OGIkOh20LFiaM8N9
QHEgMHV6Mh29Pgj7THF0SH5oS8QlNgikNHF9NG^5P7f0RhZ6UiF3V:>FTYBBRGIi
Qh5`MGi`KG^2O7idFVIbLgU_LGMdSiQmMh>@RXbMThZ0RhYgN8J7NFe`OHInNG]k
OH5hMWMiOg^4Uib>Q7n3QW]jOG=aL7IjNfeEBeU]M75jP7YnNG9nUYfDQHJL[:FH
TIF[[J>OWJJBT:6JYkJHPIRFSIjNThn@X[:HSY1kRIB6VXilRXb?TginS8>0PgMf
V:^IRYRMThN4RiBGVIVGWXf4SXV<U8UlLVm^K6YdOGM_IFf3R6ieYI68WXJ>Rfib
Je2O`VYJUjAmATUNCf^EQ6A/K89]Cg5`>5AWFGN1RW9PPWMFJ81]OhUgRXQMCg20
ESTjA58n6D=fFBh`=U1VCe9@D6f3N7ioMH6GRXFDTYZEWYZO[JJ=JEZE/I2:Ng1k
PH9lP8f8J7RHRHjk^J>i`KJoaJW2cI>>]M:nW:C6^IVBXi>2OiFeZX^5]=S8/KG3
^ko7_j>X[Z2>MXfIQ7amGTQhXiRROE>HaiIaW:ZJXi1jNj^lQWMnLGZ1DU5YI6Yh
JUmJ@EaXGfE<<TaTKV99H8=b?UjFRee8KVmkPf9HQ:B7OX>0Q75WJGJ5T8n5PU17
N70e8C0/=d<d;dA9=Q/O;2PU:Cho>5=LGVMJF79fSHQTJgE^WIQbRiB_X7IfP92I
QY6[Uhf</M:MOiNW_l76cm^mXkZ[Uj6d`K>_ZjR/Z;BiZZbYVHROZj;0`/72^Z6W
b/74el^jf]^cWZ:gY9:PW9j_W9JLRXVCQ7RFUHQgS[:ENFZ5WHATIhRAPWMjIgEg
JFIHNiQdHgESJET_DeeGGemfS85WKWaPCG1[DFM^JVn0Jf29WY:=S6iMMHUnO8Al
MfYaJCXa=TmS@b@`>bXB5S55BSTB5da/F3aADUagJEi/HUQVIVMlLE5EIVMUJX=n
KFe[PYV;QHR;XYbNX:boZ:K0fM2]V9^nd;VGUK6jZi^WY9ZKZ:o3f]C[jloBinkG
g_?Of>GP^kK0^jAoU;:MLF^9QgelPZFVRXRPZjVUXL35UGjGY7UKM8=TKg]/MfQG
J85nMVMPPIF:QYZOT9:RWjBXUiNGPX24IV5`Lgf2MgMjN7nA[KS8b;?3akZh[J>F
N6emNfQB?CDn>1T0004G3A`G3c19FUYDFUmjNg1SHGIhLF9NGWZ2EUEIIgj6QfQa
SI:KY[6RWYbV^ZN9S:2QSVa_OgYTIWQ/H6^3LF=/P8UbP9^JVIbDS:W6/ZF]Z:f_
YiBCXIV>VYnJShJKTVieU9N6QHZ?UHI^J7V;Y95jR7QPKgESGEUED4Y<G5mD?DMW
JfiZHUMUS9fFMW27N6MYLG5QFfeoLda9KG9NJGfU`[k@d<[:blZhY9fHTXB9O71]
FT/P2aXI200B;S4iA4]PNEi7HW=^M8UmIVIICeeNEDQ<B3@/AUIQN7mjNiVVWjR/
`=7@eLVb]l:WU8B9RFEUHeMRHVI`R9ZEUi^_b=oPh?[oi/Fhcmc<a;N]XI:L/ZNP
VYNRYK>m[If[`lK4a;ZRUJjjXX68UW=FHfQQJV59Eg1SH7mfE5QOKiNMOFmaKfIK
FVYYDUAYO7MXK7alQIJFQ7jATXnP^MGZknONh<k0_Z1iLW]K<Ci2;b/jDT@U9CL_
>UEHCe92>D]=@30Y71@O<bT@94E6?4aRJ6EVOgekZ<O0_<K>`:RQZ[>NT9Rad;F>
Ri2@O6mhSi^<T:Jc];2TUhN?Xk>dW8nN_;6Y`JnT]KNo_K??i]_HhnkI_[kBfLZg
Z;6dYI^RYZRW[ZnPXjBQZk>ONXBNRViZGeYNFEIECTEAL7]jO81oN71[QH]bJ6U`
Hde6BEmZF5E]SJ:jf>G]moKVdl:ZTH^3JUaGED/i:QdT<CD/92`Z<dY6@40`;BlQ
:chT520[;cQ=E5eZKV=NL6UGJXF2MWJ3TH]cJ6UPGFEmSXF7VJBPV:2]X8Z3PgY_
MX21PHV?RhZ7QXjFWZ2TYjfl]ZBWXIf`/Kc7];C?hmS=cL:c[k^oXhVFThVDVhmi
MGnLZZ2TZ:VWRW]mO8f=OfMDHFAQH6aeKg5eK5QFIWbIXHeeJ6e_KEe@H8BEWKoT
n_ooo_;XeKJ@O8=iHfEUDc/_;2T_<3M3CeUDCT8e>CX/:bHJ5@`:5RD]=DaFEE]M
EUAHFFa^HG^CTI62OXAnPh1/M9VeZIFKVYVNUY:MVGi]M865PXB;QH22Qhj<UIjU
^lOAf;^WZZnbW9V__LO4a]77`LW<cm?=`;Ve^;Zn/9ZFViVU_:VCUIbVVhn;Ngf3
R8^2PH9hNi6CPWU[I6YbLF5MJWYiIf=WKWYkNGn4PYZibM3LjMg=]j25Ie0i;C]9
CDQ6A2XU>Ce8Ddm=E61JCD<d9b4?00022`hF8cU3AEESGE54=C95EV5gOFUOI6ML
GgB3UZF[];NhZYVFVIR@R7Y/Hf9VJFmlRHb8SHj?WZja/kNc/jjVYjBPVj2//[Vd
/K_6d=KIf/o0^;O1`;Ri]:2JXYb<SYjRWZ>e`;jcY:2QX9jAQHF5Ngf2Q8bHXI^N
Wi>BWjJSVIB8NG]hKfMLIXFI/]Keoooom]k0VGQUEd]0>d58ACL[;3YAJGE^G4m3
?SH^;b@@00000A@[A5]]OXb?RI2JSWYfQ8elJVMSFV=bOi2T`<O2alBm[InEPWag
IV5WGD]7CU]JF69`OX^AYKJaXYB?Ui^DSHB3RXfHX:BW[KgAfmgMem34/IbBSHAk
OHjMUhR>X:FUX9:7OG1aP8J4Mg5/Hf5FC5]`NhR?TYF@S8b6OH6<R8F@VIfOWIZE
Rh>5T9jlfnKQeL:^T691>BL90003528W818TA65XED8i;RTY81@81000014]Bf>7
Yjnd]jnZZ:6DPFAGET8lDfenS9be_[RlaLc3^K:DMfaSG5]JEEIPL8FEUIfYYjNZ
[ZVLUi:<SIBKW9ZR/KJe][_9g>[]j=_?clg2`LS:]jFEQHZATI>IUiVQW9VMXIjC
RhV2MFmiQ8:0OgYeN7MiPH:2T:JZXINBUHf6Si>3MWMkOWikPik2k?ook]K9^Z69
Mf=9;1l[A5EFDT]3CWB8N5a@EU<l7`/000002R<fB5AFIWj:QWmmOXF6MEeAC59P
JWAnPhVGY[K3`KVcZI^CQg5RHF9UJfa/LGR8TXMgL71`NGmiN7I`JVQYJVETKWJ1
Ri>KXk35cl:f]ko5`;Ne/[2`[:NHUIjNWJ6RXj6KWZ>PW9F9Ph5iNGacJFM_OH^B
SXnGXIn@RHZ7P7]hM6m_MWb0QiNKTI>YaMk`l>7@a/BnZ8ajJemJGV=WJEa=AU9Z
Lei1=3]5@SP[8R8R820W<T=AFV5TKGIjP8J:SX^3LFQiRXMkLWB1SINS[:ZRX9f?
QXf;NfeXK71/IUmJIGJ0PhN?TYZY/JbKR8JAViB9QhV7QiV]][Rla<W9aL2o`KZX
U8f>RH>3Ri29P861QX^?UY68P7E[JVmZHV1YLGJ5SH^ATXfDV9RCQ7AcP8R:TYRG
T8N<U8UgLGQlN6]ZNXJ>VIfFS8nITX1XCdM1>3Hf>DACEe]bP7]aHf1[MVeMFf9]
M6]_PhnASXIkM6YLEeYMH6=XIemPHfMbMg]eJf]YIFIZMWejLVm`If1XLgf1O7=Z
HeeNH6V0TIJ?PX6<V9fFTiB?TYRLXZ>SZ;6d[ZBMWjbk`;BVW9NKX:^`YZBWY:BT
XIZFVJ2_`K^ZYjR/[k6b]KNf_<K8`K>UV8n9QHV>RhV8RH^;QWijNXBEWiZAShj5
MG5mPhB3PHBBXZ6KWIR6OhF2M6U/LVm[JW9gM6mYK7=fO7mmMW5cJf5KE4a3>RTR
:C<oCE]VHe]HD5=IBcXd>3m3BEIFE5QPJ6edMgj<V9:7R8AjLfa/KG5mQ8:0QXf9
OGYgMh64OWUgP9BVZ9fDUiB=RHR9PGEnRhR7RHnEWJBXZJV/][fd[j^OUYVW/K>^
Zjfb^KNc^;fi/jn_YIFCU9BASYVQWIRKXj6IUI65OWM]HEaOJGN4TiNKYJR[[:VO
TXI[Ce=UK7IjN7AeOXV>SXemI5=BEUMQM8:9Qh=oN6IBBDM=F5aDE69ZL7QmN71`
MWYiNg][FU]VM7Q`IfQjTJ2NThN3Q85jLg9bK6akRhZ6SYFBSXnBT8j;R8bDU8^3
RYBLYJ>MUYJMYJRSUh^3PI2OWIbRZ:RX[JbQUiFFTI2DTiBJY:VZZjbYX9:0MgIi
N7]lN7IbMH67P71_Lf]ZLWE/H5aUKFaVIVmmQH5mMVaVJgf;QgQcLWYnMgQfL79g
N7E[JfiZGeQIDDU=Gg9fLfmVHVEUGE58C5=JJW9VFeeVJ6Q`MFiUH6EZK6eQE5EV
MGn9UjFWXifKU7aWJG=kN6e]KgB1RX5`IVI/LWZ0SINGVInRX9bLYZjg_/:n]JZW
YZJVYJNSWIbTYJF]/kB^ZJ>ITHV7RhV4Q8>0Q8R8UInLUYBMWj:UWI^GSY:DU9bQ
XIJ7QY:APgj8T9>FVYZIW:2WY9R>P7MdMXfNThZ1MgQgMF]KFVihNGf2O6]QHF9X
LG=fPY:HSh=iLg9`J5mJFFAhRHV0L6=PI6ENFUUBBdmCBchn@T=3C5]XMhN8Oh:7
RH5cJfehNg=^KgN1PgehMWQmQhV?UinUX9fU[J>=Qi2:NW=hMfi[KFa_Mh>9OWMi
NGIdMWE]IW>7SHjGXj>MXZNNU96HVYVNWibMXj2IVj>TWIn[[:JX[:BDSHf:QhV:
RHN3QhMiKW1iNgf0QH^BU9RIUXejN8B4N75aMgf4QH:6SI6:R92DTXf7O79/JVUV
HfI_NgaeKfabM7=[G5ABDUeSHVQ^MWj0NW9`MWQ^GeaTJW5lQHJ8PgYmQ8^@Sh^8
PWI_NHN7R8f>S8jIYZb[Y9jMUHb4QHfAUIZUYjJ[[Jf[[;S0^:bOVj>[[k6e_L2l
_KR]Y9b?Q8:9QWUkRIZRWYJ;OWj0O7UaJVY]LWf8UJFVXZ2QXZ>YZYf=Ph:7PhRE
VIBATY>AUIfAPgQXH6=[IeYKK7MjO81oLVEMCSlm@T4i<c8g?4EDGU]BD55ADeiZ
Jf5DE5E@E6MkPG9NEE15?3`l>Sm=EeUOIFinRhMjL6eZIfMWHUmZN825S9BQYZJ_
/:fZXY^HV9bQY:V/[Z^WYjbb[j2CSX^<Si>FU9NMVYJASXn:QhF9T96<PX6=UI6C
WZNXZ:fd/ZbYYjJTYjn]ZK2e]JfRWiN8OWenNFeXJ6IXIF1JF5aVKFUTHV=RHVEX
JFQ[KgAiNGIhOH1iMW]mMFa`NGUdLGJ4RhMlKFU`LVYKCU9JHfUYJFANFEMFEeIG
G5aIF5IHG5YNHF9WKWQlOHFDWJBTWYnU/L;9^JFPWiF8PH21NG^;VIfOWIN?Q7ai
Oh5mM71ePX^>TIZNUiRLVYRCTI>@S8Z:Ri6NWIbTZjj^ZJJTV8n;TIjVYYbBTIFG
VYJ=QX1mO867Qh1jLgAkQ8Z9QXJ5PWmiLfe[L7InQi>NZ;2k^jnYWhYfLGQmNWAe
NW]jO7ejM6UHCTiDE51>EF5SI6I^N7YeK6=QIfebKfiaM7EhO7f3R8V5P7]eKfUV
JVi]Mh>7Q8F:SHb9Q7U^IV]aJfU_N7j1P8:3PhF=VYjKViRFV9NMZ:nb/k6^[:j`
Zjb^[JZUZ:fc/JVUXYZ@R8F6PW]aKVi`NHRCUYVNW9VOWY1nLg1dNWb3SHf:U::Z
[ZZQVIVGUI>@RX:2QhjBTi>?PWYhM75aM7IlPhN8RhN2O7=dNgmiLFU[LGEjO81o
NH2=RGeeLfmVHF5MF5iSH5]MGf5SHV1ID4Q3?Sm1@dU9AdM;CeABDE=EGF1TKG=g
NWYnQ8R8RI6IV96ATY6=RhZ8RHZ>UjN`/JbTW9>=SHj5N7AkPH>8U9VEU9>CTYFG
UiVETYFFVZJa]JnXYjNRVifPViFIWJ2V[:ZVYjJVZZfXWIB;PWj1QHZ9R8J5QXN<
S89cJVMWIFQ_M7R0Q7miMgb1OG^3SHn8OgalOgioP7]jMWAjPH5kLVIMFEUOIFY]
K6YVI61NG5MAC4mCHFmfMW5WHEeJG5iMF51@FEaKFU9>EFIdNWj3QHJ3NG9`MGIc
NXB9QGmoQhV3NG9cN7eoOGb0Q8Z>TibRXJ2PXj:LUhj5PXR?UIbQYJJWYjBPViFA
SH^FX:Va]k6WXjBRW9fV[JNRY:NXZ:^SUI6DTXjAW9Z@RhV9PgUfMgQmPh9mMgMe
Lg9gOGagLG1jQhn?RXR:S8MoNgYiLg1ZHf1OH6M/MH:0MFi]LW^1OWE[JVa]J6MZ
JF9SIFIXJ6UWJfaXIV=QJ7AhMW=hO7M_JfmeNX::RhZ<TY:?SHR0MgQfM7b:Shf9
QX9kNgn;SHZ=Ti6BUiVLX:6QX9jMVYBDUiNDTY6DUYNJWYbBSHb=Si>@SXjCVYjM
Vj:TXYjIU9BIWIVFUiVKVYJCUI>CV9ZKV9JBTiFIWIjRY:JTXIR@SXn>R8^:P7Qk
OhN>SHZ?TYFIUXYkLFa^KVYVHV5NI6igMFaPDTe=E5QIDDM8CDm@DDi;D5QGDTmE
FEQFCD<o?D5@FeeKF5]QJg9aJF9JFFA/LWAmQ8>1PX5oPHB;Si:IWijMW9nIShfA
VInSY:FSXj>TY:2NW9jOX9jLWZBTViJFVIRGTiFHVinPV8n>RXfGY:RRXZJTWYRB
TI6@U9RJVinUXYNDT8n?SHnATX^3NW]mOG]eLG=hNGYmP7ahMFiWJG9nQhJ7RHN9
TIVFRXB3P8J?THEiMW=]JV]/JfU/JVMYJf]VGUaMG5eMGV9UHE]ED51DF5ICDE5A
Cdi>EEYKFeYLHVYWIFYaM7MgNh61PhZ<RXZ2MVicO7n0Oh66Q821QHjFUi6<SY>I
X:NYZjNQWYjKVjF/[jVTXj>QY:NWYJZb/JfYYJ6NWZ6NVIbOWINFVYJ@T9>AS8R>
UYJBShj9PWj1Q8N6P7]mPHV@Sh^2PXN9R8B0OgekNGUjM6ieOgmcJFihOGicIf5P
HFAUIfIUJFi_Kg5cL6=OIFa]K75cLVi_M7^6Qh5gLG9fNW]iLVaZKgQlPHfAR7Ya
LGEiN7UhMg5`Mgn6S96?RHJ7Q861PGifLW9cO8R;S8bDVi^PY:BPWIbOXjN[YYN6
Oh68SHj8PG]hMWEfMGUlPh^=QWeoRHn>QWmoP823QHV?TXn:Qh^CXJ^/[[:f]kB/
ZJfaZjBW[:f_/Jna/Jn[YJBYZZJPUXn<Qh5oPhN9QH1nQiNQVHIiMgYnOg]cKW9d
M7ImO7=ZIVQZK6m`KF]YHUaGF5MBCDY9Ad=4Bd]9CDm8?cm8Bd];Bda=DEEKH6=R
HVQ^M7UoQHR3Oh23QH=mO7j0PhF6P7b5S8nCThn=Si>DU9FJViVDShnDViZIUiVM
X9fESi6IWjFWXj2PXjV^[jjXYj^ZYJFWYZN_^;BYXIbESHZ@TXUlM7EhO822Q8:3
Ri:@RH:0P7]cJFMYJVecN7]nQ8Z:RHZ<SHjAU8n3NGAcM6mWHV1RIf]`M7A`IUiN
GEiQJ6eYH5]GDU5CDdm8ADM7B4U;BdY7@D97BDI6BDiDFf9WK6i/JficNWioOWQd
MGImPH:8QH64Q8>6QXJ9S8f;Ri6HVYjMVYNJXZJYZjVRX:JX[;:d/Jb/ZjZ[Zjn_
Yj6MXZ^_/kJh_lK3^[Fh^KNj_;R`[JfXW9FEUYJCTIJKXjRSViJBSXj=RXN2Q8N9
RHAoOGQhNWIeMgj0O7IaJF9SL7MdKVQWJg1_K6EPGEUKH6YbMgIZH5YKHf][JW1i
OGakOX9nLVQRGUiOHVQcNgj0OGE`LgQoQXF1Oh:5PgYbLgYmOGanQHjFUYB@SH^=
S8nBTI:CV9bGSHZ;Si2>SXnFW9jKUY2>RhB2Q8R<SXMoOGihKfmeOGmmOhF;TI:>
SHnARH60Ogn1O7UgN86;RhN8SYVQXYVDUYB?SHnATIFJUXf=TiZJVI6?THb6R928
PGj0PXRGZjZLViZQ/jjAQhZ7Og]^EUYZMX>:QhJ?RWUZJ6MSG55:Bda7@TIBE4Pk
?4MEG5]MI6ieNWEWGfM^JfAKDDeEHV9KE5ETNXN>RHN:SXb4O7UfKVmbLfUTKGn8
S8V4RYFLWIRAT9BLW8f6RY6BSHjFWjR`/kB`/;2a];F`ZjV//:bZZZjf^:jTY:JR
WYnLU9BHUiF@RX9lOGehMGMkOh5oP7n1QX=lO7YiNWIdKg5iPhJ1MgV7TY^[aN?d
il6PWjj_TVUIGVAYJEiLJWAfL71aKfeXFda5@C@R6AHI5QDN>EAME4eBDTe9@Sa5
D5EEDU9HI6e/IfMWJW9mQH5mOhB1OGQaKVe]Jfa`M7MlOX:0Ng^4TIbUZZ>EUIF;
P7E_NI6QWI^U[[Jm][6e^kJ`]K6UWifJV9:DVjF`^/G?d/g6_[FZXYR=Si:@TYjS
XJ6QWIRKWj6RYjFLRGYjQ8R1NGElPH>0OGYjMV]WLGE/Jf]TJ7MnQib[WgmeQIJO
UW9KJ7ejHE5BEf=]GUISM7]hMW5cMFE<@455AdY?EF5ZJfegQ8^9QXV9Qh9jMgUm
PhEoO8FIZ:n^[[2a[::LUiNBRH5oPH5mPY2JWj6SYJJWZJ:HU8j8QHB0Oh>9T9FE
Si6GX:6CQhZDUi>:QGmlOh>7RhZ4P866RHV9R8=mMFaZIVEYM7f0OX67SY>DTHN3
RYBDSXJ4S9>FUIVR/;Jc/:jZXj2FSi2;QXV=Tif[`=[]fjR<UZNVUWecM7UfIEQP
J5i@BTa>DTTk<S<^80l62aXV9RPfC5mTHfMVGeaJFEQIFeaMFUm^OH1mNgn<VIZD
TiBGVY^HU8j7Ogj1PXR:RHN:Shj0M7=fNGenPHB2Ng9/Jg=mOgn6U9^PXjBOUiFF
VIZPZkFi_L71_;Vk^[Ff_<2l/ZVTX9jMW9RDTYBFUiNETH^6OgI^KgMmPh9mN7If
NGEaMGAVHFaeMg]oO7^5QX^Ze>odcib=WZB;KEeQJWQoNgJ3SH]jJ6M`LEm=BTXf
7@d83QXQ9B/a>TYEDdXo=Rh^<Bh^>4ABGVYaJfE/M7UnPHNAV9B?RH5hMWb2RiFG
UIRMXZ6MTHAlM6iaOHZCUY^MUh^7T9FEUiZKWj:OWjBXYYjLXZB^^kV[YJ>LVI^O
ViZSZJ^_[JNYZ:R[[:^WXJ6UYjZVWIJ?PWYiOh:4QhJ9Si67P8^GVYVDSX^8QhZ=
SHb=WK[BiN?1WI2<NV5CEfI]I5iSHfI[JDlnAeEC@cHe>2lJ20PD8R`f@UA[NWQ^
IUiFDU1>FFeiOHVDUYJDTYFU]l30`lG6`KBVVYFASXnDUYj[YiN?TI:>Qh=oPH^D
UXj5R8j;QH>2Qhj=RXnDV9^JTXjDUiRKX9nJUiF>RHR6PgmnO7f4RHJ2Q8>4Q8R<
SH^>U9VIUYJET8V2OX:6QHN<SX^6Og]mPGe^IFQ^NXN9Qh=jMWnH]]7VeZjMXIf6
KfmlOWAhQh^4P8B0KVYiQGiaLWQaG3dV9bh[<Ca1Ae=GCdI4ATE0=S<lBTm@F6I_
LFmVG61cOXNFXJ>ER8:0P7j2U::XZjf[ZJnh]:FHU9>AT9FNX9bKVYFAUZ:_^[R]
YJBSX9VBT9BQ/;Jd/[2/XIF>Si2;QHNAVj6SX9^FTI2AShb9QH:4Ph20PHB6QHF7
RH^@UY^JThj5MWJ4SXUoQ8b=RhF9TI6IWZ[1dmFiWIJ>OFMPKgf6Ph66S8f0Je]>
BeAHFemOGUE2:QhN5``83QhfCUUCBT4i<B@P9Rhg>d56@d=7BDY?H7B2SYJOXiZA
SHV0NXFFWjBZ/;BcZiIlK6Q^MX6>U9B>QhAnMG9jP867SY>BT96;OgEcOHbMZkNo
`KZ/XIfNWiZNYjR[]K^l^;Ng/:VWYjnc[J>HT8Z8Ri:JXJBWYj>FQ7]gLVMKGVmj
O8:6OG9^K6U[KGAiPYN`a[fQVhQ[HF=aLWElNWQeMWM_J6E]M79dMgM^GD/j=C`n
@DeLJg^7QX>5R8F3OGEbKVaYJFi^MX>9RHN:T9>P[ZfIQhF5NVe`QYFDSi>MYZb_
ZIjITXAcJfifPX^;QXJ<RXF8SiNNXZF[/KB`ZjZWXYjLVYVHVZ2VZJZXYJ2JTXR4
OW=ZJ6e`KW5fMW]lNWQeKf]XIF=RH69TK7b5T9RKWYZAShf3OH24PGj5TYRHWJJY
Yj2LVIVIU8j7Ph5kN7j7RXJ1OgU^IF=UJ6QWIfQYJV][If9PH65QIV]ZIfAQGE]M
Hf]_KVi[JFESH5mLFUaMH6AZLgYoQHR6PG]fLW1_KFedOXF9T9ZNWYfOXY^?QhV9
QGn1QhR<U9jUY9nKUXn:Q7ekO7amPhZ?TI2AShJ3R8f:Ph67SY:DUYB?SY6GWZJ[
[jnZY9fIXZf`[JNRX9jKV9FBSXN2QHR=T8^9SHf;S9FJVinNVIJFU8]mMFm]M7Yn
RiZRXYF;SiN@R8VATXZ2OW]mOgijNGQeLVmYH5E@DE9DEeICCD=1@T95AdA4AD]F
GEiQIVUUFeEBD59FG6I_M7MeLFmYHUmRIVY/JFU[KgAgNGanOW]fN868Qh:2QXN:
SiRSZZja[JRVZ:^TV9:DVYnU[[Rg[jf`/[2^[J^WXYfLWj6OUHj=RhZ<TYNGTi2B
UI><Q7YbL7=iOXB9R8B0PHJ>T8nAU9>@SY6CT8f6P7moPXR>THf3O7QfMG5^Kg5c
Lg1_Kg1^JfUZKgQjNGj7RX9kN6mQFf=]KVmgPX^DVYN>RHN0N7IeLg1`LFi]Lg]m
O7YkO7I^J6MZKF]YJg5fP8N:QWmiLg9fNW]jNWYjPHfFV9FCT8nAT8b8R8R7QhZ@
U9:@SXb=TYNFShb;RX^<SHZ4OgekOXF<Si>JWIRCTiNCSHV7QhV@V9jRXj2ITHnB
UIRJVYN=Q8>4QXR<SXf=RHJ7Ri2DTXV8Rhf@TI2;Q85nOGn0PH:3Q8B5QX=nMFi_
MGUjNgelNWMiN7IeM7IiOh:2OgehLVQPGVE[L7AdLG1dP8Z>S8=lNgQdMgn3OWMh
NgahMGQmPXF7QX9lNGMfNH66R8AlMG5aLW9aKfe/JFYaNWikMWAaLGIjO7QaKF]/
L7AfMWMeM7MjOX>5PhB6QHF9S8b:R8F3QXZ:RHV>TXn:RY2@Qh>6R8N:SHj@Sh^6
RHnBU9bRWINJY:RVXj2JShJ6SIJJU8nAU9VMX::QW9JCSHV7QhN5P7n1QX^;QX5n
O7QjOh1oO7YeLWAlOGI[Hf5UJFibLg9_KW9iOGinOWYdL6e/K6iaLg1ZJ6iaL6md
O7agN822O7=ZJf]WJG9mQHF4QXF3PGegKVMTIFY^KfaXJFe_LgUkNGIhNWUgN7Uh
MW=dO8>6RXj@RGmiNh22PH61P865Rhn?SH^7OWb2QhV9SIJNXj:OWYfKVIbQYJV[
Yj>QXJJ]ZJ:NWj>UYZZ][jjUW9VGU9BFTHV9T9JGUI29OWEcMWb3QGmkO820PhV;
PG9ZJficNgmmNW]oPX>6QXF7PgilP89iL6m]J6QbP8R9QhB1O7IdMgUiN7MhNWYl
PhR8QX9nOWmoOginO7UhNGaoPH>7Ri2CUHn5OgeiM7AjPH5lMgIhOX>5Q85kN7^1
QXJ3P7]gN7j4QHB4QXB1PXR=RXJ3PX>4QXbASH9hMWf3Q8:0OWakO865QXV>ShZ9
Rhj?SHR0NGMhMgEdMGQnQXf=RHN9RHN9S8^8RXj@ShnAU9RKUY>DTXf9S92@RhAm
MG9eNW]gM79bM7EgO861NgAeN7UiO7mnNWb0Q8N:T9:BU9BCUYVIV9FCSHZ@UiRC
RhV7Q8B9T96>RHR9S8j>RhEnNGEbLFi[K71eNGUjN7IgNWYgMGEiNg]kNgYhNGj0
OWYgN7UkOGioNgA[IF1MG5iUKFiWH5aJFE]LG5ePIVi`KW1gOWihM7=eN7]mOGim
NgUiNgf1R8nEUiF@RH5mNgYlPHN7R8bAUYNFThn:Q7ihMGMjNGYnPXJ:Si:DUibP
WY^HUI>BU9>BSHZ9S92HW9nQXYnJUY6>S8f>RXF5QX^;Qh:1PXF4Ph>6SHj:QXB2
PGilOH61NW=`LWEdL6mdNX23QXR:S8Z7QH5lMFm/KW9fMW=bMW]jMG9^JVAOGEmT
JVa[JfibM75`M7MhMWAbLgMlOh:4R8V6P7eoQHN3NgAbMgn2PH22Ph5oPHF7Q861
PhJ9RHR9RHR8RH^?TY>@RH>3QXJ5QHN9R8R=UI^PXYnJUiNIV9NFU92<R8F8SI>D
UYNHVYnSY9nHTXf8PWn3S9JLWYjKUY6?T9:@SHnEVifKUY6;QH60Q8J5Q81lN7Mi
NWMfMGAdMWb5RHR5P7akOH22P81nP8B7QhJ4Ph>3Q8>0OWenOGamOh:3PX>4Pgml
OhF9QXB2P7]dLgElPhR:S8b;QhJ6QXF5QH>3PhB4PhF8R8N3P8:6RXZ:Rhj@T8f7
PWmoP8:2OWUeM7IjNgYjN7MhNW]hLfaUHVAUHeiLGfAZKgImPH:0OWn0OGQiOG]g
MWYmOh64Q8F9T96?SXj=RHB0Ogf1QX^?TYFEUYJGVINEU9:<Qh>4RH^<S8V6QXN:
SHf>T8n=Si:DThn;R8N9S8b:QX5nOGmnO7akNGEbMGb3QH=kM71_KgAjP8B2PH>4
QHJ9SiFJWZ:RWijMViVETHb6QHR=TYFCShf:QhF4QH=kLFe]JfENEE9EFEeSJ6UW
I6=UJ6a`LFeXI69PG5iPHF1OH6EZLGQkNGEaKW1bMWUhLf]WJg9fLfaXHf5QHV5R
IVQVHV1RJ6a_KVUYKW5aLWV1QXJ4Ph:4QXR:RXN3P867SI2CUIFFUYNKWijJUHn@
UYZKVYRHV9F?SHf?Si6CSh^:S8b:RHZ;TibPX9jMW9ZLWj6RXJ2MVYVLWYjOXJ:P
VYJCTi:;QhJ8RhnATi>ASX^:RhMnMW1ZJVa`LG5cMgb0PX:1P860OG]hLg1_LgUm
Oh:3PGemPXF4Q8>2PX1nO7j2PGekNgn1PGeiN7UjN7IeMGAaKg=kPhN9SY2@T9:E
Ti2?SXj?T9>FUYFARhB0OG]iMWAdMW^3Rhf8Q8:3Q8B4PWejMFm^LGIlPH9oOGj0
P7elOh:0NG=bMGUlOGahMWMlQ8Z=RhJ2PH:5QhR7Q7miMgQkO7emNg]iN7IdMGIf
MWQlPXZ@TXj:QhB2P822QXR8QXN;Si2=RXN4P7ilOH21PhB6S9BJV9FEUIBCTHn;
R8R5PH:5RHb?T8j>T9BFUiRFTHZ8S8f=S8f@T8f<S92GWjFUXZ6RX9fKV9JGV9VJ
WIjLVIBAShb:QhB3PXF;S8V7QHF3PWijMG9_KF]/K6eaN7n1P820O7E_JfQXI65O
Gf1SIfMVJFY^LWMhN7A/HeiMHFQ/LGAbKfm_L7EjO7alOX1oNgUgNGeoOh>7QX9o
PH60OGQdMWUiN7Z0PWilP8>3PHF6QXF3PGn2Qhb;Rhf=RHJ7QXF2P7alPH>7RXnE
VI^ITXj<Rhf>S8=lP8F9S92ASHR5P7UiOH:1NgQhOH:5PGj1PGegN7n3PGn0Ogim
O7UjO7ilNWalN71_L6m]K6ebMGMfMGIhOXB7Qh5kMg9bLFeZJ6Y[JVY]LG=fNGQf
MGAfMG9`Kfi/K6ifPXJ2Ogn1PGn1QHF1PHJ:RH9nP860P820RI:ARhb>SHV3OWQg
N7EkQHZ<Si>BRhR=TiFHVYRDTi:EUiJ?Ri:KWinLVYJ?RXJ5QX:2Qi6JX9nIUi::
Ph24QhR8RHb@TI:ATI:;QXN=TYFKXJ:OV8n:RXb>T9VQX9nTYIfDS8Z4MW1_L75g
O824P7QgN7b1Q8Z=RX9gLg=dLVm_MX::QhB4Q8QnMGIbL7EoR8nATY>ETY2@SHV8
QH22QhZ:PWQbJF9PHfUZJW5hOWehMgMfLg1aMWn4QX^@THn;RHJ4Q8V<RHV=TI6<
QX=oQHnGW9J?RhJ4R8V3PWiiN7anOWYdLW1ZIVabLW9_KW1^KG9iP7mlNWEfMgIh
OWefM7V1PhB3P7ajNGUlOXB<TI2:QH5jMG5bNgYaL7IbM7YgNgimOGYjPhb;S8b5
OXB?Thn8Q8F<Ti>FV9VNUHR6Q8>5Qh5fM7^8TI>CTi2?S8fFX9bAS8R4PHF?Ti:D
TXf@VJ2QWifLWYnOW9RHW:2MV9bPViF>Ri2@S8R4QH>5QhF4Q7YYH69YKFecNGn3
N75gNgUbKW5`J65SKWIbHeQIGV9RH6=TI6efN6iVJVi_JF5OGUeKFe]KG5aGDe1@
EUYJG6Y_LWA^JV]aMWQiO7ehM7R1QXF2PX24R8R:Ui9oP7j3S8F2S8n@UYbPWZ>X
WiRGTIJERiBJVIfHTYBIV9NDUYF@U9RGWJBPVYbPWYB=TiNJXJ6JTYBIUHF2Qg]l
PX28S8b:QG]]HEeTMWYdNgf0RhR2Ph60P8:2P864Ph>4PWiiO8V@SXb?S8F4QH5k
OX>2P7^1RhB0QH^9Ph22OWUlQ8R;S8j>Ri>JUHj<TYVCTYZFTiFCTYJQWY:HXZBU
X9fMV969QHB9Rh^:RXV:TXYlO7f0QWi]KG^1OWUhOHB0N7j3PGilOHB4NgMfMgen
OgYfLf][NGUaL71`JEUGHVAUH5QNJFEJDe9GFEQED55=CeYNDSllBeABF69_M7Ec
Jf1PK7UnOX1lMGYnP8MoMWMmP8>9T92=R865RY6NWY>ATiFHUi6?TI^SWI^PW9JB
TIBPZZ2HWZ2RX9:EXZ>QWj2QVINIX[>e[KFo^;6/Z:bXXjN[ZIjKXJ>MTXR8RhZA
UYF@SYBDQh>7RXf4NGb9RWieO7m/A2@_F82X_:jJOEY0:Ra@Nj6cXX1QBSe4HX2C
W9J=RH9iKW1lNgR4S9>LXJVPPVigQXR:R8V>SHV6Ti^MVHj:RhfASh9bK7B1SY6;
Q8JATXInOW]aM8Z:K5i]QhQaJ7V7QGR0RhAbLXJ4M7N7UI^KV927Nfe/MGV0U9Ym
ES0W@UQRK8baW8b<Q95jCP/000l[CGRPYX0f000JAU=OMW]E;BiAKGf<QViFIXb>
QYN@GBlZCgb^jNVkT75JFF::/ZV1H7jca:fATZjgUgYdLWZC];:@MfeZOY:ET8V5
SYRGOW64VYb:Mg1`QJV`Whb8SYRLWJNaYYF>SIBWaLnjYXUeM6YMJ86>R7mlPh]l
LW]aGUeYKVMYKWMjO8B9OFmZOINDPhVS/IUmNhne`JjLT8F9ZMcCRV25gOo1B0D]
SOGofWH/6cMKRlScooG/k>KG_9^?WjB@OGj>ZZV5JeeOOjF/L2/[EgEXGXFNM49B
MVU3=4YOFV1eO6eTKfI5@WVd`KRdWhN2U<3SgL:SWJFT[kfg]kZ^Yk;?k_3XdZJ5
TI^7NHfn^89/M8UmI4LfAH6nW6V:YXeaFeUQH75QHh>;R92MU9:7P7IkPVeiO7Ek
L61QM6MPMY>ERfeRMG1ZGTA2Hg1A;ceIEDLl@dQ1?d8b8Bda9bPk@CDh<R@T9R/^
61Tk:aPJ7CY3CEe`Md`kKgmZCT=NM7Q/KW1UO81^HDiKFeYLDeQhQg9NFfUjNgY/
GFV1Ti>8M6ihR924TJjm`[Bobk:Q]<W?`Kg<d]KEjOogkNc[j^WdnOkhlOOfo_cb
ooonj>kooo;Zoooem?ooooooooooooooil>[];Vnbm3He<c7aLW6`KVOQi2OZjBX
`<BeX9:;RXn=PWM]JFYREe5ECTY0?E1DACDZ;R<6000>4P000PH44A@000H00000
000000000000008300002@d0000041HU9b<M9SHj?T8n<30b=CM6BEIMDe5AEU1<
EFIUH5a5@DQSJV1MIh=cFUiiS81iPX=eLX2AWJZmYX64RiJOX:>QVIbOVj2Y/KVf
`LbcXZ2lj?O^inWWm?oooo_]gmkEa][_koKdgn3]l??RbJ^OXJ^mblg2];2c_<;<
a[Fd[j>FVZ2IVYN8O8JL]L:d/Kf_Z:B;LWJ2V:FKW:f]YJJUUhV1NXFGVIbRW:>h
_;:IRHN8QH6FUgaeNgEcOgekOgYoQHB9OW63SXQhO8n9SibRT7b3PgYiO71XIF]g
Ng^7UXETEfEYK6i/M6i[J6EYETYMGU=:C5AAAcY0Ad18@BdiDF9ZLVmUKG5`N96C
NE4Y=EUaLW^P_JRU]kF[SGY/CTEPOi6RY:>RSWm^HEEFIfMUKVeaKG9kGD9CLgb1
PFmPEeYIA3<[AFf=UH5dJVAVFdTj>Si@LXV?T9jTTgihQHR1LG2:VZ^`XYbPY[Ni
YjZXWZ2ESJc8al_A_Yf@X[_2^ZjAJF5iOgMnUJFVX8AcRY5dCdQCDE=LFdeCKGQa
L8=oJ69QF4PlC61CAT]HNZ:WWjVhd=2PKDho=TANLYBba/g7]In:MV]A>3=0J8>:
WJ:EPgF0R6iFF5mJEUIVO7^2QGjA/[jjZ7mJ@Sm>DeabNX2DTY>]_k^RQf]IFFV6
WJ^UVJJcXj2__[^OQhZQYYnU/L[F^95oQ8b@T9je_K>S[KZi/kC8a:^[`/?0emBf
YINK_=;Be=2gWif[XY:FUXnHY;6aXYR:R8=hMFU[LVi_LX:>OW^FWZRkbLZYMU]5
<CmEF5ilWZZWXIbIQVHj5`L9:DYMIgV6QWYREDTY6b@/<3M7DEEDC3la=CXZ8bX/
81D800002A@E<EINF4i9BD0]7A`O<40nDG66S8f1Jfa`GDIFOI6T_/[<_jZQVIBT
Z9F;Uj6`bmG@cLK5a[g1dMSVk>3LfnS^i>7NfmgKen;ZdkZa[[W5aKc4bLG2[YVA
SXfCV9^OZjZNX[79j?Kdeia`IUaFIhBQ^LkPk^[Ne<JZN4Y2EFf6WJ6JUhekM79`
J61SGeiODU5NG5QJGfabGTU4>C4Q3`dN>UAbR8f2NGAZHTT]7B50J8J5P8V9NG9_
JFm[BcM0H7n=THYoNWUgKfa/IemJGE]OI6a_HEiZNGMWEdPm<QhR?eESIEeA?3Dl
@4M1;c0h<c4g?DA<CdU6Cd<Z;cHa>CHa@emnU9bV/jf3B28W>dMGIXNSXZ^k^jV8
L6=6:cQLOHnDW9ZIUi>QXhI^KX5fGEiXO9^PU8n9V:2PWhIeOh=aHgRHZkJo`KBb
^KJTV9jZ[[[:gNk_ko3]j][1`M;Gh>gfooooooonoO;Ud/kBfMoMi?Soooonk^3;
_K:[];6W]L_KfmcPfL6QU9RR[JJDRiBDSYRXYIV?Q7M[Ge9CH5iLFEMGEVb?WjBZ
XW0e7a@TCfMcOi:MWIb<JEIF?AHG=DaTLX2DRWQaI4hd9RDU71P/AUIPIEU@Ce1D
DTP`728mC59MK7]oMViYJF]XHTm0?dEFJ7b@VYREW:>BN6aYHeeXP9Zc]kW2_Z60
MGIhNh20QZ6jc^;Vck2EQGYfQ9NR]<K3_;F/[jbCQhZ1Oh^FXZni[I^AQ7MiSiB=
S8AnQY2=P7QkOWf;WZVd`lk>ZVa5A6bJZ:k1_kJh^;:OTY>=NG:2V;_Bbl2/S6iN
HEe?DFMlPHAnO89hGCh_>daDDd@j?T4d:Bd`:RPX:RXa?T4d9ATD849YLfMABeQR
HE=:@3e<GfeiR9jYWIRBPGE/K79hOY2R/kb[XkW0ZYbCSI21LXZRZJRS[kJWViR8
LgV@TX>3Q8VJZ:BIRX5lNWYcKg^5OGUoPGijLW1gS[;Bf/22C4MAEfMmWlO=amGG
_IemI4XW8dV6_M?BbK26Gde;>bhb?4aKJgIfKfEFBD8o?SLZ:D1ECcm6DDi8@d=5
BDeBEUQICdA3A4UDH6]kS8Q/CdU@FFYeNhfJWHilS:VIQGmfN8:9VjnUUiJOXIbL
XZ2O/;^j][:g_;feXIFV]ZNGVJ:///;=`kF]ZJRQW:B[Zk?0am;BalNoZ9fNVj2h
g_ooonRTLf9[Mgb<Yk^j^l70/I9mL5UDGfb;ZKBj/9fDT81K?SY6CTeFKXN>QG5L
ETmDFd/e;C58G61QD4]PIe]BDEQRG5EPIFf1T9><QH1hN7QfO82<X;6k`<:l_L>n
]KNdWXb8WL7>a/?3_K6YZJk0c/B_Y:Nkc/_2aL:gZYZ>QGn1PhZJZ;Bl_;:OOE]7
AUMVHf5SJgZ1QW5@Bda;GgF6XZfh^HI==ceEGUE^S96JZ:RMNeaD>b@bDW::V9N7
LV9NGeLl92<b>4MLI6YUCCTd:b4S9R0F4BE2EV9G@BlT:3U7ADE?EEIEGVacLFUK
E5m/OXf6N79gNhRPZk2e^KJXUI6HUYJZ`MOSfm;A`J^W/K[3dLfo_/OGh^3@^jVO
ZK>e]kc0_;:`^;jgYifSZjf/XIRMXiN=Ti^KU9:GVYZEUjBla[[0b;:8HTeJLX:J
[[S8b;6MSX9iJ5UKI7VO^L?7/8QZFDTf<DANKWV7R8F5NVYKASTkAeACCUY[KFe]
GTTi=dQEG6=VGDXm@5IbPWe[GU96A4iNIVUYIFEbOhB2OgM/Hf5XLWZ1PhNCVi^D
TI69PWf6VijDTiZER85kNX25QHF7RH^5MWAgLWEnNG1WHfEPDdaFIW1cIe]NHV=W
Jf][M7anOXJCYk69@AlaEGbDX:nj`LC5_JJ>PWAUIW^H_>Oeg[NGTYZNUWabNXBF
[K^n`[^OQGIfQY6=MeaKLI:a]ZF=LU]?D6=lQXAmLgEoSY1lJfALFfMdNgj2RXf@
VjjfYiN;OgAaOHfGWIfPZj^QXjBKTi>ISH23R92FWkBeY91jJ5aJIFadQXf;S8Z;
T9:2IU]SJ6EVKGAhPWi[Fe1BHfmbLG=fNh^MW9NcckUl?2]5Hfa]QJJc/KBZRVeH
CT<f=TUaUYfFR7IWHf5<9aX`BE1EIgYoJTa0?CPnAdE0=cMAKWYjL5m@AT55BeIX
HU9GHVabKFUVH5UDGW9mOhRCU8^7U9^?PX5oOHNMYZ^c/jjTVYFEVYbP[;W1`K6T
Xj:U[k6X[;Nm^[Rl^l36^j^QY;O8cKnZYjJFR8FCYkW2^:Z[ZZ:KUiFBTi:BUjBc
]kg@f/^IJV=`Mgb=[/2g];ZjYX^3PG9MF6b;[/?4[I23P7MRC4]FIW=kO7MjP7ib
GUMQGdP^;dEMJV]OCDUEE3@F5B]6C49;KHJ9P6Q=>cI3Ffj2SXn0KFmfNWf7ShnC
Y;k8^k>XWj6PXk2j^k6QVYBG/<oGb;Zg/jBFUZ:UUhUoQ9jb[jNLS7eaKGN7Ri>J
T7adN7UeL6a/KGJ1RHQmNH64NV]XN8^DW;71ZfY1CVf:VINT[9J8TifCM5aNEdeO
Q:Fk^jZ>K4m5CD]2BUaWLhJ<PG=H<Q<942PoCE9FI7]lL6MFBD]ECd98HW9iMg60
WZRJPfiSHF^9YKG6b<W7^K2_/[>_Z:BZ_]WUjnoWflg4`;^na;bla<[CfLo7bLBf
[ZZSY:^`/K2[YJFVXIN<RHN0Mg^1R9JRWY:5MVANIFMXKGN2QH62Q7MMBD=>HgV6
TjnnXVPj:cA>GEibRiVZ]j^ALE@o<cA7J92a]J:2HDm@EU54BFElQhj8NF]E>Blh
BEicNFQ?Ae9FE4/m=S]6C4U3C5iMBd19I7MgKeY3>CU:HFmfNh>;RX1aIV1RJG=m
QYRY[k:/UWm_KWF5V9jPZ[>i^K:/[:NFP7EfNXBO][ZcZJ>MTi6CQg1VJ6YaOHJ;
RhMnLVIMEe]YLFmUGF5SJW=`IfARGf9[O9F^]9=SDEMPN8N6T9VM[;F`YHe`FTE5
F6nHa<fkXiBCTXQeEd95EG:J];:PPf1=B59XLW5_Kg=mQXR4NG=cK6]_IfIbLVIO
Gfn4QW]dKVehRHeoM7V>WJBYXX]_H5mUMI2X/kNdZIV4LVQ/NXN=V:J^[jfRSh:2
RHj=TIZV/kR_VXZ0OHJAWJVZYjFNT8^DVIFAUYnQXJ6OUhAeMGb7UZJc^:jENg5a
Lgf8U:c5`99THVm/JW>4WJVZ][R[UGIQD3m7GgNM^;:KPfmRETPg;SUEKHBHVY1j
Ec@J5B]7DTa6DFf0PGm`CcH];CM=HVmjQ8IiJF9^MVYNFUYQKX6EXJBVXiV;OgI/
KH6IXZ^_Z:F_][[1_:66Ngf7V[?3dn;Qe<Zl[If<R8jHZko9d=[Kc;ZZWiN?Q8BE
[lSJh=O4ZiN?SY>KXJ>TZZjc]ZnRUHZ4QXfIYk:k^KS5cK^;IFQeO8B3SjV_ZZfY
XHmeL6]LIH:N];FOPf58ATmGEDmJKgI_J6=LCC`a;cYAJWUdGD]=Ddm@EE=EGFA[
Kf]PC3e1E6=]O8V9MUa@E5aSKGZ9U9NFUHakJEaIGff3VZFWZjbRRg=UHFEcR:2`
^;bfYY>2LFIVLWj>YKW4`[FSS7ARG6AaMWN0Rhj;PWIWG5UMIgF2RXb8OW1YH5EE
GVejP8R=P6YFB51SLi6ea[F9Jf9DD5EHL8V6RYNIU81TD3X`@5=WQ9VKTGmcJEU3
<CM?K8FDVIF5JU58CUYSJ6IRJ7nKYY^=NfUQI6YcOhAjKg:5WJZ^YIJ5LfYhTJBf
_;2QYJn`[:ZQUI6DWjjh_;^h[j>NWifKX:FVY:>VZZ:IV9jRWYNAS8bBVjJ^[:BO
V92:QGihLfidPXb>SHInLV=OIg1hOG]fLgZ4Rhb5N6maMWUiMgAeMGJ1TZFi`Zmn
C3e:G6elRj6]ZZZZVh=YE48b>5UlUjVTSGESFeI<@d15CU=IJWb2NV]MCdA2ATM1
?dECIFe_MG5UGe]CCeAHEDa;FVmlOWahL6EPHFASJ7J2Qi6LXJ6FQWM`M8NP[:NM
UiVKWJB_]:nZ[;2e^l;6_J^UZj^UXjJYZ:jmaKf_XiN7PXfR[Jj^/JfOU9FLVHn1
LfaaOY6RZ:NLR7]nPX:4RY6@S8jBUYjUXZ2VZjNY/jZ9PY>KWjNda/^jZJFTVXb=
TXV8W;:m_kBMQWU_J6ETI7:8UIVMWiEoHdXg=dMGFEE@CUERIea?ASXd=S<d@DY4
;QlT>UAYLVI;=BXY;cU2BeENJWV7RXAhHDToBVB2T92DVYVASXn=QX22RYBT^LS9
`[bdZZ2DSiJLWjZc][Fc[jFJUYJ;P7amQib`^[ZcYiAoLF]YJFifPh^<RH=iKEmE
D59JIW1fN7A[Hf1QJGN3QgEFBU9GFf=/NH9oO8B@T7iXFTm;FWNDXYjBPg1YLgaj
L6agOWYnSIF;O6mWHf9OG5MBDEeeR8YoMViTG5aPHfEYKW=lQXnHV85QCU1LKGj=
WJJVWiF8O7MfMW^;XK>nal>`XIjKUIRSZ[2lal_@e]75`/G6`lC5`;o1_;Nna<72
b<No_;JYWIRDT9FPZ[Bk]J^SV8b6Q7mgMWf1PXF7QH>1OGE`IV1PG5UVPIRQY:BN
U8MhH4eBGVEeSIjTWiB<Q7AOEEYPI721RXV2N6]OG6E`M71UHF=VJgAjMF]QFEIJ
I6YTEdY7C5MPI6MXGU9AEUeVKfm[KWEeKfmgMFQLF5e[MGIfNG]oQ8R9Q7eeKFae
PX^CW:6UZJJQVi24OGj5SIJPZZb^/JfUVY6?T9:IXjVVXI^>QHVDWjBQW9VAQh9l
M6]YJ6]fRIfTVhj6M5eFGVI/M7n7RXV5QhZ1LFedP8J9TibMXZVPRWA^NX^KYjn`
Y9BAW:BMTi:BS8^FXJR]Zi^8Oh><TYFCT8b;TI2?Rh9hL6mgOWmnNG=_LG1ZHUQ=
@d96CUeZL6aSGeiHD4Y:BdiAE5UQIV=PIW9iMF]WIF5RKhFGXJBPUHEjNgaiNXBC
ViVJWYjERhR9QhV?VJB]/K>d/ZfSViRIWZBW[[>c[ZNWZj^XY9^ARXF7T9BDThf2
N6mYJg1gOWefLG5eN7QgLVIOGEiQHfIbOXB5MEHl>TMIJ6ifNW9WJW5_IUYDEE=I
Jgn;RWUSDTa@E5QOIFaeO7j3QgaYG5UGEF1aMgN3VJ>GNf9A?SA3HWf:RhR0Lfac
MfmSFEAEGg>7THM_G59DFVAfQ8N5PgmjNgekMWN2Si^RYjZXWY>AUi^LWjJa_L_C
c/:l_L36cM7?c];DdM3?cLoBdmKLg=G@cL:f]KVf/;6d/[Fk^[FaYiJ2LVmbNh^E
U9:@SX^1MFUOFe]SLWf9VjJLNE50A4Q<Fg61PWQbM6iLC4M6@d9AJGYoN6QEBD=0
?Si2CUi]Mgf0O6eJBd=6DF1[K6Y^MGf0NgE]GU9@E5m]NX68S8^;RXF0N79fPY:L
Uh^6QXF3QHR:RXV:Rh^=Sh]oMGAlQY6GUY:<R8R8Q7mlO7j4SY^UXYN?Shn?TibO
VIBBTI:GVibKX:Vd`<FmZI>0LG>6X;:h][6WUhR2QHF0NW^4Tj:[/:jTTh5cK6]a
NhJDXZNTY:2DPF]UMX>9V:BUXijCRHElKVQ^LgInRXf3O7]fL7AgKVINFUaVMgin
OWadJ6=TK6YVIV9ZNXZFTWeZH5EAFFAcNg]mP8J:R7efK5Q=DVAmSiRFTHj9PGj1
QXZ;SifVYZBFR7ehNGf2QHbAT96HUi2?SXR1OWinPhnGVIfMTh]oLFIULGf5RY2G
WInNV927P7]hNh2:TiZMUXMlNWUgNGIdMgn8SYBJVY:6OGUjN7QoQhJ2PHF5QHV:
R81ZFE]WL7V2QHF3P7]gL6QQHF5LFEi[MGIdKVMUIV=KEeIJGfA]MGMfMGE]GE19
AdI;FW28U8elKUe?CE=IH6=ZM827R8Z1Kea<@TIEJWj9SY:?Pg]iM71^L7AmRIJQ
YJ6DQhF7Ph69UYfSZJZTWifLX:BXYjN^^<37bLBj[9b?SibY[k>h^kZj^KVh][B^
Yj:NX:NZYJ:QVI:=QgmjMgEfNWilOHN9Q85oNFmZIUiMJ7=iNWMdM75_LG1/JfQ/
L6IJH7B1OgI`Jee>BU5GG6YgOGagN7mnLFQUGU]UM8>;SXQiIe]HGVajQ8V<T9:C
SGeYGfE/NXbNZ9f>OVaRIG1iPX>1RYFIWZ2IShInMWAkR8f9R8V<TINIVYN>Q7Yb
Kg5gOXF?VZ:QV9:=RHF3QXZ=Ti^SZZj[YjBQUXnDUYRO[KZn`LG4`:fDQ7moOXbS
][ji^;FRRGEYGEYUNHfMZjnWVH9YFE9AF6IhS9jWYj6FRH1eIeiEDUiXLWf2QiBJ
TX=hKfAMG5iOHW23SYRKUY>7M6QOF5UUN8VK[kBXUH=_Gf1YK6U_O826TIJATHei
IF9TI6amRHfBTXIlMfiSIGN7T9VOVY6<RHJ3P7]eLW9kT9fNUHMcGEIPK79iPh9i
MWYnP7a_Hf1PHVn1S8f9PGQcLG9eNX62QI2GUI>@RHR9Qh9oPHJ<U9fQWiZ>QhR<
UInV[ZfRUXZ2P868T9FHViZKVHj6OGIiPi6LXJV^ZIZ1Gd8oAU9YOhb>Pg9VHf9K
DDU6Ae5PMhbCQVYDASTiAEUWLWf3QHAoMVaSFE9<Be1EFfEgP8>3LfEKBTA9Df=^
LGR8SXf?Sh^8OW=bNH:;U9F?R820PX:3Ph>7SHjAVYVFViN>Q7UdMGb4TZFb]K2Q
T8EfLXFDW:J_]kbl]ZnKQ7efM8FFZL74/Z6<PhV9QY:U/kk3a<G2_:jJS8R8RI>P
WYB?R7YiRYbX[ZnZVhEcMH25QhR>UiRDV:2BOW9PDU1HIgImP8B2NViUH5=5?D96
CVMfM6aZI559CE9HE55IHVelQ8N7NVM??CPnBeMXN8RHWIF3L6IPGV5_PY>MXZJT
WIN;MFAPHFZ3YKk2_kV[UX5hM71`Lg^<XK6dYiV7MW5cN7j4SIZPW9NAQGYmQiVY
[kBbZ9N;SYROX9ZGVIZKZkNbYi^:MfagT:6^][:ZV8EoLVAZKVU`PINMVjJTT7a/
J75mQX^8OgejKfegNgQmPX1lP8N:QH>6Og=YKX6FXJ6ERgi[I6AYLWIhMW1hR92A
QGYeJfAYK6AJE4e@E5USLgmiKfeSFEeUJg1eNHBBUHI]F4Tm@5MhRXfAT81aL79f
MVeZNHbS^/c<ZhUjK69UMHB=U9RDTiJBS8^7MW1kPh><X;:j]ZZISXZ3NWZ0PH66
RIJQXjR]/J^GR8B9U9RKXJ:XZJ:RZZjRTi6EU9JFU9^OVibW/[FcZIZ@QGinOX69
TINASYFESH9cJEiJH726T9BFUHf3M5Xj=3dnAF>4UiZBQ75RDdU4B5ARLgenOWmd
GTm4?CTl@e1NIG5nPg][G59@DU1?CDmFH6]hR8elIE]DCE9GEeQHGFV4WJJTVhei
HUUQK7AkQ8f=RXjBV9::PgYkPhnJXIjARHV=U9ZIUIFMX::SZ;6TRgYnRXf@X[>i
^:^SYJ:HTY:FY;K7d<g0Z9:4N7N5TijVZZ>CSi:?P7]oP8B@UiVHUiFEU9JCSHjB
THR3PX9lLG1]JgF0QH9jLG9iNWIcIf5TJW=kQ7i[GEaTKW5^KVeQCe1MJg]nNgYc
JFAULh:9SHR4QhQnNWaoP7YfNWajOHN=SHF3R8^?UifHU96:Qh^9R8j<QGaZGeaV
N7n5Si69O79/HeQII6YbPIJSWYFARhN2NWMiNh>@XZng_K6TVhZ5SY2@UIVGUZ:f
`;NZWiJ:QI2MZkNk/jFQW9F@SHf7PH>;TIJGThYiJUmWOY6OXIZAPg]fLgQnOGM_
LG9^L7AfMW9ZGfIgOX67RHAmJUMFFVV5V9jAOgagK6AFACPkCVR9ZkBYXj2BOVaR
GU]GEVR3Ui^BRG18<cLlCFYiO7MgOXB9R8=jLFa]NhR<RHIiG4QFKX2:R7ecKG1f
P8F0OgUaM7YgM7E_Jfe]L7N4TIRJT8=oO7]oQi2GWjBOW9^KUXj?Uif/_<75`[FZ
YZV/YinPXZ6NViVJWZ>V[kbk/Zn]Z:RUVI2@TibZ]K2VXIV@Rgm[HV][H6EgQHV6
QGmeJ5aMIFedNh23QXN6SY=iFE9?DFEnSi>=QWMXIVMMEUm[L6iaN7UgMFiUG5QK
H6=YL7Z5QGmjKV5IHG1bKVUWJVMULh:3NWIbJfYaL6eiOWMgOX:4QHf;O6eQIFm/
JViaN8>>TXIgKVIYLG1`M7MkOGE[J6eaL7B0SYBIWijGTH9fOHV?TIfYYinGS85h
M75^JFanT9j/[ZbYW9JGTiJOZ[6e^kFTVI>>SHb5O7V7U9^TYibAQH1nLVESJGIm
NWekKf9PIf][LGYiMgYjL69IDTmGIgF7U9F=NfeKDeIIHVacOH^GWIVBRX5eLG1e
Q9JLVibMViJGUHMmOXB3OXN@TI:EXJjf/IMiIUeFGgF<W9nIWZ>JTHanIUQQMHbT
^<O3]:VBMFQWLGj6SYVV/;Bg/iYoKVM^N8NKYZjh^KJbZYnCRHN8TI^QX9^LXj^`
];R`ZJbYW9BEUiJMZZn^YiZDWZFQThJ8T8n=Si>GUHj<RXEkLgE_JFmeLFm_KG9b
K6IIEemNGf=OH6QXHV5VJ6ASJ6YREEANIVacN7n6P75UGeA9Bdm<DF1XJgF1OFUR
HV1LH6]eOX^BSXjBR7=ZJFANI6eeNWeoQHZ8Q7YcJeY@CDI:G6mnQXb@RGm`G59@
DF5iQh^5PX=mMWYhLW1ePHnJXZFUX8n0OH24SY^RWibHTIJNYjf][ZfYZJf^[:6C
Sh^CXjZ//[B`Z:>PTHB0NWMnQI>PXj>OUh]iMGYlOH:;SXN3R8jASXAmNGQfLgAf
MW9[J6mnPgioNfaLDTi<DfYoQHB7TIF@RWi[G5IDF6MmTIVOXY5gIV1NHVaeOXVC
Thn>S8V7QGQ[JFQVJgZ3Q8>1M6][KG=jO7IZI6]dMWQgLfmZIF9SI6=RH5eSJfa/
LWIeLG9cL7=mNgEkQiFKTXV4O6aOHG21QhN:RHN5RiRIT8nHW9^S[K6_[ZNLUZ:]
ZJRa^K_2bLBdYIbKXZRVYJNTWY^KVYBDUi:8Ogn9UIjOThAfJf9MH6M`KfU]MgUi
M6]VH5YIHFmfMgE_KGEnQXAoP8>8SHJ0OGIaM82EZk_0^[2LRHF4QXfGX:Fa`/>e
WhIaIf5RLHNN[:n]Yib>QhAeGeYUMHJ9QX=oNgagJf=QI6MWJG1dMWUiLVEJEUMP
JVaeOH63Ng=cMWQdJVecMWn0O8>9RXj>RXV<T8Z2R8^7Q8^HX:^k`;bf[ZFPWIZK
XJRY[;2a[:NUXj2NWYfMXZji]jRFQ7YgNGelOXF9Q7]hM6QLE59GGFUdMG5/IV9Q
H5eKG5UIGUaGDdm?BT0h=CLmAE1LHfabKg5gN7IcMWUiN7b1QXN9VJN_];Ji]:FJ
VjVa[:BQYjnc/jVLU8n:P7=aMGn7S8j?T8j5NG1QBcXjA4mEFfQ`M75WFdm3=c4d
>DAAFEmPGf=XJV][JFEUKWAdM7MhN7YlPHZ@TY2?TY>FWjV`/Zn[Z9nAR8J<Vj^h
amCPi=_>_:bY[[Bj`l_Fh=kFc;b^Y9^LYJ^`[jnb/ZbRUi:CTHf7QHV<T9FFT8V2
NWYnPGU/HeeNHfESGe]ECTaDGV=VJfQOEUEFF5]KG61UJ6meMW=_MGimO8RCTHf?
THf1NGn:TiZOXJ>MShB3Q8:3SI:JYYf9PWY^HUMDGVYdMgQjK5U=ASll>cTd;c0a
;b`W8AXH5aHL9Rhj@d<o=c8g>3<g?3m5C5IPIFa`M7UiN7f1PXF>VIjPY[6k_/35
c=KMfm77`;bg/[K0bm;Cd]C=`[bl_;R`[k2e^[Rc[J>HT8R4Q8VDW9ZJWj6LU96A
SHEmNWf1QHF3Q8N;SHn<Q864OWEeN7f1Q8V8OWUhN7^0Qhb@UIJFW9fGT8b=T8j;
SIFPZ[6h_;fn`;V^YinESi>IVY^QZK:g]KB^Vi>GV9^ITYVRWibOWI1nMG5]KWEi
NWagLVm[IF1FBd0g>DA=Cdi;@SL_;SM3B4Q8BD];C4m=BT]?E5USLGYmO7E^LGQm
OW]kOX>3Q8jJVijQXjZb_<O5`;j_WijTZJNSWiZIViFASXIlO8:9TYJDRh=oNW9^
M7MbM7anNGMjNgUdKVmbM7=hPX=jKfMUJFY[KG1cMGQkO7UhOH:4QXR9S8nCUiVM
X9N>SH^:RXV4OgmkMWb5QX60P7eiNg]dLFm^KW5nRHnEUi>AUINAShn;QHB:TYZV
[kNl]:FISH5lNGAgOXJ<T8n8OFmRFeeTIFI_MgI_I5eHCT<k>D=AGf]aLg=ZHV5V
JV]^LgMgLW5cN7alOH25SI:BTI6GXjVVZkBg^;RbYi^GUi:CVjJ`];Vm]k2YW9:?
SHnBVjFZ[k>[W8^0OGahN7QfNgikNhB9PgIVG5mTIFETIFAOFUYPHEiLG5]HFUmT
I69XLGMlOWinO7AaKV=IF61YJVU]JfELEE5@EV1WKWIkOGalNG5VHV=SI6]kS9BE
UYF<RI:KXJ6MUXbDYjb]XI6?UiZIVI^LU8MnOgn1R8Z:SHf3NGYnOGQdKf]XJFIW
J69EAT57CUMOGf9UIfERH6AZK6UWIfU]L7EjPHJ8SIBJVijQWY^HV:2Z[k:g]K:b
][^o`<?7a/70_[Rb[:V_];Bf`<S;b<Bo][>c/K6d^[bg/kB^XinTZZnd][BZX9>6
P7amP7n0PhN<SY2@SXAgLW9aMWf2PWmjMfeUIVQ]MGb0OgelMFiVHV=TIFafOhF8
R8J0O7n1PHB7QhN6PgejOh>3Ph>7T9jXZZFFOF]VHVM`MWj3QHJ3P7YaJfISIFQ[
K6YWGeA<ACdn@D8o?3/j>ci0@T90?d94ATY;C4Y5@T96CUIQJfm_KfiZJ6U]LW9c
N7f2RI2CThn8QXbDWJF/[:FPWIRIXZZb/k:b/Jn_[kBl_;Zi[Z:PXZBVZ:RPUi:@
Ti^TZJFPWi^ETI:CTI2?S8j?RXJ0MWAlPhJ8Qh=iKV]aMgUiMgAcN829Shj;QWij
P8V<Rh^4OGUgN7^5U9VIVYF;PhVCU9B?PX:5Q96GT8QlO8>5T9nZ][J^Y9VBT9BG
V9^RYInBRH>0Ph=oPXZ@SXAoOGikMW5[JVYTGf5TI5mHEEIQK79cLfmWGeQED4mC
FEeSJfiaLVmWHEeMGF1QI6U_Lg=/IfIWJg1fNgUdKFITIg1lQ8AnMVmZJfmcMgQa
K6]_MGZ0PWilNWIdLWR3QXF3OGb1QX^=T9B@RhEoPX^@ShZ8S8b<S8f?T8^7Ogf1
Ph:0Oh:4PX9oNgUhOhZ>SXV2OgmnOhB:S8R2Ogf4T9^UZZRPV9JDV:2TY9j>Q8F8
TYbTZJBUZJBOWINDUI6=SY2>R8F5QhN7RHjBV9nTZZj/YIV9PWajNgn:UI^JT8N:
T9FGUiJIW:>YYYfAR7idKVmcLVeVHEeHFf=_NhB>Thj8PWioOgmoNgQiMgQjOH1m
N7b3Ri:HWZ2MV92;QhAoOX:;TY6>SY6CUYBDU9RHV9NFUIRJV9ZNXInHShV4OGIc
LG1cMW^4S92>RhN6QXN6P7emNgMcLWMiN7AaKFALFeiQIf]]KVMOFEQMGEiOGf9T
HF9SI6e`J65QJ6]ZK6iaM7AcMGIeM7UoQ8B2O7QeKfa[KWAiN7A]J6QZK75fOHJA
Thj;QgeaIfM[LW]oQ8R8PGUfNGf3QhZ8P7eiLg1bM7UoRI>FUiNFSXJ5PGYfMgb1
P7moOGYbIeYCEfA/LWIjOh:0OG]nQXfBT8QoNgf4RiBMWINHW:>X[Jf_]kjm^kk4
a;fdZj>OWj6W[:fZZJf`[jn`/kFf]K2[YjNXX9FAUijRY:>NW9nTYj>OVi><QXB2
PXJ5NgEfN7QjOGimNW9aM7MkOGaiLfm`M7IiOX5oO7aiMW1XGeUHGV=YK6aVGeUL
IFY/JfQPFeaRIF=QGU]JFf=_M7MdJf=IDEALIgB0Q8F4Q8B3P821PhR?UifOUhEf
LG9`JfIQGe]EEEmSIVMZKFe[IF1METe4>S@c=c`m>c`m@4=9DEQOHf=SIVa`Kf]T
HfAPH69RIVaeOhJ>TiFHWJB//KRm^kFe_<;3b=GQhmS;`KZf]kZn_[fh/k:e]kRi
^KJ`[:^][ZZTXIVBTI:CUYfW/[J`YY^GTX^7RY6KW9RIVI:;Qh1gLGEoR9:GTY6A
Rh9mOX:7SiBBS8V=UYfRXYjHUYbSYZNWZJZUX9fJW9bHUY>EV9BATIBGUYJETI>?
RhJ1OGYlPHR<RXJ5QHF7R8AnM6m_LgQiNFmVHEeKFUIHE5=HEe5<C4e8@d93ADM>
F5YGD4Lo>3Hi?d95Be5BEemPGEeRKGUmNWUhMG1/LWf2PWaeLgEfLFYWHU]JHFmn
RY>GUXenMWIhOhN;RXF0Ph^@TYJIVIVLYK2d/ZjVWiVGVj2SX9B5Ng9[KG9gOXF:
RXJ2PXF6Q8B3PXF9R8=nO7YkP8J<Si6>QGa_JVibLgF0QhZ<S8Z9RXZ8RiBLXj^e
]JfUVHf=TYVV];^o_kN_Z:RWWY>@Si2AU9>=RXEkNWn5RX^9PW=PEE1EH6]dN828
S9:JWiJ8OG=aM7IlQXn;P7eiLfm/KgF0S92BShInNG1SEe=@CTeFHVA/MWUfM6UL
FF1WLWn2OGI^I5]QM7AYLgQeNgYgOGU`K6]bOHB6QXR=QWQmRYJJWIjHTHb4PhB7
TYVKY:ff^kZl]:JTXJ2RW8j9T8f:RX=lNGZ0PX61Og]aIEeJEUMOHfM[JF1JFEMK
HFahPWmaHf5WJg5gOX62QXbCWJ:NV8ioMGIlQi6DShV6Oh25Qhb:Q89iMGUmPhR>
SHjCVInVY9N<RH9cL7=dNX>2NFeXHF1/MG^1PHB:TiVEShV3OX1oO7n=V9NGXJZY
ZZj]Zj>DR865R8R?SH9iMV]OHG5fHUeYIEUFDU=GE5=;AUEXMhRFWIR<Ri:ET8B1
Q8N=UIfY/ko>clC<flBc/k6Z[[F/Xj>/ZYfHY[Zc/[W6fl[3cL2SSX^BVIbOX::Y
ZJFRVI6=ThakPHIlNX1mOXB3QhZ5R8EcJfY[I5YHE5QGG6InTHalL6UYKVmmSiVJ
Vi9nL6UQHeeLH5ICE5QSK6MZKf=LETiBH5Y8@4]PIFacKWN1OGEbLfYYKFUaPX60
RXN9S92DSX61QhZ9QXf?SHf7N6m[Ig9jO7UdLgN3OgaeHeeLHFafPHbGX:BIOG=d
IeQ;ADe@EFAVGemIFEiOH6Y[K71ZIEM8@TeCGGUoNGahNXB<WJ2CS9BRXYNN[:ZZ
Y9>@VI^X_L6e]KVb[:BGS8R8R9Z][<C6/:nd][JfZjJ/WYNQUi>Y[kG7^ZjQUI61
OHZ8Q7][JVEUHEYSGeeGCVIfLW=gJEaWIF5VIfedMg5VIFamR7afN7A`LhJ7OhF6
O86?T9jXWYBEUhV1OgEbPYB;MWj<T8YmQH]oMGQlPHbPVi2=QX>AU7]WI5mLGV^6
UXn5TXioM6]_K6MRF55AG6=XKfmXGeUOLHN<Pgm]E5=RIfmfMhF<OWIjKVA/MgUY
Gf5MHVeUFeI>Bda5B61cLfecNGElMg23SHjCZ[jj]kFZWiNCTi>J[;N[XJR_//36
aKjg/jb^/:f`/JbWXYVE[[BOWJRNSiZLWJ>X]K6RUHZ:TZBk]i=dM8EoMFiVLH66
Ke5>HGjHQUmnWiZFTk:]X8MZJ92lZ:Jj/ZRXVIN>S:NPUJ6YSjC3]I>5MgQeHfMh
RHamMGMTKHbGO7nBWJF5GV1iM5eNLGB6QE]?HgZ2Si6=[[VGUJk:bJF5RZ29CeR9
U7MNJgeT<45CDUQZJEiPFF=VEDmKIE0m@Se4E5Y=?TmIBT54F51<IWQTBTYKHei<
B5U;?UUMJWb1SgU[Mgn>TX5mSInNT9BMW:2SUY>abLF]Xk6d/jVDSJ2PRgf2V9fK
S7ASJi2SYYj7Uj:OWi^ASk30^jRDWJ:DRXZBS862UjNWYIZKPh6DU9^ASI68QIF?
RIb?LV=fRXb>ThF4SiR2JG5RJXF3KWjCPh^9OXMgJEm6DEm/OVe`MgIfKVMYGgf;
MWb4O71bQiV:O8>?Y:jY`^GNclflZ[2YVhn3P8BBTX]jF5mcG4U;CUM?B59MEC0Q
=38T92@d=SA0:bm?HEE6B4=6Dfa^NY=aGFeNFG:BXZ6V^;J`_l:hX92HThb7UZ:N
Wjb[XjNg^JVOYZFY_;>OV9fIVHbAXjFbWHN1P6ELM7b5RX5oQHimOIF;Jf1MGUYJ
MGQ^L6ibO8:FSgnX_ZbWVH>8Z:R9M75kQ9FKUYFCVXj=S7Q]LVaLHhF8M6EOLgb:
QgaoNGYiKWMjLfU[LfmZK7=gJfI^KG9`LWn7NgYoOfeRLWf3Xk>EJ6=iOhJ2NW^6
VZ:BU:JaZIUnLGEWEFf;OfmjOW9]MFQ@A3lg;CmCETE0@B/S<3D/>THmAF5/Kg]l
KGjETX63UiVGRhF@U9FHY;G4h?CPbM[ik=SAc/Boa[nMY<K?_[FVS8RT[:>c_l6T
X:N;Q8b2N8BBV:6SX9RPZ9RBShZAY[BNU[Nm]k>SW:F`]YjE]lkYmM>j^;Bn]:BK
U:JZUiZQVIf`Z9FBW:>GRXF6QfM5>cPmBT]OLDhlC4U3?cY2<ahT9C90@UMVF4e8
B55PR;>WRhJ4Q75RKVm_L6AQHEUKK7EeHdQ6FeI2F7EjQi:0PH^LU8N:Lgf6MVih
MVMXMX5mNGihJG5cGTm2@daB@Sa4CeAGJVQ>?T]PDD=KKF5RM7n2LFigPGmYKhJ3
SIjJU9:`e<Nd]KZYUIVc^JFYZJFEPHF<OGAbIg5cJf]UKGQfMfaKK81_OhY]NXf:
QWfDZJ:TZjZn_JZcb]o^h]7@e?3ceM7NcZnXXhnCXjVb[J>AOhF0PHj4O7abJ6ma
M7UeIUeJF5Y]Oh5iGT95F6AYKW>BYifCQXVGZjFHShB8TZFNRHfEWIF4QXj6PHnL
SGj4OG1/J7>4Nh1oJfaWKGQ`N7QgUYj@V960LVAUHUMEI5mKFU9SJVAPE65XGU]P
HEa<>C8Q6B@_>DE?C4eGFe1ACcXa=dUGFVUeMXJ<OGQhOXZIXi6@/Jn@OWN<Xhan
PGb5T:Fg/;BbU8EkLFeTI7=`Ig=gNXVDY[Fg_[F/^KNg[9VXY9^^[K2nd=O<`/O5
_lJgZk_9bl70c]S?a:VGWYVGRhfTUX=oKg5eMWQZJfaDDfAVJFaTHF9dN7:6SX^B
VIfRThRARYRe[JN`ZJJYX9RKZ9igL7]mPh5jMG=dLFA_Ogf0Ph5dJgAbFVAnNg=Z
KhF:RHbDYZk4i=;3`:2U/9nCSHQgHg:4QHN0PXYmJV=B>C<c:bPP41<N<ca1F5]L
GU]MFE5HHEA8DGV@PXJ@THMdJVQbQHR;T8:2P6ifNV9A?cHm>di[JFeZEe=CCUAV
JfMZMGYdNhJ4TIf_/ijNZkW1akblc<kFf=SPh]W1[ZFJWJB[/kR^YJ>HU9:9O6ea
Mg1dMGj7RIRNUiRCRXj0NiJUYJ>OWi5mNgV1SH]nMgIkOFUSK6eUCDiMDTHo<Bdg
BUMCDf=/N7Q`MGYjJfUcNh^ERgYdLf=GDd]8D6]lL7B<SHZ2MWE]NgUVN8BA[K^e
WhfJW7aZLGn4MVmfPiNPW9EgHg^1MGn0K6MSG5iVLFmdOgE/GTmMLFmRETM:HWIh
LG9jO7M]J7R4QX^FYZ>P[jJP[Zb^YINSYJc3al[3[k>fYJ2/][B/[kS0b/[8dl^o
`:nS]lgBc<77cL73cMKGbmKJc/c6^:fEQXRHYIjDS8N7O6YSJVaTH724PHB?NV=K
CeQKF6=^O8^2NGYaM7ihKFIRIfIWLWN4Pg=]IVERDe5KFE]QG4a6EF1GCe]UHe9=
FeUDFUUBEFekKV9CA4eFD4iIHEaFEfIWHFYRHUm8C5eRLhB9UifMVhImNVe`NH><
P7J7VJFKOG=YHF]UHVYYIfaOACi4DeADIFUTG4]4A4M>BT98Df9bPX^8MFMMEF9f
QI2EZkRa/IjCZ;W5al;;e]WXh<[3^:bTY:fe^M7MakfnaKbZ[jjW[Zb^_KVf^JbT
Y:FjbLK3d>7Obkjn`/BdZ;C3a;JYYK2k]j2EZ:je^:6HTHV8Lg:4O7EgLgMmP8Ai
PHilJf]^MWegOGadN6iTHU]QJFIZIE]MFEiPDU5ACe9;@ce0Ce56@e5JD4a?E6I^
IfI[IU]@A5EaM8=oLHF?S8YkQINCVIVFZKC3f=oJ`Z:GUHf;PGV7QX:6QXf<NFQL
Bd0g>413Bd<d:QLI?55ACU5DBcdkAdPj=SXh?U=WO8n=SiJ2KVi`QHV4RXF7RX>6
Ofm[GeYQG5ebQ8b8N6MWM85nO8>>XZFJW9jPX9^X^K:Z[k_6alW1ZJ6YYZJ_/k[6
`l31^[VdXH^5SIb]/Z>GT7j0Q7n7QY6U[;6TVI^<QHV0PHR<TI2:TYnOXjRY/:>A
QGf3O7^8OgIcKWR3Q7a`IeiGFF1KEfb4Rh9jPhjCThZ9UIV@RY:IX:RTVINGVZ6F
T9R@R8IgO89iN6m_Lg1`HUi_NXJLUViQK6ILDTiDEEeQJGZ4T9JASGm^KfiXJfia
L69JIG5hM7Z7QGIYJFi]JUm8@4A:DeUGDe5?C4A2ADePJ6j1OG=iM6UQFf1NFF]h
O9>X[JbRV8YmP81nQi2Q/[Zm_[Ve[ZJYYInJThf5O7^3TIbMXjVZZjbZY:>//JbX
ZJjib<k<_[:`YZjd];bh]/K7`kFMU96DVi69ShN1QhImL6IXIV5QFEI=@DE?Ef1X
K7=/IW9dKFIYN7enSI^[/jRNViJ2L6UUJWQoNgn9T9B<NW9ZFT@b<CI6De9PLgN1
RhR5Pgn2Pgf2Q8^P_]G7]l?;c<6VXjFT]L77e];1]I^<R7a[FUAJEDY3=3Dh;1TB
6b8P7BLc>34[;RlfBEUWK6agM6]fOXJAUJFi^[>]YJFUVi>>U9jCSYZU/K6[[:JP
THB?QW=gPHRDSi:HRXbDV9RBVJRVXInQZZb][[G6dmK<_[>_Z9fETYBGRX20QYF9
P8Z7PWibMGI_KVIICTU@DdeCG5aWKViaHUeOGfAHE65XMh=nO8:5SY24P7ajOG5[
Kf9KIFeXI6UWHF=[IEaOJWEfLfm]LGA^KViXKFeaMG^9QG^0NFi]K7>2SHn=U:BY
Z:b_^<OBbjnV]JZIUhj8TIBGUI2GSGI/EdI0<34l?STc>clj>CXk@UAPHUmTKGAo
R85oQh^DUIZOVJ>WVI^MWZZZZK6]Y9ZCTH5]MH26UI:;R7mjMGUkK720QiNRXZ^[
ZZn[Z[2X[KJ`]lKAfM[Mino_i]gHc/>i]kjo][>`ZKK0]Z>DVI9oPW]`NGQkQ7]h
MgEjLF]_J69/LGUoO8V?R8b7Q89WGfAGHG=bMVaPHUIHGTe5A419D59;>ca>HFa]
JVQ/I4P_;C]7Cdm8CUUNHFA]Jf=UI6=^L75kS::MSiJNYJjLQ860P7I[O8>1T9j]
YXV8R71]M7MnNh>AQhVDShYkHUeTKW=_L7F1QGeiN7^0OWemO7UjLF1UMGimMX63
Lf]OEf1LDEIRJfmhQXN5TiNGUhf5NV]iQh9oOi>RVZ2YWinV[K6XXjBMYkS1cmG?
bl[:aKRa^lgAa[nn_KVaZ:FWYYn?PhbHYjfU[[:]/JRQYif:PX27QhNCUiNVYZ2U
YZ^OSYBAPWQbQHj2UjfRX::SX8n<RG1ZK61PH59>Fg1kL6ARIfYWGe=<D51@EEMG
F5=>EUeSGDa@EE=JG6QhJEIFFeM9AU1?BeMOKWalP7=YMh22O79lNF=YL6ehOG]g
JViiNH61M7IbJ6YbNG=SHW9hMgEcJF1LD4UBHVeaHeEEDe]MEEM?BTm>GWUkM7Ml
N79lSXN0R8V>UZBcYIf`]kNaXjjZU9jPV:Ra];^e^KBMW9fCUi5oPYBQWXj6SHj=
RXN4SjBZ[kk6_KB^[k6UYJ6CS81oQXNH^<;3bm76/:JYV8bBS8EnQIF;Qj>^[::C
VHQ/NWi_M7AgO7AmRHJ@THN@ThR5SIfUX9fKUIBJWI24QGedO8N<SXR=Vj2YXi>>
OFmYFeUKDe9PL7MeQYAkIfEIDDaKLF9HJW1dN7jITh6>QWB2Q7eeIVa]IWAkLW1Z
GU]QKgAXH5eOIF=KE5ILD4Dn=cDj>D97@de<B4]:DEA4@DDo@TY@DdQ=EeQ`RI:H
UIjWU92JTYB4M8=kNHn?TjV^[9j=UIJ?THN1SY2=TIRUY9JBRHJHYjRQY[>e^/K8
blF`YYnS/Zj^[JVha/7:f=WFc/W3/JVORXN3Q8jBX[6//J^LW8]nPgMmThR3Si6H
Ui:CQ7^3O7Z5OW=gPHR4PHR2Nh25OgAeNGAcN71/K6YYHVE^JFEGATM1=3U8DEUQ
KgQjPgmhPGiiL6I^KV1[O8NAQHZGQHFAQHR=Q8R4OXV4R9B9QHj4MF]THfE/LW:0
VJbaYJ2GQ7EXFUUCDEeTMXZ?UI66Q7]ZIF=MFE5EEeEHD51MHfmdKgMbJGAfO7]V
K7AaR9^IX9^@THN7SXF=WYnW[ZVVYJFQUY27OX>;TY2>UibKYZ^YZYnHTH^HUhV5
OgEhN7b<UIN?QXnCV9jFVYbBU9FFY:JX[::YYH^AUXjGUiRRVibUW9ZEQ8F4OHR@
SXQkLgAkR8^9T9RFQgMbJEaLGFI^I6Q]Jfm[L7eeJFMRH5mJG5aLHEiMFU9FEEMV
JfmiM7YjN8fBR8j5MgMZIVaYLGajP81eMG9]L6eWGUIEFVE]KFMPGEePK7j1Q8b0
O7]hOGYhOgQfOgQeP8:2QXnFSHjBShb7Q8V5PXN2PhZ=WIfL[InCWifKXjF][:6V
ZjN`/Jb_Zj^d][>[WI>FXZVYZJZVWY68PgUmPWUmPhbLWIbMTY>KShZ=RhjDXZj]
[ZNMV9:?TH^:SX>3QhnOVYNUVI2DQh1nMGA/GV9QEV1/KgMdKV]SH61MFeaNFeUK
Gf5VJgAkNhF9PHJ8Ri>AUI^<Q8AgMGYfKFE^Lf]]LgAbJVYaK6a[G5iSJGUaKW]`
K7=^MhJ:S8EhO7eoRH=gNGYgN7]lLfIMGfU`L6eYIf]TGUmLIFQUJ6Q/MGAdLfIW
KVU]MGUjN7miKFiaL71ZKWMeOHAjNgb3TXEoRGehPX:6RHR@UYBNYZZc/kBk^;2]
[[Fg][Ji^[Vd]:n]/jjXXibOWI^QXZRb[ZZVU92@QH>7SXf2QXR9SXn;R8>2QXB<
T8ZATHjCPG^9PWn5P7moOXF4O8>:SiF:QI2JVI:=SXV1OH68RXF2OGYiK6MUHVY[
IfYTIVm[J6USIfYSHF=ZJVE]KfQWHemSHfEUG6=VHV]ZKGmiMgigNhF3Q8V6S8f6
Rh^9RX5kNWA[J6eeNGQcKW1dL6UTJGIfMg9/LG=iQ861PgUfMFeeOWanNgmoNhB:
QhZ9Qhb9SY::SXUoOgEfPgUePX5nOGMlQH>7PGZ2RY6IUIJPZJ^YZ:RYYIb?SI2B
U9:DV9>DUIFIU9FGSh^>RHjETYB@QgmmSIJGXJJSYjVZ[::SYInUYjZg/;6k[J>U
WYnRVYRGTIB=QHR2OGieK6UVHfE/L6iXGeEBDeYPH6E/JfYTGUiMGUaAE5iLIFe[
KW5dKfYaKVIXJFQ_LgMnNh>5P8Z>U9j?Ri61NW]bLGIkQXN3Ri2CWIJ?SH=mP8R;
RHJ1OgmoOWajOWmfLFaYJf][K6EUIUiWKfimPh1nN7E]KGUjM7MkPHf>Shf2Q7mg
OGf5THF:UY2EWIfTYj2PVIBMXJBXXJ2RVY>DV9^LVi^NX9nMViNMX9VHVijNUY2@
SIRQVj>XYJbVV9:CV9FEWIN=T96GX9bJUhj=Q7j2NG]mJVYcKG5dLGYkMG9WGfAT
J6MJFV1RJG=jNWQ_JV]_Kfa_Lgn3OGUhNWUbLgA`MWUbMGEdOH1kMFm]HEaTHUYJ
EU]RH6ETI71`LgQ]LG=SIg1`Nh5kNgE]KfYZLg5dN7=kRXQnNWE_JfQZKg=cLFm^
MgakO7anO7IgMgAlO7=eL6U]LWEgOHR8RY>>Q8AoPhV8TY2:RgmnP7Z<VY6FWYfP
VY2ASh^<QXF;S9BJV9jY[:Z/ZjRVWi^OY:FUXJ6[[J^[[[BbZZbYY:n^ZK2^Zk>k
^[2`^;6a^K6YYIbKUHb>R8ZEU9^RW:R/WIRGShj;Qh^5OWedLgYjOW]bL7AcLG9`
KW1`KFeYHF5OGVEWHeeLH5mGF5=9DU1;DE9AEeiKCdaCDEISIFQ[JgAfMh1nPX=j
OWmjRY68Rhf8QX>2RXZ;T8jCUHj;Q7UgOGn1Q7mhLfeXK71bLFYVJF]_LW=lP7io
NWElMgAgMG=eN7IaMGagN7efLFm]MGAeNW=fLVM^KVQgOWIiOH:?UIZUYJFQTXb:
RI:GTI6EV9jVZjnd^KNf/jbVW9ZPYZ^ZYZRRW:2LVj:MVi^CSI2FUI2IXYZHViRJ
V9ZQVINHUZ6SXk6^XjFNU9FFUIJAT9B@T8b6QXF2QhR3QHZ<RhN0O7UcKFm]JfYT
GeeQI69QJ6QVJFASJ6IPFeYLH6QXH69XHfAWIFUVIV]WJVURIFAUKfiZMWM`KFY[
LW5aM71dL6MVHemTJF9NI6ETIFMZKFe/K6UZJfebMG]lNG^3P8:8QhbAS8R7QhJ7
TI>=UYjIV9FATHZ<Sh^AUIBJUYBLUhjCTi2CTYFKW::VYZf]Z:RTWZ2QUI2DV9jQ
WIF>QXF8QhR8PGimPHAoOX5lNWeiOH:6SYFHUiRNVhn=SXfDUYVNV9VFT9NETi^I
V9jBQh^<R8R5RXn<T8j9RhN2PWadN7]fMGAdN7YiNG]hMWEeO81mN7IiNgQkPGeo
O7A_LWEeMW=^Jg5_IVQVHVAOHVESJFQWK6][KfESJ6=QJFUYJf=PHF=]LGIoOWMb
JUmQIFI[L6m_K6IYKVm`KV]YJ6UYJWJ2QHZ8P7iiM7ElNgUjNWYoS8j;SY6@SX^?
T92IV9NLUYFMVibSW9RQWZ6TXZNZ[KFa[:n/[;2XY:Z^[JVYYjNSY:RTXJ>SXjR[
[JBJVI>8RXJ2RHb:S92?T9>?Q86:SHnDTY2;RiBBRH=mOh5kOGieN7Y^JVUYK6AK
H5aGFEQMHV9TJFMZM7EcMGA_JFEQH6I_MWQfLgAeLg9iOWj6QhR=RhN6QX1oQH9k
NWeiNWakNgIiPhB4PWemO7EhNWEfMFacO824OWj5PX1mNWn5Q8:0N7IiN7AbL6e`
KW1hNGanOW]gNGmkMginOHB6QXAnOGn4QHB9THfBWYfIU9:ETHnETY>ETiFBRhf7
PHjFTIFDSXb7QXF4RHj@TiVHVj6OV9RIUIRLXJ2IV9fMWI^FUYVPXIB;THn@TXZ7
R8F7S9>CS8V8PHF:R8^:RH^4P7mhLfQPJ6i^MWQcN7Y_If=YLFa]KVUYJVEOH5aI
FEIGFf1XKFUTHUiMGV5ZLWf4PWmnLFY`KVYYJ6MZLG5ZK75_KF]ZMH::Shf;RH1h
Ngn1OWn9R8J@Sh>0NfeUFeaQG5eSIFU`KVa^L7QlNWQlP862OWQgNX24RHf?TIJF
UYVEUY^OYjbZ[KFdZ::W/;Fm`;Vf^[Ve/:bWY:Z/[k>_ZZn_Z:^WWYjIU9NHWjRT
WIVHVYjMWYbKWIfJUI:CUYVIWj6MWifHV9fQVi6ATXf>ShR4OgE^LG=]Jg=gLVm]
IV=SHf5OIV]XHemLGeaFFeQFH5mCDe5?Bd13Bda=BdaCEU9BCDUCGUeNJWV0OGMe
M7IgLfm`M7QlPhf>QH23Qh^=SY6ETXQoP8J9QgedMWn5Q8:3OWMgNWimLFejNGR7
QgajMWEeMgn5RHb8PXJ8Q89oPXV9QhB2RYBDTIJLUi:DTi:FWj6PYJZXY:2LVY^H
U9JJViREUY:BUIBAT9BAT9JBRXZ7Q8R>S8^;SY2;QXR8QhJ0O866RHV9RXF3RHN4
SiF;PhB5R8R7RHZ9R85jNGMfMG=jP8B7R92GUHR0OgUbLGUoPXV7NW=dN7QjPXR8
Qh5nOh21QGiiP860Ogj3QH5nP85oO7b3QH1jL6UYIV=WK6i`JF5WKFi/If5TK75[
Ig1hMW5WH69WIEmNIVYTH5YGGf9HDUUUJ6MVHF1WJfefNGMhM7EiL6Y_MgYgNH6;
TI2=RhV5RibLT9>NX:6RXZFUWYjV[:FHTiVZ_;J[/;Vh/k>h_l:i[ZVZ[[:c[JBO
VYFIW9fMVHb3Qhj?UJ:RVYF:R9>CQ7Z0RHj@Uj6PWIjLTXAlNg]lPh>1Q8>2Q7md
KW5eL6meMG5fNGAcM7=^JF]bN7=SEUMMGUmRHF=ZLFi[KG5eMG1]L79ePHN6RXZ6
Qh9jMGAdLVi/LG=bLGR2PGj1OGV0QXJ4OgelOhN3MW1^L7IeLG9cMGUlNGAdMgIc
MGIeNGU^IVIUI6I]L6e^LG=gNGMdKg5lP7b2RHN<U9:<RHb@TYVOXJZd]KFe];6V
WZ6VZjVQWYbNZ[>_YInT[[6_][BRShfDTi6CV:6SVY>BT8bBUXb3P8>;UInNVIB<
O6mfQhn5NX22NGR2Qh5iNGmoNgalOH20P820OgYiP8B1NG=[IVUWGE]QHfEYHEIQ
LFiWI5]CFF9SHfUZI6IZJVe/IEmRL7QgNgihJF5]Oh=nNG9]MH64QXImL7=oQX^;
Q81oOgenPW]cLgEgOWmfK69QKGMgLG1fNX23QH1`Ig5nOgn3PgilO7enQXZ5PXB8
S96KWIB>SHnEViVFUIRU[:FPZ;:e][Jf^;J^ZjfUVjBd]k>]ZJ^_[j^YZjRWYijD
T8n=R8B2QH^<QgigN8F@U8inLFaaN7Z3QgihMFiUJ7^6O6YTIF1KFf1SHfQaN7IY
H6IfQ8MgHe]MJGUnMF]ZM7UeNXB2LVekRHIiN7YaJVimPWIdP8:0Q81aJW5gNWin
N7A`M8:9R8N<TXn=ShMnPXR6OWEaLVeVKG5_O8Z3LVMZLg=VG5eTJ6ATK6e[K6aW
JG9cKgAjOX5nNWQbMH21OWegKfmgPH5jMH2>T8bCWi^@U:6PSXB>V9J=RXf@T8j>
TIFLXYbHY:ZLR8FK]KfcX9^RXj6Y/[JbWXR:Z/>kZJ6ITiFMXj:FV:BIQhZIWYVK
Zk6LRY2KUI>MSg5fTZRd/If4MGnHWIB?RW]hRYF?RXQfIFalOg=NF6efIUa[NgMZ
GDa5C4e:E65VH51>IW]eJ65OFe=HIFMPFeiVLW]gJf9QJWnAT7eUFfZ2Si:CQgMh
OGf4TY21LF]ePGelR8UnNWIdQI:?S8bATX=aL7QkNWQcMh5iL7nCTGm^KWnCVHn9
QGejOWafNH1kKFQdPhV0NGf4RXZ;THioOhj:M7RBU8R?W:6OUiRQXZ6Z[jVJS9:Y
/Jf/Y9>:VJnk]If:SibBRYVVZ9nCSiB>Qj2aWXElLWBI]:jPThB2RHInNHRELf6<
W7]XLGf;VIR3KVi_M8VAQ75PHVakRXUfI6EdNVm]KFEVK6e/JfaYJg9eLfICBEUo
TgiZMGAEEhRMP6ALGVM/MH^=NVUWI5YTO8YnI6>0RGI]L8>BNEUMK6mcQI>9LFf1
Rh9kOh5dKgb=T7a[MXnGQW5/MgYnQHR4MGEkM7jKY8m^GgZNXXaaMHR;Ph6?W9N;
Q8>>XJ^JPY:_[Z>LTXn<SYVJT8b?Ti^Z/:ZDMH2`]hj3UIR>THj7UJNQS7]gRjB]
UGA_PHAhNXR8O7f=VHY^JHNYZHMnT9nUS6]jXJ6=R8V5RY64KWVCSfmRLWYcKg9^
NHIQ@WJhZg=CEVZ5UXUdNWIQGfE`QhQcN8AeGeeXOhf5OH5gKGImOGETIWalJg67
OUmINHimJF9JF6^8WXmUDf5^N7UgQ9BGRgYiQhV5SY^BNg1dMWAhQi:=PgYbJFjA
[IUgIfQcM6ibLVegR8M[H86RWXAXHWB4P75aQ9NKTHV6P7b1SINDSY6:NWV8Sh9]
JH6DPVagTZ6@Jf5jRH:4RW1HNjjlX7QgTYbU/ZN>OXBL/[JZXjZLT[;9^9nEY[jb
SH:7OY>o`Z5nJG^V_:5UEHFQRWE`KFejTYIdD5j:XI=ZEGF7KEYOJFaeQGmbMG=`
O7AJKYN@Lh:RSe]=Nj><MHNEU8j>U8]iLgR5Pg^5ThQXF6^DXI:7MUiIO:FXSg]`
HfB4WIZ1H5ekShioK6n2Ph2:QG]mOgn3PX:5NV]/Mh2=VY=oO7YYIVmgQIFMSG1Y
LGf8SI29M6QgT9bHTHZ<RWenTIRCSiNSVhZ7RXnOXXedNinWPVE^RYR6KFEcPh=j
O8Z:LVA`QhUiMFehY;ZPN6UcMGnacK:8IVNIZhAaUl:`R69<HXbea9]SAdiaTInZ
UU<aEHBBT9bFESAZ[KZ;HG6KTGB@W7ASO:c9[F`lDI30d/V<B4UWOj^lSfQGCV>9
UY>7LVa/HeQXSiZ5N6YWLVMJPkFMKf1EFVEVNX]gHFMRIGUfLGUnOGIXFEf5Z9b0
KEQEJgn=TY>GSg9KFV^6TiNCQgAMH7j?RX>9TX9`MXF;PXFQZ8EWJh>ERGf<WY^>
QHJATH64VIf;QiJGSXZ7RiNEPWnAVYfSYJ6EO6amX[BKP7EgRZ>h^I5^NhQoR:Bd
YX1dOhbPXiN3NXNR]:9ZHH^JXJB0ADbO`Y=QJ7elN71OCfJ7Pg5YK6QQDdm/QW1E
IGa^DVZS/HacNhN7NW>;/ZYhDeilTZk4Y5U?NHb3Ng]/JhB9Kem`PHZ?OfU/Kf9V
Ohj0IfIaLhJ@R8AgNiFOS7EeW/RcQ7=hO8BGVi29PWAgPhN>THUmP8V3NXbEQh:7
T92?T8R5R8AjLg^<U8UdKWfBSgMdRY62MW1bMGAdO8:;Q65=HH2AT89lM61NNH^8
NFa^OXf?Qh9oM6imSiRCT9VFPWR3T9>HWi^;NFiVKhnZZ8YXIh2IUgEKKYf]RfEG
J829TZBPO5IKRjRET:=lD6^OV86KYGUQLhN;Q8^NUWi`L8NW/9MnLg9mU:fXUYbF
LEYRNZ?JdgdjAG>AV[78YV4fBH:NWIjDId=:GFj;ZiU@:4Z6/;>6IV]hMeifYJ]i
EFf1MV1/Vk26J7jKUGIkUIN4If9`SIn3FV>9U8n>NVM^NGf2V:B;FeB5XI6<UinK
N5MXSZJZUGEWJ722U9VCOFE/NGV0SXb6OgUiKW6@Ug]dQXIiMXjNQWN>XHedKgJA
Z8eQIHFAQ82IY9B0NX2:S8N9UYn>MFEXRJRa[Yn<KUahUY^SYYEiIFn6UZFiZWMP
K8>HYK>gYhAVN:N`SX2>S71WNHB7Ri:CSWQYNX^9T8e`IGfBRGMcMWInVJJ>M7=d
Nibn[W9NOHI_I8:/[WaJKGn5P6mfV9eiGFbDY8meMWeeMXR>OFabMfQSOiR@L5MN
MGM`NHF5MFIUKW]kL6EWJEQ=G7Z=OF5QKVUPLHZ6LVUTG622XYmnGeUPLWM`N7j1
PWU`KG=oR8j9N6a]MG]fLG=_K7nGSW9gR8fGX9QnJW:;VYJ8OH2<UYF8PhnBRHB6
Q8:5R8j;P822OH28QhF6PHF8RXV1PHZ;P7UeOHfETXR1QXAmMWN7W9^:P82=Sh20
Tj2FRiFGSi>HTXZ7S9>BR8JAVY>7RH^;Shb=RgiiP8EoNH27QXR?TIBOW8f:TI:@
TYVQWYNBTY>6Nh69SI^/Z9B4RibDT9fSVGihRYJIRGn9RGmhO7Y`Mi6EPGj2Pgij
PG]/KW5/J6YbOWj1QH9iL7AkPHj@OViVIg5fKFahOGMlP6m`N7ElNfU]L69RKWUn
L6A]Lg=hN7AfMgElPGIdQHV0OGUhOXJ9PWUbM7mlLgUkOXV3LfmXJ7IlOgicJfQc
OgQ^K71gNWj4OWEkQ8V0MhBEVHinOiBMUXb;WJ2HViRFT8F5QH>;Sh=kP8nFQGf8
TXilO8b=PWYlPX:4SHYlMgIlQXF<TGiiT:FJPhRJWi>5Q96;QHfAVYjDU969SiF>
QX>>Ui6<SYFEQgimOH1lJVUiPGehOh1hMWEmQh=mQHZ;SHF0OWUiN7Z0PX^BRGij
NHB8N6miS9:8R8AmOWf3P6eYLgR0RHMoLWV1N7n5M6aiPgifPI6:P8J=PgJ3ViR=
S92GThR4QX9lN7MeNhR9R8N1OWUaOXb5NW=eN7IdL6QZNgijN7QjN7f0NWb9Rh9m
Q8n:P8F0L6Q`QI6GTXB:T8J5Q7YkOX65NgN1Ph=mLfi[OXZ6PG^0RHQfN89oPX^E
Sh^:UJ6KVibDQh^OXinIS8b@SHj?T9BEShMnQ8b@Th22UHanNGV5SXZ;RgmkPhV7
PGAYLWAaPi:6LG9mQXIoRHf:SXMfNhnDR7MkNgQoMWZBV9B?PGYgNHB7PWMZJWV=
VHmjKg>7RGQ]Ifn7S861Qh^3MWEaJGAnPXR6P7n1R8b3N6]]Oi6GPg5gNgQjN7Mh
Lg^5RH^8Q81hLWb7Qh>8SH=gN7MeNgUhOH23Q8R@Rh>9TI6?SXj3K6I]LGAiLfYc
PhV2M6]ePH22Ph64Qh9hLG1YHfihNG5YK7b<RXF3OX>9RXf7PXJ2Oh:8S8V8T8b7
S8n=RhZ8Tj:OR7YoQ7enPgekMfejSiB?QG=XMX5nOh:>UHUoQHR9THElQYJGQGf3
T9F<R8EiPHf?Shf8Q862S8QiLgf:SHZ3NGMmTZFMQ7EdMH1iL7mnO8J2N7EdM6i[
MWYiO8J<RXb0M7ioJVUhRI>7QI2>RXn=PWajMG^6TH]lO8B5Oh>1MWj=RH:5PhN=
PWEhNWQjR96:RXj?ThimLGZ;Sh=kSJ2OUIJERhN7QHB:Sh^5P8fGSXb?UYJ:Q8N6
SI:;OFabQXQmMg^5R8N8RiFLVi:<TiR@RH=kNhB4OWalQHV9QgUaMh>CTiBGM72B
PWMiH6Q_IgQgJVm]M7maJW5`M8:4P7ioQHAmNWR0Ph:CSH>BUXilKGN0R8n0M7V7
UYB8OVmZKg9kMVecL7>0PgUbKg5gLW1fMGanLgb<T96>R8B2QhN6TY9hIVn6QWZ2
RXj<O6efRHj6OW]iOX5nPh5lPWM/Lg1_OWmmNViXHfYoQX5dLGUnOh24PH9mOHnE
RhJ2Q8InO7f4Ti62PY6IT8F0NG^7T9:@U9jCSYVETI2:RGinS9>OY9jLRgZ1RY:I
THZ<S8ZCVINBUIZFU92;SI2<PW^0QGigOXZ8OhZAMgB>Sh>3QGN4TXAkN8=kN9BV
/[2@QhV?UY6HX8ijNh2;TiVDOWMmP89iOI2<SI:BUIB8O7aoOWUdJV5ZLg1/KgEg
Lg9iOGmgJWAcKW]hKWEcOHalN7alQH=eL75]KF]]P8alIf1]LfUePWb0MF]oQX5n
Kf1QJ7>3SXihNH=dNhF2OVY]MfidO7IaKfejPgE/LGYhKfEQLH:6Si:3OHJ5Rhn>
Ti>@Ph>CUXUgMXbAQijJPhj5JVb1SI21Pi6AThUlNgEnQGY`KW20TIBPV7m/IGV7
P7Z3TYN>SY><SXf1QHF@WIB>S9>FQXNKVWeXIGN=SXR9SY68NH2HY:fe^9n?WYb<
SI^PVHf;U92EV92CTXn1OHR2QJ>WT82:V8^0OgV6VIVMWJ6`[Y^9LfINKI^YVXE_
LGR2ThM[KGUoQH27R8BHU8jCQh67Q8>0JF1/Hf5IFgEZIg9MDeY_LeUOKf=ZMWIc
J6I]LWI/H727O7AlP7MUH6U`PX]bJF]WJVY_JEaWLg=jLgF6RXV1OHYlIVmmOVeS
MGY]KW5bNWeiQYfBL7::S9:BShadJgb1NX>8NGR3THioQhQaL7I_JX61HFnGVi:9
MW1`Lgf=V9N9P8JFSgQhRhb0MW9mT9jWW8J:Sh>2R8b;S8V=XInFVIF:SY>=Ri2N
Y9fGR6Y[MgmeJganLWZ:S8j@VI9fNH5gO8bGW9N@TjJi^9n=RWn4S8ZKVX=oU[o8
Z8fAYJRAS:SDhlFMR8UjHUaYP7mfPY>OX:>d]:ZJVjBTXYnHSXB3T961LgV6RIZZ
/KV/UIFOUWihQhj<SXA_IF9UK65NKgZ2QWm]JGV4NV]TIVi`Kg22QGUfNGEVGfEY
HE=BHVEHE55>Ff9JE59BFV9JEfEeJe5;F5mGCU9IFe5:DUMEDeYRGEmVFEATMH>1
R89eL6U[NgYTOkfdQ6jC^IelOXn>TgedUJnLLi2USXj;O7Z>YZNNQG1cRIf7JG63
LV1]JfB;UhEjN7YbM7imPWeaMHF5NGEfMFmWM8Z;QWZ=[k6_[;ZcU7igNHfj`:N;
QIfCT:BLY<:l^:>8Vkc:c9j9Vib]XX^Z^:>[[inU[J:IRIn^Y:Z/YYfKYkZeWiN8
QI:NZ:RZXhfBYIB8WJNWYjR]Y::l`kBYYj2BSZ6YW8Z@V7]mVYN>SG>2XXf@RfaN
EdmPMh9eK7=YGVn7RGm/C2lP<DmKHV]aIWf;NGJ2QF92<S@lEEeNJFE?=4MYPXR2
NfU>BF5]DTI9I9NIJDaJOHQcKWegDBP4000@9CQJJF1LIW9nXlK4S2/1018nF6me
Gf>LaLc1[8A>Cgf=PEXS8DEaXJ>0JVIhPFi/TYQUDf9VLX63Lgf5ED9VVIn<VY]k
GUeaTI5[Df^Q[Xn2Le=HOYVT/JnOS86N^:bRS7j5U9^TZJn]Zk76gL66KiZj/Jj5
JGAZNZBhYH=`PjJTYI9eMXbGN5=<FWJ:Qh24TiNMY:RVUXn0QH9iTIJ@Q6n4VIJS
[9V>XZf]^lb_Q8NUZjn`SXZJZJ>?Vk>nal:RS8J;V9RCV9JCV;?Iek:BU[K8_k>`
]KNe]kZb/j1kN8fabLc2V8;2mLmmC6g6m/mi@eAfW;68CTMMQJnZV7ESP9BKWYMo
F4YdY:^/Se]KS/;9[7eCH:SC`iZ<WY^<TJ>LLT]KOHJGZZ^AKWEeE4mHJGebHe90
BeE1EWML=c55FT]<K8jOP5EEBbla=55gIcP?01doK99lBR4HAgIiHCP`;@h42003
6b<V8Bm7ADA3@Tld1@00014_ADPoASlZ:SQ=E4Y0Bf^<Pe@i=decPGIRFFb?Z;2/
YjRNXJfIOX6Wa/o2/[g>b<WAeMK<e>?OfNO/j>3FeLRfZj:V[J>U/kc>d:^2K6MX
NYnVNVf6QWn9UIBDWZZIKW>KcmnkVY>>Sj:TVYVOUI6he[b=T;[>_:Ra`KFOWZfe
/jbNUYfLNe]TQHURCVMmIcDR>4e?FFiTAS`n?UQlO65ADF=hPY>VbNKN]GiVM8N?
WIUlFeITLXnjcK>6Jf]fOgn8UY5kA`lA=U58<BDT;C]9Ef]cHTPa7a457dmPD4a@
C4M4FY:l[hb?Z[_=gLFOThN:XkkBd]C]nncJh_3_h]OCe<6b^jb=OXB?RY>XYYjU
/ZfPV9fZXi:7MVI[PXN3TIJ6QZNg^LWDb<72Yh>0VJnaX9>T/InL//>nWiZc`l6c
/jjQXJN]ZhUfT:^_XJ:a/I=jR:6XVW]XK86CP6QZLWf>XIF6R8N3SIR8N6YWH6J;
S7IjTJ2RYJc7gn_EUf4m?fF0U8]L@dAKOHb0HCXF2QXgCDhm;200000001//:cDa
5@PC92lj?B4D7Q/aIX22MF1;?UN5[l_;/Yb?Qh=iLGn>X:B:R9FIX:2AO6ebPhn9
IUeeLVeUE5E>@E1`SZ:JS8QlMGIhOGj9VIZPVhB9Wj:SZK:aZJja^l^fRFeWL7Me
M7f<UY68OUY9HWV2N69CCf1_NXI^E6n7QHF8T9FPXXj7R7A^NW^5SGmcNhR;PGQk
MW5hP85iO8YgH61LFEE7DfEZQ9NCVZR/V79SG5IXKFEG@TICGF1/P7MJCU9SO79H
ACm1<A40120Z:2``?UINHUM1Cfm^EU9@CEQNGUUFIG^AZ[Je[Jg1f<n`Vhb2QINX
VhZ;Y/S4]JVW_<oBb;nj^LG>^I64SZ2VY:FY/kk9cmKC`kR^[[N^Z[Vj`m[Hc<?2
bmc]m>gShn3=^[Bg`LS6_;O5cL[?clBn_[^k]JR`_[R/ViNRXJ2XZk>h];JfZI^K
WYVHRFm[M86:R8>1SZ>//;2ROVYdR8mkL7f8QW1KH8[=mNc5W8N3QI:DP6=GEDE0
DfYaKFabH2h@:VN8MdHG3@L2104;9DQOFU1=>CEMOHN5MfYWMHN9LVAbN7=gNgfC
]<kJbZbGSIJGRX^L/kZWU9FIUiJKY[:YVYfUX9nJSh^2LFATN9VXVI:SZj>FTj:]
[l3>`ZVNX9nXY9bWXIBS_lg3ZI^ITHj0L8FFQh>:PWQ]GE5HKG5]MGb4Rh5YFE5>
GWIiJFIYKXB@O6UTGdi0CFEbL6ecL6ADADMGIV=VOHAXF6M^JGAeHEabY>3[_8Ug
Lf5<ATi3;cA=FE=8<B8]@4HV00@[C5Hk2`00000002a6F69FCDDm?CXc=3Tj>D=>
D5]KC4Hi>f:3W;g1^KbYTGiUEDmNPXmmI55GMh5aIg5fMH25Qi2?LUE6@4A;C51P
NIZc^:bLVjNodMKCbl6`/;^VVkK6bLc<e]oKhNOE`:V?P8:AW9F?SHJ5QHR6PXF4
S:2Y[J:;Q7m`LGYWHXRVX8f;U9^RZJbOTiVMWZ:TXY^>PG]iR9ZOZ:RBRIFKVhj<
UiFKZK_Ho_oh`J6@R8R0Q8^1MF18H7e^DdUQMfM<@Te]M5Ti6`/50P8E?V^9OF1B
CUY]PIj_YiJ<UZ6FSi:EThR8W[:leocoonc3WhjJZ;2bZIbLTg5OJGV1RIVSXinG
UjZm^:>=OGnBXjJ[_Lo>b;fd][o<f_Oooo3NclC9d<K0_;2VX:Ji^9^7Sj6VUhF1
SIZFPWUfJVI[Kg5jPgYhQh=`JF]]Mh::RHZ:Nfa/LGIlMfY^NX61LeeEFf9SFU]Y
LWIjMf]KBdM@F69ZKGJKcN;A[XE]I69PEe59>c8^;d1;@d=?FTlc7AP^ATTa3000
00001B]EI50n?dmVMgMeRIRCQfaOJWf;QWAbN79`PZC0_ZZ<KVMZIV9WN8AhHDm<
F69TL8ZRYiZEWJ>OTh^FXJ:GQXZN/l6k]KVf[Jnkd^gbi<Zd_<>j[jN[[JJQYZFI
S8ZBWJ2CQhN<VK2dW8F2SiB@T8b7SiRKWIR;PhV=S8Z<UJ>SUiZKTY>FUi>@VI^K
W92>SXB1OG9ZKh:CSgm`HeeWN7YeQindg_oofj:7TjZOOFYVMWa/GDhd4a4iIgIW
ACA6K85S;`l65R`_;dI/P7MYHUeQJWNK_/>dVhQlMGI/IW=fL7Z9UjBc_jjCShj5
Ng9fUJnTPEM3D5Y=BUmcP9BUVhj3NhJFT8:;UIJM[Kk4^:6ATifW[kFi[ZN]XhV3
SiNGY[Re]jnAQY6BPgUjPHN6P7YhM6a]NH5oMgEoU::IOFMVLWaeKW1_HfAbMW1[
I65bP7imQ8:4S7]B@eAEBTmDDfEaGT=2HFaIEEeVKWZ=Y/CRj;]hGFE^JEm^K5Q8
;Qd]AD8c<DAKET4kAeMB;P`000003RmDKgMXBci7F6UkSiVKXZJCOGEgQ8YjIf=i
VYnKYJfWSF]OIgN1Ph=jIeU?C5]YK7F8W:JVU8NDXZZ/VXN3S:2b_l2i[jjia/_:
bmW[l>?:^;Bb[JBKVI:?UZ6/YiZNX9VEUZ2YYjFVW8n5PXV=T9ZV]/6k/:f_[ZNL
SHNCWZVc[ij=QXB;TXV4SYFIXZ6:L6MWK6aQFf9YK7AlN75WGVM/HVEnTIVV`nkn
gJ5mMhRNV9:>NVAPHf1QH590?5=^M6ELIG=U?1`<52dnA51WNWUWGF1[RInY[[2e
]k>SS8B;T8b3P9>X[J^XYJ2LSGQ`OIBEPW5UJ71/FeMZPi6GVj>a^kNd][Fa[[Bo
b]?@cLo;`Kk5c]WYkn38_;BYUh=iM6iWKgeiNHB4R9:;P8B@UYJIW922PWmfNX:9
TiRIUYZ/ZibKWIVKUXj@UHj3NFm[LG=WIVmgRYF<PhV:MF]XEd4_7B4k@STf?T12
CDQ8HWU_HgElOY:afoW__HUePYfRUWeOFEaCA4QBBTE:F61FBDAKN6Lm600031TV
?eY]KEiFFf]jPXjDSi6DTHEhKVM[MFaFDF9hRi>:NW=fLVieM6i^I5YQIEM3@eal
S8n@X;Zm[jRZ/;Je[Zbc^;2WXj>^]:VPY[[@f][Gb;>PUIFMWI69QhjMUh1hQYZW
[Jn^Z:FUYJf]V7eYI7>6SI6CUIjMUi6>T9RV[Z^IPgf5S8b3M6Y/IfA]JfITIVe_
K6aYJ6a[JV1LJVMCBU5XN6eOI6=UNXR7OXJR^m_jmL>BQYNYZ9YnHUmRFTY6BD@k
>DeVIeQ@F6ETB20501Le@TQBH6AJDeEXOHNCY[Fl^JfNTY:?Q7M^L7b8Ti^<Q9JR
XiV6PX>4S8f0Kf1FEEYOHfYjQY>RXibDUJ[=g=2n^/G>c/S3a/W7`;Rla<6k^[>Z
YIZ@SHn=S9>FUXioL6efS9jITiZSZZJLVIBAU9>:OFmUJGV3NVIHGgF5QH1jOHN?
RG=QGF=/N7MZFdiCJGU`FUAOHV5RIfi/G4U6EV5KDe9FH6]UHVY^M7QeOYRed>KV
`iV7QXbCVIAjG4]1AeQPET4a>E9NE4<nBE1;?28>4b]8H6UPEE=9B620T92@UIRL
Uh=kPhF2NfYKG6AYLh23NgUhKFaiQHZ:PG1/MWEUFEUNK7McKG5kSJBa];Ji_/;6
b/[2]kVma/VgY:>Z];ZdYjFYYY^JXjZVUhjJXiN5MG>=ZjJ=Q8Z<Q8BCXZVSSh:C
[:fQVinVXY>1OHV>T9fXXYN>QXN?TiB@Rh^=SHR1OWeoO7QhL6e]JF]_KfmbLFa^
MH6BUi23OXJDXIbBV:F_^]Gkoo_Ja;Ra/:ZKShA/BSU2EE]<<c5<IVmZJ6i_H4i3
>CY5Bd]CGVERFUi]PIR_`lc9a<S<_ZbSWIjQV8R3RY:CS8B7TYVBR96MW8]aJFaZ
GTm9DV=[KWjCWIV@U:c8dm3:c=_Uflg>clNgWXjDX:FYZ9nPZ:BIUiZETYRHTHn7
NG=iOWQ[Ig1jP85oRY^X/[>XXIfIU9>;Mf]`MgEUDUA]Ng5JE69[KF]WJ6m`I61U
IUe@BdmIFE1FJ79]IE]NJfaNF61XKVm/JVeZGEi_Q9>BRY6dgN[H_:B:PH=hLW1S
B3Xj>c/i=2hjBCda=Cm9B3``;2/T82Y4FV1D?ca8E5i[OHZ>TXj:Rh9eNXR=PfaE
CeYWIVAXIfQ_JU]JHfIWK6eVH5MEIG9WFUm]Lg=iNX2>TYRX/ZbRWiVJZk6SWJ>O
VYjX^L_<]:2X]kJa[ZNWYi^>PgYbL79hPi2;OhfX^;bf[JFUX92?VYVHW961O7]i
OY:TY9fASINJT8J>ThEhL6mjPGMZLG]jMWQoRiNAPH:BThAlO8ZNVH1]MHjERGaf
Q9VJUInb^K_=iNcL_J:O[k2STX9lOG1GCda6ATM7CEUMDDiMHUQ?ACTh>d5CJ7Qf
JfmoTZ6W[l7?e=;4]:^UWIVQYY9iK6a`KfUUIg9fLfmXJG=gL6EQHEY@D5aaOgao
TJ:Y[:jc^L?2_;o4`l30b=7@b<?0a<_;c/g3^k2SWibBPWAaMh>;Ofm]LG=lS9NH
ThR6Vj^PRgilQ8^2Lg20THn2MWJ3RXR;U9bHQWQbL75ZGEIBF65OG5YECe1LK71X
J6mhOW]`IVEQH6M/J61MGVMaLf]WL7^3Pgn5TIRX]k>UTgUYKWMfFCP[;SHj=BhZ
;cDi@4M=BCP_?TY4>CDc<T1AEUMJFeYEFFYkOGAbQ9RFQ71RHVYTE51GG5mPFDa8
CUQXN7]aJG>4UYV6M75eNWf5TYVGUIRTZJ:NYkG9e]?>e=S?aL;8blW4`/K7`KR_
Zj^]ZjRVY:>TYjZXWY:6PI2T[:f][[>k_KZe]KNf][>/Y9bHVYN=R8b?SHV6RYFN
W9BCU9FIUXR9VIV:Oh6=UiVDUIjRVXN4TYZ@NfefQhb0L71dMGj4PGj0P8JEW:6Z
/;G1d]WBaL2l[Z6JUXYeIUU>BTM0=2db>dE<CDY=EUYGD4Dn@DiLGUMFGVEUIW20
SiRJWjff/jNMUiNANUmHJG]jJf1LGFA/KVa]KFa/JVMVHEUJHVEUK7V3QHVBWZfk
_KRh`m3FemC7_;Zg/k>aYj2W];BXWZ6YZYnAR8:1PX1jMG1VGf=YL7EcKgR6QGYj
PhjETHb=QgefLVi^MG]bJ71lOW]iMgAeMW5]LG1XHV1RHUaBBDQCGV1NHFIYKGEi
LfUUKGI_GU]WKf]PFUiQHfEQGfQfNgEbNiN]WhMlMFi/KFEFCda1>CY0ADA8EEiU
JFQYLWYkKeY8@dYFGf=LEEADF6=]MX6=UINCSXAkMGIjMVeWKGEdKF]]MGYbIf]f
PHR:QhVCV8UdL7Z;VIjTZJV[]<;Ij>CJe=3>bl:dZZbd/9j?TYjW/;Ng/Zjc_;be
ZZJ//[B^WH^8TYfQWibNXZ2NYJ^TWiR<PX69SX^8P7f7RhF2NW5gQi>FTi6EW::O
VI24O7QeKf1EDU=BE59?E65_NWmjM7=/J75hMgUkPXF1O7IgPHZBUYRNXjF^_LcJ
c[:WZZVOTX^7OgE]GTe@FE=>Ef9WIemFFfafKULn;cU=DTm=D5URJ6UYLhB=V:B/
/kB][;6[V8Z7QH:2OgYhNGUgLW1]J6Q_M7IgNgedIV1XMG^4RhjGYZnja;^^/lOH
gm[8_<CBd<>eZjZ[ZZ>OY:RXYinGTiBKYJVQT8F4RHZ2Mg=gNWj1Qhb9Qh=mOgig
LgQiKfIQGF5[KfibNGf4RH=jNgilNG9YIF=RIVMQFEAGH6=JC4QKMH20M6QTJFiQ
C4eGFUiRI6ITGE]NJ7ElOGMcNhRI[;BXThIkN7j0NgIhNWI`IeQ;BdmDFeUAE5eP
FeA@C4M2?C/m@4MBHVe^HeUQM8RCV9jOThAlO8F8PWUcL6maLW1`Mh66R8Z:Ri:L
ZKB_VXMgKG60RXV<VZ^i_l75b/oKj>KFbL>m^kniZjJWZ[6f_;o0_[:TXJ:OX:J]
[:BJT8b:QGn1RiJLW9bPYjZUVY:>SiBESXN7RI>KT7M^NhnMW9JBTYFKUh^3PX>5
Q7ecL71`N81nMg=_J6Y`M7QeKVebLg1]JVEYLgYdJ6UgRI>DVIjPXJBa`<[=a;>W
Xj6JQg=bN7Q[Cd57Ce]WK6QNE4mIHUm@>RPW>d<k>Ca6DeEAEf9YM8^T[kBk]Z>G
V9F<P7=WGeiQI5iBCea]LFe_MGb4QH5nNg=YHf1TKG9aMGj4PhJ<Ti^T[JjYYjbd
]ZfVYZJ[[ZVPWinGUYfQWY^DQGn;UYVBQWYjPhR9RXIoOGenQI2DRXF@VYZAOg9g
OGQbLgEhOh5oPHB0O7ioNW1VHFUgNVYHDDmBDTU4BU5@DUeWL7UhLW9hO7QbLG1^
JfidM6iTI6ahR96?SYFMY:naXiJEUiN?OFACF6YfKUA3B5EHDDe>D5ADCDiHF4a4
ADI7AD97EFI^LWEcM82>UIfWZZJUZ:b]Y9NEV9RDSX9eKFa^MWijKVUcPHV8Ph24
S8^8SiFEUj6`^KN]ZkO8dmGEe][LdLC3blk7_KRla/6^XZRe^[Vd/;2[YZBUYZ2C
Qh:4RY2?Tj6VXinGTIFLY:NOThZ9T9RISWegOXJ9QGmoQi6EU928PGmoNgMfLVYX
KW5^L7=`JVEYLginLVU_P8f:OGMiNWj5SY>;P7]oSiZGS8JCZ;F`Z:JVXY^?PGYf
M75TBc`g>4E?CDE2CF5^L6mcLfQOHFU/GdY5D5mNBT5<Gg1jPhjJXIZ:QH^>R7a^
J7=lMVaXIF=XK75kP7ioRifUWXn0OXR;P7MhO868S8nCVYbMX:B[/K:b/JnZXYV>
RHfDUI:ATi6BVYjITHjAUiJATYFDRX:7SHMiKG>7T8QoOHF@UY:9QHN4OGYiMFiX
J6mdL6IPGfA[J6AVJVUYJ6EVJF=DCUENGe]NI6IWIV9SJ6APJWEaJfU[KgAhMg5Z
JWF2RHZ:R8J>XJf[WHZ2Q8=kKFIVIEE2>Sa3?2dW:S0_9RTkCU58Ae1NHUQ?EfYd
LfYYMHNCU9NT/[>/[:^TVI2>TIBAQGinQ8N1NGImPhJ9T9BCUIbMUXf:SiROXIbJ
X:Z`/kBia<_?en7Xh]C8alg=a/70`l6j/jj^/:bQWJFZ[:ZNVJ2TW8j4Q8Z=SI2G
UY2CV9ZPXYnRZZbUVI:CU8j6QXJ2P7ilPhn>QH5kM7AeLgR2QH9oPHF5OGV0Rhj6
NWN3T9>AS8F0PH68U8n2NGMkNW=ZJGB3SiFHW9bLXJ:PVI>>R8fAPFEGEE=>@CDi
AUAEBe5UJV1BCUIOHE]GH6icL6QTKW=^Kgb=UHeoOH61MVAIG6M/HUE@E5YNI6eb
LFeaOHF6PWimOGinNgb3RXb@TXb7R8bCWj^/YjJWYJ6KV9B;PGYkP8N>SX^AW:>W
YjFSXYnLVI>8P8:3OgYfMgf7SXYnO8FAVYJ7O7YjNg]kMF]SGEeTJ6MVIfY`N7al
NgM]K7EiMG1XHV5UJFidMGEcL7=gM6i^Kg1/I5eJGVU[I5mMGFEePhjASiBPZk6_
Y9Z>SI28O6mMC4E1?3@b=S<f?Ci0@T4n?D14AD=3CEeVIVANFVMoTijUYZ>Z][fo
_[J][:n^YiZ;PhJ>TXYlMG^7T9:=RXIlO8B7Rhb7RIBJUiJO[KS3alO;c/oGhNKT
fm7:bLg=aKJYZJj`[Jfa]KNl`KfbXY6;TYNAQW]eLgMmPhR<S8^@VinJUIBJXj6G
UYNAS8b;QWmgKW1jP85nMGN3SX^5Q8>1OGMeOH5gL75hOX9mMWZ7TY>BTI6CUiNA
RX>3Si>AS8:2RYb^ZZ2ITHn@TY2?SgQC@T=6?R`L6RDd>cm9D5AFEV5bLVEJG6Ma
KfIQIfeZJgN6T9FCS8N7QX>0PXV=PVmWJ6EJDDm=Ce]SHVE]MWb3QWmgMGR1QH>1
PhR9Q8FDY[2a/kk9bL:j]K>d]:jVXIV?QhR?V9>1N7^4S9:DU9:;PX:7QGieKG1m
QX9gMH>>SHJ1Oh>:Si:CSHAmMG1^L75bKf][KFe`MGUeL6ibNGj1Q8F2OGE`KVi`
MWMdLWAhNWaiKVU^NGefLgb4P7]mPHN9RY:MYj>GS7YbM7AbI4dg9bT_;2HO8B/f
?T=8CUAHHFQZIe]BEEiVJFIUJgV8S8jDVIbRY:>SXI^CShf6P7iiMGIfM7EmRiFG
TXIoPXbCT8fAUiRBU9bRY:2LXkK8cmKRj>GTiMc@c/_7`k^g^K>WXYjHVIfIU9:C
UI>=QH63Rhj7PH>?XJ^WY:>SYZb`[Z^WXZ:XZZ6DTHn7O75YIV9NI6e`MGIbKgJ1
QHJ3NW9]K7=jOW]gMWMkPHB1OGmoO7eoPH60Q8Z>RG]dNHBAV9JLZK6]Y9^EVZ6F
Nf1CDdi3>2h/<30c>Cm7C4iAEfE[H5=9A4QBFf1VJgAiOXJ>Ti67PHFBW9R;OGMl
O71QEDm@F6EgOgioOh:;V9V=QX9lOH1oNWIhMg9aL7F2S9BKWZ2NVIbSY:FUX9R@
SY6EVYbGTYFLXIbCT9>JWYZ@RXV6P7]gMgUkNWb1PXB8T9NDRX>5SYBCSXZ8Pgik
NWmmLFMYKgIkNWMeLW1`LWAfNGQgO8:1OGYdKFmlQXJ2OGYnRiNCQh63QHF5R8jF
XZf`[Jfb/ZJKUHf1Je]DCD]:AClf=3Hc<3Lo@dM7ATM4B4mDEeEEEU=HIWJ2SIVM
VinVZJ^^[k>aYYfIU8b4OWQhOGUaMX65Ph20QHV5Mg5eMWMkP8F>UiZJX:nj_;fo
b]SLf=?Bcl_;al:o^[Ji_knl^;6_/[2XWYRCTYFFTXIhLW9fOXN>T96HWZ6SWiZH
V9NCT92>Ri2IW9^HUHn?TH^7S8f:QgmhMgMeMGUhL6ENG5mWL7MhL6Y^N8:2NgMf
Nh>7SHf3PhR?Ui^NW9ZT[K2YX9RAQG1LCdY5?cLc=d94?Sm?IF]TEeAPJFAEC4mI
HF1KGFQdN7f:U9bGQgYkPGifIeMBEeaNGEQACE9KH6=VIFQbNgn5R8J3PhB0O7Yn
QY6IW9jSZ:je_;fd[:n`[Zf/Z9fCTYRFRG]fNh>7RHjDUI>DUIFBQgemPXJ4Og]m
PhN8RHb>T9JMW9J@RXF4QH1hL6YZJVYWJ6e^JfeaLg9`Jf]`LgMiN7EeN7]mOWai
NWj0OGI_KG9jNW1VHfM_MGEfNgn8SYBKWj2NViRETHMcHEaPGEE9@3i3D5UJGVE[
JV=HDeICCTa>DUEEEeUOL7]cKGAhMgYlPXN6OGMcK6YXGeeVLGYlN7V9W9jIUIBI
VYFCU9JGUIVNWY^LZ;W3b<k?cL_8b<[9a;V^[K:g^;Ba/K>i_/;5alFo^KJh^:jO
UYVNW9F@T96CV9bPY:Z^/[Bc/JZSX9fGSXR<UIVGSXF0PhF2OGanOgeiNgeiL6a_
MGf3Ph66Si2@T8b7P7]nP860PXAnNWQfLfYVJ6ihOhN?UifHUINJV8akL6YMCD91
ADU9?S8c@U5FEeQPJf]RE4To?T0n?418BdiMKGEhNX>=Ti:>Si>@QWAODDa:AdE7
CeUSKG5aLgEhO866R8AnP8bBT8^;SY6CTIJRZk2d]K>e^KRc];>[Xj2OWYbFTYVX
];Vi];2_Z9bCTY6<QGieLWAdLgIhMgQoRI6DTY>EUHn6PX62QXN4PX:1Oh:4PGmo
P8>7QhB3OGMeLV]PEE5AEV1WJVYXIVaeO823RHj;Pgb0PWU`JFQ/KgJ0Q8bGWjFS
WijJU8j9PW=NDdTm=S0^<SQ3BdiDFEmTHEmMETe8ATM;CTmBFVI_NhV@Uj2XZZBN
VYRGTXN0NWAaJUiKH6M/LWj9S8V1OGf4S8n5Mg=jQHV<UZ:Z/ko9eMkMg=kMfMC=
`KF`[:N[[ZRQWj6V/;Zn_kjk]:^RW9^GShb9PWakP8ZBV9VGUYVT[Jf/[JVPVijQ
V92CUiVFT8b?U9FBSHV4P7aeKfaVGEECEUMEDE1FGfM]L75dN7YnQ8V:QgicLWYl
Mg=`LgUlPXJ9TinZZj:IU8f9SI62HdXn@4I6@T15CeYPHV=WJfUXKW=]GDi7AdQ:
C4mDH71oQh^CWjRVXYfIUhj2N79]IUeCDEYXLgMmQHZ:QXN;SHn>RH1iMg9_LWR1
SIJKXjbb^;Zj^;Fa[:NPUi2DVifHThj9RiBOZ:^]/KBc[ZRMShJ8RH5kMg1`NhN;
RHN3P8:6RHZ:R8F4PWaaJFU_MWE_JV]`MWYkNWI_K6m`JfISG5AAD4e;CD]?FEmU
Jfe]LGQiLg1cMW9aLg9`JfEWLgn3PhJ>VZNZYJ6OWijKViElF3m4CTa6?3U6FFAS
HFIYIf=MGV5LDdY6CUABCDeGJgn9SIFRZjZRVYRHU96AT8j2KfEUIfIVJ75nRiJG
UYFCTi>AS8EkNhF@Ti6BVJNgaLcAe]KEeMKGcl>h/kNn^[:/ZJZ_];c2_kRf]k^m
^k:VWIRBRhAlM7F1SY>CT8R3RiZTYJ6OWIZHUiJCT96BSX^<Si:IWYbCQGn1PGei
NW]jN7IcKFQTH65ZLG=dMGV1R8Z3NWEdMGIfMWYhKfmhOWmmOh:6TIbTWiB?SXnD
V9R>P7A^J6ATHV1LFfM^JF9PIVMRGEM@C4Y5@dQ=DE5ADeYVKgB0Rhn>QGahNW]i
MW5]Jfa[IVIWIfYaNH27R8F8RhZ8PWYaLGMjO863R9:FUIJJW:2X[ZfWXY^FUYNJ
W9VARhfEWZ>VZ[:h]:bWYjNUX9ZCSh^6OgaoPX1iMGMmPXJ7PGn4QX>3PG]dKV]X
JVmeO8>4PGmoOh:0NG=cLg1^K6QTHV5PH65ULGYlOWemOGagM7AbLFe[KFa]Kf]Z
K71gMWAiOh:7T9NIUiNIUYBBSY2BSGeZIFU_LFIIEeePGUQFG5]BCDiCEE5:AdYB
EU=AFFYhOh>;V9fCQh>4R8b8NW5cN7]hM71]K6aaNh>2PhF1OGaiN7QfMh6>UYRK
WIbOY:^b]KJi_Kjo`;fg/:^XYjjg_;o2`knn`lO4^k>`];F]XiZAS8f?SXf:RI2K
XjZ[ZJNXZJJOV96;RXf?TIBCS8bBUYJEU8j4NgMiOh1kLf]WJFa[JFU/L7EkOh:6
RHZ:RXJ0OWakNgUfLVQRHF=TIVibLG9_JVYcPHV<TIJFUIFBSXbDXJBIQGEaL6eW
H5aKG5YDD55DEDi4?d57CDi=CeINHF5XLgUhMgZ1Q7mdKVicNGagLgImPX>3Q8B4
Q89oOGmoNgUgMWQnQhnCT8^=TiJETY2@U9RLX:>UY:2MWj6QYZnh_;Ve/Zn[Z:FS
YJZ_[jFMWIfLViJ<PWn1PhJ8QGiiNgikLVmcO8B6QhN5QXN4OWQdLFm^Kg9cL6aY
JFYZJFMYKG5`KgEiNWf0PX>1O7UlOGemO7QcKFe_KVaYI6EXIV1KFV1SHV9MFEeP
Ig5jR9:DSX^CV9F?RXZ7MV1CDUYNEDHn@DiCDEEPJV]VIFYbN79[JVe]KF]XJ75m
Q8^BShAmOhVGWIJ:OgUkP7ifJfE]Oh^?SHb@Vj>QW9bPWi^IVYfRXj>TYZFUZ;:o
cMCAblC1_KNc];Vn_KNa/kZl_;jn_;Rf]k>/Z:JWYj>KUHn?THn>T9FIWIfKVYZI
WJ>QV96<R8V<SHZ2Oh20PH:0OGUcLgMlP7mlN7QhLg1dLfa[KVi_LW5ZI6I/K6MT
IVEOH6EXJ6MYJFIVJV]ZL7IeMWZ1Rh^6QXZDVIF>R8V;QGajO7aaGEAMIVILDTmC
FV5PHFY]I5MDG6AUGeUKHV=OGV5/NXB5OgUhN7QkNWIaKFe_KW1iPhF3Q8V>THf8
RHf;Q7ioPhF3O7MmQXV9RXjDWJ:QX9jOX9jIVIjMV9NHUHn<TiVIV9>AVJJ][JVQ
WInKUiNBR8>5RHIoOX:7RH^:RXZ9Q7mkNW]hLfm/Jfe/JVmgNW]mOh23QXF0O7f0
OWanOgelOGn0O7]nOgn3PWaiO7]fLW9`K6QTHV9SIF5OH61WLGQlOWQgNGIfNGUk
QI2CTY2<S8j9PX::SH^0L6Y[IeiABdmBE5=AEEiMEE9BF6EYHemRJW5bKfmbMgem
OhV@T9>GVj:YXiF9QHV@T8UoNh65Ph:6RhnASXb=TiNDRh5lO866QhR=TIFIWjBW
Zjf^/KBf]kZo`/C3_kZj_Knn^[Ng^[^f/:^Z[JfYYZRZYj:KThj;RH^@UIF@R8F8
T9B@RhN6QhJ2OgmnP8B1NWIfMW1^LWIiNgUcIf9/NWahNGf1PhF7QXB5PgemPX>0
P8:4PWUaLGEcKF]WIg5dLG9aLg=_MWn8TY68PhB9RHJ0NWQiOGeeIeiQI6EQFeUL
HVETIFMUGUQJHf]WGUQLIV]ZHU]SLWenNGQkNgE_JFQ]LWAfNGj2P8B<Shn@TY>E
UHn9R8Z;RhR2OgejNG]kNh:;T8n;RHR=U9B?RXbCVYfNXjN[[k2/Zjfa/kNk]JVP
VIB@SHV5QH^BSHV;SI>FUIB?QhF4OgelO7]iMg9]KgEkP81lNW]kN7=`KVmcLVe]
L75aM7EeN7UiNgmoNgEcM7MgLViXI6EYJ69KF5UMH5eKGFAXJg1`KVm`Kfe`LgEi
O868SHf9QX63PGQeNh:4MfEJEeaOG5QIHVYYIFM/LG9^J6Q_NGahMWb1O7=^KW1e
P8^CVYbKVifLW9fJU92BU9FETi:FVibLVijRYJFRWj6TXYbDSXjEWZ>SY:R]/kNg
]kVm`LC7a/70a/g>c<_9`k^f][Jf^;Ze[ZZXYjRYZJFKTXn>SH^;RhR7QX5kNGUj
NGIcKfYZKFm`LG9aL79dLg9cMgMeM7AdN7UiN7EeNH24P7M^JFYYI5YBDUUOGUQD
DeIJFUIFFUmOFEMLI6a^JfUZJFY^MGUmPX>9UIjLThf<SiBFT8EoOX1oMF]ZKVeV
GeiSJFicLVi[IUQ9Ae5LHF9TK79aK6IUKgUkN7UmQ8J4Ph>4R89hMGQjO7ejM7Ak
Og]cL7AlP7moOWamPH>1PH>4PhB8RXbBUiVNYZZ[[:fc^[Zf/k:a/;2a/kBd/JfY
XYbHUIJMXZ6KThV3PH1oOG]gLg9eMgMiNGYoPh5nO7]mOWenOWaiMgMhNh:9T9JD
S8F1OGQgN7E`LFiWI6EYJFIWJ6EQHFAVI69TIFEYKF]WJ6QYJVY]L7IjO7eoPhN9
RXjCU9JJWIN=QGn0QXJ4OGIjQXYoLFYXHUmQHF9UJFecN7QdKF]_NH>6QXF5Pgik
OX>9S8b<S8jEW9bHUiVLVI>ATiRLVYVDT96DUYJDTHn<RHF3PXB6RiBLWYfKVYnT
Y:BRXZN[ZjRSXjFVZJZXZJf`[ZZWYZRXXIfPXinJThn>TYJARHF5QXV7Qh^<S8jC
UI6>S8Z6P7]fMGR1QH>0PXF1O7]kN7QiNWn3PGajN7MhNGUgM79eMgYkNgagKV]/
KFi`MGMdMGYhM7AgNWj0P7eiNGajMgMfLGV5RXF4QHF;TI>CT8IlNWaoPhAoLfm_
KFi/JFMVIfMOFUYLGEYEDU9>BTQ4?Si4BDYBGVM^LG=fMgQiNgQdN865Q81hN7f4
QhJ1PHB8SXb6PGYdM7IiNgenOX24QHB9TYVNX9nPY:JUY:R/[jfYZJZ[[:^ZYj>R
XIjNWj>VXYjLVI:>TYJGTXf;RHN6R8N3PHJ>RXAoMWAhNWYjMg5aN7YiNGYgMWYk
NGI`KFi]Kg=aK6MTHfEVIFETIFQ/Kg1ZIfQZK6Y^KFIQIV]XIfERIVY]LW=bMWYm
Q8V:RHAmOH1oOXF<Rh9kNh>9QX=mLW1aM7eoNg]mOGn0O7YiMGN3PXB<RHV?Shb9
QY2KX::OXJFYYIbLV9JKV92DWZB[Yj:QXYnKUiJCTIFESXR7QhR7SINMX::JTiVN
YJNVZ:Z][J^^/[Vl/Zje][Nk`L:cX:6_Z9fBX;BXYHF4UHIcFT6:f9eJQZJFSUaE
JVAUKe]GI7AMD6YaKGMfIGB;VgeFL7=/HfmiLfeOJF]LBUmkK59:EGZ0HUYPIFM/
IEEKHfELCEIVKGabHf]oS8b6Mg:0VhihQINOSGYoRHf1I6aiLgj;NfE`L6aUFF1R
FUU/IUYSJFEWHEI>FFU/FEf5Qf]oUGQkS8^0P8inKXB9OWb3Mh27LhN>PH:<OG^5
PWe_FV61U8f?OfeoQgalR8nIZjJLTYRe/HZH^Zj_[j^b_lBdZjj^YJnTXJJOU8nT
Y9UlKX67SHJ5TIBAN7>AUWIcNWj3O75gQIR=OI2<OHEoQXAlQXIoM7UhNX>3OGn9
SHbFQ7b=RGiXIFiiIUM`IFJ3QgYjMG:2QGQ]IfUnP6UXOGEXK7fMWgMZTjJ9Ni6Y
Z8n=[k:MYJJBOX>9TiQeMXN=PhVARhejNXZBW8YULY^CMFUfRYbIPWJ@VX9SJ8BC
SXfDRiBMW8J3WIN1L79gQY1bG6f3MFY/LgEkQG5hOX:9NWEYIWanNWn7RY6JU8R0
Q8RBYIZ6WiZ7[:V@Pi>VTX]oPHJ:RW20TXMfNXIlLfiPF5ibL6mdLGZ3RWaiPHIj
N9jZUX25P8Z;Mh25NFY/T:2=QI^OPH67QWelOX^9TWiYPhmeJh29KEQmVG]_Ng5k
Sg]QP9j:MhV<NGV9P6YlWZ^LT8^?YJ6<O863LWR=ODmCPXUfL8QnCDmdMFQUHeeN
LW9[M6QJIFYdPhF5OfifJVAkSXA_JWB<QHAmIfMdLVMSGUEUQH9RHgehEVF4Pgmj
QHQnOGUgNX5gMWN2UjFSQY6aZinKVZFY]lWDeKbRWjnRQHJMW9b_/:BIRhZ8TIV;
O824OX=kLG^8QF]_PX5hLWF?U92@NV9VLFMhU95jOXJ?TWmUGVZ2OE95IHEfGEYW
RhidLg5`HfZ1NVmQHFaZI7]jHf5LG6f6QFmXKhjE[:ZVX:>iXXMlX:F2PX64WiY/
HX23ShafHfB0OVaTHFAZJGf4L6f1R79bM7=eJFYeSInORgZ7UYjIPW26Ui^NQGJ:
TgiaMXJ4N7N2W:>VW8MjKgJ3UGa`PhjTX85dQHnGU8j9TY:7TJjdYZbZZ:ZSUY>R
[;S2Yi^SZ9f6O8B8NGj4N6EaQX63OGJ3SH5lRXnDVI^HSY:MUXZ3MWIoOhj9NX>:
QHJ7O8B>MVQbNH=kMXn@P7UjPWIYLV]UDeMfNVYQPYIoI7>@RFiSN8MiK8>>THf=
Ui:5Sib?Jf^;QGYeHFb5Qh9hHEacLg9cHeIBGEm;?E5VM6UMKg9oSGa^NI2GP7J0
RhQaP8ieLWAiLGQjJfI]O8EoLgEoPhNDThB4TI60N7b7RHnFXj2BY:6ASIjBPH^;
XkN]Z[:e`m?DbZ^JZ;Vo/jn^WYfET:B]Y9>4RiVLVYF<Mg^EV8ijHV1XM7APHFf7
R7mkJ6QGIXIeN8EjMGacGEYMFe90?DiKIVaSGG=dLWf0OWMoRX5PIW]dGUMNJVeS
FUA[O6]_NWalUj^KW:N]VX^FYIQlL8>6Ngb7V91gIgb>RgalPGahJV1]MFmTJgZ7
QHZ?RhF9THf:SiZ7OX26VI^8PhfATiB5MVilRX=hKWAlNW]iLH6<TYRKRH64NWf6
QH^FU8^9PhB7PGIbOWmfMi:^Zj:Y/:ZGTj://[NcXYRFUYjOThZ5PhAiN8F6Ngn;
R8jDTI6@RHVCT861Rhn:QGidK7B8QHR2K7V;ShfBRgUkPH9hKWJ1PX^?TYjNQh:H
T8Z4MGMgQ8YoKgV7RGaXJ6U[K6Y]Mh5iMXJISWIcMgalPh=aKgQ]HGB=R7=UK7Mc
Mh1mIEaQH5mSHf=[IVUlNG^5R89oQ8F1M7MoJEi[LFYED5MGGfMOGFEHDFaoOgU`
MWmlRYZ:KfE_M71/KWEfNh67RX^6S9ZDOfamV9bHUZ:b_l2WVi^TZj:JVIfFSIZ[
Wi2JZ:^LXK:XV8bAUiJ<PX>4QGe^N8F6RXf6LG61OG=bMGMdLf]QHf5SKViZG5EE
FemLHW:7Sh^;SGmbNgahMGaaIGB8SXV1N7Z0NWJ5R7]mQhbKZZ^Y[:n`YYnVX7mm
TiF8PgaXIGV9NVmmRXYnQXQfMh1oO7^3RiB;M8:MXYFAS7EhQXV=THn8SIRJU9NR
YI:9PGV6T7aIEfagKfM/K6]]PI65O867SI:<SXZ8QH>2OgamUin?SIFNVIb_`Kjb
/k^iZZ6`[Z6HTYjLTHZ>RHFAUi61NWmiL75kRHf3NWEmP7]mQX>2THmoMgb4S9JC
RHZDWYnPWY25RXj5P7Q]IfifNH28Rhn9MGAhKfIQHF5RHfn1PgehRj2PThEoQ92;
OWYkPH9`IVMXJ5aKKWUYGF1QF5ELHU]?Ce=KHV1;?dmJEUUOFEidNg9gS964Qhf0
NGQnR8n8NGB1TXb9SXE_JgE^FU]SJ6YTI6Q]NHElMWAeOWYaKWZ:Thj9UYnESIBM
XZ>RY:FNVJ6Y[Zf]_LW5`Kfd];Vl]Jf`^K>TWjN`/;fo/ZbWWY^KTY:?RHMhKfaT
J7=dKFM/LWEfM71bMWIiOX5fK6AIEeYQEdm<?ce4DEmWJFeaKfETJF]]KVENI6ec
LfaSIgR4PW5ZJfM^Oh^<Shn>S8R7SibDRH61R85eKVa^L79/J6M^OhJ4PWf0PWij
MViVK7]nNGV2Q7YlPHF:Shn4QI2EX;2_Y:>U[jfLTXf=R85nNGYkPH=nOh><U9^H
RH>;WZfUShZHUhIlOhF2NWQiNGInSY::RI6N/[BOU::^[jj^ZJ6SVhQnS9jITY27
OGYdJFiiOH6:QG1YLW^4S8V0QhQoNVYTMXF3PHnOWYNIX:BTXZBFO79eP8MoPYFT
Y961PH>:T8]nMWQhMgEgLVecNhB6NF]_MWZ1QH5iLgIkP8N7Q7ejMg^4PGEUIVmc
I4mDHFeeMVeRGfI^IfI/K6YdQHMoQHjGW9bIUiZAOgV0SIBGSgYdOHJ6O6MIEUaW
JVEMIW^8QhF<ShQkMW^1OginP7ifN864OH2<Ui65OhFGXjJIRX^MZjZTUI6LYZfb
[jRUZjNBQi>X/:JMXZJWVHZ>U969O7AdN75ZJ6=WJ6QbMgQ[FUENK6Y[KfiNCdiD
G5eDB4A6B5=OHemLJ7AeJeMFHFa_K6aSGfQYJ6QUJ6eeO7UhO8B8P7UoSIVITi:I
Z:fZXJ:YYIb<O7YnPh9gKfegQI6GUYRPXYb9OX>3PGidMWn4PH>;T9:CTHR0Qi2K
YZRTZ[>j`;>QVJ:[Wi69RHf>SXnASi:GU8b:Ri>GV9NATIFCShj:QXF4OgZ0Pgmh
MgYmQHb;SI>CTIBLWYZERh1lNGMnQhjDT8^:SXj5MWInNgI^IVYdNWQbKWN6RhJ2
OG=]LWf3Q8RAUYBDUIRNWIbERX:3P7QgOXF<RgidKgAfMWQgNX:5Ph=lMgj7RhR:
RhElNg]kOXB7QGigNWemNg]lOHJ?QgE`LgIgL6]/Kfi]KV]UJW5[HEeSKWEfLVmb
Ngj2PhJ;S8f?S8B3QXR6QHjIWIV@QGemOWYfMWEbKFmdMWQlOgmhMG]mNWMjOX:6
Rhf4PHR@Thj;TYRFT8EnP8fMY9nFUIn_]k2[[[Fg/J:MXZRXZJZUXj:LV9NDSXEo
LfIUIV1NHFAWKW=fLVi/K6eaKfi`LFmYIFM[J5]ABdYBEd]3C5YRJ6QOF5aSIFAN
FEQMH5aJEEAMIFIQI6edL6QXL7=_LWV2QXN:SI2FVZ2TWXf3QHV6Ph5oPHN;SY6?
RhnBShf9P7A`L6m_LGEgNXB<UYbES8^AUYZGTIFR/[B`ZJ2OZ[:d/Z^LVInKT8bD
VY^HTHjBVIRJWibEU9N>Q8>4PWmiMW9hNgEaLG=hPXZ<SHnDV9jVZZ:HUiRBRXR6
OWEcMG^1O75cNH27R7Y^KWMkMVe/L7^8RhEmMgQjMW5bNXJ?UYRDThn<SiJDSX^5
Oh25RHV6OGMiPHB2P8:7RXZ8PX1kMg^2QXF1OX21Ogn0OWelOhJ?T89cNXbJXIf>
PX64Q8AoMW=hOh1hL6]`NWYhNh64PWn0OgaoQhZ:QhF7RHN7Rhb4NW5bNhR@T8b5
R8j?S8^8OgQkPHB5PGanPhJ5QHEnLW5mRH^2M75fPHJ9S8f@U9B>OgMjR9>DShR8
S8n;S9FMWj2QWibKUiBCUIFDU8n7QHV@U9>:PGemNgEaKfmaL6i]Ie]IGUmJEeMD
FV1PGF9TG55@E5UKEdm<DUaLEe5<B4mFFEYKGV=^LfYMG5mMFUmXLWMjP8=oO7]n
QI2CTY:CShnGW9^JVI:>T9>@S8R:UIfIU9BHVYfRYZVXX9J=R8R>T8Z3Ph>7SY2B
UiZNXZFSWYjSZZbXXZ:[/:^VZk2/XYNATi^OX:6OVYRHUYRNWinLV9>?Shj;Rh^;
R8N3OGE_M829SY2@SXf<RXR?ViV>RHf>S8=iM7R0QXAlLFa]LGIeK6AOFeUIFUeS
KG=`K6idMgE_KgN0QHbFVYBBV9fOX9jLViN=R8J2OGYeKVa_KV]ZIfAWJfa`MgIe
Lg=dNX20Q8B4OgimLfe_MWb2PX23RY2CUYF=QXN6P7]gMgQhLVe/KVi[JVY[K6e]
JfETJVm`KFa[J6Q[LGIiNWj4Ph24RXZ:Si>EUI>@TIJGUI::PX20O7YmPhJ5OGEe
NWf0PX1kNgYhNH66R92GVIRFShfBUI2<TYNGUiJDUIfTZ:V//;6]ZZ^`[ZNOV9BB
T8V6QH=oO7QaK6e/J6MXIVMXJVi_LWEkPH1mMG=fNGAYHUmRIFAMF5aOH69TI6I[
KFQPFUMJG5YKHF9KF5YHFF5]LW=bKfi`LW9gO7UaJfefOhR?TYBCT96DU9>AShn?
Shn>S8f?TYJMXif?RH^AUIJ>PWQfO81oO7b0QHZ?TYFIWJ:SXInOX:2T[;Be/Zn]
ZjRUXj:UZ:VYZjNTYJNUXIjHT8j=RXR7PG]kOWeiMgA_KVi[KWR0PhN?UYVIV9RH
U8n<Q823SY>?QgefMGEgNgagMW]oNgE`JVITJ6e`KFERH5aKGVE[LWUlOWn0QY:J
VYNDT8f=SHf?S8B3R8^=SX^2OGemOXB4OWQiOX>6PGIaMG]jNGQhNGf0Og]eL79n
S9FFT8b<RXN5Q8N=TiBDThb4OgejNGYkNGb2QHF3P7akOh5mMVa[LGUkMg=`L7Aj
Oh60NgUhNX2<UY^OXJ>UXIJ9QXbAU9>:PGmoO7^3QWmhNh>:SHf?UINEU9FBRH:0
PH5nOX:8S96FVYnUZ:>LVIVNYZf]ZZ:FS8R:RXV6Q8N=TY2<QWacL71`L6eYI6=U
IfMSGEeSJVeZIF9PH6AZKFMNFUYKG5YHF5]LG69VGe]MHfERG5A?DUIJGF5UJFmc
MgYlOGemO7YeKf]/KgEoQhV7PgikNGUiOHF<TIJFTHjCW:BWYInLWj2KUI2;QX>2
PH>5QHF:TiZLWIfLVinQWYRDShb=TiNJWj>RXJ6OWInRXZ6SXj6NViVGUiJFV9VI
UiFDTI2?TI>?QWacJfU]KVa/L7EnQhZ:Rhn>R8F1O7f2RXj?S8R7QGifMGYoQ8V?
TXn3MF]XJVe`K6=JEUQJGfUcMgAcM7MnQhb<RhJ0Oh20Oh:0MfiZJFMZL7QnP862
QXJ3PXF9Rh^7PH20O7IcMGQjN7EeN7QkOh>5S9BDShZ5P7eiMGZ8TI:ATHn<RXAj
MWUmP8>5PWinOgijMg=bMGYkNWUjN7=`L6maN827SHj:QH9oOXJCWInJTXnBUHj2
OX25QhV<S8Z8QhJ1OGf3RY6FV9VJVYVIUXj9RX^;Rhf=SI:KY[>k^[Zm_;Zj_Kfj
^KJbZYnDSHR5Q8N<S8b?T8b6PX:1Og]iMW=]IV5RJF]WHUmNGfAXIfAQGemOG5UK
Gf1OG5MCCe1EFf1SHeiIEU=@CeAMIW1fLfaYJ6U]L6iZJ6U[LGUnOWajN7QiNGYn
OgelP8F5PX62QX^=RHB3QXV8QH1oPhJ4PGehM7AjOgimPHN;Rhf?T8n>Si:DTXn;
Rhb?UIZJVIfV/KFbZYnJVifMVINFUYJDShb<RXR6QXF7RHR4PGijNW]jNh6:SXf=
T9NNX9bFTXj;Ri2CTYBKX9jHTHf9Ph:5RHf?SX^8QhB4Ph60Ph9lMGAeMWYnNW9Z
J6efOXB7RHV8R8J4PGinP85nNWMcLGElP861OW]mOW]gMGMmQXR2OGakNgn0OGQg
NWn5RXnCU9:@TYBCTY6ATI:FVIRCShf>SX^9R8Z<RhV:RHN7RHMoN79_LGMjNGE_
J69PHV=TIFM[LGQoPX>2Q8Z<RXV>TiNFTH^3NWAgO7aiNG]kN7EeNG]iN7^0PhJ6
Ph21PX1kMgEhP8F7R8^?UIVKW9nU[;2b[jj^[Zn`[:FNVYB>SY6DV9VCSXnBTXj9
Q85oNg5VHfIXJFYXI5mIEEIKH6AVI5iFDe=CDeEIFUUHE4i=De]NGEM@CDm>BTQ=
F6I_LFm^KFeaMgUhLfm]KWElPH>0NgMdM7IkPHF6R8fATY6BUYNDTY>CTI2?S8Z<
SXn<PgahN7IbM7UlNWYkO824QXF2PhN=Shj?U9RKViVFUi^QYJRZZjf`/[6/YZ:Q
XjNXYJ6MUi2=SY2@S8F0OX20OGUfMGQjNGQiOXB7S96BT92BTY:EWJ6QXJBWYjBR
WijOWYZET8^<T9>BSXZ3O7MaKFa`M7MgM71]KW5fNgn2QHR:RHR9RX=jM7=gOH1n
NganOgmmOH65PgehN7QjOX1mMFm^L71/IfIWIVAWKGElPXF7QhJ5PGakPhZ?TY:A
Sh^5OWemO7n3Q85mOX1oOGUfMGAcLW5cMgQdK6APHFEVI6AYLGUmOX23QhN1NgUj
O825RHR7QXAoNgQgMG9eOH60NgMfMgb1PGegM7MkOGamPHR=Shn@T9BHWJ2RYJR[
/[Vm_Kjn^kNf]kJb[JNSXj>OVI>@TYROXJ2QYJJQUXn=SHf?T8^3OW]hMWMiNgYg
MgYoOWYeLFa[KW5`JVASIfYYIfIQEde6@dE:D5MOIVUVHf=TJ6eaKf]WIf]`N7Yg
MWQkNgUhMWV2Rhb8PgmnOgikO7eoPXB6Qhb@THj;RXIoMg1`MGYoPH5oP8B6QHB1
Oh25Ri6GVIVIUi69QHF8SiNNXZJXZJNRWIN@RXR9RhV3OGQgNWioOWakOH20OWen
P7mkMgMkP8J9R8B4R8V9S9:GV9JDUIVLW9VDT96GW9^AQh>4QhV:S8Z7QXB1Ogaj
N7UiN7MeLg9dMgUjNWYmQXnDTXf8QhfATHf:R8V9Qh5nOGagLFi^L7=eMgQkOgif
K6MZKFeWHF9UJ6]`MGQnQXR4OGUjOhF;TI:?S8V7Q8B5R8V:Rhf?TI>DU9:>Qgie
LG1dMgQdL6eYIF=RI6Q]LG=fOHF9Rhf?ShV3OW]iO8::S8ElN7UhM6eYJW9iNW=[
J6eeO7ijMgEcMWj7S8j>S8R6Qh^>T92?T96CU9NMYJb^[:ZZZjb/ZjRUXj2NW9RF
V9^JV9VJVIRIVijMUi2:QXF5QGmgLgIkOGioP865R8N2NWIfNG]hM75/JFY_LFaU
H5aIF5MGF5aPI6]aM75/K79iNG9YI6=TIFIWIVIVIVIVIf]bNH69Shn;QhF5QhR8
QX>4RXj=SI6GVIN?PgYiOH62P7ejNgakNWf1PX5nOXB=TY6<R8J9RXV7QXV?UY^J
UYJJViJ=QhJ8Rh^6Og]nPXF6QXR7PWenPXJ5PWehLgAiOGajO8:5PW]iNgf0PhF6
QXR9Qh>2QhjBUYRHTXb8QhJ8S8n@S8N6RHb<R8F3PX:2P7j0QHV;RhR9SI:CTHn@
U9NHUiBAShj?TIBFThj9Q864RHf<RhZ8QhJ4PX60OgejMWAcMGMiNgn1PX:2PGij
MgMjOhJ;RH5kNWj1Ph60PXR>SX^9RHR6PWagMGMjO7YeLW5aJfIUJg1bL6i/Jfa`
Lg=cMgamNGEeMgA_KFmbMGIdKfUVIVMWJFeaLg=cMGQgLVe/KG=nQXV8RH^@U9JF
UIJKX:6NW9fQXIjLWJ:UYInGTiJKW9^JW9fKUiBEW:F//K>`[[6d/jfVXYjKV9F@
S8Z:S8j@TYBCShjAUYNET8V5PhB4PX:3QH9iKVIUJVm`Kfe]KFa[JVa_LG5aL6m^
KW1_JfY]LG5_KW1`KFMTI6IZLWYiLF]/KFe[KG5fNGYkOH64QXAmNGUlOGamOgij
M6m[J6MYK6i^LGAeM75_LGEkPHJ8Rhf<S8nGWInJU8j;RXZ9QH5oOgmlNGYnPH1m
OGelOGmoOGanP7mlN7IfMgQhMW=aL75aL75fNWYgMG9bMgf2Q8F5QXF1PHF;SHV3
OWf1QhZ9QhJ6QXJ8Rhb8Q8:4R8^<S8Z<TINHUIBKXjFQW9VHVIfNVY:<RHZ:QhJ9
SY2=QWiiNh65Q8:2PWiiLg9eNGn4QH>3Q8B3PhF:SXn?SHb>TiNHVIbNWifMWZ2O
ViB=QGilO7ajNGQeKFALFEUKGUmPHVMZK6UTHfIZKG1dO8>7QhF1P861Og]jNgj0
OW]hMgYoPh=nNWYiN7IfMgUhMGAfNWn3QXJ4Q8B5QhV:RXV9RXb?TiJGUibPX9^G
V9fPWIVHVinPWi^EU9VNWifJVYbNWIRBSHb?THn;RXb<R8B2Q8N;SH^6PhB5QH9n
O7b1Q89mN7=_Kg5dN7enO7UfLfm_LG9cM7EcLFm_K6AJEUQOIVYZJVY^M7]kN7Ig
O7ioOh66RXV5PH24R8Z7QHN9Qh=oNWIgNgekMW5^JVEPH6QdOWigK6ASJG=kPXR=
T9BIWIjMW9^HUYJHVYbPY:JQVIFFVI^KVYVIVY^HShAmNGUhMWEdLg9aL71_LG9^
JFEUIfQXJ6U]LgQjNGQlPXR9QH5oPHB6PgmlO7j2QX^=RhV7QhF2P820OgaiMg9]
JV]/K6meOXN>U9NGUYFGVIbMWIbJUiBEVI^LVi^IUiFCSX^=T92=RHJ5QXV:Qh1k
O8:7QhB5RiBLWIJ<QHB8SiJKWinMViZIUYFEUI>BU9JCT92AShV1NgEaKF]YJF]/
KVaVGe]KGEmTJFibMW]oPH>4PGU`KFmdN7QeLG5dN7UhMgUlO7QaK6]_Lg=^K6ib
MWYnOgmoOWn2Q8J:SHR1OGinOGj0PhJ9RHN5PhB8S8j=SY2ATI6BTHj<S8f@U9RJ
VIJBRhJ2PHJ;S8R5PGmnPXN:S8nAU9BBShf>T96BT8f:RHR8R8R7PgehMWIiO7ei
M7IlP861PhF5PGUbJfIUJVmbMWaoP861Og]hN7YnPXF6Q81lNgalNg]lOh>8S8j>
S8Z7Ph20OW]gKfQUIVY`M7MhMgEaKg=gO865QhV<T9>BS8J5RHb<SHnBTi>ASX^7
QXN5PGn0PhF6Q8:2P7elOGemO7MaKFmcMWIdLVm]JfYYJVabNGn1OgaiMgEfNGal
OGenOh60OWalO7amO7YjO7n3Ph1kO7n0OGUgM6mZIVEZLgj8SY6CUiZKVIRGV9RI
VIRGV9VIUY:ATI6DUIBBT8n@TY:@T9:CTXn9Ph20PXF8S92DV9^JU8f=U9jVZjj]
[:b/[:ZUXInMV9FFUiNCSHN2Og]eL6]XJ6]]K6QUIVU[JF1HEEYRJ6]^L75aLgAb
L6i^KVi[J6U]LWQmO7MaK6UYJfe^Kfm`LFi/KG9hNg]iLfi^M7f5R8V9R8=mNgf2
R8^;S8nAT8n<RhjDUI2<RXfDVY^ESHV9SI2AT92?Shn=QWmnPXN8Q7mjMgIiOX62
PX1mOGj1PhF6QhJ3PH:5RHjEVYVETXf8Q8:2QHJ5PhF9RhZ7Ph20P7ehLVmbNGn2
PGejNgajMG=fOhV?Shf9Q861Q8B3Q8>4QXR:SY6BTY6>R8=oNWYmPHB5QXJ4PX1m
NG=_KVm_L7AlQ8^@TI2;Q866SI6BTHn?U9VITh^6RY:GV9RGUiRKVY>=RhZ8QH9o
OGamOWilNgamOWeiMWEdLg=gO7imNG=^KFmbMWYoPXF8Rhj>S8^:R8J6R8V7QhN4
OGEaM7IeL6QQGEmVK6e^KgImPX60PHB6QhB0P8F<TiJGUiFARXJ5QHJ7QX>1PXJ:
S8Z7R8R6PGUbLGR1Qh^;RHJ3Ph:1P8:7SY:FVijNW9^KViVFUIJIWJ2OViJASXZ7
QHJ8RXZ5PGilNgUcK6UVHV1PHVEXK6mdNGeoP7ifKVYYK6maLgMlOW]bJVMXJfia
LG5`LW=eMWMhNg]hMWUnPXF8R8J3P7ajNgeoPH1nPHN;S8Z7QXF5QXR;SXn>SHnA
T8f9QhR<TI6>RHJ3Ph>2Ogn1Ph>0NWEeN7YkNGUkPXN9RXb:QH5oOG]kP8J;S8Z8
QH5lN7MhNGQfMWMgMgMgMWIgN7UkOGioOginOWmnO7UjOGinOh:8SY:CTHb8QHR=
T8j;RhjATi>CU9JDT8f9QhJ6QXN8R8N5PgmoPhR7PWakOH>9SHn@Shj=RHB0PHJ9
RXb=RhV8RH^<S8Z:S8f=SHb9QhR8QH:0OgakNgalNWUkOGagLW9cLg1/J6U/L7=b
L6eZJFY^LWEgMW=bMh28R81gMGQkO7enPHJ:RhR3OginOGQaJfMUJFmdMgUjOX:4
Q8>0Oh21PX>5QhN7QXN7QH5nP8F7QhR7QH5nO7aoPH5oOWemNg]lPHR?UIJDTI>J
X:2MWJB]/JnZYZN[/K>`[:NUYZFTXZ6NVIFCTY6CUYRHUY:>RXJ3PH:2PGmlNgUh
NGYjNG]oPX>3P7YfMGIiP8J8QXJ6QH5lMW9aLgIfLfi]LWEcKfi`LW=cMGUmPXB1
NWAaLWAdLW=gO7ioOgn2QXR9R8J6QXN8R8R9S92@S8N5QXV;RHV9RX^:R8AoOG]j
N7MdKfa[KG1aLG9fNWf1Ph5oPHJ9R8V;T9FFTH^4O7EbMGQjNgYfL6a[K6a[J6EV
Jg9fMgA`L79eNGf2QXZ?U9BASXb9QH61QHZ?T8n;R8F4PhF9T9JJViVCRXB2PhN:
RhX\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]],

Cell["\<\
Click on the sound plot above to hear the speech signal.\
\>", \
"Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sample images", "Subsection"],

Cell[CellGroupData[{

Cell["Gray-scale image", "Subsubsection"],

Cell["\<\
Adjust the directory setting and input file below to your system \
configuration.\
\>", "Text"],

Cell[BoxData[{
    \(\(dir = "\</Users/nechyba/public_html/eel3135/data\>";\)\), "\
\[IndentingNewLine]", 
    \(\(file = "\<sample_bw.jpg\>";\)\)}], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetDirectory[dir];\)\), "\[IndentingNewLine]", 
    \(\(im1 = Import[file];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[im1];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.15948 
%%ImageSize: 232 269 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00410509 0.0276067 0.00410509 [
[ 0 0 0 0 ]
[ 1 1.15948 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.15948 L
0 1.15948 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02761 translate
.95238 1.10427 scale
232 string
232 269 8 [232 0 0 269 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000000000
010000000000010001000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000000000000000000000000000000000000000010001000000000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000100000000000000000000000000000000000000000000
000001000000000000000000000000000000000000000001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000000000000000000000000000010000000000
000000000000000000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
000001000100000000000001010001010102030507080B0C0C0C0C0B0B0B0B0C0B0B0B0B
080402010100010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
00000001000001010205090F141E2A3743525C686F747777767773727676767D817F7C76
6B6655442C1A0E0B05030100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000001
010101030C172943586A757E8C9CA0A3B0B7C2C4C3BBBAB7B6B6B5B4BEBAB5BBC4BFBAB5
B4B7B6AA9B8C76735F4C341D0E0402010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000203
0D1B355C7EA4B6BBC5C9C0BBBCC1BDC2D0CACDCAC3C5C3BEBFBAB5C5C3BBB9B9B6B5B6AB
A9B1B7B4A69A9EAFB1A6A29775453927190B020100000100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001000000000208173256
7D9CA7B6BAC1C2C7D5E2E4E5E5E0D0C4C2C5CDD8CCC6BCB5B6B6B2BEB5B8B8B7B6BECFB5
ACAFAEB39EA8B1A8ABBAB5ABA292959CA27E4F240D040100020000000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000100000000000101030D23466B8C9EA7
ACAEB7C0C4D2DAE5EFF9F9F7F2E4D5C3B7B8BCC0C3B8B2ADADACAAB3A7B1ADADABB1B2A6
9EA09E9D96A0AAA6A9B4ACA3A3A6A1A1ABB5B48D65503011050100000100000001000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000001010000000000000001030E2A588EB3BBB3ACA9AA
B0B4BCC3CBD4DCE1E7E1D5C6BDB6B5B1ACADAAA9A9A8A6A6A9ACA6A5A4ADA3A7ACAFAF9D
9A9C9F9B999A9D9BA4BBA2999BA1A1959EA6AAA2939B95714D2910040100000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000100030B245793BEC3C2BEB5B0ADABA7
A8AAB1AAA0A2A3A4A39DA1A2A0A7ACB8BDAFADAAA4A4A7B2B3B4ABA4A6B0A6A0A6A7A397
A3A2A4ACA19592949AA4988C928884707E8A908A899598949087734C230A020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000000000000104194A87AEC5C7B2A39F9FA1A1A19C95
96A09F97959697938F8F98A2A4ABA8B3B0ADB9ADA6A1A5B4A3A5A2A89FA59B9A9C9E9893
A5A8B0B3AB988F919383707076725F5F67727F777881858B8D8D968E725F321104010000
000000010000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010001000001092A6CB3DCD2B9A99B908E8F909094928E8F
929C9C98959699908991A1A8A69B90A296909AA6999196ACA2969BAA9FA1A09F9992939A
A19DA1A1949A9187867A6C6B717271686360676967646C747F88838680898C7540150501
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000020C387EBDD9D0BBA79B8D8885888B8C888A8A898A
8B8F939088889199908D99A8A5958B8E7F79819EA9959EAFB3A7A6A6A399938C90919798
898F92A1909288807F7A706D6A6C6E6A656164666361656A75797C878A867F8C81604220
090101000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000210408DCED2BEB79E97918B8683808283858383828082
807F82858385949FA196899CB1B79C817A7E87A4A190AAAAB1A8A1A49C93838086868F92
9195919894938D847D78726F6A5F5E6166605B5C5E626C76776E787B7779727B8282786A
44220A010000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010002124796D2E2D1C3A69192938E8F8A86828280807C7C7C7A78
7371777D84878D99ABA2949CBDD5BA9E949298A39FA6A0959AA0A8B6A4A5A5939194928E
9FAE9D94898D99A69783897572645A57625E5655545A61676A6A6C716A5F5C6B6F786D67
676A4B1B0801000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000100000000020E45A0DDDED2CBB2A19392908B88878684817D7673727074746F
7777767E8795AAB0B0B4B6AFBBC3BDAFA99683899AA3998C898A9DB0A3B1BCB6A69D8F8C
ACC2A89A8B8B9BA59E80838472695E60686058514D4C535559616C736F706A6C6A6D596B
796C5F543913050100000100000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000001083692E0F9ECC8BFAF96908F9494867F7D7D8185827974706E75737F
9DACA4A9B8B9C4C0A7B3CAC0C0BFB6ACAF8E7180918B7C7C8592887A7895ACB4A49B969A
A4AAAAA8A498A0A2A5A1908B766E69696E6957524C4746454850555F636B6150676A6073
6F5A61605048290C03000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00010000000001176BCFF7F7E7C1A59E9B90908E9698827D7F83868B857A7370757E92B9
C3C6CACACCBFCAD0C1BCCBC7B1AAADACAE97857671776D78918879797B929390908FA2A7
A2A2AFB0ABA6A9B3ABA8A0917F7B7A787367554D4D4C494543464C4E58594C546B7A6C6B
7A62595C5A5B433C280B0100000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000001093791E0F8E8D1C0B39F9592928F8F968F7F7F8583807974757782A1ACB8CA
C6C0C7D4CFC6CBC8C6BFC6B8958392B0AFBFB99D8081767B81849BAB9288918DA3A2AEA4
9A989799A2A9A5A5A09DA5957E8184887967565152544B464240434548504E647276715C
63524866565F514640260E02000001000000000100000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000031E69BAEAFAEFCBBCB6AC9894908E878E91858080837B7775777A91B3C8CFD3D7
D1C7C4D0C9CAC9C5BBB4A3999DA0A4ADB0AFABA3A4988385909499A687859F9EA89BA59E
96969C9D9091959993909588808882817C6C5D6A5D4F4A474745423F40454D626C675152
51524C605353554D3417151C0E0100010000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
01010E4798D8F4F8ECD5C3BD9D9195948D888D928D868181807E7D7C7E94C1D5D9D6CECD
C9C5C5C7BDC1C8C6C4BAB0AAA3A5ACB6B1ADAAA7B8AEA7ADB3B1A290939CA6A6A69C9D9D
9C97A79D888F9188807E8F8B7F6E61676E6A6F6F645A5C565A574A41444D505F6B5D6366
645C49514F524C4F3B251929230602010000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
041E6CBAE3F7F3DECED3CBA38E8B8C88868E98938787898789888996ABC3D2D8DDD7C8C9
C2BFC5C4BAB3C3BBBBB5B3AC9FA1A2B5AABBC0AEB0ADAFA4ACB0B8AEAEA3A59C96A19E98
9B9C9A929698948A7F6F878D7D5C5C5D5F5F6E6E5B5E625A615F595249535B6463545B59
47593339464E51593838302525191C0B0000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000001000108
398ECEF1F9EDE2D8C9C1AE9C8F9090868494A1A09B98938F979BA8C1D1D5D5DCD8CEC3BC
BBB2B4A4AAA2988B8B918E90A09998A6ACBDD3BFBEB2AC858293B4C0A9A4A99C95969792
919DAAA2A2A08E8E8874797D7E64635E605758726E5E5D585D5B61625557675A51525854
4D56433C454F583E434342322424281A0300000001010100000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000100000000010002165D
A9DCF7FAEEDEDDD8D8D2BFB1A0ADAC9F9298ACBAC3A89396A2B6C5D4DEDCDAD9D7C9BBA7
938B848082827E787677747171787F8D9BB0BBB7AEA0A7908D97B6BEB6B0B1ADAC9E9F9A
9198A1908788888C837A6B696F6A6F735E52546F78625C4E505B69685C5C68594F4F5562
4C48504841535E574F422C372119231D120A000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000100053089C3
E1F8F6E9E0D4D1C6BFBEB8ABB2BAB3A7A3B6BCBABFA89B9FB2CED9E2E8DBDCD6CBC0A389
7A777778757275737172736D6A666A718FB7ABA0A09391969F9BAFBDBFAEB3BC9F9FA699
8F88776F696B6F87877C665B5C5F6666636063706C595542455C796E6062666458504C59
5C43514E4755585A473D212E221C24211A1B130301000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010E50B2E1EA
F1EFE6E7E1CEC7AC9C9BA6A4ADABB0AEB3BCB0A79A9CA8C5DDE3E0E3E1D7CFCAB098847F
78777978747172736E696A676665676C879F90808A86918298A2AFB6BBB5B3AF9997948B
85786773767C757273766D5F584D4D505253534F4B4C4D4C4C576F74545F66625C524B55
56414C564C5B4B503834120A152126292016271D02010000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000032380CEEDF1ED
ECE5E6E5D6C6A19397929A9799A2AFA5A7A39B9499AFD0E7EDE5E0E4DAC7B4BBA2877D7D
7D7F7C78727072726F6A6A696667666A6B787572716E78768695A9B2AEB6B4AEA69F8C7C
6C74776E7A846A5C7275655B594F494D4E494540424244494B4C58554A455B6155554F4B
444043403D5050574248281E2033341F0D1221310E000100010000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000641B0E3ECF4EFEA
E5E8DECBA896868894948D898D969EA0A49D9BA6C0D7E6ECEFECE7DCC2ACA0A392807A79
7B7E7F787472716C6C68646563666262656D6E6967606177939AA3B0A9B3B5B2AFA38A76
6E80827D828D7C778071675C564E47494B46454343434043494445474B4C565D4D4B4E49
414144353144514E41452F25272F482C0B150C100D010100000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000001000C53C9EEEDF3F1EBE7
EBE4C2A1877E7F8C908A88878A9FA5A2A7ACA3ABC6D3E4F1EEF3E9D6B0A0938A827D7F74
767C7E767272726C6A656563615F5E63686C675E5F5C5E7C8CA19F9DA59EA8B8B296908D
868A81797C8F8E857E72706555544D484846484846474644453E3C3D4042484849474440
3F45413A37404D44424B2A232B2731290F20100C06020101000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000011372CFE4EEF2F0E7E2E7
DDAF9186827F82879091949DA3BFB1A3A8AEACB1BFCFECF1EDF5DEC5AB998D8582808276
74767571717272706E6B656260606166665F5C5F68615E759EA89E9E9E9297B6C0A29592
8C807E7E868B827F86746F604E50504D53534B4A5058524C49433C3B4141414346464944
444646464543503642572D2C2B1A1F170A0A080805040201000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000011A85D6D4D7EEF2F7F2EFE9
C692898C8685807E8BA0A1A2B5C39F8D8FA0B9CBCDE7FBFBF5EEC9B8A9948986847E7C7A
7A79757372707172716F686766626161635E585D6F6C6B7497A690939E8892AFBAA79F95
927C7F8A85858081947B6A544B4C4E515B5F545566654F44444D464044443C3F41454A4B
3D3144514A393A2D3E4F25101D1E2C1B160F0E0604030200010100000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000012097E0D0C9D3EAF2FCF8DFB9
9B8C8B8F898079767B8A8D8093908087ACC0C9DBE3F7FDF3EEDBBEC7BD9E928985858480
7B7B797573716F6D6F716A68696162626360595B656D80808EA58A8C8D8A9DA7B39990A0
9C908F91938F8B8B88837763535250555156615F74714F424047534340474343413F4643
403145543A3C2F373C3B351E2A3E241821140E0D06020201010100000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000226A2EBD5C5C4D1E0DDEEE2AA92
948F8A8A7D7778787A7A7773737082A4C1C2C6D2E5F9FCF5F2CFC3E1D2AA968D87848480
7F7E7976757572716F6F6B696562666A6665646E7B7B949693A294958F9BA0AAA89192A3
A09E948A9DA09092848284796C645A5C68655B5B687A715A585F6E50494A4944403D3A41
53474D4947321C2D303630241C3E21121B17171906030202020001010000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000227A8EEDDC7B7A4AEAFA9BCAE8C90
90857E7A71747F7E7A817A747589ABC3C7C7C8D2EBFCFCFDF8DAD3CCC0A18D81807D7C7E
7E7C78777A7C7978747375746E6A6C6C6C6E7FA68E7F7C8283899999919FA5AAA1989895
96928F8A96998A9D857D818A817A797D7469645C626B7B7E848C755B54504E4744434145
494A4026482A1B2F3C3D2B2416282B0E1311171103030202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000001012AAAEAD9BFAF9E95949291968C817F
7E8079767476887B767C7987A8BBC3CCCCC9C7D5EFFDFEFEFCF0D0BEB4A2938B86848180
818380818082827B777476726E70747C7F748698846878978F898CA59EA6A3A7A29A9397
9A8F979D989C969A8F80828C7E7F86806B6671676769737A8A857D6E615859524C4C4B48
4C482C212E2A323F4B452A1F1D232F130E181C1308030202020101000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000227A9E7CEBBA6A0958E91928F8B877F75
727372707174746D6A6E85A5BEC2CECBCAC8CFE7FBFDFBFEF6E9C8C0B29E91908A868785
81858489888A857F7A7A7973717691999F888A8B7366789B8F8B98A3A0A2A59F93959598
A097A0A4A7A8A29D9C827B8A83828680747B8A76686A6B6775807D544E585E524B4C4E46
3A2932343D2E27423E34230A1D221C1C1C1910130F060202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000126A8EDD0BAAD9A98949399918A887F7B77
716F6E6F6F706B65667AA4B7B4C0D3CCCBD2E6F9FDFCF7F7F6E5D3C2A58C8A8788898A8A
81817D7F83857F7874757A7C7987A2A9AFAC9E86868F8E8E909195A19CA2A19890919AA0
A199A1A2A3B0B0AC9781828E877984757E989C8A716A67615E69683F4851685E4A484742
3F3342393F252962493C1B062242191A1F08040F13060302020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000120A1F1E4D0BB9C8F8D8D8E8A867E7E7B7A76
74726F6B6D6D6C676B89B0B5B8C3C5C9CCDFF7FDF9F7EAE0E2DCD4C8AC94888787878D93
89837C7E7F827B7378818080808897A1AECECA9495B5A69C9C969D9FA7B0AA9F988C96A2
9D95A39687AABF9D817F8783887E8384796B697B79686567626461545059696545444543
4545453F412832473C4519051D380E111F0B030607030201020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000010000011997F3F1E5CAAC948C88838484847E79797773
746F6A6A6C706D676C81ABBBC2C4C4CAE0F6FCF6EAE3DCD4D2D3D5C7C1AF9CA0968B9CB1
A18E888A929A827787928889898E9496B0D0BC9E96AAADA2A7A5A9A9B5B1A99C9088929B
A2999E8486A4BBAD84878780888B8787645A5A6984706569635C5D5B5B60665241444641
3E3F3C4340363B37374A2A0D173814101915050307040302020201010000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000200011288F0FAF6EBAF938D8682838286817878777372
706D6C7175736D707583AFC2C4C5C8DFF6F7F1E6D9D6CECEC9CBCEC7BDABB1C4ADA6C4D6
C5B4AD9EA9B49E9095A49FA6A6988B95A4AD9A9BABA19B9694939CA7B8B6A292958F8F91
9793959895A7B7A5878588868792897D716161647E79606869626A5B59564F4343484540
403F2F2C2E322E2A43432B12162A180C130C03030D050202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000001000000000000000C73EBFDFDEFC19B8C88847D7D7E837C7B7C787470
6E6C717B7F7A7A7A7C90B5BEC0BED1EEF0E4DEE2CCCACBB6B5C8C7CEC2ADA9C5AFBAD1D0
C0B9B5A89CACADA79FB0A49EA194909CA4ACAFA7B0B1A7999D908C9AAFAC9B9DA0939994
8B8A92A0A3AA978A8891989595927F7A7D66666A826C66696E695F5454584C4846454040
3D3A322C333929213D2726120406140C0F07080404030303030200000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000001075DE2FDFCF4C7A2958A897F77797E7C767A7875716F
6E707579807D7C777B8F9A9BA8C4E4E9E2D6D7DBC2C7D2B8B8C0BAC9D6BDA7A69CBAC4BB
B6B9B5ADA1A1A3A9A2A6A6ACA39F9CA0A0AFB7BCB4AFA79FA7A6918C9CA19D9FA1A2A494
8F8D989A917F7B8A8F989E9B94938A8183686C6E775C636E737866555657504A433F4040
3934392F32372E272F1B2018080425220E0C0E0604020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000000000345D3FDFEF1CA9B9B9187867975767777737270716F6D
737E7B7C81837E76808E93A0B4D3E2D4CDD3D9D8C5CBC9B6B4B3B7B9B9BFC9BFACAEBEB6
B2ADA7ADB2AEA6AAB0B7C5C2C1B4A4A2ADC1B9B8AA9B9AA6A5A2A19AA29B99999DA69C92
8788A09182808D9F9798989D9D9B958680666B6C766C74847B786A58504E4A4C43394043
464246332F3524251F1E1E1C12113429090E080302020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100012EBFFBFDF3C59B8D9083848276787876726F7072726E6F
7E878285898A857D8A99AAC9E2DDCAC7C8B8C2CFC7BFBEBFB9ADAFB0B2BFC3BCC8C1B8A6
9F97A0A5AFBFBDB5B6C5CCC6CBB7A8A8ADB3ADA8A696969DA09C9E9EA19C9B9AA3A29991
838499968D98A19A9794919191959A93856D6B70737689806F504D44404E504F463A3E42
442D32312E2E232120201D1B1712191011180E0202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000011AA2F8FDFBD29C8E87847C807C767B7B7877777E7D72727B
8B8E8B8D909891939FB7CDE9FAE4C9C8C9A9A6B9C1BFBEC6BCB4ABAFC5C9CBCADBD0AF9D
959FB6A7A5BAC5B6B4BBB6B9BCB0A8A9A9A5A0ACAD9E9D9EA3A1A1A0A1A29798ABB0A798
8A8E8D8B8E94948C8D8F8F8A8B909C948E7A6E715D5C727C452F3B3A3E4D5A54443A3B3E
341B37362D26221F1E1F1B1B190F0D0F170F060202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000101000C7EF0FDFCE3A5888483817D7F79778086878480827F737C8C
97949494969F989EB1C5D9F1FBECCECAB5AAAEA5AAACBBBFC0C2BCC2CDCECEC7D1D0AFA8
A9B2B8A6A5C2C1AFB0ADB7B6A5AAA6A3A6A89F9DA29E9FA3A7ACA5A59A9993999FA2A194
92968B84878C918A8A888480888B88898A7A726C4D61708037373B4242444D554C3A3A38
382A323E3A262321201F1C1B19100E151605020202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000555E2FEFDEAB48E8884878C8B7E78818884888781787A7A829A
9E9890909CA39E9DA8AEC6E8EEE8DED4C1C8BCB2AEBAC1B3C2CCC7C3C7CCD7CDCAC5C2B7
C2D4C5ACB5C6B2A6B1B0B2AB9F8F939E9F9F948B8D98A19EA3A4A1A1A298828C999A8E89
8C949184868B8D7D7A80807D7F807C7D7F66657E6773787F3942414B4A403B4A57463D31
353030392F28272322201B1A191109101103020302020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000232C9FCFCECC79E868C8B8C8E8E7B82958B7F7C827B7676818DA5
ACAC908FA3AEA1999CA9C2DCDCDEDED9D8D3C3C4CDD6C9C4D2DFD5CAC3CCD1C8C1B4CBBA
D1EDDACACABEADA5AEA9A6A29D8797AC9E9189888587959CA0A39EA3AC848491919F8F84
8B8C8E848A8C867E75757984828283817A6E76837276706036494A4C4E393A4859402338
3A352E282A2B2923201C1B1A1A0F05110F05020202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000001000117A2F8FEF1C6A98C888E8D8A8B80798992847C79797776798A91A3
AEB3A098B1B3A79AA2B8C6E3DCD8D9D1D9D7CBD0D7D9D2E0EEF6EBDDDCD3CABABEBACABE
D0DBD0C8C4C1AEACB9ACA4A49C8F929C8C8C888B8D91A0A59A989EABA5858A8981A0927B
848E82858A8A87817A7A8284928C82807B7B6C6F756A6463474544423E383F505F443047
332A342D2B2624221F1B1A18150E09140A06020202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000970EFFDFAE3C09A888F8D85817E797F837F797C7D777273829DABAB
B0B4B0B7BEBBB1A8B5D5E3ECDFD7D9E0DAC8C6D0CBCCD5E4F2FAF4EEE9DED2C3BABBC0BF
C0C2B9B1BFCDB6AEADA8A6A19D979892878B8C898E99A2A08F91A8AEA088859399AC8980
8B88848B86898780727A848A928D7F7D7C75646F7666746B674D4949484A4A59665B4044
2729332E2222221C1D1B1A180F0F0C0A0604030202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010240D6FDFAEFD3B4978F96877D777272797B76747C7D77747584A9BBB9
BABDB8C5C4C0BEBAC5D9E8E3DDDBE5E2D8CFCCD2CDCCD3E4E8EBE6E0E2DAD1C6C2C4C7C0
B8C2B9B3C9CFBCAFABA8A7A7A29A97928F918F8592969F9A777E91A093858C8E958C8189
8C8491958B88817B767C7A817E807C7D7A726A686F6E6E6C75564B5153545C665D3A1F28
2A2932311F21211C211B18140D0D0A060301020202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000001BACFAFDF8E9C3A18F8986777372707075777273777A7877828AA4B8C4
C4C7C5C9BFCAD2D2D9E2EBE6E4E4E7DCDCDAD9D3D4DBD7DBE0E3D8CECECBC6BBBBC7CBC1
B9BDBDC1CCC8BEBAB6B3ADAAA69C97999390928F969A9F907A8282958C85898487848586
868078878B8B837C777776726E736E7E6A756E68706C666C70564C545E5B524C43110C21
3D3C3D2C242322201B181B0C11120A060302020202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000871F0FEFDF0E6B491867F766F737372737874747981847D7E969EA4BABD
BFC3CECEC8D0DBE6E7EBEDE5E1DADBDBDFE5DDD6DFDED5D9E7EAD8CBC4B6BEB5BAC1BFB9
BFC5BEBCC2C5C3C6C0B8BAAFB2A99F9E989495909097918D868687908084878380838B83
726C6D7B878A86777073726D69686A6D6172696A6B6869626555494F514D4248450E1921
39452B262526211C17181C101E1B0B050302020202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000137D3FDFEF6E7D4A78A7D787272777474747371788288847E869E9FACBAB2
BBBDC2CACED6E8F2F4F7F3E3DCDBDADAE2E3E0E0ECDDDADEE7F1E4CDC9C0BDB8BCB4B3BA
C2CBC3B8AFC1D7D7C9C2BDB1B29C9A9C9692918E888A84848A908B807B8587837F848A73
666E76737B8688887C736F6E6A6A64716762626463656157574C494F4948494738162022
31512C27252417121817140E0D0D06040302020202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000010000139DF9FEFBE6D4C6A485777272797F7273767B767A8A8D817B84878C90AEBA
C0B2BBC6D1D7E8F2FBFCF2E4E6E3E0DBDFE3E9DFEAE4D9D8E0EFE1D2C6C0C0BEB5ACBEC4
BCB8B4A1B5D3E1E6CDC9A4A2B3999A9A9892938C8A8C877A808684857F7F828082867D66
74848679757C859386736A706D6E6A6F696A6364686865574D474D5149464A3E1C292D32
4C4324211F1F161217180F0D0C0A04020201020202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
02000100045AE9FDFDF3D9CBB89D7F71727678756E768F957A808D847A757A77757D97BF
BEB6BDD1EFEAECF9FBF3EDE5E3DCE1DCD7E3EAE1E5DBD4D7D8E1D9C6B4B7C3B5ADAFB7B1
ADAFAFA4C2D8E6E5C5BCA6AAAE9896A3AA908E8D90867D77767D87927F7C7A7C7E82706E
79888A7F76737994917569716D6E6E6A686463646767675E4D555A4B46474D36142C2C2A
2F2E27231F1F191015150E0B0B0803020202010203020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0100000123BEFCFEFCEDDACBB59B8378757271707183A68D7783827977777775789E97A6
ACAFB2D2EAE6F1F4F6EEE7E3DEDDE0DED8DDE1D3CDCAD2D2D9DDD3C5C0BEC3B8B3AFB4A8
ACB4B5AEBECFD7C9C1C0B8A7A597979C99908C8F8981807C797C837F7A7A77797B7E6F75
7B7E7F7972706F7D957B6A736E6A646562595D6365465C5B343D4D4441444D3915292B22
2C3C2B241B1A17171816150A0B0804020101020203020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000878F3FEFEF8E8DDC9B6968679736F71717587897472787B7B787A7F7B7D9296A5
AEB6BCCEDEE7F0EBECDFD8E0DBDCDBD7D8DCD6D2CBC7CACACAD0CEC2C6BBB7B1A7A6B3B6
B7B9AAADB6BCBCB6BFC6C7AAA89C988C91908F998A8382828784827D7B7A767A7C807973
797A7C74727477829B856B776F6A676A5E5758635B4E6345303D434A4245483C18262A29
393F252919141C1B100F0C080B0304020101000202020202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000100
01000132D1FDFDFDF3E7DCC7B79E867A7A76797C7F787170788186857F7F7C77777B90A0
AEB2B6C9D1E3ECEDE7DFDEDFDDD6D4D3D5D5D5D8CDCBC3C6BFCBCEC7C7BCAFA69AA4B0BA
BCB8ADADACA9ABB7BFCEC7AD9F9B958A9092908A848482848A868988857D7C7C80868074
767578787675808F907E69737A7B6D685B605A6058585F3C454A404E4E41473820303336
45331B2A22121F16130A0A0C070203020101010001010202020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000C8CF7FEFFFCF5EBE0C8BAA28A858C859DA38F7A747B84928B8582857D7577788996
A4A6B2C5CCD8DCDCE2DCD3CEDCD7D3CBD3D3CCD7DFD8C8C9C5C7BFC2C8C1BAADA4AAB3B3
B4B1BAB1AAA8A7B0B3BAB5AEA098A192928B8F86828383868884878D8F8A8786868A857E
7C787A7A7C82888C836B707478515469645D5B595355533F3E49485B653D443B26333334
2E1D19282E0E140E1D0B0E0B040302010101010101010102020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
01013BDBFEFEFEFAF4F3DCC3BD9F838DA19BABA484797F84878B86868586807473778288
858AB0C0C3C5CCD4DCD9CED3DBD1CFC7CDCBC6CEE1E3CACBD2C0B8C3C6BBB6AFA5A1ADBA
AFB5AFB1ABA7AAAFACA9ABB3A59AA79D8E8594817F7F848785848A948C918D838B8F8683
8A7E818686888578636978696243617A6E6360584F4C524C48545D6A6136414B332E2E28
201B1D26300D0E0F120B0B05070502010101010101010101020201000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010F97F9FEFEFEF6EDEBC8B5BE9D96A1ACA6A78A7D80858482828689868582787475787C
7A86AEC2C3C0C5CCD2D0CCD7D2CDCDCFC7BFBACCD9D5CACDCEC7B6C1C1B4B9B6A8ABB0B3
B0B6BBB4B1AAA5AC9F9F979EA5A0ABAB958978828A8486877F8389927CA6958E9691828D
8D7F787A72706B656776695C5256676F5E564658554D4E4B4E595E543C3540443C3C2A2B
25201F3035100F13130B0806080402010001010101010101010101000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000100
0142DFFDFFFEFBF8EADFC5C8C6B4B5AFABA49889858387857F807F828586858076737274
7E97ABB6BDBCC4C5C8C1C3CCC7C8C0C2B0A6AEC8D0CCBDCCDDD0BCB7B0AFBBAFA7ABABA5
A9AEB0AEB1A4A3A6999A8D929CA2AAA398847E8D8C8D87897C84899399A3988C8E8C8183
867C7174756D6F696F6E69514E5B55555A564C5E5D555A564F4940443A3B38433938383E
342E303A241113160D030206060101020101000101010101010101000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010001
0F99FAFEFEFEF8EFDEDCD6DAD1BFBDBCAA948F87848384827C7C7D7E8487847F74706E71
7F99A3B1BABEB9BABFAEB7CABCC5AEA69897ACC5D4CABAC0CBC0AEAAB0B2B2A4A4A7A4A6
A49EA1A4ABABAB9E9B9B8785959A9F8E8987878A8D8A8A8F80888E969C9F99928F877C7A
75707173746F716E6D6F654C4F5B54595B5D676A5B5B6054483F414A293E43463B3E4548
2F2C221F130C040505020210110201010102010101010101010101000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000002
3EDFFEFEFEFAE8E6DDCABCC8BAA8C7BF998587888584847D7B797A7E858C867C706D6F71
7C8FA7B9BDC4B8B4AFACBEBFABB7AF9C9999A9C3CBC0B3A8A8A8ACAEADA4A0A7A8A09FA7
A69DA0A5B0AFB09D9F978889999F9384818283848C8183878B8F9094848983888D877978
716D757B70706D61696A5C4F595755575863665A4D49384C42303B372149463F3D4B4B47
1C141D13080402070A0203080C0201010101010101010101010101000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000100000A
90F9FEFEFAEAD5E8D8BBB5BCA9BFE2BB878D8D8F8784827B7A797A7E8387897D716E7071
7E8EB5C9C4C0B4A89EACACA19EA6AC9CA2A6AEBFC3B9B1A7A2A6AFAFA69D95ABAA9C979C
9C9696ABB0B6BC9F96998D8B9099908A87827A7981827F879FA09384738081888A8D7F78
6C6E767C797465646E6D6C615153575A5A6F5E41523E364F4422303328493A272D3A3438
0E16240A030202030606040B090201010101010101010101010100000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000001000133
D7FDFEFFF4D5C1CFC2ACAFB1B0E2EBA5848C90928987807D7D7B797F827E7F7A73717475
80A0C4D7DACBB0A19A998D90A99F9993A3B6B9C0BBBEC1B2AFACB4AFAAB0B7BAAC9C9592
8B8A94AAADB9B0A6999084807C8A9A8C82796C68798284849394817072807E7F899C8D78
68767A798876696F6E78714D56575A5F6D744E475B474352371E2E3730362D2F35413F48
111F2306020104040B0D0C19080201010101010101010101010100000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000087E
F7FDFDF9E2BFB2ACADA7AC9FAADFC092898D9093908C848584817C7F807C7C7670737678
8AB2D1CDD2D3B4A3988F8D9096929291ADC2C9BCBCC5C2B3B2B5B1B3BAB6C2BDB4A2988B
8F939EB1BDAB9C9B95867E807880978E7F6A575875818383888F766D787B7D7980978C77
737A77767A706B6F69706D5C6756586569584B5158463E2C2933373C3C35323A393E4A58
2F231E08020103050D061013040201010101010101010101010101000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000124C9
FDFCF7E8C9ACA29B9996978DA0BE918A8E929795958B86878D888581827D7C787273767C
98B7D7CFCACAB1A5968E8A8A888B8F93A9B8C5BEB8B7AEAAB2AEAFB2B7B3B6B7B0A79B92
9C999B9F9F98979C96827D8484898B90896F5F5C6D72767C86826A7392787D7A737C7581
736D666B716B6869606A6860584B505A5B484A4F4C4232283B454445433C3B3837334565
43181209030102050F0A1A1B040201010101000101010101010101000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000364F0
FDF4E1C7B6A1948F9A8A8A949F9B83878D9AA29D988E898C928C8786837D80827975767D
99B6C9C7C8C0A299978F8B848485898F9CAAB3BEB5ABA3AEB3AAB0A8B8C9B7B8B2B0A29A
989E9BA59595A29889867F838586829793837B73697381807A777B847B667878707C8077
69615A6A716766555C6F6A5D4F454C53564D494A4E47323A3A504E4D464442382F2F395F
321009120902020518241F18030202010202010101010101010101000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000015ACFB
FBEFCFBBA497909BA5888F959688808788909FA5A0938C8B8B8A8E948B8181837E75767A
91A4A9B1BAB49B90928D8F87858184878F9AADBCB9B2B4B7B3A6A8B0BFBFB2B9B2ADA49B
959A9EA0969592888B8376787D848892948E88827F8387787A867C8169747D8474756F58
5E6A5D6A6F6F63586E77685347454F54584F4A4B522F2537334F544B47473C322E28334C
1A3E1D0E0C040A0E272B1207020203010101010101010101010101000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000100000041DFFC
FCEAC5AC90949DB3AC96949596827E8383848E959897919189848A958C838589867B787A
82949A9FACB1A4A1958E8C8884848483898B95ACBBBFBAB0A8A0A3ADABAAACB3B0A6A49F
94949C978F8C888687776C6F77858A8C9C9995857F8587767C807D88707F918B706C605E
626D636F6E685B6268635E52495150515B52494E4C242E4142474047423E2E402520293B
3D5C1A0305050A0F16140402020202010101020201010100010101000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000A83ECFB
FCE1B6968197A8C1BDA9909C927C7C81807F8187878B8D908A8584898C8787857D7C7A7C
82888790A3A8A5A59287888B858581848A8E96A4B6B9B6B2AB9FA2A6A3A4A6A7ACA4A19C
9993928A85868E8C7E706D7279808C9093979E7670858D817C7F7E7D7A8496786D6D5F60
60686A6F6A645A616B605A5B5E5B4E535E4C4A473A373C504C3D39342315141B2023252B
46380602050E140D0F0C0202020202010101020201010101010101000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000002AC7F1FB
F6CEA77F7B93B5DBBFA09BA3877A7E83807D7E848382848C9189868B918D88827B7C7D7E
828D8086939A9D9B908B939A8C817F8CA4A9A0A6ADABA4A5A39F9FA3A3A4A8ADB0A5A1A0
9D94938E8182908D8079737B878C8E8B8D9B9A7376859E7E7A85847A80767C6D6F6B605E
60686764625A585F635A595F614E48575741442A345A434C4C3720141C1B181D25221E1E
524005060A0E0D080A050302020202020202020201010101010101000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000363DDEDFB
F0CC9B717B97D1DEAE9F9A997E7E8483807F7F84868381848786868A91928F898280807F
7F83818491969A98929FA5A594898892ABA2929BA2A19F9A9D9A9CA1A4A9B2B1BFBFB6AE
A4989B94888A8984897D73808D8F868586979A8C869691717882817B7B6C746C6C6C685C
5D62686C6165675856675F5D4C2C525843404B3D5A64453F431E0D222D2927252325282C
46230A0B0603020202020202020202020201010101010101010101000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000100000000119DD7E6F3
E3BC8A75839CDCC39795959480828382858481828787857D7C7F8185888F918F8B8B867E
7C818283878E9C9D94A1A09F938F9397A69B9AA09D9C9E9598999EA9A7A9A8A5B1C1BBB9
B09D9991928B83807E80828D888A837B87959695908D797176817B7D716B716A70685C55
60657068586561585F5D5A55473B6A614042424849453C4032100C2B2C2828251F26403B
3618140B0504040202020202020202020201010102010101010101000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000012CB9CDDFE5
CAA0827B899FBEA78F958A8F83827F8183828385898C8B807C7B7D7D7F878B898D928B81
7D7A7C85898D919BA5ADA49F999897979A9F9FA0A0A09E9695989EA4A9AAA49DA2B3BFC6
B1A39A8D8D837D7877818D8C838781838C8C8886887E72707B867871616561636C5C5255
555F5F595A59525751515E534F4B5F443B37414642393B41380E0D292F333C291D26454E
270D0A060503060402030201020202020201010102010201020101000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000035DBFD5DCD8
B69382838E9B9F90918C7C87837C7C7E7F7F81848C8C8884817D7C7D7B7D8283878C8E84
81838895949298A0A7ABA39EA1A6999AA1A5A4A79D9C9B9D9F9E9CA1A7AAAEAA9FA4B5CE
DBBA988E867E7776767C898D8D877B828D86878B8E8576717680775F545856615F59554E
5460625F545858595F60574A45403B3B4A51473C413B3C3B3D0F071F2F3B2E13122E543D
130403020202030302020202020202020302020203020302020101000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000100000000000D83BDDFD9D1
AD90888A919895838D8374797C7574777D807F80858784817E797A7E7B7C7E8281899693
8C969B9E979396949BA09E9BA7A4A0A2A1A59F9D9B9A9C9DA5A49EA29C97A1BBA898A7CA
D1B599958E827C7B7B7A879891837C7B838E96978C857E77737F6449575B6263625F5B59
5D6366605767625C5E664D3F46413E445362403A423D3B38341806182828150F0F35521D
1E0D02020202020202020201020202020202020202020202010101000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000024A9C0E3E1C8
A18A8D8F9097958E91846F757A76727780807D7D8182817F7C77787C7C7F80848C96A6AE
9796A2999396918C94999C9FA0A09FA0A8A394959D999A9FA1A6ADA097A6A5AFB5A0A2B1
AD9D979B9687857E7C82909C8A797B79778893998C868575737553576465646666605C5C
61686E645F655A51585C3E423E3D3E404B6244363E3A33382E28121B27262920233A3D2A
2E0B02030803020302020202020202020202020201020102010101000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000014DB5C9E0E6C2
998A8F8F929FA49E8E9371737877727682807F7C7E7E7E7F7D7A7A7D808485939EA4ACA9
8E8A91929192928F9397A0A4A39E9FA7A19990949CA3A0A1A2A6AC9C97ABAEA7B69DA4A9
A59F949390929287868F989E8976757A78848D99867E8C7671635763685F56746C615D5E
626C6964555B595A62574649454548414A574C38433B31311F322D2A2A283B333D523036
0E0302020402020202020202020202020202020202020202020001000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000001000000087AB8D0DEE2BF
938E909093A39F8E878271737977747B8282807D7F7D7D7F7E7E80858489919E9FA6A898
86878C8C8C969A9896A3B3A8A7A4A4AC9F96929AA0ADADA1AEB7A0A29DAEB3AAA995A2A7
ACA2908E8F909A8C848796A5958581847A7D8894747E8D7D6D64686B6961677D6C605F60
64675F5852605D5C5D5741473F4234374656512E4543342A23333C352A2A3C3A444E201D
060302020303020202020202020202020202020202020202020101000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000018A3BDD2D8D3B2
919497929AAA928B8C767077797A7D828486837F807F81807F828182848B949798A5A290
86898D8F8B95A0A6A8B7BCA2ACA69E9D9A929099A1ACA8A3B6B7A9A1A5B1B7A89B979BA0
A29E908C959494898594A3A6988F8C8E7E7C807E72818986726A6A6764676F6E655F6666
7173695A5D6A5A5A4F4F41464046454D404E4332483A3830272E33271C1E263C3C261106
040302020202020202020202020202020202020203020202010100000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000135BDCAD6D1CFA7
93999A9CA6A69B958D7D707D7D7C81878C8F87828487828081838183858692999DA69E8C
8A888B8B8B909FA5ACB4B8A6A9AB9D99969295A2A6AAA0A0A2AEAC9EA3A8A998979C9CA0
9D99958F9496929697A6A49C938D84847F857D7D7E82857E6E686966626467656566726E
786C6F5D58615A5650494540415054423D513E423728362F1B2623231E1B1F241F110403
020201010202020201020202020202020202020202010101010100010000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000001025DB8CFDFCEBF9D
989894A5AE9CA59A9380747A7C7B7F89979584828689818183838284858791A2A7ABA69A
938D8E8C8C8D9C9897A7B7A9A6B5A79D9C9596999BA1A6ACABB6A4A4A2A5A9989B9F999D
9F9A8B85899CACA8998B8B8E9997868689877C8178737A7574726B67625F5F5F6F78716A
6970804C506A6A594B494C4B56564437374F4B3C2C3041250F0F18232734200F1A0B0203
040201010202020202020202020202020202020202010101010000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000A7EAFD6E1CEB094
9B9795AFB3A8ADA49A8A7B7A7B7D838B928A817D7875797E86868080808692B0B1AFB0A6
958A8E8E8C8F9E9E9E9A96979BAAAAA29FA19C9B989BA3A9ADA6A2A5A29FA39C9E9D9A99
9B9F8E808FA7AC9D7A6C767C879A9A878E7D78776C727D7076796C69635C5E62716C6263
6A745D43656F5D52504B514752403A33394D5742382F29231914232A34381C1113060202
010102020202020202020202020202020202020202010101010000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000169AACD8D5BCA597
98979CB1B2B2B2ACA59B96897F7F818F9387807970727E8186837C7C7F869FB3B3B5B7A0
8F89938D8F929598998C929D95999F9DA2A7A7ABA6A1A2989DA5A5A4A5A29E9FA29FA29A
97A3A19198B0AF8F6A68676E748CA7888C83747C7B78717077786F6C5F5D60636F615F5D
6154494A56626F514049434158423F383A4B5432232C3D2E231B24212E31120508030201
010102020202020202020202020202020202020202010101000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000101012DA9ABD5C8A89E99
939AA5ADBCB8B7BAB4A6AF9D8D84828A9289807773767F8386827B797B8BAAB4B5B5AFA4
9C9293919C99918F8F8E97A29C9190919BA8ADAEADA7A19998A5A3A1A4AAA196A09BA1A0
96989B9593AFB4816E6B676B7386A0808A76827F7564636E706C706E665F6863534A4E4F
55484D4F50576A53455B4D52472D4A43473F45302545333F2219212439290D0707030202
020202020202020202020202020202020202020202010100000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000014CAAAAC5BB9BA1A1
95A2ACB1C2C1C0C7C9B5C2A7968E86868D90867D7877818986817C787B9BB1B5B8B2ADA5
9689969CA59F8F8E9198A0B0A38D888891989C9AA3A7A6A09DA4A1A0A4A8A49DA7979CA4
9C97938488A3C39477756D6E747E987F7E7B97786A5F6C6F6D666B6D656B62463F454544
4440454D4D4E544B64634C3F3A424C42393C40413936383B19203036361F0B1716050202
020202020202020202020202020202020202020202010000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000464A6A7B3A18B9AA4
9EB4B8BBCDCBC9D2E0C0B5A4A19A8985888E887E7A78828E867D797C86A6B7B6B9B4B3B1
9E8999A3B19E908F9298A7A8988C868587898B90959BA0A0A1A0A89B999F9F9E9B989E9A
9FA1A28888A2BDA08B7D73777F94967A808B846A62626A6A696B64767368503F3D3E3C39
3C4247494A4D4E4C5C493B3C3C34393A3A484A4D444552290C21352D1F1E111B11040202
020202020202020202020202020202020202020202010000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000C769C9DA38D7D9AAD
B2BFC6C9E1DBCDD2DCBCAAAAAEA09086898886837E7B86878379737991BBBEBBB7B1AEB3
A99EA3A6A1979293929195938A8C8C86858A8882878C91989C959A95999D9DA7A5949794
979BA7A4A4AEAA9E9E898A8B9A96807E86918060636465636069686D715F4A3D3C3C3A3B
3B414242474B484C4D424F5133333F3A36394341362F2E14062739151215090D0D040203
020202020202020202020202020202020202020202000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000014809092937A7A9EBA
BFC8CBD1ECE7D0CACABDB7B5AA9D948F948E998E848081797F7D7B8299BCC0C1BDB0A9B0
B0ABA5A29D9A9692909191908E8C90868489867E837D808F988F8B8B939A9AA1A9968E93
9B9CA4ABA9AA9DA1A08C96908B8B7E7A8694726D6F686363646B6D6A6F63483E3C3B3A3C
3E413F3C40403D40464649462F393A3733343C4E3A2C2C1915302F121E0D03040B040203
020202020202020202020202020202020202020101000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000020838691856F81A8C7
CBCACFDAF1F0D3CCC0BED5C5B0A191969295A99F8D87817D838C8995AEBFC2BFBDB6AEAF
B5ADA5A3A3A6A3948D8F8E98989991888780828383767A8B9190928C90908F96A59E8A94
A1A1A3A5A9B09E9995918F908481807D888679776767656A69646E71716253453F3D3A3B
3C403D3A3A38373F47454D543431383C36343F483B24251F27270B050C05030304050302
020202020202020202020202020202020202010000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000133857F948A7C8BAFCC
DDCED5E3F1E8CFBEACADC8C9B7A59AA8A9ACB3B5B3AD8F909B959BB2BBAFB6C0BCB6AEAD
B7ACA8ACAEAEA39A9296979C9C97969B98908D89887A777A7F858A8C9084848B949D9695
9CA8AFA6ACAF9A97978E888B7F7B82868F8F7E6A6368656B6C666A6C6C635C56443F3B38
3B3F3F3C3C3D3B4249444B443F3F3D3B3D4038433E232924281A05030513060202020204
020202020202020202020202020202020202010000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000245817992918899B6CA
D4CED5DFE3E4C3A28F9EB5ACA5A19DACC2C0B5C6D3CBA8ACBCB5B6C2B3A2B8C0BAB6B0AD
ADA6A8AEB5AE9F9C9AA2A09C9A908F9496958E8683777478797A7C7E818589878E96989A
9EA3ACACA4AA978B848992837D8292968D927360646D66666B6C6C6A696466594D423B3A
3A3F454546453D414842445562423A3B3934333D41261B141B1608050F290E0202020202
020202020202020202020202020202010201010000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000010457827C8F9494ABB9C3
C1C5D0D1CFC3AB988AA3B3A6A29E9C9EA6B1AFC2DBD7C0C3CCCECBC5A7A0B0B4B6B8B8B4
AEA8ABB2B9AAA39F9B9B9699978F8485868481807974757A767476767D82888D969797A2
A3A1A5A7A6A5968C8E92949088919C8E8088635A596564606D766B6E796D6956564D413E
3A3C44494949414243424D5257403A32352F40442F0B0404050808070F1F080202020202
020202020202020202020202020202020201000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000965858490949DBDC7C0
C4CFCCD0CCB2998A8EA9C2B9ABA29FA1A8A9ADC3E1DDC6C4C5CACEC7B2A8B4B6B6BCC6B9
BDB4ADB7C1AFA1A1A09B9292958D8180817D7C7F7873747671707070798680818E9393A1
ACAEA8A8AEB0A0908E92959898998487836364525B63585A77836A7973645B5857564B43
43444849483F36444E4F5B454B3E30262E2F443A1202020607040A151311030202020202
020202020202020202020202020202020201000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000020F7A8E8E96979DB9C6C4
C9CAC5CCC9B89D9293B2C3BBB6AFA8A4A19EA4BBCCC6CCCCBDCBD3CDCBC0BCB8B7C1C0BC
C4BEA6B3B6ACA19B9E9B8E908D877C7C807F7C78777672726E6B6C707E91847B83989D9E
A8A9AAA8AFBAA595939A9B95979C8B7F6B5F685F616A5D667C8E7279686B55625D595648
474E4C4746463E48524B4939473D25273035422C0A030D13120A0E1E0C04020202020202
020202020202020202020202020202010100000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000158C9E9CA09B9EB4C6C5
AEACBDC2C3B49F999AB5BEB8BAB4A8A29B989DA9B7C0CBCBC2D4C9BECBC0B4BABDBFC3C6
CDC3A6A8AE9F9793928C858586897C7A807B7775797673726F6B6D6E819185828696A4A4
A69BA5ABB2B4ACA09AA39D9194A28F75636C776E63777374827A6C6F685D4C555E5C5D55
4F51524A4A484446413E43434037273734342E1602091517140C0A191204030302020202
020202020202020202020202020202010000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000011C95ADA9A7A09AB1C3AF
9A99B3C0BAADA3A2A3BBC3B7BDB7A799949EA3ACB3BACBCBD5CBBDBAC1B4AEC4BBB8CBD9
E0BFA59C9E9795968F8E8C8582847E7B7A78727176736F72706E6E6E7D878681828EA2A1
A09F9FA3AEB4ACA69D96978F9599896C69717C6A677471736D6D7168605C534A595D615E
566156494C4A49444042424846332E2D2935281106101127190905161D0C020202020202
020202020202020202020202020201000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000002895B0B0AAA39DBFB898
8E8FA2B9B5B5AC9FA5BCBDB2B6B4A29598A0A1A9B3B0B3BCC4BDC2C7BBB9BBBFB2B3BBC4
BEA599999C98999C95948D878180817F79767172756F6D6D6B6B6C6C7C87847F8288969F
A09C989DADB1AAA59F94959A9E95886C6D75796E6B6E77706F6E72685E66565565656961
5E6A4752504E4A4945433F444743392B283128170D1414140B04041E2A09010202020202
020202020202020202020202020101000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000013195B0B3ACA3A4C2B696
8A899BB4BAB9ACA0A6B4B6BDB6B1A8A19D9A9BA3B7B8A9ABAAAFBBBBACB4C5B4ACB0B3AC
A29793969894979B91918F8C858485817B74747575726E6D6B696B7583857B7A80889898
959D98A0A8ABAAA39D91968B909D8467717A806D646B796E73726A6A61645F66645D7173
70604458524F4D4C4844403B4F5C3F202A2829250D0F110B0A05071F1503010102020202
020202020202020202020202020101000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000013A9BB6B4ABA1AAAD9D8A
858AA6B7BFB8AAA1A9B1B5BCB6B7B3B19E9AA2AAB8B1A9AAAAACBABAABAEB7A7A7AFB5A4
949596959495979DA39C98958986867D7A7574736E6E706D6B6C717E83807B7E8287928D
8E9B98A2A5ABABA49890866987A5826B737978676F727B777859537272656C606A726F80
744B4E5454524F4B47403E3955572D1D271627230C060A08070B1E180601010101010202
020202020202020203030202010100000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000010142A0BCB8ADA1AE9D8E86
858BB1BEC2B7A89EA2B0B3B3B1B4B0B7A09DA1A8AEACA7ABA5ADC6C7B6AFA7A0A1B1B5A3
93969A969E9BA1A2AAA18E908A7F7E7A787674726E6D706E6C6D727C82817E81898C909C
9C989BA3A6A49FA197AA87748DA7896D7479788685958D7F695161817A6364636C6E7086
675054525151524443393B3B4645271C14111F20140D0F13191F230F0300010101010101
020202020202020202020201010100000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000001479DBCBDB1A3B0958481
828DB7BEC0B6AEA4A3B1B1AFAAADB6BFA1908D9DA3A7AFBCB0AFCECEBBB4A8A7A8A9A9A5
98969A96A1A5B1ACAAA18A837C7C7C7A77767472726F726E6E777A7D85888082888B8B97
999D999DA09D9CAABAA79185989A917D81828294889382776668718067616B63696D7676
5D3D4F534D4F50423E3D3D3645472B1E16171E1E0F0A0A12181911030102010101010101
010202020202020202020202010000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000034D9ABCC1B7ADAC938787
8795B1B4BBB5A6A3A7ADA6A3A3B1C2C4AD9992949BA2AFC1BBB0C1C4B8B4ACADABA3AAB1
9D9693929DA0B0ADAB9E88817C7A7877797973716F70707079847E7F878A8484898E8690
939A96A0A2A5AEABA09D9B9495929486898B85836A78736467716F62626A75666970703D
201E4E5B454A463E403B3535483D252416151B0E0A0B0405050502010202010101010101
010101010202020202020101010000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000003539BBEC2B7B3AB9E9A93
8991AAAFB1B1A49D9EA39B9A9CA8B3B0A89A9F9E9DA1ACC7C4B3B3BFBDB9B1ACA29A9DA1
9993909099A2B1ADAA8F827E7D7E7A72757A787672707074767E80848988868A8E8C8B91
969C949FA5AAA185859199998E97948D8B8981856B767C6D6B6661696F6F746B63786620
40526C693E3D46493E352E3650331D240F0E11080D0B0301020201020101010001010101
010101010101020202020100000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000055DA4C2C3B7B4ABAB9B8B
8288A5ABAFAE9F999A9D98969AA6A29B9A98A0A7A8A3A3B6BAB4B5B9B8B0ABADA2969598
9390928F8D919E998E81807C79787674747D77757472717A7B80888E92888C8F91888A8C
909192A0A18F7A73787B89858697978B8F8B8A806E8A736E816F6D7366746E665C735824
53537174323F4A41152C3945551D1017070A14110D0D0803030303010201010101010101
010101010001010102010100000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000769B2C3C3BCACA4A5988C
8187AAB1B1ACA19B969A94979AA1A29C979BA0A4A3A2A0ACAEA9BEB5B4B1AFB1A8989495
908A8E918E8B87807A797D7D7C78747675847771787B767A7C848C8A8C8D93938E89878B
8E908D8E8A7B7174787482797F7D8A9092888989817B7080746F7E6D60676B69666C5D3B
4C5C876E364A43361B515C43280B12170F0F100E0A0806030A0704030101010101010101
010101010101010101010000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000086CBAC3C3C3B2A1958C84
7B84A4B2ACAEA4A39C968F90979B9F9D989FA3A8A3A0A0A3A7A4AAB0B0B9B1ACA595918E
88868D8E8A89847F7B7978797A797676717471747E86797B7F88908C8F8F918F8089928D
88837D837C76747B7372746F73777C777C787C7C777E6B7266738560596276766D6C5B50
546D773F364241424A6852262221281C16100F0F0B08060B0A0402010101010102010101
010101010101010101010101000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000086DC1C7CAC9B49A938D85
7E829AAFAAAF9CA19B8881898E959A9A9CA3AAADA49C9CA0AFA7AAB3B6BDAFA6A499918D
868C989189858081837C79797B7C7977726F7278808080888A8D92898A8F9597879B997F
7A79767B7B777377727172787877767677716D6E75804A757D6C764C515F6B6E675F524E
46483D3A4241434840403623211F1C121307060A0C09060F060001010102010001010101
010101010101010100000001000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000086FC5C9C8C4AE9A8F8F88
84868FA2A09E8C88877D7B83858D94999DA8AEB2A59B95A6C1B6ABB3C8CAB6ABA99F9793
898E969C938D8584837D787F86857C77736F737C8988868C8684818386888C909095877B
7C7B79797A77767B757A7B8179777570726E6D7280877095835F6B4B5F656C7667595B48
4044424B3E3648382C2E21151C120B040E06040B0F090607020101020201010101010101
010101010101010100000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000086EC4C9C2BAAA9B959490
8C86879B998F85847E7C7B8886878D979FA9A9A9A099919FB5AAA6ADC4C3B4B1ADA99B98
8E8C95A3A69389837F7C7B807F7B787F7C7B7C808B908B84847F81858787838587837C76
77757676787D72767D7F82947D787470796C71707A737C6B5F565C57666D6F6F60556A3A
283E4C43413741222113121F180A09061D10040D0E0A0402010101020201010101010101
010101010101010000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000001086EC6CAC2B8AFA1938C8B
8B8786948E8181857C7978909C8F8B949E9D9E9DA3A0918FA9B59F9FA5ABABB1B2AB9B9B
948A969C968D868582837C7B79767D858181838284878B878381828788857D7F7F7C7775
7373756F74776F71777C82818275707480696B6B717675535D5E5D67726F615D514E4F13
0D394A3D4438320E11251A201C17141C2E0A0709080A0503010101020201020101010101
010101010101000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000066FD6D6C5BBAE99908B88
888C9089827C7C7E7C79758192958B8E979394928D94918A91ACA09BA2A8AEB7B6A9A6A3
A089868C8789827F7C847D797A7A7A7E787B7E8284838082807F8184838077757B7E7877
7271746F706D6B7077777A7B736D687C7D6A64696C7167475E595D60686E615C4D473911
1842543C3C3A290A24341125271917161404050403030301020102020202010101010101
010101010101000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000001056EE1DFC8BEA992908C89
8D8D988E847B7A7D7C7972767E898B8A8E908F8E898C8B88839FAE9F9DA6A8A8B4B0A6A1
A39186858486827F7E807E7B7978757D7A7B7F8484837E817C7E7E7A7B817A787A7A7575
736B6B6C73726E6D70747D756B6C6D6E6B675F636468575164595D67686F664C4D413726
3E5A3D3B3F382D1D3415061D1F0E13120B03020201020102010101010202020202020201
010101010100000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000056CE3E4CCBEAA978D8A88
888C9F97877D7D7A78766F727984898A898D8B898A8884808394AAA29AA1ADA7ACAEAAA4
A2958A8684868580808085857B72727A7E7F8E8684817C7F7B7D7B757C88817D81777475
6F696C6D76776F6E6D79726D666C716869615D606361536F6C535F695F6065564D3E2D2C
3430253D37302C1517130F19190506050803020302020202020101010202020202020201
010101000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000010366E6EFCDB8A99B898281
818EA89B867E7D797A79737075848487868A85838988837F8186959B9EADADA6A6A9AAA3
9D9A8E8D878585838386898C7F74747C7F83888588807B817C7B7D7B837F7F7D837B7D7C
706C6D6C7666686D6C706D6A6B716E69655F6160565F5F69644A58594D59654D3E3E2A28
2D2E333F2E282B10151A1C1B260905040702010102020202020101010203020202020201
010100000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000010260E4F2D0B29D9B908480
8190A598867E807D78797870757F80848585817D858281817F7D8390A3B9A6ADB4ADA9A3
9997958E8581847F808284837F79797E817C7F85857D7D82807B7C797A767A807A747F85
757272727261686F6C6C6D6C6C6867605F61645D5F62615E3E204E4E4B5E60413E432C28
2D31374C2A2B32110F1D261F170503020201010204030202020202020202020202020101
020000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000024EDAEFCEAD9890918A80
7F8AAA91828080807C7B7A7579787D7E83807A797F7E7C7F817E797D93AEACAFB2C1B5A3
968582838081837C767D807C7D807B7C7F7E878E83838788807C7A7578797F8275727986
867A7B7E70646872676C6C6A686864626364605D585B604B203663613F42514227332138
323240502F241E0D1425230E030302020201010203020202020202020202020302020101
010000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000141D2EFD1AE97928A8B81
7D8190847D7E80807E7B7B79797C7E7C7A7A7C7B7B7D7B7C80807C7CA3ADA4ADB5BDADA0
937D72787D817D787B797F807F84827B7C8080807D8B8E8C857C7A767C7E808179747884
85797878706A7072696A686264666368645C5C5D5959554A324D695120304C391E222C2D
2D264048290B161A19241B06020102010202010302020201020202020202020302010101
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000137CCE9D4B4998A858B84
7B7C7F7E7E7D7D7A77777B7B7A7A797875757778767979767D7C7C86A0A79AA7AEA8A9AB
9577707A7B7A797A7F7C80858284837B7B7F77768090979E8C7C817D7C797B807D777A7B
777271716D70726869676564676061645B5953565A5A5D4F4A5A5B2F2C3E46281E1F322B
293B49301513201B181D0F06020203020202030704020202020202020202020201010101
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000028C1D8CBAE9D91878A8E
867E7C7C797B797773747C7C7D7B7874747575757477787376797A848FAEA59BA4A7ADBA
AE897C817E7C787A7E7E7C7E81827D787D7E797C819099A38B7B83807E7C7C7E74717673
6E6E6E706E6D6F686E626163655B6755564E4050605A4E34353C423A353D492C2D2D3030
2D402E141314141316150B09020203020302020405030202020202020202020101010100
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000119ADCECBAF97978E8686
8B857D7A7878797770717B7D7E7E797474757571727576767578797C84A4A895A3AAB4C5
BE9F8F857F7F7C797977787A7E837E7980808080848B8A888D80817D7D7E79796D6A7771
6D6E6F726D6A675F6B5C606768616A594C454A4F59513A1B3342563E36414E282D2D2D2C
2B3F1F1B1F130C16150E0B06030202020202020202020202020202020202010101010100
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000011195CCCDAD90898F8D7F
7F87827E757479767072787A7E7D79777672767276817275777876777D99998F989EA4B6
B4AB948A7D7C7B7775766D788689897B7B82817F7F81867F808382807F83777A736F7A71
7073706B6764625F656269666462684B375052515154312640455F4A3B34422C27262B2E
38351F251C0A0E1B190F0604040302020202020203020202020202020202020101010000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000001000B7ECBC9AD8E868D927E
727A818378757874707779797C7B7B7A756F7174797C7173787472717B9D9B909E999FA1
A3AE9E90817D7C7676726F8190888B807D7D838E8681867E7A7E8183817A727B7B79766F
75776D6969635E5E63696957615F6549495757514A4A4434424B66392F3538322A293437
3B2B2422151513190D030404080302020202020202020202020202020202020201010000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000566C6C6B593909E8881
7274778382757775727679797B7A7C7C77727074767573727A73716E7A92908B979B8F8D
9495928C807C7B787771727A827E7E827D7D8B9790887C7C767778808278737D7E797B7D
7E7A6F6B69615F6166635B5E5F585D474751554B474C4F3F4B574D312F37303726283837
29210F16170F0A08080B0804010102020202020202020202020202020202020100000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000024EC2C7B99790968281
7976737C837B7679777374747876767A7A7873777873727E9878706C78928C828C928B88
8C8E8B897E77787676747377827F7F8E8788888A8E897B797877737E8375768374768181
776F6D716B6366675E595B60604A513A4852524B4B524B42444B3F3030352B3616242D10
1217091A1306060206070301020302020202020202020202020202020202010100000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000010137BCC9B7A18B858483
82736E727377737B79747471727A7675747878797D746D7485776F6E7491958C8C8B8787
8B918E8979717777757172767C7B79818B86837F807F7D7C7C78737B7D707777717A8579
6B6B696F6F65676059595C605E58484A5A5F4A535D5B4A474C4A2D2C2E32292118241806
131C13180B04030207050202020202020202020202020202020202020201010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000121AECFB5A891808080
7D756F7270737173747374706C737676717376747775707074717072738C9283848A8785
87898A87766B6D7170696D73777A787E89837C7B82827C7E7F7D76767E757A7474777A74
6F6B6B6D7166635A5C5F5C595F5E4B546259485D4D413F36334528342D2A25202E2D210F
1E2617140C07050303060303020202020202020202020202020202020201010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000001291CFB8AC98848481
7B77737470706F6C71706F6C686B71707272746F6E6F7273716E73777985766362788788
80878989786B696B6B64686C71797E818385817C81827D7E838384817D767D8176737370
6F6C6E6E6F65616463635B5C5E54555153494F423C3D3E3844422E2C2824272F2B1E1710
201D1E0B0203030204080302020202020202020202020202020202020101000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000971C6BBAC988A8985
7D7675756F706C676C6F6E6A66656A6E6D6E716F6C6C6E7677787E7D8282685A57648383
7B888A83756867676561676C6F7478828083877E7E86838081898C897A7B828478737471
6E6D716C6967656A6661635F5B585345434A443941433F36373530252A29282619151510
182319060203070503050203020202020202020202020202020202020101000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000357BDBCB39A8C8A8A
7E75797870716C67676C6E6C6A6866696C6D6E6D6A6A6C737B897F70768270615960828A
83878D8475666564605E63696C76757487828785818988808391897E77818384736B746A
6D6D7470696C6B5F4C56605D4E4C4D4247503C3F453B322E37372C2428272725211C1917
18150C040207090502030202020202020202020202020202020202010100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000139AABCB499878A84
7977767576746D6869686D736F6D65646A6C6C6C6B696E7076908D7472817F675E698A85
84878F86766361615B5B5F6569757E8C90868786888A887F8A90847A797E757C736E736F
6B6C726E6A706D5B535E6368575D57504D4F3D39393B363639312A27272628252B201913
0F120C060205040302030202030202020202020202020202020202010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000001F95BEA98D868680
7A77797478736A6A6A67696D6965656364656B6C6E6E6D6F6A7A7B70727C8D8676839080
86858381766763615E5A5B666C77808A888A878A8F94948A8D9186807B75797C817F7C72
6F6F6F6B6F79705757636A62494C53514845382B3E473237373330292425292F2B1B190D
0D100B040202020202020202020202020202020202020202020201010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000100000E7CBCB28D8A867F
7C7A7C79716E6969696766696462636665626B6B706F696968697078717B8799968B807E
8584827F7768696965616372767C80808287878C969FA19F928C83897F7C8683878C716E
7478716D757C5D5761605B463D4F543E38443C3249422F3236312D27202F2E1B0D0A0A09
090F0F040202020202020202020202020202020202020202020201000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010657A2AD918A8678
7A7C7979726E67676A666666626162676564656A6B6B67656462718D7B77808B88837F84
8585857E6E676969686A6D75767B7D7D7E7E828B969A9C978F8C888F7F878D858B917276
78796E6F7C6C595F615E5A4F4B5E392D3E54403E4232333237332C222931170402020309
080C0E050202020202020202020202020202020202020202020101000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000001388FA3918C8B76
787F7A78736B6766646562626263626662636163676867646363656C6E6F7A9190908B8B
8A8A7D6D676865636468747D7D7B7E8081807F8692999AA5A5958B9794A5958C9A907079
817C6D7377646464605F5755536538454D5E493A3239322A323324262E2505010102020B
190606020202020202020202020202020202020202020202010100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000001F7B94908E927F
747A827F756B67676466625E636662636160635F5F6665656463605E60637392A1B7A094
89806F6663656561636468737B78787A7D81808286808998908B8C92A0A99C99A682777F
8174696E6F614E575E595A5A60573D3B4E4E43323038253030312027210D010003050416
2A0B05030202020202020202020202020202020202020202020000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000010D608A92889289
74747A776F6B66696666635E60605D61605B5E5B5A62636564636D635C5B6583A8C2A488
776F6A67656564636061616C756A6A72767B82847B7F8D9F8F8A9096A6987C767D777881
7A7673756A43295966575A58453941303E40543D343C28261128221A1D140301070A0D29
2A0803030202020202020202020202020202020202020201010100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000001000000000548878D8A9497
7C7172726F6C656E6D67635F5E5E5E605C585959595E6063616678685E585F7A93B39B7C
6D696968666765636064686B6E6F6E7172777A7F81889596888A8F999C717C8284807D7E
7D7A75786B434D7A7C515553435B5B354C595822383B1317133D2C1817150E0D1412222D
130301010202020202020202020202020202020202020100000001000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000131838B8A979D
8E6F6C73716E656A696766615D5C5D5E5D5A585856585B5F616674665E586878839D967B
66646262646769676364656367757B727677787B838888818388909C8C7A918F8D8C887D
7E7F807664606D86654D5551535949485449332835290F292B35231612151D17161C2512
040102010101020202020202020202020202020202020100000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001177B89838990
8F746B7172706865666768645F5C5E5F635E59565555575E60657366626474787E8E8F78
686160605E6267686765615E60697672747477777B81807B828B90967F88938D8A8B8C7D
78756C6C65656551414C534F5152474D3F2A313430292A28102023180F171C0A16100902
000000010001010102020202020202030202010202010101000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100095E827D7E81
78736E6D7270696565666764615A595C615E5A575656555D60646D646673797D79848E7F
655F63645F5D62646665635F60646B70716C7370747977767E878D928687918D8B8B8C7E
736F685D615F604B5054473E4C4E4848392A34322728300E031828140B120D0911030101
000000000101010103020202020202020202020202010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100013C7D77797E
7472716C6C706A66666669635F5A58585C5E5B56555555595D6161636B777C817D7D837B
6A6766655F5D605E6060616164636773776E7171767C7D7C7F848B8E8E8F9A8B9091947B
76746A64615A5C555557464B514345453D332D292C32340C0722360C1007050F0A020201
000000000000000102010102020202010201030202010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000001B7979777B
7572736E696D6C67656667625C5B57585B5D5955565654565D62616675797B82756B6E6B
6B7669625E5F6161675F5B5D606062696D6C74767A7F807D7F878985868C6B609A9C8173
716C5B5857545250514C4550454139352E1F16293A3720111E3028090D0A0F1005020101
000000000000000000010102010202020202020101000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000001095F7E7375
7A726E6E6B6B6C67656868655D5C59585A575856575957586063686E797B7B7A72676C6E
7174666360626163675E585D605E626262636D74757A7878818A89847F7F5C7BB17F5D65
68605C55514F4D4C4845423E3B463727281E1E283230151A190E0B06080B080302010101
010101010100000000000201020102020203020100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000001000002397E7574
776F696C6F6C6B68676967645E5B5B5656555A5E605C5C627176788085827A7275727A7A
736D605D5C5E5E5E5C57575E696A726C686A717676827C7F838582807C786789A762626C
695F5A56534F4C4A43403E3B40362D2A222925232D200D11140C0C060603010101020000
000002010000000000010102010101020203010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000016737A75
7A6E696A76756D6D6B6C6969615C5F5A5654586065625D6476857F8A89888776797D7C79
6E69615B5C5B59575856575D70787D716B6B7073767B797A7A7D7F7F7B7365696B62696F
665D555454514C46413C3B393B2B372E1A28232124201118141008050A07010101010000
000000000000000000010100000101010101010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000006538877
746D69697379716E6F6F6D706561645C5552565F66635E5D677E7A808587827A7A817771
6A6A6762615F5E5954525C5E5F696E6D666A6A6D77746F73717679766B655D5C6470716B
5D585756525048423C383832353134211A2422212E260F08030504010708020406020000
010100000000000000000000000001010201010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000001278884
736E6A697176756C71716E6C6463645B5251545C65665E5A62788478767D7A7E7D78716A
6A6968706C5F605B57545964696C6D68616965676E66696E70706E615865605E6767565D
5B565452514F45393A3738303025251B242D2B2F3C16030204060A030104020403000101
010000000000000000000000000000010101000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000A5885
76706D68737B766C7072706A615F615D545354586167635D5C667D7A787B787C7A75726F
6C6B696D6E615F595855576777716B666567635F63737572727179706F6B696669625956
5B544D49474139383D38352E2C2B2A2B2E2D23190F050101050710080201010403020101
010000000000000000000000000000010101000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000101287B
7C796E6870847F6F6B6B6B68635E605F595453555B62645F5D5E6B76767A797A7A736C70
6C6A6A67635D5C585656575C64686F71706B6768706D6D716E6F7B766D66616468645E5F
5D584D48433E3F40413C362E2B2825261C1F13100C0E0B05091A1D0D0200010302020201
010000000000000000000000000001010100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010C5D
80786E6A6E7779706D6968635E5E615F5C555453585B5E616160657A726F717E7B797A7B
766E6A665E5D5B58565A5F6164676D6D6F6E6D72756F6A6E6B6F786F685B555A5D5B5A60
56534E48414048423B393330292627201D241814121E1C080A0B06020101010101010201
010101000000000000000000000001010100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000233
7A786D696D7172716B6665615C5B5D5E5A585A585857595B5F60667A746C70787A7B7C81
7D6F686461605C5B5C5F6362635F62626B67686C6C706E70737B7B715E5858595E5C6069
404B4946424150362A33322F2B252625251E161722200F02010202010101010101010101
010101010000000000000000010101000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000001000010
5F7B70686B6E6E6B656362615C5A5B5B595C645B59555758595D6278796E727378777781
88766D6A6962605C5857595A5D5D616267686566686965706D6D5D5C514A555D5A565A5F
414B444B46444B2B2E393927242429221C1F1A2121100502010406020101010101010101
010101010000010000000000010100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000003
36767369676B6C6765635E5A595A5958565769685A58565656585E808773747877787B7B
756F69696D6B62615F575756595E5E6364626066676463636056544F2D38546651565D56
393D404E4B473C323238241F24201C1C1C161415110A0202010304020101010100000101
010101010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000001
13607B72696A6964656860595658595B5556636C5E5B595555565C818A7A797B7B7A7975
73665B5D6565626C60595C5D5E5F5F5F5D5B5F61625C5A5D5D5357493960677C575C5B51
493E3C3B373B3A342F221B2123251E27160B070B13060101000101010101010101010101
010101010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
043676766E6E6A65646A665B58585A5B585A647073675F5B57565F7E8188817E7C757477
6D6157575D615E5F5B565D605A5F5D5C5F5B5C5A5858575B5B594F4A486C818247494241
3D333935323737342D1C212521211D1D0A0C0C1313030102010101010101010101010101
010101010101010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
01125B7572737168646368625E5B5C626663677881857C72695F648292997D7E7F817A78
6E5B54525860635D5A555F60565D575455565B585855555859574D4B4B647A58393F4344
453C393634353B301E1F251F181C140A0D0B0D120C020101010101010101010101010101
010101010101010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0002336A7374777168636666645F636E6D71707278848C92948786987F736E757D827B7C
685B514B4F5C616060575A5F54514F515457595A5755585957574D4C4A51534335414A45
423F3D4230343020202B201A15130E0E170D0F120D020101010101010101010101010101
010101010101010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000111536F76787B706565675F5D686D68797972777F82889596998F7571727274777F73
635A544D4C545B5E5B545D5B46464D50535C575759585655584F4A4746483F333244533B
3C3C3936252A2C2C2C2C1B1A1A1311151A150F0F07020101010101000101010101010101
010101010101010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000336677376787B6D6266625E686B666B7B6E71736F737D7D8384747A76747375736D
625756534D52545756545C504F5152535756515558585352524C4B48484C3A393C464F2A
393933302D2C393D2F211720191613101017080503010201010101010101010101010101
010101010101010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
00000114546E777675676163605C5D5B6868686E6C686A6C716F757078797278726E6765
605952504B4B4D555A5B5F53575A58545456545855565150504D4B46474B403D3E3E492F
3A3A342C27293629241E24261C221C070409020101010001010101010101010101010101
010101010101010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000032F637378736E65635F5C5957606D676E726B696B6C6863647474767A74746E60
5F5B55514B4A4C5258535B51575A595953555959545352514D4948464545413D3E404A2C
2E35291F252930231E1F160F14160A020208030102010101010100010101010101010101
010101010101010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010B496A77796F66625F5B57565A6560626C6B6D6B696E6C787171757475836C60
5E5D57514B47464B5263714D54524D4F5152545A514E4F4E4B4A48494A4641383D3F3A26
29312120212527181718080A0B0B0A020102020101010101010101010101010101010101
010101010101010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000002225B6E7A726461605C58565860605D62686A68676C6F6F6970726D69706361
615F5A524B45434853605B53514F4B4C4C4D50594D514D4B4E4C4C514C3E3D36322D2A29
27281D1D272F281612120C06050A09020201010101010101010101010101010101010101
010101010100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000063B65757A6E67655C595455595F5C5C65695F61646E716F737575645D5A60
614F5C584D46444951575B565A534F4D4B4D545343453A414F515556240F32362D2B2C29
24231C1C29241C1415121608060504020101010101010101010101010101010101010101
010101010100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001144F6C817C716C615B5756575A5C5D666964706268696E736E6E5B545256
5A5D765E4E47464B4D565A53535057545459594F463A35404237413A1517524C2B2D2C2B
282723242A291D1418161504020202020101010101010101010101010101010101010101
010101010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000002265C7CA1816D635E5A5556585C626565686D585C606C6B605F574E4E51
515562514A49494949565448544E5551564E48474A364347433F3F3929425F3A2A232A2B
27221E2D2C2C140A13140801010201010101010101010101010101010101010101010101
010101010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000010000083B679F967C68615B545051545A5F5F615D595D626B5E5F685F4E4A4C
4C4A4B4749484647484846454F4F4D4A4D4B4A4A4B3F4348464947402E31302A35282624
1F1B1E2C1C09030204070402010101010101010101010101010101010101010101010101
010101000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000001154C728D8E77675F56504E4E4E525756585F59585B545F695C4D4746
4544454345474343474A4648464948434647474B49474850575E543832312E3040391E20
1B1C1B200902020202030502010101010101010101010101010101010101010101010101
010101000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000032458767F776A5F57514E4F4C4A4B494C4E52514E53595D5A4D4542
3F3C3D3E3E423F3F4648474A464644414648464644403E4245493027332F2B2B403A2020
161C191B0E03020203020406010101010201010101010101010101010101010101010101
010100000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000010000000007355F716D675B575052504C4A49474442454542474F565E55493F
3A3839383B3E3C3D4245454748484C4E433C3C42413F3C3D3A4038363B29282735321D15
0712161A1605030403090F04010101010101010101010101010101010101010101010101
010100000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010F425D625F5A54524F514D4B494846403F3E3C3D424652545040
3A363637393F3D393C454544444448432F3437413F3D3A40483B3024231C26252B351A18
101112090F090A090C120902010101010101010101010101010101010202020201010101
020100000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000119495B5A5651504E4E4C4A494948403E3D3D3C3C3B4246433D
37333233363B423B3A3F424444434C3F393F3F3D3B3F4146391B1A202928252B3730121A
170A0A02070A040308060101010101010101010101010101010101010202010101010101
020000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000004254D54504C46484E4A45464647443F3F403D39383A3E403D
363432313031393C3F3C3E41454642332A3C393B3E3E38250E04051025261B1E22140E15
0F0A02010204030201020102010101010101010101010101010101010202010001010101
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001010001072F4D4F4E484A4F4E44424446413E3E3F3C3937383F4A4A
3B3534322C2D2E34393A3B3C3F41373336443339363F3E110307101122251109110C0B0A
0707030202030B0501010101010101010101010101010101010101020302010101010100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000B344A4C4B494C4A4340403F3D3C3D3D3B3A37363B4145
3F3936312C2A2A2E3437363939393B2F323536333140370F051A2A222030290A0A08070C
0B0D040201030D0501010101010102020101010101010101010202020202020101010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000010F384848464948433E3C3D3B39393A3A38373433363B
3B383934302B2A2E34363538383736313A3A312F2F3C301712191F171B4739080809110C
050404030202040201010100000102020101010201010101010202020202020201010100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010001133A4645464945403D3B3B38373536373533303438
3936353433332F2C3032333637353534352F2D2F30361D1A1919212C3C51250807050703
020204030101020201010101000102020202020201010102010202020202020201010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000002183A43434442413E393A39373636343332313536
363332313031302E2F30303237343432303337303533171816121F2D2F20070303020303
030203030201010202020101010102020202020201010102010202020101010101010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000041B393F403F3D3D3B3938363739363433333436
3432302F2E2D2E2D2C2B2C2F302F2F302C2E21182C241A1D161215120C06050302020102
020202020202020201010101010202020202020101010101020201020201010100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000031E383B3B3B3B3D38363435373B3834333232
3231302F2C2E2D2A282726292A32302F29251B1D202218191A160F0A0508060402020102
020202020202020202020202010202020202020101010101020202020100010100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000520373A383738393634323235373430302D
2D2D2B2B2A2A2A2A2827242323291623211F2121252A1316130E08060708050302020302
020202020202020202020303020202020202020101010101020202020201000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001000000000521353736353435322F3033302E2A2925
292A272527282624252322201E1F1D2E1A1C1B1C20180C120E0E07040404030202020202
020202020202020202020202020202020202020202020202020202020201010100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000051D3436323232312F2F2F2F2D2D2623
262725242223252323211F1F1E1E1E1F1C171617110F0F110C0B04040404030302020402
020202030202020202020202020202020202020202020202020202020201000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100051D323532302F2D2D2E2F2D2E2726
2525252322222221201F1E1D1D1D1C18151213100F10110B060604040403030702020202
020202020202020202020202020202020202020202020202020202020101000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000041C3133302C2A2C302F2D292624
232223222220201E1D1B1B191919171412100F0B0B0D0C05040705040202020302020202
020202020202020202020202020202020202020202020202020202020200000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000041A2E302B2A2A292C2B282421
2121201F1F1D1D1B1A181716151614110F0E0B0907060503020403030202020302020102
020202020202020202020202020202020202020203020202020202010100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000004162C2C2928252526252422
201F1E1D1B1A1A19181514141413120F0D0C090706050402020102030201020202020202
020202020202020202020202020203020101020302030203020201010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001000313282827252322222120
1F1D1C1B191818171614131312100F0D0B0A090605040302020203020202020202020202
020202020202020202020202020202020101010101020202020201000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000101021020252321201E1F1E
1C1B1A191516151313110E100D0B0C0A0807090806030203080402020102020202020202
020202020202020202020202020201010101010101010102020101010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000109222322201E1E1C
1B19181515141211100F0D0C0A070606050303030303040A0B0302030202020202020202
020202020202020202020202020201000101010102010101010100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000100000000000107141D1E1D1B1D
1B1813131212100D0C0B0A0908060504030302020203050A070302020202020202020202
020202020202020202020202020101000000000001020102010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010001030E181C1B18
19171312100D0D0C09090707090605020201010101020202020202020202020202020202
020202020202020202020202010100000000000000000201010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000109161819
151415100E0B0A0908060604050403020102010101030202020202020202020202020202
020202020202020202020202010100000000000000000003000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000001010000051019
11110F0D0C09070606040402020202020202020202020202020202020202020102020202
020202020202020202020202010000000000000000000000000101000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000030A
0D0C0B070605060404070602020202010202020202020202020202020202020202020202
020202020202020202020101000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001000000000001
020604030403030303080803020202010101010101020202020202020202020202020202
020202020202020202020201000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010104060704020101020202020202010101010101020202020202020202020202020202
020202020202020202020101000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000000000000
000100030303020101010203020202010101010101020202020202020202020202020202
020202020202020202020101000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001010101010102020202020202020202020203020202020202020202020202
020202020202020202010100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010000000000
000000000000000101010001020302020202020202020202020202020202020202020202
020202020202020202010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010101020202020202020202020202020202020202020202020202
020202020202020201010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000000000000
000000000000000000000101010102020202020202020202020202020202020202020202
020202020202020101000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010101010202020202020202020202020202020202020202
020202020202020100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000101010101020202020202020202020202020202020202
020202020202020100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000101010001020202020202020202020202020202
020202020202010100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010101010102020202020202020202020202
020202020202010100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010101010102020202020202020202
020202020201010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001020101010101020202020202
020202020201010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001010101010102020202
030303030201000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001010101010102
020202020201000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000001010101
010101010101000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000001
010101010101000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{232, 269},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003X00013B000`400?l00000o`00003oj?ooool0
0>Sooooo003Xooooo`00j?ooool00>Sooooo003Xooooo`00j?ooool00>Sooooo0005ooooom`00000
1oooool000Gooooog0000007ooooo`001OoooooL000000Oooooo0005ooooom`000001oooool000Go
oooog0000007ooooo`001OoooooL000000Oooooo0005ooooom`000001oooool000Gooooog0000007
ooooo`001OoooooL000000Oooooo0005ooooom`000001oooool000Gooooog0000007ooooo`001Ooo
oooL000000Oooooo0005ooooom`000001oooool000Gooooog0000007ooooo`001OoooooL000000Oo
oooo0005ooooom`000001oooool000Gooooog0000007ooooo`001OoooooL000000Oooooo0005oooo
om`000001oooool000Gooooog0000007ooooo`001Ooooon30000000300410@000000000000<00000
00<00@410000000000000P0000000`010@40000000410@1;000000Oooooo0005ooooofT0000000<0
0@41000000000000500000000`010@40000000410@040000000300410@0000000000058000001ooo
ool000GoooooL`0000000`010@4000000000000D0000000300410@00000000000140000000<00@41
000000000000>`000007ooooo`001Ooooome0000000300410@000000000000/0000000<00@410000
000000004@0000000`010@40000000000012000000Oooooo0005ooooof@0000000L00@4100000000
0000000000410@0000000@4100H000000P010@402@0000000@4100410@010@400`<300D51@071`L0
20P800/;2`0400`<30@02`/;00<030`<00/;2`0;2`/00P0;2`/01P061PH00P8200410@010@400000
00410Dd000001oooool000GoooooI00000000`010@400000000000020000000300410@0000000000
00800@4100d00P8200D51@092@T03`l?01@D500N7Qh0:RXZ03Lg=`13@d<0EeMG06QXJ01_Kfl0M7Ad
0080MgMg00@0MWIf07MgM`1cLg<0LW9b0`1fMWH03`1mOGd0PH6107moO`1lO7`0MWIf06UYJ@1EEED0
A4A402`/;00J6QX03Ph>00/;2`051@D00`<300410@19000000Oooooo0005ooooofD0000010010@40
50030`<030`<01LG5`0Y:BT0@d=305QHF01ZJVX0MGEe07inOP2<S8`0W9bL0:2PX02SXj<0/;2`0;fm
_@34a<@0`l?30;^k^`2j^[X0]kNg0P2f][H02P2e]KD0];Bd0;jn_P2j^[X0]KFe0;^k^`34a<@0_kno
0;Zj^P2e]KD20;Jf]P0=0:ZZZP2KVi/0S8b<07IfMP1cLg<0GemO04a<C00d=3@07AdM00h>3P0410@0
0P8200410@14000000Oooooo0005oooooed0000000<00@410000000000000P00000040010@4010@4
01<C4`0];Bd0ADE505aLG01^KVh0RHV909bLW02c/k<0_;bl0<71`@3=cLd0e]KF0=;BdP3@d=020=7A
d@0/0<O7a`33`l<0bLW90<_;b`3AdM40b<S80<K6aP30`<00^[Zj0;^k^`2h^;P0];Bd0<;2`P2l_;`0
^[Zj0;Vi^@2h^;P0][Jf0;Zj^P33`l<0/;2`0:j^[P2c/k<0];Bd0::RXP2QXJ40Z:RX0:b/[02^[Zh0
/;2`0:b/[02QXJ40S8b<06a/K01WIfL0HV9R05iNGP15ADD0:BTY00d=3@020P800@41000000010@43
0000000300410@000000000003H000001oooool000GoooooE`0000000`010@400000000000030000
00800@4101000`<300d=3@0S8b<0ATI606][J`2EUID0YjNW0:b/[02^[Zh0]kNg0<30`034a<@0d];B
0=[JfP3UiND0kno_0P3inOT02`3gmoL0l_;b0>CTi03EeMD0`l?30;Ng]`2j^[X0`<300<?3``2h^;P0
/[:b0080[Jf]00D0[:b/0:ZZZP2c/k<0YjNW0;6a/@020:f][@0>0:^[Z`2a/K40/[:b0:JVYP2OWil0
WYjN09fMW@2FUYH0X:2P0:ZZZP2VYZH0ZJVY0;Bd]02/[:`20:>SX`0<0:JVYP2QXJ40XJ6Q0:^[Z`2e
]KD0];Bd07UiN@1@D500<30`014A4@051@D00@410P0000001@010@4000000000000000000@4103@0
00001oooool000GoooooDP00000200410@L0000001/00@4100<30`0>3Ph0:RXZ05QHF02>SXh0/k>c
0;^k^`2c/k<0Zj^[0:ZZZP2`/;00];Bd0;bl_033`l<0bl_;0=CDe03Lg=`0hN7Q0>OWi`3QhN40eMGE
0<K6aP2m_Kd0][Jf0;Fe]@2a/K400P2/[:`20:VYZ@0<0:RXZ02VYZH0YZJV0:VYZ@2/[:`0YZJV0:FU
Y@2TY:@0[Jf]0:>SX`2WYjL0[:b/0P2_[jl03@2MWId0Vi^K09nOW`2KVi/0VIVI09ZJVP2MWId0Vi^K
0:BTY02k^k/0XZ:R09VIV@2KVi/00P2QXJ40102EUID0WYjN0:JVYP2ZZZX209^KV`0709FEU@1aLG40
CDe=02TY:@0@410010@400410@040000000300410@0000000000034000001oooool000GoooooE`00
00008P010@40000000<30`0;2`/092@T05MGE`2CTi<0_[jn0<?3``32`/80_[jn0;Fe]@2`/;00[:b/
0:NWY`2XZ:P0ZZZZ0;6a/@2ZZZX0X:2P0::RXP2SXj<0Y:BT0:>SX`2MWId0XJ6Q0::RXP2PX:00YjNW
0:b/[02h^;P0_Kfm0:j^[P2ZZZX20:BTY00[0:NWY`2b/[80/k>c0;Bd]02[Zj/0Y:BT0:JVYP2`/;00
YZJV0:2PX02VYZH0YjNW0:>SX`2GUiL0Xj>S0:BTY02/[:`0XJ6Q09FEU@2BTY80U9BD09ZJVP2TY:@0
V9RH08b<S02BTY80R8R808B4Q01`L700OWin08Z:RP2@T900RXZ:09FEU@2HV9P0U9BD092@T027QhL0
Lg=c04a<C00S8b<02PX:00820P0f000000Oooooo0005ooooodd0000000<00@410000000000001P00
00002P010@4010@401TI6@1:BTX0QhN70:j^[P35aLD0alO70;:b/P2SXj<209nOW`80XJ6Q00X0WinO
09FEU@2FUYH0X:2P09nOW`2GUiL0UIFE09JFUP2GUiL0Ti>C0P2?Shl08P2HV9P0XZ:R0:BTY02[Zj/0
Z:RX0;>c/`2`/;00/k>c0:f][@2VYZH0XJ6Q0:FUY@2d];@0Xj>S0:FUY@2RXZ80Z:RX09nOW`2UYJD0
Vi^K09ZJVP2LW9`0WYjN09RHV02CTi<0YjNW0;2`/02c/k<0Zj^[09RHV02?Shl0TI6A09>CT`23Ph<2
071`L00;07IfMP1bLW80GemO05mOG`1WIfL0LW9b07moO`1hN7P0PH6108F5Q@2;Rh/00P2=SHd0202F
UYH0SXj>079bLP1OGel0<S8b014A4@0410@00@411@0000000`010@4000000000000[000000Oooooo
0005ooooodd0000001@00@410000000000000@41000000010@40000000410@092@T0:RXZ06a/K02c
/k<0g=cL0=;BdP2i^KT0ZJVY09^KV`2@T900SXj>08n?S`80T92@00@0U9BD092@T02?Shl0TY:B0P2L
W9`08@2HV9P0UIFE09JFUP2IVIT0T92@08V9R@2ATI40XJ6Q0:RXZ02VYZH0Vi^K092@T02RXZ80UYJF
09FEU@2VYZH0VIVI096AT@2FUYH0[:b/0::RXP2FUYH0Vi^K0:ZZZP2OWil0XJ6Q0:2PX02OWil0VIVI
09:BTP2CTi<0VYZJ09nOW`020:6QX@0O09BDU02JVYX0TI6A08N7Q`26QXH0NWYj06a/K01[Jf/0LG5a
079bLP1aLG40J6QX06=SH`1PH600IfMW06QXJ01TI6@0K6a/07AdM01oOgl0R8R808>3P`26QXH0P820
08V9R@2<S8`0MGEe0410@00E5AD01@D500410@0a000000Oooooo0005oooooe80000001400@4100`<
300h>3P0OWin0;fm_@3IfMT0d=3@0;^k^`2WYjL0Vi^K08f=S@28R8P0QHF508R8R02;Rh/0S8b<08R8
R00308Z:RP0408^;R`2?Shl0Ti>C092@T080R8R801<0TI6A09VIV@2@T900SHf=09VIV@2XZ:P0YJFU
09FEU@2;Rh/0SXj>07moO`1mOGd0WYjN0:VYZ@2EUID0WYjN0:n_[`2c/k<0YjNW0080YZJV02/0Xj>S
09VIV@2CTi<0S8b<092@T02ATI40UiNG09RHV02<S8`0TY:B0:6QX@2@T900TY:B08R8R020P800Ogmo
07YjNP1`L700KFe]06YZJP1/K6`0KVi^06YZJP1UIFD0HF5Q06ATI01UIFD0HF5Q06EUI@1ZJVX0MGEe
07UiN@1lO7`0QhN708Z:RP26QXH0Ogmo08b<S021PH40H61P0492@P0P82002@T900800@41;P000007
ooooo`001OoooomA0000000A00820P0X:2P0SHf=0<k>cP3Bd]80_[jn0;Ng]`2NWYh0UiNG096AT@2;
Rh/0QXJ608>3P`20P800PX:208>3P`25QHD00P23Ph<05`21PH40PX:20820P01oOgl0PX:208F5Q@23
Ph<0QHF509BDU02OWil0XJ6Q09JFUP29RHT0W9bL0;6a/@2g]kL0W9bL0861P@1jNWX0Ph>30:BTY02Q
XJ40T92@0080ZZZZ00P0/K6a0:RXZ02QXJ40Y:BT09bLW02CTi<0Ph>30820P080QXJ60200Shn?09:B
TP2CTi<0TI6A09RHV02DU9@0Ti>C08f=S@24Q8@0OGem07QhN01bLW80Kfm_06YZJP1OGel0GUiN065Q
H@1VIVH0H61P05]KF`1MGEd0HV9R06a/K01fMWH0MgMg06i^KP1hN7P0Ng]k07MgM`1iNGT0LW9b07]k
N`80PX:200H0N7Qh06YZJP14A4@08R8R00X:2P010@4]000000Oooooo0005ooooodd0000001400@41
000000020P804Q8B04M7A`2d];@0h^;R0=7Ad@33`l<0YZJV096AT@2BTY80Ti>C08j>SP2?Shl0RXZ:
08J6QP0208:2PP80P8200P1lO7`07P1kNg/0N7Qh07=cL`1aLG40MgMg07emO@24Q8@0QhN708f=S@2I
VIT0Zj^[0::RXP2DU9@0W9bL0;fm_@3EeMD0^[Zj09jNWP2DU9@0UIFE0:>SX`2OWil0YZJV0:2PX02E
UID0VYZJ0:2PX02XZ:P0][Jf0:BTY080YJFU01/0Ti>C096AT@2DU9@0TY:B08j>SP2WYjL0WIfM09BD
U029RHT0SHf=09VIV@2VYZH0UiNG08>3P`29RHT0MGEe079bLP1TI6@0FUYJ05MGE`1RHV80GUiN05IF
EP1EEED0FUYJ065QH@1WIfL00P1ZJVX02@1/K6`0LG5a06YZJP1OGel0G5aL06][J`1_Kfl0N7Qh06e]
K@0206MWI`0406YZJP1;Bd/04Q8B00410B`000001oooool000GoooooAP0000000`010@4000000041
0@040000000I00820P0>3Ph0ADE50:2PX03MgMd0f=SH0<_;b`2b/[80XJ6Q09>CT`2BTY80T92@08^;
R`28R8P0QhN708J6QP24Q8@0PH6107emO@1fMWH0Lg=c079bLP1`L700M7Ad06m_K`0207MgM`0507If
MP1nOWh0QhN709FEU@2ZZZX00P2`/;007@2d];@0][Jf0:n_[`2k^k/0`l?30;fm_@2_[jl0ZJVY08f=
S@29RHT0VYZJ0:>SX`2IVIT0S8b<08V9R@2:RXX0WIfM0;2`/02SXj<0/K6a0;bl_02f][H0YZJV09fM
W@2?Shl0S8b<0;Ng]`2XZ:P0VYZJ0080Rh^;02@0Vi^K0:FUY@2NWYh0P82008>3P`24Q8@0LW9b06UY
J@1NGUh0H61P06QXJ01PH600F5QH04m?C`1<C4`0De=C05EEE@1IFET0HF5Q06a/K01cLg<0Kfm_071`
L01ZJVX0K6a/06YZJP1]KFd0FEUI06][J`1iNGT0K6a/05mOG`17AdL04a<C00D51@010@4200000003
00410@000000000002D000001oooool000GoooooB`00000030010@4020P803Hf=P2BTY80h>3P0?Wi
n@3/k>`0a<C40:n_[`2FUYH0T92@08n?S`80U9BD01P0QXJ607moO`1mOGd0OGem0861P@25QHD0PX:2
07UiN@1dM7@0L71`06i^KP1dM7@0Ogmo09fMW@2/[:`0Y:BT0:VYZ@2h^;P0^KVi0<C4a030`<00YjNW
0;>c/`3:b/X20<30`0040;no_`2f][H0[:b/0:n_[`80P82001d0TI6A08^;R`1lO7`0O7al08F5Q@2B
TY80R8R807YjNP1hN7P0UIFE0:b/[02d];@0Y:BT09^KV`2FUYH0VYZJ0:NWY`2ZZZX0Z:RX0:BTY02H
V9P0X:2P0::RXP2UYJD0XJ6Q092@T02;Rh/0MWIf06i^KP0206UYJ@0K06i^KP1YJFT0EeMG04m?C`17
AdL0ATI604E5A@18B4P0D51@05EEE@1OGel0Hf=S06][J`1QHF40D51@06MWI`1ZJVX0H61P07=cL`1_
Kfl0FUYJ065QH@1HF5P0B4Q802TY:@0<30`00`<302T000001oooool000GoooooA@0000000`010@40
0000000000020000000400410@0G5aL0Jf][0<o?c`80moOg00@0inOW0<71`@2RXZ80Vi^K0P2@T900
4P2>SXh0UYJF09RHV022PX80OGem07moO`23Ph<0QXJ608^;R`25QHD0NWYj07=cL`1`L700MGEe08R8
R02i^KT0`l?30<K6aP80b/[:01D0c<c<0;no_`3:b/X0d=3@0<71`@2l_;`0bl_;0<O7a`2a/K40ZZZZ
0:f][@2/[:`0[Zj^08j>SP1fMWH0LG5a07MgM`1]KFd0N7Qh096AT@28R8P00P1iNGT00`1kNg/0TY:B
09>CT`02092@T00X08n?S`2RXZ80YjNW0::RXP2_[jl0/;2`0:^[Z`2VYZH0ZJVY0;>c/`2[Zj/0Z:RX
0:2PX02ATI40Ogmo07]kN`1jNWX0N7Qh07=cL`1WIfL0EEEE04e=C@1<C4`0BDU904E5A@13@d<0ATI6
04a<C01>CTh0F5QH05UIF@1<C4`0E5AD06][J`1jNWX0K6a/06][J`1jNWX0HV9R05UIF@80Fe]K00D0
@d=303`l?00X:2P02`/;00410@0W000000Oooooo0005ooooodP0000000/00@4100T92@0g=cL0TI6A
0>3Ph03hn?P0j>SX0=7Ad@30`<00/k>c09ZJVP0209:BTP80Shn?03L0UYJF08n?S`1oOgl0Ogmo08F5
Q@23Ph<0P82007UiN@1dM7@0MGEe07MgM`22PX80XJ6Q0;:b/P3:b/X0a/K60<30`037alL0e=CD0<o?
c`36a/H0bl_;0<S8b036a/H0_kno0<K6aP2h^;P0UIFE08>3P`2BTY80/;2`0:n_[`2l_;`0WIfM0820
P021PH40MWIf07]kN`21PH40Q8B409^KV`2[Zj/0TY:B08R8R02ATI40SHf=0:>SX`2RXZ80[Zj^0:BT
Y02IVIT0UiNG09VIV@2RXZ80ZJVY0080YJFU02H0X:2P09fMW@2UYJD0UIFE07inOP21PH40Q8B408R8
R01iNGT0IfMW05IFEP1BDU80E5AD04];B`16ATH0@T920410@013@d<0ADE504Q8B01@D500CTi>06AT
I01bLW80MWIf075aL@1LG5`0Hf=S059BDP18B4P0GUiN05mOG`1ADE40ATI60410@00V9RH03Ph>0082
0P80000000<00@410000000000000P0000000`010@4000000000000L000000Oooooo0005ooooodL0
000001800`<301hN7P1YJFT0^[Zj0>[ZjP3jn_X0kno_0<_;b`2l_;`0][Jf0:b/[02FUYH0T92@08j>
SP27QhL0SXj>096AT@25QHD20820P01308>3P`1kNg/0MgMg07EeM@1gMgL0NWYj096AT@2c/k<0b<S8
0=7Ad@3GemL0dM7A0<O7a`34a<@0d=3@0<W9b@3:b/X0bLW90<G5a@2k^k/0];Bd0:>SX`2IVIT0WIfM
0:2PX02TY:@0[Jf]0;2`/02][Jd0Xj>S0:BTY02HV9P0Ph>308F5Q@2@T900U9BD09VIV@2VYZH0QhN7
08F5Q@2OWil0WYjN0:RXZ02KVi/0YJFU09jNWP2FUYH0W9bL09fMW@2@T900TI6A09FEU@2IVIT0Ti>C
092@T02EUID0R8R80820P028R8P0PX:20861P@1lO7`0K6a/05eMG@1TI6@0Cdm?04Y:BP0204M7A`0J
04E5A@12@T80?clo0410@015ADD0CDe=069RHP1/K6`0IfMW055AD@1BDU80DE5A059BDP1<C4`0FUYJ
05=CD`1EEED0CDe=03@d=00G5aL05ADE01`L700>3Ph00@41000000010@4R000000Oooooo0005oooo
od@000000P010@404`0>3Ph0AdM709RHV03Hf=P0m?Cd0?Shn03/k>`0eMGE0<?3``2m_Kd0WIfM096A
T@2EUID0SHf=08R8R02=SHd0TY:B08f=S@26QXH00P21PH403020P800OWin07emO@1lO7`0OWin09BD
U031`L40eMGE0=WIf@3Bd]80cLg=0<W9b@80aLG501X0alO70;fm_@31`L40b<S80<K6aP34a<@0^[Zj
0;2`/02ZZZX0Xj>S0:FUY@2/[:`0][Jf0;6a/@2/[:`0YjNW0;Rh^02^[Zh0YjNW0:f][@2c/k<0/K6a
0::RXP2@T900Ti>C09bLW0<0YZJV03@0W9bL09fMW@2MWId0VYZJ0:NWY`2MWId0R8R808n?S`2ATI40
R8R80820P01nOWh0Shn?08^;R`1oOgl0KVi^065QH@1WIfL0KVi^06YZJP1_Kfl0JVYZ05YJFP1LG5`0
EUIF05YJFP1GEeL0BTY:0451@@14A4@0CDe=051@D01OGel0Jf][05eMG@1SHf<0IVIV06ATI01LG5`0
BDU9051@D01BDU80C4a<04m?C`0k>c/09BDU01TI6@0Y:BT08b<S00H61P020P800@418P000007oooo
o`001Ooooom40000000C00@4100N7Qh0K6a/0;Zj^P3Shn<0moOg0??cl`3Ng]h0c/k>0=?Cd`3;bl/0
Xj>S08j>SP2;Rh/0RXZ:08J6QP2>SXh0V9RH09>CT`0208N7Q`0D08V9R@27QhL0RHV908R8R029RHT0
UYJF0:^[Z`33`l<0d];B0=SHf03MgMd0d=3@0<W9b@32`/80_kno0<G5a@34a<@0^[Zj0;>c/`33`l<2
0;^k^`0A0;Fe]@2c/k<0[:b/09nOW`2QXJ40XZ:R0;Fe]@2ZZZX0_[jn0:j^[P2`/;00[Jf]0:n_[`2T
Y:@0[:b/0;2`/02h^;P00P2^[Zh04`2SXj<0YJFU09bLW02FUYH0XJ6Q09jNWP2HV9P0W9bL09ZJVP2B
TY80UYJF09RHV02DU9@0RXZ:07moO`1_Kfl0QhN708f=S@1mOGd00P1LG5`06`1MGEd0GemO05mOG`1^
KVh0IFEU05iNGP1RHV80FUYJ065QH@1OGel0FEUI059BDP19BDT0De=C05]KF`1TI6@0Hf=S05ADE01K
Fe/0FEUI04M7A`1IFET0<c<c0410@01>CTh0DE5A05UIF@0203Ph>006030`<00U9BD09BDU01TI6@0L
71`02`/;8P000007ooooo`001Ooooolm0000000S00410@000000000000410@0000000@4100P8200i
>CT0SXj>0<k>cP3alO40nOWi0>g]k@3Rh^80f=SH0<W9b@31`L40[Zj^09bLW02?Shl0T92@08^;R`24
Q8@0U9BD0:6QX@2PX:00Vi^K09RHV02CTi<0Shn?09NGU`2KVi/0Z:RX0<71`@3AdM400P3EeMD02`3L
g=`0f=SH0<W9b@2l_;`0^k^k0;:b/P2d];@0Y:BT0:ZZZP2RXZ80V9RH0080Rh^;01`0TI6A08j>SP2@
T900X:2P09VIV@2HV9P0YZJV0:b/[038b<P0_kno0;jn_P2b/[80[:b/08F5Q@22PX80Ti>C0;Bd]030
`<00ZJVY0:BTY02YZJT0W9bL09FEU@2FUYH0UiNG09:BTP2GUiL0ZZZZ0P2RXZ809@2PX:00SXj>08j>
SP28R8P0M7Ad07UiN@1mOGd0OWin06ATI01SHf<0GUiN061PH01GEeL0F5QH071`L01NGUh0GEeM05QH
F01MGEd0Fe]K065QH@1RHV80EEEE05MGE`1WIfL0FUYJ055AD@1BDU80F5QH05ADE01=CDd0EUIF04=3
@`11@D40Cdm?05QHF00n?Sh00P13@d<01`12@T80<S8b02@T900T92@0:2PX01XJ6P030`<00`000003
00410A/000001oooool000Gooooo>`0000000`010@400000000000020000000;00410@020P805QHF
05eMG@2YZJT0g=cL0?Ogm`3jn_X0k^k^0=kNgP3MgMd00P3Hf=P07@3Bd]80_kno0;6a/@2PX:00[Jf]
0:JVYP2BTY80V9RH0:b/[02j^[X0`l?30:RXZ02CTi<0UYJF0::RXP2f][H0aLG50=CDe03Ng]h0g=cL
0=[JfP3IfMT0emOG0<;2`P2WYjL0Ti>C08^;R`24Q8@0P8200080PX:200D0OWin07QhN01fMWH0MgMg
07AdM002075aL@0J07QhN01oOgl0SHf=09^KV`2f][H0]kNg0:j^[P2PX:00YjNW092@T02=SHd0UiNG
0;Jf]P2n_[h0][Jf0;2`/02a/K40[Jf]0:b/[02NWYh0WinO09ZJVP2EUID0XJ6Q092@T027QhL208R8
R00D08b<S023Ph<0NWYj06][J`1YJFT0Kfm_06YZJP1_Kfl0Lg=c05iNGP1BDU80E5AD07AdM01RHV80
G5aL04i>CP1@D500Fe]K06UYJ@1XJ6P205aLG00G06QXJ01IFET0Cdm?04m?C`1EEED0HV9R04a<C018
B4P0D51@04E5A@1CDe<0GUiN05MGE`1?Cdl0@T9202`/;00g=cL08B4Q01TI6@0S8b<07AdM018B4P0:
2PX080000007ooooo`001Ooooolo0000000I00410@0I6AT0LG5a0;Fe]@3GemL0jNWY0?Cdm03^k^h0
j>SX0>7Qh@3AdM40c<c<0;Vi^@2^[Zh0[Jf]0:n_[`2XZ:P0/;2`0;>c/`2_[jl0Zj^[0;Vi^@2f][H0
/K6a0:f][@020::RXP0>0;:b/P38b<P0fMWI0=gMg@3Shn<0iNGU0=WIf@3Fe]H0d=3@0;jn_P2PX:00
Q8B407UiN@1gMgL207QhN00U07EeM@1bLW80M7Ad07=cL`1`L700KVi^06m_K`1ZJVX0J6QX06IVIP1Y
JFT0Kfm_08^;R`2UYJD0T92@09FEU@2=SHd0TI6A08b<S02LW9`0WinO0:n_[`2j^[X0_Kfm0;:b/P2c
/k<0][Jf09bLW02KVi/0WIfM09:BTP25QHD0Kfm_075aL@1`L700M7Ad079bLP0207emO@0607UiN@1Z
JVX0GEeM05YJFP1FEUH0FUYJ0P1KFe/0701JFUX0Fe]K05iNGP1CDe<0DE5A04M7A`19BDT0FUYJ07Ad
M01aLG40FUYJ065QH@1VIVH0Hf=S05YJFP1ADE40C4a<05MGE`1IFET0@T9204m?C`1>CTh0F5QH059B
DP1EEED0@41003Ti>@0J6QX201`L700901lO7`0U9BD09BDU01dM7@0I6AT07AdM010@40020P800@41
01`000001oooool000Gooooo?P0000009`030`<08b<S0:NWY`3]kNd0lO7a0>g]k@3/k>`0iNGU0>KV
iP3UiND0e]KF0<K6aP2QXJ40Ti>C09NGU`2BTY80VYZJ09NGU`2IVIT0XZ:R0:ZZZP2WYjL0Xj>S09^K
V`2DU9@0VIVI0:n_[`3@d=00inOW0>g]k@3UiND0h>3P0>CTi03Jf]X0alO70;Bd]02k^k/0XZ:R08:2
PP0207emO@0507moO`1lO7`0N7Qh079bLP1`L7000P1bLW80>@1_Kfl0JVYZ06YZJP1YJFT0IVIV06MW
I`1VIVH0JVYZ06][J`1gMgL0LW9b075aL@1^KVh0N7Qh07IfMP26QXH0UIFE0:VYZ@2b/[80[Zj^0;Jf
]P2d];@0[Zj^0:JVYP2OWil0S8b<07alO01`L700MgMg06i^KP1jNWX0Q8B406YZJP1LG5`0LW9b07Ee
M@1UIFD0Fe]K05UIF@1?Cdl0BDU904e=C@1>CTh0BDU904E5A@11@D40@T9204A4A019BDT0Bd];04a<
C01HF5P0EEEE04Y:BP15ADD0Fe]K065QH@0205EEE@0604m?C`1;Bd/0A4A40410@013@d<0?clo0P1@
D5003`1GEeL0@T9204Q8B00X:2P07QhN020P800c<c<0=3@d01lO7`0=3@d04Q8B024Q8@0a<C403Ph>
0000000200410AX000001oooool000Gooooo?@0000003`061PH0@D510;2`/03Xj>P0m?Cd0>o_k`3Z
j^X0iNGU0>SXj03Ng]h0bl_;0:RXZ02FUYH0QXJ608R8R00209BDU00O08f=S@29RHT0SHf=09JFUP2O
Wil0Y:BT09fMW@2KVi/0YZJV0<30`03GemL0i^KV0>c/k03_knl0k>c/0>OWi`3Lg=`0`/;20:b/[02P
X:00Xj>S09:BTP1mOGd0NGUi07]kN`1nOWh0Ogmo07QhN01dM7@0LW9b075aL@0206a/K00506QXJ01T
I6@0IFEU06=SH`1VIVH00P1RHV809@1UIFD0KVi^06UYJ@1WIfL0H61P065QH@1gMgL0Ti>C09ZJVP2S
Xj<0/;2`0:VYZ@2c/k<0]KFe0;:b/P2_[jl0Xj>S08Z:RP1fMWH0MgMg08:2PP1mOGd0PX:208f=S@1l
O7`0MgMg0820P01aLG40IfMW05aLG01FEUH0CTi>04M7A`19BDT0Bd];04I6AP15ADD00P13@d<03P10
@400@d=304U9B@14A4@0ADE504M7A`1;Bd/0C4a<05IFEP1MGEd0CDe=04];B`1>CTh0BDU90P11@D40
4P14A4@0<c<c04A4A01ADE40CTi>0451@@15ADD0;bl_02DU9@0W9bL0;bl_04Q8B00/;2`02`/;01DE
5@0<30`0410@00d=3@800@416`000007ooooo`001Ooooolj0000000`00410@00000030`<05=CD`39
bLT0k^k^0?3`l03alO40jn_[0>OWi`3[jn/0i>CT0<;2`P2QXJ40QhN707inOP1oOgl0S8b<092@T02:
RXX0R8R808N7Q`2:RXX0WinO0:BTY02WYjL0[:b/0:>SX`2[Zj/0a/K60=?Cd`3Ti>@0lO7a0>k^kP3c
lo<0jNWY0=KFeP2`/;00X:2P09>CT`2:RXX0PX:207inOP1dM7@0MWIf07alO01nOWh0MWIf0`1bLW80
:P1/K6`0JVYZ06EUI@1UIFD0Hf=S065QH@1OGel0GUiN06=SH`1XJ6P0JVYZ05iNGP1OGel0G5aL05iN
GP1lO7`0S8b<0:6QX@2OWil0WIfM0:FUY@2NWYh0Z:RX0;Rh^02b/[80UYJF092@T02=SHd0R8R80861
P@1iNGT0O7al08n?S`2>SXh0QHF507inOP1bLW80L71`06EUI@1EEED0E5AD04e=C@80B4Q800`0ATI6
04Q8B017AdL0AdM704I6AP14A4@0ADE503hn?P0l?3`0?Cdm0410@012@T8204Q8B00J04U9B@17AdL0
A4A40410@00o?cl0ADE50451@@0i>CT0@41004e=C@14A4@0@T9204];B`0Z:RX08b<S02/[:`0W9bL0
<C4a02TY:@0?3`l0820P010@400<30`01PH600820P010@4K000000Oooooo0005ooooocX0000002l0
0@4101<C4`1bLW80clo?0>CTi03^k^h0lO7a0>OWi`3Rh^80inOW0=gMg@2_[jl0TI6A08J6QP22PX80
Ogmo08:2PP27QhL0T92@096AT@2DU9@0WIfM0:>SX`2o_kl0ZZZZ0:RXZ02^[Zh0[:b/0;6a/@2o_kl0
clo?0>c/k03alO40kNg]0?Gem@3Ng]h0aLG50:^[Z`2IVIT0SHf=08F5Q@22PX80PH6107IfMP1dM7@0
MWIf07EeM@02075aL@80LW9b00D0L71`06i^KP1[Jf/0IFEU069RHP02061PH00;065QH@1VIVH0IVIV
05iNGP1OGel0J6QX065QH@1NGUh0MGEe09jNWP2XZ:P00`2NWYh0202BTY80UiNG0;Jf]P30`<00XZ:R
09FEU@2BTY80QXJ60P1nOWh02@26QXH0Rh^;08:2PP1oOgl0QXJ607AdM01_Kfl0H61P04i>CP02051@
D00<04e=C@1CDe<0De=C04];B`1=CDd0F5QH059BDP1<C4`0BDU904=3@`0l?3`0>c/k0`11@D401013
@d<0ATI604I6AP19BDT204A4A0<0ATI600/0@d=3051@D00f=SH0@T9205MGE`0];Bd0;2`/02/[:`0J
6QX07alO01LG5`0200X:2P8020P800<01@D500@410020P806`000007ooooo`001Ooooolf0000000S
00410@000000000000410@0J6QX0QHF50=KFeP3De=@0emOG0>k^kP3emOD0l_;b0>o_k`3YjNT0a/K6
09:BTP29RHT0S8b<08J6QP25QHD0P82007inOP2;Rh/0X:2P0:6QX@2RXZ80]KFe0<?3``2FUYH0Shn?
0:2PX02i^KT0bl_;0<g=c@3WinL00P3kno/02P3emOD0k^k^0<W9b@2h^;P0ZJVY09BDU029RHT0QXJ6
08B4Q01mOGd207YjNP0=07UiN@1eMGD0Lg=c079bLP1`L700LG5a079bLP1aLG40Kfm_06QXJ01WIfL0
IVIV069RHP02065QH@0F06=SH`1KFe/0GEeM06m_K`1/K6`0Jf][07AdM02GUiL0YZJV092@T02CTi<0
WYjN08R8R02BTY80[jn_0;Zj^P2WYjL0WinO09FEU@27QhL0Ogmo08Z:RP80QHF50100P8200861P@2D
U9@0Ng]k06YZJP1DE5@0Bd];04a<C01>CTh0DE5A05]KF`1OGel0E5AD05iNGP1UIFD0Cdm?0P14A4@0
0`1=CDd0ATI60410@00204A4A00K03`l?00o?cl0@D5104E5A@1:BTX0Bd];03dm?@0a<C40A4A404i>
CP0i>CT0>SXj02d];@0n?Sh0Cdm?02DU9@0@41007AdM01hN7P0/;2`06a/K01HF5P0?3`l03Ph>00H6
1P0410@00`<300<00@416@000007ooooo`001Ooooolh0000000[00410@0P8200UiNG0>3Ph03@d=00
bLW90=?Cd`3Zj^X0moOg0?Shn03Ogml0^KVi09^KV`2<S8`0Rh^;08n?S`29RHT0P82007UiN@1fMWH0
Ng]k08Z:RP2=SHd0P82009>CT`2@T900Q8B40:b/[030`<00bLW90=_Kf`3Shn<0moOg0?gmo@3clo<0
k^k^0=_Kf`2n_[h0alO70;fm_@2NWYh0TY:B08V9R@0208F5Q@0?0820P01kNg/0Ng]k07UiN@1eMGD0
Lg=c075aL@1_Kfl0KFe]06m_K`1aLG40JVYZ06QXJ01YJFT0HF5Q0080HV9R00D0Hf=S05eMG@1KFe/0
IFEU06e]K@020820P00A08j>SP2UYJD0RXZ:08b<S02=SHd0RXZ:09fMW@2WYjL0/k>c09VIV@2@T900
X:2P09JFUP2?Shl0TI6A09>CT`2?Shl00P2;Rh/05@28R8P0Ph>307MgM`1SHf<0De=C059BDP1@D500
EEEE055AD@1FEUH0HF5Q06YZJP1aLG40Cdm?0492@P10@400AdM705=CD`13@d<0@41004M7A`0204=3
@`0H0451@@0o?cl0ATI604=3@`10@400<C4a04E5A@17AdL0?3`l02l_;`0g=cL0?3`l03/k>`0e=CD0
7QhN02XZ:P0n?Sh092@T01PH600Q8B4051@D00h>3P0=3@d01PH60P020P8200410AT000001oooool0
00Gooooo=`0000003`020P809RHV0::RXP3[jn/0eMGE0<G5a@34a<@0dM7A0>3Ph03Vi^H0h^;R0:ZZ
ZP2BTY80U9BD08n?S`0208Z:RP0407emO@1gMgL0N7Qh07QhN080NWYj01`0MgMg07=cL`1cLg<0L71`
09>CT`31`L40`/;20<K6aP3Bd]80iNGU0?Win@3lo?`0mOGe0?;blP3?cll0`l?30>7Qh@3Bd]80ZZZZ
09JFUP2=SHd0QhN708B4Q020P800Ogmo07inOP1iNGT0MWIf0P1eMGD03@1bLW80LG5a06m_K`1_Kfl0
Jf][06UYJ@1UIFD0HV9R06IVIP1ZJVX0IVIV06EUI@1^KVh00P1kNg/0@02DU9@0UYJF09>CT`2RXZ80
U9BD09FEU@2?Shl0Vi^K0:2PX02ZZZX0Z:RX096AT@2BTY80Xj>S09nOW`2DU9@0RXZ:09fMW@2PX:00
T92@09:BTP24Q8@0PX:208B4Q01iNGT0K6a/06ATI01JFUX0G5aL06QXJ01UIFD0Fe]K069RHP1jNWX0
LG5a05YJFP1HF5P0GemO06i^KP1@D500BDU904Y:BP19BDT0A4A40410@00m?Cd0>SXj0451@@1CDe<0
AdM704e=C@18B4P0<S8b01`L700];Bd0<30`03Hf=P0`<30092@T01`L700n?Sh08B4Q018B4P0K6a/2
01LG5`0301TI6@061PH00`<300800P8200<0000000410@010@405`000007ooooo`001Ooooolf0000
000=00820P0W9bL0Z:RX0>k^kP3MgMd0alO70;Ng]`2TY:@0[Zj^0:n_[`2c/k<0[Zj^08b<S002092@
T00>08F5Q@1nOWh0NWYj075aL@1dM7@0Ogmo07inOP1jNWX0PH6107YjNP1dM7@0MGEe08V9R@2g]kL2
0<O7a`030<S8b03Bd]80jn_[0080o?cl00/0oOgm0?Shn03Jf]X0dm?C0<c<c030`<00XJ6Q08f=S@21
PH40P82007emO@0207inOP0=07alO01hN7P0MgMg07YjNP1lO7`0NGUi07QhN01dM7@0Lg=c07EeM@1d
M7@0KVi^06YZJP0306a/K00807MgM`2VYZH0SXj>07moO`1lO7`0PX:208>3P`29RHT209VIV@05096A
T@2OWil0YJFU0:ZZZP2QXJ400P2HV9P0=P2EUID0U9BD08n?S`2:RXX0UYJF09VIV@2:RXX0WIfM08F5
Q@1mOGd0PH6108Z:RP21PH40NWYj07UiN@1mOGd0M7Ad06UYJ@1TI6@0GemO06][J`1kNg/0OWin08B4
Q02<S8`0MGEe05]KF`1DE5@0D51@04i>CP17AdL0A4A404=3@`11@D40ADE504U9B@1:BTX0@41003Lg
=`0Z:RX06a/K02l_;`0l?3`0?Cdm02/[:`0T92@05QHF02PX:00[:b/03Ph>01<C4`0A4A405aLG014A
4@800`<30`020P800`010@4000000000000F000000Oooooo0005oooooc@000000P010@408`0Z:RX0
ZZZZ0>[ZjP3IfMT0_kno0:n_[`2NWYh0UIFE09BDU02BTY80U9BD08b<S021PH40Ogmo07inOP20P800
NGUi07IfMP1dM7@0MWIf08R8R01kNg/0MWIf07alO01iNGT0QhN70:RXZ02k^k/0b<S80<c<c039bLT0
alO70=GEe@3_knl0oOgm0080o_kn0100o?cl0?3`l03@d=00_[jn0;Bd]02RXZ80Ti>C08^;R`26QXH0
Ph>30820P021PH40Ph>30820P021PH40P8200P22PX80>P1kNg/0MgMg07AdM01fMWH0LW9b06i^KP1`
L700M7Ad07alO01oOgl0OGem09RHV024Q8@0J6QX07QhN02GUiL0Shn?08V9R@2<S8`0YJFU09jNWP2V
YZH0Xj>S0:NWY`2RXZ80VYZJ09>CT`2GUiL0UIFE09NGU`2MWId0V9RH09bLW02FUYH0VYZJ08n?S`20
P800PX:208b<S01nOWh0Ogmo08J6QP20P800Jf][06IVIP1aLG40IfMW06UYJ@1cLg<0NWYj08Z:RP25
QHD0OGem06i^KP1QHF40F5QH05UIF@1BDU8204a<C00G04];B`18B4P0C4a<04Q8B00/;2`0:2PX02XZ
:P0b<S80?clo04];B`15ADD0:RXZ01lO7`0M7Ad08b<S02l_;`0C4a<03Ph>01PH600L71`04a<C00P8
20030`<00P020P8200410AP000001oooool000Gooooo=00000005@020P809bLW0:VYZ@3WinL0c/k>
0;^k^`2VYZH0X:2P09FEU@2>SXh0TI6A09:BTP2=SHd0QhN707moO`1eMGD0LW9b07=cL`1bLW80L71`
075aL@0207AdM00S06e]K@1ZJVX0KVi^08F5Q@2UYJD0_[jn0<;2`P3=cLd0b/[:0<S8b03?cll0inOW
0?_kn`3moOd0no_k0?knoP3fm_H0jNWY0<S8b030`<00/[:b09jNWP2ATI40T92@08Z:RP27QhL0QHF5
0861P@25QHD0Q8B408V9R@28R8P0RXZ:08F5Q@1oOgl00P1jNWX05P1iNGT0Lg=c075aL@1fMWH0TI6A
09VIV@2OWil0RHV908^;R`1cLg<0IVIV07QhN02KVi/0Shn?08^;R`2HV9P0Xj>S0:2PX02RXZ80YJFU
09nOW`2CTi<209FEU@0`09RHV02LW9`0X:2P0:BTY02WYjL0Z:RX0::RXP2MWId0W9bL08:2PP1kNg/0
RXZ:08>3P`22PX80QXJ60820P01dM7@0Ng]k08Z:RP1_Kfl0JVYZ06][J`1WIfL0MGEe0820P01mOGd0
E5AD04i>CP1HF5P0GUiN059BDP1;Bd/0C4a<04i>CP16ATH0>SXj02TY:@0b<S80>CTi02h^;P0W9bL0
@T9203hn?P0d=3@08b<S00X:2P0M7Ad08R8R0`0L71`01@0I6AT0410@01<C4`0?3`l01PH600<00P82
00<00@410000000000005P000007ooooo`001Ooooolc0000000D00410@0V9RH0Z:RX0>g]k@3@d=00
^[Zj0:f][@2JVYX0V9RH09BDU02CTi<0VIVI096AT@29RHT0Ogmo07]kN`1gMgL0LG5a06m_K`1^KVh2
06m_K`0@071`L01[Jf/0IFEU06IVIP1jNWX0Y:BT0;Ng]`2d];@0`<300=3@d03;bl/0d];B0>KViP3i
nOT0oOgm0?clo080moOg00T0m_Kf0>GUi@3Cdm<0`/;20:FUY@2<S8`0RXZ:08N7Q`28R8P00P2:RXX2
0861P@0@07emO@1oOgl0Ph>308F5Q@1oOgl0N7Qh07AdM01eMGD0NWYj07alO01iNGT0QhN70::RXP2Y
ZJT0[jn_0:FUY@80QXJ601<0Shn?08j>SP2>SXh0T92@096AT@2EUID0XJ6Q09bLW02RXZ80XJ6Q09RH
V02@T900TI6A09ZJVP2PX:00WIfM0:6QX@2RXZ80Xj>S0080/;2`0380[:b/09NGU`21PH40PX:208j>
SP27QhL0NGUi08B4Q01eMGD0OWin09RHV02LW9`0OWin06YZJP1WIfL0HF5Q05iNGP1YJFT0J6QX03lo
?`18B4P0DE5A06QXJ01NGUh0BTY:04Q8B017AdL0@T9203lo?`0c<c<0@T9203`l?00U9BD0:BTY069R
HP19BDT0?3`l01/K6`061PH08R8R0492@P0I6AT06QXJ01lO7`0820P010@400l?3`0C4a<01PH600<3
0`800P8200<00@410000000000005P000007ooooo`001Ooooolb0000000900410@0P8200XJ6Q0?7a
l@3Ti>@0d=3@0;^k^`2LW9`0Shn?0080SHf=00/0SXj>08Z:RP26QXH0OWin07]kN`1jNWX0MWIf07Ad
M01bLW80Kfm_06][J`0206e]K@0H06a/K01WIfL0Jf][08V9R@2`/;00]KFe0;Rh^033`l<0alO70<c<
c03Ogml0moOg0?gmo@3inOT0moOg0>[ZjP3Ph>00h^;R0=cLg03De=@0b<S80:b/[02DU9@0R8R80P27
QhL0302:RXX0Ti>C08V9R@23Ph<0O7al07inOP1oOgl0PX:207]kN`1cLg<0N7Qh0861P@<0P82000T0
R8R809NGU`2QXJ40[Zj^0<c<c02DU9@0UIFE0;Fe]@2VYZH00P2LW9`0;@2FUYH0WIfM09nOW`2WYjL0
/;2`0:ZZZP2OWil0V9RH08b<S02FUYH0XZ:R09VIV@2SXj<0UYJF08N7Q`2ZZZX0_kno09fMW@21PH40
Ogmo08N7Q`23Ph<0R8R807inOP23Ph<0Q8B407UiN@1[Jf/0JFUY07YjNP1XJ6P0IFEU06MWI`1RHV80
I6AT065QH@1DE5@0D51@05UIF@1YJFT0IFEU04E5A@14A4@0ADE504=3@`0304E5A@0B0410@00X:2P0
<S8b04M7A`0l?3`0ADE501TI6@051@D07AdM03Ph>00>3Ph04A4A01lO7`0;2`/00`<300H61P071`L0
0`<30`020P800`010@4000000000000F000000Oooooo0005ooooobh0000000l00@41000000000000
0@4101TI6@2GUiL0lo?c0?7al@3UiND0b/[:0:b/[02DU9@0S8b<08R8R023Ph<00`24Q8@01P1lO7`0
NGUi07MgM`1cLg<0M7Ad06m_K`80JVYZ02T0K6a/071`L01]KFd0IfMW06a/K021PH40Zj^[0;^k^`32
`/80a<C40<O7a`3Ph>00m_Kf0?clo03fm_H0j^[Z0>?Sh`3Lg=`0e=CD0=;BdP3Cdm<0eMGE0<O7a`31
`L40[jn_09bLW02PX:00UYJF09BDU02a/K40XJ6Q08j>SP28R8P0RXZ:09:BTP2JVYX0PX:207MgM`27
QhL0TY:B08R8R00208V9R@0<08j>SP2DU9@0UYJF0;2`/036a/H0WYjN09JFUP2ZZZX0[Jf]0::RXP2W
YjL0YJFU0P2YZJT0202e]KD0/K6a0:VYZ@2LW9`0T92@08R8R02BTY80Vi^K0P2NWYh01P24Q8@0QXJ6
0:BTY02k^k/0[Jf]08B4Q080QhN700<0P82008R8R02;Rh/00P27QhL02P1TI6@0FUYJ05YJFP1gMgL0
L71`06EUI@1YJFT0Hf=S05aLG01MGEd205]KF`0=061PH01VIVH0DU9B0451@@14A4@0ATI60451@@0n
?Sh0?clo03`l?012@T80=SHf03/k>`0203Lg=`0>04Y:BP0Z:RX03@d=01LG5`0h>3P051@D010@400I
6AT05ADE00D51@030`<01`L700@410030`<200820P800@415`000007ooooo`001Oooool^0000000[
00820P0000000@41018B4P28R8P0l?3`0?[jnP3fm_H0jn_[0:n_[`2CTi<0SHf=08J6QP22PX80Ph>3
08:2PP26QXH0PH6107QhN01gMgL0Lg=c079bLP1`L700KFe]06a/K01aLG40MGEe07=cL`1]KFd0L71`
07EeM@23Ph<0[jn_0<;2`P34a<@0aLG50=CDe03fm_H0moOg0?7al@3Vi^H0fMWI0=KFeP020<k>cP0F
0<W9b@3;bl/0c/k>0<O7a`2m_Kd0Zj^[0;6a/@34a<@0[Jf]0;Fe]@3Fe]H0aLG50;Bd]02][Jd0WYjN
0:VYZ@2d];@0WYjN092@T02EUID0Y:BT09nOW`80YZJV00<0V9RH08^;R`2EUID00P2TY:@03P2KVi/0
Zj^[0:6QX@2KVi/0UYJF09BDU02CTi<0W9bL0:NWY`2h^;P0][Jf0::RXP2BTY80UIFE0P2?Shl04@2A
TI40UIFE09FEU@2HV9P0UIFE0:NWY`2g]kL0YJFU08N7Q`25QHD0R8R808J6QP27QhL0TY:B08V9R@1m
OGd0LG5a0080HF5Q00/0LG5a07UiN@1PH600J6QX06UYJ@1RHV80JVYZ05]KF`1IFET0EUIF04m?C`02
04=3@`0:04Q8B015ADD0@4100410@00o?cl0;bl_02d];@0b<S80;Rh^02XZ:P80@d=300P0:b/[018B
4P0F5QH0:RXZ01PH600<30`04a<C00`<30800`<300<03@d=00D51@020P800P020P800`010@400000
0000000F000000Oooooo0005ooooobT0000000<00@41000000000000100000000`0<30`0Lg=c0>_[
j`020?gmo@060>o_k`31`L40Vi^K08b<S028R8P0Q8B40P1mOGd0301nOWh0Ph>307alO01lO7`0N7Qh
07AdM01`L700KVi^06a/K01aLG40Ng]k07moO`<0NWYj04L0O7al092@T02e]KD0_[jn0<30`02n_[h0
h>3P0?3`l03Ti>@0g]kN0>;RhP3<c<`0b/[:0<_;b`2f][H0]KFe0<S8b037alL0c/k>0<;2`P2][Jd0
ZJVY0<G5a@2_[jl0a/K60=3@d030`<00^KVi0;Fe]@2XZ:P0W9bL0:b/[02][Jd0YjNW09nOW`2`/;00
Y:BT09jNWP2QXJ40U9BD092@T02LW9`0Y:BT0:j^[P2WYjL0/;2`0;6a/@2WYjL0VIVI09fMW@2@T900
S8b<09ZJVP2_[jl0[:b/09^KV`2MWId0X:2P09>CT`2IVIT0U9BD08^;R`2BTY80X:2P0:>SX`2ZZZX0
UiNG08Z:RP28R8P0TI6A09RHV00209FEU@0409:BTP1oOgl0NWYj07emO@80IVIV00L0MWIf06a/K01V
IVH0JFUY06i^KP1YJFT0GemO0080E5AD00D0F5QH04a<C018B4P0ATI604E5A@020410@00B03dm?@0j
>SX0<S8b030`<00i>CT0:BTY024Q8@0m?Cd09bLW02HV9P0B4Q8010@400H61P0D51@030`<00l?3`07
1`L020P80P0410@300<30`0300820P000000000001L000001oooool000Gooooo;P000000;0010@40
1`L705eMG@3Rh^80oOgm0?clo03dm?@0alO70::RXP2EUID0RXZ:08V9R@1oOgl0MgMg07UiN@1nOWh0
O7al07IfMP1iNGT0MGEe075aL@1_Kfl0KVi^071`L01eMGD0NGUi0820P01mOGd0O7al07MgM`1kNg/0
Shn?09ZJVP2KVi/0Z:RX0<C4a03WinL0h^;R0=KFeP3GemL0fm_K0<;2`P37alL0d];B0P2h^;P03P30
`<00^[Zj0<W9b@3Fe]H0_Kfm0:NWY`2VYZH0W9bL0;no_`2k^k/0][Jf0;Vi^@2e]KD0[Jf]0P2QXJ40
0`2SXj<0ZJVY0::RXP020:JVYP040:b/[02SXj<0WinO09bLW080X:2P0380/k>c0;bl_02d];@0[jn_
0:NWY`2OWil0YjNW0:JVYP2ATI40S8b<09bLW02QXJ40WIfM09nOW`2QXJ40XZ:R0:BTY02DU9@0SXj>
09RHV02JVYX0TI6A07moO`1kNg/0RXZ:08n?S`2HV9P0WYjN09^KV`2DU9@0Ti>C08Z:RP21PH40Ph>3
06QXJ01/K6`0Lg=c05aLG01SHf<0KVi^07=cL`1hN7P0IVIV05EEE@1FEUH0EeMG051@D01:BTX0@d=3
03lo?`80@41001@0>CTi03@d=00i>CT0<C4a03Lg=`0^;Rh09bLW02l_;`0K6a/0820P01PH600820P0
10@402DU9@0R8R803Ph>00`<300>3Ph01PH600@410@00P8200<00@410000000000005P000007oooo
o`001OoooolZ0000000;00410@0000000000000000030`<0ADE50=?Cd`3moOd0o_kn0?7al@3:b/X0
0P2KVi/01P2ATI40QhN708J6QP1iNGT0MGEe07IfMP80MgMg01l0Lg=c075aL@1aLG40Kfm_06e]K@1c
Lg<0OWin07]kN`1lO7`0PH6108>3P`1nOWh0MWIf0820P02>SXh0Ti>C0:2PX02d];@0dm?C0=_Kf`3=
cLd0dm?C0=WIf@3Hf=P0aLG50<_;b`39bLT0][Jf0;Bd]02c/k<0]kNg0080^KVi00@0_kno0<W9b@2o
_kl0[:b/0P2f][H07@2b/[80[Jf]0:NWY`2][Jd0/[:b0:j^[P2VYZH0ZZZZ0;2`/02g]kL0aLG50<;2
`P31`L40];Bd0:BTY02RXZ80[Jf]0;fm_@2h^;P0ZZZZ09^KV`2JVYX0YZJV0:FUY@2RXZ80XJ6Q09ZJ
VP2RXZ80Vi^K0080VIVI00`0WIfM0:JVYP2LW9`0TY:B08R8R02PX:00TI6A08:2PP20P800SHf=09nO
W`2GUiL209RHV080WIfM01h0Vi^K09FEU@26QXH0P82006IVIP1[Jf/0LG5a06a/K01dM7@0Q8B407]k
N`1hN7P0JVYZ05QHF01@D500CTi>04Y:BP1<C4`0@d=303Ti>@10@400@d=304I6AP12@T80ATI6034a
<@0e=CD092@T02DU9@0O7al201hN7P0901`L700B4Q804A4A03@d=00Y:BT02@T900h>3P0820P00`<3
00D00P8200<00@410000000000005P000007ooooo`001Oooool/0000000400410@0820P0J6QX0=cL
g080o?cl00<0hn?S0;6a/@2EUID00P2:RXX01020P800PX:207moO`1fMWH207YjNP0E07MgM`1eMGD0
Lg=c07QhN01bLW80L71`07EeM@25QHD0Rh^;08N7Q`29RHT0SHf=096AT@2;Rh/0R8R809FEU@2XZ:P0
_;bl0=WIf@3^k^h0hN7Q0080bLW902<0/K6a0;Bd]034a<@0a<C40;no_`2n_[h0`l?30;^k^`2a/K40
[Jf]0;2`/02l_;`0a<C40<O7a`33`l<0d];B0;no_`2RXZ80VYZJ09^KV`2[Zj/0YZJV0:ZZZP2m_Kd0
`L710;Jf]P2e]KD0`<300<71`@30`<00a<C40;Bd]02XZ:P0ZJVY0:^[Z`030:ZZZP80VYZJ00L0WYjN
0::RXP2OWil0X:2P09nOW`2QXJ40WinO0080VIVI00/0YjNW0:VYZ@2PX:00UIFE08R8R02CTi<0TI6A
08j>SP2FUYH0Vi^K09>CT`0209:BTP08092@T02>SXh0SXj>09>CT`2KVi/0U9BD08Z:RP1dM7@206e]
K@0606UYJ@1nOWh0OWin05YJFP10@400A4A40P0o?cl05P1>CTh0EEEE059BDP15ADD0>SXj03dm?@10
@400?3`l02@T900e=CD0<C4a02XZ:P0S8b<0820P01lO7`0P820071`L01/K6`0H61P04A4A01<C4`0@
410201@D500300X:2P020P800P8200@00P8200<00@410000000000005P000007ooooo`001OoooolZ
000000800@4101T0000004E5A@3`l?00oOgm0?clo03Shn<0YJFU08R8R024Q8@0Ph>30861P@1mOGd0
Ogmo07UiN@1gMgL0P82008J6QP27QhL0Q8B40820P021PH40Lg=c07alO02<S8`0UiNG00<0U9BD01P0
UYJF09nOW`2HV9P0WYjN0;6a/@35aLD0fMWI0?7al@3kno/0k>c/0<c<c02e]KD0ZZZZ0:j^[P2UYJD0
ZZZZ0:b/[02k^k/0_kno0<30`032`/80_;bl0<;2`P3=cLd20<k>cP0M0<O7a`3AdM40`<300:RXZ02Y
ZJT0/[:b0;Rh^02VYZH0YJFU0<;2`P31`L40[jn_0;2`/02][Jd0]kNg0;Jf]P2UYJD0ZZZZ0:JVYP2S
Xj<0YZJV0:BTY02MWId0XZ:R09jNWP2OWil0Xj>S0:NWY`2/[:`00P2UYJD01`2JVYX0VIVI09>CT`2I
VIT0WinO0::RXP2QXJ400P2DU9@01@2;Rh/0Q8B408N7Q`2<S8`0TI6A0080RXZ:00h0R8R808B4Q020
P800R8R808^;R`28R8P0RHV908Z:RP1jNWX0LW9b05eMG@1QHF40L71`0820P080=cLg00L0>c/k0492
@P12@T80A4A404e=C@1EEED0C4a<0080>SXj0P0h>3P0400Z:RX0<S8b03`l?00V9RH08b<S024Q8@0P
82007alO01`L700K6a/06ATI010@400>3Ph05ADE01HF5P051@D700820P0300410@000000000001H0
00001oooool000Gooooo;00000006P051@D0W9bL0?knoP3moOd0j^[Z0;Bd]02>SXh0R8R808B4Q027
QhL0S8b<08^;R`1nOWh0N7Qh0861P@28R8P0Q8B408R8R027QhL0PH6107UiN@1jNWX0PX:209ZJVP2N
WYh0V9RH0P2@T900=`2LW9`0Xj>S09jNWP2MWId0Z:RX0:j^[P36a/H0j>SX0>k^kP3Xj>P0fMWI0<71
`@38b<P0_;bl0;:b/P2^[Zh0^[Zj0<71`@2c/k<0`/;20<c<c037alL0`l?30<O7a`3<c<`0emOG0<g=
c@3:b/X0a<C40;Ng]`32`/80e=CD0<G5a@2/[:`0]KFe0<K6aP2b/[80YZJV0;6a/@2`/;00/[:b0:^[
Z`2OWil0Shn?09>CT`2NWYh0WinO09ZJVP2;Rh/0SHf=09RHV02QXJ40WYjN0:>SX`2TY:@00P2QXJ40
402RXZ80V9RH08:2PP2<S8`0VIVI09ZJVP2>SXh0RHV9092@T02ATI40Q8B408J6QP2;Rh/0SHf=07em
O@1jNWX20820P00807emO@1oOgl0P82007alO01mOGd0Ogmo06IVIP1UIFD207=cL`0?07QhN01oOgl0
>CTi0492@P11@D40Bd];04Y:BP10@400>c/k04Y:BP1GEeL0ATI603dm?@0a<C40=CDe0080<30`0100
=3@d02PX:00W9bL08b<S028R8P0P82006a/K01XJ6P0I6AT04A4A00T92@0@41004A4A00<30`020P80
0`<31@020P800`010@4000000000000F000000Oooooo0005ooooob/0000000/00P82038b<P3Shn<0
o?cl0>c/k037alL0WYjN08J6QP2<S8`0Rh^;08b<S00208j>SP0<07]kN`22PX80UIFE08^;R`1oOgl0
O7al08:2PP1kNg/0MWIf0861P@2=SHd0YJFU0P2/[:`02@2@T900Shn?0:>SX`2^[Zh0XJ6Q09VIV@2L
W9`0ZJVY0<;2`P020=cLg00H0=kNgP3Lg=`0f=SH0=?Cd`33`l<0a<C40<g=c@3Fe]H0bLW90<C4a03B
d]80gmoO0=GEe@3:b/X0`l?30<c<c03AdM40b<S80<71`@30`<00^[Zj0=7Ad@3]kNd0f][J0P3:b/X0
5`2n_[h0[Jf]0:FUY@2^[Zh0ZJVY0:JVYP2RXZ80WIfM08N7Q`2GUiL0[:b/09jNWP2=SHd0R8R808F5
Q@27QhL0UIFE09bLW02PX:00Xj>S09jNWP2SXj<0[:b/0080Q8B40P2ATI402P2OWil0Shn?08B4Q02<
S8`0SXj>08B4Q02:RXX0S8b<08J6QP1nOWh207EeM@0S07UiN@24Q8@0PX:208:2PP23Ph<0PH6107Yj
NP1^KVh0MWIf07]kN`1fMWH0L71`061PH00f=SH0BDU904Y:BP1<C4`0CTi>03Ti>@0j>SX0B4Q805UI
F@10@4008b<S03Ph>00j>SX0=CDe02h^;P0Y:BT0:b/[02TY:@0S8b<0820P01`L700K6a/00P0J6QX0
1@0?3`l01@D5014A4@0?3`l01@D500L00P8200<00@410000000000005P000007ooooo`001OoooolX
0000000E00410@0000000@4101LG5`2RXZ80no_k0?7al@36a/H0ZJVY08b<S028R8P0SXj>08f=S@2:
RXX0Rh^;0820P01iNGT0RHV909:BTP24Q8@0O7al0080NGUi0340MgMg07QhN02:RXX0TI6A0:>SX`2^
[Zh0/k>c0:2PX02HV9P0/K6a0;>c/`2WYjL0VYZJ0::RXP2h^;P0a/K60>?Sh`3Lg=`0f=SH0=GEe@3I
fMT0emOG0<_;b`3@d=00emOG0=WIf@3Bd]80h>3P0>k^kP3fm_H0jn_[0=gMg@3Lg=`0dm?C0<[:bP2j
^[X0_[jn0<;2`P2n_[h0d=3@0=_Kf`3@d=00b<S80<C4a031`L40[Zj^0:b/[02i^KT0[:b/0080Y:BT
01X0W9bL08n?S`2BTY80W9bL08b<S02:RXX0Rh^;08f=S@2ATI40X:2P0:FUY@2JVYX0V9RH09jNWP2[
Zj/0YJFU08F5Q@2:RXX0RHV90861P@2PX:00TY:B07]kN`29RHT0PX:208F5Q@80RXZ:00X0QhN70861
P@1jNWX0NWYj08:2PP24Q8@0TY:B08b<S022PX80P8200P1kNg/08P1/K6`0LW9b06YZJP1TI6@0Hf=S
04M7A`15ADD0A4A40492@P0n?Sh0>3Ph03lo?`1@D500GemO04A4A00`<300AdM703<c<`0Z:RX0=3@d
02`/;00V9RH092@T028R8P0O7al06a/K01XJ6P0H61P05ADE00h>3P092@T051@D00X:2P061PH70082
0P0300410@000000000001H000001oooool000Gooooo:P00000060092@T0L71`0>o_k`3lo?`0hn?S
0<30`02JVYX0R8R808n?S`2=SHd0QHF50861P@1nOWh0NGUi07moO`23Ph<0Ogmo07UiN@1lO7`0OGem
07MgM`1bLW80Ng]k09fMW@80Zj^[05d0/;2`0;Bd]02`/;00]kNg0;jn_P2k^k/0/K6a0:RXZ02e]KD0
eMGE0>?Sh`3/k>`0gmoO0=OGe`3MgMd0f][J0<S8b036a/H0d=3@0<_;b`3<c<`0eMGE0>CTi03bl_80
n_[j0?Cdm03^k^h0jNWY0=kNgP3Bd]80`l?30;Zj^P2n_[h0_kno0<30`032`/80^KVi0;6a/@2o_kl0
cLg=0;Jf]P2^[Zh0[Jf]0:RXZ02VYZH0XJ6Q09fMW@2GUiL0V9RH09:BTP27QhL0S8b<08V9R@2>SXh0
VIVI0::RXP2PX:00Shn?096AT@2XZ:P0[Zj^0:2PX028R8P0QHF509>CT`2IVIT0[:b/08V9R@20P800
RXZ:08B4Q02;Rh/0QXJ608V9R@27QhL0P820079bLP1jNWX0Q8B408Z:RP2BTY80SHf=07moO`1mOGd0
O7al07EeM@1TI6@0Lg=c06IVIP1dM7@0Jf][06MWI`1=CDd00P19BDT03018B4P0BTY:04Y:BP1IFET0
IVIV05]KF`10@400A4A402LW9`0Y:BT0<c<c02PX:0808R8R00D071`L01dM7@0K6a/06QXJ01PH6002
00l?3`0500`<300:2PX01PH600@410030`<01P020P800`010@4000000000000F000000Oooooo0005
ooooobP0000000h00@4100820P10@400e]KF0?gmo@3emOD0dm?C0;Bd]02GUiL0Shn?09JFUP27QhL0
OGem07MgM`80LW9b03P0NGUi07]kN`1fMWH0M7Ad07alO01mOGd0MgMg07AdM01mOGd0ZJVY0;^k^`2i
^KT0^[Zj0;fm_@2h^;P0aLG50<C4a030`<00_[jn0;Zj^P35aLD0fMWI0>SXj03Shn<0gMgM0=_Kf`3T
i>@0f=SH0<o?c`3<c<`0d];B0<g=c@3<c<`0dm?C0>CTi03Xj>P0jn_[0>KViP3Ph>00h^;R0=[JfP3A
dM40a/K60<;2`P36a/H0`<300;Rh^032`/80^KVi0;>c/`39bLT0clo?0;bl_02_[jl0Zj^[0:RXZ080
YjNW02X0XZ:R09ZJVP2GUiL0TY:B08n?S`2@T900QHF509:BTP2FUYH0WinO09ZJVP1gMgL0OWin096A
T@2PX:00Ti>C08F5Q@2<S8`0SXj>09FEU@2<S8`0PH6108V9R@28R8P0TI6A09FEU@2;Rh/0R8R80861
P@1kNg/0MWIf07alO01jNWX0PH6107inOP20P800O7al07emO@1jNWX0LW9b06YZJP1/K6`206i^KP0A
06a/K01eMGD0EUIF04];B`1ADE40De=C05ADE01LG5`0IVIV05eMG@0j>SX07alO02PX:00Z:RX0:BTY
038b<P0X:2P00P0Q8B401@0L71`08B4Q01/K6`0H61P051@D00803@d=00@02PX:00H61P030`<00@41
1`020P800`010@4000000000000F000000Oooooo0005ooooobT0000000d06a/K0:b/[03jn_X0oOgm
0?7al@33`l<0XJ6Q08n?S`29RHT0QXJ607MgM`1cLg<0LW9b0080L71`00/0MGEe07MgM`1bLW80Lg=c
07MgM`1jNWX0N7Qh07MgM`26QXH0Y:BT0;Rh^0020<C4a0050<O7a`35aLD0bLW90;no_`3:b/X00P3B
d]80103IfMT0h^;R0>_[j`3Vi^H20>CTi00<0>;RhP3Lg=`0f][J0=WIf@3Cdm<0e=CD0=_Kf`3GemL0
fm_K0>3Ph03Shn<0f=SH0P3>c/h01`3;bl/0a/K60;^k^`2k^k/0bLW90<71`@2i^KT00P2m_Kd05@31
`L40c<c<0<S8b02n_[h0^[Zj0;Jf]P2c/k<0[Jf]0:ZZZP2VYZH0W9bL09NGU`2IVIT0Ti>C096AT@2?
Shl0UYJF09ZJVP2OWil0T92@07YjNP0208:2PP0<09FEU@2<S8`0QHF508V9R@24Q8@0QhN708B4Q025
QHD0QXJ608>3P`1hN7P0QhN70P2;Rh/03@23Ph<0O7al07MgM`1gMgL0MWIf079bLP1^KVh0Lg=c06i^
KP1nOWh0JVYZ07EeM@1^KVh00P1/K6`07P1VIVH0K6a/071`L01FEUH0C4a<05ADE01NGUh0Fe]K059B
DP1<C4`0@d=3014A4@0<30`08B4Q03dm?@0l?3`0?Cdm02PX:00S8b<08R8R020P800K6a/061PH01/K
6`0<30`04A4A018B4P0:2PX01PH600<30`P00P8200<00@410000000000005P000007ooooo`001Ooo
oolX0000000<00P8201aLG40l?3`0?knoP3moOd0jn_[0;Bd]02ATI40QXJ607moO`1fMWH0Kfm_0P1c
Lg<00`1bLW80Lg=c07QhN00207AdM00;07UiN@21PH40Q8B407emO@1nOWh0VYZJ0:BTY02j^[X0_Kfm
0;no_`33`l<00P3>c/h0<038b<P0d=3@0=_Kf`3Vi^H0inOW0>_[j`3]kNd0iNGU0>7Qh@3Jf]X0fm_K
0=oOg`3UiND0gMgM0=KFeP3Ogml0g]kN0=GEe@3IfMT0inOW0>[ZjP3Hf=P0bl_;0<C4a02f][H0_[jn
0;Fe]@2j^[X0`<300;Vi^@2o_kl0aLG50;jn_P2l_;`0`/;20<G5a@33`l<0a/K60<30`02h^;P0^[Zj
0:n_[`2b/[80ZJVY09nOW`2NWYh0V9RH09FEU@80T92@00<0UiNG096AT@2=SHd00P26QXH0;`27QhL0
T92@0820P024Q8@0QhN708>3P`20P800Ph>308^;R`23Ph<0Kfm_06e]K@1kNg/0QhN708Z:RP26QXH0
MgMg071`L01cLg<0LW9b06e]K@1YJFT0J6QX06YZJP1]KFd0HF5Q079bLP1YJFT0Jf][06QXJ01YJFT0
HV9R06EUI@1EEED0BDU904m?C`1ADE40CDe=0492@P18B4P0ADE500h>3P0I6AT08B4Q03Ti>@15ADD0
:b/[00809RHV00/08B4Q01`L700G5aL061PH01`L700@41007QhN01/K6`0;2`/01@D500<30`080082
0P0300410@000000000001H000001oooool000Gooooo9`0000002`010@40=cLg0=?Cd`3moOd0o_kn
0?KfmP3Ng]h0YjNW08Z:RP1mOGd0N7Qh0080LW9b0240MgMg07AdM01dM7@0M7Ad07=cL`1aLG40N7Qh
08:2PP28R8P0Q8B407inOP26QXH0WinO0:b/[02j^[X0/[:b0;^k^`2m_Kd0`/;20<[:bP3>c/h0e]KF
0>SXj03bl_80m?Cd0?Ogm`3clo<0hn?S0=cLg03Kfm/0f][J0>;RhP3Shn<00P3Ph>005@3/k>`0gMgM
0=[JfP3Ng]h0inOW0?7al@3Ti>@0cLg=0<W9b@30`<00_Kfm0;Rh^02l_;`0];Bd0;Zj^P32`/80bl_;
0<?3``2h^;P0[jn_0<71`@020=OGe`0=0<W9b@32`/80_Kfm0;6a/@2b/[80W9bL09ZJVP2LW9`0UYJF
09:BTP2>SXh0R8R808Z:RP0208B4Q00A08Z:RP2@T900Rh^;0820P01kNg/0QHF508N7Q`23Ph<0Ogmo
08B4Q02:RXX0Lg=c06YZJP1fMWH0Lg=c07]kN`26QXH00P28R8P0101lO7`0Lg=c06m_K`1^KVh206YZ
JP0306ATI01aLG40IfMW0080HV9R00<0I6AT06EUI@1QHF400P1GEeL05P1<C4`0BDU904m?C`19BDT0
B4Q804U9B@17AdL0>3Ph01HF5P0P82008R8R034a<@1ADE40;2`/02HV9P0T92@05aLG018B4P0H61P0
5aLG01@D500>3Ph200d=3@0300H61P0410@00`<300P00P8200<00@410000000000005P000007oooo
o`001OoooolT0000000=00410@000000000001<C4`2MWId0nOWi0?knoP3kno/0i^KV0<g=c@2TY:@0
QHF507MgM`02079bLP0]07UiN@1oOgl0LW9b07=cL`1fMWH0Ng]k07IfMP1jNWX0RXZ:08f=S@21PH40
Ng]k08B4Q02:RXX0T92@0:j^[P2j^[X0`<300;:b/P2k^k/0a/K60=7Ad@3GemL0j>SX0?;blP3kno/0
o?cl0?;blP3Ti>@0i^KV0>?Sh`3Ng]h0gmoO0>?Sh`3YjNT0gmoO0>[ZjP3Ti>@0fMWI0=SHf03Ph>00
kno_0>7Qh@3Bd]80a/K60080`<300180_[jn0;Fe]@2e]KD0a<C40;bl_02h^;P0];Bd0:6QX@2e]KD0
dm?C0>7Qh@3Vi^H0cLg=0<W9b@2TY:@0XZ:R0;>c/`2IVIT209ZJVP0;09RHV02CTi<0S8b<08Z:RP2<
S8`0QhN707YjNP20P800QXJ608B4Q025QHD00P1oOgl0=P22PX80P82008:2PP26QXH0OGem06IVIP1l
O7`0QXJ607UiN@1eMGD0O7al08F5Q@2CTi<0QXJ607=cL`1ZJVX0L71`06e]K@1^KVh0JVYZ06m_K`1Y
JFT0JVYZ06=SH`1VIVH0J6QX06EUI@1GEeL0CDe=04M7A`1=CDd0DE5A04U9B@16ATH0BTY:03hn?P0L
71`0:BTY02d];@0b<S80C4a<04=3@`0T92@0820P01lO7`0F5QH04Q8B01LG5`0H61P03`l?00d=3@0<
30`02PX:00@410800P8200<00@4100820P020P801@020P800`010@4000000000000F000000Oooooo
0005ooooob80000000L00P82000000010@40000000@4101JFUX0jNWY0080oOgm03`0lo?c0=WIf@32
`/80WIfM07moO`1aLG40LW9b07IfMP1hN7P0MGEe06i^KP1fMWH0Shn?09FEU@1jNWX0P82008f=S@24
Q8@0NWYj07EeM@1jNWX0MWIf07emO@2GUiL0_kno0;jn_P2f][H0_Kfm0=7Ad@3_knl0j^[Z0>c/k03i
nOT0no_k0??cl`3]kNd0iNGU0>?Sh`3Lg=`0gmoO0=OGe`3Shn<0j^[Z0>7Qh@3UiND0fm_K0=CDe03G
emL0f=SH0>7Qh@3IfMT0a/K60;Bd]02g]kL0`l?30;Fe]@2][Jd0/k>c0;6a/@2][Jd20:n_[`0/0:BT
Y032`/80f=SH0>KViP3UiND0aLG50;bl_02VYZH0ZZZZ0:j^[P2HV9P0UYJF0:>SX`2ZZZX0Shn?08f=
S@2@T900QXJ607emO@1gMgL0MWIf07emO@27QhL0TY:B07moO`1lO7`0NWYj07alO01nOWh0PX:2071`
L01^KVh0PH6108Z:RP1oOgl0MWIf07=cL`1iNGT0U9BD096AT@1eMGD0JFUY075aL@1]KFd206i^KP05
06YZJP1XJ6P0I6AT06=SH`1VIVH00P1WIfL02P1NGUh0CDe=05EEE@1JFUX0Bd];04I6AP17AdL0CDe=
03Hf=P0D51@202`/;00802XZ:P0_;bl0;Rh^02LW9`0Q8B407alO01TI6@0@410201DE5@0500h>3P0;
2`/02`/;00P820030`<00`020P800`010@400P8200<30`0400820P0300410@000000000001H00000
1oooool000Gooooo8P0000006`010@400000000000010@408b<S0;jn_P3lo?`0o_kn0?clo03]kNd0
f][J0<30`02KVi/0Ph>307QhN01eMGD0LW9b075aL@1`L700LG5a08>3P`2VYZH0SHf=07MgM`23Ph<0
PX:207UiN@0407MgM`0H09jNWP2GUiL0YZJV0:b/[02_[jl0/[:b0=;BdP3Zj^X0i^KV0?7al@3dm?@0
m_Kf0>k^kP3WinL0hn?S0=kNgP3MgMd0gmoO0=SHf03MgMd0hN7Q0=?Cd`3=cLd0b/[:0P3Bd]80603I
fMT0gMgM0=?Cd`35aLD0`<300;jn_P33`l<0^;Rh0;>c/`2b/[80Z:RX0:b/[02d];@0]KFe0:j^[P2n
_[h0clo?0=OGe`39bLT0`L710<30`02h^;P0YjNW0:FUY@80UiNG00`0W9bL09VIV@2>SXh0Shn?08V9
R@21PH40P82007alO01iNGT0O7al08>3P`1oOgl207YjNP0]07MgM`1iNGT0Ng]k07inOP1_Kfl0MGEe
07emO@1oOgl0NGUi079bLP1`L700Kfm_07emO@2EUID0Ng]k06YZJP1cLg<0KVi^06YZJP1TI6@0IFEU
069RHP1IFET0GEeM06ATI016ATH0G5aL05]KF`0d=3@0?Cdm04e=C@14A4@0@D5104A4A01=CDd0>CTi
01DE5@0Y:BT0:b/[028R8P0/;2`0?3`l02/[:`0P82006QXJ00805aLG00P061PH01HF5P0E5AD02PX:
00/;2`0820P010@400820P800@410P020P800`030`<00P8200820P0200820P0300410@0000000000
01H000001oooool000Gooooo9@0000000`0820P0N7Qh0??cl`020?knoP090?Shn03Xj>P0gMgM0<30
`02FUYH0QXJ607UiN@1cLg<0Kfm_0080LG5a00H0MGEe08N7Q`29RHT0M7Ad079bLP1hN7P207]kN`0L
07QhN01jNWX0Ogmo07alO02BTY80UYJF0:FUY@2^[Zh0][Jf0;bl_03>c/h0g]kN0>OWi`3`l?00jn_[
0>c/k03Ogml0f=SH0>3Ph03Kfm/0g=cL0=WIf@3Hf=P0g=cL0=KFeP3Bd]80bl_;0<O7a`<0b/[:00l0
d=3@0<k>cP32`/80a/K60;^k^`2g]kL0/K6a0:NWY`2][Jd0][Jf0;Ng]`2i^KT0ZZZZ0:f][@2f][H0
0P2l_;`03P2f][H0_kno0<K6aP37alL0ZZZZ0:RXZ02LW9`0V9RH08b<S02ATI40T92@09VIV@2:RXX0
Ph>30P22PX80?@27QhL0Q8B408:2PP1mOGd0Ng]k07YjNP1fMWH0NWYj07alO020P800NGUi07=cL`1j
NWX0O7al07AdM01bLW80M7Ad07MgM`22PX80Vi^K08F5Q@1[Jf/0MgMg06m_K`1ZJVX0IfMW06YZJP1N
GUh0EeMG05QHF01OGel0CTi>06=SH`15ADD0<30`03dm?@13@d<0BTY:0492@P15ADD0B4Q803`l?00H
61P09RHV02XZ:P0Y:BT0>CTi03lo?`0U9BD08B4Q01@D500L71`06a/K010@400?3`l030`<00P8200;
2`/00`<300@410020P800P010@400`0000000P8200820P0400820P0300410@000000000001H00000
1oooool000Gooooo800000001`010@40000000410@0000000@41038b<P3AdM400`3moOd01P3clo<0
inOW0=cLg02o_kl0WYjN08J6QP80NWYj00/0MWIf07UiN@1lO7`0Ogmo07QhN01aLG40L71`07QhN021
PH40QXJ608F5Q@0207moO`0D07alO01gMgL0Ng]k092@T02PX:00[Zj^0;:b/P2f][H0bLW90=7Ad@3S
hn<0k>c/0>g]k@3WinL0gmoO0=kNgP3Ogml0gMgM0=KFeP3De=@30=GEe@080=SHf03=cLd0bl_;0<?3
``36a/H0_kno0<_;b`3>c/h20<O7a`080;bl_02_[jl0YZJV09ZJVP2ZZZX0^[Zj0;bl_02h^;P20:f]
[@0?0:b/[02YZJT0Zj^[0;Ng]`2o_kl0c/k>0<O7a`2][Jd0WinO09^KV`2EUID0RXZ:092@T02ATI40
RXZ:0080Q8B400P0PX:208B4Q02:RXX0QXJ608V9R@28R8P0QHF507emO@80O7al00D0P82008J6QP20
P800M7Ad07IfMP0207QhN00F07IfMP1eMGD0P82008n?S`2@T900OWin06UYJ@1cLg<0NWYj07]kN`1]
KFd0J6QX05]KF`1PH600FUYJ05aLG01HF5P0GemO03`l?015ADD0BTY:0410@080CTi>00l0@D5104M7
A`0h>3P0820P030`<00c<c<0=SHf04E5A@0c<c<06a/K02HV9P0B4Q807alO01HF5P0C4a<00P0:2PX0
1@0<30`01`L700820P030`<00P8200<00@4100<0000000410@010@400`020P800`010@4000000000
000F000000Oooooo0005ooooob@0000002H030`<08b<S03gmoL0o_kn0?ooo`3lo?`0mOGe0>_[j`3P
h>00`L710::RXP2:RXX0QHF508b<S025QHD0WIfM0:>SX`2?Shl0NWYj07AdM01kNg/0Q8B409:BTP2;
Rh/0QHF508:2PP25QHD0OGem07IfMP1hN7P0RHV909JFUP2TY:@0YZJV0;:b/P35aLD0c<c<0=SHf080
g=cL00L0h^;R0=cLg03Cdm<0c/k>0=cLg03GemL0clo?0080dm?C0200c<c<0=OGe`3Ogml0f=SH0<S8
b039bLT0aLG50<O7a`2o_kl0`/;20<S8b031`L40^[Zj0:f][@2TY:@0[jn_0;>c/`2d];@0/K6a0;Zj
^P2a/K40ZZZZ0:RXZ02WYjL0/;2`0;>c/`2j^[X0]KFe0:j^[P2PX:00V9RH0:6QX@80TY:B00<0SHf=
08J6QP22PX800P23Ph<02026QXH0R8R808B4Q027QhL0SHf=08n?S`2:RXX0QhN70P26QXH00`2:RXX0
QHF507inOP0307YjNP0L07alO022PX80R8R808b<S023Ph<0Jf][071`L01dM7@0N7Qh055AD@1DE5@0
JFUY06ATI01MGEd0Fe]K05IFEP1EEED0De=C03lo?`0n?Sh0BDU904Q8B01KFe/0IFEU03dm?@14A4@0
>c/k02HV9P80<c<c00l0=3@d02h^;P0M7Ad06ATI02/[:`0>3Ph051@D00h>3P0M7Ad02`/;00h>3P0;
2`/010@400<30`020P801`010@4300820P0300410@000000000001H000001oooool000Gooooo8P00
000200410@0303/k>`3Kfm/0o_kn0080o_kn0180n_[j0?Cdm03clo<0g=cL0<30`02OWil0Ph>308f=
S@2QXJ40Vi^K0:^[Z`2TY:@0Q8B407UiN@1oOgl0Q8B408N7Q`2;Rh/208J6QP0l08F5Q@26QXH0P820
07AdM01gMgL0PX:208R8R025QHD0RXZ:0;2`/030`<00`l?30<G5a@3<c<`0e=CD0=cLg03IfMT0c/k>
0=?Cd`3Kfm/0dM7A0<_;b`3=cLd0bl_;0<K6aP3>c/h0hN7Q0>?Sh`3:b/X0bl_;0=;BdP30`<00^;Rh
0<?3``36a/H0^k^k0;Jf]P2_[jl0YJFU0:NWY`2j^[X0[jn_0;Fe]@2_[jl0/K6a0:^[Z`2WYjL0ZZZZ
0:n_[`2/[:`0ZJVY0:^[Z`2c/k<0YJFU09ZJVP2WYjL0WIfM08j>SP2=SHd0PH610P1oOgl04024Q8@0
QhN708F5Q@24Q8@0RXZ:09BDU02<S8`0TI6A08f=S@23Ph<0Rh^;08n?S`26QXH0Ph>308B4Q021PH42
08J6QP0K08R8R025QHD0N7Qh06=SH`1YJFT0N7Qh06UYJ@1RHV80@d=3065QH@1jNWX0KVi^06=SH`1P
H600E5AD04a<C01BDU80C4a<04Q8B01DE5@0GEeM06YZJP1QHF40=SHf0451@@1;Bd/0<c<c0080;Rh^
00T0:2PX020P800K6a/07AdM02/[:`0=3@d03Ph>00l?3`0B4Q800P0;2`/010051@D01`L700D51@02
0P8800410@800P8200<00@410000000000005P000007ooooo`001OoooolR0000000400410@0?3`l0
UiNG0?Win@<0o_kn0100m_Kf0>g]k@3[jn/0b<S80;Zj^P2MWId0UYJF0:6QX@2/[:`0YZJV0:NWY`2:
RXX0OGem0820P025QHD0Q8B40P22PX808`26QXH0RHV908J6QP25QHD0PX:207IfMP1eMGD0N7Qh07al
O01jNWX0QXJ60:j^[P32`/80`l?30<30`035aLD0c<c<0=;BdP3@d=00c<c<0=OGe`3Bd]80cLg=0<k>
cP37alL0_kno0;Zj^P3<c<`0fMWI0=GEe@3:b/X0cLg=0<k>cP37alL0][Jf0080`L7100h0];Bd0;Vi
^@2f][H0Z:RX0:j^[P2c/k<0/;2`0;Jf]P2k^k/0];Bd0;6a/@2ZZZX0YJFU0:b/[080WinO00@0UiNG
09jNWP2UYJD0X:2P0P2[Zj/0<@2EUID0PH6108:2PP2:RXX0Q8B408J6QP27QhL0Ogmo08>3P`29RHT0
TY:B07alO02VYZH0UIFE08j>SP2FUYH0TI6A08:2PP2=SHd0QXJ607QhN01jNWX0LW9b071`L01[Jf/0
IFEU06MWI`1fMWH0JFUY05aLG01BDU80EUIF06MWI`1_Kfl0GUiN05IFEP16ATH0EeMG04e=C@1>CTh0
Bd];04i>CP1IFET0GUiN05ADE00l?3`0=CDe0410@014A4@00P0l?3`0200Z:RX0:b/[02DU9@0P8200
7alO03<c<`0@41003`l?0P0C4a<0200;2`/020P800H61P0820P010@400820P010@4000002@010@4H
000000Oooooo0005oooooal000000`010@405`0820P0KVi^0>g]k@3no_h0oooo0?knoP3jn_X0m?Cd
0>CTi03Ng]h0c/k>0<o?c`2j^[X0^KVi0;Jf]P2[Zj/0W9bL09BDU028R8P0QHF508>3P`26QXH0Q8B4
00<0OWin02`0P82008F5Q@27QhL0QHF507]kN`1bLW80L71`07=cL`1oOgl0V9RH0:NWY`2d];@0_;bl
0;fm_@2o_kl0`<300<C4a02h^;P0_Kfm0<_;b`32`/80alO70;Jf]P2TY:@0WinO0:f][@37alL0d];B
0<_;b`2l_;`0a/K60=CDe038b<P0]KFe0;6a/@2`/;00/K6a0;Ng]`2ZZZX0YZJV0:VYZ@2VYZH0YjNW
0:JVYP80ZJVY01X0[Zj^0:RXZ02WYjL0XZ:R09ZJVP2KVi/0RXZ:08b<S02IVIT0WYjN0:FUY@2IVIT0
TI6A08F5Q@2<S8`0SHf=08b<S029RHT0S8b<07inOP26QXH0S8b<09FEU@2KVi/0XJ6Q09VIV@80Shn?
00d0RXZ:07moO`1oOgl0NWYj075aL@1dM7@0MGEe06i^KP1`L700K6a/06i^KP1_Kfl0IfMW0080Cdm?
00@0Fe]K05EEE@1GEeL0Fe]K0P1JFUX08@1PH600F5QH05eMG@1EEED0C4a<04A4A011@D40AdM7038b
<P0m?Cd0?Shn04E5A@0j>SX0>c/k03lo?`13@d<0<S8b02d];@0Y:BT09BDU00l?3`0<30`03Ph>00T9
2@030`<00P8200/;2`0<30`00P8200410@020P800@4100820P0800410AP000001oooool000Gooooo
8@0000000`020P80?Shn0=oOg`030?knoP0?0?[jnP3Xj>P0i^KV0=gMg@3:b/X0_;bl0<71`@2XZ:P0
alO70;no_`2IVIT0QHF508N7Q`28R8P0QHF50080Q8B401/0OGem07]kN`1iNGT0NWYj07inOP25QHD0
S8b<08J6QP1fMWH0KFe]06m_K`1aLG40O7al08n?S`2WYjL0^KVi0;fm_@34a<@0^;Rh0;Bd]02_[jl0
[:b/0;jn_P2o_kl0Zj^[0;Ng]`2VYZH00P2IVIT01@2YZJT0`l?30<_;b`30`<00/k>c00<0Z:RX02l0
[:b/0:j^[P2][Jd0Y:BT0:2PX02WYjL0Z:RX0:2PX02WYjL0YZJV09fMW@2PX:00YJFU0;2`/02_[jl0
/;2`09fMW@2OWil0UiNG08R8R029RHT0VIVI09nOW`2CTi<0Q8B40861P@23Ph<0Q8B408b<S021PH40
Ph>308N7Q`2;Rh/0Shn?092@T02DU9@0Q8B408V9R@23Ph<0R8R808f=S@27QhL0NGUi07QhN01_Kfl0
MGEe07]kN`02071`L00J06e]K@1QHF40JFUY06YZJP1LG5`0Cdm?05UIF@1GEeL0EEEE05MGE`1HF5P0
Hf=S06IVIP1DE5@0BDU903Ph>01<C4`0@T92030`<00k>c/0=cLg024Q8@19BDT0ATI603lo?`0m?Cd2
04];B`0>04M7A`0L71`051@D01dM7@0>3Ph010@400820P071`L02PX:00820P030`<020P800`<3002
0P8<00410AP000001oooool000Gooooo7P0000001P010@4000000000000:2PX0T92@0?Win@80o_kn
00`0n_[j0>[ZjP3EeMD0j>SX0=SHf02k^k/0]KFe0;>c/`2o_kl0h^;R0;^k^`27QhL208f=S@0I08n?
S`27QhL0Q8B408:2PP1kNg/0NWYj07UiN@1jNWX0OWin08>3P`27QhL0RHV907MgM`1^KVh0L71`075a
L@1nOWh0SXj>0;Fe]@39bLT0a<C40<30`02d];@0Z:RX09jNWP020:b/[00>0:6QX@2NWYh0YZJV0:BT
Y02RXZ80YZJV0:j^[P2o_kl0`l?30;Vi^@2a/K40YjNW0::RXP2VYZH20:n_[`060:JVYP2MWId0UIFE
0:^[Z`2ZZZX0VYZJ0P2LW9`209JFUP0^0:^[Z`2`/;00][Jf0;bl_02OWil0UYJF09VIV@2=SHd0Rh^;
092@T02IVIT0T92@08Z:RP27QhL0OWin07UiN@21PH40PX:207moO`27QhL0WinO0:2PX02CTi<0Q8B4
07=cL`20P800PH6108R8R02:RXX0SHf=07moO`1hN7P0KFe]07IfMP1lO7`0NGUi07AdM01UIFD0I6AT
06i^KP1]KFd0K6a/065QH@1ADE40De=C05MGE`80FUYJ01H0Kfm_05iNGP1:BTX0?Shn03Hf=P1?Cdl0
A4A4028R8P0`<300<c<c02PX:019BDT0>SXj02LW9`0];Bd0>SXj03@d=00h>3P03Ph>01HF5P0T92@0
1`L70P020P801`030`<01PH600H61P0410@02`/;00T92@020P802`010@4I000000Oooooo0005oooo
oah0000001X00@41000000010@40<c<c0=OGe`3moOd0o_kn0?ooo`3dm?@0eMGE0<71`@3?cll0`/;2
0:b/[02_[jl0/K6a0>;RhP3[jn/0YJFU08B4Q02<S8`0T92@09:BTP29RHT0QhN70820P080OGem0440
Ng]k07UiN@1oOgl0PX:207inOP1oOgl0MgMg075aL@1dM7@0MGEe0820P02PX:00a<C40=OGe`3Jf]X0
bl_;0;2`/02QXJ40VYZJ09VIV@2=SHd0T92@0:VYZ@2OWil0UYJF0:>SX`2f][H0^KVi0<30`02k^k/0
_[jn0<71`@2b/[80[jn_0:b/[02d];@0[jn_0:ZZZP2`/;00]kNg0;Zj^P2/[:`0VIVI09:BTP2;Rh/0
RXZ:09BDU02ZZZX0[Jf]0;Vi^@2`/;00YZJV09VIV@2@T900Q8B40820P01lO7`0RXZ:09ZJVP2<S8`0
PX:207=cL`1XJ6P0NGUi08:2PP0208B4Q00c09>CT`2DU9@0PH61071`L01bLW80P82007inOP1oOgl0
RHV909bLW02=SHd0N7Qh06m_K`1jNWX0NGUi08R8R01fMWH0JFUY06m_K`1^KVh0N7Qh075aL@1=CDd0
EUIF05MGE`1JFUX0GemO06e]K@1dM7@0CTi>055AD@17AdL0@d=3059BDP0g=cL07QhN02h^;P0g=cL0
<30`03Hf=P0];Bd0;bl_03De=@11@D40?clo04Q8B00A4A407alO02<S8`0410@00@41008010@400H0
2`/;00d=3@0<30`06ATI00P820020P8;00410AT000001oooool000Gooooo800000000`0820P0OWin
0?Ogm`020?gmo@0I0?Win@3Rh^80_kno0;:b/P2/[:`0[Jf]0:NWY`2/[:`0YJFU0=oOg`30`<00TY:B
08V9R@2=SHd0T92@09>CT`2@T900S8b<08B4Q025QHD0Q8B40861P@1lO7`0Ogmo0820P00207alO080
Lg=c00l0MWIf07QhN02:RXX0/[:b0=7Ad@3=cLd0d];B0=?Cd`2d];@0Xj>S09RHV02?Shl0SHf=092@
T02FUYH00P2BTY800`2][Jd0`/;20<W9b@020;bl_00S0<G5a@32`/80/k>c0;:b/P2e]KD0/K6a0;>c
/`2j^[X0][Jf0<;2`P2m_Kd0];Bd09fMW@2;Rh/0Shn?09>CT`2NWYh0/K6a0;fm_@2[Zj/0W9bL09^K
V`2EUID0QXJ607inOP20P800N7Qh0820P02GUiL0SXj>07moO`1QHF40F5QH07EeM@21PH400P23Ph<0
2`28R8P0Shn?07IfMP1]KFd0N7Qh07]kN`1mOGd0NGUi0820P02GUiL0S8b<00<0MgMg01L0MWIf07Yj
NP1`L700Jf][06m_K`1YJFT0L71`06e]K@1LG5`0IfMW05IFEP1HF5P0IFEU06UYJ@1HF5P0Bd];05EE
E@16ATH0?Shn02`/;00Y:BT0<c<c03Lg=`0203`l?00D03De=@0b<S80>SXj03Ti>@0n?Sh0BTY:05QH
F00_;bl08b<S01hN7P051@D00@4100<30`051@D03@d=00H61P0@41004a<C00@410020P8<00410AP0
00001oooool000Gooooo7`0000003@010@4092@T0<W9b@3moOd0o?cl0?Ogm`3Xj>P0bLW90:b/[02R
XZ80Vi^K09VIV@2FUYH00P2GUiL01P2n_[h0TI6A08Z:RP2>SXh0TY:B09NGU`80UIFE0180Rh^;08J6
QP27QhL0SHf=08R8R025QHD0PH6108:2PP1mOGd0O7al07EeM@1cLg<0MWIf07alO02HV9P0]kNg0=OG
e`3?cll20<[:bP040;6a/@2UYJD0UYJF08j>SP80RXZ:01T0R8R808^;R`2ATI40ZJVY0;Rh^035aLD0
_[jn0;Rh^02g]kL0[Zj^0:ZZZP2b/[80[Zj^0:n_[`2b/[80]kNg0;>c/`2f][H0]kNg0;2`/02QXJ40
TY:B09bLW02IVIT0Vi^K0080WinO00H0V9RH09NGU`2LW9`0UYJF08:2PP1mOGd208B4Q01508V9R@2;
Rh/0T92@08V9R@1WIfL0G5aL06e]K@1bLW80MWIf07alO026QXH0PX:206YZJP1cLg<0TY:B07QhN01m
OGd0NWYj07=cL`1lO7`0MGEe0861P@1`L700IVIV06][J`1aLG40Jf][06QXJ01YJFT0H61P06YZJP1X
J6P0H61P05QHF01;Bd/0D51@05YJFP1KFe/0B4Q804Y:BP1>CTh0@T92038b<P0X:2P0>c/k04E5A@14
A4@0ADE504=3@`0l?3`0>c/k03Ph>00g=cL0<c<c04E5A@1UIFD0@d=301PH600B4Q801PH600410@02
0P801@D500l?3`0:2PX06QXJ01/K6`0410@00P8200@00@4100<0000000410@010@401@010@4H0000
00Oooooo0005oooooal0000000`00`<306ATI03`l?00oOgm0?Cdm03QhN40alO70;Jf]P2QXJ40U9BD
08n?S`2JVYX208Z:RP0R09ZJVP2KVi/0Ph>308N7Q`2=SHd0VYZJ0::RXP2MWId0V9RH08j>SP29RHT0
S8b<09:BTP2<S8`0QhN708J6QP23Ph<0OGem0820P01nOWh0MGEe07IfMP1mOGd0VIVI0;Jf]P39bLT0
alO70<S8b030`<00XZ:R09VIV@2GUiL0Shn?08^;R`80Q8B401T0QHF508b<S02LW9`0ZZZZ0;>c/`2n
_[h0]KFe0:^[Z`2SXj<0[Zj^0;>c/`2ZZZX0/;2`0:RXZ02h^;P0bLW90;Ng]`2h^;P0/[:b0:VYZ@2J
VYX0V9RH09jNWP2KVi/0YJFU0080UIFE01L0XZ:R09RHV029RHT0QXJ607moO`23Ph<0QHF508J6QP22
PX80UiNG09>CT`1oOgl0Lg=c06UYJ@1cLg<0PH610820P01jNWX0MgMg07]kN`24Q8@0Ng]k06IVIP02
07QhN00I071`L01lO7`0P82007MgM`1UIFD0FUYJ06YZJP1aLG40IfMW06IVIP1EEED0G5aL06m_K`1Z
JVX0GEeM04m?C`15ADD0C4a<05=CD`1FEUH0CDe=04U9B@1<C4`0AdM7038b<P0203Xj>P07051@D01>
CTh0CDe=04I6AP14A4@0@T9203Ph>00202l_;`0603Ti>@1OGel0<S8b010@40092@T03Ph>0P020P80
1P051@D061PH02@T900O7al061PH00<30`800P8200<00@4100820P020P8020010@4H000000Oooooo
0005oooooal0000001T05ADE0:b/[03kno/0no_k0>o_k`3?cll0^k^k0:BTY02GUiL0T92@09^KV`2U
YJD0R8R808n?S`2FUYH0R8R80820P027QhL0R8R8092@T02OWil0YJFU0:2PX02CTi<0S8b<0080Rh^;
00@0RXZ:08j>SP2DU9@0Rh^;0`21PH407P1eMGD0MWIf07YjNP2ATI40Y:BT0:VYZ@2a/K40^[Zj0;Bd
]02KVi/0T92@09:BTP2=SHd0Shn?08N7Q`25QHD0PH6108J6QP2?Shl0VYZJ0:f][@2l_;`0^KVi0;:b
/P2d];@0]kNg0;>c/`2VYZH0Z:RX0;2`/080_kno02/0/[:b0;Vi^@2b/[80ZJVY09^KV`2EUID0VYZJ
09jNWP2PX:00UYJF09FEU@2BTY80R8R808^;R`23Ph<0MWIf07QhN01mOGd0Q8B408R8R02BTY80U9BD
08^;R`22PX80Ogmo08>3P`27QhL0N7Qh07YjNP26QXH0O7al0861P@1YJFT0M7Ad07emO@24Q8@0M7Ad
07EeM@1_Kfl0F5QH06ATI01MGEd0JVYZ0080Kfm_01D0Hf=S05QHF01^KVh0MgMg06QXJ01CDe<0AdM7
04E5A@1?Cdl0E5AD05QHF01?Cdl0BTY:04m?C`0_;bl09BDU03Lg=`0c<c<0Cdm?05ADE01;Bd/00P17
AdL04@0l?3`0<S8b02h^;P0X:2P0<c<c04a<C00J6QX0?Shn01dM7@0=3@d010@400X:2P0>3Ph09bLW
02/[:`0B4Q801`L700800P8200<00`<300410@010@402@010@4H000000Oooooo0005oooooa/00000
00H00@4100000000000000000451@@3Ogml20?clo00=0>[ZjP35aLD0[:b/092@T02DU9@0WIfM0;>c
/`2/[:`0UYJF09BDU02FUYH0PX:207inOP0208>3P`0508B4Q02>SXh0UIFE09RHV02GUiL00P2ATI40
5`29RHT0Q8B408Z:RP2EUID0S8b<08>3P`25QHD0R8R807]kN`1hN7P0NWYj08:2PP2DU9@0VYZJ09nO
W`2/[:`0/K6a0:BTY02QXJ40UIFE08j>SP2<S8`0R8R800<0Q8B401<0RHV908^;R`2EUID0[:b/0;^k
^`2o_kl0^[Zj0;2`/02XZ:P0X:2P0:>SX`2][Jd0Zj^[0:ZZZP2/[:`0/k>c0;2`/02UYJD0WinO0080
U9BD04d0W9bL09NGU`2?Shl0S8b<08R8R026QXH0QhN707MgM`1/K6`0Kfm_07MgM`25QHD0RXZ:08b<
S02LW9`0UiNG08F5Q@1oOgl0QHF508N7Q`1fMWH0O7al0820P01mOGd0R8R8071`L01oOgl0TI6A08^;
R`1`L700K6a/061PH01NGUh0J6QX06=SH`1_Kfl0KVi^06QXJ01KFe/0HV9R06QXJ01SHf<0GUiN059B
DP19BDT0DE5A051@D01ADE40Fe]K059BDP19BDT0CDe=02@T900^;Rh0@D510492@P17AdL0@41004M7
A`12@T80?Shn02h^;P10@4009BDU020P800Y:BT0>c/k03dm?@1LG5`06QXJ00@410051@D02PX:00l?
3`0F5QH051@D00@4100400820P<00@410P020P8600410AP000001oooool000Gooooo7P000000400:
2PX0Ph>30>c/k03kno/0o?cl0>7Qh@2f][H0UYJF0861P@2GUiL0Z:RX0<71`@2m_Kd0ZJVY092@T02G
UiL207alO0040861P@20P800Ogmo0861P@80QhN700P0Rh^;08f=S@2@T900RXZ:08F5Q@24Q8@0RHV9
08b<S080QhN700X0PH6107alO01jNWX0O7al08:2PP28R8P0QhN7092@T02SXj<0Z:RX0P2UYJD0102B
TY80QhN708R8R02;Rh/208F5Q@0c08>3P`2:RXX0SXj>09JFUP2TY:@0][Jf0;Vi^@2f][H0/[:b0:^[
Z`2OWil0XZ:R0:JVYP2SXj<0Y:BT0:JVYP2WYjL0[:b/0:>SX`2LW9`0VIVI09>CT`2BTY80RXZ:08F5
Q@26QXH0SXj>08b<S01nOWh0L71`06e]K@1bLW80NGUi0820P02<S8`0T92@09>CT`2KVi/0MWIf071`
L025QHD0SHf=0861P@1lO7`0Ogmo07inOP1mOGd0NWYj08B4Q02FUYH0N7Qh0080KFe]02d0GemO061P
H01TI6@0JVYZ06m_K`1ZJVX0I6AT05YJFP1QHF40Jf][061PH01JFUX0Fe]K05iNGP1KFe/0CTi>05=C
D`1NGUh0C4a<04Y:BP11@D40=cLg03`l?01@D500C4a<03dm?@0i>CT0=3@d02<S8`0E5AD051@D01/K
6`0P82008b<S02DU9@0[:b/0ATI603Ph>0061PH010@400h>3P0D51@03@d=00l?3`0<30`01@020P83
00410@800P821P010@4H000000Oooooo0005oooooah0000003h0:RXZ0<O7a`3alO40no_k0?KfmP3>
c/h0YjNW07moO`1kNg/0Ti>C0;Fe]@3Kfm/0_kno0:2PX02KVi/0UIFE07YjNP1nOWh0Ph>30820P01m
OGd0OWin08B4Q023Ph<0PX:208B4Q02<S8`0TI6A08V9R@26QXH0Rh^;096AT@2=SHd0R8R807moO`1l
O7`0OGem07inOP22PX80SHf=0820P026QXH0Ti>C09ZJVP2MWId0Vi^K092@T02;Rh/0Ti>C09ZJVP2<
S8`0PH6108J6QP2TY:@0ZJVY0:2PX02VYZH0[Jf]0:^[Z`2TY:@0YJFU0:>SX`80WinO0P2SXj<0=`2T
Y:@0Z:RX0:f][@2`/;00Xj>S0:2PX02MWId0U9BD09>CT`2>SXh0PH6108:2PP2@T900SHf=0820P01i
NGT0Lg=c07]kN`27QhL0S8b<08j>SP2;Rh/0SHf=09^KV`1cLg<0MWIf08F5Q@2NWYh0OWin07YjNP25
QHD0Q8B407YjNP20P800MWIf07alO01]KFd0Kfm_06][J`1PH600GUiN06ATI01WIfL0I6AT069RHP1J
FUX0F5QH05mOG`1SHf<0FUYJ05UIF@1OGel0HF5Q04i>CP18B4P00P1GEeL01@11@D40A4A402l_;`1J
FUX0@d=30080C4a<00T0=cLg020P800D51@071`L01/K6`0H61P07AdM02DU9@0R8R800P0N7Qh02P1B
DU80@41000D51@0820P03Ph>00d=3@0820P02PX:00D51@030`<900820PH00@4160000007ooooo`00
1OoooolM0000000E00<30`1SHf<0gMgM0>g]k@3kno/0l?3`0<c<c02KVi/0LG5a07]kN`2GUiL0dM7A
0=kNgP2^[Zh0WinO09ZJVP2<S8`0OWin08B4Q023Ph<0P8200080Ogmo00H0Q8B408J6QP23Ph<0PH61
08B4Q027QhL208J6QP0508Z:RP2ATI40TY:B08n?S`26QXH00P20P80207moO`0908>3P`21PH40Q8B4
096AT@2FUYH0VYZJ09RHV02BTY80WinO0080YJFU0300U9BD08V9R@2=SHd0Zj^[0::RXP2BTY80Vi^K
0::RXP2QXJ40WinO09ZJVP2MWId0VYZJ09bLW02QXJ40Y:BT0:VYZ@2b/[80/K6a0;no_`2k^k/0[Zj^
0:BTY02HV9P0Vi^K09BDU028R8P0RXZ:08V9R@24Q8@0RHV907emO@1cLg<0P82008f=S@2?Shl0QXJ6
08F5Q@26QXH0VIVI08b<S026QXH0UYJF096AT@1aLG40N7Qh08:2PP21PH4207]kN`0306a/K01dM7@0
K6a/0080K6a/02T0J6QX05aLG01PH600J6QX06a/K01QHF40IFEU06MWI`1HF5P0EUIF06MWI`1OGel0
GEeM04a<C00/;2`0DU9B05QHF013@d<0@41004];B`1<C4`0I6AT04E5A@0o?cl0@d=301hN7P0=3@d0
8R8R02d];@0Y:BT09bLW02DU9@0S8b<09BDU02PX:00/;2`0ATI602<S8`0:2PX02@T900<30`0;0082
0PT00@4160000007ooooo`001OoooolI0000000B00410@00000000000000000A4A40WIfM0=OGe`3V
i^H0lo?c0>?Sh`2l_;`0RXZ:07EeM@23Ph<0W9bL0=cLg033`l<0UiNG0P2EUID0202:RXX0PX:208>3
P`22PX80QHF508B4Q021PH40PX:20P27QhL0HP25QHD0OGem07alO01oOgl0PH6108F5Q@28R8P0Shn?
096AT@2=SHd0Rh^;08J6QP1nOWh0O7al0861P@22PX80Ph>308N7Q`2>SXh0W9bL09fMW@2DU9@0XJ6Q
0:2PX02OWil0Ti>C08n?S`2EUID0YZJV09^KV`2JVYX0X:2P09fMW@2LW9`0WYjN09FEU@2HV9P0VIVI
09jNWP2YZJT0YjNW0:VYZ@2XZ:P0YJFU0;6a/@2n_[h0^KVi0;2`/02MWId0VIVI096AT@2BTY80Rh^;
08>3P`20P800OWin0820P022PX80SHf=08R8R02:RXX0Ph>307]kN`27QhL0UYJF09FEU@2@T900SHf=
07UiN@1aLG40MWIf0861P@1kNg/0OGem075aL@1[Jf/0LG5a06YZJP1`L700J6QX05aLG01EEED0Hf=S
071`L01XJ6P0F5QH06EUI@1QHF40F5QH05mOG`1MGEd0FUYJ05EEE@17AdL0>c/k06YZJP1QHF40@410
0P12@T802@19BDT0ADE503`l?010@400<S8b010@400<30`0:b/[02`/;00202PX:00902DU9@0O7al0
9RHV0410@00k>c/0=SHf01PH600D51@020P8008010@42P020P8300410@0300820P010@400@4100<0
0@4160000007ooooo`001OoooolL0000000O00410@0/;2`0^KVi0<g=c@3Ogml0iNGU0<[:bP2PX:00
PX:207]kN`29RHT0WinO0;jn_P2WYjL0Shn?09FEU@2:RXX0RHV908:2PP1oOgl0PH6108>3P`22PX80
Ph>308F5Q@29RHT0S8b<08^;R`20P800O7al07]kN`0207emO@0G07moO`27QhL0Rh^;08^;R`2BTY80
Rh^;0861P@1mOGd0NWYj07alO025QHD0RHV908f=S@2ATI40Vi^K0:FUY@2][Jd0Y:BT09nOW`2IVIT0
V9RH09NGU`2JVYX00P2OWil30:2PX00@09jNWP2FUYH0UIFE09RHV02NWYh0Y:BT0:VYZ@2ZZZX0Y:BT
09fMW@2RXZ80^KVi0<K6aP2a/K40Xj>S09ZJVP80SHf=02D0Ph>307emO@1hN7P0MgMg0861P@2=SHd0
S8b<08>3P`27QhL0PH6108>3P`2<S8`0RXZ:08J6QP28R8P0OWin079bLP1`L700Ng]k08J6QP1hN7P0
LG5a065QH@1UIFD0HF5Q06=SH`1/K6`0G5aL059BDP1EEED0FUYJ05mOG`1IFET0FUYJ05UIF@1BDU80
EeMG0080DE5A02@0GUiN05=CD`1?Cdl0Bd];05mOG`14A4@0>c/k03Lg=`11@D40A4A403Ti>@0k>c/0
@D5103Ph>00>3Ph03@d=02TY:@0_;bl0<c<c03`l?00Y:BT07AdM02HV9P15ADD0CTi>02LW9`0=3@d0
2PX:00H61P030`<01PH600@410020P800`<300820P010@4500820P<00@4100@00P8200410@020P80
0P820P010@4H000000Oooooo0005oooooa`0000001800`<305eMG@2o_kl0eMGE0=cLg03Hf=P0][Jf
09>CT`22PX80Ph>308j>SP2KVi/0WinO092@T02ATI40S8b<07alO025QHD207alO00507inOP1oOgl0
Ogmo0861P@24Q8@00P2<S8`0=P28R8P0Q8B40861P@1mOGd0O7al07emO@1kNg/0OGem08:2PP25QHD0
S8b<08j>SP24Q8@0PH6108>3P`28R8P0UIFE09BDU02BTY80V9RH0:2PX02WYjL0Zj^[0:>SX`2NWYh0
XJ6Q0:JVYP2JVYX0XJ6Q0:FUY@2TY:@0YjNW09fMW@2LW9`0Vi^K09fMW@2OWil0WYjN09bLW02QXJ40
YjNW0:ZZZP2^[Zh0ZZZZ09nOW`2][Jd0c/k>0=_Kf`2j^[X0V9RH08j>SP26QXH0OWin07MgM`80MWIf
01h0O7al08V9R@2=SHd0SHf=08N7Q`1kNg/0PX:208f=S@27QhL0Rh^;08j>SP25QHD0MWIf075aL@1f
MWH0P82007MgM`1OGel0E5AD05QHF01FEUH0HF5Q05mOG`1IFET0EEEE04i>CP1JFUX0HV9R05mOG`1D
E5@205QHF00705UIF@1OGel0H61P05MGE`1:BTX0ADE50410@00203/k>`0F04Y:BP1ADE40AdM703lo
?`0k>c/0?3`l03/k>`0m?Cd03`l?00L71`0O7al0;bl_03/k>`0^;Rh04a<C018B4P0^;Rh0E5AD03dm
?@0C4a<010@400<30`800P820P030`<800820P0800<30`020P800P8200820P030`<00P8200<30`02
0P8200410AP000001oooool000Gooooo5`0000000`010@400000000000020000000f00d=3@23Ph<0
_Kfm0=oOg`3IfMT0dM7A0:f][@2@T900R8R808Z:RP2ATI40V9RH09FEU@23Ph<0SHf=08>3P`1dM7@0
Ng]k07EeM@1dM7@0MgMg07emO@20P800Ogmo0820P025QHD0QhN708B4Q021PH40OWin07UiN@1jNWX0
OWin07]kN`1lO7`0OWin08:2PP29RHT0UYJF09>CT`2<S8`0UYJF09^KV`2NWYh0UiNG09>CT`2FUYH0
U9BD09^KV`2PX:00WYjN09^KV`2WYjL0Y:BT0P2QXJ406@2UYJD0WinO09fMW@2KVi/0VYZJ09bLW02M
WId0YJFU0:BTY02NWYh0XZ:R09bLW02GUiL0XJ6Q0;^k^`2XZ:P0X:2P0<[:bP3AdM40]KFe09VIV@2E
UID0SXj>08:2PP1lO7`00P1kNg/0=01jNWX0QhN709RHV02ATI40Ph>307alO01kNg/0Ph>309:BTP2G
UiL0S8b<08F5Q@1nOWh0MgMg07=cL`1oOgl0I6AT04U9B@1GEeL0Fe]K069RHP1SHf<0HV9R05mOG`1K
Fe/0FEUI061PH01VIVH0H61P05MGE`1WIfL0HV9R05aLG01NGUh0IVIV04e=C@0o?cl0ATI60451@@0n
?Sh0A4A405=CD`1RHV80@41003hn?P0m?Cd0>c/k03Ph>00d=3@061PH00H61P0H61P202PX:00801DE
5@0?3`l03`l?03De=@1BDU807AdM01hN7P0=3@d800820P0300410@020P800P8200T00P820`010@4H
000000Oooooo0005oooooa`0000001D092@T0:VYZ@30`<00hn?S0>7Qh@38b<P0XJ6Q08Z:RP2=SHd0
Shn?092@T02GUiL0UIFE08j>SP2ATI40Q8B406m_K`1hN7P0MWIf079bLP1gMgL00P20P80207emO@07
0861P@22PX80PH6107moO`1lO7`0MgMg07QhN00207alO00B07moO`20P800R8R809JFUP2VYZH0[Zj^
09NGU`2FUYH0XZ:R09VIV@2CTi<0UYJF096AT@2<S8`0U9BD09VIV@2LW9`0WinO0`2PX:00<@2XZ:P0
Xj>S09BDU02EUID0WIfM09VIV@2JVYX0WinO0:6QX@2VYZH0[Jf]0:2PX02GUiL0YZJV0:FUY@2_[jl0
]KFe0:6QX@2a/K40[Jf]09fMW@2GUiL0Vi^K09JFUP27QhL0QHF507inOP1lO7`0PX:2092@T02LW9`0
RXZ:07UiN@1kNg/0NGUi07MgM`2>SXh0VIVI08b<S026QXH0QHF507EeM@1cLg<0MGEe05=CD`1GEeL0
I6AT06EUI@1TI6@00P1VIVH05@1PH600G5aL05aLG01UIFD0KVi^06ATI01OGel0IFEU05YJFP1ADE40
F5QH05aLG00n?Sh0@T9203hn?P0m?Cd0?Shn0410@01;Bd/0HV9R04A4A00203Xj>P0E03<c<`0h>3P0
;Rh^02PX:00B4Q806a/K02LW9`0V9RH0:BTY020P800S8b<0>SXj03dm?@0Z:RX0;Rh^00/;2`020P80
1PH600<30`020P800`<300`00P8200<00@4100820P020P800`010@4H000000Oooooo0005oooooa/0
000000T00@4104e=C@2e]KD0bLW90>3Ph03Vi^H0`/;209VIV@2:RXX00P2?Shl03`2BTY80WinO0:BT
Y02NWYh0SXj>09>CT`1aLG40MWIf07MgM`1bLW80MWIf08:2PP20P800Ogmo07alO00307inOP0A07mo
O`1mOGd0NWYj07YjNP1mOGd0P82008B4Q025QHD0VIVI0:BTY02/[:`0ZJVY08j>SP2:RXX0TI6A09:B
TP2ATI400P2BTY80802?Shl0Ti>C09NGU`2PX:00Y:BT0:>SX`2NWYh0Xj>S0:6QX@2IVIT0T92@09BD
U02LW9`0Xj>S0:2PX02QXJ40XZ:R0:JVYP2/[:`0W9bL09NGU`2[Zj/0[Zj^0:NWY`2f][H0XJ6Q0:VY
Z@2UYJD0WinO09BDU02CTi<0T92@0P2BTY809`27QhL0QXJ608n?S`2HV9P0WYjN08V9R@1fMWH0MGEe
07YjNP1hN7P0RHV909VIV@26QXH0OWin08b<S01fMWH0LG5a06=SH`1GEeL0Hf=S06QXJ01OGel0EUIF
07AdM01/K6`0HF5Q05eMG@1NGUh0IfMW06UYJ@1TI6@0EEEE05]KF`1IFET0FUYJ069RHP1GEeL0ATI6
04U9B@0204E5A@0704Q8B011@D40BTY:05MGE`1<C4`0?Shn03/k>`02034a<@0301lO7`0b<S80;Bd]
0080:RXZ00/0:2PX03/k>`0c<c<0?Cdm059BDP0`<300=SHf00h>3P030`<00P8200<30`0C00820P03
000000010@40000001L000001oooool000Gooooo6000000030010@4000000000000410@0NWYj0;Rh
^03@d=00g]kN0>;RhP2o_kl0Ti>C08j>SP80T92@00/0Ti>C0:>SX`2OWil0SXj>08N7Q`22PX80LG5a
07IfMP1gMgL0M7Ad07]kN`0208:2PP030820P01mOGd0Ogmo0080OGem00h0Ogmo07inOP1nOWh0P820
08F5Q@24Q8@0RHV9096AT@2OWil0YZJV0:RXZ02HV9P0QXJ608N7Q`<0S8b<00l0UYJF09ZJVP2HV9P0
UYJF0:>SX`2c/k<0Z:RX0:NWY`2TY:@0Z:RX09nOW`2FUYH0TY:B09ZJVP2PX:000P2][Jd0B@2QXJ40
[Zj^0;Ng]`2PX:00XZ:R09fMW@2^[Zh0/k>c0:ZZZP2YZJT0W9bL0:NWY`2/[:`0XZ:R092@T02>SXh0
Shn?092@T02JVYX0S8b<08B4Q027QhL0UYJF0:FUY@2EUID0QHF50861P@24Q8@0NWYj08>3P`2DU9@0
M7Ad07inOP2=SHd0OGem06e]K@1TI6@0J6QX06][J`1YJFT0HF5Q06MWI`1mOGd0K6a/061PH01OGel0
H61P06IVIP1OGel0F5QH059BDP1PH600GEeM05aLG01MGEd0EeMG0451@@17AdL0?clo0492@P0d=3@0
=cLg04I6AP1FEUH0DE5A03Xj>P13@d<0=3@d02XZ:P0S8b<0<c<c03`l?00e=CD00P0Z:RX02@0l?3`0
>SXj04A4A01>CTh0820P01dM7@061PH00`<300820P0200<30a800P820P010@4H000000Oooooo0005
oooooa/00000018051@D0;2`/034a<@0e=CD0=GEe@3AdM40[Jf]09:BTP2GUiL0VIVI09NGU`2PX:00
Z:RX09NGU`2@T900SHf=07YjNP1`L70207]kN`0907moO`25QHD0R8R808^;R`25QHD0PH6108:2PP23
Ph<0PX:20080P82002/0Ph>30861P@23Ph<0QHF508V9R@2CTi<0VYZJ0:JVYP2PX:00SXj>08R8R029
RHT0S8b<08f=S@2;Rh/0Ti>C0:2PX02VYZH0ZZZZ0;Jf]P2j^[X0Y:BT0:^[Z`2YZJT0WIfM09RHV02B
TY80Ti>C09jNWP2TY:@0Zj^[0:BTY02RXZ80[:b/0;>c/`2[Zj/0X:2P0:BTY02][Jd0/;2`0:2PX02I
VIT0Vi^K0080X:2P00<0W9bL09>CT`2>SXh00P2EUID09P2CTi<0T92@08j>SP2MWId0Y:BT0:6QX@2F
UYH0SXj>08R8R029RHT0Ogmo0820P01nOWh0N7Qh08:2PP27QhL0PX:2071`L01YJFT0JVYZ06MWI`1S
Hf<0IVIV06][J`1ZJVX0IFEU06=SH`1/K6`0JVYZ07=cL`1/K6`0G5aL05]KF`1VIVH0FUYJ05QHF01@
D500C4a<0P13@d<03`11@D40Bd];04e=C@18B4P0?clo051@D011@D40?Cdm034a<@0g=cL0<30`024Q
8@0Z:RX0:b/[02DU9@0201dM7@0602<S8`0`<300;Rh^01`L700;2`/01@D50P030`<A00820P0300<3
0`020P800P8200800@4100<0000000410@0000005P000007ooooo`001OoooolJ0000000800410@0`
<300^;Rh0<o?c`3Ogml0c/k>0;no_`2MWId209RHV00909BDU02UYJD0[Zj^09bLW02UYJD0VYZJ09>C
T`20P800M7Ad0080Ng]k00P0Ogmo08V9R@2GUiL0UIFE08B4Q022PX80QXJ608V9R@80PH610P23Ph<0
3022PX80Q8B408F5Q@27QhL0TI6A0:FUY@2[Zj/0YZJV09ZJVP2CTi<0SHf=08j>SP80S8b<01@0SHf=
09bLW02HV9P0UiNG0:NWY`2g]kL0ZJVY0:JVYP2e]KD0XZ:R09bLW02EUID0UYJF09VIV@2KVi/0XJ6Q
0:JVYP2/[:`0Zj^[0;Jf]P80Y:BT0100XZ:R0:FUY@2YZJT0V9RH09^KV`2LW9`0WIfM09nOW`2JVYX0
Rh^;08F5Q@29RHT0W9bL0:b/[02XZ:P0VIVI0P2;Rh/00`2>SXh0VIVI09NGU`0208J6QP0<08V9R@22
PX80PH6107QhN01cLg<0NWYj07EeM@1dM7@0LW9b06][J`1WIfL0HV9R0`1OGel0201_Kfl0N7Qh075a
L@1ZJVX0KFe]0820P01<C4`0D51@0P1ZJVX01@1IFET0Bd];04U9B@1<C4`0Bd];0080EUIF00T0A4A4
03Lg=`0g=cL0Cdm?04];B`0d=3@0<30`0451@@0U9BD00P0?3`l03@0H61P08b<S02LW9`0d=3@0820P
00l?3`0J6QX02`/;00820P030`<010@400820P010@404@020P8300410AX000001oooool000Gooooo
6`0000004@14A4@0[jn_0=KFeP3QhN40c/k>0;2`/02DU9@0Vi^K09NGU`2EUID0[jn_0;>c/`2XZ:P0
[Jf]0:BTY02JVYX0RXZ:0080Ng]k00/0OGem08>3P`2;Rh/0TY:B08Z:RP21PH40OGem07QhN01eMGD0
NGUi07inOP0208J6QP<0P82000P0QXJ609:BTP2a/K40[jn_0;2`/02VYZH0UIFE08Z:RP80SXj>00<0
S8b<08n?S`2NWYh00P2NWYh09P2JVYX0UYJF09NGU`2KVi/0ZZZZ0:JVYP2OWil0XJ6Q09bLW02KVi/0
V9RH09^KV`2SXj<0ZJVY0:f][@2VYZH0XZ:R0:FUY@2RXZ80WinO0:>SX`2LW9`0WYjN09bLW02IVIT0
Vi^K09nOW`2>SXh0P82008n?S`2WYjL0[:b/09fMW@1jNWX0K6a/07IfMP1lO7`0QhN70P2JVYX0=027
QhL0SXj>07]kN`1gMgL0K6a/079bLP1mOGd0L71`07IfMP1iNGT0K6a/06UYJ@1SHf<0G5aL05iNGP1R
HV80LG5a06a/K01RHV80Hf=S06m_K`1MGEd0@d=306EUI@1_Kfl0GEeM059BDP1@D500Bd];055AD@17
AdL0DU9B0410@00j>SX0<c<c03Ti>@1=CDd0EeMG03dm?@0_;bl0:BTY02<S8`0I6AT051@D02<S8`0Z
:RX0=3@d03Ph>00L71`04A4A01<C4`061PH200820P800@414P020P8300410AX000001oooool000Go
oooo6`0000002`1HF5P0[:b/0=SHf03EeMD0_;bl0:FUY@2GUiL0V9RH09NGU`2LW9`0/K6a00<0/[:b
0180[:b/0:FUY@2KVi/0UYJF08B4Q01oOgl0PH6108n?S`2CTi<0QhN70820P01iNGT0L71`079bLP1n
OWh0PH6108J6QP23Ph<207alO00G07moO`26QXH0WinO0;>c/`2e]KD0]kNg0:2PX02?Shl0RHV909>C
T`2=SHd0Shn?09:BTP2EUID0V9RH09VIV@2<S8`0TY:B09fMW@2EUID0VIVI09jNWP2RXZ800P2WYjL0
1P2[Zj/0YZJV0:6QX@2RXZ80V9RH09fMW@80YJFU01T0Y:BT0:FUY@2RXZ80WYjN09nOW`2RXZ80XJ6Q
09ZJVP2GUiL0Xj>S0:6QX@2ATI40V9RH0;2`/02_[jl0Shn?06YZJP1XJ6P0IfMW06i^KP1dM7@0S8b<
0:NWY`28R8P0S8b<0080O7al0340Ng]k07QhN01aLG40L71`07MgM`1hN7P0Kfm_06a/K01OGel0GEeM
061PH01SHf<0Kfm_065QH@1OGel0GEeM05]KF`19BDT0BTY:05IFEP1RHV80Kfm_055AD@10@400BDU9
04=3@`11@D40F5QH0492@P0o?cl0>3Ph03Xj>P1;Bd/0E5AD02/[:`0/;2`0?Cdm02h^;P0S8b<06a/K
02@T900Q8B40;Rh^034a<@0B4Q801@D500P820030`<00P8200<00@414P020P8200410A/000001ooo
ool000Gooooo6000000300410@0U06][J`2[Zj/0eMGE0<S8b02XZ:P0WYjN09VIV@2CTi<0VYZJ0:FU
Y@2][Jd0_;bl0;Rh^02g]kL0^[Zj0;Bd]02VYZH0[jn_09FEU@24Q8@0PX:208Z:RP2BTY80RHV90820
P01gMgL0Lg=c07IfMP1oOgl0Ph>308J6QP22PX80Ng]k07UiN@1kNg/0Rh^;0:ZZZP020;Fe]@090:n_
[`2TY:@0W9bL09:BTP2CTi<0TI6A09bLW02IVIT0TI6A0080Shn?00@0SXj>09NGU`2RXZ80W9bL0P2A
TI40=@2KVi/0Z:RX0:f][@2^[Zh0[Jf]0:NWY`2QXJ40VIVI09RHV02UYJD0Xj>S0:6QX@2TY:@0ZZZZ
0:6QX@2FUYH0X:2P09jNWP2PX:00UYJF09RHV02KVi/0UIFE09>CT`2_[jl0];Bd0861P@1^KVh0Jf][
06MWI`1[Jf/0Lg=c08J6QP2PX:00P82008Z:RP1lO7`0Ogmo07EeM@1TI6@0Hf=S06i^KP1`L700K6a/
071`L01^KVh0IVIV05mOG`1XJ6P0Hf=S05=CD`1:BTX0CTi>0080Cdm?01`0CDe=04m?C`1@D500EeMG
06YZJP1CDe<0ADE505]KF`1=CDd0DU9B04M7A`0];Bd0BTY:04=3@`17AdL0?clo04E5A@0[:b/0ADE5
03<c<`0o?cl08R8R01TI6@0Q8B4092@T03Ti>@0Y:BT03@d=0P071`L00`030`<00P8200820P0D0082
0P800@416`000007ooooo`001OoooolJ0000000600410@1kNg/0ZZZZ0<G5a@2k^k/0Vi^K0P2QXJ40
3@2EUID0XZ:R0:b/[02a/K40`/;20<71`@30`<00alO70<W9b@2e]KD0`/;209nOW`2>SXh00P26QXH0
E@2=SHd0T92@08J6QP1mOGd0N7Qh07MgM`21PH40RHV908J6QP21PH40O7al07QhN01kNg/0Vi^K0;6a
/@2g]kL0/[:b0:f][@2UYJD0UYJF08V9R@2FUYH0W9bL0:FUY@2OWil0Shn?08j>SP2ATI40V9RH0:2P
X02`/;00Xj>S08f=S@28R8P0TI6A09RHV02LW9`0VYZJ0:>SX`2WYjL0YZJV0:2PX02MWId0Y:BT0:6Q
X@2PX:00Y:BT0:RXZ02TY:@0WIfM0:NWY`2JVYX0Y:BT09bLW02GUiL0Ti>C08B4Q028R8P0Xj>S0<?3
``2DU9@0MgMg07EeM@1]KFd0KVi^07AdM01nOWh0V9RH07moO`1nOWh0RHV907QhN01ZJVX0GemO06a/
K01_Kfl0KFe]06IVIP1[Jf/0KFe]06EUI@1[Jf/0HV9R04I6AP0o?cl00P15ADD00`14A4@0@T9204E5
A@0204e=C@0E04i>CP1DE5@0Bd];06ATI01SHf<0C4a<03lo?`0j>SX0@T9204a<C012@T80>CTi03`l
?010@400?Cdm03Hf=P0h>3P0>c/k01TI6@0P8200<30`0080=SHf00D07alO00/;2`0G5aL05QHF00D5
1@0F00820P0300410@000000000001X000001oooool000Gooooo6P000000?`0410@0QHF50:NWY`2c
/k<0XJ6Q08^;R`2JVYX0Y:BT09jNWP2d];@0^;Rh0;^k^`3=cLd0bl_;0<W9b@3Bd]80h>3P0<30`02e
]KD0Xj>S09ZJVP29RHT0QHF508R8R02>SXh0R8R807inOP1jNWX0N7Qh08:2PP2>SXh0QXJ607emO@1i
NGT0O7al08J6QP2VYZH0]kNg0;Rh^02d];@0/k>c0;6a/@2NWYh0RHV909VIV@2SXj<0/K6a09jNWP2@
T900Shn?09:BTP2HV9P0YjNW0:RXZ02HV9P0S8b<08J6QP27QhL0RHV908^;R`2@T900UIFE09^KV`02
0:2PX0050:6QX@2PX:00Z:RX09^KV`2IVIT00P2OWil01`2NWYh0Vi^K09^KV`2JVYX0WinO0:6QX@2R
XZ800P28R8P03P2RXZ80_Kfm0:2PX02;Rh/0OGem07=cL`1gMgL0Ogmo09BDU02FUYH0NWYj0820P028
R8P0JVYZ0P1RHV8206YZJP0F06UYJ@1[Jf/0I6AT07IfMP1cLg<0J6QX051@D00o?cl0?Cdm03hn?P0l
?3`0>CTi03lo?`17AdL0BDU904Y:BP1=CDd0CTi>04a<C01LG5`0BDU903/k>`80?3`l01@0=3@d03Ti
>@0j>SX0>SXj04Q8B01:BTX0BDU904E5A@1BDU80:BTY00`<300Q8B40=CDe02d];@0O7al07QhN014A
4@0K6a/04A4A00@411H00P8200<00@410000000000006P000007ooooo`001OoooolJ0000001600`<
3029RHT0WIfM0:>SX`2=SHd0OGem09ZJVP2][Jd0/[:b0;no_`36a/H0bLW90>7Qh@3Kfm/0cLg=0=;B
dP3Lg=`0_;bl0:ZZZP2/[:`0X:2P092@T026QXH0RHV908R8R026QXH0Ph>307inOP1kNg/0QXJ608N7
Q`23Ph<0NGUi07=cL`1iNGT0TI6A0;^k^`2n_[h0^KVi0;6a/@2^[Zh0/k>c0:VYZ@2NWYh0Xj>S0:JV
YP2QXJ40UiNG09:BTP2CTi<0TY:B096AT@2EUID0Ti>C08Z:RP2<S8`0RHV908F5Q@2:RXX0R8R808:2
PP27QhL0S8b<096AT@2HV9P0W9bL09FEU@2JVYX0UIFE09VIV@80WIfM00L0YjNW0:FUY@2FUYH0U9BD
09NGU`2KVi/0YjNW0080Y:BT01X0[Zj^0:ZZZP2NWYh0WYjN08V9R@2:RXX0Rh^;09ZJVP2FUYH0P820
07inOP26QXH0RHV9061PH01SHf<0I6AT06EUI@1SHf<0H61P06UYJ@1XJ6P0KFe]075aL@1OGel0BTY:
03dm?@80?3`l00<0>SXj03/k>`0n?Sh00P12@T802017AdL0Bd];04Q8B01<C4`0CDe=0492@P1?Cdl0
DE5A0P0c<c<0400o?cl0>SXj03Hf=P0i>CT0@d=303`l?00_;bl0;Rh^01@D50061PH09bLW03Ti>@0E
5AD04Q8B01DE5@092@T200d=3@0300@410020P800`<301@00P827@000007ooooo`001OoooolJ0000
000401@D5028R8P0TY:B09>CT`80NWYj00T0WYjN0;Zj^P2o_kl0b<S80<_;b`3AdM40k>c/0>OWi`3@
d=000P3:b/X0602m_Kd0]kNg0;2`/02MWId0U9BD08n?S`2DU9@0SXj>09VIV@2>SXh0Q8B40820P021
PH40NGUi07moO`1mOGd0Ng]k08:2PP2IVIT0_;bl0<30`02o_kl0/;2`0:VYZ@80/;2`00P0Zj^[0:FU
Y@2RXZ80WIfM09ZJVP2FUYH0TY:B092@T080TI6A00h0T92@08j>SP2<S8`0Rh^;08B4Q029RHT0QXJ6
07inOP23Ph<0OGem0820P02?Shl0V9RH08n?S`80Rh^;01<0Ti>C09ZJVP2JVYX0XJ6Q0:VYZ@2BTY80
Ti>C09^KV`2LW9`0Y:BT0:^[Z`2YZJT0ZZZZ09fMW@2QXJ40X:2P08b<S02FUYH0T92@0080Rh^;00L0
OWin07YjNP26QXH0Ph>306e]K@1_Kfl0J6QX0080Hf=S00l0I6AT06][J`1]KFd0JVYZ06m_K`1SHf<0
B4Q803hn?P0l?3`0>c/k03Xj>P0l?3`0@41003lo?`0l?3`00P10@4003P0m?Cd0@41004I6AP16ATH0
BDU904I6AP0_;bl0>CTi03Xj>P0g=cL0<c<c03@d=00l?3`0A4A40P0/;2`03@0I6AT05ADE030`<00_
;bl04Q8B01hN7P0=3@d00`<300@4100;2`/010@400820P030`<04P020P8200410Ad000001oooool0
00Gooooo6P000000;@0P8200QHF5096AT@25QHD0Kfm_0861P@2XZ:P0alO70<_;b`3:b/X0clo?0=[J
fP3alO40l?3`0=?Cd`3<c<`0`<300;jn_P3EeMD0^k^k0:6QX@2ATI40UYJF09:BTP2EUID0ZJVY09nO
W`2=SHd0QhN70861P@1mOGd0Ph>308b<S029RHT0UIFE0:j^[P2o_kl0`/;20;jn_P2f][H0[Zj^0:n_
[`2e]KD0[Jf]0:FUY@020:>SX`060:JVYP2SXj<0U9BD08f=S@2?Shl0SXj>0P2HV9P01@2IVIT0SHf=
08N7Q`20P800PX:20080Ph>300L0MWIf07YjNP2;Rh/0TI6A092@T02BTY80S8b<0080T92@00<0Shn?
09JFUP2UYJD00P2DU9@20:6QX@0A0:>SX`2UYJD0ZJVY0;2`/02NWYh0VIVI09FEU@2ATI40Shn?092@
T024Q8@0PH610820P01mOGd0R8R80820P01gMgL00P1WIfL01@1UIFD0JVYZ06UYJ@1TI6@0KVi^0080
LG5a00T0HV9R05=CD`15ADD0?clo03dm?@0j>SX0>c/k03hn?P0m?Cd00P0j>SX04P0h>3P0=cLg03lo
?`17AdL0ADE504e=C@1DE5@0=3@d034a<@0h>3P0?3`l03Hf=P0d=3@0?clo0492@P0T92@09BDU01lO
7`809bLW00@02`/;00D51@0<30`01@D50P030`<00`0410@01@D500<30`0B00820P0300410@000000
000001d000001oooool000Gooooo6@000000;`010@40<c<c08:2PP2DU9@0RXZ:07alO02;Rh/0[jn_
0<c<c03MgMd0c/k>0=GEe@3Shn<0lO7a0>SXj03?cll0_[jn0:b/[02][Jd0b<S80<30`02UYJD0VYZJ
0:RXZ02YZJT0[:b/0;>c/`2e]KD0/k>c0:f][@2?Shl0T92@09^KV`2EUID0Vi^K0;:b/P2k^k/0[jn_
0;Jf]P2n_[h0][Jf0:j^[P2][Jd0]kNg0:b/[02XZ:P0[:b/0080[Zj^00D0Xj>S09ZJVP2BTY80UYJF
09NGU`0209bLW00?09NGU`2IVIT0V9RH092@T02=SHd0RHV908R8R01jNWX0MgMg07YjNP1oOgl0QHF5
08Z:RP2<S8`0T92@0080Q8B400/0Rh^;09BDU02JVYX0UIFE09bLW02XZ:P0[jn_0:JVYP2/[:`0[jn_
09ZJVP0209NGU`0A08j>SP28R8P0Rh^;07moO`1kNg/0PX:208J6QP2?Shl0QhN706YZJP1SHf<0J6QX
06EUI@1[Jf/0K6a/06IVIP1ZJVX00P1/K6`02@1SHf<0G5aL05IFEP14A4@0?clo03/k>`0h>3P0?Cdm
03lo?`0203`l?00703dm?@0k>c/0@T9204U9B@14A4@0Bd];04A4A00203lo?`0@03dm?@0k>c/0?Cdm
0410@00h>3P0@D5102<S8`0Y:BT092@T02PX:00J6QX01@D500<30`051@D04a<C00H61P@00P8200<0
10@400820P020P803`020P800`010@4000000000000M000000Oooooo0005oooooaT0000002X00P82
04E5A@1mOGd0TY:B096AT@28R8P0VIVI0;Jf]P3:b/X0e=CD0<k>cP3EeMD0gmoO0>?Sh`3Ti>@0`l?3
0::RXP2?Shl0WYjN0;Fe]@2YZJT0XJ6Q09fMW@2/[:`0`/;20<30`02e]KD0a/K60=?Cd`3;bl/0Z:RX
0:b/[02l_;`0]KFe0;Jf]P32`/80/k>c0::RXP2h^;P0_Kfm0;Jf]P2`/;020:f][@0S0:JVYP2XZ:P0
[Zj^0;Fe]@2^[Zh0WinO09bLW02JVYX0XZ:R0:2PX02LW9`0VYZJ092@T02BTY80UYJF09FEU@2>SXh0
QXJ608>3P`1gMgL0M7Ad07QhN01iNGT0NWYj07alO01nOWh0PH6108F5Q@29RHT0QhN708j>SP2GUiL0
VYZJ09jNWP2SXj<00P2/[:`04@2TY:@0ZZZZ09NGU`2;Rh/0Q8B408V9R@2BTY80Ph>307emO@22PX80
TY:B09JFUP2=SHd0Ph>3061PH01TI6@0KFe]0080IVIV00d0Jf][06a/K01/K6`0JVYZ06UYJ@1TI6@0
IVIV05UIF@1=CDd0@T9203/k>`0j>SX0?Cdm0080ADE501X0ATI604E5A@0m?Cd0@D5104Q8B012@T80
A4A405EEE@1RHV80@T9203Xj>P0k>c/0>CTi03@d=00c<c<0?clo02HV9P0K6a/051@D01/K6`0F5QH0
20P800D51@0?3`l0:BTY00h>3Q<00P8200@00@4100820P010@400@417`000007ooooo`001OoooolH
0000000500410@0410@0EeMG07moO`2?Shl00P2DU9@08P2[Zj/0^KVi0<?3``31`L40aLG50=3@d03A
dM40clo?0<?3``2[Zj/0V9RH08Z:RP2SXj<0/k>c0:BTY02NWYh0W9bL09jNWP2VYZH0/K6a0:n_[`32
`/80fm_K0=OGe`30`<00`l?30<c<c03>c/h0bl_;0<G5a@2WYjL0X:2P0;2`/02e]KD20;Rh^0090;Bd
]02^[Zh0Z:RX0:^[Z`2b/[80^KVi0:ZZZP2SXj<0WinO0080Vi^K00l0UYJF09VIV@2GUiL0Shn?08F5
Q@26QXH0Q8B40861P@20P800NGUi07AdM01eMGD0NWYj07IfMP1dM7@00P1fMWH09@1mOGd0PX:208R8
R02=SHd0UYJF09NGU`2RXZ80Xj>S0:6QX@2UYJD0YjNW0:JVYP2UYJD0UYJF08b<S02>SXh0TY:B09BD
U02@T900R8R8096AT@2LW9`0SXj>0820P01fMWH0FUYJ05UIF@1UIFD0I6AT061PH01]KFd0MWIf06][
J`1^KVh0NGUi06e]K@1YJFT00P1FEUH01@1=CDd0@D5103hn?P0k>c/0A4A400<0BDU900l0@D510492
@P13@d<0@T9204e=C@1BDU80EeMG0410@00j>SX0<S8b03De=@0_;bl0@41003Xj>P0;2`/00P0410@0
1`051@D020P800P820071`L03`l?01lO7`0820P05@020P800`010@4000000000000N000000Oooooo
0005oooooaT0000003402@T906EUI@25QHD0T92@09BDU02MWId0_Kfm0<O7a`30`<00a<C40<o?c`3<
c<`0d=3@0<c<c02b/[80VIVI08Z:RP2>SXh0ZJVY0<;2`P2b/[80XZ:R09nOW`2QXJ40Z:RX0:VYZ@2]
[Jd0`l?30>7Qh@3MgMd0a/K60<C4a035aLD0b/[:0<k>cP37alL0/[:b0:RXZ02d];@0][Jf0;bl_036
a/H0^KVi0;fm_@2d];@0[Jf]0;Ng]`31`L40[jn_0080XJ6Q00H0X:2P09^KV`2BTY80TY:B09FEU@2=
SHd20861P@0807emO@1lO7`0Ogmo07QhN01cLg<0M7Ad07IfMP1aLG43071`L00907UiN@26QXH0P820
0861P@2>SXh0Ti>C0:6QX@2/[:`0[Zj^0080Z:RX00L0[Zj^0;2`/02PX:00T92@08j>SP2BTY80UIFE
0080V9RH02T0VIVI08B4Q027QhL0Ph>306ATI01BDU80Fe]K06=SH`1HF5P0FUYJ07MgM`23Ph<0JVYZ
07UiN@1cLg<0I6AT05]KF`1HF5P0EeMG05IFEP1;Bd/0@d=304A4A018B4P0BDU904Q8B00o?cl0=SHf
04A4A01>CTh0Cdm?05]KF`15ADD0Bd];03hn?P0`<3009RHV02h^;P0_;bl0A4A402HV9P0200820P08
00H61P071`L010@400X:2P0E5AD04a<C014A4@030`<E00820P0300410@000000000001h000001ooo
ool000Gooooo600000007`020P803`l?07YjNP2>SXh0UYJF09NGU`2MWId0^KVi0<K6aP34a<@0bLW9
0<[:bP35aLD0c<c<0<W9b@2h^;P0WIfM09:BTP2CTi<0/[:b0<?3``2i^KT0[jn_0:RXZ02TY:@0XJ6Q
09jNWP2TY:@0^k^k0<c<c036a/H00P3<c<`0802m_Kd0bl_;0=?Cd`3=cLd0bl_;0<30`02l_;`0^;Rh
0<71`@30`<00_;bl0<C4a02n_[h0YZJV0;>c/`2f][H0[:b/0:6QX@2KVi/0WYjN09^KV`2>SXh0T92@
08f=S@27QhL0O7al0820P01oOgl0O7al07QhN01gMgL0MWIf0P1bLW80<@1^KVh0Jf][06a/K01`L700
OWin096AT@24Q8@0Ng]k08>3P`2KVi/0WYjN0:RXZ02YZJT0ZZZZ0:RXZ02_[jl0^[Zj0:FUY@2EUID0
Ti>C09ZJVP2KVi/0UIFE09NGU`2LW9`0Rh^;07moO`1[Jf/0I6AT05mOG`1QHF40JVYZ05eMG@1VIVH0
O7al08j>SP1bLW80NGUi06QXJ01[Jf/0EEEE069RHP1MGEd0FEUI05IFEP18B4P0Bd];04a<C017AdL0
0P16ATH05`0n?Sh0B4Q8059BDP1;Bd/0BDU903Ti>@17AdL0?Cdm02DU9@0W9bL0<30`03De=@12@T80
6a/K00<30`0=3@d04a<C018B4P0:2PX03Ph>01hN7P0<30`010@401@00P820P010@4Q000000Oooooo
0005oooooaT0000001h05ADE08b<S02MWId0X:2P09^KV`2NWYh0];Bd0<K6aP35aLD0[Zj^0:b/[02m
_Kd0`/;20<?3``2d];@0WinO09VIV@2JVYX0]KFe0;jn_P2i^KT0];Bd0:RXZ02RXZ80Vi^K09RHV02M
WId0ZJVY0;Ng]`30`<020<_;b`0E0<;2`P3De=@0bLW90;jn_P3;bl/0`<300;Bd]02l_;`0_kno0<?3
``36a/H0cLg=0<?3``2VYZH0Z:RX0:j^[P2OWil0UiNG09>CT`2BTY80S8b<0080QHF503/0QXJ608V9
R@1kNg/0P82007]kN`1gMgL0MGEe07UiN@1fMWH0Lg=c079bLP1_Kfl0Jf][06e]K@1^KVh0PH61096A
T@25QHD0PX:208J6QP2MWId0Y:BT0:JVYP2KVi/0YJFU0:^[Z`2b/[80];Bd0:b/[02PX:00VYZJ0:>S
X`2MWId0TI6A09BDU02RXZ80Shn?07EeM@1SHf<0LW9b06i^KP1SHf<0MgMg07=cL`1dM7@0PX:207Yj
NP1/K6`0Kfm_06QXJ01MGEd0C4a<05EEE@1NGUh0G5aL05eMG@1EEED0D51@059BDP0204Y:BP0504Q8
B014A4@0ATI60451@@0n?Sh00P13@d<01010@400=cLg02LW9`0g=cL203@d=00;02h^;P0<30`02@T9
01DE5@0G5aL051@D00`<300:2PX06ATI018B4P0410@00P030`<B00820P0300410@00000000000200
00001oooool000Gooooo600000007`010@4071`L09FEU@2[Zj/0YjNW0:2PX02JVYX0/K6a0<?3``2_
[jl0VYZJ09VIV@2c/k<0`<300;Zj^P2][Jd0Xj>S0::RXP2SXj<0^k^k0<?3``2j^[X0]kNg0:NWY`2I
VIT0U9BD09jNWP2SXj<0[:b/0;>c/`2j^[X00P3;bl/08`3EeMD0bl_;0;fm_@2j^[X0`L710;Bd]02^
[Zh0`<300;Rh^03;bl/0fMWI0>3Ph02o_kl0YJFU09bLW02NWYh0UiNG09FEU@2FUYH0Shn?08j>SP2<
S8`0QHF508:2PP24Q8@0OGem07YjNP1hN7P0LW9b075aL@1fMWH0Lg=c06m_K`1bLW80L71`00<0KVi^
00P0OGem08N7Q`26QXH0PH6108:2PP2HV9P0XJ6Q0:2PX080WinO01@0Xj>S0:j^[P2d];@0[:b/0:JV
YP2MWId0UYJF09NGU`2?Shl0UIFE09VIV@29RHT0K6a/06UYJ@1gMgL0JVYZ06MWI`1dM7@0LG5a07=c
L`80KFe]0180LG5a06QXJ01PH600G5aL05=CD`1:BTX0FEUI05eMG@1QHF40GUiN05aLG01FEUH0BDU9
04a<C01:BTX0BDU904A4A010@4020492@P0B04Q8B016ATH0<c<c02h^;P0];Bd0:BTY03De=@0X:2P0
30`<010@400A4A409bLW01TI6@092@T01@D501HF5P0M7Ad030`<4`020P800`010@4000000000000Q
000000Oooooo0005oooooaT0000000d0:2PX09FEU@2`/;00ZZZZ0:>SX`2MWId0_kno0;Rh^02HV9P0
SXj>08n?S`2RXZ80^KVi0080]KFe00D0[:b/09nOW`2UYJD0_;bl0;fm_@020;Bd]00G0::RXP2EUID0
V9RH0:2PX02QXJ40ZJVY0;>c/`2`/;00/k>c0;bl_034a<@0_Kfm0<;2`P37alL0^k^k0;Vi^@2k^k/0
^KVi0;>c/`2k^k/0a<C40;jn_P2UYJD00P2IVIT02@2LW9`0V9RH09VIV@2LW9`0UIFE09BDU02=SHd0
QhN70861P@020820P00607UiN@1fMWH0LG5a079bLP1eMGD0Kfm_0P1]KFd206][J`80K6a/02H0O7al
08N7Q`24Q8@0Ogmo08:2PP2?Shl0WinO0:2PX02LW9`0V9RH09fMW@2][Jd0/K6a0:ZZZP2UYJD0WinO
09BDU02EUID0VYZJ09jNWP2EUID0R8R806a/K01]KFd0MgMg06i^KP1[Jf/0KVi^07MgM`1`L700Kfm_
06i^KP1bLW80J6QX05iNGP1VIVH0EUIF05EEE@80IFEU01D0JFUY065QH@1TI6@0AdM7059BDP1@D500
CTi>04Y:BP19BDT0ADE504=3@`0o?cl0A4A404M7A`13@d<0>CTi02/[:`0X:2P0<C4a02PX:00B4Q80
0`0D51@01`0;2`/010@400@4100N7Qh0:RXZ00T92@010@404@020P8200410B<000001oooool000Go
oooo600000008`010@40=SHf09RHV02d];@0[:b/0::RXP2WYjL0^;Rh0:ZZZP2@T900R8R808Z:RP2Q
XJ40][Jf0;fm_@2i^KT0Zj^[0:6QX@2XZ:P0/k>c0;Jf]P2j^[X0];Bd0:j^[P2YZJT0WYjN09ZJVP2O
Wil0YjNW0;Rh^02e]KD0ZJVY0:^[Z`2ZZZX0[Zj^0080^k^k00X0[:b/0;6a/@2n_[h0[:b/0;2`/02d
];@0Z:RX09^KV`2FUYH0UIFE0P2FUYH0302EUID0UiNG09bLW02JVYX0UiNG09BDU02ATI40QhN708F5
Q@23Ph<0Ng]k07EeM@80M7Ad00@0LW9b071`L01_Kfl0KFe]0P1[Jf/03P1^KVh0NWYj08>3P`23Ph<0
Ng]k07alO021PH40Shn?09>CT`2BTY80W9bL09RHV02QXJ40YjNW0P2[Zj/02`2TY:@0Vi^K096AT@2>
SXh0NWYj08b<S02QXJ40Ph>306UYJ@1bLW80Ng]k0080JVYZ02/0Kfm_07YjNP1cLg<0MWIf06IVIP1O
Gel0KVi^06YZJP1UIFD0IVIV06=SH`1WIfL0J6QX071`L01jNWX0I6AT04U9B@1FEUH0De=C055AD@1>
CTh0C4a<04Q8B012@T80?clo03Xj>P1BDU80FUYJ03Hf=P0O7al0:BTY01lO7`0X:2P06ATI00/;2`0>
3Ph02PX:00T92@0820P04a<C01`L700>3Ph00P8200800@412`020P8200<30`<00P820P010@4S0000
00Oooooo0005oooooaL000000P010@40C012@T80X:2P0;Zj^P2][Jd0XJ6Q0:j^[P2MWId0SXj>08J6
QP25QHD0Rh^;0;6a/@2n_[h0`/;20;Ng]`2XZ:P0WYjN0::RXP2`/;00/k>c0;:b/P2d];@0/;2`0;Ng
]`2PX:00WIfM0:6QX@2XZ:P0[Zj^0:b/[02WYjL0Zj^[0:FUY@2][Jd0a/K60<O7a`2f][H0[jn_0:NW
Y`2QXJ40/K6a0;Fe]@2SXj<0Ti>C09JFUP2JVYX0UYJF09jNWP2KVi/0XJ6Q0::RXP2ZZZX0XJ6Q08j>
SP2@T900RXZ:07moO`1lO7`0N7Qh07IfMP1dM7@0LW9b06i^KP1]KFd0L71`06i^KP1/K6`0KFe]079b
LP1lO7`0PX:20861P@1nOWh0PH6108V9R@2>SXh209bLW00U09RHV02KVi/0Xj>S0:JVYP2TY:@0WinO
0:6QX@2GUiL0ZZZZ08N7Q`1dM7@0SHf=0:NWY`29RHT0KFe]07AdM01iNGT0QXJ608F5Q@2EUID0SHf=
07moO`1YJFT0DE5A065QH@21PH40NWYj06=SH`1TI6@0Hf=S06a/K01^KVh0L71`08J6QP1LG5`0E5AD
059BDP02055AD@04059BDP14A4@0@d=303Ti>@80>c/k0140ATI604E5A@0W9bL071`L01@D500A4A40
7alO01XJ6P0=3@d03`l?01<C4`0I6AT07alO02<S8`0?3`l00`<30000000600410@X00P820`010@4T
000000Oooooo0005oooooaP0000001<00@4104M7A`2MWId0_Kfm0;6a/@2SXj<0/;2`09FEU@24Q8@0
PH6108:2PP2=SHd0]kNg0;jn_P30`<00][Jf0:j^[P2TY:@0Xj>S0080/K6a0P2][Jd0302f][H0_kno
0:6QX@2@T900SHf=09fMW@2SXj<0YjNW0:n_[`2l_;`0/;2`0:n_[`80c/k>00@0^k^k0;Bd]02XZ:P0
Z:RX0P2YZJT03@2UYJD0V9RH09JFUP2JVYX0UYJF0:6QX@2UYJD0/K6a0:b/[02ZZZX0XJ6Q08Z:RP23
Ph<00P1lO7`0101kNg/0MgMg07IfMP1dM7@2079bLP0_06m_K`1bLW80KVi^06i^KP1gMgL0NWYj07em
O@25QHD0R8R80820P022PX80R8R808^;R`2GUiL0VIVI09fMW@2IVIT0WIfM0:2PX02MWId0W9bL0:ZZ
ZP2j^[X0YjNW096AT@25QHD0V9RH09ZJVP2ATI40OGem0861P@22PX80U9BD08R8R02CTi<0PX:207Mg
M`1VIVH0J6QX075aL@20P800IfMW065QH@1[Jf/0Hf=S06UYJ@1]KFd00P1fMWH0201=CDd0Cdm?05=C
D`1=CDd0Cdm?051@D012@T80?Shn0P0m?Cd02@0f=SH0ADE504M7A`0[:b/07QhN01HF5P0G5aL07QhN
01LG5`0200X:2P07018B4P0H61P06ATI014A4@030`<00@4100820P0700410@X00P8200<00@410000
000000008`000007ooooo`001OoooolH0000000800<30`1=CDd0VYZJ0;no_`2g]kL0[Jf]0:b/[02C
Ti<308N7Q`0L09FEU@2a/K40];Bd0;^k^`2e]KD0YZJV0:>SX`2WYjL0[Jf]0:JVYP2SXj<0/K6a0<;2
`P34a<@0[Jf]09VIV@2BTY80U9BD09^KV`2RXZ80[jn_0<71`@2k^k/0/;2`0<71`@34a<@0^;Rh0;Bd
]080[:b/0180Xj>S0:ZZZP2a/K40WIfM09JFUP2CTi<0TY:B09fMW@2PX:00/;2`0:f][@2[Zj/0WYjN
08R8R021PH40O7al07YjNP1hN7P207UiN@0307=cL`1aLG40Kfm_00<0L71`00H0NGUi08B4Q01nOWh0
Ogmo08N7Q`2:RXX208B4Q00M08V9R@2:RXX0T92@09>CT`2JVYX0UYJF0:2PX02RXZ80YJFU0:j^[P2[
Zj/0X:2P09fMW@2KVi/0U9BD09FEU@2BTY80U9BD08J6QP29RHT0R8R808>3P`1ZJVX0N7Qh07=cL`1T
I6@0IfMW075aL@1_Kfl00P1RHV80101ZJVX0MGEe06IVIP1YJFT2071`L00:03dm?@0O7al0CTi>05]K
F`15ADD0BTY:04I6AP0n?Sh0@41003/k>`80=CDe00X0B4Q803dm?@0U9BD092@T01HF5P0E5AD06a/K
00`<300;2`/010@40`051@D010020P800@4100820P020P8900410@H00P820`010@4U000000Oooooo
0005oooooaP0000000h00`<305=CD`2KVi/0`<300;Ng]`2c/k<0Zj^[09jNWP2JVYX0Ti>C08V9R@2A
TI40ZZZZ0:n_[`80/K6a00@0Y:BT09fMW@2NWYh0Xj>S0P2KVi/0302XZ:P0/k>c0;2`/02XZ:P0VYZJ
09nOW`2NWYh0WIfM0:6QX@2/[:`0alO70<C4a080/k>c00X0_kno0;fm_@2i^KT0/K6a0:NWY`2JVYX0
WIfM0:6QX@2IVIT0Ti>C0P2@T900402IVIT0XZ:R0;6a/@2][Jd0ZZZZ08n?S`22PX80OWin07emO@1n
OWh0MWIf07EeM@1jNWX0N7Qh07IfMP1bLW82071`L00C07AdM01fMWH0OWin0820P024Q8@0RHV908R8
R026QXH0RXZ:08j>SP2<S8`0TI6A09JFUP2LW9`0U9BD09nOW`2UYJD0ZZZZ0:6QX@0208F5Q@08096A
T@2IVIT0VIVI08j>SP2GUiL0U9BD08f=S@2;Rh/208F5Q@0806][J`1fMWH0O7al06e]K@1[Jf/0IVIV
065QH@1YJFT206m_K`0H07AdM01[Jf/0Hf=S07QhN01VIVH0820P04U9B@1/K6`0JFUY03hn?P0m?Cd0
ATI604U9B@0n?Sh0=CDe02h^;P0f=SH0D51@03<c<`0M7Ad092@T00l?3`0>3Ph04A4A0P0;2`/01P03
0`<00@4100820P020P800@4100820P<00@4100<0000000410@010@401`010@4400820P0300410@00
0000000002D000001oooool000Gooooo600000001P051@D0GEeM0:BTY033`l<0]kNg0;Bd]080Zj^[
00`0Vi^K08^;R`22PX80R8R80:FUY@2[Zj/0[jn_0:j^[P2OWil0VIVI09ZJVP2MWId209RHV0080:JV
YP2RXZ80Vi^K09ZJVP2HV9P0X:2P0:NWY`2XZ:P20:>SX`0k0;Jf]P2j^[X0];Bd0;Fe]@2i^KT0^;Rh
0;2`/02[Zj/0Z:RX09JFUP2EUID0V9RH09>CT`2@T900TY:B08n?S`2=SHd0TI6A09jNWP2IVIT0SXj>
0861P@20P800O7al07UiN@1hN7P0MGEe07AdM01mOGd0MgMg07EeM@1dM7@0LW9b075aL@1jNWX0Ng]k
0820P028R8P0SXj>09:BTP28R8P0S8b<08n?S`2ATI40RHV908b<S02@T900TI6A09:BTP2PX:00XJ6Q
08n?S`1jNWX0Lg=c07QhN01kNg/0RHV908F5Q@26QXH00P2GUiL0:@2;Rh/0Shn?08^;R`20P800KVi^
08Z:RP1cLg<0KVi^0861P@1_Kfl0KFe]07=cL`1VIVH0M7Ad06i^KP1VIVH0G5aL07=cL`1HF5P092@T
05=CD`1aLG40M7Ad038b<P0o?cl0BTY:0451@@0E5AD0;2`/03Ti>@15ADD0EEEE01dM7@0@41005aLG
00L71`0:2PX051@D00l?3`0=3@d020P800@00`<300<00@4100820P010@403@010@400`020P800@41
00410@0W000000Oooooo0005oooooaP0000000d01`L706UYJ@2b/[80`l?30;bl_02/[:`0Y:BT0:FU
Y@2HV9P0S8b<0861P@27QhL0ZZZZ0080/K6a02L0[:b/0:6QX@2KVi/0UYJF09ZJVP2DU9@0VIVI0:6Q
X@2RXZ80W9bL09NGU`2KVi/0X:2P0:BTY02SXj<0XZ:R0:2PX02/[:`0[Zj^0:VYZ@2n_[h0]KFe0;Bd
]02a/K40[jn_0:f][@2HV9P0U9BD09FEU@2@T900RXZ:08j>SP2ATI40SXj>08^;R`27QhL0P82007Yj
NP1iNGT00P1mOGd04@1lO7`0N7Qh07EeM@1eMGD0Q8B407MgM`1aLG40N7Qh07]kN`1fMWH0NWYj07al
O024Q8@0S8b<08Z:RP2<S8`0SHf=0080Ti>C01@0SXj>08R8R02;Rh/0SXj>092@T02=SHd0SXj>08Z:
RP1kNg/0LG5a07AdM01hN7P0M7Ad08:2PP1iNGT0Ogmo07emO@2:RXX0T92@09:BTP80RHV901l0PH61
07]kN`1`L700P82007AdM01_Kfl0OWin06e]K@1PH600IfMW06][J`1YJFT0IVIV06a/K01MGEd0>c/k
05ADE027QhL0KVi^03Hf=P1:BTX0@d=303Hf=P0K6a/0DE5A05aLG013@d<0:2PX00/;2`0B4Q805aLG
00803`l?00T0410@00`<300820P01PH600<30`0:2PX01`L700@410030`<04@010@4X000000Oooooo
0005oooooaP0000000<020P806a/K02j^[X00P33`l<06@2b/[80XJ6Q09FEU@2<S8`0Q8B407]kN`24
Q8@0Y:BT0;:b/P2/[:`0[Zj^0:BTY02SXj<0W9bL09JFUP2?Shl0U9BD09^KV`2OWil0WIfM09RHV02O
Wil0Xj>S0:RXZ02SXj<00P2PX:00102SXj<0YjNW0:BTY02ZZZX20;2`/00Q0;Vi^@2a/K40ZJVY09FE
U@2ATI40SXj>08R8R026QXH0SHf=08j>SP2:RXX0RHV908B4Q01oOgl0Ng]k07UiN@1hN7P0NGUi07Yj
NP1iNGT0MWIf075aL@1dM7@0LG5a07AdM01nOWh0QXJ607UiN@1kNg/0Ogmo08R8R02@T900S8b<0080
Shn?0280TI6A08n?S`20P800SXj>08f=S@28R8P0Ph>307emO@23Ph<0O7al07IfMP1dM7@0Ng]k07=c
L`1bLW80M7Ad06m_K`1cLg<0MgMg07alO01gMgL0O7al07YjNP1lO7`0MgMg07inOP1[Jf/0LW9b06IV
IP1cLg<0QHF5061PH01IFET0HV9R0P1fMWH07@1]KFd0K6a/05]KF`1@D500HF5Q07MgM`0o?cl0=SHf
0492@P11@D40@T9204Y:BP1XJ6P0DU9B02HV9P0R8R808B4Q02PX:00L71`05QHF010@400?3`l03@d=
00P820061PH02`/;00X:2P0410@00P8200D00@4100<00P8200410@010@4030010@4V000000Oooooo
0005oooooaP0000000<020P806e]K@31`L400P39bLT04P2d];@0VYZJ09>CT`2=SHd0QHF507inOP22
PX80VYZJ0:n_[`2ZZZX0[jn_09bLW02QXJ40Vi^K08R8R021PH40S8b<09FEU@80VYZJ00D0W9bL0:>S
X`2ZZZX0[Jf]0:BTY00209bLW00F0:2PX02_[jl0YjNW0:ZZZP2c/k<0][Jf0;fm_@2_[jl0YJFU09VI
V@2ATI40SHf=08J6QP2<S8`0V9RH096AT@29RHT0QHF50820P021PH40Ph>307alO080NGUi00L0Ng]k
07alO01hN7P0LW9b06m_K`1bLW80N7Qh00<0P82000l0R8R808Z:RP2=SHd0TY:B08V9R@2:RXX0Shn?
09FEU@2GUiL0QhN709ZJVP1oOgl0NWYj07UiN@1fMWH00P1kNg/01P1gMgL0Lg=c07MgM`1bLW80LG5a
079bLP80N7Qh01d0MgMg07IfMP1fMWH0MgMg06m_K`1^KVh0MGEe0820P01:BTX0MGEe07emO@1/K6`0
MWIf04a<C01ADE40GemO06][J`1^KVh0IfMW05mOG`1BDU80CTi>04M7A`0m?Cd0>SXj0492@P11@D40
@d=304Q8B0020410@00?03Hf=P0S8b<08B4Q01lO7`0L71`04Q8B01<C4`071`L01PH600/;2`092@T0
1PH600l?3`061PH0000000<00@4100<00P8200410@0000002`010@430000000300410@0000000000
02@000001oooool000Gooooo600000001`0820P0Kfm_0<G5a@39bLT0a<C40:j^[P2JVYX00P2?Shl0
@@28R8P0Q8B408J6QP2?Shl0XZ:R0:2PX02NWYh0S8b<08R8R027QhL0OGem07]kN`24Q8@0SHf=09BD
U02IVIT0WIfM0:RXZ02^[Zh0/[:b0:FUY@2KVi/0UIFE0:JVYP31`L40][Jf0:^[Z`2c/k<0b<S80<[:
bP2f][H0ZZZZ09nOW`2GUiL0Ti>C08V9R@2>SXh0UYJF09bLW02CTi<0SHf=08F5Q@24Q8@0Ph>307em
O@1hN7P0Ogmo08J6QP25QHD0NWYj07=cL`1_Kfl0Lg=c07alO029RHT0R8R808J6QP2<S8`0QXJ608B4
Q021PH40Ph>308J6QP28R8P0S8b<0080T92@00@0SXj>07]kN`1lO7`0Ng]k0P1iNGT07`1jNWX0MgMg
07IfMP1kNg/0MGEe07YjNP1kNg/0PH6107UiN@1gMgL0MGEe071`L01bLW80KVi^079bLP20P800QhN7
071`L02EUID0Ph>305mOG`1[Jf/0Bd];05mOG`1UIFD0K6a/07IfMP1WIfL0FEUI05]KF`18B4P00P12
@T805@1;Bd/0?Shn03Hf=P18B4P0>3Ph02`/;00^;Rh08B4Q01DE5@0L71`04Q8B00/;2`0410@03Ph>
00H61P0410@03@d=00T92@061PH01`L700820P0200410@800P823P010@4Z000000Oooooo0005oooo
oaP0000001D020P806i^KP34a<@0a/K60;Zj^P2ZZZX0Vi^K09FEU@2DU9@0T92@08b<S026QXH0QhN7
09^KV`2IVIT0Shn?08F5Q@24Q8@0OWin07alO01kNg/00P27QhL00`2=SHd0UiNG09nOW`030:VYZ@0M
0:2PX02IVIT0TI6A09nOW`2e]KD0ZZZZ0:JVYP2][Jd0a<C40<?3``2d];@0[jn_0:VYZ@2KVi/0V9RH
08j>SP2<S8`0UIFE0:>SX`2VYZH0Ti>C08V9R@23Ph<0Ogmo07alO01kNg/0P82007moO`1kNg/00P1l
O7`01P1kNg/0O7al0820P02;Rh/0T92@08^;R`80Q8B400<0Ogmo0861P@25QHD00P27QhL01`23Ph<0
QHF508N7Q`20P800MWIf07MgM`1eMGD00P1fMWH06@1hN7P0OGem079bLP1fMWH0OGem07moO`22PX80
U9BD07emO@1hN7P0M7Ad071`L01iNGT0Kfm_071`L01jNWX0Lg=c07alO01[Jf/0GemO05IFEP1LG5`0
EeMG06IVIP1]KFd00P1_Kfl06P1PH600EEEE06YZJP0j>SX0<c<c04a<C013@d<0@D5103Lg=`11@D40
8R8R024Q8@0C4a<04Q8B01lO7`0H61P02PX:00T92@061PH07AdM010@400410@03Ph>00X:2P0410@0
0P820`010@4200820Pd00@41:`000007ooooo`001OoooolG0000000300410@0820P0KVi^0080a/K6
00D0^;Rh0:n_[`2QXJ40Ti>C08b<S00208^;R`0408N7Q`26QXH0U9BD08j>SP80PH610180QHF507al
O01iNGT0N7Qh09JFUP2?Shl0Rh^;09BDU02NWYh0WIfM09jNWP2MWId0Xj>S0:2PX02ATI40Shn?0:VY
Z@2e]KD209nOW`050:FUY@2[Zj/0Zj^[0;:b/P2[Zj/00P2KVi/03P2DU9@0RXZ:09JFUP2LW9`0UYJF
08f=S@26QXH0QHF508:2PP23Ph<0O7al07]kN`1iNGT0MWIf0`21PH403@23Ph<0PX:208B4Q027QhL0
Rh^;08N7Q`23Ph<0PH6108:2PP27QhL0R8R808F5Q@1mOGd00P1oOgl0>`1jNWX0MGEe07=cL`1cLg<0
MGEe06m_K`1dM7@0MgMg06m_K`1aLG40MgMg07alO022PX80PH6108:2PP1eMGD0L71`07AdM020P800
JVYZ06][J`1aLG40MWIf07EeM@1CDe<0GEeM05iNGP1MGEd0IfMW079bLP1_Kfl0HF5Q05eMG@1ADE40
CTi>04m?C`0C4a<08b<S04Y:BP0m?Cd0A4A403Ph>00b<S803Ph>014A4@0U9BD06QXJ020P800L71`0
5aLG01@D500L71`0;Rh^00X:2P071`L02@T900X:2P051@D00`<300<00@410P020P800`010@400P82
00410@0900410B`000001oooool000Gooooo600000002@061PH0Kfm_0=KFeP3>c/h0^k^k0:j^[P2I
VIT0T92@08^;R`0208R8R00408b<S02@T900RHV908:2PP80O7al02L0OWin07alO01iNGT0MGEe08Z:
RP2EUID0Rh^;08j>SP2GUiL0Ti>C09BDU02BTY80SHf=09BDU02ATI40RXZ:096AT@2/[:`0X:2P09^K
V`2RXZ80Z:RX0:j^[P2g]kL0ZJVY0:JVYP2SXj<0X:2P08V9R@26QXH0S8b<08N7Q`29RHT0PX:207mo
O`1lO7`0Q8B407emO@1iNGT00P1jNWX04@1lO7`0N7Qh07]kN`1nOWh0PX:208B4Q023Ph<0P82008:2
PP20P800Ogmo0861P@24Q8@0Ph>30820P01gMgL0MGEe0080Ng]k00T0MgMg079bLP1aLG40M7Ad06m_
K`1`L700KFe]06][J`1`L7000P1gMgL06`1jNWX0Ng]k07=cL`1]KFd0J6QX07alO01mOGd0IfMW06UY
J@1/K6`0LG5a06MWI`17AdL0GUiN05UIF@1MGEd0H61P06QXJ01^KVh0HF5Q05aLG01=CDd0AdM703Ti
>@0A4A40;Bd]05ADE00203`l?00?03Xj>P0Y:BT02PX:02@T900d=3@04A4A02DU9@0W9bL06ATI01LG
5`0F5QH051@D00@410051@D010@400800`<300<00@4100820P010@4010020P8;00410B`000001ooo
ool000Gooooo5`0000002`010@401@D506i^KP3QhN40e=CD0;jn_P2YZJT0TY:B092@T02<S8`0RHV9
0080SHf=0380V9RH08j>SP24Q8@0Ng]k07YjNP1mOGd0O7al07UiN@1bLW80NWYj08V9R@2;Rh/0RXZ:
08j>SP2@T900Shn?08j>SP29RHT0S8b<08^;R`28R8P0Ph>309nOW`2^[Zh0WinO09fMW@2VYZH0Z:RX
0:j^[P2`/;00YZJV0:6QX@2SXj<0TI6A08J6QP25QHD0Q8B408J6QP22PX80Ogmo07inOP20P800OWin
07]kN`1iNGT0N7Qh07UiN@1jNWX0Ng]k07moO`80Q8B400@0Ph>307inOP21PH40O7al0P1nOWh02@1j
NWX0Ng]k0861P@1jNWX0N7Qh07YjNP1hN7P0MGEe07=cL`0206][J`0>06a/K01cLg<0LW9b06i^KP1]
KFd0L71`07AdM01mOGd0MGEe06][J`1/K6`0KFe]06i^KP1[Jf/206=SH`0Q06ATI01XJ6P0EeMG055A
D@1TI6@0FEUI05eMG@1WIfL0J6QX06m_K`1VIVH0C4a<04e=C@11@D40=cLg02HV9P1<C4`0?Cdm03/k
>`0o?cl0>3Ph02d];@0M7Ad0=3@d01DE5@061PH07AdM01lO7`0>3Ph04a<C018B4P0;2`/00`<300<0
0P8200<00@4100820P010@400`010@4700820PD00@41;@000007ooooo`001OoooolH0000000900D5
1@1/K6`0hn?S0=SHf02n_[h0ZZZZ09NGU`2=SHd0RXZ:0080R8R800@0S8b<09nOW`2GUiL0QhN70P1m
OGd08P1jNWX0N7Qh07IfMP1_Kfl0MWIf08B4Q029RHT0RXZ:08V9R@2=SHd0Rh^;08V9R@2:RXX0R8R8
08B4Q020P800Ph>309BDU02ZZZX0XZ:R09ZJVP2QXJ40[Jf]0:ZZZP2^[Zh0ZZZZ0:BTY02RXZ80UIFE
08Z:RP26QXH0Q8B408J6QP25QHD30820P080QHF504<0Ng]k079bLP1fMWH0OWin07moO`2>SXh0QXJ6
08B4Q021PH40O7al07moO`1kNg/0OGem07]kN`1eMGD0O7al08R8R021PH40OGem0861P@1fMWH0MGEe
06m_K`1YJFT0K6a/06e]K@1fMWH0MgMg06m_K`1^KVh0KFe]07UiN@1bLW80KFe]06IVIP1/K6`0LG5a
06QXJ01YJFT0GemO061PH01SHf<0HF5Q05=CD`1_Kfl0K6a/05=CD`1OGel0JFUY05mOG`1PH600IFEU
05IFEP1=CDd0?Shn02d];@0/;2`0<S8b02DU9@0m?Cd0=cLg030`<00/;2`05ADE01LG5`0C4a<03`l?
00806ATI00L01@D500H61P051@D020P800<30`020P800`<300@00P820`010@4700820P@00@41;P00
0007ooooo`001OoooolG0000000:00410@030`<0IVIV0>KViP3Ng]h0^;Rh0:VYZ@2KVi/0RHV908:2
PP80PH6100T0SXj>0:RXZ02KVi/0QXJ607inOP1mOGd0NGUi07YjNP1iNGT00P1cLg<208B4Q00>08N7
Q`26QXH0RXZ:08F5Q@23Ph<0RHV908R8R023Ph<0Ogmo0861P@26QXH0UIFE09^KV`2NWYh20:f][@09
0:JVYP2YZJT0ZZZZ0:>SX`2MWId0VYZJ08j>SP2=SHd0QhN70080QHF50P23Ph<04`26QXH0RHV908b<
S01oOgl0M7Ad07QhN01oOgl0Ph>308R8R025QHD0R8R80820P01kNg/0PH6107alO01kNg/0OGem07]k
N`23Ph<00P1oOgl05@1mOGd0Ph>307alO01lO7`0L71`06a/K01]KFd0K6a/07IfMP1VIVH0J6QX06e]
K@1/K6`0L71`06e]K@1ZJVX0Jf][075aL@1^KVh0JFUY06EUI@02061PH00<05IFEP1OGel0GemO06UY
J@1TI6@0BTY:05QHF01IFET0CDe=05UIF@1UIFD0CDe=0P0n?Sh0500Z:RX0:2PX02h^;P0c<c<0?clo
02h^;P0X:2P0:b/[010@400E5AD06QXJ01`L700K6a/09RHV00T92@051@D010@400L71`020P800@41
1@020P8300410@0300820P030`<00P8200@00P820`010@4_000000Oooooo0005oooooaL0000001X0
0@4100820P1PH600i>CT0>7Qh@2b/[80WIfM09^KV`2@T900Q8B40820P021PH40T92@0:FUY@2HV9P0
QXJ607inOP20P800OGem07QhN01iNGT0N7Qh07=cL`1oOgl0P82008B4Q080QHF500@0PH6107emO@25
QHD0PX:20P21PH407@1oOgl0OGem08>3P`2@T900Xj>S0;Vi^@2VYZH0/K6a0:f][@2YZJT0Xj>S09VI
V@2GUiL0UIFE08j>SP25QHD0PH6108B4Q01oOgl0P82008:2PP24Q8@0Ph>307moO`1iNGT0O7al0861
P@1lO7`0Ogmo0080QHF50P1mOGd02@22PX80P82007]kN`1lO7`0NGUi07YjNP1fMWH0NWYj0820P002
07YjNP0308F5Q@1eMGD0LW9b00<0LW9b00<0HF5Q06QXJ01_Kfl00P1/K6`03`1]KFd0K6a/06a/K01X
J6P0IfMW061PH01OGel0Hf=S05eMG@1OGel0HV9R065QH@1NGUh0?Shn020P800204i>CP0F04];B`1N
GUh0H61P0451@@0n?Sh0@d=302`/;00X:2P0;bl_03Lg=`1<C4`0:RXZ02/[:`0b<S804A4A00l?3`0M
7Ad09RHV01lO7`0G5aL01@D500<30`800P820P010@4200<30``00P820P010@400`020P8000000000
000^000000Oooooo0005oooooaP0000000l00P8204i>CP3Jf]X0gmoO0:f][@2HV9P0T92@096AT@2:
RXX0P82007moO`2:RXX0ZZZZ096AT@22PX800`20P800;@1lO7`0Ng]k07YjNP1gMgL0N7Qh07emO@1n
OWh0Ph>30820P01jNWX0NGUi07moO`1nOWh0O7al07moO`21PH40OWin07UiN@1mOGd0Ti>C0:j^[P2/
[:`0/K6a0<71`@2e]KD0Xj>S09JFUP25QHD0PX:208>3P`20P800PH6108>3P`1lO7`0MWIf07emO@20
P800O7al07emO@20P800O7al07moO`1nOWh0QhN708j>SP0208>3P`0<08N7Q`28R8P0P82007alO01j
NWX0MGEe07QhN01iNGT0Ogmo08:2PP1eMGD0MWIf0P26QXH0201jNWX0Ng]k07inOP1`L700I6AT06QX
J01bLW80IfMW0P1/K6`08`1ZJVX0J6QX06QXJ01TI6@0HV9R06=SH`1RHV80GEeM05QHF01KFe/0H61P
04];B`0P8200=SHf06=SH`1QHF40?clo0492@P1ADE40@T9202LW9`0c<c<08B4Q03Ph>00b<S80@410
051@D00_;bl092@T01hN7P0=3@d051@D02DU9@0S8b<03Ph>00800`<30`020P8200410@0300<30`02
0P800P8200P00P8200<00`<300820P020P800`010@4`000000Oooooo0005oooooaP0000000h00@41
03`l?03?cll0h>3P0;6a/@2HV9P0SXj>08R8R02;Rh/0Ph>307alO01oOgl0R8R80861P@80OWin00T0
Ogmo07emO@1kNg/0NGUi07]kN`1jNWX0Ng]k07alO01jNWX00P1hN7P207YjNP0Z07UiN@1kNg/0NWYj
07UiN@1oOgl0OWin07alO021PH40XZ:R0:ZZZP2OWil0[Zj^0;>c/`2[Zj/0YZJV09BDU01jNWX0LG5a
07UiN@1lO7`0OWin07]kN`1iNGT0OGem07]kN`20P800Ph>30861P@24Q8@0Ogmo07alO020P800O7al
07]kN`1oOgl0SXj>09>CT`2EUID0RHV907alO01nOWh0NWYj0P1lO7`01`1nOWh0PH6107]kN`1hN7P0
P82007inOP1fMWH00P1eMGD0101_Kfl0KFe]075aL@1]KFd206UYJ@0706MWI`1SHf<0IVIV06=SH`1R
HV80IVIV061PH00405YJFP0C05UIF@1=CDd0?Shn05ADE01RHV80@41002HV9P0g=cL0BDU9034a<@0N
7Qh08B4Q02l_;`0/;2`0;Rh^04E5A@0l?3`07alO00l?3`0201/K6`0401TI6@0Q8B405ADE00H61P80
0P8200<00`<300820P020P800P020P800`0410@00P8200820P0800820P0300<30`020P800@410080
0@41<@000007ooooo`001OoooolI0000000;02PX:031`L40d];B0:j^[P2MWId0TI6A08N7Q`2:RXX0
SXj>08J6QP1nOWh00P1lO7`02P1iNGT0Ng]k07UiN@1gMgL0Lg=c07AdM01lO7`0OGem07]kN`1hN7P2
07AdM0<0MGEe01L0M7Ad07MgM`1hN7P0Lg=c07IfMP1iNGT0NWYj08B4Q02?Shl0[Zj^0:FUY@2PX:00
YjNW0:f][@2j^[X0[Zj^08V9R@1lO7`0PH6107inOP1lO7`0N7Qh07YjNP0207inOP0B07alO01nOWh0
PH6108:2PP1kNg/0OGem07inOP1iNGT0O7al0861P@2@T900VIVI0:>SX`2;Rh/0Ng]k08>3P`20P800
OWin0P1lO7`0101nOWh0M7Ad07AdM01cLg<306i^KP0L071`L01^KVh0KFe]06m_K`1XJ6P0KVi^069R
HP1QHF40Hf=S06EUI@1KFe/0IfMW05EEE@1FEUH0AdM7051@D01PH600FUYJ04i>CP0d=3@0=CDe03`l
?012@T80>SXj03De=@0m?Cd0BDU902`/;080;Bd]0P0`<300100g=cL0;Rh^01@D500C4a<201@D5005
01<C4`0F5QH05ADE00/;2`092@T00P020P800`030`<00P8200<30`0200820P0300D51@030`<00P82
00P00P8210010@4b000000Oooooo0005oooooaP0000000D00@4101TI6@2][Jd0cLg=0:n_[`0209NG
U`0708j>SP26QXH0QXJ608^;R`25QHD0OGem07YjNP0207QhN00507UiN@1gMgL0L71`075aL@1kNg/0
0P1nOWh00`1iNGT0M7Ad07AdM00207EeM@03075aL@1bLW80MGEe0080MWIf00l0MGEe07QhN01iNGT0
O7al08B4Q02TY:@0Z:RX09bLW02ZZZX0];Bd0<G5a@2n_[h0WinO08n?S`25QHD00P1oOgl02@1lO7`0
NGUi07UiN@1gMgL0N7Qh07YjNP1nOWh0Ph>307alO0040820P00708B4Q02;Rh/0RXZ:08R8R02=SHd0
P8200861P@0207emO@0407inOP1iNGT0NGUi06e]K@80LG5a01l0KFe]06i^KP1_Kfl0LW9b06e]K@1Z
JVX0IfMW05mOG`1[Jf/0G5aL061PH01WIfL0J6QX065QH@1ZJVX0FEUI04a<C018B4P0Cdm?05UIF@1A
DE40>SXj01/K6`0c<c<0@T9205IFEP0n?Sh0=SHf0451@@1>CTh0:2PX00<0;Bd]00d0;2`/03De=@0O
7al06a/K01lO7`0C4a<030`<01HF5P0E5AD03Ph>00/;2`061PH00`<301000P821@010@4b000000Oo
oooo0005oooooaP0000000T00@41014A4@2EUID0cLg=0:f][@2@T900RHV908n?S`2=SHd00P1oOgl0
6`27QhL0PX:207inOP1eMGD0M7Ad07UiN@1fMWH0L71`079bLP1hN7P0O7al07emO@1iNGT0MgMg07If
MP1bLW80MWIf079bLP1fMWH0PH61079bLP1eMGD0MgMg07QhN01fMWH0MgMg07emO@0209VIV@0F09BD
U02NWYh0Y:BT0;Jf]P2d];@0Zj^[09BDU02:RXX0OGem07alO01kNg/0MgMg07EeM@1fMWH0KFe]07Qh
N026QXH0RHV908:2PP1kNg/0PX:20861P@80Ogmo01l0PH6108J6QP1oOgl0P82008>3P`22PX80P820
07moO`23Ph<0MgMg07YjNP1cLg<0MGEe075aL@1`L700Lg=c071`L01[Jf/0IfMW06ATI01RHV80GemO
06EUI@1RHV80JFUY06IVIP1TI6@0HV9R06QXJ01;Bd/0=cLg00<0DE5A01T0E5AD034a<@0V9RH0@410
04E5A@1OGel0BTY:03/k>`0d=3@0@T9202`/;00W9bL09RHV02/[:`0^;Rh0=cLg01lO7`0U9BD071`L
00X:2P0>3Ph06a/K01TI6@0?3`l01PH6008010@400<00`<300820P020P800`020P800`030`<00P82
00820P0800820P<00@41<`000007ooooo`001OoooolG0000000F00410@0000002`/;07inOP3:b/X0
[Jf]08j>SP26QXH0SHf=09:BTP1nOWh0LW9b07YjNP21PH40Ph>307QhN01eMGD0N7Qh07AdM01`L700
MgMg07UiN@<0Ng]k01/0NWYj07EeM@1_Kfl0LG5a07AdM01iNGT0O7al075aL@1cLg<0N7Qh07AdM01b
LW80LG5a07]kN`2MWId0Vi^K09NGU`2IVIT0WinO0:6QX@2SXj<0[Zj^09jNWP2@T900PH6107emO@1l
O7`00P1fMWH01P1bLW80Kfm_0861P@2@T900R8R808J6QP80OGem00d0Ph>308j>SP26QXH0PH6108J6
QP1nOWh0NWYj07inOP21PH40Ph>30861P@1jNWX0LW9b0080Ng]k00D0N7Qh06m_K`1eMGD0MgMg06e]
K@0206UYJ@0406=SH`1NGUh0GUiN06=SH`80JFUY00@0EeMG065QH@1OGel0IFEU0P19BDT05@1GEeL0
DE5A04Y:BP1:BTX0A4A403@d=012@T80Bd];06IVIP0i>CT0;bl_03De=@0h>3P0<S8b02XZ:P0Y:BT0
=3@d03Lg=`0c<c<092@T028R8P0201DE5@0401<C4`0I6AT03@d=00<30`8010@400<020P800<30`02
0P8040020P8200410C<000001oooool000Gooooo6@00000050051@D0IVIV0<K6aP2e]KD0Ti>C092@
T02NWYh0R8R80861P@1bLW80M7Ad07MgM`23Ph<0PX:207EeM@1gMgL0MGEe079bLP1fMWH0NGUi0P1j
NWX207alO00R07MgM`1bLW80L71`07AdM01fMWH0MGEe07=cL`1bLW80NWYj07=cL`1aLG40KVi^07Yj
NP2BTY80T92@096AT@2KVi/0Shn?08f=S@2DU9@0UIFE09:BTP2<S8`0P82007alO01kNg/0N7Qh07Mg
M`1aLG40LW9b07YjNP22PX80OWin0820P080OGem00@0Rh^;09NGU`2@T900R8R80P1lO7`06P1fMWH0
MgMg07QhN020P800PX:207QhN01cLg<0OGem07inOP1jNWX0OGem07inOP1jNWX0Kfm_06][J`1YJFT0
HF5Q05mOG`1QHF40IVIV06=SH`1KFe/0GUiN05mOG`1HF5P0GEeM0P17AdL0601CDe<0Bd];04M7A`1<
C4`0Cdm?03lo?`1;Bd/0EeMG04e=C@0a<C40;bl_03Lg=`0`<300=cLg02HV9P0X:2P0>3Ph03Lg=`0U
9BD03`l?01HF5P0G5aL03`l?00X:2P8020P800<02`/;00P8200410@00P010@4@00820P0300410@00
0000000003<000001oooool000Gooooo6@00000050020P80CTi>0<G5a@2i^KT0UiNG092@T02FUYH0
PX:20861P@1iNGT0MWIf07=cL`1lO7`0Ph>307]kN`1fMWH0NGUi07MgM`1cLg<0M7Ad0`1fMWH207Yj
NP0I07QhN01cLg<0MgMg07QhN01cLg<0LW9b07inOP2HV9P0N7Qh071`L01/K6`0N7Qh09:BTP2<S8`0
QhN709:BTP2;Rh/0R8R808b<S02>SXh0Rh^;08V9R@1nOWh0MgMg07QhN00207IfMP0507AdM01cLg<0
MgMg08:2PP1oOgl00P27QhL208R8R00K08Z:RP2>SXh0RHV907]kN`1iNGT0N7Qh07MgM`1cLg<0OWin
08>3P`1eMGD0MWIf08>3P`1dM7@0O7al0861P@1gMgL0Kfm_06e]K@1aLG40Jf][06=SH`1VIVH0IfMW
05iNGP1IFET0Fe]K0080H61P00D0BTY:055AD@0j>SX0B4Q8059BDP0204];B`06059BDP1;Bd/0@T92
04A4A01;Bd/0?clo0P0`<3002`0e=CD0:b/[03Hf=P0F5QH092@T02d];@0@41005ADE00T92@0J6QX0
4a<C00801PH600L00P8200H61P071`L00`<300410@020P800`<300l00P820P010@4e000000Oooooo
0005oooooaP000000P010@404@0g=cL0`l?30;Ng]`2QXJ40Rh^;08F5Q@24Q8@0Ph>308:2PP1cLg<0
KVi^079bLP1cLg<0MgMg07=cL`1kNg/0NGUi0080M7Ad00D0LW9b07YjNP1fMWH0MGEe07AdM00207Qh
N00>07UiN@1mOGd0M7Ad06e]K@1dM7@0QHF507MgM`1_Kfl0KVi^07AdM02ATI40UIFE08b<S02;Rh/2
08N7Q`0608^;R`2ATI40SXj>08V9R@1iNGT0LG5a0P1gMgL03P1eMGD0LG5a079bLP1fMWH0O7al07]k
N`1mOGd0Rh^;08J6QP23Ph<0Ogmo0820P01oOgl0OGem0P1lO7`01@1hN7P0Lg=c07]kN`1mOGd0L71`
0080MgMg00<0LG5a0820P01iNGT00P1[Jf/01P1YJFT0Kfm_06m_K`1UIFD0IfMW061PH080FEUI0280
G5aL061PH01NGUh0F5QH04Q8B01:BTX0FUYJ05EEE@1CDe<0GEeM05]KF`1:BTX0AdM704a<C01:BTX0
;Bd]02`/;00^;Rh0<S8b02TY:@0Q8B4061PH02@T900H61P01PH601PH600C4a<061PH00/;2`0410@0
0`<300820P071`L01@D54P020P8200410CH000001oooool000Gooooo6@0000001P010@408B4Q0;no
_`2e]KD0Z:RX096AT@<0P82000d0OGem07EeM@1_Kfl0LW9b071`L01cLg<0LG5a07=cL`1dM7@0Lg=c
07AdM01^KVh0Lg=c0080MWIf00H0LG5a07=cL`1fMWH0M7Ad07MgM`1eMGD2071`L00N07AdM01aLG40
L71`079bLP1cLg<0S8b<09:BTP24Q8@0RXZ:08N7Q`25QHD0QhN708V9R@2:RXX0QhN707IfMP1[Jf/0
KFe]075aL@1`L700JFUY06e]K@1cLg<0MgMg07YjNP1kNg/0RHV908>3P`1lO7`0Ng]k0P22PX80101l
O7`0OWin07moO`1mOGd207IfMP0307inOP1eMGD0NWYj0080M7Ad00<0NGUi07AdM01_Kfl00P1[Jf/0
9P1]KFd0LG5a06IVIP1SHf<0FUYJ05aLG01OGel0G5aL05UIF@1OGel0GUiN04];B`1DE5@0HV9R055A
D@1MGEd0CDe=0451@@0o?cl0=SHf03<c<`15ADD0:2PX03@d=00];Bd0:RXZ02DU9@0P8200;Rh^02d]
;@0Q8B403`l?028R8P0G5aL051@D00`<30071`L01@D50P030`<00`061PH00`<300<30`0@00820P80
0@41=P000007ooooo`001OoooolJ00000005018B4P2`/;00^;Rh0:b/[02HV9P00P24Q8@01@21PH40
Ng]k07MgM`1cLg<0M7Ad0080L71`00T0Kfm_06a/K01aLG40L71`06m_K`1ZJVX0Jf][075aL@1`L700
0P1bLW804`1dM7@0Kfm_06i^KP1_Kfl0LW9b07=cL`1aLG40KVi^07=cL`1gMgL0NGUi08F5Q@1fMWH0
Hf=S07QhN027QhL0R8R80820P027QhL00P29RHT00`1hN7P0Jf][06UYJ@0206][J`0>06ATI01XJ6P0
K6a/075aL@1iNGT0P82008>3P`25QHD0PH6107alO021PH40PX:207emO@1nOWh208>3P`0;08B4Q021
PH40OGem07IfMP1mOGd0PH6107IfMP1cLg<0L71`06m_K`1/K6`00P1^KVh0101_Kfl0IFEU065QH@1T
I6@206=SH`0M05]KF`1LG5`0GUiN05ADE01EEED0DE5A05=CD`1<C4`0@T9203`l?00m?Cd0?Shn03Ph
>014A4@0@T9202h^;P0/;2`0:2PX02@T900W9bL0;bl_02/[:`0N7Qh05aLG010@400O7al07QhN00/;
2`020P800P030`<010020P8010@400P820030`<@00820P800@41=`000007ooooo`001OoooolJ0000
000:00T92@2LW9`0^k^k0:b/[02HV9P0RXZ:08V9R@25QHD0OGem07IfMP80MGEe00l0Kfm_071`L01/
K6`0IfMW06a/K01_Kfl0KVi^06QXJ01UIFD0JVYZ06i^KP1]KFd0KVi^075aL@1_Kfl00P1/K6`01P1^
KVh0MWIf07MgM`1hN7P0OWin07emO@80PX:200<0J6QX05UIF@1TI6@00P23Ph<01P1kNg/0R8R808Z:
RP23Ph<0MGEe06QXJ080IfMW00X0IFEU065QH@1WIfL0K6a/06m_K`1dM7@0OGem0820P023Ph<0QhN7
0P1nOWh0;P26QXH0Ph>30820P021PH40RHV908b<S029RHT0NWYj07]kN`22PX80Q8B407QhN01dM7@0
LG5a06i^KP1]KFd0LG5a06a/K01YJFT0IfMW06EUI@1ZJVX0IVIV065QH@1SHf<0GemO05]KF`1HF5P0
De=C04E5A@13@d<0AdM703Ti>@11@D40@d=303lo?`0f=SH0=cLg03De=@0`<3009BDU02XZ:P0Y:BT0
:2PX02HV9P0I6AT201DE5@0<010@400N7Qh06ATI00H61P020P800`<300L71`051@D00`<300D51@02
0P800`<33`020P8200410CL000001oooool000Gooooo6P0000001P030`<0RXZ:0;bl_02c/k<0VYZJ
08b<S080RXZ:00L0OWin07EeM@1iNGT0N7Qh071`L01aLG40K6a/0080IfMW00X0K6a/06i^KP1[Jf/0
J6QX06IVIP1YJFT0K6a/06e]K@1^KVh0KFe]0P1ZJVX0;`1/K6`0Lg=c07]kN`29RHT0Ogmo071`L01f
MWH0PX:2071`L01MGEd0H61P08:2PP2:RXX0Ph>308N7Q`2=SHd0Q8B407EeM@1VIVH0IFEU06ATI01P
H600GUiN06=SH`1YJFT0K6a/07IfMP1eMGD0QhN708:2PP27QhL0QHF50861P@29RHT0R8R80820P023
Ph<0TI6A08V9R@1nOWh0MgMg0861P@23Ph<0Q8B407=cL`1`L700JVYZ0080KFe]01D0M7Ad071`L01Y
JFT0K6a/06][J`1OGel0C4a<05IFEP1PH600GEeM04i>CP1<C4`0CDe=0492@P17AdL0ATI603lo?`15
ADD0>c/k038b<P0^;Rh00P0g=cL00`0/;2`092@T02PX:00202LW9`0402DU9@0Q8B4071`L01TI6@80
5aLG00P030`<00@410020P801`L700T92@051@D00P8200<30a000P820P010@4h000000Oooooo0005
oooooaX0000001P00@41079bLP2l_;`0];Bd09VIV@27QhL0RXZ:08B4Q01iNGT0MgMg07IfMP1eMGD0
MWIf07AdM01]KFd0J6QX06UYJ@1XJ6P0KFe]075aL@1]KFd0IFEU06ATI01ZJVX306a/K00E06][J`1Y
JFT0KVi^071`L01fMWH0T92@08f=S@1dM7@0LW9b0861P@1oOgl0Hf=S06UYJ@2:RXX0QHF508B4Q027
QhL0Shn?08J6QP1fMWH0Hf=S0080HF5Q0P1KFe/0:P1OGel0IFEU06UYJ@1eMGD0QHF5092@T026QXH0
QhN708J6QP28R8P0RXZ:08R8R01oOgl0RXZ:092@T024Q8@0NWYj07UiN@1nOWh0MGEe07alO01cLg<0
LG5a06m_K`1[Jf/0K6a/079bLP1^KVh0JVYZ071`L01]KFd0Fe]K05=CD`1NGUh0Hf=S06QXJ01GEeL0
GEeM05MGE`1@D500CDe=04I6AP80>CTi00H0>c/k03Hf=P0f=SH0>CTi034a<@0Z:RX202LW9`0@02HV
9P0X:2P09BDU02/[:`0P82006ATI01<C4`0A4A4030`<00H61P020P801@D500@410030`<00P8200<3
0`800P8200<00`<300820P020P802`020P800`010@4000000000000g000000Oooooo0005oooooa/0
000000@0FUYJ0;jn_P2YZJT0SHf=0P26QXH01`20P800NWYj07MgM`1iNGT0M7Ad07QhN01cLg<00`1Z
JVX00`1WIfL0JFUY06][J`0206EUI@0506=SH`1TI6@0IFEU06][J`1/K6`00P1^KVh08@1]KFd0Kfm_
06YZJP1jNWX0Ng]k071`L01bLW80O7al08f=S@1nOWh0Ph>3092@T020P800QXJ608F5Q@23Ph<0PH61
07IfMP1WIfL0Hf=S065QH@1NGUh0FUYJ05]KF`1VIVH0K6a/07MgM`25QHD0R8R808Z:RP27QhL0RXZ:
08n?S`0209BDU00<08Z:RP2=SHd0TI6A08J6QP20P800Ng]k07EeM@1iNGT0O7al0861P@1nOWh0LW9b
0`1_Kfl0101[Jf/0Kfm_07UiN@1`L70205MGE`0=06=SH`1ZJVX0HV9R04U9B@1<C4`0De=C055AD@18
B4P0?clo02/[:`0n?Sh0AdM7038b<P0203Lg=`0>03<c<`0`<300:BTY02@T900U9BD0:BTY02l_;`0[
:b/06a/K01TI6@0=3@d03`l?00/;2`0410@E00820P800@41>@000007ooooo`001OoooolH0000000@
00410@000000000004E5A@2l_;`0/[:b08f=S@2:RXX0QXJ607moO`1lO7`0NWYj07alO01iNGT0LG5a
06i^KP<0JFUY00P0IfMW06IVIP1WIfL0HV9R06=SH`1VIVH0IFEU069RHP80Jf][01D0L71`06m_K`1Y
JFT0JFUY06QXJ01YJFT0L71`07QhN01aLG40Ng]k08N7Q`2HV9P0Rh^;0820P01nOWh0QHF508B4Q022
PX80Ogmo07MgM`1XJ6P00P1YJFT0201UIFD0HF5Q06=SH`1bLW80MWIf07alO020P800PX:20P27QhL0
<02<S8`0UYJF09nOW`2QXJ40WinO09:BTP2<S8`0Ph>308V9R@1oOgl0O7al08J6QP23Ph<0QhN707mo
O`1^KVh0M7Ad07QhN01aLG40KFe]07EeM@1lO7`0GEeM05MGE`1QHF40H61P05]KF`16ATH0?Cdm04m?
C`1DE5@0?Shn03Ph>010@400<S8b04U9B@12@T80;bl_038b<P0f=SH0<C4a02d];@0W9bL0820P02l_
;`0^;Rh06a/K00d=3@802PX:00@02@T900`<300?3`l010@45@020P800`010@4000000000000h0000
00Oooooo0005oooooaX0000000X00@4102l_;`2RXZ80[Jf]096AT@2:RXX0QXJ607QhN01jNWX0O7al
0P1iNGT01@1bLW80KVi^06MWI`1WIfL0JVYZ0080IVIV00P0I6AT065QH@1RHV80IfMW06EUI@1TI6@0
IFEU06YZJP80Jf][00d0IfMW06EUI@1TI6@0HV9R075aL@2=SHd0Ng]k07MgM`20P800RXZ:08>3P`1o
Ogl0Q8B400<0QHF500<0OWin06i^KP1WIfL00P1YJFT01`1XJ6P0JVYZ06e]K@1eMGD0MWIf07]kN`1m
OGd00P1nOWh0<022PX80Rh^;09JFUP2JVYX0W9bL09NGU`2?Shl0S8b<08R8R02?Shl0Ogmo08N7Q`2=
SHd0QHF508^;R`22PX80MWIf07QhN01iNGT0KVi^06m_K`1lO7`0K6a/05UIF@1OGel0HF5Q05iNGP1J
FUX0Cdm?04];B`1NGUh0>CTi02d];@0n?Sh0BTY:03hn?P12@T80<S8b03<c<`0b<S80=cLg03<c<`0/
;2`08R8R02TY:@0a<C405aLG00@410800P8200D00`<300T92@0:2PX03Ph>00D51@0D00820P800@41
>P000007ooooo`001OoooolK0000000A01dM7@2?Shl0Xj>S096AT@2<S8`0Rh^;07IfMP1hN7P0Ogmo
07YjNP1hN7P0Lg=c06][J`1WIfL0IVIV06ATI01UIFD00P1RHV802`1SHf<0HV9R06IVIP1RHV80Hf=S
065QH@1SHf<0IfMW06QXJ01WIfL0I6AT0080Hf=S00L0IFEU06a/K01^KVh0Kfm_07YjNP2ATI40T92@
0080Rh^;0P2:RXX02@1mOGd0KFe]06MWI`1XJ6P0IFEU06=SH`1TI6@0J6QX07AdM00207emO@0907]k
N`1oOgl0PH610820P01oOgl0QXJ609:BTP2IVIT0VYZJ0080YJFU00l0UIFE08^;R`2GUiL0U9BD0:FU
Y@2EUID0S8b<09ZJVP20P800NGUi0861P@1lO7`0KFe]07=cL`1gMgL00`1TI6@05P1PH600GemO05MG
E`1EEED0De=C06EUI@0h>3P0ADE504e=C@1DE5@0>SXj038b<P0i>CT0<S8b02XZ:P0b<S80<c<c02@T
900V9RH0;Rh^02DU9@051@D200410@800P8200<02`/;010@40061PH050020P8200410@0300000001
0@40000003P000001oooool000Gooooo6`0000003@0@4100Ng]k09BDU02@T900SXj>09:BTP1oOgl0
M7Ad07YjNP22PX80Ogmo07EeM@1[Jf/00P1WIfL02P1TI6@0IVIV069RHP1QHF40IVIV069RHP1SHf<0
HF5Q061PH01SHf<205mOG`0C06IVIP1UIFD0IFEU06ATI01SHf<0H61P05iNGP1PH600Hf=S07=cL`2J
VYX0]kNg0:2PX02DU9@0RHV90820P01_Kfl0IVIV06=SH`0206EUI@0U065QH@1SHf<0I6AT06QXJ01c
Lg<0Ng]k07QhN01iNGT0OGem0861P@20P800PX:208J6QP20P800RHV909RHV02@T900Rh^;08b<S02B
TY80X:2P0:VYZ@2LW9`0VIVI0:JVYP1mOGd0Ogmo0861P@1dM7@0JFUY06i^KP1_Kfl0HF5Q04i>CP1G
EeL0GUiN05UIF@0205YJFP0:061PH01GEeL0?Cdm03/k>`1>CTh0BDU9038b<P0`<300>3Ph02DU9@80
<30`00h0<C4a020P800W9bL08B4Q00d=3@010@40000000<30`051@D010@401HF5P0K6a/01@D500<3
0a@00P82?0000007ooooo`001OoooolG0000000F00410@0000000000000000051@D0E5AD08V9R@2@
T900RHV909>CT`2@T900N7Qh07=cL`1fMWH0MGEe06m_K`1/K6`0IVIV06a/K01ZJVX0IfMW06=SH`80
GemO00D0GUiN065QH@1NGUh0FUYJ05aLG00205YJFP0B061PH01RHV80I6AT06=SH`1UIFD0Lg=c06IV
IP1MGEd0FUYJ069RHP2?Shl0^k^k0:2PX022PX80LW9b06a/K01ZJVX0J6QX0P1VIVH05`1UIFD0Hf=S
061PH01SHf<0IFEU06a/K01bLW80KFe]06m_K`1dM7@0NGUi07inOP22PX80OWin08B4Q02ATI40Vi^K
08b<S02:RXX0T92@09RHV02QXJ40QHF50080O7al0280PH6107alO020P800O7al07QhN01dM7@0MgMg
06][J`13@d<0>c/k06YZJP1aLG40E5AD05QHF01FEUH0A4A404Y:BP1>CTh0<c<c04E5A@1BDU80<30`
03Hf=P0l?3`07QhN01lO7`0B4Q80<c<c02LW9`0I6AT06QXJ01DE5@092@T01`L70P0>3Ph00`0H61P0
:b/[01<C4`0D00820P@00@41>P000007ooooo`001OoooolK0000000H00410@0a<C40Ph>308^;R`2:
RXX0UiNG09fMW@2>SXh0Kfm_06a/K01cLg<0LG5a06i^KP1UIFD0JVYZ06UYJ@1WIfL0IVIV05mOG`1L
G5`0GEeM05iNGP1MGEd0FUYJ0P1HF5P04@1FEUH0F5QH05]KF`1OGel0HF5Q06IVIP1dM7@0IVIV05iN
GP1HF5P0J6QX07inOP2MWId0UYJF07]kN`1VIVH0I6AT0080HV9R0100I6AT06MWI`1YJFT0IfMW06=S
H`1TI6@0IFEU06=SH`1WIfL0MGEe07MgM`1fMWH0MgMg07QhN01kNg/0Ph>30P28R8P0<@21PH40Ph>3
08R8R02@T900W9bL08b<S01jNWX0TI6A08n?S`2=SHd0RXZ:07emO@1nOWh0Ogmo0820P01fMWH0I6AT
061PH01]KFd0QXJ606EUI@1=CDd0EEEE055AD@1CDe<0FEUI04U9B@18B4P0E5AD03hn?P0X:2P0=CDe
02TY:@0?3`l0:BTY02/[:`0e=CD08b<S01HF5P0B4Q805ADE01dM7@0G5aL05QHF01`L700U9BD04Q8B
00<30`020P800`010@4?00820P0400410@000000000000410C/000001oooool000Gooooo6`000000
6P010@405aLG07]kN`29RHT0Ph>308V9R@2@T900Shn?07AdM01[Jf/0LG5a079bLP1`L700J6QX06EU
I@1VIVH0IfMW06QXJ01RHV80G5aL05iNGP1OGel0Hf=S05iNGP1IFET0EUIF0P1EEED03`1GEeL0GUiN
061PH01UIFD0Lg=c06IVIP1RHV80I6AT07AdM01kNg/0SXj>08n?S`1hN7P0J6QX065QH@02061PH00:
05iNGP1RHV80IfMW06QXJ01WIfL0IFEU065QH@1NGUh0H61P06UYJ@<0M7Ad0P1gMgL04@1kNg/0PH61
0820P01kNg/0PX:208^;R`2@T900UYJF07moO`28R8P0Ti>C08f=S@2:RXX0S8b<07emO@1hN7P0MGEe
0080K6a/0`1UIFD0701ADE40@D5104a<C01CDe<0Cdm?055AD@1BDU80AdM704e=C@0o?cl0;Rh^03@d
=00`<300:BTY02XZ:P0X:2P0410@020P800S8b<061PH00l?3`0G5aL071`L00X:2P0F5QH0410@00T9
2@020P820000000300410@0000000@4100800@411`020P801@030`<00P8200820P010@400P8200<0
0@41?@000007ooooo`001OoooolK0000000>00410@092@T0GUiN08:2PP1mOGd0OWin0861P@1hN7P0
Lg=c06i^KP1]KFd0LW9b071`L01YJFT206EUI@0:06IVIP1WIfL0Hf=S05YJFP1IFET0G5aL065QH@1N
GUh0FUYJ05MGE`80EUIF03d0EEEE05eMG@1PH600I6AT06e]K@1TI6@0IVIV07=cL`1iNGT0Ng]k08B4
Q02>SXh0Ogmo06EUI@1OGel0Hf=S06ATI01OGel0GEeM069RHP1TI6@0IVIV06EUI@1SHf<0GemO061P
H01TI6@0KVi^075aL@1/K6`0Lg=c071`L01dM7@0NGUi07MgM`1fMWH0OWin08N7Q`2=SHd0TY:B08J6
QP27QhL0TI6A08f=S@2;Rh/0S8b<07inOP1cLg<0Kfm_06QXJ01MGEd0HF5Q05mOG`1PH600Bd];051@
D01DE5@0AdM703hn?P1<C4`0CTi>0080B4Q80140>CTi02l_;`0b<S809bLW02PX:00`<3003Ph>00<3
0`0H61P0:2PX01@D500;2`/04Q8B00d=3@092@T04A4A00<30`0200410@<0000010010@400`030`<0
0P8200820P0900820P0300410@000000000003d000001oooool000Gooooo6`00000200410@0803`l
?01mOGd0MgMg07UiN@1nOWh0M7Ad079bLP1aLG4206a/K003071`L01ZJVX0IVIV0080IVIV00<0JFUY
065QH@1JFUX00P1HF5P0101LG5`0GUiN05]KF`1FEUH305EEE@0D05UIF@1MGEd0HF5Q065QH@1SHf<0
Jf][07MgM`1lO7`0Ogmo07emO@23Ph<0Ng]k06YZJP1WIfL0IVIV06EUI@1OGel0GEeM061PH01NGUh2
061PH080HF5Q00D0I6AT06=SH`1]KFd0MgMg06i^KP02075aL@0707IfMP1lO7`0OGem07alO01oOgl0
Q8B408^;R`0208j>SP0=08n?S`2JVYX0Rh^;092@T02CTi<0Ng]k07IfMP1dM7@0JVYZ06ATI01QHF40
FUYJ05aLG00205EEE@0505MGE`16ATH0Bd];055AD@13@d<00P15ADD0400m?Cd0<30`02TY:@0/;2`0
<S8b03@d=00<30`01`L7028R8P0f=SH030`<010@40071`L01@D500l?3`0:2PX200820P0300410@00
0000000000@0000000@00@4100820P010@400@4110020P801P010@400P8200410@030`<00P820041
0Cl000001oooool000Gooooo7@000000600K6a/0NGUi07UiN@1gMgL0Ng]k07EeM@1bLW80Lg=c06i^
KP1YJFT0KFe]06a/K01WIfL0IFEU06IVIP1WIfL0GemO05]KF`1GEeL0F5QH05]KF`1MGEd0FEUI05EE
E@80EUIF00`0E5AD05IFEP1MGEd0HV9R065QH@1VIVH0MGEe07UiN@1kNg/0O7al06][J`1^KVh206][
J`0507IfMP1YJFT0HV9R05iNGP1OGel00P1QHF40101WIfL0GemO05]KF`1MGEd2061PH00e06IVIP1]
KFd0K6a/07AdM01fMWH0NWYj07moO`20P800OGem07moO`27QhL0RHV908F5Q@26QXH0S8b<06][J`1P
H600VYZJ08n?S`1cLg<0LG5a06a/K01KFe/0F5QH05MGE`1DE5@0DU9B051@D01ADE40C4a<04E5A@1@
D500ADE50451@@0i>CT0=CDe02h^;P0K6a/0:BTY03Xj>P0g=cL0820P014A4@0N7Qh0<30`02PX:009
2@T03@d=00X:2P0?3`l0410@00D51@020P800P010@48000000800@4100<00P8200410@020P801@02
0P800`010@4000000000000n000000Oooooo0005oooooa`0000000P00@4100T92@1OGel0OWin07=c
L`1eMGD0NWYj079bLP80KVi^0P1[Jf/00`1/K6`0IfMW06EUI@0206QXJ00A065QH@1LG5`0FEUI05QH
F01JFUX0EeMG05QHF01FEUH0EeMG05UIF@1GEeL0F5QH061PH01SHf<0J6QX06i^KP1iNGT00P1kNg/0
4P1fMWH0IfMW06a/K01^KVh0LG5a07AdM01VIVH0Hf=S061PH01RHV80HF5Q06=SH`1WIfL0GUiN05QH
F01MGEd0H61P05iNGP80HV9R00D0Hf=S06e]K@1dM7@0MGEe07YjNP0207QhN0040861P@2:RXX0RHV9
08B4Q080Ogmo02D0G5aL07]kN`2a/K40KVi^06EUI@1XJ6P0H61P05aLG01EEED0DE5A04m?C`1=CDd0
C4a<04Q8B015ADD0@T9203hn?P0k>c/0ATI603Lg=`0W9bL0:2PX01hN7P0X:2P0<S8b030`<00E5AD0
6QXJ01TI6@0>3Ph02`/;00H61P0820P02`/;00P820030`<00P8200L00@411@00000010020P800@41
00820P010@4300820P0300<30`020P800@41040000001oooool000Gooooo6`0000004`010@400000
00820P0i>CT0OWin07EeM@1dM7@0MgMg06m_K`1YJFT0K6a/06m_K`1/K6`0Jf][06QXJ01WIfL0JFUY
06MWI`1QHF400P1KFe/205IFEP0405EEE@1JFUX0GUiN061PH080G5aL00X0HV9R075aL@1fMWH0N7Qh
0820P025QHD0PX:207YjNP1dM7@0LW9b0P1jNWX01@1cLg<0KFe]061PH01MGEd0G5aL00<0GUiN00X0
G5aL05MGE`1GEeL0GUiN06UYJ@1ZJVX0Kfm_06QXJ01ZJVX0LG5a0P1fMWH09P22PX80O7al07moO`23
Ph<0QHF508:2PP20P800O7al07QhN01WIfL0RHV90:NWY`1RHV80K6a/06UYJ@1OGel0FUYJ05IFEP1C
De<0Cdm?04a<C01:BTX0@d=30410@00n?Sh0>c/k0410@00f=SH0;Bd]02XZ:P0R8R809bLW02<S8`0]
;Bd0820P00d=3@0A4A4051@D0P0<30`200H61P0500<30`010@400@4100410@020P800`0000000`02
0P800@4100000004000000800@4100@00P8200410@010@400@410P020P800`030`<00@4100410@10
000000Oooooo0005oooooa/0000000d00@410000000000005QHF07=cL`1jNWX0MGEe07YjNP1^KVh0
JFUY06YZJP1fMWH0MGEe0080KFe]02T0Jf][06a/K01YJFT0IFEU05aLG01OGel0FUYJ05IFEP1DE5@0
F5QH061PH01UIFD0HV9R05eMG@1TI6@0MWIf08F5Q@1oOgl0RXZ:08V9R@28R8P0QhN707QhN01mOGd0
O7al07UiN@1^KVh0JFUY065QH@1KFe/0G5aL05]KF`1IFET0EeMG05QHF01FEUH0EeMG05eMG@1`L700
N7Qh07MgM`0206][J`05071`L01cLg<0MWIf07]kN`1iNGT00P1jNWX03@1mOGd0Ogmo07moO`1kNg/0
Lg=c06EUI@1YJFT0Jf][06IVIP1_Kfl0IVIV05eMG@1EEED00P1DE5@0601ADE40C4a<04I6AP11@D40
?3`l03/k>`0i>CT0>c/k02/[:`0g=cL0;Rh^01XJ6P0V9RH08B4Q02@T900P82004A4A01PH600D51@0
410@00P820051@D02PX:00L71`@00@412P00000200410@8000001P010@51000000Oooooo0005oooo
oa/0000000T00@410000000000001PH605=CD`28R8P0MgMg07AdM01]KFd00P1YJFT0101cLg<0NGUi
075aL@1^KVh206m_K`0H06e]K@1[Jf/0HF5Q06ATI01LG5`0EEEE059BDP1FEUH0GemO06IVIP1SHf<0
GUiN05eMG@1WIfL0OWin07YjNP20P800QHF508N7Q`22PX80NWYj0861P@1gMgL0LG5a0P1ZJVX03P1W
IfL0HV9R065QH@1OGel0GUiN05UIF@1DE5@0DU9B05aLG01NGUh0GemO06UYJ@1^KVh0IVIV0P1ZJVX0
6@1]KFd0MgMg07AdM01_Kfl0Lg=c075aL@1fMWH0NGUi07IfMP1[Jf/0IFEU05eMG@1LG5`0I6AT075a
L@1[Jf/0GEeM05QHF01GEeL0EUIF059BDP1@D500B4Q80492@P0l?3`00P0h>3P05P0b<S80=CDe034a
<@0d=3@08B4Q01XJ6P0S8b<08B4Q02h^;P0V9RH03`l?00P820030`<01@D500@410010@401`L700P8
20020P8010@400H61P020P820000000300410@000000000000X000000P010@400`020P800@410041
0@11000000Oooooo0005oooooah0000000`00@4102LW9`28R8P0Q8B407=cL`1^KVh0JVYZ06UYJ@1a
LG40MWIf07EeM@1/K6`2075aL@0G06i^KP1XJ6P0Hf=S06ATI01KFe/0DU9B055AD@1DE5@0G5aL06EU
I@1VIVH0GUiN05YJFP1RHV80N7Qh08B4Q01hN7P0MWIf07emO@1jNWX0OWin07QhN01aLG400P1ZJVX0
5P1YJFT0J6QX071`L01/K6`0GemO061PH01KFe/0EeMG05ADE01IFET0I6AT06UYJ@1/K6`0Jf][065Q
H@1YJFT0IFEU06MWI`1^KVh0IVIV06UYJ@1^KVh2071`L00D06i^KP1QHF40F5QH06EUI@1PH600GUiN
06MWI`1OGel0GEeM05]KF`1FEUH0E5AD059BDP1ADE40Cdm?04E5A@0i>CT0>SXj03Lg=`0h>3P2030`
<0809BDU01806a/K02@T900/;2`0;bl_03`l?00F5QH00`<300820P0410@01PH600X:2P030`<00@41
00@410020P8010@400<30`00000300410@d000000`010@52000000Oooooo0005oooooal0000003/0
2PX:05QHF025QHD0MWIf071`L01]KFd0J6QX07=cL`1kNg/0MWIf06a/K01`L700LW9b071`L01VIVH0
GemO065QH@1MGEd0E5AD05=CD`1DE5@0F5QH065QH@1WIfL0Hf=S05eMG@1LG5`0IVIV07emO@1jNWX0
N7Qh07]kN`1hN7P0Ng]k07EeM@1bLW80Kfm_06a/K01[Jf/0JFUY06e]K@1^KVh0HF5Q05mOG`1IFET0
F5QH05EEE@1GEeL0IfMW07MgM`1aLG40JFUY06EUI@1WIfL0Hf=S05mOG`1SHf<0Lg=c07EeM@02079b
LP0O075aL@1iNGT0L71`06m_K`1[Jf/0JFUY06IVIP1YJFT0GUiN05IFEP1KFe/0E5AD04e=C@19BDT0
AdM70451@@0i>CT0>3Ph03dm?@0h>3P0=CDe02h^;P0/;2`0:b/[02XZ:P0[:b/0;Rh^02PX:00I6AT0
3`l?00D51@0200410@0500D51@071`L0410@00P820020P800P010@400`0410@00`<300820P030041
0@d000000`010@52000000Oooooo0005oooooah000000P010@402P0X:2P0Ng]k07alO01iNGT0KVi^
06QXJ01`L700Q8B407moO`1_Kfl306][J`0?06IVIP1NGUh0H61P05mOG`1IFET0E5AD05=CD`1EEED0
Fe]K069RHP1TI6@0GemO05eMG@1NGUh0Jf][0080MWIf00L0NWYj07UiN@1jNWX0Lg=c06a/K01`L700
K6a/0080JVYZ00D0IfMW06=SH`1MGEd0G5aL05QHF00205IFEP0405MGE`1LG5`0I6AT06QXJ080L71`
00@0Jf][06MWI`1XJ6P0L71`0P1]KFd0:`1aLG40KVi^06m_K`1kNg/0MWIf06e]K@1VIVH0HF5Q06AT
I01XJ6P0HF5Q05mOG`1MGEd0F5QH04e=C@18B4P0@d=303hn?P0o?cl0@4100451@@0l?3`0=SHf02h^
;P0[:b/0:2PX02DU9@0V9RH071`L01TI6@0@410030`<00h>3P0;2`/01@D500T92@0J6QX07AdM00d=
3@020P80000000410@030`<00`020P8200410@`000000`010@53000000Oooooo0005oooooal00000
01T00@4100`<301MGEd0P82007QhN01^KVh0JVYZ06i^KP1gMgL0NGUi071`L01]KFd0JFUY06QXJ01Q
HF40GUiN065QH@1OGel0G5aL05EEE@1DE5@0De=C05QHF01KFe/0GUiN0080HF5Q04L0H61P06EUI@1j
NWX0LW9b06m_K`1aLG40OGem07UiN@1jNWX0Ng]k07IfMP1^KVh0JVYZ06IVIP1NGUh0GEeM05]KF`1H
F5P0EUIF05YJFP1OGel0HF5Q06ATI01WIfL0KFe]06m_K`1^KVh0KFe]079bLP1eMGD0Kfm_06YZJP1^
KVh0Jf][06m_K`1hN7P0Kfm_06QXJ01KFe/0EEEE05YJFP1MGEd0Fe]K061PH01FEUH0De=C04i>CP18
B4P0@D510410@018B4P0@T9203/k>`0i>CT0<c<c030`<00Y:BT09RHV02LW9`0P82007AdM01hN7P0D
51@04Q8B01hN7P0L71`020P800X:2P0;2`/01PH600820P0600410@0400820P010@400@4100410@/0
00000`010@53000000Oooooo0005ooooob00000001@00P8203<c<`1jNWX0N7Qh06e]K@1YJFT0KFe]
075aL@1bLW80LG5a06][J`1VIVH0IFEU05mOG`1KFe/0GEeM05iNGP1JFUX0F5QH05YJFP80F5QH0200
EeMG05UIF@1KFe/0GemO061PH01VIVH0NWYj07AdM01/K6`0L71`07UiN@1kNg/0O7al0861P@1mOGd0
Kfm_06QXJ01TI6@0HF5Q061PH01LG5`0Fe]K05aLG01OGel0Hf=S069RHP1SHf<0GemO069RHP1[Jf/0
IfMW06QXJ080K6a/00@0L71`06i^KP1`L700Lg=c0P1kNg/01@1aLG40GUiN05QHF01HF5P0FEUI0080
GUiN0100JFUY0410@01;Bd/0BDU904I6AP12@T80@D51051@D00f=SH0:RXZ03<c<`0b<S80;bl_02/[
:`0U9BD09RHV0P0U9BD01`0J6QX05aLG028R8P0P82003`l?00820P010@400P020P8<00410@P00000
0`010@55000000Oooooo0005oooooah0000000T00@41000000000000410@05mOG`1kNg/0L71`06QX
J01[Jf/00P1^KVh01P1[Jf/0IFEU06=SH`1RHV80GemO05YJFP80Fe]K0100FEUI05aLG01TI6@0Fe]K
05UIF@1EEED0EeMG05QHF01IFET0GEeM069RHP1hN7P0NGUi06i^KP1bLW80MWIf0P1gMgL03@21PH40
R8R807IfMP1]KFd0JVYZ06UYJ@1RHV80H61P05aLG01HF5P0EeMG05UIF@1JFUX00P1MGEd02@1RHV80
IfMW06QXJ01UIFD0IVIV06QXJ01YJFT0IFEU071`L00206e]K@0B05eMG@1LG5`0DE5A04Y:BP1EEED0
GEeM05YJFP1HF5P0GemO0451@@1;Bd/0A4A404];B`16ATH0A4A404];B`0[:b/0;Rh^0P0i>CT01`0W
9bL092@T02@T900Y:BT08R8R01`L700M7Ad00P0Q8B401`0@41001@D500820P010@4010@400H61P02
0P802`010@420000000300410@000000000000<000000P010@56000000Oooooo0005ooooob400000
00`00`<303Hf=P1fMWH0Lg=c06UYJ@1WIfL0Jf][06a/K01WIfL0IFEU06=SH`1NGUh205YJFP0805UI
F@1HF5P0EUIF05MGE`1YJFT0J6QX05YJFP1HF5P305IFEP0605QHF01NGUh0P82008N7Q`1cLg<0M7Ad
0P1hN7P207]kN`0907EeM@1_Kfl0JFUY06UYJ@1]KFd0Jf][069RHP1QHF40GemO0080EeMG00X0EUIF
05UIF@1NGUh0HF5Q06ATI01RHV80H61P06IVIP1WIfL0I6AT0P1SHf<04P1PH600EUIF05ADE01?Cdl0
;Bd]03Ph>01DE5@0IVIV055AD@1JFUX0EUIF03Ti>@0m?Cd0@41004i>CP1;Bd/0AdM703`l?080<S8b
00D0>3Ph02@T900O7al092@T020P800301`L70805ADE00P04A4A00X:2P020P800P8200410@030`<0
10@400820P@00@410P00000500410@80000000<00@41000000000000B`000007ooooo`001OoooolQ
0000000<00410@0C4a<0H61P07]kN`1bLW80JFUY06YZJP1YJFT0I6AT06EUI@1XJ6P0H61P0P1HF5P0
2@1IFET0Fe]K05EEE@1FEUH0Hf=S06a/K01NGUh0Fe]K05UIF@0205EEE@0>05IFEP1LG5`0PH6108Z:
RP1jNWX0NGUi07]kN`1jNWX0NGUi07EeM@1cLg<0IVIV05]KF`1MGEd206EUI@07069RHP1/K6`0H61P
05UIF@1LG5`0GEeM05iNGP0205mOG`0705eMG@1KFe/0GemO065QH@1RHV80G5aL05YJFP0205eMG@0O
05=CD`1GEeL0BDU903Ti>@1PH600IfMW07alO01GEeL0G5aL055AD@19BDT0?Shn03`l?00k>c/0=cLg
03/k>`0j>SX0=3@d02l_;`0R8R806a/K024Q8@0S8b<09BDU01hN7P0W9bL05QHF00T92@0;2`/04a<C
00H61P0200410@03000000010@400@4100`00@410P0000000`010@4000000000001;000000Oooooo
0005ooooob80000000@010@403Hf=P1fMWH0MWIf0P1^KVh07P1ZJVX0IFEU06ATI01ZJVX0IVIV05YJ
FP1HF5P0FUYJ05]KF`1HF5P0FUYJ06ATI01`L700Lg=c06MWI`1OGel0Fe]K05MGE`1FEUH0GemO07in
OP21PH40R8R80861P@1mOGd0MGEe07AdM01gMgL0KFe]065QH@80EeMG00l0GEeM065QH@1NGUh0GemO
05]KF`1FEUH0GEeM061PH01JFUX0GemO05eMG@1OGel0Fe]K05aLG01JFUX00P1HF5P04P1GEeL0Fe]K
05]KF`1IFET0Cdm?04Y:BP18B4P0K6a/0861P@22PX80AdM704I6AP11@D40?Cdm03<c<`0i>CT0=CDe
038b<P80=cLg00D0=3@d02d];@0L71`08B4Q02DU9@02024Q8@807AdM00L02PX:00`<300C4a<04a<C
00<30`010@400P8201800@41C@000007ooooo`001OoooolO0000000800410@000000000000410@0:
2PX0AdM7071`L01cLg<207AdM00806e]K@1VIVH0Hf=S06MWI`1SHf<0GEeM061PH01XJ6P206YZJP18
06a/K01eMGD0OGem08F5Q@24Q8@0PX:207moO`1cLg<0MGEe08f=S@29RHT0QXJ607IfMP1lO7`0PX:2
07]kN`1jNWX0Jf][05]KF`1CDe<0Cdm?05ADE01NGUh0HV9R05mOG`1MGEd0EUIF05eMG@1PH600EEEE
05MGE`1CDe<0EEEE05MGE`1JFUX0FEUI05QHF01EEED0EeMG05UIF@1HF5P0EeMG04e=C@1<C4`0Bd];
05]KF`1WIfL0CTi>03Lg=`14A4@0ADE504A4A00n?Sh0>c/k03`l?00b<S80=CDe03Hf=P0X:2P07alO
02DU9@0S8b<07AdM01LG5`0H61P04A4A00`<300B4Q803@d=018B4P0=3@d00P8250010@5=000000Oo
oooo0005ooooob<0000000P00@41014A4@1CDe<0Kfm_07IfMP1hN7P0Ng]k071`L080IFEU00D0Hf=S
05eMG@1XJ6P0KFe]06QXJ00207UiN@0L079bLP1gMgL0Ogmo08:2PP28R8P0UIFE09JFUP2IVIT0Shn?
07EeM@1aLG40LW9b07=cL`1gMgL0Ogmo07=cL`1SHf<0FUYJ05ADE01=CDd0C4a<05ADE01KFe/0GUiN
05]KF`1DE5@0GEeM05]KF`80ATI600<0Cdm?05=CD`1LG5`00P1GEeL03`1IFET0F5QH05IFEP1EEED0
F5QH04m?C`1:BTX0AdM704I6AP18B4P0?clo03<c<`0b<S80C4a<03/k>`0203`l?00403Ti>@0f=SH0
9BDU02XZ:P@0;2`/00/06a/K01XJ6P0J6QX04a<C014A4@0E5AD06QXJ018B4P0?3`l01`L700820P05
00410@03000000010@400@4100`00@41C@000007ooooo`001OoooolT0000000E00<30`0f=SH0IfMW
07=cL`1fMWH0N7Qh07]kN`1]KFd0HV9R06ATI01NGUh0J6QX06][J`1VIVH0Jf][07]kN`1^KVh0LG5a
07=cL`1_Kfl0Lg=c0080OGem01`0Ph>308B4Q01dM7@0NWYj07IfMP1dM7@0MGEe07=cL`1]KFd0HV9R
05MGE`1FEUH0De=C04e=C@1BDU80E5AD05MGE`1FEUH0E5AD05aLG01@D500Cdm?055AD@1CDe<0EeMG
05IFEP1ADE40EEEE0P1HF5P01@1CDe<0DU9B059BDP1<C4`0Bd];0080B4Q800H0C4a<03Xj>P0i>CT0
?3`l04];B`0Z:RX203Ti>@0=03<c<`0`<300;Bd]02`/;00i>CT0?Cdm02l_;`0Q8B405aLG020P800I
6AT05QHF01<C4`03010@400400D51@030`<00@4100820Q<00@41C@000007ooooo`001OoooolO0000
000300410@00000000000080000000d00@4101@D501DE5@0KVi^07MgM`1fMWH0MGEe06MWI`1QHF40
HV9R05aLG01MGEd0Fe]K00<0J6QX01@0KVi^06a/K01XJ6P0JVYZ06a/K01aLG40Kfm_07EeM@1`L700
N7Qh07UiN@1bLW80MGEe06i^KP1WIfL0IFEU061PH01IFET0DU9B051@D080Bd];0100CDe=05EEE@1J
FUX0Fe]K05mOG`1CDe<0EeMG05YJFP1FEUH0E5AD05IFEP1DE5@0F5QH05EEE@1FEUH0DE5A0P1@D500
2P1=CDd0Bd];04I6AP17AdL0Bd];0410@00m?Cd0?Shn04A4A00_;bl203Xj>P0@03@d=00/;2`09bLW
02TY:@0f=SH0:BTY02@T900N7Qh092@T02HV9P0L71`08R8R01`L70071`L010@400H61P<00@4100<0
000000410@010@404@010@5=000000Oooooo0005ooooobD0000001P00`<302l_;`1SHf<0Lg=c07Qh
N01cLg<0KVi^06EUI@1QHF40G5aL05UIF@1GEeL0H61P06e]K@1WIfL0KVi^079bLP1[Jf/0JFUY06][
J`1/K6`0J6QX06=SH`1TI6@207AdM00F07IfMP1gMgL0M7Ad06i^KP1PH600GemO05]KF`1EEED0DE5A
04];B`1:BTX0C4a<059BDP1HF5P0De=C05]KF`1ADE40EeMG05YJFP1IFET0De=C05EEE@80FEUI00P0
E5AD05=CD`1BDU80DE5A04e=C@19BDT0B4Q804I6AP80ADE501@0@D5103dm?@0n?Sh0ADE502`/;00^
;Rh0=CDe02TY:@0O7al09BDU02TY:@0`<3008b<S01hN7P0O7al05QHF00l?3`0D51@05QHF00X:2P80
0P8200<01PH600410@020P801@010@400`0000000@4100410@0=00410Dd000001oooool000Gooooo
9@00000060010@402`/;04U9B@1ZJVX0MgMg07UiN@1_Kfl0IVIV065QH@1KFe/0EeMG05IFEP1JFUX0
IFEU061PH01RHV80K6a/06][J`1]KFd0Jf][06UYJ@1^KVh0K6a/07QhN080LG5a0P1eMGD08P23Ph<0
K6a/061PH01NGUh0GEeM05MGE`1ADE40Bd];04M7A`16ATH0Bd];059BDP1SHf<0LG5a04e=C@1DE5@0
DU9B04i>CP1ADE40DU9B05ADE01JFUX0DE5A04i>CP1?Cdl0CTi>04];B`1:BTX0B4Q804U9B@1:BTX0
ATI60451@@0h>3P203dm?@0=02HV9P0Y:BT0<C4a024Q8@0P82008B4Q02DU9@0W9bL061PH01LG5`0H
61P020P800X:2P0200/;2`0400X:2P020P800@4100820QL00@41C@000007ooooo`001OoooolV0000
000<00820P0R8R80Fe]K06i^KP1jNWX0LW9b06ATI01QHF40G5aL05QHF01FEUH0F5QH0P1PH6001`1M
GEd0HV9R06QXJ01ZJVX0J6QX06MWI`1/K6`00P1_Kfl01P1YJFT0L71`079bLP1[Jf/0L71`06=SH`80
HF5Q00d0GemO05YJFP1BDU80Bd];04E5A@13@d<0B4Q805=CD`1PH600Fe]K05=CD`1ADE40Cdm?0080
C4a<00P0CDe=051@D01IFET0CDe=055AD@1=CDd0Bd];04i>CP80C4a<00X0DE5A04a<C00n?Sh0?Cdm
03Hf=P0b<S80;2`/02TY:@0W9bL0:2PX0P0M7Ad0100W9bL0;bl_02PX:00F5QH2018B4P0500`<3006
1PH01@D500X:2P092@T00P020P8F00410Dl000001oooool000Gooooo9`0000003@061PH0>c/k06EU
I@1eMGD0NWYj06i^KP1VIVH0G5aL05UIF@1DE5@0EEEE05UIF@1OGel00P1LG5`0<P1UIFD0JFUY05mO
G`1QHF40I6AT06i^KP1aLG40Kfm_07=cL`1eMGD0KFe]05eMG@1JFUX0H61P065QH@1?Cdl0G5aL05QH
F01=CDd0ATI604A4A019BDT0DE5A05MGE`1KFe/0EUIF05YJFP1CDe<0CTi>04];B`1=CDd0E5AD05=C
D`13@d<0ADE503Xj>P11@D40Cdm?055AD@1EEED0EUIF02@T900?3`l0<S8b03Hf=P0];Bd0;2`/02TY
:@0T92@08b<S0P0L71`0300Y:BT092@T01`L700D51@05ADE018B4P0F5QH020P800H61P051@D010@4
00820QL00@41C`000007ooooo`001OoooolW0000000X00410@0D51@0Cdm?06a/K021PH40O7al06m_
K`1QHF40Fe]K05MGE`1FEUH0EeMG05YJFP1LG5`0GEeM06IVIP1YJFT0I6AT071`L01RHV80J6QX06UY
J@1^KVh0Lg=c06i^KP1UIFD0E5AD059BDP1FEUH0FUYJ05eMG@1fMWH0GUiN04i>CP17AdL0ATI604];
B`1=CDd0EUIF05YJFP80De=C00<0D51@05IFEP1DE5@00P1IFET0701?Cdl0ATI603Xj>P0e=CD0@410
0492@P0g=cL0@D5103Xj>P0E5AD05aLG059BDP1<C4`0:b/[02d];@0[:b/0:2PX02LW9`0S8b<092@T
02XZ:P0Y:BT07AdM01@D500H61P05QHF01DE5@0410@400820QH00@41D0000007ooooo`001OoooolX
0000000>00820P0V9RH0G5aL07alO02QXJ40MgMg06=SH`1NGUh0FUYJ05EEE@1FEUH0F5QH05aLG01R
HV8206EUI@0906QXJ01]KFd0F5QH05aLG01PH600K6a/06][J`1PH600Fe]K0080CTi>0P1ADE40101E
EED0HV9R055AD@1:BTX404U9B@0?05IFEP1DE5@0B4Q805ADE01>CTh0De=C05IFEP1>CTh0B4Q804M7
A`1:BTX0=SHf04=3@`17AdL0@d=30080?clo00`0>CTi02TY:@12@T80GemO03Xj>P0Z:RX09bLW02/[
:`0W9bL08R8R01hN7P0];Bd202`/;00501@D500:2PX04a<C01@D500820P00P010@400`020P800@41
00410@0F00410E0000001oooool000Gooooo9P00000040010@4000000000000820P0>c/k06MWI`2O
Wil0RHV906QXJ01QHF40Fe]K05ADE01@D500DE5A05ADE01JFUX205mOG`0;065QH@1MGEd0FEUI05eM
G@1RHV80Jf][05iNGP1OGel0I6AT04i>CP1:BTX00P1<C4`01`1:BTX0Bd];04M7A`19BDT0B4Q804I6
AP17AdL00P18B4P01`16ATH0ADE504m?C`1?Cdl0C4a<04e=C@1;Bd/00P1:BTX06`1;Bd/0?clo04=3
@`18B4P0ATI604U9B@17AdL0@41002h^;P0a<C40<30`02XZ:P0e=CD09bLW02@T900O7al06a/K01hN
7P0/;2`071`L00T92@030`<00P8200@410071`L010@400820P0I00410E4000001oooool000Gooooo
:@0000002P010@405ADE04a<C01bLW80SXj>07MgM`1WIfL0GemO05IFEP1@D50304i>CP0D059BDP1G
EeL0EUIF05QHF01OGel0FEUI05QHF01KFe/0E5AD05mOG`1SHf<0CDe=04M7A`16ATH0ADE504A4A015
ADD0@d=304E5A@17AdL204=3@`0604M7A`1:BTX0ATI604Q8B016ATH0BDU90P16ATH204M7A`0E04];
B`19BDT0AdM704Q8B01@D500EeMG05iNGP1DE5@0>3Ph038b<P0a<C40;Rh^030`<010@400;2`/020P
800K6a/071`L01/K6`0P82002@T900@00P8200<00`<300D51@020P806@010@5A000000Oooooo0005
ooooobX0000001d00`<302@T901HF5P0Ng]k07MgM`1ZJVX0GemO05MGE`1ADE40CTi>04m?C`1<C4`0
BTY:04];B`19BDT0C4a<04i>CP1BDU80DE5A04i>CP1CDe<0FEUI05aLG01=CDd0ADE50492@P0o?cl0
?3`l03dm?@0203hn?P070492@P0o?cl0?clo04I6AP18B4P0AdM704Y:BP0204I6AP0304=3@`16ATH0
B4Q80080ATI600X0A4A40410@00n?Sh0@T9204E5A@19BDT0<30`02LW9`0c<c<0;bl_0P0[:b/02@10
@400;Bd]020P800F5QH071`L01TI6@0K6a/03Ph>00<30`0200820P0400<30`020P8010@400H61P@0
0@4100<00P8200410@010@404@010@5B000000Oooooo0005ooooobH0000000<00@41000000000000
0P00000040071`L0=CDe06QXJ01]KFd0IfMW05]KF`1GEeL0D51@059BDP1@D500C4a<04Y:BP19BDT0
AdM704A4A012@T8204E5A@0@0492@P17AdL0Cdm?05YJFP1EEED0BDU903lo?`0j>SX0>3Ph03Ti>@0h
>3P0>c/k03hn?P0l?3`0?Cdm0492@P80ADE500D0AdM704Q8B018B4P0CDe=04=3@`0203`l?00L0492
@P11@D40?clo03`l?00m?Cd0>SXj0410@00h>3P0=SHf03/k>`0Y:BT0:2PX02LW9`0e=CD0:2PX01DE
5@071`L04Q8B01HF5P0J6QX05QHF00D51@030`<010@400<30`092@T03`l?00@411P00@41DP000007
ooooo`001Oooool[0000000J00410@0?3`l0D51@069RHP1OGel0FUYJ05ADE01BDU80Cdm?055AD@1=
CDd0Bd];04U9B@18B4P0ATI60410@00o?cl0?Shn03`l?00m?Cd0@T9204a<C01DE5@0D51@0410@00j
>SX203Hf=P0603Lg=`0i>CT0?clo03dm?@0i>CT0?3`l0P15ADD304A4A00P04I6AP0_;bl0=3@d03Lg
=`11@D40?clo03dm?@0j>SX0@41004Q8B00k>c/0<30`02@T900S8b<071`L02HV9P0U9BD0:b/[02PX
:00H61P0410@014A4@0B4Q802@T900l?3`092@T02PX:00T92@0<30`04Q8B00T92@020P8?00410@@0
0P8210010@400`020P8000000000001@000000Oooooo0005ooooobX0000000T00@41000000010@40
<C4a05]KF`1JFUX0EUIF055AD@1@D5000P1>CTh01`1<C4`0BTY:04U9B@19BDT0B4Q80410@00n?Sh0
0P0m?Cd203`l?00?03lo?`16ATH0@d=303dm?@0g=cL0<c<c038b<P0c<c<0=SHf03/k>`12@T80>c/k
03Xj>P0o?cl0@T920080A4A400<0@d=304I6AP0i>CT00P0o?cl04@0m?Cd0>c/k03lo?`11@D40ATI6
03Ti>@0K6a/06QXJ020P800Y:BT0:2PX02DU9@0[:b/0=cLg024Q8@0J6QX05aLG00802PX:00L00P82
00L71`0:2PX010@400<30`0820P01PH601400@410P020P8700410E8000001oooool000Gooooo;@00
00002P0E5AD0CDe=05ADE01@D500C4a<04I6AP18B4P0CTi>04Y:BP15ADD204I6AP0604M7A`14A4@0
?clo03lo?`10@400?Cdm0P0i>CT05P0n?Sh0@41003dm?@0f=SH0=3@d038b<P0a<C40<30`034a<@0i
>CT0?3`l03lo?`0l?3`0?Shn0451@@15ADD0ATI603/k>`0Z:RX0?3`l03Ti>@0k>c/203hn?P0I03Ph
>00U9BD03Ph>00@410051@D0410@02DU9@0V9RH06a/K01hN7P0R8R804A4A01DE5@0?3`l02PX:0082
0P010@400P8200@410030`<00P8200410@020P800@4100820P0?00410@800P8200<00@4100000001
0@4010010@5B000000Oooooo0005ooooobX000000P010@403`00000010@402l_;`1=CDd0Cdm?04i>
CP18B4P0BTY:04m?C`1>CTh0A4A40492@P14A4@0ATI60451@@0203hn?P0503lo?`0l?3`0>CTi03Ph
>00o?cl00P1:BTX08P0k>c/0=CDe03@d=00b<S80;2`/02d];@0^;Rh0=3@d03Ti>@0j>SX0>c/k03`l
?00o?cl0@D5103De=@0f=SH0A4A403<c<`0i>CT0=SHf03lo?`0n?Sh04A4A00<30`071`L0410@014A
4@0R8R809BDU014A4@092@T04A4A00`<300:2PX200L71`0600<30`020P800P8200<30`0;2`/01@D5
4P010@400`020P800`<300820P0500410E@000001oooool000Gooooo;P0000000`061PH08R8R0451
@@0204Y:BP0504Q8B01;Bd/0BDU904=3@`0o?cl00P0n?Sh05@0l?3`0>c/k03/k>`0l?3`0>c/k03Ti
>@0f=SH0=cLg03`l?010@400?Cdm03Ti>@0h>3P0<c<c02h^;P0[:b/0:RXZ02h^;P0d=3@0=cLg03Hf
=P0203Ti>@0A03Ph>00e=CD0=SHf03Ph>00d=3@0<C4a030`<00n?Sh0=3@d01<C4`0<30`06QXJ02DU
9@0M7Ad07QhN03`l?00a<C400P092@T02P0;2`/030`<00P820092@T010@400<30`020P800`<300T9
2@0410@600410@800P820P010@400`020P800@4100410@0300410@L00P820`010@5D000000Oooooo
0005ooooobd0000000`00@41000000010@404a<C03Xj>P16ATH0ADE504I6AP19BDT0ADE50410@00m
?Cd203/k>`0=03Ph>00g=cL0=CDe03Hf=P0g=cL0=3@d030`<00d=3@0>3Ph03Ti>@0f=SH0=CDe03@d
=00203<c<`0702l_;`0/;2`0<30`038b<P0c<c<0=SHf03Lg=`0303De=@0702l_;`0];Bd0;bl_030`
<00f=SH07AdM01XJ6P0201TI6@09024Q8@0/;2`0?3`l055AD@0U9BD020P800L71`061PH00`<30080
0P8200@010@400<30`010@400@410P020P8400410@03000000010@400P8200@00P820`010@400`02
0P800@4100820P0600820P800@41E@000007ooooo`001Oooool`0000000300820P0H61P0>SXj0080
@d=300P0A4A40492@P11@D40?Shn03Ti>@0j>SX0>CTi03Lg=`80=SHf00@0=3@d03<c<`0a<C40=CDe
0P0f=SH0200c<c<0<S8b034a<@0`<300<C4a030`<00^;Rh0;bl_0P0`<3004`0b<S80=cLg03@d=00c
<c<0<30`03<c<`0g=cL0<30`03De=@0c<c<05aLG01PH600F5QH04Q8B01lO7`0];Bd0;bl_020P8007
1`L01@030`<010020P800`<300<30`020P8200410@<00P8210010@4500820P<00@4100<00P820041
0@020P800P020P8600410ED000001oooool000Gooooo<@0000001P0410@06a/K03Ti>@0o?cl0@410
03lo?`80?Cdm02X0>c/k03Ti>@0h>3P0=SHf03Lg=`0i>CT0=SHf03@d=00c<c<0=3@d03Hf=P0d=3@0
<S8b030`<00_;bl0;Rh^02d];@0^;Rh0;Bd]02`/;00[:b/0;2`/02l_;`0`<300;bl_030`<00/;2`0
;Rh^024Q8@0H61P0;2`/02@T900J6QX07AdM01HF5P0B4Q805ADE018B4P0<30`01PH600D51@030`<;
00820PD00@411@020P8500410@800P8200<00@4100820P020P800`010@5G000000Oooooo0005oooo
oc80000000<00`<301hN7P0h>3P0100k>c/02@0m?Cd0>3Ph03Hf=P0d=3@0=CDe03Lg=`0k>c/0=SHf
03<c<`03038b<P0N034a<@0`<300;bl_02`/;00^;Rh0;Bd]02XZ:P0X:2P09bLW02HV9P0Y:BT0:RXZ
038b<P0`<300:BTY02DU9@0K6a/07AdM020P800R8R8061PH01TI6@0J6QX05QHF00l?3`0:2PX01@D5
00P820061PH010@43`020P800`010@400P8200820P0300820PD00@4110020P8010010@4000000041
0@010@5G000000Oooooo0005oooooc<0000000X01@D5020P800g=cL0>SXj03Ph>00g=cL0>3Ph03Ti
>@0f=SH0=3@d0P0b<S80100e=CD0=SHf030`<00`<30302d];@80:b/[100Z:RX00`0X:2P09bLW02@T
900202<S8`0402TY:@0M7Ad08B4Q01lO7`808B4Q00h09BDU02XZ:P0C4a<05QHF01<C4`0>3Ph020P8
00H61P071`L020P800D51@030`<00P8200<30`/00P820P030`<600820PD00@411@020P800`010@40
00000000001G000000Oooooo0005ooooobl0000000<00@410000000000000P0000009`051@D08B4Q
03De=@0g=cL0=SHf03De=@0d=3@0=CDe038b<P0_;bl0<30`03<c<`0_;bl0:RXZ02TY:@0U9BD0:BTY
02XZ:P0W9bL09BDU02LW9`0X:2P09RHV02@T900U9BD08b<S028R8P0P82007QhN01lO7`0V9RH06QXJ
01`L700K6a/071`L020P800H61P030`<018B4P0200h>3P0500L71`0410@010@400@410030`<08002
0P8300410EL000001oooool000Gooooo=@00000010051@D07AdM03@d=00f=SH3038b<P0?034a<@0_
;bl0;bl_02l_;`0^;Rh0;Bd]02HV9P0S8b<09RHV02LW9`0U9BD092@T028R8P0S8b<09BDU00808b<S
00<08B4Q01lO7`0O7al00P0N7Qh01P0O7al071`L01LG5`0F5QH05aLG014A4@803`l?00<04A4A00`<
300;2`/0100410@200<30`0300820P030`<00P8200<00P8200<00`<300820P020P805P020P800`01
0@4000000000001G000000Oooooo0005oooooc@0000000T00@41000000051@D07AdM038b<P0e=CD0
<S8b030`<00_;bl00P0];Bd302h^;P0302LW9`0V9RH09BDU00809BDU00P08b<S028R8P0R8R808R8R
024Q8@0P82007alO01hN7P<07AdM00T06QXJ01DE5@0B4Q804a<C010@400?3`l0410@014A4@0;2`/0
0P061PH300@410800`<300<01`L700820P020P8070020P8200410ET000001oooool000Gooooo=`00
0000400410@071`L034a<@0c<c<0<30`02`/;00Z:RX0;2`/030`<00^;Rh0:BTY02HV9P0T92@08b<S
028R8P0S8b<2028R8P80820P00@07QhN01dM7@0K6a/06a/K0`0I6AT0100F5QH04Q8B010@400?3`l2
00/;2`0700d=3@0<30`01@D500@410071`L01@D500@4100300820P0300<30`020P800P8201d00P82
FP000007ooooo`001Ooooolh0000000500@4100J6QX0;Rh^030`<00[:b/00P0Z:RX0100Y:BT0;2`/
02PX:00T92@3024Q8@03020P800O7al07alO00807AdM01806a/K01XJ6P0H61P05aLG01HF5P0E5AD0
5QHF01<C4`0?3`l03Ph>00/;2`092@T01`L700H61P051@D00`<300820P0410@200<30`<00P8200<0
0`<300820P020P8050020P800`030`<00P8200820P0400820P800@41FP000007ooooo`001Oooooli
0000000@00@4100F5QH0;2`/02`/;00Y:BT0:2PX02DU9@0V9RH09BDU02@T900R8R80820P01lO7`0N
7Qh07AdM01/K6`806QXJ00<06ATI01PH600E5AD00`0D51@02@0C4a<04A4A00d=3@0<30`02@T900L7
1`061PH01@D500@4100200820P0500410@020P800`<300820P010@404`020P802@030`<00P820041
0@020P800`<300820P030`<00P8200<30`0200820P800@41F`000007ooooo`001Ooooolh00000004
00410@0000000`<301<C4`80:2PX00/09bLW02DU9@0S8b<08R8R024Q8@0P82007alO01dM7@0L71`0
6a/K01TI6@0201PH600301LG5`0F5QH051@D00804a<C00X04Q8B010@400>3Ph02`/;00X:2P092@T0
1PH600D51@0410@00`<30`020P800`030`<00P8200820P0F00820P@00@411@020P800`010@400000
0000001J000000Oooooo0005ooooocT000000P010@4040020P80410@020P800U9BD08b<S024Q8@0N
7Qh07alO01hN7P0L71`06a/K01XJ6P0I6AT05ADE01HF5P0E5AD201<C4`04014A4@0>3Ph0410@00d=
3@802`/;00X020P800L71`092@T020P800H61P030`<00P8200<30`0820P010@40P020P800`010@40
0P8200820P0B00820PP00@410P020P8300410E/000001oooool000Gooooo?00000001@010@402@T9
028R8P0S8b<08B4Q00807QhN00@071`L01/K6`0I6AT061PH0P0E5AD02`0D51@04Q8B014A4@0@4100
3`l?00d=3@0<30`02PX:00L71`061PH01@D500D00`<300H010@400X:2P0;2`/00`<300820P030`<E
00820P0300410@0000000@4100800@4100<00P8200410@010@400`010@5M000000Oooooo0005oooo
ocL0000000<00@410000000000000`0000002@010@401`L701@D500N7Qh07AdM01/K6`0M7Ad06a/K
01PH600201<C4`804Q8B00T0410@00d=3@0<30`02`/;00X:2P092@T020P800H61P051@D00P030`<3
00820P0500<30`051@D02PX:00L71`030`<05P020P8200410@@0000000D00@4100820P010@400P82
00410@1N000000Oooooo0005oooooc`0000000d00@41000000010@400`<301<C4`0L71`06a/K01PH
600I6AT05aLG01<C4`0B4Q80410@00803@d=00<030`<00T92@092@T00P071`L010092@T01PH600@4
10020P8400410AX00P820P010@470000000300820P010@400@4105h000001oooool000Gooooo@000
00003@051@D05QHF01PH600I6AT05ADE01@D500E5AD0410@00h>3P0;2`/02PX:00T92@0820P00P06
1PH01P0410@01@D500@410030`<00@4100820P<00@4100<00`<300820P020P805`020P8200410@P0
000000<00`<3000000000000G@000007ooooo`001Oooooli0000000300410@000000000000800000
0P010@40100000000`<300X:2P0B4Q8200l?3`0300d=3@0:2PX02@T900801`L70P051@D00`061PH0
1@D500820P0R00820P0300410@000000000000T000000P010@5L000000Oooooo0005oooooch00000
00<00@410000000000000P0000001P010@400P8200H61P0410@00`<300@410@00`<30P0820P01003
0`<00P8200820P020P8500410AT00P8200<00@41000000000000J0000007ooooo`001Ooooom40000
00800@4100D010@400H61P071`L010@400820P0200410@H00P821@010@4H00820P800@41JP000007
ooooo`001Ooooolm0000000300410@000000000000D0000000<00@41000000030`<00P030`<01P02
0P800@4100410@010@400P8200<30`<00P821@010@4H00820P800@41JP000007ooooo`001Ooooom9
000000H00@412`020P800`030`<00P8200820P0B00820P800@41J`000007ooooo`001Ooooolo0000
000300410@000000000000T000000`010@40100000000@4100820P030`<M00820P0300410@000000
000006X000001oooool000GoooooC@00000300410Ah00P820P010@5/000000Oooooo0005ooooocd0
000000<00@410000000000003P00000400410A/00P820P010@5]000000Oooooo0005oooooe000000
0`010@4J00820P0300410@000000000006`000001oooool000GoooooD@00000400410AP00P8200<0
0@41000000000000K0000007ooooo`001OoooomC000000<00@4100<0000000410@020P804`020P82
00410Fh000001oooool000GoooooE@00000500410A800P820P010@5^000000Oooooo0005oooooeP0
00001@010@4>00820P800@41K`000007ooooo`001OoooomJ0000000300410@020P800@4100@00@41
2P020P8200410Fl000001oooool000GoooooG@00000600410@<00P8210030`<00`020P800@410000
001_000000Oooooo0005ooooof0000001@010@4600820P0300410@000000000006h000001oooool0
00GoooooH`00000900410G0000001oooool000GoooooI@00000700410G0000001oooool000Gooooo
g0000007ooooo`001OoooooL000000Oooooo0005ooooom`000001oooool000Gooooog0000007oooo
o`001OoooooL000000Oooooo0005ooooom`000001oooool000Gooooog0000007ooooo`001OoooooL
000000Oooooo0005ooooom`000001oooool000Gooooog0000007ooooo`001OoooooL000000Oooooo
0005ooooom`000001oooool000Gooooog0000007ooooo`001OoooooL000000Oooooo0005ooooom`0
00001oooool000Gooooog0000007ooooo`001OoooooL000000Oooooo0005ooooom`000001oooool0
00Gooooog0000007ooooo`001OoooooL000000Oooooo0005ooooom`000001oooool000Gooooog000
0007ooooo`001OoooooL000000Oooooo0005ooooom`000001oooool000Gooooog0000007ooooo`00
1OoooooL000000Oooooo0005ooooom`000001oooool000Gooooog0000007ooooo`00j?ooool00>So
oooo003Xooooo`00j?ooool00>Sooooo003Xooooo`00\
\>"],
  ImageRangeCache->{{{0, 231}, {268, 0}} -> {-5.80121, -6.81083, 1.05456, \
1.05456}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Color image", "Subsubsection"],

Cell["\<\
Adjust the directory setting and input file below to your system \
configuration.\
\>", "Text"],

Cell[BoxData[{
    \(\(dir = "\</Users/nechyba/public_html/eel3135/data\>";\)\), "\
\[IndentingNewLine]", 
    \(\(file = "\<sample_color.jpg\>";\)\)}], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetDirectory[dir];\)\), "\[IndentingNewLine]", 
    \(\(im2 = Import[file];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[im2];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
%%ImageSize: 320 240 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00297619 0.0178571 0.00297619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01786 translate
.95238 .71428 scale
960 string
320 240 8 [320 0 0 240 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0D05020C07030B08010A0A020807030908060B040B0C020A0D020A0E0206120205110303
0C02000D05020C04020A05020B060308070508060B0907140B071E0C05270E032E0C0030
0D012F0C042D0D08280B07200E091D110B19120B12130A0B1307070D04050B090E08090E
060A0B0509080507060507060806090705080905060905060806070806070B05090B0507
0D04070B05050A04040706040907080705080B060D0D030E0F030F11040E15050F17080B
1A08041607001606061006070E080C0B090C0A09070605010A05020C06060E050810070C
0D060D0E080A100B080E0903110A040E0A0708070F070A130A091109080E0A041009030D
08050C0806090A060508070308070206080307090604080907080C07060B0B07080C0606
0F06070D07070A060307080307080306080504070C05080D0A090F0606080A0509090504
0B0706080703080703070803060803060803080705090806080806070705080703080705
0B07080B060C08050C07040B08060906060608080A06070906070906070907080A050608
04080903070806070905060A06050D07060E09030D0A050B0A030A0A04060905060A0605
0706040807050806090705080A05090B060A0A0509080607080607060604070906070906
050704050704080904070803070904060803040903030802050702060803060702070803
060902030801050A04040B04050C05050C05050C05050B07030C09030B0D040B15020816
02051604051706061207060C070707070803060604060702060702080903080703070803
06070103080204080902091102071A0207250605310905370D053810043211022B0F0124
0E011D0B03180C061209090B090907090E0706120606130C031019020A2102062B08062D
1007221005150E030B0D04070A070E0806130B031B0D02200F01220F001D0F01180D0210
07040B070709060709060807050702050A04040D08020C0E00091801062301032C07012D
0F002710001A12000E0D01030B060307080306080704080908090E06070C07060C08070D
06040F0805100A04100B040C0D02080D05030A050207060207070706070B06050D07060E
0A040E09040A0B0706080703070602070803070803070803080702080702060604070705
0806070907080C06060B05050A0603070602070705060B05040903030A02030905030905
030907030907060A09040807040807040807060709050608050706050706050608060709
05060A05060B03060D03060F06060E05050D08081405050F08051006050B07060B030708
04080703090906070B06070C08060B09040A0B040B0D030B
180E0C18100D18130F1815101915121915141913171B111920131A211217221215221414
201513201614211716211716211917211B1B211B1F211B25271E312D203C18082C130328
120428100525120A22140C21140E1C151017171115170F0D160C0A1109070C0A0F0A090F
0B0B0D0A0A0A0808080707070806070806070A06070905040C08070A06050B05070C0606
0D05030D05030D05030B06030804030903050E050A0E030B11040D12050E160A0E1A0E0E
1C0F091A0D05160B071309080E080A0C08090C08050C07030E06030F0704100605120809
110809130B0915110816120719120A130E0A0C0A0F0908100C09100C070D0B040C0B040C
0A050B0D090A0A06050A06030A0904090A05090907080A0907060B0A080D0F090B0F0607
1008060C07040C08050A0904090A04080A0707080A06070B08080A090708090806090504
080703080702080904070A03060902070904060702070705070705090907090806080705
0B07080B060A08050C0A070E09070A07070907080A06070B08070C08070C070709060709
07080A04080907080A06070B07060C08070F0A050C0B060C0A04080A06070A06050A0605
09080608060709070A0806090705080B060A0A05090B060A080607070705080806060805
060805080A07080904060803060803050702050A04030802070904060803070803080904
060803080B04040903050A04050A04060B05050A04060B07050B09050A0D050A10050914
04061306051308061107060C0707070707050707050A0907090806080705080705090806
08070308080606080705080D05091506081F0A092B0F0A32120A33150B3017092C140725
0E041D0F061B0F09150F0A100C0B070A0D0608100507120C081118050C1E040823070723
11091E10081511080D0D070909070C0A08150E091F12082315082615072116071C110513
0B060C080607090909080A070A0C07080D06091009081012070D19070B2408082E0B042E
15072B1505201604121105090B050508070508090B04080B06070C06070C09080E07060C
06050D07060E0A040E0B040C0E05080E06040B060209080308080607080A07060C08050E
0B060D0B040B0C06080B0704090806080705080705060702080703080904080806070705
0807050908060B07060B05050B07040B0704080806080A05070C06060B05050A06050908
04080903070806070907080A06070906070906070B06070B07080A07080A07080C07080D
07080D07070F04061204061208081406061206061206061208061107060E06070C04080B
02070A03080B03060B06060E07060C08050C0A030B0C050D
231816231917251A18261C1B2B23212D24252E232730242832262A332427362627362627
392B2B3A2C2C3A2A2A3A2C2B392D2D3B2F2F3F303542333A2E1C2835202F341D2D331C2E
311C2D2D1B292B1B28291E26271C2028201E26211E26211D25201A221D1A201B1F1E191F
231E22241E2026202024201F211D1C231F1E241E1E231E1B231E1A221D1925201C241F1B
241D17251C17281D1B271C1A281D1B281D1B2A1C1C291A1D291D1F2A201F2A201F2C251F
2B271E29251A28231D26211D25201D261E1C281F1A271C16241A11261911261911271A12
261C12261E11282212252211242112211D121D17171C161A201519211519201418211519
2015191D14151F16171B161318130F14110C130F0C130F0E120C100B0509100509130908
150D0A0E09030D0A030D0D050B0C040C0D070C0C0A0B0B090B0B090E0D090E0D080E0D08
0D0E080C0F060F120B0D13090C12080C12080D10090E100B0F110E11110F11100E11100E
1511121410111311141210150B0A0F0B0C10090A0F09080E0A070E0D0A11121015171719
15171617181A15191A1415190F0E130E0D12110C10110D0E141011110D0C110D0C0E0D0B
0C0A0B0B090C0C0A0D0E0C110E0C110D0B100E090F0F0A0E100E1110101010101011110F
11131010120D11130E10120D0E100B0C110B0F110E0B0D0A0B0D0A0C0E0B0D0F0C0E100B
0E0F0A0E0F0A0E100D0E100D0C0E0B0F110E0E100D10120F1113120E0F110C10130E0F14
0F0E14100F150E0C110B090C0909090808080C0A0B0E090D0C070B0E090D0E090F0F080F
0F090D0F0B0C0D0B0C0C0C0C0E0D12100F1712101E130E22160E232A21363C334852495E
453C512C23361F1422241A22231B191E1B14191A12181A1510161614191D171A23191923
1E1B22211C201D1B1C1D1B1C1D1C211E1D25211D2E261D3223152E22132A1B0A1D170714
12070B0C06060908040A0B06090A040A0D040C0F080C0E0B131419181729171433160E35
1C0E311A0A251B081B180812130A0F0D080C0A090E07080C0D0D150E0E160E0D130E0D13
0E0D120F0E130E0D12110F121F1B1A1F1A1719161116160E161711171813151316131116
20192031272F31282B2C23242C26282F2B2C211D1E1D1B1C202020141613090B08070906
0909070807030905020905020904010A06030C080509080408080607090806070906070B
07080C07080C06050B06050B04030905040A05040C07060E06060E05050D050811070A13
0608140D0F1C1110221412271617291B1D2C1F1E2E1F1E2E1F1E2C1D1F2C1E202C1D212C
1D212C1D212A1D1F2B1F1F2B211F2C211D2B221C28221C28
251919221616261A1A271B1B2B1F1F2B21202D23243125272F2323332525332524382A29
382A293C2C2C3B2B2B3C2C2C3C2E2E3D2F2F3E2E313E2B2F3F2A31422D32432C32432E33
412E304131324133333D32303C332E3B342C37332A36322936322937322E3A3132393033
3B30343B31323F35364137363E36343D35333F37353C34313E37313B342E3F3830403730
3F362D3F352C44373142332E42332E443530463734453633443633443935453C37453E38
433C34403C33443D37423A3740363542373541333041322D40312A3B2D243A2C23392B20
382C1E372E1D362F1C322D19332E1B342E203229222F2422322423332323312121322424
3327273125253026273228272E242229211E281E1D1F1617160D10160B0F150B0C140A09
17100A17130A14140A13130714160B17190E1718101718101818101A1A121D1D151B1C14
171A11171A13151A13171C15151B11141912171C15191B16181A171A1A1A1D1B1C221D21
211D1E221D211E191F17151A0F0E130E0D130C0B1109081009060F1A141E353239413F44
4140453B3C4025262A2021251C1B2019171A1C1A1D1A18191A19171B1A18161513131210
121011110F101311141311141313151413181B161C1D181E1B191E1B191C1F1F21202022
2121212020201C1C1C1B1D1C191B1A171B1A191A1C151618141517151618151716151714
16171214130F1514121817151918161B1A181D1B1C1D1B1C211F2220202217161B1A191E
1B191E17151A141215100E110B0B0B0E0C0D120D11140F131811181F181F2218211F151E
1E13191C1316110B0B0D0707181212191313171115180E16261C2440363F594F5A605563
564B5B453A4835293541363C5248474A423F3E39353736323333313232322E2E2E302E2F
36323336323336323133313234323539363D3B3541342B3C211627150819140615170A14
180D1115100D14130F11120C10110B0E0F070E0F070D0E0911111119161F211C32221934
2518321C0D241B0D1E190B18150B14100B120D0A110D0C14100E1916141F1C19241A1720
1B1A20201F24212025232124201C1D1C181718141116130E13120D1A1915252122262024
241B20271C22352A30584D535B5257585256504B51444247353537212224090B0A020401
0406030808060706040807050905040B070608070509080607070707070906070B06070C
08070D06050B07040D07051004020D05050F080613050511050511060814080A17121524
1417261D203124253A2B2C4137384C383B4E3C3D513C3D4F3C3D4F3A3D4C3B3E4D3F4251
3D404F3A3D4C3A3C4B3B3D4C3F3E4E413F4D3B3746363241
271D1E241A1B271D1E2A1E202C20202C22212E24222F2523302722312620362B25362B25
372C263A2D273D2E2B3C2D2A3C2E2D3C2E2E3C2D303B2C313B2C2F3C2D303C30323D3131
392F2D39322C39322A3A362B3836293634273834293A33293B342A3B322B3C312F3C3030
3F313141313243333444343545353544363541333241333241333043363044372F43362D
44382C44362B44362D46352D47362F47362F463430473531463732463734493A37493939
493939483838493B3B4638384435384436364030303F302D3D2E2938292237292036281D
392B1E3A2D1D372B1B362A1A352C1B342B1C382C2034261D32231C35261F352623342424
3224233123223224243426253224233224232F1F201A0C0C190F10190F0E170D0C150D0A
13100917170D1A1A0E1C1E10191B0E181A0C1D1F121B1D101A1C0F1A1C111C1D15181913
13160F171914181A17161815161815191B18191B181A1A181B1B1B1C1A1D251E25272027
241D25221B2319111C120C16120C160F0A110A070E08050C0D071129232D423C4846434C
3E3B4435343C1F1E261B1A221D1A211A181D1B191C1B1B1B1A1A181B1C1712130E12130E
12130E10110C1312101412131313131616181C171D1D181E1C1A1F26252B2D2C322C2B31
2E2B322B2831211E271E1C271D1D251C1C24181B2416192015181F12161912131511110F
1615111813101A14141E15161E1516231A1D241B20211A21241D25201B221C171E19161D
1B181F1411180D0C110C0C0E0D0B0C0C0A0B110D0E1610121D1419271D25271C24261B23
23161D1D1115150B0C1309081B11101B0F0F1709091D0F0F3A2E2E45393B473D3E483D41
483D41493E44463B3F4A3F434E4445483F403F36373D3737383234352F31352F31372E2F
3C33343B32333C33363832343933373D363D3E373F2D2530130D17100B12171018181118
1410111915141E1D1918171212110C0E0D080E0D080D0C070E0D09100C0D1510161A121D
1A121D1B111C190E1C170C1A1008150F07140D0715130D1B130F1E1713221D1928201C2A
201D28211E2923202B241E281A151C130E12171113171111130E0B1812121F1619251C1F
22171B1F141A34292F473C44473D45564F56524D54403D443D3C42292A2F05090C000405
040807060A09080A0906080705070606080708080A07070907080A06070B05060B05060B
090A0E07080D06040F07051206051304061306051506071907081A080B1C0C0F221D2235
1F243722273A2D2F4432374B3A3F52393E513C3E533B40543C41543D43533D43533D4353
3C42523A40503A3D4E3A3D4E3C3D4F3C3D4F39384A343343
241B1C20171823191A271D1C291D1D2B211F2B221D2E271F30291F332B20322A1F342C21
352D22352B223B2E283B2D2A3A2C293C2E2D3B2D2D392D2D372B2B382E2D382E2C362F29
3730283430253733283834283733273733273731253932283C332A3D342B40332D3E302D
41322F44323046323347333445333347353546343447353548363443342F453631463730
44362D43352C43352C45372E45372E46382F45372E47393046382F473831493A35483934
4A38364937354A3838493638453536423233412E30412F2F3C2D2A392A25392A25372821
392B223B2D22392D21382C20362A1C34281A35291B33271B32261A32251C342721312320
32242130221F3123203426233224233123222A1C1B1C110F1C121018100D15100C15120B
15150B1B1D121E20131E201216180A17190B1A1C0E1A1C0E1A1C0E1A1C0F1A1C11171810
1718121617121616141717171919191818181A18191C1A1D1D1B20252027271F2A271F2C
231B281F172419131F130D19120C18130D170E08120D080F211B25413B47504A564F4955
3D37431E18221D1723201A24201B221D1B201E1C1F1E1E1E1B1B191A1B16181913181913
16170F11120C14130F1716121414121917181F1A1E1B161C1D1B2034333947444B5B5861
615B65423C48221E2C2F2B392523302424302626322224301F242A161B1F161719171715
1B1A16201B18251C1D261C1D261C1D281E1F291E242C2129261C251E16211D15201B151F
1A172013101906050B08070C0A0A0C0B090A140F131C161A2721252E252A2E2329271C22
2115191A0E10170B0B1A0F0D190B0A1608051B0C09291A15372A24352724342925403533
433737463C3B4F43454F434742373B41383D3F363B3C33383A3134382F32382D313A3031
4034383E32363E33373E333941363E40363E392F372E272E2621271E1C211E1C2119171A
1919192626242A2B261C1D1810110B0B0C060E0F090D0E080E0D090F0E0A0E0A09110D0E
140F13130E14140C17120A170F07140D05140D04151910211D14251E17271D16261D1626
1E18261C162418142215121D100D16100D14151014120E0F140E101610121C131620171A
23181C1E131721161C30262E392F383831393B353F3D3A433B3A421D1D2507080D03070A
020607070B0C070B0C080C0D090D0E090D0E08090B08090B06070905060A05060A07080D
06070C05060B07051005041206051508091B07081C08091E11122715172C181A2F22273B
292E422C3346393E52393E523B42543A41533A3F533E43573D42553C43553D44543D4454
3C4252393F4F3A3D503B3E513B3D52383A4F37384C36374B
261C1B241A19241818271C1A2B221D2A211A2C231C2F281E2D2719322C1E322A1D332B1E
342E20342E20352D22382E253A2F29382D29382D29372C28392E2A392E28372C26382D27
372D24382E253A30273A31283B32293D342B3B322B3A312A3A31283C332A40332B41342E
42332E4634304733324834334733324733324935364B3939493737483636463636473835
453734433630453832453832443A3142382E433B2E443D2D443D2D443B2C453C2D473B2D
483A2F483A3149383147353143312F433131412E303D2A2C3B29293C2A2A392929382828
362825372C28352C27342B2431281F2F271C2F271C2E281A302A1C2F271C3229202E231D
2E231D2C211B30251F2F261F2C231E2A231B221B13120E05100D06120F080F0F0714140A
15170C1C1F142023181C2012191D0F1A1E0F1B1F10191D0E181A0C1D1F112020141B190D
19160D1916111B16131C16181C16181D171B201921221A25241C2B251E2E2A23332A2333
231F2E1C18271A162417141F16131E16131C100D161D1A23433D49524C58564E5B4F4752
38303B2A232B2C242F241D25231C24252026221D211C1A1B1A19171E1D191B1C161A1B13
17190E16180D181911191A121918131A19151E1A191915162520245B595E746F75817C83
726D744A444E48424E3A3742302E394D4B5644424D3737412F3237202528202221222421
2728232E2A272F2A2731292731292732282931262C2D222A291F27241D25221A251E1822
1310190B081109080E0A090E0A090E141416242328252326302B2F342E302E282A2B2223
190F0E130907160B07190E0A1207031409031F120A20130B23160E23160E312320382D2B
3B2F2F52464865565B53464D43383E4338404238403E343C3933373731353B32373C3135
3D30373E313840333A41363E453A423E343D382E37312A322A252B2A282D28282A272729
2729282C2E2B272924161813050A04050A04080A050709040A0F0B080C0B0A0C0B0C0C0E
0E0E10110F14110C13130B16110914100611100513201523271C2A2119281F17261C1624
1B152315111F100E190F0D180F0F170B0C110D0E120F10121212141917181A1617191516
1B1517161012171115231D21251E25252026312C332E2B32221F281110180E0D130B0A10
0B0C100C0D110D0E120D0E100B0F10090D0C090B0A0C0C0C080A0905070605090C03060B
06070C05050D0707130605150807190B091F0B091F0C0C241C1C361F1F3925253D2E3047
31364C34394F373C523A3F533B42543B42543C41544045583F44573E44543E44543D4353
3D40533B3E513C3D523C3D523E4057383A5139395136364E
291F1E241917281D1B291E1A2C211B2A211A291F162E261B2B25172F291B31291C322A1D
332D1D352F21363022372F24383226373026372E25362D24372F24392F25372D233A2D24
3B2E263B2E263D30283C2F273E31293D332A3C312D3C332E3F342E3E342B3F352C42352D
43362E4435304836324A38344735314735334A38364B3939473535483636453536453535
44363544363345373444393342382F41392E41392C423B2947402D463F2C453D2A463E2B
473C2A473B2B483A2D41332A42312A412F2B412F2B412F2D3A28263C2A283C2A2A3B2B2B
392B2A362B29362C2A352B29332A252F28202A261B2A261B2C281C2C281C2E271D2A2319
231C122A23192D261E2B271E2521181D1A1116130A0D0D030A0A000C0E030F110615170C
16190E1C1F161D20171A1D141B1E131A1D12191C11191D0F1A1E0F1E2012212214201E11
1C180D1D19101F17141F17152017181F161921171F221A25271F2E2A23332D26362E2A39
292534201E2C24222F24222D201E291F1D28211E29383540514B575B55615E566159525A
463F473F383F3831392C252C292229241E221C171B1813171814151A19171A1915181913
17181214150D181911191A121B1A151C1B16211D1A1C18171E1A1B686465898387878286
7D767D635E655D55604B454F4C495078757C605D644342484B4B4D3E403F343432393A35
3D3C383C3B373D38353B3233433A3B393033332931362C35382E37302833231B261D1522
150F190F0C15110E17100F151211172322272E2D3229272C2D2B2E322E2F2A2627221C1C
1A15121C150F19100B130A03130A03130A01170E051A10061A10071E140B2A1F192D221E
3E3331574B4B5D4E534D4145453A4044393F4238403F353D39303539333740373C3E353A
362B31352A323C31393E323C3F333D3C323B362C35332C343530373634393331362F2F31
2B2D2C292B2A1618150D0F0C0A0F0B080D09070C08060B07080C0B090D0C090D0E0C0D0F
0D0D0F0E0E100C0A0F0F0A10110A12110A120F050E160C171E141F2119262119261E1824
15121D110F1A0E0E161010180E11180C0F140C0F1410141716171B19191B1C1A1D161417
1914181510140B060A140F15181319201B21241F261C192018131A131017120D140D0A11
0D0C120C0B110F0E140F10140C0D11080C0D0C0D0F0A0B0D090A0C05090A080C0F03060B
02050C03060F0507140908180B091E0E0C221311271A183023233D2929433131493A3A52
3D3F563A3F553D42583F445A41485B3F465940475A3F44573E43564146593F44573F4457
3F42553B3D523E3F543D3D554141593D3D5536364E36364E
271C1A231814271A14291C162E21192A20172D20182C22192D23192B231831291C342C1F
322C1E373123363022383222363322353221373121363020363020332D1D362E21382E22
3A2D243C2F263F31283F31283F302941342C3E302D3F343044373140352F3F342E40352F
40352F413330453734463835463835453734483936483936463636473737473737493939
473737443633463835473A34473A3245392D463A2C453C2B453D2A453D28463E29463B27
453D28463B294337274337273F31243D2F223F31243C2E21392B203D2C243D2C253B2925
392A25392B28372928352929332927332B282C27232A27202B281F2C2920262418211F13
1C191023231927271F2828201F1F151313090C0C02080A00090C0110130812140916180D
1B1C141C1D171B1D181B1D181C1E19191C15141912161C12191F131E2214232317202113
211F12221E12201C111E170F201913211916201A1A2620222D262D2E29302E28322D2A35
2A27322C293437354037354036343F3E3C4944404E4F4C5759535F5A54605F5963605B62
5550565550544641473530342B2728201C1D1D181C1D181E18161B18161B1A181D1A181B
18181A1616161C1B191E1D1B1D1C181E1D19231F1C25201D1A14145A54548B8285767072
736A6F6C666A6258605E575E706A6E908A8C7F797B655F5F716C695B5652443F3C4A4542
4A464344403D474342443E40494347453E463D3542453D4C3E3645352D3C271F2E1E1625
1D15221E18221F19231F1A21201B223330373532393230353230332E2C2F201E21221E1F
221E1D1D1815140F09100C03130C04120B01140D03170E05180F081C130C231A15281F1A
372D2B463C3B4337373F33353F34383F343840353B3B32353B323540373A40373C3E353A
392F37392F373D333C3C323D3C323D3A323D38303B362E3939333D37343B37353A27252A
2422272220251414160F0F111111110E0E0E08080A08090B0A0B0D0A0B0D0A0B0D0B0C0E
0A0A0A09090B0B090C0C0A0D110C12110C12130C141712191D181F211C231F1A211B181F
1110160D0E130D0E130E0F141011161011160E111610131817181D19181E1A171E151318
140F16110C130C070E120D1318131919141A181319171218171017140F16140D15100B12
120D140E0B120D0A13120F180D0D15070A11080B1204090F04090F050A10050912060A13
02060F0509120408140B0D1C0E0F211011231D1B302523392C2A403230483B39513C3C54
3F415A3E40593E425B43476040465C40465C43495F3F465940475A41485B40475A40475A
3E43573E405741415941415943435B4341573A384E3B394F
2D221E261B15291C142E21192F221A2A20172B21182D231A30231D2E241B32281E322A1F
342C21383025362E21373123363324373423343120353221343321363322393325393325
392F253B312740322941332A41322B3E312B3F312E4133304234313F34303E332F413632
423733413632443935443935433836463835473936493A37483838493939473737493B3A
4A3A3A463835473936483B354B3C35493B32483C30483C2E493D2D483D2B453A28453A28
493E2C4338264034244034244134243D30203D30203D30203A2D1D3D2D203A29213B2A23
3A29223829243A2B28362827332927322A272E29252A25212B282128251E1E1B121C1C10
1B1D1225271C27282025261E191B10070900080901090C030C12080F150916190E14170E
1B1C141B1E171C1E191B1D181A1C17181A15141611181B141B1E1522251A29291D2A2B1D
2B291C252314222013211D111F1B10201C132B241E2B26222E2828302A2C2F292D2B242B
2F2A30423D444C49504C49524D4A55504C5A56526057545F5B58635E5862605A64635E65
615F646664675651553934382D292A231F202823271C1A1F13111615121917141B1A171E
18171D18171C1E1C1F2220231D1B1C1F1D1E2723222622212924215B5653787370686360
686360676161655F5F7C7676958F8F999491908B888078757D75726B6360413936463E3C
4D48454F4A47514D4E55505456515758525C57515D534D5B403A482F2937271F2E271F2E
2E26332C24312A222D28222C2E283238353C3E3B423D3B4039373C211F22161419211F22
2220211D1916110E09100D06110E05120E05110C06120D07150E081A130D1F1812271F1C
2F25233127253125253A2E2E4034364034363F33373E333740353941383B3E33393E343C
3E373F3F38403F35403D35403B333E3B353F3B33403D37433D374139333D28252C1A181D
151017151017140F15121015110C120D0B100D0B1009070C0A080D0B0B0D0D0D0F0C0C0E
0B090C0A080B0A080B0D0B0E1412151210131611171E191F1C19201C1A1F18161B151316
1110151111130F10140F1012100F1412111611121614131916151D1C19221C192217141D
16101C130D190C09120F0C15151017130E15171018140D14150E16140D15150E16130C14
110B150F0913110B17100D180E0C17090915090B17040613030713060A16070B17030A14
030A14040B15090D190C0F1E181A291E202F27283C26273B37354B3C3D523F3D553F3F57
41435C41435C41455E44486143476042486043495F43495F43495F40465C42485E41475D
42475D40455B41435A4042594041564243573F3D52403F51
3027202920192B22192C231A2D251A2E251C2920172C211B2F211E312320332620332620
352820332920362B25382F26393027393228343024333124333426333426363428373529
3933273933273E342B3E342B3E332D3E312B3F312E4133323E33313E32323F3333423434
433836423735433836443937483A3A493B3A483838493939483838473938493B3B493E3C
4A3C3B4B3D3A493B384A3B364C3D364A3B344C3E354B3D344A3C314B3D3245372C44362B
45372C43352A3F31263D2F243F2F223D2D203D2D203C2C1F3B2B1E3C2B213C2B23382720
382720392A23392A25392C26382A27352A26332A252F282229241E1E1B1418150C18180E
1D1F1226281B25281D1D201510130A0609000B0E070F140D10150E10160C11170D161C12
191C131D20171D20171B1E171B1C16191A141819132021191D1F141C1C1226261A323023
3031232728182122122220111E1C0F221E122C251B2E271F2D26202D25222C24222F2627
3C33364D4449534C5358515957515B56505C5D57635E5B66605D68625F68615E67656269
64636869696B615F624240433634353634353331322624251A181B1B1A1F1C1A1F1B181F
1B181F1C19201D1A211F1C23201F251F1E232B292C2A28293332305C5B5666665E69695F
66685D5F615674746C8C8B869E9B969C99948986816C6763615C58605B5848403E453D3B
514C495753505D5B5C7472757A787D75727966606A56505C47414B302A342F273239313C
3B333E3B333E37313D302A3436333C3A3941403F45403F443D3C41232325211F22282629
2321221C1B1915141013120D14130E13100B15110E120E0B140F0B16110D1B1612231B18
2218161D1311221616332525413134402F353E2F3641323940333A41363E41343E40343E
433944423A474038453C34413D37433A37423D3743403A463D37412B252F1B161D130E15
140F15161117171218140F151009100F0A110F0A110F0A110C070E0D080E0F0A100F0A10
0E090F0D080E0D080E100B0F15101416111519171A1D1B1E1B191E1B191C151014100C0D
0F0D101210111111130F0F0F1311141513161611171611181A141E1D17231F19271A1323
130F1D110D1B0F0B19110D1B100D180F0C15120C16120D14110B15110B15170F1A170F1A
120C18130D19120C18110B190E0A180B09170A0816090617080717070918080A19070A19
060C18080E1A0F1221171A291F2231222534313447373A4D41425642455845465B46485D
484A61454A60484A63484A63474962454962464A63474D65464C6442486040465E41475F
43496141475F3F435C3E435940475A3E4356373A4B3C3E4D
29221A2821192B221B2D241B2D241B2E271D2D241D2F24202E201D302020322320342522
342623332522342925382D29362B27382F28362F2733302732322833332935352B37342B
38362A39352A3D362C3D342D3D322C3F342E4133304234333F3432403533443538433535
473939453736463838473939493B3B49393A4C3A3A4C3A3A493939463837493B3A473C3A
473C3A483D394A3C39493B384A3D374A3D354B3E364A3D35483B3345382F41342B403229
41332A45342C4130283F2E263D2C223D2C223D2C223D2C223E2D233C2B23382922382922
382922392A23392A233A2D25382B233227213229242D262027221C1C17111A1710181810
1F21162023181F22191A1D140F1209070A01090E0710150E10150E141710181B12171A0F
1A1D121A1D121F22192021191E1F171A1C111C1C122020162020161C1C102422162E2C1F
2E2F1F27281826271720210F211F102825162A24162C24192A22172B22192E251E352A26
4035334A3E3E51464A584D535D535B60565F645D6566606A68626C66636A6B656F6A676E
69686D69696B6563664E4C4F4C4C4E4040403B393A3030302121231F1E231C1B201E1B22
1F1C23201D26211E27211E2724232B27262E2D2C3226252A36363661605C6F6F6773756A
7173686E706591928AA0A19B9B9A957978745958544F4E4C535250595556575155534D51
5D585C645F63737174AEADB2B8B7BD9B989F76737C58535A49444B413C43484149453E46
3F3742403A44403A443B38413E3D4543444944454A43474A404445333534333333353535
21211F13140F11100C15110E15110E120E0B130F0E120E0D14100D191512191411191411
19110F180E0C1F13132C1D203A2A2D43323843323A43343B40333C41343E4A3C49493B4A
483D4B463E4D453A4B423A49413B493D39473E3B463C39442E2B341310170E0910110F14
100E110F0D10100B0F110C10100B11120D13100B110F0A10120D13130E14110A11100910
130C13120B12100B11130E141813171D181C201B211E1C211A181D161417130E120F0A0E
110D0E0F0D0E100E0F1311121713141B17181913171912191A131B1E16211D152416101E
150F1D0F0B190F0B1A130F1D110D1B0F0C170F0C150C09120D0A130D0A13120C16130D17
110B15100D16130D190D0A150C08160B07160B07160A06170906170C0B1D0B0A1C0B0C1E
0E11200F12211F2233292C3D2C2F402C2F403C3F5247495E484A5F47495E4A4C634A4C63
494E64494D664C4E674A4C654A4C654B4D66464A63474B66464A65434963434762424862
43496341476140465E3E465B3F475A3C455438404D3B414F
2C251F2A231D2F26212D241D2F261F2F261F2E25202F26212E231F30221F332524332524
362827342625352A28342927382E2C382E2C392F2D39322C36332C37342D38352E39362F
3B382F3B372E3E372F3C352D3E352E3E332D443731463933443731463933433534463837
4537364333334838384A3A3A4A3A3B4F3C3E4F3B3C503C3D4D3B39493A374C3D3A4A3C39
473C38483D39483D39473C38483F38463D36483D37483D3744393340362D3E342B3F322A
3D30273E3027402F27402F27402D263E2B24402D263E2B243C2B233B2D24392C24392C24
3A2D24382E24342A21342B22352C232D241B2A231B28211B221D171A150F1916111C1B16
1E1F191F221B1A1D1612171011140D0F120B0F120B0E110A0E110A1819131C1D151A1C11
1B1D1220221523251A25251B2121171F1F132321152321142021131E1F11242215282617
28291928291726271521230E2524122B28172D27172C25152C25152F2519372A21382B23
392C264638355143425B4D4D64585A695D616C61676F656D726870706970736C74726B72
6F6A716D6B706C6A6F6463685150553B3A3F4140454140452D2C311E1F241E1F241F1E26
24212A221F2A24212C26232E29283038373F39363F34313A4C4A4F7772768B8786807C79
7F7C77898883A6A5A191908E6F6D6E4A484B49474A504F5456555B55545C55525D595661
6D6A75908D98AFACB7D1CED7C5C2CBAFACB5928F966B686F49444B474248504B524B464D
423C46413E474140463F404545484D484B5045494C666C6C6E7470585E5A4D524E3B3D38
2526210C0B061C19141B161217120F17120F16101018121217131219151417131214100F
130E0B120D0A170E0F271D1E3B2F3141353741353942353C3C2F3852454F64536357495A
4B3E50473C4D473A4E473B4F463D503C354536303E2D2A3516131C0302080D0B0E0F0F0F
12121012121012130E10110C11110F11110F121011100E0F1614171412170E090F100B11
140E12100910140D141B141C221B23231E25201B22231E251A171E0D0A110D080F0E090F
0F0D100F0D0E0B090A1713141915141913131D14151D14171E151A1D131B170D16180E19
18101B130D190F0B19130F1D100E1B0F0D180F0E160E0D150E0D13100F15131017131017
110F14100F14110E150C0B110D0C140C0A150F0B190D09180D0A1B110E21100D20131126
1B192E2122362C2D423234493C3E5340455944495D484D63494D66484C654D4F684E5069
4C50694A4E694E4F6B4C4D694D4E6A4A4B67484965494A68484967454966474866464A67
444A64414862424A613F4A5C404C5C3D49573C46523D4751
2E26232A231D2A211C2E25203027222D241F2C231E2E231F2D221E2F211E332524322423
332524342625372928342927372C2A382E2C382E2C37302A36322937342B3B36303D3930
3B372E3C382F3F38303E372F3F362F40352F43363044372F453830453830443731463732
4637344634324735334A36354B37384D393A513B3D533E3D4E3A394B39374D3B394A3B38
483A37473C384A3F3B483D3949403B47403A463D384239344138313D342D3A30273A3026
3B2E253A2D243C2E253E2D253D2C243D2C223E2B243F2D233C2B233C2E253B2E25382E24
392F25382F26352C23332C22342D232824191D16101A150F1D18121B18111C1B161C1D17
1D1E181F221B1A1D1615181113160D0F120912150C14160B16160C1C1C121C1C101B1B0F
1C1D0F21221428281C27271B2223152021132321142324141A1B0B1D1E0E262415242515
2627172627172223112324122627152B2A182B28172D27172F2818362D1E392D213A2D24
372A213F322A493A355E504D695B5A6F64627367676F6566766D707D74797E757A7B747B
777077757076726F766360674F4C53423F4647444D48454E38373F15151D17161E1C1B23
1E1B241E1B2426232C24212A27242B504F55636067625F666D686F8E898FA59FA39C9698
9C96969C9897827E7F585357524D534F4A51514E5757545F5957645E5C6A656273777485
9894A5C0BCCBD6D2E0D7D4DFCFC9D3CAC5CCB9B4BB878288504B514D464D534C534B464D
47424948454C48474D46474C474A4F46494E55595C929697B2B8B4979D99666B65333530
33342E23221D25221D211C181E16141F17151E1516191313191313171312181415161213
151110120E0D130D0F2A21243C33363F363940353B3C3137382D35584A576E606F57495A
4A3C4D42354745384C46394B413647352D3C29212E231D2715121908070C1111131D1D1B
1E201D1D1F1A171A1313160F14161111130E11110F121011151314131114110F12120D11
130E12100B0F150E15231C24261F27271F2A26202A1C162016131C0E0B140B080F09060D
0A080D0B090C0D080C100C0D100C0B1610101711111D14151C1316160D10130A0F130A0F
130C13110C130F0C170E0C170E0C170D0C140D0C140C0C140D0E130F1015100F150E0D12
0B0A0F0C0B100E0D120A0B100B0B130C0C140D0B180E0C190E0D1D12112113112617152A
26273C2F304536364E3F41584B4D644A4F65464B61494E644B4F684A4E674F516A4E5069
4E526B4C50694E50694C4E674C4E674C4E67464763474864474864474864484965474B66
464C66434B62424A61404B5F3F4A5C3E4A5A35414F37434F
2823202B23202C24212F25232F26212B221D2C211B30231D2E211B30211C322320332323
342424332323362626372926342925362D26362D26362F253733273735283D392D3B372B
3B372B3E382C3E372D3D342D3F342E40352F41342C45362F44352E47393045362F483730
4938314B38324A37314C37324E3936503B38513C39523D3C4F3B3A4F3D3B4E3C3C4A3A3A
493B3A483A394B403E4B403E463C3A4037323F38324039333E372F3C352D382F26392F25
362C22392D21392D213C2E233A2C21392B1E3C2B213A2C1F392B20392D21382E22392F25
383025372E25362D26332C24332F2623201918130D19160F1C1C141D1D131F2018202119
1F21161F21161D1F12181A0D11130610120516180A191A0A1B190A221F10211E0D1F1E0C
1E1D0B2423112A2B1B2728182225142023122122122122101A1B091D200F27281827281A
292A1C26281A1F21131C1E102A2D1C2C2D1D2A281B2E2A1E2A261A312B1F362E23362C22
32281E362C2340332B5C4F49695C5670655F736A6569615E746C69867E7C8D8787888284
817B7F807980766F776159644E46534E4653564E5D585260494553100E191C1924211E27
201A24201B222621282B292E3634376967688A8889828083858084A19CA0ACA6AAA49EA2
968D907B727751474F5049515A525D5D556460576861586B696274746D7F877F94AAA5B9
D1C9DEE0D9EBDBD4E4D9D3DFDCD4DFD6CFD7C1BAC1989296726C70574E5350474C4D4449
4F454D534C54555057524F565150566B6A7087868BBCBCBEC1C2C4A4A6A5686A67353631
42433D38373224211C211E1926211D28201E22191A1D14151D14151913131C16181B1519
171314171314191418352F33403A3E423C403E373E3831383D333C574D565B4F5B4B3D4A
483A47453744493B4A473B493F333F332932251D281E192018161B1210131D1D1D323230
323431282A252425201E1F1A1719161517141010100F0F0F111111101010101010121011
110F100F0D101510142520262821282B242C231D2719161F100D160F0C150E0B1408070F
08070D0D0C120E0C110C0A0D0C0A0D141011161213181415161211120E0D110B0D100C0D
0E090D0F0D100D0C120F0E140E0D130E0D150D0C140B0A120F0E16100F170F0E160E0D15
0B0C110B0C1108090E080B10090C13080B12080A160D0F1B0E101F111322171A2D212437
262B3E34394C3E405547495E4C4E634B4D624B4D624C4E634B50644B50644D52684C5167
4D52684C51674B50664E53694E50654C4E6348495E494A5F4B4C6146465E474960474962
45496243476042465F41475F41495E424A5F394154394154
271F1D2A22202D23212D241F3027222D221E2E231D30231D2E211B2D201A31221D31221F
332323332524352623352822342923362C23382F263731253532233835263936273E382A
3D37293C362840382D3E352C3F352C40362D44372F45383044362D46382F48372F493830
4B3A324A37304B38314E3A334E3A334E3A334E3934503D374E3B374D39384E3C3C4D3B3B
4B3C39493B38483A39473C3A463B394237333E35303F362F3B342C3A31283A3026392F25
3A3024392F233A2E22392D21392D1F392D1F392B1E3A2C1F372B1F382C20382E243A3027
392E28352C27342A28322A27332E2A221D191813101B18131D1D151D1D1324241A27271D
2121152021132223151F2010121303141505191A081F1E0A1F1C0924210E24210E201F0B
1C1B072628132C2D1B2728162427141D200D1D1E0C1E1F0D1D1E0C1D1E0C2826172E2C1D
2F30222324161F20122324162829192C2D1F2B291C272519242216302C212E271D2D261C
342D23362D24393027483D375A514A6C635C6F6860706963766F697D7874938E8B8C8686
877E81857C81796F78695F6A4F4452564B5B615667635A6B4F4B59292631393641302A34
29242B2A282D322D333F3D404A48497E7E7CA09F9D9B9A98999798AAA6A7A4A0A18B8587
736A6D5D545950464E574D565E53615B506064596A7064788B7F93B4ABBEC6BDD2D0C8DD
DBD2E5DDD6E6DAD2E1DED6E3D4CDD5D2C8D0C0BABC9B959772696A52494A574D4E54494D
554C51564C54585159615C637C777EB2ADB3C7C2C8CCC7CB8D8B8E6A68694746443D3C38
4C494443403B292621211E192D28242C2724251D1B221A182017181A14141A14161D191A
221E1F262125282327373238443D44433E453B363D3C3640453F4948404B4A4049443A43
473B454B3F494B3F49463A44392E3630262E2A232A251E25201B1F2826272E2C2D323230
353734383A352E2E2C2424221F21201A1B1D141416131315131217111113101012101012
1111131311141A1519221C20261F26272027221D2418131A17111B131019110E170D0C14
110E17120F16100D140F0D12100E13110F1213111413111212101111100E0D0C0A0C0B09
0907081010101111131112161110150F0E14100D140E0D150F0E160F0D18100E1B0F0F1B
0B0B150A0A14070A130A0D16090D18070B160C101C131625121526171A2B222538282D40
3035494045594A4C614D4F644F51664D4F644E50654D4F644C51654E53674E53674B5064
4D54674B52654B52654C53665055684C51644B4E614A4D604A4D604A4D604B4D62484A61
4547604547604547604347604248604248603E445C3E445A
2C20202F23233426253123203426233126202E231D2D221C2C231A2B22192C221930231D
332620332822332620332920362C23352B21372D233830233830233B35273C36263C3626
3E38283F392B40382B40382D3F372C41392E42382E43392F43362E45382F473930483A2F
483A2F48372D4A392F503E34503E344F3D334F3C354D3A334D3A344B3A334B39354E3C38
4D3B37493A3548393645373445373445383241342E41342E3E312B3F322A3E31283D3027
3B2F233B2F233C30243A2E22392F23382E223A2E223A2E22382B22392C233B2E263C312D
392E2C362A2A33272933282C352A2E271C20180F10181212201B171F1C1526211B28241B
201E121E1C0F24221322210F1A19071A19051C1B06211F0A24210E23200D252211201F0D
201F0D27281630311F292C192326111B1E091C1E091D1C081E1D0921200C2724132E2B1A
2E2B1A2623122423112F2E1C31301E31301E2E2C1D1F1D10201E1128261A29271B2A261D
2F2B22353128332F2637322C47423C5D585266615B736E6A736E6A6A67628A8683918D8C
857F7F7B7577776E73756B73635C6461596468606D675F6C5A576247444D514E574C4950
36333A39383D4543484B4B4D4646467B7D7CA5A5A5A6A6A69A9A989392908E8A896F6969
554F4F504748534A4D574C525C525B6F6570877B899A8D9EB7AABCDCD1E2D9CEDED1C9D8
D8CDDDDDD5E4D5CAD8D6CED9D2CBD2C9C3C5A39E9B7A75716A625F58504D554B4A5B5150
574E4F4940436C6368958C91ADA4A9B9B3B5A7A1A38A8486635A5D5D5455534B494B4341
4C47434C474338332F2B26222F2B282B27242C272429262124201D1D19161915121D1918
2D292834302F393335403A3E4238403B343C3C343F4E4854534D5949434F453F49413A42
454047524B52554E554F464B3B3237312B2D2822242B25272A26273534323C3B393C3C3A
4345424648453C3C3C2C2C2E27262B1F1E2419182016151D15131E13121A110E17131017
120F161311161C151C241A22281F24271D252319211A10181A131B1B161D151017131017
151017140F16130E15110C13110E151210151311161111130E0E100E0E0E0E0E0E0D0D0D
0A0A080C0C0C17171718181A15161811121612111712111913121A11111D0D0C1A0C0B1B
0B0A1A0A0C1B0B0C1E0C0D1F0D10210E112210132618192D202136292A3F2D2E433A3B50
4949614A4A624D4D654E4E6652526A52526A52546B5052694B506650556B4E53694B5167
4C54694D556A4951644A52654D55684A52654A5163484F614B50634E51644F51664A4C61
474960484A6146485F47496245476044465F41435C43455E
332524332522362724342520362921372A222F221A2E241B2920172B22192D231A2E231D
2F241E2F241E30251F342A21352B22392F263B31273931263931263D352A3C34273A3225
3E382A3E382A3F372A3F372A423A2D423A2D433B30453B3143362D43362D483A3147392E
483A2F483A2F493B304F3E344E3D335040335140364D3C32503F354D3C344C3B334D3C34
4D3C3548373047362F48373046343047353144322E42312A41322B40312A3E30273C2F26
3D30273C30243C30243E3226382E223A30263A2D243A2D243B2E253C2F273C2D283F3130
3F3131392D2F32262A33262D33262D2F22291D1216170E0F201816221A17241C19231C16
19150A1F1B0F2926172623121F1C091D1A07201E09211F0A24210E282512252412201F0D
2223112E2F1D2E311E2D301D2A2D1A1A1D08191B061D1C081E1B0A201D0C272111322C1C
2B2515251F0F2926152E2B1A35321F32311F2A27181C1A0D1C1A0D23211528251C2A271E
2C281F322F2635322B33302B3C39344F4B48514C495C58556D69666F6B6A7B77767F7B7A
7B77767A7474777173777175706A6E6F686F716A726B666D64616863606766646968666B
46454A4646485757595A5A5A4848487575759E9E9E9898969392907978766561605A5454
4D4747544B4C5B5255665D626F656D867C859F95A0C3B8C6D2C6D4DACFDDDAD0DBD5CBD6
D7CDD8D8CED9D3CBD6D6CFD7C4BDC497939479757465615E605B58645F5C605856595353
5E5858605A5C898085B0A7AAB3ADAF9A949482797A5B535163595A685E5D564C4B4D4342
5046454F4745473F3D3B36333A3532312D2A322F2A38353037363122211C1C1B171E1A17
26221F3A34343E3538433A3F423840372D36392F3A574F5C57515D49434F423C46423D44
443F455550565B5559514B4F4C464A453F412D2427262022302A2C4642415A5655565553
565654595959504E512D2B3029282E2928301E1C271A182519172414121F17141F17141F
17141D19141B1B141C2319212C222A2F262B1D131B170D1518111819141A181319151016
110F12131116120D13140F16100D14100D14100F15100F150F10140E0F130F10140E0F11
0C0D0F0D0F0E11121414151716171917181C19181D19181E16161E13131F0E0D1D0C0B1D
090A1E0B0C210D0D250C0E250E13290F142A14162F2729422A2C452B2D463B3D564C4C66
52526C50506A524F6A52526A52526A53556C53556C4E53694C52684F556B4E546A4C5469
4B566A4B566A4954664A55674A55674A55674A52654A52654B52654C51654D4F664C4E65
484A614749604B4B634848604A4A6448486243435B46465E
3A2D2734271F37282134261D37292036292030231A2F251B2D23192D231A2E231D302521
302521332A25322924352C25332A23382F283B322B39322A39322A39322A3D342B3E352C
3F372C423A2D3E36293F372A433C2C433C2C443A2E43392D43372B463930463931463931
483B33483B32493B324B3D34493B304D3F344B3D324C3B314F3F324D3D304C3A304A382E
4B383149352E49352E46322B44312B45322C45322C45322C42312A3E30273E2F283E3027
3C2F263B2E253E31283E31283C2F263B2E263A2B243A2B243B2C253F3029402E2A3F2D2B
3D2D2D3B2D2D38292C35262B35262B34252A23171B160A0E1D1314221A182119171C1411
1511081C180D2B25192B25172421101F1C09201D0C252211272614262513272516242213
2223133233232F32212B2E1B2629161D200D1E1F0D1F200E1E1C0D221F10272115302A1E
2A27182320112B2517302A1C332D1D312E1D2822141E1A0E231F1429251C2A261D2C2721
2B28212E2B24312E2936353045413E3E3A39353132504B4F6B696C706E71706E716E6C6D
72716F7874737A76757975746F6B6A6F6B6A747071706E6F6A686B67676965656768686A
5F5F615D5D5D6A68696B696A5D5B5C7978769594928584807A76735F5A57524C4C5D5455
62595A685F62696065736971867C84ABA4ACD1CAD2E6DFE7E1D7E0D4CDD4D6CFD7D4CDD5
D2CBD3D4CDD5CDC7D1BEBBC48E8B9267646B5350575E5B626361666664696260655C5A5D
7472757E7C7F959094A29E9F8E8A8B706C6B625D5A5D5552685E5D675D5C554949514547
4F43454C42434C414549404147414136322F322E2B3C3B373D3C3735342F2E2B262A2722
2D282540373840373A40353B3F343C3D313B3D313D4C424D4A404B463C45443A43413A41
453E45575155574D554B41494A40484E444C4439413D333B453F43635D616D6769605C5D
696566585657534E52565157514E55423F482E2B36282530201E2B1B19261D19271C1924
1E1822221B232218212319212A20282821281E181C1A14181C171B1B1718191516161415
141414141414141215171218100D140E0B120D0C140E0D150F0F1912121A11141B101318
0E11160D10150F12171011161A1B1F191A1E1E1F231C1D2214141C0E0E180E0D1B0D0C1C
0A0B1F0C0E250F112A0E0F2B111532181D3A2528472C2F4E3236534246634B4F6C515270
51526E51536C53536D53556C52576B50576A51586B4F576A4D586A4C57694B58694D5A6B
4D5A6B4956674956694B586B4B586B4A55694A52674A52674A5066494F674C506B4A4E69
4B4F6A484A634C4C644A4A624A4B604B4C6148465B474658
2F221A30231A30241831251933271B34281C31241B2E21182E241A2E241B2F221C30221F
312622342925312624342927342925372E293A312C39302B3A332D39322C3B322B3D342D
3F362D40382D41392E443C31423A2D40382B41372D41372D44372E493C334A3D35463933
483B33483B33493A334A3B34483B32493D314A3C314A3C314B3D304A3A2D49372D4A382E
47352B49352E46322B44302945302B47322D47322D45322C43322B3E2D263C2D263C2D26
3E31293D30273E31283D30273B2E263B2E263A2D25392C243A2B243C2D2642302C3D2B29
3C2D2A392B2A37292835272738292C36272A26171A190D0F201617231B191E1614130E0A
15100A1D1910252116262314201D0E1C1A0B1E1C0F232114242213272516262415252314
2425152A2B1B282B1A262918262916222512262717242515252314252316292519302C20
2E2A1E2824182E2A1E2E2A1E302D1E3330212C281C29251929251A28241929251A29251C
29251C2C2922322F283C3934433D3D302A2C3932395F586068626C66636C706B72726D73
7472757B797A7C7B797675736F6E6A706F6B71706E6F6F6D6F6F6D656563636361676767
6A6869696768736F70747071706C6B827E7D7F7979726C6C67616161585961585B635A5D
655C5F71686D80757DA399A1C7BDC5DDD6DDDFD5DDE2DBE2DFD6DBD3CDD1D2C8D0CAC3CA
CAC3CACBC4CB9F9AA17F7A815F5C655C5962605D6666636C605D666C697277747D747178
AFAEB3A9A9AB807E7F6B6A6866625F5F5B58615C58645D57665D585B504E564848514245
473B3F473B3F4B3E45493E44483F423F39393E3838433F3E423E3D3C38353934313A3532
3B323340353942373D43383E43363F453A42473B454B3F49443941463B43473C42463B41
4B40444E4347463B41463B434E414A4E414B55485261555F70666F7B7179736A6F706A6E
746E705953576E686C8F888F7C777E45424B201A2438354033303B24202E25212F292331
2B2330342C372C222D241A231F18201D161D1C171D1C171D1C171B19171A171516121212
121212131313151316171218110E150E0B120E0B14100E1912101B14121D10101A13131D
12151C11141B101018101018191A1F1C1D221E1F241B1B230B0B15080A160E0D1B0F1022
0D10230F11281415311418351A1F3D2328462B30503A3F5F454A684E53714F5271515572
51557051556E54566D52576B535A6C515A6B515A6B4F5B694E5A684D5B684E5B6B4E5B6B
4D5A6A4D5A6B4C57694C576B4C576B4A55694B53684A50684A50684C526A4E526D4C506D
4B4F6A4A4C654C4E654B4C614A4B5F4B4C5E494858444351
2E241A2E241A30261A32281C31271D33291F30231B2C1F172C1F172C1F19352623342522
332524342625332525352727372928372C2A372C2A3B302E3D342F3B322D3D342F3C332C
413831403730413A32413A323F382E40382D3F352C41372E4639314B3C35493A35483B35
483B33483B33493A33483932463930473A31493C33493D3145392D47392E47362C48352E
47342D422F2945322C43302A43302C44312D43302C44312D44322E3F2D293C2D283E2F28
3E31293B31283A3026392F25392F263A3027382E25382E253B2E263C2F273B2E263B2E28
3B2E283A2D27392C26352724382D2B362B292115151A100F1D1513221D1A1813100F0C07
17140D1A170E2220142122141D1E101A1B0D1D1D111B1B0F23231729291D222216222315
2A2B1D292A1C282919262717272A19252817292C19282B182425132425132B2C1A30311F
2B2C1C2725162B291C2F2D203031233233253230232E2C1F2D2B1E2927182B28192A2718
2925192F281E3A332D433B383E35363D34396559636B5F6D5C51616E63738C84937E7683
807A8489868D7E7C7F6E6E6E666664696A656D6E696C6D686D6E696869646B6A666C6B69
6F6B6A746E6E786F72786F72736A6D71686B6A6166635A5F655C6163585E695E666F646C
8378809F949CBEB1BADFD4DCE3D8E0DFD5DDE1D6DEE3DADFDDD2D8DAD1D6D7CCD2C0B7BC
A39A9F82797E6A606870666E6A636B5D565E5E545D6D636E776D789B919CA69EA99E979F
A5A0A6847F83605C5D56524F5D5854605B55655E566C635C696059524743524443544548
45363B4A3E424C3F464A3D464B40484A3F474E434B4D424A483E46443B40433A3F42393E
42373D41363C463942473A43483D434C4147483D43453A4042363A473B3D4A3E404A3E40
52464646373A3A2B30483741533F4A574551705E6C81717E8678857F717E776B75736870
736A6F726C709690949B9599716A71282329211A22352F392F293328222E292331292130
2D2532322A372B23302018231C141F1B141C1D181F1D181F1A171E18151C17151A151419
1413181412171611171712191310170E0B120F0C15110E1714111A14111A130D1714111A
18162116141F13111C17152018182216162013131F12121E0A0C190D101F12132514172A
0F142811162C191D382125402328452C314F3A3D5C4E5170505372515572505471545873
53577052586E52576B505769525B6C4F5B69505C6A4F5B67505D664E5B644E5A66505C68
515A6950596A4F576A4F576A4E56694C53664D54674C51674B50664C51674C50694D516A
4F516A4C4E654D4F664C4E634C4D5F484A59464854444652
2820152A22172D23192F251B2F251C2F251C30231D2E211B2C1F192F211E322320322320
3424243424243323243626273A2A2A3628273828283A2C2B3B302C3B302C3C312D3F3631
3F362F4239324039333F3830413A323F362D423731443731443530493A35463730473831
4839324C3D36493831463730493B32493B324A3C33473A3145372E45372E45342D45322C
45332F43312D44322E44322E43312D42302C42302E402E2C402E2C3F302B3B2C273D302A
3C2F273B31283A3026382E24392C233A2D243A2D253A2D243C2F27392F253B2E263A3027
382E25382E25392C24362C23372C26362D28261C1A160E0B1A15111D1A151C191416160E
16160C1C1C101F1F131E20121E20131A1C0F14160B1A1C111F211623251A2426192B2D1F
292B1D252817282B1A2B2E1D2C2F1C272A172A2D1A2A2D182528132629142C2E1930321D
2B2C1A2526162526162D2E203233253235242F30222C2D1D2A2B1B292A18292814292615
252213312B1F3930293D342F43393A675C62857882685A69584B5C8F82939F94A47F7784
89838F908D947D7D7F737373666865666863686A656769646C6D6770716B71706C72716D
74706F79737371686B6E6367695E645D54595F555D625860675D656A6068786E77918790
BBB1B9D1C6CEE6DBE3EEE3E9E5DCE1DCD3D8E0D7DAE0D7DAD8CFD2D7CED1C2B7BB94898D
6E6568665D606A5F636C61656A5F655A4F5762555E7B6E77A498A4C4B8C4B7ABB7847A83
544D545650545953555C57545C57515D5950686159756C636D635A584D47584A49544646
4E3F425344494C3F464A3D444E414A54475050434D493C46483C46473C44453A42473C44
443941443941483B444B3E454B42474A41443C33363F3536453B3C433737443838483C3C
4B3D3D2C1C1F3420294E3A45604C5875606F7D6A7D9481949786987B6D7E635564675B67
7369727C757C746D746F686F4C464A1B141B1C151C211A22251E26241C27251D2A271F2C
29212E271F2C20182518101D18101D1A121F1A142019131F19131F14111C16131E17141D
14111A14111A140E18140F16131017120F16130E15110C13110C13211C23241F261C1620
17141D14111C14101E1715221616220E0D1B0E0D1B0F0E1E0C0E1D0E112210112514162B
14192D1C21372D2F48323651383C59474B68505372515572545573525673545873565A75
555972545A7051586B4E5768505C6C4F5B69505C6A4F5B67505D664F5C65515B67525969
535A6A51586A4F56694F56694D54674C53664D52664A4F654C51674C51674C51674C5167
4C51674B4D644D4F664C4E634A4D5E484B5A444853434750
291F16291F162F221A30231B30231D2F221C2D1F1C2D1F1C2B1D1A2E201D332421342522
3624223624223826243927253E2C2A3829263C2A283B2C293D2E2B3C2E2B3F312E403531
3F36314138334037324037303F362F3F362D43393043362E45362F4738314938304A392F
4C3B314B3A3248352E4C39324B38324938314A393246373246343045332F44302F443031
46343242333044353244353242343140322F4232323F312E3C2E2B3D2F2C3C2F293D302A
3D30283E31293C2F263B2F233C2E233B2D223C2E253B2D223E30273D31253B2D243C2F26
392F26393027392F26382E25392F263C332C28211B140F091A150F1E1B141E1B141B1B11
18180C1B1D0F1E20121B1F1015190A121607121608181C0E1D201523261B272B1D2B2F20
272E1E2128162A2E1D2F34202A2F19262B142A2F182F341D242912262A132D2F192C2E19
2A2C172728162725162C2D1D3233233334223031212F301E292C192729141F210C252412
2A2718312B1F382F263B322B4D41416C60647868725C4F596357638E82907C727D756E76
9A959C9896998383836D6F6C6667626B6C676B6C67696A656F706B767772737270737270
74706F716B6B5D54575F565B5F555D5A535A5C575E656067746D757F7880A49FA6D0CBD2
E1DCE2DED9DFDED9DDDDD9DADEDAD9D8D4D3D8D2D2DBD5D5D6D1CEB4AFAC8F8687635B59
625A586F65636D6260675B5B6256565A4E504F4045594A4F988B94B7ACB491868E695F67
5952595B55595B57585D59565C57535A564D6B645C7D746D786D67584D475A4C4B564848
55474756474A52434650414653464D55484F4F424B4C3F484B3E474A3D444D40474C3F46
4A3F454A3F454C41474D44474D4447474141413B3B463D3E3A3132342A2B3E323444353A
4130362918202F1B2745303F735E6F87748788758B8F7C92928096796A7F4F4254524757
534B58524C5646414838333A2C272D1B161C211A21201920221B22241D25281E272C222D
2B212C291E2C1C1121190E1F1B12231C13241A13251A1325181123171022181123191222
16101E150F1D140E1A130D17110E15131116110F120D0B0E1513162C2A2D29272C1F1C23
19161F15131E17152213111E11101E0F0E1C0F0C1D100F21100F210F102416142916172C
26273C31314934344E3939534B4B674F506C545573525371555473535470585975565A75
585C75555B71555C6F525A6D525D6F525F6F525F6F4F5D6A515D6B515A6952596B54596D
52576B50556B50556B50556B4E546A4F556B4D52684F536C4C526A4E546C4D516A4D516A
4C51674A4F654C5167494E62484D60464C5C424854414852
2F241E2C211B30231D2F211E3123202F211E3020203222222E1E1E2F1F1F322320362422
3523213725233A28243B29253A28243A2B263F2D2B3D2E2B3E2F2C3F312E413330433532
3E332F3E35303E35303D342F3F362F40352F41363041342E44352E4637304A392F48362C
4A382E4B392F4A382E49352E46332C47342E47342E46343046332F44302F443031432F31
4330324232324131314436354335344035314133324335323B302C3B302A3C2F293B2E26
3E31294032293E30253D2F24413026402F254130263E2D233C2E234032274032293C2F26
372E253A312A393029382F28362F253E372F312C2614110A14140A1B1B111B1B111C1E11
1A1C0E181C0B191D0E171B0C131A0A121909171D0F1B21131E24181F251722281A27301F
232C1B1E2714272E1C2E3621283019242C142E361E343A201F240D1F240D2B2D172B2D18
2B2D18282917262717292A1A3132223334243334243233232A2B192324121A1B09232210
2B271B2D291D39322A4037324B41406054565C4F564B3E485246507266706D636C7A737A
8E888C8581827A78796B6B696867656E6D696E6D6B706F6B72716F757472737270706E6F
6E6A6B5D5759574E535D535B5C555D5C545F635D67746E788E8892B2ACB6D8D2DCE3E0E7
DFDCE3DBD9DED7D5DAD5D3D6DDDBDCD6D5D3DCDBD9C8C7C5A5A1A07874716A6464645F5C
655D5A6F67646E635F675C58615652372C2A2A1C1C3C2D30716569776C7260575C61575F
5C555C5B55595B55575E59565A55515F58526C635E736A63645955564845574948584A4A
56484856474A53444954454A56495054474E4E414A4C3F484B3E474B3E4751444D50454D
52474F51484D4F464B4943454741434A46454B454547414138323439303344393D4D4047
3D2D3721111B1D0B173E2C3A726171928193958497917F958E7F9456495D3C31423E3546
38324039333F322C3829232D1D17211B161D211A221F18201B141C1E1621261C272D2230
2C212F1F1726160B1C160D1E1A11241811231811231710221A13251C15271A1325191224
191222120E1C100D180E0D150D0C110F0F110F0F0F0D0D0D11111128262724222518161B
18171F17161E17152214121F13122011101E120F2213102315132815132819172D27253B
3533493E3C54403D584E4E685959755A5A76595877575773595975585975595A765A5E79
585C75575D75545C71545C71525D71525F72525F70505D6E505B6D515C70545A70545A70
52586E52586E50566E51576F51576F50566E4E546C4E546C4F556D4D556C4C526A4C526A
4C54694A52674B5169474D63474D63464D60424959414858
2D221E2D221E31232031212131212132222233202233212134222232201E342222352323
3725233624223B29273B29253829243A2D253D2E293D302A3E312B3C2F2940322F3F312E
3D322E4136324035334035334035334035333F34303E332F42352F44352E47362E47362C
443329443427433125443228443228423026422F2843302A45302D402C2B422E2F422E30
412E303F2F304131324234334335344133323F34303F34303E312B3B2E263C2F273C2F26
3D2F24402F253F2F223F2F22412F23412F253E2C223F2E263E30273F31283E3129392E28
372E2738312B37302A342F2933302735322935352D20211916190E1A1E101D1F121C1E11
1E2012191D0E131708131A0A121909141B0B1D23151F25172026181C24151C241521291A
1F27181C27161E2716252E1D2C35222B341F29331B2F371F262E171F240E2528132A2D1A
282B18272A17272A19292A1C2D2E2034352739372A373528252316201E111F1D10231F13
2B271E2C281F35302C403836463D3E4C4145463B43382C363E323C554B5370666E796F77
7F767B7A7174767072746E706F6B6C736F6E7672737672717874757A76777A7677625D61
5D575B5C555C574D555D535C5A525D6E6673807583908593B1A9B8DAD2E1E8E0EDE4DEEA
DAD4E0DAD7E0DCD9E2D6D3DAD9D8DED3D2D7C1C0C59C9C9E706E715E5C5F5F5D5E646061
625C5C655D5B6A625F625B55534C46261F191D13122A2021433A3B5B5557544E52554F53
5651555650525650505B5351615956645A58695E5C6759565244434B3B3B524243524245
53434654434951424953434D5548515347514E424E4A3E4A4B3F4B4D414D524652594F5A
615760564F56454044423E3F423E3F403E3F4A46474D494A312C303631354842464C454C
3B31391B11191A0F17281C26514350786A778A7C8B746675594D5B4B404E453A4A3F3746
3B35433933412A24321A14221A12211A12211C14231F17261E1625201728251C2D271E31
2B2235211A2C180F22181123191222160F1F1812201913211B18231F1C271D1927181623
16142111111B0C0F160A0D120C10130D11120B110F0C110D0D0F0C16161617171916151A
17161E15141C14121F14121F12111F13122014132516152719172C1A182D221E352D2B43
36344C40405853536D5757715A5A745A5C755E5F7B5B5C785B5C78585C75595D76585C75
595F79585F79555D74555D74565E75535E74556076545F75505C74535D76505A73545C73
525A6F535B7051597050586F50586D4F576C4F576E4C576D4E596F4E596F49546A4A556B
4A556B4A556B4A516B484F69484F69484F69424A613E465B
3025232C211F3022212E1E1E32222231212132202034222235212033211F352122392725
3826243A28263B29273B2C273B2C273A2D273C2F293C2F293C312B3B302A3F312E3D2F2C
3F312E4133324436354436364335353F33334034343F343241333041342E41322B403229
3A2E223A2E223A291F3C2C1F3E2D233E2C22402D263E2924412C29422D2A402B2A412B2D
422E30422E30422F3145333342323241322F40322F41342E40332B3F32293E31283E3226
3D2F223F2F203E2E1F3E2E1F402E203F2F223E2C223C2B233E30273D30273F322C3B302A
3A312C3B342E37322E36312D37342D32322A2F2F2723241C191C11191C111E20151D1F12
1D1F121B1F10171B0C161A0B191D0C171B0A2024152327181F26161D24141F2517202618
1D25161E2617202618222B1A2D36232E372429311C2E36212C341F272C18262918292C1B
292C1B292C1B27291B2A2C1F2B2B2131312739362D35322926231A1F1C13201C13252118
2C2721302B27342F2C3A31323F3639494045423640342A334D434C5D535B7369717A7176
786D71776E71776E71786F727771737670727973757B75777A76777671756C6A6D585659
59545A5D585E5C555D615A626B656F86808AA79CAABCB1BFDDD5E4EBE3F2E6DEEBDED6E3
DFD7E2DED6E1E1DBE5DED8E2CFC9D3AAA7AE918E9578757C646267656368626063615F62
6862645E58585D5855514C483A352F1D18121F171429211F35302D4844434B4748474344
504A4C514B4D574E515A5152695F606B6160695B5B5848494333344333344A373B4B383E
4B3A404D3C4451414B55455052454F5145515044524E42504F43514C414F594E5C756D7A
6B636E4D484F3F3A403A383D3D3B3E3D3B3E4E4C5159575C4543483F3D42514E554F4A51
342F361F1A201F181F221820291F274F434D625660564A54463A444238413F35403B333E
3E36433D3542221A29140C1B180F201910211910231F162922192C21182B241B302A2237
3B33483834452D263617132217132116131E19131F19161F1B1A221D1C241D1C241A1A22
16162013161D0F14180A1214070F11060F0E07100D0B110D0C110D101211101115121318
13131B11111912121E14142015142215142217162821203223243827283C3533493A384E
44445C4E5067585A715A5C73585D73585D73585C755B5F78595F75575D73585E74585E76
586077585F795A617B575E78585F79575E78585F79585F79545E79545E79535D78525C75
525C75515C724F5B734F5B734F5B73505C744C58704D59714D5C734B5A6F48576C47566B
48576C49556D47516C47516C49506C474E6A4249633C445B
3127252C211F2F211E2D1F1C31232034252232232030211E35231F342520362422372825
3829263C2D283D2E293C2D283E2F2A3D2E293F322C3F322C3F322C3F312E403030413131
4131314535364535384434374434374233364233364031343F34323E332F3B302C3C312B
372E252F271C2C1F162F231734261D36281F3A29223E2B273F2A27412C29422A2A442C2C
462D30472E3147313348333246323145322E44322E43342D42342B4133283F33273D3125
3C30203B2E1D3B2E1D3C2F1E3C2C1C3A2D1C3C2C1F3B2D223E302741342B433630443933
3D342F3B342E38332F383330383530302F2A201F1A1B1A151718121B1C142121191C1C12
19190F1B1D101B1D0F1F2211212411191C091C1D0D252616242716222514242618242618
1F231524281A282C1D282C1D3135242C33212A2E1D2C301F2E32212F3221292B1D28291B
27291C27291C282A1F2B2D222C2C2431312936332C34312A2828201D1A131F1A1425201C
2E292536312E352D2B342B2C393033443B4050464F524851655B646A636B786E76776E73
746B6E746B6C7970717872727A71747D74777C767A7B75797570745D5B605B5A5F57565B
5E5D62605F646664696E6C7187848BB0ABB2D4CFD6E2DBE3EBE4ECEFE8F0EBE1EAE3D9E1
E2D9DEE2D9DED8CDD5CBC0C8B7ACB48278806D636B6F686F655E65625D63605B616C676B
747071625E5D4A4643423F3A302D26201B15211A14271F1C2F2A263C3734423D3A433D3D
4C4346534A4D534A4F5C535872696E6B606654474E4C3D4237282D34252A37262C37262E
4130384B3A445545505646515143504F414E504452514455514656544C5B625A677C7481
5A545E3A343E3A343E47414B4F4A51514C525451585E5B625A5760514E5757545F504D58
413E472C2930221D241F1A20221B222E252A43383E3F343A40333A3D3037362932362A34
372B37302631281D2B2318281C1122190D211D142920172C221A2F20182D241C312E293D
504C5D5A58664D495722202B1E1D251D1C221B181F1F1D2217161B100F14191A1F1C1D22
181B221015190E16190A1214070F11081110060F0C060F0C0B110F1014150D1114111419
11141B11141B11131F11131F14162316182515162823243630334433364941445746495C
4D526654596D5A61745A6174596174586073556171556171596575596575586375556072
5661755863795B637A586077595F79595F795A5F7C5A5F7C565B79585D7B565B79565D7A
525B784F5A764E5C774E5C774D5B764F5D7A4C5A774959734B5D75485A7049597046566D
45556C46556C47536D48526D4B526C464C644248603F455B
2B211F2B211F2F242030252132242131241E31241E342721372A24362923372823392A25
3A2B263B2C253E2F283E2F283E2F2A3E312B41342C40332B41342C3F322C40332D3F312E
4234314434344434354434354434374636394233364133333E33313C312D3B322D372E27
2D241D292017251B12231910281B1332251D3627223C2A26402D29402D29432B2B442C2C
452D2D4830304B333347323147322F48353147362F47362F44362D3D2F243F31283C3024
3E32223C311F3B2E1D3A2D1C3C2F1E3A2D1D3D2F223B2D223D312542352C473A32433930
4037303B342C3C352F39342E3A35312C27211D1A151C19121D1A13201D16221F18222218
1E1E142020142122142122102324121A1C071918062524122728162D2E1C2E2C1F272518
24251727281A2E2F21313222363727323323282919292A1A2E2F213031232E2E2227271B
28281C26281B26281D292B202C2E233030263030282E2E242A2A201D1D13201D1628231F
312C2835302D332B29322829342B2E42393E554B53655E656D666D6C666A6E656A72696C
766D6E78706E7B73717B73717A71727B7273716B6D69656667626659575A58575C58595D
62636769686D807F859C99A0C0BDC4DEDBE2EAE5ECE7E2E9EDE6EEF0E9F1E7DDE5E7DEE3
E7DCE0D9CFD0AEA3A7998E929F929971666C675C626C6368625C605D585C6C676B7D7B7C
8482836766643D3C3834332E27271F1F1C15211C16221D172C27233D3834443C3A463E3C
4C43444F464951464C62586080767F726670463B43382B3432252C261A1E2C1D222E1F26
3A2B3250414854454C4E414A4F424B4D414B504450584C58564C5758505B605863574F5A
403A44332D374E46515E56615B535E58525C5B555F635D69615E6964606E6D6977676572
4B495438373F2A272E1E1C212621272C262A30272A33282C3F333733262D2C1F2830252D
30242E271B27291D2B2D20312015261C102420172C21182D1F182A241D2F2A26373A3645
514D5B504E594948503A393F3130352A292E1D1B201F1D2016161810111315161A161A1D
181C1F151A1D0C11140810120A13120C15140B14110D13130F15151015180E131712171D
12171D11151E111520141824191D291A202E26293A2A2D3E393F4F3B4252464C5C505769
565D6F575E705960725E67785B67775864745764745764745A6777596676566374586576
5562755966795B637A5961785C627A5E647E5E627D5B5F7A585C77585C79585D7A575C7A
565D7A515A77505E794F5D7A4E5D7A4D5C794C5B784A5A74495B73455A6F495B71485A70
46576B46556A465268485369494F6549506344495D414659
2B23202C22202D241F2E251E312620342A212C221930261D32281F352B22372A2235281F
35281F372A213B2E253A2D243D30283C32283C32283D33273C32263E34283C32263D3329
3F352B41372E44372F42352F40322F4234314032314234333E332F3C312D382D29312821
29201B251C17261B17271C16241913271C16322421382A273C2D283C2D28402D29402D29
442F2C442F2C4833304734304734304A38344634304738314837304032293C2D263E3027
3D31253A2E203B2F213B2F1F3A2E203C30223C3024392D213F332745392D463930463930
453B2F3E342A3E342A3C3429342B2229231720190F221B11251E1427201625211828251C
25221925231725261823241220210F1C1E091F1E0A262511302F1D363523322E22302A1E
2F2B1F2F2D1E302D1E3936273C392A383222312B1D302A1C302D1E363324393529262417
242517252618262918272A192A2D1C2B2E1D2E30222D2E2026271925261828261A2D2A21
302B25322D29332B29302728342B2E3C3336534D4F6D6767736D6D706C6B76707077726F
776F6C7E7673857D7A7E7673716A646D656267625F605C595F5B5A5E5C5D616163626166
67666C949399B9B6BFCDCAD5E1DEE9E7E3F1EBE5F3EBE3F0E9E1EEECE4EFE9DFE8E2D8E0
C8BFC2B5ACAD7E757672696A897F7E786E6D6D63626B636157524F4E4A4772716D9E9F9A
9FA09B82837E42433D2D2E282728201A1B131A1A12221F1826211B37322C4B43404D4342
544A4B51464A4A3D446C616794899180757D3E323C241921261B2122171B23181C241A1B
352B2C443A39473D3C4D434450454951464A564B51584D53584F54584E565C525A544A52
3E343C3F353E5E525C695D69665C67665C67695E6C6A6271756F7D7975847F7B8A84808E
65636E4E4D552E2B321B191E2220252823272B25292D24292C2328271D25231921271D26
291F2A281E29271B29291C2D241929201526201728201728221C2A27212F342E3A4A4750
56535C4E4B52434146403E413535372C2C2E1A181B1614171515171012110F10120D1112
1317161115140E12130A0E0F0C100F11171511171714181911151810151911161C121921
141B23141B2512182418202D1E2633232A3A363D4D383F4F444C5947515D565E6B5E6575
5C63735D64765D647660677A60687B5C67795B687B5A677A5766795A677A59657B5A657B
5764775A67785C64795B63785D657A5E667B5C62785A6174585F72595F75595F755A6078
586077535D76515B76515C784F5D78505E794E5E784B5B744A5C724A5C70495C6D485B6C
4659684658664653634753614950604B5360474D59454955
2E29252B26202E271F2F282030291F312A20322920322A1F342C21352D20372D233A2E22
382C20382C203B2F233C30243F32293F35293E34283E35263C35253B34243A33233E3629
40382B41392E41392E40362D413630423731403531413632382F2A342B26332A25251C17
211716241A192419172318162318162116142B201E382D293A2C293A2D273D2E29402E2A
43322B41302942312A47362F45362F44362D45362F493B324A3C3344362D3F30293E3129
3E3128392F233C3226392F23392F233A3024372D23362C203A3024362C202E2418392F23
4037283E35263E36293B33262F291B221C0E201A0C251F11251F132A231929251C29261D
2624182624182324161E1F0F21221021230E24230F2625112E2D1B393625383226342E22
363022322F20332D1F3B3527413B2D373123322A1D332D1F322C1E312D213C382C2F2D20
202113202214212413232716292D1C272B1A272A192B2E1D2627192526182624182D2A21
322D2736312D372F2D302826332A2B4138395A51526D6865746F6C736E6B77726E7C7471
7E76737F7872847D777D76706662595D58525956515C5855605F5B62615F6B696C807E83
97949BB7B4BBE3DDE7F0EAF6ECE6F4EAE4F2ECE3F4EFE7F6ECE4F1E4DCE7D9D2DAC4BDC4
938D8F807A7A6864616D6A65756D6A6F686268635D69645E48453E3838306766619D9E98
B0AFAA9899946B6C673F403B1C1D18191A151A1915211D1A282320372F2D4C42414B4140
5347495145474A3E425D51558B80866F646A372C341C13181D14171D141720161723191A
2D2322372D2B3F34324A3E3E564C4B554B4C594D4F5A5051594E525A4F53594E524B4046
32272D483D45665962796C7671656F6A5E6A796E7C776C7A766E7D817B898A84928F8C97
7C7982615E673B383F1F1C23252026252026241D24211A211F18201F1820211A22261F27
291F28251B24241A25231924211722211722201823201823241F2629242B332E344C474D
5B595E514F52474548413F423434361313151010121515171314161112140F1012080C0B
0F111012141312131513141615161814181914181914181B14171C14191F141821141B25
181F29191F2B171F2C1B2330242D3C323B4A3B44534049584B5561515B675A64705E6874
5C65746067775F66785F66795F677A5E697B5C687E5C687E59687B5A697C5D697F5B677D
5865785C697A5B687B5964785A65795A65775964765965755962735A63745B64755A6275
576274566175545F75525E76535F77505E784F5D774C5C73495A6E4A5B6F495A6C485969
485A684757644755624753614B53604C545F4A4E59464A53
2E2E262A2A202E2B222F2B22302E222F2D20302C20343122353223312B1B372D213C3022
372B1D3A2C1F3C2E233D2F243F312641352941372B3F38283D37273933253832243A362A
3B372B3C382C3D392E3C382F3F3B32403B353C37333C373338302D2A2220241C1A1D1312
1E13172015191F13152014162115151F13132C1E1E4234344234313C2E2B3D302A45362F
47393044362B42362A44382A4138293F36254236284D41334C403244382C3F32293B3128
3A32273D352A3C34293C3429332B20352D22332C222E281C2F2C1D2D2A1B1C180C262314
3936253D3A273B382733301F23200F1B180722201123211425231728261A2D2A2126261C
2222182424182321151E1C0F21221220210F2827152B2A182E2B1A3431203933273A3428
363022312B1D2D291D343024363226363226373125353125322E223331253A3A2E2F3126
2224191D20151B1E1323291D262C1E262A1C25271A27291C25271A25251929261D2E2A21
332C263B33303B3130332928332B29433A3B6158596B6263716967756D6B7F7775837B78
8078757B76727370696360595A5A524E4F4751524C5D5E596465607E7D7B8C8A8DA49FA3
D1CCD2E5DEE6EEE6F1F6EBF9F4E9F7EFE4F2E7DCECE2D7E5E0D8E3D3CCD4B3ACB4918C92
6F6B6C646361696A656C6D6765625B6A675E5C5C5048483C3A3A303A3A305C5C5482817C
A9A5A2A09C9B837F80494448110C1219141B1B141C291F2730272C34292F3F343A4D4145
53444757484B4034364D41436E6465574D4E2E2425140A0B1D131423191A231719271B1D
3022222E20203626275646475D4F4F5749495A4B4E5C4D506152556054564B3F41372B2F
32272B564B4F665B6182777F80757D71666E7E727C847A837E777F807981948D959A959C
938E95514C5328222C2B252F2D2530271F2A1F172419111E1B151F19131D1D1721211C23
211A21211A211A14181D171B1E181A1C1616201A1C211B1D2420212C2829312D2E646061
6765665D5B5E4A4A4C29282D22212614131813121714151A1314191011160E0F13090A0C
10101217171913121714131818171C18191D191A1E14171C151821151924141823191D29
1D232F212733242C39343B4B343D4E3D465745515F4F5B695864725A66745D69775D6977
5F6B77606978616A7B626B7C616D7D5F6A7C5E697B5D6A7D5A697C58697B5B6A7D5A697C
5767775869795B6C7C586979566777546575556676556676566675566675566675556574
556574536372536070536071536073535F75515D73515D734C586E4A596E48576C49586B
49586B4A57684853654753634A51634B5262424652414550
3030282B2B212E2B222D2A212E2E222C2D1F2E2C1F2F2D1E312E1F2C2616312A1A362D1E
362A1C3C2E213D2F243B2D223D2F2442362A41372B40382B3B3529353125383428363226
37352839372B3A382C3B382F3C3C323B3B313B38313D3A33312E29211C181F1A171F1715
22171B2015192014162014162115172416162E20203D2D2E3C2C2C3C2D2A3C2D2844352E
493B3245392B4337274037264038253E36234E4633514837453C2D3B31253A30263A3128
352F233731253730262F2B2029251A262216282418282619282919242513191A0A242515
33322033342236352327281615140218190720211322221624241826261C20201619190F
18181019190F17140B1C1A0E1E1F111F20122826172927182D2A1B3532233531253C382C
2D2A1B2825162E2A1E302E21322E2233312233302132302332302434342838382E2C2D25
24251D1C1F181B1E1723261F24271E23261D21211924241A25251B29261D2F2B222F2820
312A243D35323B312F372D2B3A302F4F47456C62616F6566766C6B796F6E7F7574827A78
68636067645F61605B52534B5758505A5D5662655E7779747E7F7A989793AEAAABC3BFC0
EBE5E9F7F0F7F9EFF7F3E9F2F2E6F0F0E4EEDFD3DFD8CCD6BBB1B9948D94797377706B6F
716D6E6463616869646D6E6863645C54564B393B302D2F2231332844453D605F5A6D6966
8D89868581806C6668302A2E0C050D1B141C2117202C222B352C31372C32382D33463B3F
4C40424B3F3F342A29362C2B4D43423C3432120809190F1021161A22171B22161A291D1F
3021242D1D203525284F3F405242435444455A4A4B6050516656574D3F3F342626302426
403436685E5F665B5F71666A8A7F83847B7E766D72837A7F847E82827B82948D949C959C
807B82272229251D28372F3A322A37302835221A291C142318121E150F1B17111B1E1920
1D181C1D191A1E1A191B17141C17131A17101E1915221F1A201D181F1B183D3938858482
6B696A49474A1D1C21100F141A191E1B1A2017181D13131B0E0E160E0E16100F150E0D13
100F1518171D18171D17161C18171D17181D17181D14171E131720121621171B26191D29
2329352E3442394050484F5F444D5E4F58695B6775606E7B616D7B626E7C616D7D5F6B79
606C7A626E7C616D7D5F6B7B5F6B7B5F6B7B5D69795D69795F6C7D58687854637658677A
56667656677757687A556879526576516377526478526778526778506674536674546873
52667154667251616E505E6B525F6F525F704F5A6E4E5A704C586E4B576F48576E48576E
48546A48546A475266454D62494F65484D61444758434655
2A272225221B24211A29261D2E2E2429291D2B291D2F2B1F2E281C2D2719322A1D352C1D
382C1E3A2E203E32263B2E253B2E2540332A3E342A3B3328393228393228373328373328
39372B3A382C37372B38382C3B3B2F3B3B2F3B3B313E3E3433332B26231C1E1913201B15
2119172117162115151F14122214132515153220203B29293D2B293F2D2B422F2B46332D
4A393147392C4437274237253E3321443C295148374E453442392A3B33263D352A3B3529
342D23322E23343024272518211F121F1D0E262513252614262813282B16262916242714
2C2D1B3134213233232023121314041E201221231621231824241A2121191F1C151A1710
15120D18150E16130C1C1912201D141E1B122521162723182624173331243432253A382B
2E2C1D2826172D2B1C2A2B192E2D1B2F301E302F1D30312130312333332933332B292823
2726222322201D1C1A22211F25242024231F27221E2B26202C281F2D291E332C22342B22
332A23382F28392E2A372E293A302E564C4A6F65647268677A70717D73747A7172786F70
635D5D5955525A595558595361625C6A6D6672736D8E8F89B0AFAAC7C6C2CAC6C3E2DEDD
EFE9EBFCF3F6FBF0F4F1E6EAEDE2E6ECE1E5D6C9D0A99DA1817579685D61675E5F6D6767
716D6C6B6A6671706B6E6F69555650393A3421221C2D302935383143443E50514C63625E
73726E72716D585451211D1C130D0D1B1517201A1C2F2929352F2F372F2D332B293E3634
45403D35302D221A18201B18282222231D1D150C0F191315191317201A1E22191E271C22
2D2125291D1F3425284B3B3C4E3E3E4C3D3A584644645250645252362626261616342626
463A3A786E6D6A60617A7172918889837D7D7C76788882847F7B7C8B868A9B949B989198
6560671A151C342C37342C39312B39312B39211A2A1D172519131F1A141E1A151C1C171B
1B1A181C1B17201F1A18181016130A1313091C19101C1C1214140C161510403F3B666563
49474829292B1110151A191F18171D1B1A2218162114121D110F1A12101B14121D111018
1110181918201A1A2219192116161E15181F171A1F181B20161B21151922191D261B1F2A
313743454B59484F5F4C5363555E6F626E7E616E7E5D6D7C606D7D606D7D5F6C7D606D7D
606D7D616E7E636F7F5E6A7A616A79616B775F69755F6975636C7B60697A5964765B6678
5B687B57647757667B58687F55677F51637B4F637B50667B52687D536A7C4F6475506673
50667151656E50626C4D5E684F606A4E5E6D505D6E4D596F4C58704A58724A587247556F
48546E4A546F484F6B464D674C506947496043445946475B
27241F211E191A1712201D1628251E26231C2A261D2B271E2F281E322B21342C21392F23
3A30243A30243C32283B31273A30263A30263C3229382F263831273B342A3834293A362B
3A362B3B392D3A382C393A2C3C3A2D3B3C2E3B392C3D3D3138382C2F2D21232115221E15
1E19131D161020171223181426191326171233211D402E2A402E2A44312D45322C47342E
4A392F48382B443727453828433727423626443B2C4A4132443C2F3E36293D372B3B372C
363227323024272518252618222313222512272816262914292D1630341D2A2D18262916
2D301D3033223537292D2F222224172224171D1F141E20152222181E1E14201D14211E15
1C19101F1C131F1C13232017221E15211D14231F142420152D291E353327333124333124
3031212F30203334242C2D1B292A182C2E192E2F1D2D2E1E27281A2B2B1F2E2B222A2720
2726212C2825282423241E1E231E1B2B2623302825302923302921342D23352C233A3227
3830253930273B322B3B322B423934635C56766E6B716967797071776E6F696363635D5D
625E5D5C5B59605F5D68676373746F7B7C779A9995C9C8C4E3DFDEE1DDDCE1DDDCF3EDEF
F1E8EBF3EAEDF0E5E9EEE3E7E5DADEC6BCBDA3979B685C5E645A5B6B62636C64626B6663
6C6865736F6C7773706E6D694B4A462B2C2731312F3737353E3E3C41413F46454362615F
74706D75716E4B48431C19121E1915241F1B25201C35302C37322E36312D322D29393631
322F2A18141114100D1C1817242021221E1F16111518131919141A1B161C201921231921
271E23271C2031252742343447393841322F50413E604E4A4937352F1D1B3424244C3C3C
5A4C4B6D6260796F6E837B79847C7A8D88858D8787857F7F7C7678ABA5A9BBB4BB999299
3E394019141B2C242F342C39312B372B253127212D211B271C16201E19201E191F1D1B1C
1D1C181F1E191E1E1619190F14140A16160C1A1A1019191116160E1817122E2D2B383735
2725261D1B1E1C1A1F1D1A211A171E1C19221A17221815201815201815201B1823181621
171520181822191C25181B22141821191E24191E24181D23171E24171E261C232B262D37
3A404E4A505E4F55655D6373656C7E677081656D80626D7F626F80626F80657084626D7F
616C7E647080656E7F646D7C646C79636B78616974636B76636B7861687860677960687B
5F677C5C677B5A667C5A6882576781556680546881536981536980546A7F536A7C526876
50667352666F51636D4E606A50616B50606D4D5D6D4C5B6E4C5B724A5872495771475570
4A55714B547149526F49506C4A4E6946486146465E494A5F
26211B1E19151914101D1814231E1A27221E2924202B26222E2923332C2439322A393027
382F26393126382F26362D24362E23372F24383025352F23363024343024373125383428
3935293C382C3D392D3A38293E3B2C3C3A2B3C392A3C3A2D3E3C2F312F22282619201E12
1E1C10211D121F1B10221B11241C112B211733261D3C2F263E302745372E47362E47362C
49392C46382B45372A44362944382C42362A3F352B4B41374B423941382F3E372F3D3930
34302729271B1D1F11202214232615262B172D301D2B301A272C1630351F2D301D292C19
2C2F1E3133253234293133282C2F2423261B1C1E132123162527192122141F1D10222011
2624152624152623142723172721151E180C2822162D271B342E22393529353326333124
303123363928383B2A2B2E1B292C192A2D1A1E21101C1F0E21241324261827271B27271B
26231A2B28212D282227201A27201A2C251F362D26393029342D23322C20332D213B3527
3A34243731233E382C3A3329443D3567625C7974706F6A666D69666763605C5B595F5E5C
5F5F5F6969696C6A6B747273888687A4A0A1CBC5C9F3EDF1F8EEF6F4EAF2F4EAF2F7EDF5
F4EAF2F2E8F0E6DDE2D7CED3C5BCC1887F82746B70655C5F6761616C68676E6A69676362
676362807C7B6B67665C58575E5A594642414E4A4B444041464243484443494343615B5B
706A6A645F5C36332C2320172A271E2B281F2C292035322938352E35322D2C29242E2D29
1615110807050B090A1C1A1D211F241C1A1F1A171E19161D1A171E1B161D201A24201921
221B222C23282C2326352B2C3A2E2E382A294738354536332F1D192F1D193F2D2B584946
71625F7B6D6A877978857A78877C7A8B8180817778958C8D9D9497BBB2B7A9A2A9756E76
2C272E1A151C29242B353037322B332B242B292327282327211C201E1C1F1C1A1B1D1D1B
20211C201F1A1F1E191C19121A17101A17121C19141D19161E1A171E1A19231F1E272324
221E1F1C171B1B161C1B161C2019201B141C1C151D1C141F1D17211B1521211B271E1B26
1E1C29191923181B24161A23151C22151E231821261821281A232A1D262F2D35403D4351
4349575154655A5D7065687B67697E696B806B6D84686D83666C82666C82696F87696F85
666D80686F81686D80656B7B656B7962687463697562687463697760677762697B60697A
61697C5F6A7E5D687E59657D5B678158668157678156678156688053687D54697C546778
53667551647251636F4D5F6B4E606C4F616D4D5E6E4B5C6E4B5C704A5A7148586F47556F
47556F4B577149526F484F6B484E68454962474960484A61
261E1B2018151B13111A1210201816221A1828201E2E2624302825352E283B322D3B322D
393029362F25352E24332C22332C22383127352E24352E24322E23322E23373026383127
3A332939352A3B35293935293B38293B38293A362A3B372B3E3C2F353326282619222013
211F12222013221E12201C102923152F271A382E223B31253F332743372B47393047362C
46382D44362B47393044362D44352E42352D3E31294A3F394C433C3E372F3C37313B382F
322F262323171517091B1F0E1F2312272C182F341E2D321B282D162B301A2C2F1A292C19
2B2E1D2E30222D2F243031292C2D2522251C1F2116212316232517242716212212252412
2D2C1824230F262312272413292313231D0D2A2313352D20393325393327332F23333124
3233253A3C2E3F41332E30222C2F1E2226151517091D1F1123251724261827271B27271B
29261D2C29202F2A242C251F2C251F2D261E322B23342D232D291E2C281C2B271B322F20
3431203532233935293A362B544F496F6C676865605E5D5961605C6362605C5C5A5E5E5C
6567667274737D7D7D949293B8B4B5E4DEE2ECE2EAF2E7EFF4E9F1F6EAF4F4EAF3E9DFE8
EFE8F0E8E1E8D7D0D7A9A2A98F898D666165635E62625E5F6564626B6A686965625B5754
534F4C605B58443E3E443E3E6C6666706A6A666062534D4F544E504E484851484B675E61
645E60514B4B211D1A201D182827222E2D283C3B36383732302F2B272622242321232323
1717170C0C0C0C0C0E1B191E1B181F140F16150F1919131D1B151F1F19231F19231E1822
211A22231C2327212530272A33292A362A2A3F3130352623261714291A15423330685956
81726F8779769B8D8A958784827773827775847A799E9495A1969A958C917871784A454B
231E25241F25322D343631373530342E282A282222292524201C1B1B1A181B1A181B1C17
1D1D1B1E1E1C1C1B171C18151C18151B17141D191A1E1C1D1F1B1C201C1D201B1F1F1A1E
1B161A18131717121819121920161E1E141C1D131C1E16211D15201C1622201A26211D2B
1D1B28191925161824151C26151E27151F2818222B1C2630202A362F39453A4151474E60
4F54675B5E7164667B66687D686A7F6969816E6E886A6A84686A83686C856A6E87676B84
676C82686D816A6D80676A7B686B7C666C7A636977626876636979606777636A7C60697A
61697C61697C5F6A805E697F5E6A825A667E58668054647D57678055657C55657C526478
5164754E61704D5E6E5062704E606E4D5F6D4A5D6C495C6D4B5C70495970495970475770
46546E46546E48536F46506B4A516B464C6443485E474960
2117161E14131E14131B11101E14132117162519192C2020342927362B29372C283C312D
3C312D362D26332C24352E26322E25312D24352E26352E26342D25352E2639322A3A332B
39322A3A332B39302B3A332B3C352B3A33293A332B3A362D3C393037342B302C212F2B20
2B291D29271B2A281B2B271B2D271B332B203B31273B312740332A41342B44352E45362F
47362F46343045332F4334314233303F312E4537344D423E4B423D3F38323A372E36362C
2E2E221C1E100F1304191D0C1C210B22271030361C30361C262C12252B112E311C2C2D1B
2A2B1B28291B27271D292B2028292125261E22231B25271C24261927291B252618222313
26271522240F23220E2726122623102623102C271437321F373123373125332F23323024
35332742423647473B35372A2C2E2326281D23231924241A2B2B2129291F2A27202A2720
2625202E2B26312E292D28242D28242D28242F2C27303028312E27201D1426231A2D2B1F
3432253432263A372E44413A55524B6A69646362605B5A585F5E5C5E5E5E6161616C6C6C
7677798D8F8EA0A0A0CDCCCAE5E1E0F2ECECF4E9EDF8EDF1F7ECF2F6EDF2F3E9F1ECE5EC
ECE7EDCAC5C99B969A716F7267656866646766646567666468686668676355524D423D39
35302A38312B3D3630433C36746C697B73706E6664696061685F605C53545C5356696367
5F5A603C373D1513181F1D2226252A2E2D323D3C413130351A191E12111618171C16151A
13121716151A12101518161B18131A130C14170F1A1C141F1A121D1D15201F17221F1722
211C23201B21241F232F292B363030372F2D382C2C2E2321281D19251A16372926554744
6E615B8D807A9C8F898A7F79655A546B605C776D6B776D6C776E715F565B423C403A3539
353036302E3133313639373A3A38392D292824201F2521201F1B1A191816191816191816
1D1D1D1B1B1B1A181917151616141516141519171C1C1B20201E231F1D221C192018151C
151219120F16140F16130E1519121A1F18201D15201F17221E18241A16241E1A281E1A29
191725181727181A29181B2A191F2D1A21311A2133262D3F333B4E3B4358464C64585E76
646A82656982666A83686C85676B84686C856B6C88696A86696B846B6D866C6E876B6D86
6B7086696E84656A7E666B7F686D81686D81666B7F636A7D636A7C61687A62697C61697C
60697A5E697B636B7E5D687C5B687B5A677A5B677D5B677F59657D56657C55647B526279
53637A5162764F60745162744F60724D5E704C5D6F4A5B6F485A6E495B71485871465670
46567046546F47557246516D454F6A454D6443485E454A60
2119171D13111C12101B110F1B100E201513261B192D1F1E372926392B28382A273B2E28
392E28362D26312821342D2538312934302737302A373028362F273831293C352D3A332B
3A312A3930293B322D39302B3930293A332B3A312C39322C3A362D3A362D373328363227
322E23312F22322E22332F233430243731253C34293B33283E342A41372D44372F43362E
41322D43342F41322F4334314233303E302D4234314D423C514A44433F363D3A3138382C
292A1C181B0A0E1100151A061E230D282D162D33192E341A2C3218282D162B2E192E311E
28291B22221623231924241C2A2B2328292327282227282024251D26281D27271B202113
1D1E0E1C1F0C2223112627152524102625112E2B18302D1C2E2B1C312D21323024312F23
353327403E324C49404D4D4544443C3B3B3333302B322F2834312A322F2A312E292E2A27
2B2A262C2B272F2E2C2D2C282A26232D2C282C2D272D2E2832332B22231B2B2B23323228
3131273232283838304746415655505B5C575B5A585959596565656C6C6A686866797977
878988AAACA9D2D1CFF0EFEBEFEBE8F0EBE7F3EBE9F7EDECF6EDEEF3EDEDF5ECEFE3DDDF
D0CCCDA8A6A77D7B7C716F706A6A6A65656569696970706E7272706665614C494435302A
302923372E273D342D3C332E5F54507268666D63627066656D65636A61626B62656F696D
615F643E3B42201D2627262E2A2A342F2F372E2E3624242C17171F16171C18191E15161B
16151A1C1B201A181D18161B140D14120B12180E1720161F1B141C1C151D1D161E1C151D
1E1920201B211D181C2723243C3839373131342B2C2F27252C24212A221F2A201E332A25
4035316A5F59867B75746963594E48594E4A5A504E53494852494A464042363233343235
3F3D403B393C3C3A3D42404147464432312F1716141D1C1A211D1C1817151A19171A1819
1A1A1C1C1C1E1715181614171412151210131311161A191F2421282320271C19221A1720
17161E15141C13101916101A18121C1B151F1C16201E18241D1A251C1A271A18261C192A
1B1A2A18192B1A1D2E1B1E31191E3222273D242A40363C54454C6649506A5257745C617E
676D87686E88686C87676D85676D85666C84676B86676B86696D86666A83696D86686D83
686E84686E84666C82676D83686E86676D85656D82666E83646C81636B7E636B805F6A7C
606B7D5F6A7C626D7F616C7E5C697A5D6A7B5B667A5A65795A667C576379556177536277
5362795060775061755061754F60744D5E724E5F734B5B724A5C72485A72485872495973
46567044546E44526D46546E454F68474F64444B5E454A5E
1E19151D18121F18121C150F1B120B1F160F281D1730251F352A24372C26392C26392C24
382E25352C23352C23383127383127383127393029382F263A31283A31283C332A3C332A
382E25372D24382D27392E28392F26382F263B302A3A312A3B32293A3128393327393327
3A342837332737312537332839352A3A362B3834293C352B3E362B3F372C3F372C3E362B
3F352B3F32293E31293F322C3F322A3E342B3E342B463D34534C444B473C403E31363727
2425131518051013001A1D08232710292D162D311A2E311C2C311B292E1A2A2E1D282C1D
26281D22241924251D24251F2B2C272F302B2A2C29282A2523252023261F25261E212318
212316202415222416242618222514262918282B1A2C2F1E2B2D1F2E3022323226313125
38382C3E3C3046433A56534C53504B4F4C47423D3A3D3834393430332E2A342F2C322E2D
302F2D2F2E2C2F2F2F2E2E2C2B2D282E302B2D30292E312A2E312A2A2D2632332D34352D
2E2F273738323D3E394A4B465D5E59595B58616161616362686A676E706B73746FA0A19C
BCBDB7DADBD5F1F0EBFAF7F0EDEDE5F4F1EAF0EBE5EEE9E3F2EDE7F5F2EDCBC6C2B3AFAC
B9B8B49F9E9C6F6E6C6A69676C6C6A6868667272727F7F7D7F7F7D61605C413D3A36312D
2F2822362D283C312D392E2C4B3D3D6C6062786C6E746A6B6F6667706768706A6C595458
44424538373C27262C2B2A3032323A3033382D30351B1E2314171C1A1E2118191D151618
1919191A1A1A1C1A1B19171A150F131711151910151B12171711151B161A1D181E1C171D
1F1A21221D231E1C1F2220232A282B2624272826292624252625232524222723202D2825
322A27463F39665B575D524E554A465449454D43414A403E49413F3D38353632313A3839
4141414343434545454949493F3F3D20201E0E0E0C1818161A19171715161B191A1C1A1B
1B191C1B191C18161916141715131614121513111418161B1E191F1E1C211D1A211C1920
19181E13121813121A16131C18151E1E1B261C19241E1C271D1B261D1D291A1C29191B2A
191A2C181B2E1B1D321E20371F233C2C324C343A54464C664B506D565B78626785636885
656B85676D87686E86676D856B7189676F846971866A7287636E82677286687085666E81
657082657082657084646F83646F83657084626D83626D83616C82616C80626D83626F82
606D80606D7E606D7E5E6B7C5C69795D6A7A5A67775A6778596677566374546172556273
505F72516073505F72505F724F60744D5E724D5D744D5D76485A72475971485973485973
46577143536D42506A425168434E62444D5E434A5A434957
1B1B1319190F1B170E1E1A111C180D1B170C1F160D2B2219312821342B24392E28392F26
382F26372E25382F263A31283730283730283930293A31283B32293B32293C332A3C332A
3931263B3127382E25382E25372D24382D273B302A3930293C32293930273A33293B3529
3933273A342839322838312739352A3735293632273A362B3C362A3E382A3D37293E3828
3B34243931243B33263B332841372B423A2D3F372C423B314A463B4B473C403E31383627
33312220210F1C1F0C2528152528152A2D1A3033202A2E1D282C1B282C1D262A1C25281D
272A21282B222A2B252728222D2E2932332E2F302B282A2524251F27282226271F24261B
24261922261825271A23271926281A26281A27291B2C2E202C2E202F312433352834342A
37372D34312837322C47423E4F4A47443C3A352D2B3A3230362E2C332B293832323D393A
3D3B3C3B3B3B383A3935373632373331363033383231362F2F342D3437303E413A3B3C36
383B344B4D484F504B5D5D5B5B5B595E605D6464626D6D6B7A7B768D8E88BDBEB8E1E2DA
F4F5EDF6F6EEF8F5EEF8F5EEF8F5EEF3F0E9F1EEE7F5F0EADED9D3ADA8A28F8A84ACA9A2
AFACA7797873625F5A676661666561696A65908F8DAAAAAA8F8D8E67666444403F292323
1D1513302624352B2A4135356054586F636770636A706569756C6F625C5E3D383C322D31
3432352E2E3027262B42414656575B58595D494A4E2D2E321F20241D1E2218191B1D1E20
242424222220201F1D1A19171612111913131A14141B15151A16151C18171E1A1B1E1A1B
1F1D20201E21201E21232124252527252429262628232426242527232325262425332F30
302C2B3B36334D45434A403E473D3C4A403F3C32313E36343D38353D39363B3A38434341
494949484A494F4F4F3535330D0F0C0707050D0D0B10100E1818181C1A1B1B191C19171A
1A181D1C1A1F19171C17151A15131616141717151819171A201E21201E211E1C2118161B
14131815141A16151B17161E1F1E2624222D24222D22202D1F1F2B1D1D291B1D2C1B1E2F
1A1D301D1F341F21382527403135503D435D4348655257745D627F656A87696E8B696F89
696F876C728A6A70886971866A7287667185687588667386647386647386647386637383
647484617181627184647184626F82626E84616D83616D83616D85606C82616D83606C82
606F845D6C7F5B6A7D5A6A7A596978596978586877576776566675536372556272576474
50606F50606F5060704E5E6E4D5E704C5D6F4B5B7249597049597049597249597245556F
45556F44546D425168455167445162424E5E404A56404853
181B1015180D19190F19190D16160C13130918140B211D1429261F312C26362F2937302A
3A332D39322C362F29372F2C362E2B39312E3A332D3B342E3B342C3C352B3E372D3D362C
3A33293930273A31283A3128372E27382F28382F2A37302A39302B3A332B3A332B383129
3A33293B342A3A33293831273B372C3935293733273A37283C392A3936253835243A3724
39342136311E3833203C3724423B29443E2E494335433D31403C313F3B30413D323F3D31
3C3A2E27271B27291B2B2D1F292D1E2D3123303426292F21252B1D23291D23261B262920
2A2B232A2B2326252025241F30312B36372F35362E2B2D2227271D28281E2B2B1F2A2A1E
27281A26281A25261827291B292A1C26271927271B28281C2B2B1F3131273333293A3730
302D262C29222D2824302825372F2D352B2A2F25263228293128293A3134413B3D474246
5351545656585051534A4E4D3F4342393E3A3A3C39383A353537323D3F3A494B46494B46
4C4D485657525556515E5F5A61625D6869646E6D697D7C77A7A6A1CACAC2E4E4DCEDEDE5
F2F2EAF8F5EEF5F2EDF8F3EFF5F0ECEFEAE6F5EDEAE0D8D5B5ABA9786E6C77706A8D867E
847F796C69626A655F65625B5E5B5673726E9C9897C7C5C6AEAAAB918C90686367464044
272123251F212923254D4447655B636D626A796E766C626A564C54383236272226322E2F
302E2F24222326242554525370707084848482828468676C3B3A3F14151924252937383A
3434342929272526211B1A1619161119161116130C1919111818101716111C1B171D1C18
1D1E191D1D1B21211F24242426262827272924252922232724252928272C2B2A2F302E33
302E313530343E383C3E383A3E353A3E353A3A31363A34383A35393D3B3C3D3B3C434343
4D4D4B4F4F4D51514F1D1D1B05050311110F12110F110F101816191B191C1A151B1B161C
1D181F1E19201C19201A171E16151A17161B1616181B1B1D2121212020201E1E2019191B
16161819181D18161B1D1B2025242C2B29342D2B382422301C1B291E1D2D1E1F311D1E32
1E203520223924263F383A5340445F4A4E67545873636780686E86646A82686E846B7086
6B72856B728568708368738768758865748964748B63738A6274886075885F7487607384
607384607384607183637285627186616D83606C84626C85626C87616B84636D865F6B83
5F6E855C6B805C6B80596A7C596A7A5A6B7B576A79556877566876526472536370546672
51636F50626E51636F4F616D4C5E6C4C5E6C4B5A6D48576A4C5B7048576E48567047556F
49577148546E47536B465268445164414E5F3F4B59404C58
161C1014170C17190C191B0E15170C12120815120B1D1A132A27202D2A23332E2835302A
36312B36312B35302C342F2B36312D3934303E39353F3A34403C33423E35403C313E372D
3D362C3B342A3B32293A312A3C332E3A332D3A322F37322E372F2C37322E37322E36312B
38342B3C352D3B342C3932283834283936273A37283936253A372435321F33311C36341F
3735203A382336341F36341F3C392645422F545142524E42353126312E25322E2538352C
3E3B3437372D33352A32352A30332835382D32352A2A3022242A1C22281A25281D24271C
292B202C2E232C2C242D2D252F3028383A2F3E403333332727271B2B2B1F2F30222F3022
2B2C1E2D2E202D2E2029291D2D2D2128281C28261A2B281F2F2C2333302935322B33302B
2F2C27231E1A221D19251D1A2A201F2D23222B1F21281E1F2E232740373A474145534D51
65606468666B66656A5E5E605A5B5D5759584E4E4E4B4B4948484646464450504E545452
5859545A5B565B5C5762615C6E6D686B6A65807F7A9D9D95BDBAB3E7E4DDF5F5EBF4F4EA
F9F6EFF4F1EAF2EEEBF0ECE9F6F1EEEFEAE7DAD2D0B6AEAC958B8A7066646B645E716A62
757168716D646D69605B574E524F4865625D7D7976ACA8A7B6B2B3AFAAAE8D888C6D686C
4D474B2D272B302B2F4A454B655E66685E67736972564C552C252D241D25312A313C373B
3D393A2A26251C18173A3635575352928E8DA4A0A18E8C8D6765663030302F2F314C4C4C
3A3A382E2F2A28292322211C1C1C141F1C1511110914140C1A1A121819131C1B171D1E19
1D1E1921231E23232124242225252525262825262828292D2C2B3036353A343339302F35
333136312F3435303636313736313837323937303839343B38353C3D3B403F3F41414141
4747474A4A484444443939372E2E2C2626241715161B17181816191E1C1F1E191F1F1A21
201A241E1B241E1B221B1A20191A1E1C1D211D1E201D1E201F1F1F20201E2020201E1E1E
1A1B1D1D1D1F20202229282D2D2C322E2E362929352322302322322022312122341F2235
21233A262A432C30493B3F5A3D415A4D516A5E627B646881656B83666E83686E846B7187
6B72856B73866974886A758B6A768E66758C66769064758F62768E60768B62778C60758A
5E7388607286617286617286627188636F8766708B66708B646E89626C87646E87616D85
606F865C6B825A6A815A6B7F596A7C576A7B576A7B56697A556678546577526373546575
5265745063714F616F4E606E4E606E4D5E6E4D5D6D4A596C49586D48576E47536D47536D
48546E4A566E49536C465167445164455263404E5B3F4D58
181B10181B1017190E18180E16160C12120817140B211E152E2B22332F2636322937332A
37342B35322937342B36332C36332C3E3B343F3C354441384441384542394240343F3B30
3E3A2E3A362B3B342C3D36303F37343F3A373F39393A36353933333834313A363335322D
35322D37322C3C352D3B342A3933253731213934213B36223A351F36311B312C1636311B
34321B3937203A3823353420434230484637504E415C5A4E4745393232282B28212D2D25
39383340413940433A3F42393E413841443934382A2C302125291A25291A27291B282A1C
2C2D1F3233252E2E222F2F23343629383C2E3E42343A3C2F2D2D2131312536342839372B
343226302E22302E222E2B222F2C23302D242A261D2D2822342F29322D27322D292B2623
26211E1E19161B1613191411261E1C2B23212A2021241A1B2C21253E333742373D4C4149
655B636E646D7069716D666E69646A6A686B6B666A6560645D595A5B57565B5A585A5957
605F5B63625D61605B64645C7171697A7A7294918AC5C2BBDDDDD5F1F1E7FDFAF3F8F5EE
F4F4ECF3F3EBEBEAE6E9E8E4EFEBEAD9D5D4AAA6A5938F8E7773706F6B686D6A656E6B64
6F6C636D6A616B685F5E5B52514E47514E496964607C77749A96939F9B9A938F907A7579
746F735954584B464C58535A6760685E56615248533A2F3D251A28261B29524853564F57
443E42383234272123241E1E3933335C57548D888587827F635E5B48454047464252534D
3F40383738302F2F2726261E1C1B161D1C171C18151514101A19171918161C1A1B1B1B1D
1F1F1F2022212323212222202325242628272525252D2B2E3331343B393C3A383D323035
353036312C322E2B32312E3533303934313A37313B39363F38353E3F3E44434247424244
474749464646413F424240414141412727271B191A1C1A1B1C1A1B2220232220251F1D22
1F1C231D1C221E1D221E1D222021231E1F212324282223251F21201D1F1E1F20221E1F21
191D201F23262C2D313334392E2F342B2E35272B361E222D20222F1F213021243522273A
24293F292F47383E56444A62545A746066806A708A6B718B69708A6B728C6D748E6D748E
6D758C6B738A69738C6B759068738F66748F66759464759365769262769166779362738F
63748E62738D60708A63718C636E8A66718D68718E67708D68728D636D88636F875F6E85
5F6E855D6D8458687F59698058687F58677E58668056647F55637E54627D52607B506079
50627A52647C5060775060774C5E724B5D714C5D71495A6E48586F47576E48567047556F
47566D49556D49536C475268435063455263424E5C414D5B
191B101A1C1117170D18180E1512090F0C031A170E2A271E312D2435312839352C39352A
36342835332736342835322937372D3F3F35403D34423F364644384543373A382C3B372C
3B372C3D362C3E3731403835413C39443E3E413B3D3C38393B3736373332393532383530
34312C35302A35312638342836302037321F37321E3A351F3B3620353118332E1835301A
35331C3735203A39253938264442354C4D3F50504453534948483E35352B34342C2A2924
2A2B2352534B5F625952554C50534A56594E4A4C3F26281A25291A292D1E2A2C1E282A1C
2B2C1E3031232A2A1E2B2B1F2F312435392B3C3E313C3E313A3A2E3D3B2F433F34433F34
3733282E2A1F2D29202F2B22302B252B28212F2A24302B25302B252E29232C2723221D19
1C17131914111D18151C1714241F1C29211F28201E23191A2C222331262A362B2F493E44
5B50566E646C736870756B73716A71706B6F6F696D6E686C666062635D5F646061666261
6D69666C696469666169665F77776FA6A69CD1CEC7E9E9E1F7F7EFF4F4ECF5F5EDF3F3EB
F5F4EFF5F4EFE8E7E3D6D5D1C0BFBB9695917978747A797574736F6C69646A67626B6863
6E6B646B685F66635C6A6760625F585A57505F5A566A65617D7A7584807D7B7776736F6E
7672736D686C69646A716A716C656D4E444F2C202C2418262B1F2D3A2E3C675C6A675D68
473D452C23282A2124251F1F2B262348433F736E6A67625C4E4B444F4C4356564E515147
3E40353D3D3337372D302D2626231C23201B241F1C1C1616211B1D2621252621252A2529
2B292C2B2B2B2624252423212424222929272F2E2C3733323B37363E3A3B3A3539373236
2F2A30241F25242128302D362F2C35322F383835403B38433B394444434B48474D47464B
47464B3C3B4033313639373A3434361D1D1D1B191A1B191A1F1D1E252324211F22201E21
1A191E1B1A1F1C1B201D1D1F27262B2F2E3329282D27262B2424261E1F211F20241E1F23
191C211F2227393C43373A41272A3123282E262A3522263121253126293825283724293C
2A2F43393F554C526A586077676D877076906F758F7177916D748E6E75917077936D7490
6D74906F76926D76936C7594697291687393667395667596677695667795667594647593
65749165749164728F66718F66718F67708D68718E67718C67718C6571895F6E855D6C83
5C6C835A6C8259698058687F56667F57657F56647F5A6581576280545F7D53617E53617E
4F5E7B4F607C4F5F794E5F794D5F774C5E744B5D73495B7147596F47596F47577047566D
46556C46556A475369465366455263455161444D5C414A59
15150B16160C18150C16130A181409120E031B170E2A261D302C233531283C382D39352A
3735293735283634273533273A3A2E413F333F3B30433F34444034423E32332F24373026
3C352B413A32423B35443C394A4240463E3C3B32333B3535393333352F2F37322F35302C
342F29332F26322E2335332434311E37352035331E37351E38361F33311A32301B35331E
3A35223936253836273C3A2D44413847443B49494146463E3D3F3433352A35362E2C2D25
2A2C215A5C517173685E60555F61566F716466685D2E30232D31232F33252A2C1F2C2E21
2D2D212C2C202B2B2128281E2B2D2233352A41413745423943403745413849423A413A32
322B232A231B2E27212B262029251C28241B30292130292128241B27231A27231A211C16
120F0817140F1E1B161F1C17211E1927221E27221E25201D26211E2A2522332E2B423D3A
4E4946625C5C716869706A6A747071706C6D696365685F62675E616D646772696C7E787A
8781837F79797D78757E7B769C9C94E3E3DBF6F5F0F1F0EBF5F4EFF1F2ECF0F1EBEFF0EA
F1F2EDF3F4EFD6D7D29697927B7A7672716C6B68636F6C676F6C676C67636A656168635F
75706C7D7872837E7A948F8B96938E827F7A55524B58554E69665F6C69626C67636F6A66
6E69666D6767746E707A7176675C64392E361D101A1305121C0E1B443643685C68554B56
392F372822262A24262925242A262336332E4A49445050485050465050444F51464D4F42
47473B4242363C382D38342B3730282D26202C22212C222324191D34292F4B4247494045
413B3F3A34362F292B2C26262B2726312D2A3A36333D38353E39363F3A373731312C2829
201B1F1B161C211C232D2A3336333C36343F3937423A3843403E494745504A475246434C
37363E2423291F1C232522291E1E201B1B1B1C1C1C1919171B1B1921211F2322201A1819
1816191D1B1E1F1D22211F2435323935323B2C293226232A252229201F251B1A221C1C24
1C1C2423262F3638442A2C3823262F2125302327322226322326352326352A2D3C323848
4045584E55685C6278666C846F758F7076906E75916E75916E75916F76926E74946F7595
6D76956C75946F75956B74956D76976974946872956774966B7898677695667491667592
67759065738E67728E68718E68718E6A718D69708C656F8A64708A6170875D6C835D6E82
5A6C8054697C56687C57697D56687E53637A53637A55637D54627D54627D545F7B55637E
53637D4E5E784B5C764B5C764D5E784B5F774B5F77465A72455B7043586D485A7047576E
45566A465568465568445162435061445060434C5B434B58
18150C16130A19150C18140B1E170F1811091C150D302921352E263A362D3D39303D392E
3A382B3836293735283634253C3A2B413F30413E2F423C2E423C2E453F313C362A3C352B
3F362D433A33463F394B443E4E46434C4441423A373E36333E363339343037322C2F2B22
2F2B22312D2232302334322332311D36352037362137362137362134331F34331F343321
3F3C2B3D3B2C3C3A2D4341354B473E413E3539392F39392F35372A2B2D2031332635372A
2C2E20383B2A76786A70726466685A7A7C6F737568484B4040433833362B313429303225
2A2A202D2D232C2C2228281E2C2C2234342A423F3849463F4A463D49453C4A433B332C24
2019111E1A11251E16201C131E1B121F1D112723182824191F1B101B190D211F131D1B0F
16130A1B180F221F18211E1724211A29261F2A251F27241D25221B28251E2B282137342D
47423C544F495E5953696460706C696F6A675C54525C54526F6566766B6F82777D92878D
A3989E9D9499938D8FB5AFAFD3CFCCF1F0ECFBFAF8F7F6F4F6F6F4F3F3F1F0F0EEEDEDEB
F1F2EDD3D4CF93948F6D6C676D6D656E6E666B685F6D69606D69606F68605A534B7D746F
8E8580887F7AA29A97BDB5B2B7B2AE9C97935A55515B585164615A6A67606E69656E6965
65605C6F6A667D75736A616250454925191D2112191C0C1622121D2D202A372B35382E37
362F36322D31322E2F2C2B272B2A252827222B2C244A4B4362645957594E4E504548483E
4B4B4147473B3D392E443D33423B333229223C312D403232362A2C463A3E5F54585C5155
544A4B453C3D382F30352C2D342E2E3A35323E39363E3A373E3A3736323124201F252122
211C201C1A1D201E23312E353A393F3C3B413938403D3C4445444C47464E4A47503F3C43
1D1C2216151B1B181F1B191E19191B1919191919171818161819141E1F1A22211F252422
1A18191D1B1E27252A343138403D4635323D2B2531211B27201D281F1C2722202B211F2C
22202D26263227263420222F22243120222E242633272936272A392C2F3E383B4A414755
4D53635960726B72856D758A6C748B6D758C6E758F6F76907077936E75916F7595707696
6F78976C75946F759571779970799A6C75966972936974946A7595687693687391687691
67759066748F68738F68718E68728D66708B66708B656F8A62708A62708A5E6D845D6D84
5A6C82586D80576C7F596B7F56687C55667A56677B56657C55647B57667D56627A57637B
54627C4F5F784C5C764D5E784B5F78495D764A5E77475B7445597144587047597145556E
44546B445569455467465366475264475061434A5A414956
1A160D1A160D1C150D1F18102118111C130E1B120D3229243B322D423B33403931403C31
3B392C3937283836273433213C3B273F3C29423D2A413C29403D2A45422F453F31413B2F
423A2F453C334B42394F463D4D463C4E473D4F463D443B323D342B3E372D3D372B363024
332F23322F203331223534222F311C32341F353722343523353624353626323323323323
3D402F42453440413347473B4D4B3E39372A2D2E202B2C1C2C2F1C2A2D182D301B3C3F2A
3E422B40442D6469536B705C6065516F73627E8273797D6F5E62544A4E403D4133323627
2D2F223032252D2D232B2B212E2B223533274440373E3A3138332D3A352F3F3A34211C16
130F06120F0618140918160A141408191A0C1E1C0F1E1C0F1617091415071F2012212214
1718081E1F0F2425172321142624182824192A271E27241B24211824241A26231A2B281F
48453C56534A59564D5E5B5466615B69645E655E58665C5A7B71708A7F8391848D9A8D97
A0939DB8ACB6CBC1CADAD3DBF0EBF1FAF5FBF7F5FAF5F3F8F5F3F8F4F2F5F6F4F7E2E0E1
B0AFAD9695917A79746A6A626D6D636A6A5E69675A6F6C5D736D5F70685B585043786E64
7D70686C5F59948985B0A5A3A399989187867A7270746F6C736E6B6D6865736E6B716C69
56514D595450625B5558514B443A38271B1B3021243021262D202732252C342931372D35
3530342E2C2D2C2B292A29252B2A252829212121194141395A5A525E5E5653534B3D3D35
40403844443A423F36433F36474036453C33493E384B403A453A364C413F655A58635856
534747443A393D35333D34353D3737423E3F3E3A3B3331342B292C272528201E21222224
2121232121232424263232343D3D3F4040403B3C3E3F3F414646484B494C444245222023
1010121A1A1A1C1C1C1919191818181A1A1A191B18171916151714191B18212121282828
2323232424262F2D323B383F44414A35323D28253025212F221E2C221E2C272331252331
2523312826342825362C2A382A28362827352A29392D2C3C303241323544414755545C69
5D65726D76856D76856C78886D788A707B8D6E798D717C92707A93707A956F7994717A97
737A977178957278987076967076986E74966E74966D76956B74936A75936C75946A7591
69779269779167758F67758F67759065738E65708C5E6C8762708B60708A5E6E8860708A
5B6D855A6C82596B81596A7E5A6B7F5B6A7D576679596679576477586578566278566278
55647B5161784D5D764E60784A5E774B5F784D5E7A4A5B774A5978495877485776465373
45537045536E48546E49556B4752664A5265464D5D444A5A
1C171117130A1B120B2219121E1510150C071A0F0B2B201C372E293E352E433C34423E33
3C3A2B3736243938263837233A39253D3B263F3D2844422D45432E474431423F2E423C2E
433D31464034473F324842344E483A4D4739514B3D453F31433D2D413B2B413B2B3C392A
363324302E1F3331222E2F1D2B2C1A2E311E313423313524343829313526313325333527
3A3C2E404234404034424033403E312D2B1C2E2D1B2B2D182B2D18292B1532341E575B42
5D61484A4E354649345D624E5F63526468597A7E70868A7C797D6F6165573A3E30313325
393B2D37392B313125302E222F2B203D392E433F343E3A3125201A241F1928231D1A160D
14110814120615130717180A16180A181A0C1A1B0B191A0A171A09181B0A202312242716
22251420231223251724251726241727251929271B27271B25251926261A2C2A1E2C2A1E
3C3C3055554B56564C5E5B545E5B5465625B75706A7A726F847B7C93888C9E919AA2959F
978996C4B8C4E9DEECEFE4F2F8F0FBF8F0FBF4EFF6F5F0F7F1ECF2E3DEE2D9D5D6AFABAA
898681807D76706D646F6D616C6D5F6768586A69576B68556D68556E6956655E4C635C4C
5F5549544A417F74709B908E90868582797A8077787E78787A74747B77766963635D5855
544F4B47423E2C2721342D254D463E37302A2D2321312725423837423A383F3637383232
38343329282624201D28252027262126252024211C37342F54504D5955525853503F3C37
35322D3D3A33413E35423E354743384D463C52494050473E483F384D443F605752594F4D
493F3D3E36343D3435403A3A464243433E422F2D322523281C1B2019191B1F1F21262628
2525272222222828283433313E3E3C42433E3F3F3D424240454442434142323031181617
1717151818161818161919171919191D1D1D1B1B1B191B1A181A191B1C1E2525272C2C2E
2D2D2F2E2D323431383C3942403D4633303B272331262230251E2E231F2E262231262231
2623342825362D283C2C293C2A27382C2B3B302F412D2E403B3E4D474D5B555D6A646E7A
6C76826E7884707C8A707C8A707D8D707D8D717C90727D91707B91717B94717B94737A96
737A96737A96737A977177977177977177977076966D76956D76956D76956C75946A7591
6A789269779167758F67758F65758E64748D65738E616F8A5F6E8B5F6E8B5E6E885D6D87
5B6B845C6C835A6A8158697D5B6A7D59687B58677A59687B566676566676546376536275
5364784E5E754F5F764E60784B5C764B5C764B5C784C5B7A4D5A7A495676495678475474
4552724C577348546E47516A475266485063464B5E454B5B
1A151119140E1B120D20171220150F160B051A0F092C211B352A243D342B443E32434031
3E3C2D3736243A39273837233938243A392541402C454430454430444331454334423F30
423F304744354943334845344D4A39514E3D53503D3F3C293C3A25403E29403D2A403F2D
3D3B2C3132222A2B1B282B1A272B1A262D1D2A30222D33252F352930362A32352A35372A
37392C3B3B2F3E3C303C382C322E2229261729261522210D21200C302F1B41402C636550
5C5E4940422D343525686A5C686C5E64675C6D70676C6F66696C635D60554F51444E4E42
4647393D3E303A382B3836293A362A433F333735292B291D1B170E1E1A112320171D1B0F
1715091715091B190D19190D181A0C17190B171A09171A09191D0C212514212516242819
24281925291A23271924261923251829291F2B2B212A2A2026261A2424182E2E22313125
3E40354D4E4654554D5F605A63645F6768637F7E7A838280888485948E92B0A4AEBFB3BF
A69AA6B8ACB8DDD1DFF3E7F5F9EDF9F4E8F2F7EDF5E2D9DCC9C3C3D2CDCACDC8C2949087
7A766B6F6B5F6C695A706F5D6D6E5C686A55686A556B6A556B6A556766515A584354513E
524F404E483C6E675F877F7C837E7B7D79787C78777C78777D79786D6C6A4E4A473E3A37
2B2823211E1924211A36332A48453C47443B312E2529261D59564D57544B423F3639362D
37342D27241D25201C2A25212C242129211F2C2223382E2F483E3F4C42434F46474A4240
433B383E3731463F374D4940524E455450475450474A463D49463F4B48414D4A45433F3C
3D39383B37363C3839433F4042404333313417151A13111619171C1D1B1E232124272526
272526282725302C2B3A363342413D47464146454147464243423E3C3B39262523191816
1A1A1A1A1A1A1917181816171A1A1A1D1D1D1B1A1F1B1A1F1E1D2323222A2C2B332F2E36
34343C34343C32313935323B36303A2E28322D273329232F29213028223025213024202F
2522332726382A273C302D42312F442F304434374A353A4D4D54645D6675666F7E6B7785
6E7A86707C88717D8B727E8C727E8E727E8E747C91747C91747C93747C93737B92737A94
707791727C97717A976F78956D76936E77946C75926C77936A75936974926B76926B7993
69779167778E67768D67768D65758C64748B62728B61718A62708B5E6C875E6C865B6A81
59687F5C6D815A6B7F596A7C5B6A7D59687B5A697C57687A566779516274506276516377
5163794F61774F61774D5F754D5F774A5B754B5A774D5B784B59764A58754B56744A5571
48536F4A546F49536C4A5269495164495062424858434657
1B16101B16101E17111E150E1A110A180E051A100721170E2C22193A3227413B2D403D2C
3F3E2C3837253A39253C3B273A3C273D3F2A4243314445334243314847354A4839484637
4543344847354746344B4A36504F3B504F3B504F3B41402B41402B42412C403F2B434230
3E3F2F292A1C2022142022151C20121C2214272D212A32252931242A3024313429383A2D
3A3C2F3C3C30403E323C3A2D2E2C1D232210201F0B1A19051C1B073736214B4A36484733
31331E2A2B194F4D3E6D6E6064645A66675F65645F63625D64645C6161595C5950545148
5351454C4A3E4442363F3D314442354B493C3C3A2E19160D0C090019160D1D1A111D1A11
19170B201D14201D1418180E19190F191B0E181A0D161A0B1D2112262A1B24281A232719
262A1C262A1C24271C25271C24261B27291C3032252F2F2326261A2121152D2D2137372B
494B404E514851524C61625D797B786F716E6F6F6D808080959396A09BA1AEA4AFCABECC
CCC0CCBEB2BED2C6D4EBDFEBF4E8F2F6EBF1EFE6E9ACA4A2918986BBB7AEC7C0B68E887C
6662566966576D6A5B6E6C5D696A5A6768586768566C6D5B6F715C62644F4446314B4A38
4E4C3D45433768655C89867F7C7B777C7B77807E7F8583844F4F4D34343230302E33322E
24231F12110C31302B61615959594F52524846483D2E30234A4C3F48493B333124373528
312F23221E1529221C2A221F261C1B271D1C3024263D31333E32344B3F3F4F4544504644
4D443F49423A48413955514656534A53534952524A45453D42433D41443D3D3E393A3A38
3A3A3A3A3A3A4141434442453F3D40201E211311161813191C171D201B1F262125242223
2A28292D2928322E2D3C383544433F48474249484340413B3A393534343221211F171717
1A1A1A1D1D1D1A181919171A18181A1C1C1E1D1A211D1A2327242F2927322C2A352A2833
353541393744332F3D322F3A3D3A45443E4A3E38462E28362C25352C2837252331252434
2A293B292A3E2D2B4131324737394E36384D44495D50576A6770816D76876D79896D7989
717D8B74808E737F8F737F8F748090737E90757D92747C91747C93737B92747B95757C96
727C97727C97717A976F7A966E77966D78946C77956D78966B76946A75936A7893697791
69799267778E66758C66758C647589627387637488627289627188606F86606C825E6A80
5C6B805F6E835A6B7D5C6D7F5C6B7E5A697E58697D54667A54667A5163794D62774E627A
4D61794E627A4E627A4D61794E60784E5E774C5A754C5A754C57734C58724B567247516C
49536C49536C495168485065495063474E60414659454859
19160D1B170C1D160C1913071711051810051D150A1F170A20180B332D1F3D3A293D3A29
3E3D2B3A39253C3B293B3A283938263D3C2A4240314142324142304344324846374B493A
4748384647354144314447324F523D52543F4C4E3942412D44432F444331444233444235
3B3C2E26261A1F21161A1C111A1C111C1F1426291E2A3024272D1F272D1F333729383C2D
3C40314042344446383A3D2C292C1B1D200D1B1D081D1F0A1F210B2C2E163B3D2732341E
201F0A25240F585544696657635F5466625968615B68605D6D656268605D5C5451554D4A
544F4B56534E4E4B4447443D49463D4F4F4543433B12120A05050019160F1D1A131C1912
1914101E1B16201C191B1A161918141A1B151D1E181D1E1620231A2A2D24282A1F24261B
26281B282A1D25271A25251927271B28291B2B2C1E2B291C2826192826192C2A1E3A3A2E
4A4C414D50474E4F496566618C8E8B8A8C8B7B7B7B828284929093A29DA4A8A0ADB1A6B6
C9BECCCCC1CFD3C9D4EBE1EAF7F0F7EDE7E9BFBAB778756E807E72A7A5989D998D777367
6763576C685C6D6B5F6C696067675F63645C64655D74766B75776A6466594C4E4159594D
4C4C404141376969617E7E767877737A7B767F7F7F6D6D6D2F3130202221333534353533
2525231819144748437879737677716667615051493D3E3637372D2C2C202A281C2C2A1E
27231A2521182F2822271D1B211715251B192C2220392F2D3E35304A413A4B4239484035
4E483C4943374743374F4D404F4F434D4E464A4D46424740434A4337403B363C38383E3C
363C3A383C3D4344464747493634351A181B1C171D221B221F181F231C23261F26282327
2B262A322E2F3632313A39354645414A4B4644454034363130302E2E302D2022211A1B1D
1E1F211D1E201C1C1E1B1A1F1B191E1D1A21221C26241E2A2A24302C283625212F1D1927
2F2B3A3B3746332C3C3834435955646965735652612A2836211E2F2D2C3C262837252839
2B2E412B30442A2F43363B513A4056464C62596176626A7F6B738671798C737B8E727A8D
767E91747C8F767E91767E91777F92777F94777F94798198767D97757C96767D99747E99
747D9A717C9A707B996E7C99707B9B6E7997707B9B707B9B6A77996B789A6B7898677592
68789268789167778E63738A6273876374866372856170836271846170835D6C7F5D6C7F
5D6C7F5A697C5A6B7F5C6D815A697E59698057698154688052667F51657E5263814F607E
4B5E7C4D617C4C5D794D5E784F5F784C5C754F5B754E5A744D57724E58714D57724C536D
4C536D4C536D4A5269474F64495063464D5F414659454A5D
1311051513071814091B170B1D170B1D17091F190B21190C231D0F302A1A3B35253D3A29
3D3A293B38273B38273936253936273734253B38293A38293A3B29393A283D3B2C474536
4546364447363F4231424534484B3A4D4E3E4A4B3D4546384846394543364240343B392D
29291D26261C2323191D1F141C1C121D1F14282A1F2B2F212A2E20313526393D2E3A3E2F
404435474B3A494D3C383D292A2F1B2126121E210C222510252912252912292B152A2C16
26281221200B3A37245C5646645E526861576A615A6D645D6C635C655C575B524D584E4C
574F4C544F4B4E494348453E4A4740484840403F3A1D1C170706011716111C19141C1914
1C1815211D1A201F1D1C1B191A19171E1D1923241F21221C24251F292A222D2D2529291F
27271D28281C26261A24241821211526271927281A292A1C2B291C2C2A1E2E2C20333327
3C3E333F42394D4E4860615C878986B1B3B2C4C4C6BCBCBEA09EA38C899296909E918998
B0A8B5CBC3D0D4CCD7E1DCE3E5E0E4C2BEBD7C7974716E65808173868777807E716E6A5E
6C685C6E6A5F6C69606B686166656062615D5B5A567677728A8B856C6D6752524A63635B
6060584B4B436665607A79757E7D797D7D7B707070494B4A2628273337363E403F424441
2D2F2C1517124849448C8D877A7B755C5D574B4C463F403A32322A3131272E2B22232017
23201925201A29211E2A221F241C191F1714221B15352E263C352D453E34413B2F3D3729
4744354643343F3D30454539494B404849414446414146403F45413A433E343D3A343D3A
353B393D41404547464747473534322420211C1618201A1E22191E241E222D272B312D2E
2F2B2C31302E37363439383441423D4445403F413C32342F2527242325241E22231E2223
2223272021251C1B20201F25221F281F1C25221F2A26232E2723312A263425212F201C2A
272030332C3C3B34444740506B67767572835754652724372423352C2D3F272A3D282D40
2930432D34472F354B3F455B474F645D657A6E768B6D758A6D758A727A8F747C91747C91
767E93757D92777F94788095788095777F947880957A8297777F96747F95727C9774809A
747F9B727D9B6D7B986F7C9C6F7C9C6E7B9B727D9D717B9E6B789A6D7A9C6F7C9E6A7797
68779468789266768F65758C6172866374886374886271846271845E6D80606F825F6E81
5D6C815E6D825A6B7F5A6A815A6A81576780576882576B84526681536684536384536385
4D60804D60804D5E7C4D5E7A4D5C794D5B764E5A744D59734E58734D57704C56714A546D
4B556E4C566F47516A4A5269495166484F62434A5D454C5E
14140815130717150919170B1D190D1E1A0E211B0F231D0F231D0F2923153630223F392B
3F392B3E382A3C36283A34263731253731233A34263936253B3827383725393627434132
434134434134413F3344413843403946433C4946414B47444C4B4643423D34332E2A2A22
29261D2421182320171D1D111F1D112020142B2B213434283333273D3F31454837424534
484C3B4D523E494E3A353A2624291524291321240F232611262914232611282A15282A15
2628131C1E0921200E4A47366663526862526A62556C6256675D51645A4E5E544A5C5249
5B5148544B424D443D49423A4A463D403D3427241D19191112120A161510191611201C19
201C19201F1B201F1D21201E1E1D1B1E1D1922211D22211C23221D29261F2E292329251C
27241B28251C28251C23231924241A23251A22251A25291B2A2C1F2C2E212E3023313326
32342934352D4C4F48575954818380B8BAB9DDDDDFEBEAEFDBDAE0A7A4AD8E8A98908A98
A9A3AFD6D0DCD9D3DDD0CDD4BAB8BB9A999773726D74746A7A7A6E8081737E7C706E6C60
6C685D706C616B675E69645E66635E635F5C5955546968668685837574725F5B5A6A6665
6F6B6A5E5A596C68697573747A787976767864646647484A3133323F41404648454E504D
393B381F211C41423C73746C62625A4F4F474948434645403C3B3631302B29282323221D
22211D26221F2824212E292626211D1B1612211C163632293C382F39352A363428373528
3C3D2F3A3A2E37372D3D3F3445463E45464041423D3A3C39383D393A3F3B363A39353938
3537343C3E3B3E3F3A3F3E3A36322F2C2724221D1A1F1A17231E1B2A25222F2A27312E29
302F2A302F2A36353035342F3A3B353B3C373839343232302527261D1F1E1F2024222327
212227202126201F27201D2625222D24212C211F2C2E2C3935333E302E39302E392A2732
241E2C322C3A4B4553554E5E564F5F4A46573F3A4E322F442B293E2D2E422D2F442E3347
2C3346363D503D43593F455B575F726D758871798E73798F73798F747A90777D93787E94
767E93788095767E91788093788093777F92788093788093768193748192748096748096
737F9772809A707E99707E9B707E9B6F7C9C727D9D717B9E6F7C9E6F7E9F6C799B6B789A
66759667769566759264748E62748C617389607288617286617286607185617286607185
5F6E855E6D845B6B82586A82586A82576882536780536782536883526784506383506384
5060824F5F81505F804D5C7D4E5B7D4D5A7A4C5A774654714C57734C58724C57734B5771
4A567047536D47536D47536D444E67474F66464E63444C5F
17170D17170D17170D1A170E1B190D1D1B0E1F1B0F251F11241E10221C0E2C2417383023
3B33263C34273830233931243931243933253C36263E3B2A3E3B2A3F3C2B3C392A413D31
44423544423646413B49444045413E413D3C4743424E4A4952514F48474328272321201B
252219211E151F1D111E1C101A180C211F13322F2638362A40403446473947493B484B3A
474B3A4A4E3D4146322B301C2126122126101F220D21240F262916262916262715252616
222311212210201E0F3736245F5C4B6A6756686252676050645D4D6059495C54475C5449
5951465249404B443A48413939352C2C29201F1C15120F08120F0817140F1915121C1815
1A19151E1D1925242023221E1F1E1A21221C22231B24241C25251B29261D2C281F2B271C
26231A2A271E29261D23231B22231B21241B1E241822281C262C202C30222B2F212F3124
3032273032273B3C345F605AA2A39DC8C9C4D8D7D5E2E0E1E3E3E5E4E2E7C4C1C8BAB7BE
C2BFC6E6E3EAD6D4D9ABA9AC8F8D8E8988847877727070667270647573677C7A6E726E63
6C685D6E6A616D68626B666267625E5D5855575151706A6C847E807771736B626571686B
726C706E686C7770777B767D79747B716E756B6A705A5B604C4D514E4F51525453515350
4C4E4B41433E4B4C4663645C56564E49494148474244433E3F3E393D3C372A2925252420
2625212625212B27242C29242E2B2626231C23201938352C3D3A3139372B33312537372D
3A3A30383A2F3C3C343B3C363F3E39494A454C4B493B3B39323230383A37393937383836
37383336353135342F37342F3A3732282520211C18211E19221D1927241F2D2A2535322B
2F2F272C2D2530302833332B30312932332D2E2F2A2F302B2D2F2C222421212224242529
20212522212725222B2A273227242F24202E2523304848544F4F593E3E4837354034323D
302C3A332F3D4844524D49584541523A36473936493331463031463032472D32462E3548
2C3248333B50484E66545C73646C8170788D727A91747C93767E957880977A80987B8199
7C849B798498768195768193778294778393778393768292758292728292728194718095
707F94718097717F99717F9A73819C6E7C99717C9C717B9E6E7B9D6F7E9F6D7A9D6A779A
67769766759466759465749164748E64748D61718A6070876171885F6F866171885D6D84
5D6C835C6C835969825B6D85586983556982556680526681536782526583516484526283
4F5F804E5E7F515F824D5C7D4D5B7E4F5E7F4F5E7D4958774857744959734A5A74485872
46567043536D41516B43516C434F67434E64444C61424A5F
181911171810191A121C1C121C1C101F1D10242112252213251F0F231D0D231C0C2A2313
362F1F3831213932223831213C37243835223B38253E3D293F3E2C3F3E2C3E3C2D3E3C2F
44403549453C47423C4C47434743403F3E3C454140514D4C51504E42413D2A27201F1C13
1D1A111B190D1E1C101B190D18180C20201439372B3C3A2E45453945473A424437434538
4A4C3F36382A2629181F220F1E210E212411242513242513292A1A282919262719222315
2324162523162422153432255856496C6A5B6663545F5C4D5D5B4C59574A59574A575549
5553474B493D434037322F28221F181D1A13120F0A0D08040F0A0615100C16110E181411
1A191522231E26272225262022231B22251A23271921251725271927281A2A2B1D29271A
24241829291D28281E24261B20211923261D20261C262C20282E202930202E32232D3122
37392B3C3E30313325555549B3B1A5CFCCC3E0DCD3E7E4DDE5E4DFE9E8E4E0DCD9E5E1DE
DDD9D6BBB7B4A5A19E86827F7C79747D7A7378756E6F6C636E6A5F706C61726E65736C64
6D665E716A64716A646F6764635B59564D4E5A51527E75768D83847C717574696D786D73
7A6F777E727E7E73817E73837C768474707E7876837775807070786465695B5B5D5C5C5C
5C5C5A5E5E5C5A5B56595A5557585344453F393A353839343B3C3641423C31302B292823
2C2B262B2B232E2B242C2922302B25312D24302C233B372E3D3A313C393035322937342D
4B484145443F403D38403F3B45413E51504C524E4D3938362F2E2A37383338373235342F
33322D2E2D282F2B28322E2B33302B26252024211C24231E26231E24211C2A2722322F2A
2E2E262C2C242B2C242C2D252D2E262F30282F30282F30282E2F27292A24252621222220
2323232525272B292E2E29302D2A3325222D25222D4D4B56504E5B42404D38364342404D
4543513A384633313F3836442F2E3E2F2E3E2F30422F30422D304330324734394D373D53
3840573C475D5C637D6C768F6D77926F7994717B9677819C767F9C79829F79839E79839E
76829A77839B7581977683967685987484947383927282917182926F8090708193728397
72839771819872829972829B72809B717F9C727D9B727D9D6D7A9C6D7A9C6C799C6C799C
68759768759569769667759264728D63718C62708B62708A62708A606E88606E885E6C86
5C6C855D6D8659698359698359698256688055657E56678154658154658152638151607F
5261804F5E7D505F804F5E7D4E5D7E4D5E7C4B5C7A4B5C7A465A75465A75475B76455974
45597444587342536F42536D435269445066414C6040485D
1A1D16161910191B101C1E111E201220211123221024231124210E211E0B211C0925200D
302B1836311E3630203832223A37243B38253534203938263A39273B392A39372A373529
3B372E443F394B464248454042413D41403C4A46434B4A464E4D4832322A232017211F13
201E121E1C0F2220131D1E101E1F1127281A3A382B36372937372B383A2D3F4134383A2D
2A2C1F1E20121B1E0D202312232613262916292A1A252616242515272818252618242418
252519212115211F133B3B2F6462556D6E606361545B5B4F58584C57574B56564C535349
4F4F4544443A2C2C2412120A10100816160E0F0A060A05010F0A06130E0A140F0B15100C
211E1924231E22211C22231B22241924281A242819212516232716272A19292A1C28291B
24251723231727291E26281D262920272A212A2D242D33272A3022292F212D31222C2E20
3C3E305354464A4B3D4F4D41918D82CCC8BFDCD5CDE1DAD4DBD8D1D9D6CFDCD7D1D9D4CE
B6B3AC928F887D787278736D76736A78756C79756C7571686F6B62706961726B63726B65
6F6661726964756B69756B6A605655544A496E64637F75747E72727B6F6F82767A82757C
82757E8376807B6D7C7C6F808C8192938A9B9B94A495919F928F9A89888E7371766B696A
767475737270605F5D5B5A5651504C403F3B35343032312C3736313D3D3534342C2F2F27
312E272F2C232F2C23322E232F2B223430253A362B433F34454239403D34403B3538332D
55504C5D5A554E4A47514D4A544F4C524E4B4C46463A363537333233322E33322D32312C
2F2E292C2B272C28252F2B282A292528272323221E2625212625232322202A26272B2728
2925242B2724272622292824292824292A242B2C262D2E282D2E282A2B25282924262722
2424222828282E2C2F312F342F2C332B283127242D3E3C47474552464451413F4D535260
4C4B592D2C3C2928382E303F2D2F3E2A2D3E2F32432D32452B304332374B3A40563F475E
4B556E5B657E6B7590757F9A727D9976819D77809D78819E7984A27883A17984A275839E
7A88A377859F74839A75869A75869A738496748595748595738496708193718296738498
73839A71819875849B75839D73819C72809B737E9C75809E6F7C9C6E7B9D6D7A9C6D7A9C
6A779968759569779468769367728E63718C646F8B63718C62708B616F8A5F6F895D6D87
5D6D875A6B855B6C865A6A8459698358688158688156667F55657F55657F54638052617E
53617E505F7E515E7E4F5E7D51607F4E5D7C485977475876455876455876475A78435674
43567443577245567241516B425168445066434B603F475C
171D13171D11181C0E1C200F1F241020230E20230E22240F22210C21200B211F0A211F0A
26240F33301D35322133301F3835243A392736352338362738362739372A3C382D3A362D
3B372E413C3646433E46433E4645404D4C474D4D4552524A4E4E443032252323171C1D0F
1E1F0F20211120210F1E1F0D23251031331E343523323321393A2A3F40303C3E30323426
1B1F101A1E0F212514252817272A17282B182A2D1A232613262916252817242515242517
28291B1F21132021134A4C3E69695D6163565B5B4F57594E55574C56584D5758504B4C44
3D3E3834352F1B1A150D0C0714140C17170D140F090E09031009031811091A130B1F1810
27221C28231D25221B2323192325182226172024152024132226152428172C2E20282A1C
23251823251827291E2A2B232B2C242C2D253031292E31282B2E23292C212D2E26373830
47473F605D566E69635E595578706DB6AEACCFC5C4E3DBD9E7DFDDD1CCC8B8B3AFA7A29E
85827B827F7877746D716E67726F6674716875706A78716B746D67716A64756C67786E6C
736866786D6B7D7171867A7A685C5C5E5452796F6D8076747D746F8077728A7E7E897D7F
8D7E838B7C838A7A85948491AC9EADB2A5B6BDB2C2B9B1BEB4ACB7B8B1B9AEA9AF908C8D
7A7476706A6A625D5A544F4B4845403C39343936313B38333C39323A372E38352C353327
322E23312D22322E23302C203430253B372C433F3448443B4C483F4B473E4C453D464239
57524C5C57535954515E59565B5350413C39382F303C36363B3535332F2E2F2B2A2F2B28
2D2C282C2B292D2C2A2C2B29282826282828262425262427282329252027261E29271F2A
2B212A2E242D2B242C2C252D2A252B27252A2B292C302E312D2D2D2525252828282A2A2A
292B2A2D2D2D30303033333531313329282D2E2D353B3A4243414C4F4F5B545361535260
41405028293B2E2F412F32432E31422C31442E33462D3447333A4D40485B454D62556076
667089717B96737E9A737E9A747F9B78839F7782A07984A27A85A17782A07583A07785A2
7886A176869F76869D76879B75869A72849877889C76879B708097738299738299738299
75839D77859F75819B75809C76819D75809C737E9A747F9D6F7D9A6D7A9A6D7A9A6D7A9A
6A799868779467769366769066748F62728C63718E637291627190606F8E5C6D8B5A6D8B
586B89576A88596C8A576884596A8458698356667F53637C55637D57657F53617C54627D
55607E515F7C525D7B515F7C515E7E505D7D4D5878495676475675485778485577475476
44537446557445527243516E44506A434D66454B6140475A
161C10161C0E171B0C1D21102126121F240E20230E1F220D1F220D21230E20220D22210D
1F1E0A262511302D1C322F1E3330213431223431223733273834293733283F3830433C36
413A34403835403B37443F3B4845404F4C474F4F4751514757574B3D3E302C2D1F2C2D1F
27281823241221240F22251026281231331D34331F2E2D1931301E363523393A2C353628
292B1D26281A282A1C292C1B292C1B272A192629182A2D1A2B2E1D272A19252616242515
27291B26281A2E3023494B3E5A5C515B5D52595A52575850585953595A5450514C3E3F3A
2F302B292A251B1A1616151019190F18180E1B170E151108130C041710061D160C211A10
2821192B271E27241B2424182426182426182024131B1F0E1E2211212514232517252719
2525192325182C2C222D2E262F30282D2E262B2D222B2D222C2E232B2D223234293A3A32
535049807B77ABA3A1958D8B766D6EA39A9BCEC5C8DAD1D4D4CBCCB5B0AD9F9A977B7673
73706B7B787178756E716E67726F68737069746F6B736E6A776F6C78706D7C72717C7271
7E7475867C7D8B7F81918587887E7F6F65647C74727E7673847D7789827C8B817F8E8482
9B91909A8E9096878C9B8C93BCACB6C5B8C2CEC1CBCFC3CDCEC2CCCDC3CBC4BBC0A69DA0
776E6F655D5B655D5A57524E47423C302B2535302A38352E39362D38362A353327353327
2E2A1F2E2A1F2F2B20373328423E33433F344541385B574E605C535D59505D59505D5950
5E5953615C56645C5A635B594A423F3A35323832323C36363C3638332F30312D2C32312F
3332303230312C2C2C2B2B2D29292B2A2A2C28272C25222925222B231D29211B29231B2A
28202D3126342F24322A222F26202A28222C26232A2C29302D2B302A2A2C2B2A2F2B2B2D
37383A41424440404238383A2F2E3329282D302F354140483D3D47464650494955393B48
282A39292C3D2C2F402B30432C31442E334631384B2F3649373F524D55685F677C727A91
767D97757C9876809B79829F79829F7B84A17982A17984A07D86A37984A07883A17684A1
7886A17886A17987A179889F76869D73839A76859C76849E75839D76849F7984A077829E
7785A076849F747F9B737E9A75809C717F9A6E7C976E7C976D7B966B79946A7893697792
68779467779168789263738D63738D61718B61708D61708F606F8E5F6E8D5B6C8A5A6B89
596C8C576A885869875768845A6A8457678157678055637D53617B54627C56627C55607C
55607E525D7B545F7D525D7B515C7C505B7B4F58794C57774A54774B55784C567A485276
46507349537648537345506E454E6B464D6743495F41485B
161E0F171F10191F111B2212212816232A182125142125141F2312212413222514242515
2122121F1D0E2522132B2819332D21332D213630243A31283A312A3D322E403231463B39
463B394238374036354C42414F47444D4844504D484F4C45524F464E4E4246463A3C3E30
3A3B2B2F301E282A152C2E1831331D34331E2C29162B28152C2918312E1D302C20332F23
312F22312F222C2A1D2A281B2425172122142627193435253D3F313537292C2D1F2C2D1F
2A2C1E303225404036515149595A545859535658535557545759585B5D5C4D4F4C353734
21231E22231D1C1B1615150D18180E1B1B0F1E1A0F1C180D1612071B170C1E1A0F211D12
211F1328281C2525192022152123152125141E2211191D0C1C200F212413262719242517
2523172424182C29202E2E243333292E2E2427271B2D2E203132222D2E1E303121373528
444138847F79B9B1AED0C8C6B5ACADA49B9CBBB5B7C9C3C5B9B3B59690907E787877726F
73706B71706B74716C716E696F6C67706C69716D6C736F6E7872747F797B847E80898085
8A80889A9099AEA4ADA89EA6938C93837E82857F818884838783808D8C889A9792989590
A29F9AA39E9A948C89867C7B918585ACA0A2CDBEC3D4C5CABBACB1AFA3A7B1A5A98C8283
736A6B7B7673746F6B49463F3E3B3236332A39372B3634283836293A3B2D353529343428
2E2C202B281F2D2A2138352C4C4940514E45504C435F5A54746F69706B656B666068635D
67625C65605A6A626058504E423D3A3B37343D39383C38373B37363332302D2C2A30302E
3232323131312E2E302A292E28292D27282D222328222129211F2A201C2A221E2C24202E
24202E2A24302C263227212B26202A26232C2B252F2C29302B282F2A282D2F2C333B3A40
4D4E53494A4F4142473D3E433031362F30353F3F4742424A3C3C443636402C2E3A292B38
282C38292F3D2C32422A31412C33452C3345373E513F4659454C5F5C6376686D83767A93
797D96797D987A7F9C7E83A07D84A07F86A27E85A27E87A47E85A27C86A17B84A17C87A3
7984A07A85A17984A07A86A079859F78849E77839D78839F76849F74829F76819F7883A1
7684A174829F73819E72829C70809A7080996F7F986D7B956D7B956B7993687690697791
6B799467758F68769066748E63738C61718B61718B61708D606E8B606E8B5D6B885A6885
5B68885B68885A67875866835C6A8559678156647E55637D55637D53637C52607B505E79
505E7B515F7C505D7D4F5C7C505D7D4C59794E587B4B55784B53784B53784A52774B5378
474F73485074475071464F6E464F6C444E67454D62424A5D
1C22181E241A1C2218252B212B31252B31252B2E23292C2124271C24271C24261B23251A
252519242418221E13251F1331291E372F243A30273A30273F322C40312E453633473835
4537364335323F3432463B3749403B4F4842504B45504B454B473E4C483F4C4A3E48483C
4445374142323635232F301E302F1D31301E282514241E0E2B25152D27192E281A342E20
333021312E1F312D212C281C25231622231523241643443656584B5456494242363F3F33
3C3E313A3C3152524A5A59545958545454525656565354565455575E605F505251373936
262823282B241F1F1717170D18180C1F1F131F1D111F1D101B190D1D1B0F211F13232115
1E1E122325182426191F2114191D0E1D21101E2211191D0C161A09212413232414232114
24221529271B2A281C312F232E2E242F2F232C2D1F2B2C1C3132202C2D1B42412D4F4E3C
3531257D766CB0A9A1CEC5C0D4CAC8C4BCBAA6A0A2A9A3A5928C8E7B75777B7575736F6E
6C6B67706F6A74716C726F6A716E69716D6A75716E777372817D7E8E8A8B9A9498A39CA3
A29AA5B5ADBADAD2DFDAD2DDAAA4AE88858E908D94959398939395959593B3B2AEC4C3BE
CDCDC5B8B5AE78746B645D558A817A978C88B2A4A3A79999A294949387878C80807C7271
79716F79747069665F53504923231927271B4240344142343A3B2D3A3B2D3A3A2E343428
30302635322935322B39362F5450475C584F5A554F6E696378736D706C6368655E656259
645F5965605A635E5A514C493935323B37343C3B393433312E2D2B302E2F2C2C2C2D2D2D
2E2E2E27272928282A2E2D32292A2E28292E1E1F241E1D25201F271D1B2622202B211F2A
25232E27262E2B28312B262D201D2426232A2E2930312C33302D3429262D36333A504D54
6A697156555D37354035353F3C3C4645454F52525C4949533838422E313A2A2C38272B37
272D39292F3D2B32422E354531384A333A4C3F46594D54675B627570778A757A907E8097
7B7D967B7F987E829D7F84A17F84A17F84A18087A48289A68087A47F86A37D86A37C85A2
7D86A57C85A47C85A47C85A47B84A37C85A27982A17B84A37984A27684A17782A27883A3
7683A37281A072819E74849E6F809A6E80986E7E956E7E956D7C936D7B956B7993687691
69779266769066748F67779165758F63738D61708D61708D616F8A5F6D88606B895D6886
5C67855C67855C67855B66845B66825B678159657F55637D55637E54647E56647F505E7B
4F5E7D4E5D7C4F5E7F4F5E7F4C597B4C597B4D577B4B55794B53784D52784C51774C5177
485074475071475071454E6B49506C474F66434B5E414A5B
1E201D2224212325222B2D2A3034333034332F3332303433282D29242925272924242621
20211B22221A242017251E142B2318342A203C2F263F312842342B44332B45342C46352D
47362F43352C42352D41372D443A30453C334B42394E453E4B423B4E453E4E473F4A463D
4D494043403738342B2F2C232A261B282419231F13221E122721152A24162E281A2F2919
312B1B322C1C322C1C2A27162826172E2C1D29271A3C3C305F6156686A5F5F60585B5C54
57585051524A5F5E595D5C585E5D5B5554525250535252545454565C5C5C595957353631
2528212B2E2726261E2121172323172323172424181E1E121B1B111A1A10202217222419
2023182124192024161D2113191D0E1A1E0F1A1D0C171A09191C09222512272816242515
262717292A1A2C2D1F2C2D1F2A2A1E2C2D1F2A2D1C2F322133362330331E3537216A6A52
6F6A547B74619C9585C3B9AFD6CCC3C8BDB991878683797A81787B7D77797A7474716D6C
6B6A666F6E696F6E696E6E666E6E6674716A77746D726D69827D7AAAA4A4C4BBBEC2B8C0
C2B8C3D0C5D3DED3E1CFC7D6A19BA9817D8BAAA6B4B3B1BCBFBEC4B6B7B9C5C5C3DDDED9
DFDED9B4B1A8716D626F685E948D839C938A998F86887D777E736D7E756E8077727B746E
7B767078736D504D46413E372929212728203E3E3651514748483E3D3F323D3D333B3B31
3431283B372E443F3948433D534C4658514B635C547A736B77736A726E636662595D594E
625F566562595C595233302B312D2A3D3936413D3C332F2E2826272B292C2C2A2D2D2B2E
2B2B2D2525272624272A2A2C2B2C2E27282C2120251F1D22222025211F24232126252328
2221262524292B292E2B292E2624292B292E35303639343B363138322D343A343E5F5963
7B75815A5762322E3C3533414A48565C5A686766765958683B3D4A272936282A392A2D3C
2A303E2A31412B3242333A4C363E513F475A52586E646A80757B917D839981859E7F839C
7E829B7C829A7F859F7F859F8086A08289A37F86A38288A87D86A57E87A67D86A57B84A3
7D88A87C87A77B84A57C85A67883A37B86A47D86A77C85A47B86A47D88A67A85A37883A1
74829F73829F72819E6F809A6F809A6C7E966D7F976E80986E7E976C7C966A7996697897
68779666769765749567779864749560709162739162719062708D606E89626D895D6884
5C65825D66835D68845B668258647E5A66805B668256647F53617E53627F546382526182
4D5D7F4D5D7F4C5C804C5C804C5A814B59804E5A804D567D4B53784B50764A52774A5276
494F7149506D484F6C474E6A484E68484E64434A5C434A5A
242424282A292E302F34363536373935393A33373835393A333738292D2C25272421231E
20211B2323192521162822162C241733291D3A2E223F312444342745352848362A463629
47372A47392E45372C43372B44382C40362C4339304A40374E433D4D443D4B443C484139
47423C36332C2A251F28251E231F16201C11242015221E122421122923152B25152C2714
2C27142E2916332E1B322F1C2E2D1B3635233C3A2D3F3D3155554B6B6C64696A646A6B66
696A6568696465646262615F5E5D5B5856575250535151535555555B5B59585954262922
171A1123261D26281D24261928281C26281B25271A2022171A1C11191B101C1F141E2116
1B211520261A1E22141E2214191F111B1F101A1E0F161A091D200D222512272A152A2C17
2B2D1830311F3132222F30202B2C1C2B2C1C2C2F1C31342135382535382331331D616149
95937C97927C958E7CAFA898B9AFA5A1978E7F74707F75737E74737C747277726F74716C
716E6971716972726871716773736772726675736789857C928D87B8B3AFE3DADBE2D9DE
B8AEB6B2A8B3B4AAB5B0A5B39991A0908A98BFB9C7CBC8D3C8C5CECAC9CEC4C2C3B6B5B3
B6B5B08F8C856B675E8881778E877D827B717F766D7B7269746B62786F687E776F837C74
7A756F5D5A5343403942423A3E3D3834352F34342C4A4A42585A4F47493E404036423F36
36332A3E3A314B473E4A463D4C453D54504759524A6B675C6A665B666457635F545F5D50
6765596B695D69695F282820201D183834313C38373632332D2B2E2E2C2F302E332D2D2F
2727292323252523262B2B2B2C2C2E2A2A2A262425272526262425252324282425282327
2523262624272B292C2D2B2E2F2D32332E3439343A3D363E39323A3F3742423A47564E5B
655F6B5E5866474354433F50524F606867777170826B6C7E4C4D5F2E31423033442F3545
2C334331384832394B343B4D3941544F576A696F85777D937A80967B819980849D8286A1
8187A17E849E8086A08187A17F86A08087A38187A77F85A77E87A87E87A87E87A87F88A9
7E89A97D88A87D86A77C87A77A85A37D88A67B86A47B86A47B86A47886A17B86A47A88A5
7584A17485A170819D6D7E9A6D7E9A6D7E986C7D976D7E986F7E9B6C7B9A6A799A69779A
6674996474986271986373976272965F72935F6F91617192606F8E616F8C5F6D8A5D6B86
5B66825B66825C6A855B698456647F56647F576582576484556483556483536283526083
4F5F834F5F834C5B824B5A814C59834B59804E5A824A567C4D577B4B53784A52774B5377
485170484F6C474E6A474D67464C64464D60444B5D434A5A
31302E3434323535333A3A383B3B39393B383B3D3C3D3F3C3F413E3C3E39252A231D2017
2123162324162523142822122922102E2613352A183C311F4134234235244A3A2B483829
49392A493B2E4B3D3245392D43362D41372D42382F443B34443B34423B333E3A313E3B32
312E252020162320172121152220132321122523142423112726122926132C29162A2813
27251028261132301B3836213B3A263E3D2B49473A48463A4E4E445C5B566867636B6A68
686866666666676568666467605E5F5A5A5A5151514E4E4C50514C56595252554C24271C
191D0F232719242819232718252719242819202416191D0F14170C14170C1B1E131A1D12
1C1F141E21162124191E24161A22132029181D2414141B09222713282D172D311A30341D
2C30192D301B30321D30321D2A2C162D2F192E301B373924373826353624393A28636452
7877658B8877A19B8BA49E8E9F978A8E867B81786F7C736A7A716A79726A79726A77736A
76736A7472667172647374667576667374626B695A979586CAC8BBD6D4C8E2DDD7D1CCC9
999393999395A298A0A69CA5A298A1ABA1ACC4BAC5C8C0CBB2ABB3A8A1A89B969A8D898A
8C88857F7A767E77718B847E837C74766F67776E67786F68756C6577706A827B75857E78
67625C35322B39362F4B4B434A4A423E3E363E3E3642423A4E4E444343393735293B392D
39372B424034514F434D4B3F4A463B514F425450445856495C5A4D5C5D4D626053666757
6F706268695B4C49402F2C2533302B413D3A3E3A393E3A3B353336313035313133323234
2626282325242626262B2B292C2C2C2D2C2A2B2A282A29272827252726242B27262A2627
2B27282D282C322D33332E343732393732393D333C4036413E3341493E4E5F5465675C6D
514859534C5C625B6D5D586C5754676362746D6B80616276494E61333A4C2C334530394A
313A4B353E4F3942533C4556485162687182777E917B81977D859A7B839A8187A18287A4
8186A38287A48186A38186A48188A57F85A58086A88086A88086A88187A98187A77E87A6
7E89A77F8AA87C87A57984A07B87A17A88A27785A07987A27987A276869F7886A17686A0
72869F7286A172839F6E7F9D6D7D9E6C7C9D6D7C9D6D7C9D6E7B9E6E7B9E6A769C69759D
68749E66739D67749E64739C6170996170976070946171936070915E6D8E5C6B8A5D6C89
5B6C88596A865B6A87596885586784556481566584556485566586526283546285536184
515F844E5C834D5B824D5B824D59814C58804B598049577C4856794A5779495678485373
47527046516D444E69464E65444C61454D60424B5C414A5B
37363235342F3536313A3B353C3D373B3C3640413C44454044454041443D35382F2A2D22
2A2C1E2B2C1C2A29172A27142A25112D2711312B1539311C3E331F453A28483B2A493C2C
4A3D2D4A3C2F483A2F44362D45382F453B32433A31423B333F382E38362A31312525271A
2022151E2013232517252719242716292A18292B16292B162928142827132A291524230E
24230E30321C3E3D283F3E2A3E3D294546344E4C3F4B493D4E4B4256564E625E5B62615F
66656364626362606365636662626259595751514F4E4F4A4E514A53564D53564B33362B
1F23151F23152226172428192226171C20121D2015171A1114170E14170E1A1B131D1E16
20211922251A25271C1F22172026182932211F26161C2311262B17272C1632361F30341B
272B14292D1632341E33351F2E30182E301A2F311B393B263A3B2937382847483A716F63
73716579776B827E728B877BB0AA9EA39D9180786D776F62776F627A72657C74677C7467
7A746674716075726174735F73725E6E6D59797665B8B5A4E7E3D7EFEBE0EFEAE4A19C99
847B7CA59C9FA89FA4A59BA3ABA0A8D6CAD4B9ADB7A99EA6968B918C83888E85888A8182
8B83808A807E7C736E7D746F817871887F78857C777C736E776E697A736D88817B6C655F
48433D39362F46433C48484044443A41413746463E404036413E3539372B3533273E3C30
39352A48463A5854484F4D404B493C4D4B3E4B493C5152445A5B4D57594B6465576F7062
74756757574B3A372E333029413D3A46423F433F3E3D3B3C333134313035353537363638
2626262626262828262B2B292D2C2A2928242928242C2B272928242928242A26232C2827
2E2A2B312C3037323837323938333A39323A3C323D392F3A4439476E63737366785D5263
42394A615A6A6F687A615C705C596C6564766263774346592F34482E36493B4356434B5E
374353333F4F40495A5861726E7689838B9E82889E8288A08389A38188A28388A58489A7
858AA88388A68287A58287A78187A77F85A78187A98086A88187A98288AA8389A98086A6
818AA77E89A57E89A57B87A17A89A079889F7A89A07A8AA17989A276869F7787A073849E
71859E7286A17184A26F7FA06E7E9F6D7D9E6B799C6C7A9D6D7A9D6D799F6D769F68749C
69759F68749E67749E65729C66749B606F966070945D6D8F5E6E905C6F8F5D6D8E5C6F8D
5A6D8B586B89586987576886556684536482546384566586536385516183546285536184
4F5D825260854E5C814F5D824D5B804D5B7E4B597C49597B465677465775495877465572
43536D45556E45516B424E66414C60444F6140485B3F4859
3A3B353738303837323A3A323E3E343E3E3642413C4847424848404343393F4136414336
36382A3033222D2E1C2527122527112827122B29142F2A16352E1B3F3724463A2A46382B
483A2F473930493B32493A33483B33453B32463D34413A303331242F30222B2D1F242819
232716212514252A16292E1A292E182B301A2B2E19272A15232510232412252614202310
272A173E412C42442F3F422D434631484B384E4F3F504E41504E415451485954505F5B58
625E5B63626062615F62615F5B5C5753544E51524C51524A4D4E4655574C52554A313429
1F221720221724251D22231B21221A1A1B15191B161416131515131818161D1C18262521
23221D28292125251D23251A282C1E272B1C1E22131F2312282B182B2E192F331C292B15
21230B292B1330341B2F331A2E301A30321C2F311C393A28403E31413F33413E3577726C
898481706B68736B6899928CB1AAA2938C82726A5D756E5E7B72617B73607D72607D7260
7A725F78725C79735D7A745E746E586C6552A39A89D4CABED0C7BEF3EAE5D4CACB8E858A
A79CA4B2A8B1B0A6AFBCB2BBE8DCE6E5D9E38E828C92878D988D918C80808F84828A7F7B
958882786B6362554D877A72A89B93A79A94887A77766B677F7470867D78736967554D4A
46413B44413A45423944413843413545433749463D4340373C382F3733283D392E3E3A2E
403A2E4B473B4B45394A463A504E42504E424B4B3F4C4E415A5C4F676A5F6B6D626F7068
6A6A624645403B373446423F4E4A4B4C48494745483F3D403B393C363437373538333134
2927282927282C2B292C2B292D2C282726222524202827222728222A2B252B2A252E2D29
3635333735383C373D3B363D3B363D39333D372F3A443A456257656B606E5548595F5464
615968655D6C655C6F675F746562755E5C7148495E2B2D4229304341495C545C6F475264
3A45573F4A5C5D65787880937E849A7F859D7F839E8085A28186A48388A6878CAA868BAB
8389A9848AAA848AAA848AAA8288A8848AAA8388A88488AB8589AC8488AB8389A98087A4
828CA77F89A27D89A17B879D79889D798A9E798A9E7A8B9F7989A076889E7586A07384A0
7182A06F82A07083A37080A16E7E9F6F7E9D6C7B9C6D7C9D6D7C9D6A799A687598677497
6875986573966773996674996472956270936171935D6D8E5E71915B708F5B6E8E5B708F
576C8B586D8C566989566989556888536686546486546486526284536385556586506081
5060814F5F80505F7E4E5D7C4E5D7C4A5B79485977465977465A75435772435772435770
42566E41556D43536C405067404F64404D603E495B41495C
41403B3B3B333C39343F3C3543403944413A47443F4E4B464D4A4343403946463C4D4F42
484A3D404435282B1A1F2312262916272A152527122827132C2916342F1C3E3727453B2F
44382C45382F473A324C3F374A4037382F26332C22312D222D2B1E313222262918222615
242817222917242C172C341F29311A2C311B2D321C1E210C222512292C19282B18242714
333824424733434633454833494C374A4D384E4F3D5351425653445753475652495B5650
5E5B54615E59605F5A61605B58595353544E52534D4F504A50514952534B4C4F462A2D24
11140D18191321221C1E1F1A18191415161114141210100E11110F1D1C1A24231F292522
24231E2E2E262A2A2227271D28281C26281A202214202312292C1B2C2D1B30311F292B16
2325102C2E192E301B2F321D2E311E3235222F30203536283F3F3347443B48433D7F7A76
817C796F67657169668A837D867F77787266756E5E7C75637C74617B735E7E725C7F735D
7D725C7E735F7F74607E76617A725F645B4A9F9387B2A59DAFA19ED4C8CAAFA4AC8E828C
B4A8B4BFB5C0DED6E1F1EAF2F9EFF8BDB2BA776C72857A7E8F83838C817D92857F7F726A
7C6F664E413856483F8F8279A2958D92857D6D5F5C7A6F6B887D798076744F4544473F3D
4A474249463F434039403D34434135464438444138423E35413D32403C31433D313E382C
3F392D423C30403A2E49453A5351455350474E4E4651524A6A6B636F726972736E797A75
61605E3D3C3A4541404F4B4C524D51433E423D383E413F443E393D39373A373538312F32
2C2A2D2E2C2D2F2D2E2A2A2829292722231E21221D262721292A242E2F2931322D32312F
383639413F44433E4538323C322C38342E3A49414E58505D574C5A4F44525B4F5D726775
6C6471675F6E6E65766F687A524F6239374C38394E303247383F52565E715F6A7E414C60
465165626D81788399838BA28087A1838AA68287A58489A78389A9858BAB878CAC868CAC
848AAA858BAB868CAC848BA88389A9858BAB8489A9858AAA868BAB848AAA8389A98089A6
818BA67F8BA57F8BA37C8BA27A8B9F7A8B9F7989A07A8AA176889E75879F7586A07586A4
7182A07181A27282A36F809E707F9E6F7E9D6C7B9A6B7A996C7B9A6A7998697897677695
6574956675966776976574956473946272936171926073935E7191586D8C596D8E5A6E8F
586C8D586C8D576A8B536687546788536687546486536384526283526283526381516280
51627E4F607C4F5E7B4D5D774A5B754A5B75485C75455972445A7242587042587041576F
40566D40546C3F516940526A3F4F663F4E63414C603F4A5C
45403D3D3834403836493F3E4A42404B43414E45464D47474C48454845404B4A45606159
666960575D514144392A302225291A272B1C262A19282B1A2B2C1A302F1D3532233E3B2C
403A2C3E382A453D324B43383D352A272115241D132922182B271B2E2C1F282619393A2C
2A2C1E232718292D1E2A2E1F2D3120262B172328141D220E2B301A30351F30351F2D321C
35382341442F4548334B4E3950543D4D4F3951503C52513F5554425756445956475D594D
5C5A4E5A574E5E5E545F5F5757585057585252534E50514C5455505657523D3F3C181A17
090B081214111A1A18191A15181A1513140F10110C0E0D0915140F1E1D1825241F26261E
2929212F2F27312E2724241C2121172525192424182A2A1E2D2D212F2D203533262E2C1F
2D2B1E30302430302431332834362934382A34362935372A393B3042423859564D75706A
77706A736A65766D66776E657870657870637D74637E76637B735E7B735E7E715E7C6F5C
7A6D5A796E5C796E5C7E7262796D5F60534A9788839A8C8B938487AEA1A8988C98998D9B
C7BCCCE0D8E5F0E8F3FFF9FFEAE4E8938A8D756D6B8A827F847B76827970746A6053493F
52483C51473B55483F60564C62584F6359506F64608B827D857D7A726D6A4C4744494542
4C484545443F4645404C4D454D4F4446483D46463C46433A4745394442353D392D393529
3A362B3C382D39352A4F4B42615E57625F585A59546665607A79756E6F6A747273868485
716F70464243433D3F4D474B4742463732363530363B363C39333737323638363B2D2B30
26252A2A292E2B2A2F292A2C2426251E201D20221F292B282F312E343635333436353439
39383E403F47413E492F2B392B27363B37465750605953614E4655544C59665C676D636E
746C7979717E6A6472514D5C413E4F3B3A4C3B3C5032374B40475A5B63785A657B465167
66728A7F8BA5838EAA838EAA818CA8818CA8848DAC848DAC838CA9848DAA878EAB878EAB
838AA7828BA8858CA9858CA8838CA9848DAA838AA7838AA7848BA8828BAA838CAB828BAA
808BA77F8DA87E8CA77D8DA77C8CA67C8CA67A89A67887A47687A174859F73829F7281A0
7281A071809F71809F6F7E9B71809D6F7E9B6A7B976B7C986A7B976A7B976B7C98667793
6475936576946677955E718F6174926073936073935F72935C6F90586B8C586A8E586A8E
586A8E586A8E58688C58688A5467885366865366865164825266814E627D52637D51627C
4F607A4F607A4E5F794B5D754A5C744A5C74465A72465A7344587143577042566F41556E
40546F41557041526C41536B4050694251683D4C613E4B5E
534A4B3E36343F35344F454453494A5047485047484E48484B474449484454534F71726D
75787163695F555A53383E3422281C232719282C1E2C2E202F30222E2F1F2E2C1D383627
413E2D3C39283F392B413B2D2E281A110E00191307171307211E0F353324403E313E3C2F
27291B26281B282C1E292D1E2428191C200F1C200F252918363B27393E2A393C273C3F2A
454634484937494A384E503B4E503A504F3A52513D53523E53523E5756425C59485C5B49
5C5A4B5B594C5A5A4E5A5A5058595154554F52534E5252505A5A585959573737370D0F0E
101211191B1A1A1C191B1C171B1D181518110F100A0D0E061214091A1C1122241923251A
282A1F2F31263030281E1E161D1D1323251A27271F2C2C222C2C22312E25322F26322F26
3330272D2A2332312C34332E383931383B323A3D323A3C3136382D48483C626054736F64
777066746B62766E63766E637B73667A73637D76637B755F78725C79715C7A6F5B756A56
756A56746957736856766D5C796D61776A62998B889D8F8E9D8E919B8E957A6E7A9F94A2
C5BDCCDFD7E4E1DBE5EAE5EBC7C1C38C868688807D756E68534A4351483F463C333B3127
42382E463C32433930443A314B403A5D544D7A716C847A78776F6C6F67645B5653524D49
514E494E4D4855544F4E4F473F413642443946463C49493F4F4D414240342C281D363227
36322738342B413D345E59536D6A65686560696562706F6B7571706D6B6C979296A19CA0
777276383337403B3F4944483934382D2B2E2B262C302B313732363432353231362B2A30
28292E292A2E282C2F2327281F23221D23212026242F3332363A3B38393B38393E3A3A42
3838423D3B483432402B29373A3647423E4F4F4B5C5C55655953615E58646C646F736B76
7C7680706A7657545F4D4B58383745373948393C4F363B4E3E4659455062545F7568748C
7E8AA27E8AA47E89A57E8CA9808EA9818FAA8290AB8591AB838FA98490AA8690AB8791AC
858FAA848EA9838DA8848EA98791AC8490AA858EAB818AA7828DAB838EAC8590B0828DAD
7F8CAC7D8CAB7D8CAB7D8CAB7B8AA97B8AA97A89A87887A67687A57485A37685A47483A2
71809F70819F71829E6E7F9B6E7F9B6F809C6C7D99697D98697D96697D96687C95667A93
6579946377926175906073916075926075926275955F72935B6E8F5A6D8E5B6E8F576A8B
576A8B576A8B56668858688A5467875265835265835266815166814D637B4D617A4F637B
4D61794C60784C6078475B73455972455971475B74465A7344587143577242536F435470
44557341527042516E41506D3F4D683E4C663C48603D495F
666062433A3B473F3D554D4B58504E504B48504B48524E4B4F4E4A5455506D6E69747570
71736E6F726B6769645457503E41382F31263032273333273132243230232926172F2C1B
37362235342035331E2B29141E1B08171602221F0E1E1D0B32311F40412F3A3B2B323524
25281725291A2024151E22131A1E0F1B1F112B2F21363A2C4042344547394748384C4A3B
514F42514F42504E3F5352404E4D39514E3B54513E54513E52513D555440565543595846
5B594A55564858584C5B5B5158585051504B51504C5453515A58595C5A5B4846491A1A1C
191B1A2224231D1F1C1B1D181B1E17171A111013080F1305141809171B0C1E221424281A
272B1D2D31232B2E2320231822251C282B222A2B252D2E282D2E282F2F27302F2A34332E
32312C2E2D282C2B262F2E2935362E3839313C3E333E3E343B392D5553466B675B767266
756F61756F6177706079726279746178735F7B76607A765D77735A767259746E56706851
6E68506C664E706A54746D5A7A71627D7369958A84978E89968C8B8980837F757DB1AAB2
C8C0CBE0DAE4DAD5DCC7C2C8B8B3B7979392746F6C4F4744372D2B352C27352A26352A24
3A2D273A2D273C2F29392E28433834605553766B697469677167656B625D645A58645B56
5E574F5E5A51605C534A473E403D3443433747473D5151474B4B4137372D302D243A372E
353229403D3659564F66635E746F6B736E6B6E69666C68656D6767837F80A59FA389848A
544F53322D31443F434745482D2D2F1B1B1D20202228282A2D2E303031332B2F32292D30
282D30272D2D262C2C212A27202926222B2827302F373D3D3A3E41373A3F3737413D3D49
3C3C483433412B2A383837475654625E5C6A5F5D6B666270615E696E6B748A879075727B
59586046454D43434B43464F3C404B3D434F3C44513A4352414D5D6370817A879A7C8BA0
7E8DA27E8DA48391AB8191AA8292A98192A68293A78493A88493A88895A88794A78692A8
8692A88692AA8490AA8490AA818FA98290AA808EA97E8CA97D8CAB7F8EAF818FB27F8DB2
7E8CAF7D8BAE7B89AC7C8AAD7E8DAE7B8AAB7B88AA7986A87685A67787A87685A67382A1
7384A26F839E6D819C6A7E996B7F986C8099687C95667C94677D94667C93667C93647A91
63799161778F6277925F748F6075925F74916174945E71915D70905B6E8E5A6A8B5A6A8B
596A88596A885667855768865366845366845166835065804D657F4A627A4B657C4A647B
486279475F77475F77485E76465B76455B73465A75455974455672455674455473465576
465576435072444E71444E71414A6B404968414864424862
807C7D423E3D3C3734615C58615E5956534E53504B54534E605F5A6F706A787973787973
75777272756E6D6F6A686B645D6057494B404042373131252E2F212E2C1D2B291A282715
2B2A162A29142C2A1524220D1B1A0521200C2C2B1732311F3435233839273336252B2E1D
1E22111B1F101D21121E22131F23152327193134293C3E3145473A494A3C504E41514F42
55514554524554514252513F51503C51503B52513C52513C53523D51533E575644585947
58594954554757574B58584E59564F55524D5650505852545C5859615C605D585C302B2F
2222222525231D1F1C1E211A171A13171A1113160B101608131A0A151C0C1A211123291B
242A1C272D1F2E3428282E222A2D222E31262D30272F30282F30282E2F2731302B34332E
32322A2E2E263030282F2F27383A2F393B3037372D47473B4F4D40656356757364767364
7370617774637A74647873607A75627974607974607B766075705A726D576F69536B654F
6B66506B6650716A5778715F817A6A898176978E85918881897F7D8C8482A79EA1C5BEC5
D4CDD5DCD7DEC6C1C8CAC5CBCDC8CCAEAAAB878382474141241C1A2D2322332927362B27
362B27372926392B28382A27382A276355546D5F5E655756726461766B67746965716662
675E57665F556B645C5450454A463B4F4D415250445452463E3C303431283A372E423F38
3B3630534E4A67625F635E5B807A7A837D7D6660606F6969746E70817B7D8D878B746E70
646061504C4D4947483B393A2626281A1B1D1D1E20212526292D2E2E32332A2F32272C2F
2A30302D3333292F2F2A302E242D2A282E2C31363935393C38393E35353D3836413B3944
3737433434403A38454D4B5863616E7A78837573806E6C7774737B8C8B9385848C62626A
4344493E41463E41483F434C3D414C3F4553444B5B4B54656974867F8C9D7E8AA07E8AA0
7D8CA17F8EA58392A98393AA8394A88293A58495A78697A98394A68696A68595A58493A6
8594A98594A98490AA8290AA818FA98191AB8190AD7E8DAC7F8EAD7F8EAF7D8BB0818FB4
7E8CB17C8AAD7B89AC7B89AC7E8CAF7B88AB7986A97986A97785A87787A97483A47282A3
6E819F6E829D6C819C6A7F9A687D98697E99657A95667B96657B93647A92657B93647A92
647A9263779260748F6073915E73905E73925F72925E7191596C8C5A6D8B5869875A6B87
5869855667835566825566825367825165805065824D627F4E66804D67804E688149657D
48647C47637B47617A48607A445C78445C76455974435772465775445573465375485577
465376445174454D72434B6F444A6C424767414463424663
8988865D5C583D3D3555554B7476696A6C5F5F5F5367675D75756B7C7C747B7C747A7B73
777A7372786E6E736C686E64686E625E62544C50423F41333436283031212D2E1E2B2A18
2A29172A2915312E1B2C29162B2A162B2C1A2C2D1D3435253B3C2E393A2C2E3023191D0F
171B0D1D211322241725271A292B1D2E30223C3E3143433747473B4B4C3E4C4D3F4E4F3F
504F3D50513F52513F4C4E3951533B53563B4F51394F513952543C535740565745575A49
57594B595A4C5D5D5158554C57524E58504E5E535760555B61565E655A62645961584F54
4945462A29271B1B1920211B1E211A1A1D14171D11171D11181E101921121C2415222A1D
272F222931242B33242B33242D34242B2F202F33242E30222E2F21303123343226323226
31312730302630302437372B3C3E303B3D2F3A3B2D5051435E5F516F706277786A737464
7475657977687B78697C76667973637B75657A73637B7464736C5C6F68586B64546D6656
716A5A706959736C5C8079698981748C8479938980867B75968B87B3A9A7D6CCCDE4DBDE
D8D2D6DBD4DBD9D4DBDBD6DDE9E7ECCDCBCE9694973F3B3C1F19192C2422342C29362D28
352A26342721392B28392A2734252051423D5647445B4C497B6C69827471786A67726763
6C615B6D645D766D64686157645E52605C505753475D594D4A463A413D324D4940544F49
524A4760585662595A5E5558807A7E898387736D71817B7F8985867571706B6766686461
76736E6E6B665857522A29252525252123221B1C1E202425292D2E272D2D262C2C262C2C
2C31342D31342E32352A2E31292A2E3132363D3B4037343B35323933303734313A333039
342E38403A444A47504E4B5259565D7574797170766C6B709E9DA3A4A3A976777C52555A
45484D40434A3E414A4145513E415043485B595E726B70867F879E838EA4818BA68690AB
8591AB8692AC8793AD8695AC8493AA8594A98495A98495A78596A88598A98497A88294A8
8495A98596AA8391AB8290AA8391AC8290AB808EAB818EAE818EAE808DAF818EB0828FB1
808DAF7E8BAD7E8BAD7B88AA7C89AB7C89AB7A87AA7987AA7987AA7785A87484A57383A4
6F82A07083A16D809E6B7E9E6A7D9D697C9C66799A687B9C66799A677A9B66799A647797
6477976474956272936272936073935F72936070925E6E905A6D8D5B6E8C5A6D8B596D88
576B86566A835667815667815367805367825065824F64814B637D4B657E4B658048627D
48637E47627D46607B46607B445B7A425A76455974425671465775465775465375475476
465375455274444C70434B6F454B6D444969434665444563
64646273746F5C5D573E403575776A787A6D6A6A607471687A77707B7A7576757073746E
6F726B6C716A6C716A6A6F686A7066646A5E5A6052565C4E464A3B3336253134232E2F1D
292A182D2C1A36332236352330311F2D2E1E2E2F2132332536362A37392C2A2C211B1D12
1A1C0F232518282A1D27291C2F312435372942433548493B474838494A3A4C4D3B4B4D38
4A4C364C4E384B4D374B4D374E523750543950543B51553C53573E555942595C49585B4A
585A4C5A5A4E5F5C5358534D57524F5A51525E535762575D63586063586061565E665D62
5C58593837351D1E1922231D21241B1E21161A1D121C22161D23171A2215232B1E272F22
2833252934262C3425293221252C1C282F1D2F3322292C1B212212323021363427363427
353529313125313224393A2C3C3D2F4042344647395A5B4D6365576D6F61757668757668
76786A7E7F6F807E6F7976677D77697F796B7B73687A7267766E636F675C6A62556D6558
70685B71695C7D75688E8679968E81898176847A70958B82B2A7A1D3C8C6E3D9D8E4D9DD
E1D8DDE1DAE1E0D9E1E4DFE6E4DFE6C9C6CD7E7C81282629201A1C2E2828342C2A322826
3025213224213729263A2B283829244536314A3B3856474472636074666370625F726763
70655F7267617C736C786F66736D616D675B5F594D635D515C554B564F455D564E675E59
695F5D6D63646A5F63675C62847B809A9498958E959B9599A09C9B716D6A524E4B65625D
77746D65625B403F3A1817132727272C2D2F1F2324282C2D292F2F222828232929262A2B
282C2F2E2F332E2D3325242A2B282F38353C3D383F3730382F2A31322D34322D34322D34
383139494249534E54504B51514F5463616678777C6D6C7196959B87878F595C63454952
494D56434752404352434657494E6254596F7778947D819C8489A6848BA7858AA88A91AE
8992AF8A94AF8993AE8995AF8995AD8695AC8897AC8495A98697A98598A98496AA8395A9
8395A98495A98392A98492AC8391AC8391AC8590AE8590AE848FAD8590AE8590B0848FAF
848FAD808BA97D8AAA7D8AAA7C89A97B88A87988A97786A77887A87686A77585A67285A5
7184A26F82A06C7F9F6B7E9E6B7E9F697C9D697B9F697B9F687AA066789E67799D69799D
67779B6472956472956472956474966373956070945D6D8F5E6E8F5B6E8E5C6D8B596D88
586C85586983596A845768825566805367805165804F647F4F647F4F647F4A627E4B6281
47607E47617C475E7D48607C455D79475C79465A75445873475874485977455473485575
465373465373455070424B6A454C69454A67434764424661
51525677787A888888555553565551615E59605B58706A6A827C7C7A7677716D6E6E6A6B
676767676968696D6C6A706C676E67656C6461695E60685B5B6153444B3B3438292F3221
3233233334243A38293533242D2E1E2D2F212D2E202E2F213133253436292E302527271D
28281E29291F2B2B212A2A203434283E3F31494A3C4D4E3E494C394A4D38494D36474B32
45492E44482D474B32484C334D513852563D54583F5458415456405658435A5B49595A4C
5A5A4E5B5B515A575057524F5751515953555E585A605A5C5F595D5F595B5E5A5B605C5B
61605C4E4F492E2F27282B202023181C2012212517212517232719202618232B1E2B3326
2B3628283426283323242F1E252E1D282F1D2C311D2528152122102C2D1D323023373528
3A382C39372B3A382C3C3C303F3F3349493D5E5E526B6B5F717165717165727266747567
7C7D6F7F8072817F727C786C7B776B807C707D766C777066777066746D63706A5E736D5F
746E60726C5C807A6A908A7A938C7C867F6F867C70BAB0A6D1C8C1DDD4CFEADEDEE7DCE0
E4D9DFE3D9E1E4DAE5F2EAF7E2DCE8BDB7C15552591A181D211B1F231D1F2D2427322829
2F2323312323332525392B2A3B2D2A3B2D2A40322F584A4761544E5D524C6C615B716660
716660766D668178737F7671777068726B61675E55645B526B625B6B625D6D625E6E6361
6F63636E62646F63676F64689D9497B3ADAFA7A1A59E9A9BA09A9A716C69443F3C625D5A
6B6764524E4D3B393A1C1A1D2423282C2D31292D302B30332B3131242A2A23272A292A2E
2C2B31312E35312B352E283238323C3B353F3D35403129342B242C332C343B343B3A333A
3F383F4B444B4E474E524D534B484F4F4C556D6C7466646F63636F4D4F5B494B58434655
44475843485B42475B454A605C6079787C978889A88888AA898CAD898EAE8A8DAE8A8FAF
8A8FAD8C93B08D94B08D94B08A94AD8A96AC8998AD8897AC8796AB8596AA8798AA8697A9
8495A98596AA8594AB8695AC8492AC8391AB8590AC8691AD848FAB838EAA828EA88490AA
838FA9818DA77D8BA57C8AA57C8CA67A89A67887A67584A37586A47184A47487A77184A4
7184A47083A36F83A46E82A36E80A46B7DA16A7EA3697DA2697BA167799F69789F6C7A9F
647297667298667396667396647193637293616F92616F925F6E8F5C6C8D5E6D8C5C6D89
5A6B85596A845A6A8458688256667F53647E54657F52637F5364804F637E4F6280516482
4E63804B607B4C617E495E79495E79485C77465A73485973475872465771485973465670
43536C42506A43516B434F69434D66444C633F455D41475F
64656A87888C88878C6666684C4A4B5854555650526B65679993977C777B645F63696468
646464656766686C6B696F6D686E6A646E66656F66667065687063626A5B494F41303426
323426383A2C3B3C2E3637292E30222C2E202E30222E30222F31233133252D2D212C2C20
2E2C202C29202E2E2431312739392D454638494A3A4B4E3B494C37494D3644482F42462B
45492E42462B43472C484C334E523952563F5458415759435557425758465A58495C5A4D
5C5A4E5B585159545056514E5753545854555B57585C58595E5A5B5D5B5C5D5B5C5B5B59
61625D595C5541443B3033282124191F221722241722241726291E292C21272D23293126
293328263123222D1F222D1D232C1B252E1D252C1A272B1A292C1B2C2D1D2F3022383629
3A382C3E3C303D392E4341354C4A3E52504460605473736778786C77776B747468747468
78786C7E7C6F817D727F7B707C786D7B776C7F78707A736B79756C747065746D63767266
7976677D7A69868372908A7A87826F7D78658C8575CCC4B7E0D8CDE1D8D1E6DBD9E6DADA
E3D7DBE9DEE4EDE1EBDED4DFA9A1AE837B8639343B342F35211B1F241B1E2C212533292A
362A2C302424302424322725362B27352C27382D2949403B483F38544B44675E576C635E
6F66617A716C7E74727C727079726C746D676D645F7067627269647067627166646E6361
7166647468685E52546155579E9495A2999A8B8585908A8AA6A19E77726F433E3B56524F
4E4A492E2C2D302E3128282A2C2D312C2D312B2F322C3031292D2E25292A2324282C2B30
2F2D32332E35342D353A323D4139443C343F332B362B232E272028332E34524D534B464A
433E424742464C474D4F4A5148454E48455053515E494755474656454658444559424459
464861434762464A67595D7A7C7F9E898CAD8989AD8E8EB28D90B38C8FB28D90B18C8FB0
8B90AE8D92AF8F94B18F95AF8D95AC8A95AB8B97AD8796AD8995AD8793AB8A96AE8796AD
8594AB8392A98391AB8492AC8694AF8492AD8691AD8691AD8590AC828EA88490AA838FA7
828EA8818DA77D8BA577859F7888A27989A37887A47887A47485A37184A27386A67184A4
6F82A26F82A36E81A26D7FA36B7DA16B7DA16B7DA3697BA167799F6A79A068779E69779E
67759A68749A677497637093626F91647193637092616E905E6D8E5E6D8E5F6E8F5B6A89
5C6B885968855867845766835463805564815564815463825463824F5F804F5E7F4F5F80
4E5E7F4D607E4F607E495C7A4D5E7A46577344557145567044556F45567045567041536B
42526B4050693F4D67425168414C623F4A603F455B3E445A
7374787F80846C6D7166666856565859575A615F62767175A09C9D8280815351525A5A58
63645F666863686D67676C66696E68686F676B756C6C766D69736A6F766E636A62565B54
51574D4B4E434044363135272F33252B2F212D31222F33243034253133252C2D1F2C2D1F
323023302E223232263535293A3C2F484A3C494C3B484D39454A34454A3340462C41472D
45493042462D4648304E503A4F533C565944595B465B5A465B5A485B5A485D5A4B5D594D
615A505D565057524E57524F5854555553545A58595D5B5C605E615D5D5D5E5E5E5D5F5C
5D5F5C5B605A5156503B40392429221D23191B1E171F221B242720292C25282D27282F28
262D252229211B221A1C2419202B1D222A1D22281A282E20292D1E2E3223343628353628
3B392C3F3B2F403A2E4A44385A54485D594D69675A7775687C7A6D7D7B6E7A786C79776B
7A786C7F7D71807C73807C737D79707B776E7E776D7D766C79756A7672677470657B776B
7F7C6D8785768886778C89787D7A6775725F938E7BC8C2B2D7CFC2E2DACFE2D8CFDFD1CE
DBCDCDD7CBCDCABDC4988D9370656D584D55362D32362D302E2526271D1E2B2122362C2B
362C2B2D23222C24222F2724342F29312E27302B253E3933403B354F484267605A6E6663
79716E7C74717B737178706E776F6C756D6A746C69756D6A736C66726964766C6A685D5B
605553695E5C4D4240564B49746A686F67647C74718C87838E89856B6863585451585753
3D3C3A2222202828283030303133323032312A2C29282A272B2B2B2A2A2A2A282B312C30
363135352E35342D353F3840413A42312A322E29302E29302B262C32303558565B555356
434345434345454348434047424149413F4A444250423F50423E5542405843405D454261
43426446466A6262887B7BA18A8CB28A8CB28F8FB39090B48F92B39095B58E93B18F94B1
8F95AF8F95AF9197B19298B09199B08E99AF8E98B18B97B18D96B38C95B28C95B28B94B3
8994B28792B08691B18792B28792B08893B18694B18492AF8593B08290AD838EAA828EA8
818CA8818CA87E8CA97B89A67987A47A88A57786A57988A77484A57383A47484A67282A4
6F82A36D7FA36D7FA36F7FA36E7EA26C7CA06C7CA06C7CA06A79A067769D66759C67769D
65749B667499657396647295617091627192616E90616E905D6A8C5F6C8E5A67895B688A
5B6A8B576685576687586788546384556386576588536083535F85505E85515D854F5D82
4F5D824E5E824D5B7E4B5B7D4D5C7D48577846557447567345567245567243547043546E
42526C42526C414F6A42506A414B663F496240465E40465E
7273786C6F7465696C5054555256576C6E6D82848187878588898476777251524C53544E
53564D54574E61645B6A6D6464675E646A6071766F757C74757C74767D767277716E736D
72786E676D6142483C33392B393D2F35392A343829323627333726333625303121313222
34352532332536362A37372B3A3C2E47493B4B4F3E494E3A454A34444932424730454930
474B32474B324B4D3750523C51533E5759445D5C485E5B485D5A495F5C4D5D5A4B5D594D
635C525B544C55504A58555053524E5655535B5A585D5C5A626262646464646464626463
5F61605D625E595E5A4B504C393E3A2C312B2527242628252628232A2C27272C28282D27
272E271E251D1C231B1F261E242C211E261B23291F252B1F22281A2D3123323426333527
3A3B2D3B392A484236534D3F5E584C676155726E62817D71848074837F73837F747E7C70
7C786F7E7A71817D74827E757E7A717C786F7F786E7E776D7874697672677A766B848075
8785798785788280747E7C70807E717D7B6C9C988CB8B4A8BCB6AAE1D9CEDAD0C7D5CAC6
C1B3B2A498987E7274594E5253474B493E423C3233392F30362C2B2E2423302625352B2A
352D2B2D25232E26242E29252E2B242E2B242D2A2338352E3F3A34514A446A615C756B69
7C72707E76737E747379716F79716F78706D766E6C756D6A77706A6A635D625B55544D47
443B364F463F483F3A473E3749403B453C37736C6690898385807C6D6A655F5B584A4945
2D2C2A21211F2A2A2831312F31312F292B282525232A2A28302E2F2F2D2E312C30322D31
3732363C373D3A333B332E35362F362E292F241F252B292E3230353F3E434C4B50414143
3B3C3E3F40423F40453E3E463D3C44413F4A413E4F413E533E3A5345405E464062464265
4D4B706B69908180A88F8EB69193B98D90B38F92B59194B59095B59095B39196B39298B2
9097B18F96B09096B09096B09097B19299B38F96B28E97B48C95B48C95B68E94B68E94B6
8B94B58A94B78991B58890B48791B48690B38592B48491B38392B3808FB0828FAF8290AD
808BA97C89A97E8BAB7C89A97C89A97C89A97887A67786A77484A57383A57684A77684A7
7080A46E7EA27080A46D7DA16E7EA26C7CA06C7A9F6B799E6C7A9F69799D66769A67779B
647498647498647496627294607091606F906271925E6D8E5E6D8E5C698C5C698C5A678A
5A688B57658857658857658A546488556589526085515F84515F864E5C834F5D844E5C81
4F5D824E5C7F4C5A7D4D5B7E4C5B7C485778475675495877475673445571455674415270
43527141506F414F6C404E6B414C683F496441486241475F
64676E62676D6C747756605F56615B79837A949E938E9689676D5F5C62545D6153585C4E
494B3D5254476B6D606B6D6267695E63655A6E6F677C7D7580837A7D80797C7F787B7E75
7C8278777D715E61564246383F43343D4130383B2A373A2934372434372432332130311F
323321333424393A2C3B3B2F3D3F314547394A4D3C494C39484B38484B36494C374B4D37
4B4D374E503A4F4E3A53523E54533F5754415956455956455D5A4B5F5C4D5F5C4D5F5C4D
615D515A584B58564A58584E59594F5D5D5564645C64635E6565636868686A6A6A676767
61616160616356575954555752535548494B353736262827232824292E282A2F29262B25
282D2621271D1C221821271D252A2320261C25281F26291E2327192D31233335273A3C2E
3E3F2F3B3A284744355751416862546F695B7D77698B85778E887A8B85798A83797C786D
7C756B7F786E837C747F78707E7A6F7C786D80796F837C727B776C7B776C8480778C8781
8B868089847E817C7875706D7A76738D8A85A5A09DA7A29E948F8BB0A9A3B1A7A5ACA2A0
95898983797A5D53543F36373B3130392F2E392F2E3C3231352B292F2523312726342A29
362C2A302625342A29362E2C362F29302C23312C2638312B3930294F463F655A54766B67
7E736F7B726D7B706E766C6A766C6A776E69746C69756E68716D6455514846423947433A
3B372E413D32413A32413A30433C3439322A453E367D767089817E68635F484340352F2F
2F2B2C2A28292B292A303030343434252525211F222C2A2D2E2E302F2F3133313638363B
38363B3D3B4039343B29262D2F2A303230352B282F302D3437363B3F3E43454449403F44
393A3E383C3F3A3D423B3E453C3C463F3F4B434254424055433F584944624946654F4B6E
6B6A8C8B8AAC9292B68F92B38F92B38E91B09093B29196B49196B49297B48F96B39097B3
8D97B28E98B39299B68E95B29198B59097B49096B68E94B68F95B78D93B78C92B68F95B9
8D95B98B93B78890B58991B68993B7838DB1828EB4828EB6818FB47F8DB28290B5818FB2
7F8CAF7C8AAD7987AA7887A87B8AAB7B8AAB7786A77886A97785A87381A47683A67381A4
7280A3707EA17280A36C7A9D6A789B6A789B6C799C69779A6A789B6A789B657597647496
6275966275966073946073946073945F72936070925E6E905C6C8E5C6C905B698E59678C
58668B58668B59678C56648B54638A55648B5160874F5F834F5F834D5D7F4D5D7F4C5C7D
4C5C7D4C5D7B4C5B7A4A59764A5976485774485673475673465574465574465576455376
445173404D6F3D4C6D3F4C6E424D6D414A69414864404761
666972656A70666E71757F7E7F8A847F8B817F8B7F57625451594A5F6758666C5E626658
595B4E5D5F528B8B817070665C5C5267675D726F6885827D868580807F7A807F7A808179
7F82797A7D7272756A5D6153484C3D373B2A313423353825383B2630331E31331D32341E
323520353825393A2A3E3F2F41423242433347483851524052513F55544251503E51503C
51503C52513D53503F53503F5552415A54445B55475B55475C594A5C5A4B5957485E5C4D
5F5D4E5657475859495B5C4E61625464645866665A66665E6867636C6B69736F6E6E6A6B
676568615F6256545954525757565B55565843444622242320221D252A232A2F28242A20
242A20242A1E23261B25281D282B222B2E252A2D222B2E23272B1D313526393B2D424534
46493643443248473553503F6D67577771617C75658D86768C84778C84778880757C736A
7A73697C756B827B73837C74817D747D796E7E776F878078847D758581788F8A84928D89
88807E827C7C7973756E686C868084A7A3A49B9597979193A29D9A948F8C8D85828D8582
7F77746C6461524A483C373336312D3D3832413A343F383238302D2D2522271F1C2A221F
3A302E38302D372D2C38302D362F29332C24332C26352E283B322B514640625751766B65
766B65766D667B716F766C6A736C66746D67726D676B66605A574E3230242F2C233D3A31
37342B36332A3B382F3A362D3C382F39352C2D282256514D736E6B544F4C403A3A352F31
353132323033312F3233333533333527272928272C2D2C312E2D3233323739383D38373C
39383D38373C3231372B282F2E2C3136343939363D37363C37383D3A3B403E3E46393941
36393E363B3F383B44393D463C404C3E415041425643445947445F4949655A59786D6C8C
8283A29091B08D91AE8E92AF8F93AE8F95AF9298B29096B09197B19097B39097B48D96B3
8C97B38E99B59099B88D96B59096B69298B88F95B78F95B78F95B78B94B58C92B48B94B5
8A93B48993B68791B58892B68693B68390B3818FB47F8DB4808FB67E8DB47D8CB37E8DB4
7B8BAF7B8BAF7989AD7787AB7888AC7686AA7785AA7987AC7684A97482A77381A67280A5
717FA26F7DA0717FA26F7DA06E7C9F6E7D9E6C799B6C799B6A799A697899677697667697
6275966174955F73945F73946175965E72935D70915D7091586A8E586A8E58678E5A688F
58668B58668B57658A53628954638A5565895161854F5F814B5E7E4B5E7E4E5F7D4A5B79
4D5E7A4B5C784A59764C5B78495875475673475474475474455274425172455177455177
4450763E4B6E3D4B6E3E4B6E3E4B6D3F4A683B44613C435F
6C6C746A6B70676B6E848A8A8D9691737D75636C674C534C555C55606760676C66666B65
5F625B5E5F5A8F8E8A69686454514C615E596F6A67807B7886817E817C7984807D7F7B78
7E7D797F807A82857E787B725A5E50363A2B30342334372435382335392233371E353920
34361E3739213F3E2941402B403F2A423F2C45422F4E4838514E3D555243585244534D3D
534D3D544E3E544C3F534B3E544C415650445B544A59554A5A584C5C5D4F525345525544
575A49585B485C5F4C5D5E4E64655566645767655965625966635E716D6A7670706B6565
666062655F63615B5F5651555553565C5C5E5B5B5B3A3C392E312A2E31282F32272B2F21
282E20252C1C242819282A1C2C2E202F33243337282E352535392A3A3E2F3E4233444837
454A364D503D4F4E3C5B58476B665376715E797260847B6A837A6B82796A83796F7F756B
7970677B72697F7870837C767E79737C786F7F78728B847E867F798B83809189878C8384
867B7F80777C756B737B747C9E979E9D979B8C868A958F91A6A29F8B888389847E8C887F
7672695E5A4F5652494441384340374441383E3A314642393E393328231D27221C2A251F
3A332D38332D362E2B36312B37332A2F2B20302C23362F274039314C433C625952746B64
716861706961746C69726D696F6C65706D6671716965655D4244391D1F1423241C313129
30302831302B37363135343034332F3837333A36353A36354B4748433F403D383C302B2F
353034353338302E332F2E342E2D332B2C312F303532333838393E34373C34373C32353A
3334393031362F30342A292E2F2E343A393F3A394136363E36363E363940383B44393D46
363A43353C44383C48373D493B41513C415440455942475D454962535772747893858BA5
8A90AA8E94AC8D93AB8D93AB8F95AB9098AD9199AE929AAF929AB19299B39097B39099B6
8E99B58F9AB68E99B78A95B58F98B99099BA8F97BB8F98B98C95B68B96B48C95B48D98B6
8994B28694B18594B38594B38394B28191B27F92B37C90B17F92B37B8DB17B8DB17B8DB1
788AAE788AAE7789AD7688AE7486AC7587AD7584AB7584AB7382A97382A97281A87180A7
6E7EA26F7FA36D7D9F6D7D9F6F7E9F6C7B9A6B7A996D7C9B687796697897677695657493
6474956174946174956073945C70935D7194596D905A6C905A6C9255678D58678E57668D
56668A56668A56668A5464865363854F62825164844C5F7D4D617C4B5F7A4C607B4A5E79
4A5D7B4B5E7C485977485977465677485778485578475477475477475379464F76454E75
424E74404C723C486E3D4A6D3F4C6E3D48663A436039435E
6D6C72717075717276808485818584565C5A606463666C6A656968696D6C6B6F6E6D7170
70726F696B686D6D6D6867656362605B57545853507D757388807E88807E837E7B807B78
817E79807F7A858680888B82787B703B3F312F33243B3F2E3F422F3D402B3B3F283A3E27
3638223537213E3D283F3E29413F2A43412C443F2C47422F464030534D3D544D3D4F4838
50493950483B4B41374F453B544B425B544C5D564E5C584F5B584F58584C525447525446
5A5E4D5E62516164535F625160615363615563605765625B686560736E6B746E6E696363
675E61645E60615B5F5D575B5A585B5B5B5D5B5B5B53555241443D33362D313429323628
2C33232930202C2E203033222D2F213639283C40313D4132404435464A3B484C3B484C3B
4B4E3B5457445C5D4B63624E6E695675705D7B72618077668478688377697F73677E746A
7E746B7B72697F766F817A747E77717D76708179768D85829189868F87858A8081867B7F
83787E7D727880757D8A8088978E9391888B968D90ABA2A3AEA9A588837D837F768B897D
7674686563575C5A4E4B4B3F4D4D4351514737372F32322A3C393234312A2C2922312E27
3835303D383237322C363229343128332F24312D223831273F38304C453B5F564F766D66
7A716A766F69746F6B73706B71706B64655F5A5B554C4D4731342D2528212E2F292E2F29
2E2D29302F2B32312F312F303131313333333836373D3B3C373538333134383339342F35
3331362E2C312A292F2B2A302A2B302C2D3235363B393C413A3D4235383D313439303338
2E31362E32352F30342C2D31302F3538373D3939413838423B3B453739453A3C483D414C
3B3F4B363C48393F4D3E44543F4658434A5D454B61474F66585F796E758F7E88A18892AB
8A95AB8E96AD929AB19098AD939BB0939BB0929AAF949CB1959DB2939BB29299B5919AB7
919AB7909BB7909BB98E99B78E99B78F9AB88F9ABA8D98B68D98B68B99B48D98B48997B2
8795B08595AF8495B18394B08194B28194B27D92B17B90AF7C90B17E91B27D8FB37A8CB0
788AAE7789AD7789AF798BB17688AE7486AC7584AB7484A87382A97483AA7281A87082A6
6E80A46B7E9F6C7FA06E7E9F6E7F9D6B7C9A6A7B996A7B97677894657692667594657694
6174946073936073945E71925F71955D71945C6E925B6D915B6D93596B9157668D55648B
56668A5565895565875464865363845063815364825165804E627D4C607B4C5F7D495C7A
485B79495C7A4757784858794656784755784956794A5478475477495377495377454F73
434D71414E713E4B6E3D4A6C3D4A6A3D48663A45613B4560
66656A737375767678797A7C7172744F53546667697F8384727375717274737574747675
7476736E706D6A6A6871716F7B7B796D6C685F5A567974708B86808B868088837D85807A
85827983837987877F8E8F878E91885A5D542D30253D40354244374143354042343F4133
373A293435233938263F3E2C41402C3C392645422F4845323F3C29403D2A46412E433E2B
433C2A423B2B3E3428372D233F362D564F475D56505A575056564E54554D56574F5E6055
606456636759616358585A4F5B5C545E5E566966616B67646F6B6A736F6E706C6D676364
635D5D646061625D615F5D605D5B5E5C5C5E5757595456554F514E3D423C3B40393B4137
353B2F31372932342737392B393B2E3A3C2E45473A4A4C3E4C4E40555749585A4C525544
5758466263516A69556D6C58736E5B746F5B7A71607C73628279688077687C72667E746A
7E746B7B7269827972857E78827B75827A7781797789817F968E8C8D8787837A7B807778
84797D7D7374807677978D8CA29897A29896A89D9BABA09EA2999490898187807A8A857F
7E7B7475726B6C6C645E5E5653564D53564D42433D3637313D3C373F3E39383732393833
3A39353D3A353C393239362D302C23302C21342D233B3328423930494136645A517B7269
7A716A77706A736E6A7874716E6D6951524D464644343633292B282C2E2D2D2D2D2E2C2D
2E2D2B302E2F312F32312F32302E313432353A383B3B393C3432352C2A2D2E292D302B2F
2F2D302E2C2F2E2D322F2E332F30343031353A3E413A3E41363A3D3135382F33362E3235
2D31342D31342D2E322E2F3334353A36363E3937423A3A443D3D493E3D4B403F4D40424F
3C3F4E3A3D4C3C3F5044495C434A5D464C62586077667089757F98818DA78896B08997B1
8C98B08C96AF919BB4929AB1959DB4969EB5949CB3969EB5979DB5999FB9979CB9949BB7
919AB7939CB9919AB79099B68F9BB5919DB78E9CB68D9BB58D9BB58B9BB48A98B28595AE
8696B08495AF8596B28495B38494B58191B27F92B37F92B37E91B28090B27F8FB37D8DB1
7D8DB17A8AAE7A8AAE7989AD7989AD7888AA7886A97684A77383A47585A67386A67083A3
6F82A26A7F9E6B809F697E9B677C99677C99667997657896677A98657896637897617695
6174956174956171936070926070945F71955D6C935A6C925B6D95586A925A699057658C
5563885563885664895361845261825161825261825162804F62804D607E4F5F804D5D7E
4C5C7D49597A4A587B4A587B47557848557848557848557748537148537146516F45506E
444F6D434E6C414C6C3D48683F4A683D48663A456139455F
6765687373757474767777797B7B7D6E6F71696A6C6D6F6E6E706F7678777779766D6F6C
676966696B666B6D6A71736E7D7F7C7879746B6A657F7C759E9B929593878785798A887C
88867A86847887877D89897F8F908882857C51544B51544B494C41474A3F494C41414537
393B2E3537293637293738283839273D3E2C46453344432F373622312F1A322F1C2F2C19
37321F2C26162A2215251D12231C123D362E544F4953504952524A5758505D5E5662635B
60635A62655C5E5F57595A545C5D576768637372707372707171717573746E6C6D615D5E
666263666263615F62605E61605E615B5B5D555557525453535552474C46464B45494E47
474A3F42463843453845463847483A48493B4A483B5B594C626353626353626051525041
5B594A6E6D5B706D5C7673627973637A74647B73667A72657E77677F776A7E766981776D
80766C80766D847A71867D76857C77837A75837977897F7D948A89837977796F6D7C7270
8075738176748E837F9D928EA497919C8F89A2958F9F928C9287818B827B8E85808D8680
85807C73706B726F6A75746F63645F5F615C60615C5859544F4E4A3E3F3A3B3A36383733
3837333736323D3A353B3831302D243531263730263D362C413B2F433D31675E5580796F
7B746E746F6B716D6A77767270706E393B382E302F2F31302A2B2D2C2D2F2E2E30302E31
2F2D30312F32323033312F343331363836393E3C3F3E3C3D3331322927282F2B2C2C2A2B
2D2B2C32303131313333333535363A3A3B3F3A3E41383C3F32373A2E32352E32352D2E32
2D31342D31342F303431323735353D36363E3B39443E3C4942414F424453414050404153
3E4152404656414358454A5E464C64555D746B75908C96B1909BB78D98B48D9BB68E9CB7
939EBA939DB8949EB9979EB8979EB8959CB6969DB7989FB9969DB7969DB7979CB9949BB7
939DB8919AB7919AB78F99B48E9AB28E9AB28C9BB28C9BB28C9BB28999B08797B08898B1
8898B28695B48594B58493B48391B48391B48391B6818FB4808EB3808EB37F8DB4808CB4
7E8AB27D89AF7B87AD7B89AE7B89AC7987AA7887A87685A67585A67485A37083A16D809E
6F84A16C819E677C9B6A7F9E697E9D687D9C65799A6478996477976277966074955F7394
5F71955F71956070945E6E926171955E6E925B6B8F5A6C90596B8F57698D58688C566688
5765885464865462855462855261825261825261825060814D60814C5F804C5C7E4C5C7E
4C5C7D4A5A7B49597A495879495879455475465373465373475570475570444F6B42506B
414C6A424D6B434E6C3F4A683E49673F4A6839446037435D
676266706E717371747777797D7D7D79797771716F62635E696A657B7C7675767063645E
63665F6F726B72746F71766F757A7471766F797E7785887FB6BAACBBBFB08E9082838577
8A8B7D8C8D7F8E8C7F83837785877C8B8D827C7F747B7E73707368686E625D63554A5042
3B3F31393B2E3A3C2F36382A3335273C3F2E4142323839272A2B19282713272614242311
29261523200F292313302A1A2522132E2A1E433F34504D4455554B5E5E5461625A63645C
61645B62655C5E615A595B566365607173707B7D7A8486858789887B7D7C5D5D5D5C5A5B
6C68696C676B676266615F645D5B6059585D56565853555456585553555053564F55584F
5456494E5042565749565445504E3F5755465A5746666352716B5B716B5B5E58484A4436
575143696355756F638C867A8F887E80796F7A736B7E776F817A70817A7080796F837B70
80786D7F756B857B718B7E768A7D75877A72897A738A7B748F807B83746D80716A83746D
83766E84776F91847C9B8E8696878093847D93847D8F827C90837D8F847E9287838D8381
7D75736B666378737085817E8C8B898382807B7A785F5E5C4E4A494B4A484844433C3837
35313034302F38343135312E33302B38352E39362F3E3A31433F3449453A716E657E7B74
75726B6D6C678687828586815E605B262B272F33323438392F30322F3032333237313133
3232343030323030323131333333353B3B3B403E3F41403E393A35353631353430333230
32312F363634363636353535393A3C3D3E423A3E4134373C2F32372D30352A2D32292C31
2F303536373C35343A33323A36353D3A38433C3A473E3D4B43455245485745465A3F4255
3C415540475A42465F454B635F64817B829E868FAE9099B8919AB9939CBB939CBB949DBC
959EBD989EBE969DBA969DB9989DBA989EB8989FB9989FB9979EB8959FB8979EBA939DB8
929CB7929EB8919DB7909CB68F9BB38F9BB18F9BB18D9CB38D9CB38A98B28997B28B99B6
8895B58693B68692B8838FB78591B98490B8868FBA828BB68089B2828BB48089B48089B4
8089B4828BB47E87AE7B87AD7B88AB7885A87684A77483A47282A37383A46F82A26F82A2
6F82A26D80A06A7D9E6A7D9E6A7D9E6A7D9E67799D67799D67769D62749A62749C5F7199
6170996170995D6F955E70945F71955B6D91596C8D566989566989566987536684546883
596A865265834F607E4E5E7F5161825262835262845262844E60844A5E7F485B7C495C7D
4A5D7D485B79485C7748597547587247587247567345547146557247567344526F404F6C
3F4C6C414E6E404D6D3D4A6A3F4D6A404B6938435F39425F
6965666B696A7371727775767A7A7882837E7E7F796B6C647173687F8176727469585951
65685F757871737871757A736E756D7980789CA39B9EA69BCDD5C6D8DED0989E9065695B
77796B8182747C7C7072726673736980827784867B898C818A8D8282887C7A8074616759
4C5042404436383A2D393B2E333728343829363928313423292C1B2A2B19292A181E1F0D
1A1B09201F0D34331F3C39263D3A293431223430244E4A3E5E5C4F606153606056626258
5F60585E5F5763645E646560696B686C6E6D7B7D7C95999A969A9B78797B5F5F617E7E80
888689787379666167645F655E595F5C575D59575A595758595A5558595359595158584E
5B5C4E5A5B4B646253646150605D4C6A64546C67546D6654746D5B6C6555544D3D4D4538
4E4639585045736A618B847C99928C8E86837C7471817C78847F79848077878078877E75
81796E7F756B877A718B7E758A7C73897B72897B72897B728B7D748C7E7586786D817368
87796E867A6E8F827995887F91847B8D80778C7F778C7F778D827C918680938A858C8481
756D6B6A6562837E7B9F9B989B979484807D716D6C635F5E605C596C68655A5653393532
312C293833303A353238343137333038373243403B44443C45453D505048777870777872
757772797B768B8D8A727471383A37292B283132343132342D2E30313035323136323136
3131333232343232343535353636363C3C3C3F3E3C41413F3D3E39393A35363634323230
343432363835393B3A383A3935393A373B3E36393E34373C3033382F32372F323931343B
36363E3D3D4539384037363E3D3C443A3A443836443C3B4B41435243465741435840455B
40465E4B51694B516B5E63808289A68E94B48B94B58D96B7919ABB939CBD969CBE979DBF
969FC0949DBE959EBD969DBA989FBB979EBA96A0BB96A0B994A0BA94A0BA94A0BA939FB9
929EB8929EB8909CB6909CB6909CB48F9BB3909CB48D99B38B99B48A98B38A98B58998B7
8694B78694B98692BA8591B98490BA8591BB858EB9848BB78289B58289B57F88B37F88B3
7F88B37E87B07D86AD7884AA7A87AA7684A77684A77585A77484A67386A77184A57184A5
6F82A3697B9F6D7FA56A7CA2697BA1687AA068779E69789F64739C64739C63729B617099
63729D5E70985E70965D71945D71945A6E8F596E8D536887556A87546984556A85546883
5468835266815164824E61815161835161835262865363874E60844A5C80495C7D4A5D7D
4C5D7B485C77495A74475B7345597147597145567045556F45547143526F435271425170
3C4B6C3F4E6F3D4A6C3C496B3C49693B49663843613A4360
6D6C6A6C6B6973726E7778737D7E787E7F7782847980827585867886877972746765675A
5F62576D7067777C75757A738289828D948D9BA29BBDC4BCDBE2DAC4CBC3878C8541463F
595C5364675E5C5C545050486161597A7A7281817982827A8C8D8591948B8E91887F8277
6F7365595D4F44483A363A2C3236273236273236272D3120292D1C3033222E31201B1E0D
1619082829173B3D2844432F44432F393824373423504D3C615E4B625F4C625F50676357
67635867635A6C6763736F6E6967686866697D7C818B8C90818287797A7F8A898EA09FA4
969499807D846C676E666168605961615A615D57595F59595E59555E5953625B51655F53
625F506764536C66566C6656706A5A7B7462746D5B69604F675E4F5D5347564E41524A3F
4B4539514A4069625A7E7673A29A979A9592837E7B918C889E9993969289918A82898077
7E746A7A6D6481746C8B7C758D80778B7E758A7D748A7D748B7F73908478877B6F7F7569
837A6B857B6F8F857B92887E8A8277847C71867F758D867C8F887E87807895908A9D9A93
8C89847B7A7569686376757087868185847F726F6A77746F7F7A7478736D514C463D3832
423B35423B35423A374038353F3A3745413E4C4B475B5C575759545B5D58787D77828781
9399958A908C6F73723B3D3C2E302F35353736363837363B37363B363439353338353439
3434363133323234333A3C39383A373D3F3C3F3F3F3E3E3E3A3A3A35373632333533373A
383C3D373B3C323838363C3C353A3D33383B34393D32373B31363C30353B363A433B3F48
4548514649524646504646504B4B553C3E4A3D3C4A3E404F43465944465B42465F444863
454A674D54706269867A80A08C92B29298BA8F95B99298BC959BBD9399BB979DBF939CBD
95A0C095A0C0949FBD95A0BC939FB994A0BA93A1BB91A1BA909EB993A1BC92A0BB949FBB
929DB9929DB9929DB9909BB7929DB9919CB8909BB98F9AB88B98B88B9AB98B9ABB8797B9
8797BB8797BB8694BB8593B88490B88692BA838FB7838CB58289B38289B37F88B17E87AE
7D86AD7A86AC7A86AC7987AC7987AA7686A87787AB7587AB7286A97488AB7486AA6F81A7
7183A96B7DA56E7DA86E7DA86B7DA56578A065779F65779F63759B62749A63759B607298
61739B5F73985D7196597092586F91576E8E576E8D546B8A516887536A89536A89546988
536885546787506384526286526188526188536289505F864C5E82495C7D4C5C7D4C5D7B
4D5C794A5B754A5A74485A72485A7247596F44566E43546E445571455674435374425273
3E4E703F4D703F4C6F3F496D3D4A6D394668374260384361
6F6E6A6B6A6671726C78797380817980827784867987897B8587798386758385777F8374
676B5D646A5E70766C7F857B8C938BA9B0A8CDD4CCD3DAD2A8B2A98E958E60655F555A54
575C5551544D55544F4E4B4665625D76736C77726E78756E83837B8F908893948C929489
8D90857B7F715D6153424638383C2E333728333728282C1D2A2E1F3134232F31231A1B0B
2223133435253635233E3D2942412D41402C43402D49463355533E63614C6B66536F6959
6F695B716A60756E66726A676C66667A76777C7A7D6F6D72858489ABAAAFADACB1919095
87858A7E7C817772786F6A70645E62635A5D62595A625A57625B55665F556D655A6D6558
6660506761516F6858756E5E837C6C8B84746F6858534C3C5850435C5449575145575145
5953475851475B544E7B7370A39B99A1999799918FB7AFACC1BAB4B3ACA49E958E776D64
73665D796C637F726A8B7E768F8279897F75887E74867E73877D718C8276867C7082796A
837C6C857E6E888073867E71857D70857F738983778D867C8A83798D897EBAB6ADC2BFB8
A2A29A72736B50504877776F9A9A9094948A79766D928F86918E857C786F5C584F3F3B32
3C37313D3832423A37453D3A45403D4743425250517979796D6F6E5F61607A7E7DA7ABAC
9A9E9F6B6F704F50523435373636383A383B3A383B39373C39373C373538312F32333333
3636343537343537323F413C3E403B3F413C3F3F3D3A3A3A373938353638333438383B40
4044473B404333383C33383C34393D33383C35383F31343B31343B373A433C3F4853565F
585B6250535A50505856596250535C3D3F4B3E404D42455645485B464B61464A634E5370
535A77686F8C848AAA8B91B19298BA9399BB9399BD969CC0989EC2999FC1989EC2959DC1
96A0C396A1C1939EBE92A0BD92A0BB93A3BD90A1BB8FA0BC92A1BE92A1BE909DBD919EBE
949FBD949FBD939EBC919CBA909BBB929DBD909ABD8E9BBD8A99BA8795B88797B98797B9
8496BA8395B98494B88595B78391B48391B48391B67D89AF7E8AB0818BAF7D89AF7C89AC
7B88AB7886AB7987AC7989AD7787AB7585A97685AC7688AE7488AD7387AC7486AE7180A9
7180AB6E7CA96B78A56C79A66977A46778A46576A16778A365779F61739B63759D5F729A
5E71995E71995B71965B7196587092546C8E57708F546D8C536C8B516A8952698B51688A
54688952668952648A54638C51608B52618C52618A4F5E874E5D844D5D814E5D7E4B5A79
4D5C794B5B754B597447577149597241536B43546E4455714354724353744151733E4E70
3C4C703D4B703E4A704049703E486C3C46693A43623A4362
71706B6C6B667877727F7E7981827A82847986887B87897B87897B8589788286758A8E7D
777E6E5D6454787E70909688AFB7AAD1D9CCD9E1D6A1A99E71796E697068575C555F625B
62655E55564E62625A68655E6D68626E6A61756E6874706777746B84847A8C8E8396988D
96998E92988C7E8478585E5042483A2F35272C30222D3123292B1E292B1D2624181E1C0F
2F2D20383629393627403D2E403D2E413E2D3F3E2C403F2B4C4B366665506D6B56716E5B
797461777161726C5E686256706961A5A09AACA7A49B97969A9997ACABA9B2B1AF797876
6F6F6F7B797A7F7B7A7A76756B666368635F6B66606A665D6D695E706D5E787262716C59
514C394A4532635C4A7871617D7568746E606761534F493D575347565448575549555347
59574B625E556E67618A807E978C8A9B908EB3A8A6D6CBC7D1C6C0B1A79E8D8078776A61
7C6F6680736A83766E837970887F76887F76837A71827C70857D708B8376867F6F827B6B
847D6D837C6A877E6F8B82738E85768E86798981767F776C8B8279ABA49AC3BFB6BFBCB3
87877D67675D7272669090848D8F8187897B89897DA3A397A6A69A8A877E69665D4E4B44
4A494442413C433F3C4C4847514D4E47454666616589878C7A787D6C69707C79808B888F
625F6646434A3C394038363B3B363A3D383C3B363A3D393A3D3B3C38373532332E34352F
393A343839313C3F3641443B41443B41443D3E403B383A37393939393A3C38393D383C3F
3E41463E41463B3B433A3A423D3C443C3B433B39443B39443B3B453B3B454D4D5767676F
65666B4E4F5344474C50535A494C5540444F4549554349594A4F62484E64484E66555A77
707794838CAB8E94B68D93B59498BB969ABD989CBF999DC2999FC3999FC3999EC4989DC3
969EC3959FC2949EC1919EBE92A1BE90A1BD90A1BF90A1BF91A0C191A0C192A1C292A1C2
929FC2919EC1939DC1929CC0909DC08F9CBF8E9AC08C98BE8997BC8B99BE8797BB8595B7
8598B98295B58494B58393B47F92B07E91AF8191B28090B17C8CAD7B8BAC7D8BAE7B8BAD
7686A87888AC7786AD7988B17887B07685AE7786B17685B07887B27786B17582AF7380AD
6F7AA86E78A96D77AA6C76A96C78AA6A76A66874A66674A36475A162739F61749F60739E
60739E5C719C5A6F9A5A7099556D93566E94546E91556F92556D9150688C50668B52668B
52658D51648C5465904F608C4E5F8B4D5B88505F8A4E5D864D5C834D5D814E5C7F4C5B7C
4C59794D5B784D58764A58754957744655744554754553764553764351743F4D723E4C71
3E4C733F4B71414A71404A6E40486C3E47683D43633A415E
61605B78777282817C8081797D7F7480827785877C86887B85897A878B7C8C9081888C7D
7279696A71618A8E80AAAEA0CBD1C5D0D6CAB0B6AC7F857B5C615A595E57595B565D6059
68696364655F6665606B686156534A58544B635F565B574C6462567A7A6E7F8174878B7D
94988A979D8F878D7F6C726462685A484F3F2D31223034252A2C1F17170B201E122B271C
332F233A362A403A2E443E32413B2D403D2E3E3B2A3F3E2C4B4A3666655076745F787661
78735F75705C6E6956666050635D51958E84C4BDB7D9D4D0AFACA782817D999894878883
5B5C5764656074736F7D7C777B787175726977746B7B796D817F726F6C5D63604F5F5C4B
423F2C27220F514B3B7771636E685C5A564B56524755514857574D58585057574F55554D
60605876736E837E7A8B83818E8381928785A39594BCAEABBAADA7978A828679717E7168
7C6F667E746A80766D7E756C817A70878076847D73847D73857F73888276868072847E70
868070867F6F8B827390877890887B898174898176776F6480786DACA499AAA399979388
827E728785769A97889492837372606A6859898778B9B7AABDBDB196968C7171696D6C67
6B6C6661605C5F5B5A5E5A59605C5D5F5A5E7872768F888F88818979727A574F5A564E59
3F38403C353C453E453F393D3832343A34363C363844403F42413D3E3D383B3A353C3D35
3D3E363C3D3540413944473E44473E40433C3C3E393C3E3B4040404343453F3E433A3B3F
3B3C4148494E47474F403F4745444C43404937343D3D3A4348474F5958606A696F75747A
6D6E72494C51383B4242464F434955434957444B5B464D60474D634C526A5B617B737895
8289A69096B69197B99195B8969ABD9A9EC19B9FC29B9FC29AA0C49A9FC5999EC699A1C8
99A1C696A0C496A0C393A0C292A1C090A1BF91A0C192A1C293A1C493A1C4919FC2919EC1
929FC2909CC2929BC2949DC4909CC28F9BC18D99BF8B97BD8B99BE8A98BD8898BC8696B8
8396B68295B58495B38093B17F92B07F92B08091AF7E8EAF7E8EAF7C8CAD7C8CAE7989AB
7989AD7887AE7887AE7A89B27988B37988B37986B37885B27683B07481AE747FAD727DAB
7179AA727AAB6E78AB6C76A96D77A86B77A76975A76674A56374A26172A05F719F5E709E
5F719F5C719E5C719E5A6F9A586E97586F98576F95556D93566E94536B8F52688D50668B
4F628A51648C5366914D608B4F608C4E5F8B4E5D884F5E874C5B824D5C834D5B804F5D80
4D5A7C4C56794D577A4A547749567848557846547946547B46547B425077424F79404D77
404C763F4B7540497240486F41496E4147693E4363393E5C
5E5F596F706A76776F73756A6F7166777A6F84877C878A7F888B80878A7F8D908593968B
7E8075797B70ABACA4C3C4BCC4C5BFA1A29C747770686B646C6E695C5E595757555F5F5D
6466636F716C6D6E696C6D675F60584D4F4452524654554756574977786A7A7C6E7D8172
8286778A8E7F878B7C7175646569585D61504047353337263032241113051D1D11403E32
3E3A2E3834283F392D413B2F423C2E4744354A47384441305451406B6855706D5A716E5B
6B695465634E706B586A64545F5B4F6A665B8E8A81AFACA59D9C97706F6A71726C767771
60615B54574E5A5B53686A5F77796E797B6E7C7C707F7F737E7F716866595654474A483B
45433434322345433662605459564D55524B56534E57565258575357575555555361615F
76767481807E8581808A86858F87858B8380837977887D79928781867C7382786F837970
7B71677E766B7D756A7C756B827B71867F77837C74847D75827E73868277878378817D72
8581758985798E877D938C828B8579827C70857F73857D7280786B8E86798D85788C8477
8A83739A9381A79E8D9C95825D564456513E777163A9A599CBC9BDA09D9474746C767570
7877726E6D6884807D817B7B766D6E746B6E887D838C81878C81897B70783F343C3C3139
473E4341383B41383B42393A3E39363E39363F3B3845413E45444041403B42413C42413C
403F3A40413B42433E45464141413F41413F43434343434547454846444947454A3D3C41
3334384C4D515B5C604E4F534546484747473F3D3E3E3D3B5A5A5A8E8E8E8F8F916D6C71
57585D4C4F58414551444A5A464D60434B60444C634C536D4D54705D6480777C9A898EAC
8F94B49499B9969BBB9B9EBF9A9DC09B9EC19B9FC49B9FC49BA0C69BA0C699A1C899A1C8
99A1C697A1C5949EC2959FC3929FC191A0C1929FC193A0C2929FC1929FC1929FC1919EC0
909DBF909DC0929CC0919BBF8E98BC8F99BD939DC18E9BBE8B99BC8A98BB8997BA8797B9
8295B58396B68093B38194B28194B27E8FAD7F8FB07E8CAF7F8DB07F8DB07E8AB07B87AD
7C88B07987AE7A88AF7987AE7C89B37B88B27B86B37984B17782AF7580AD767EAC7179A7
7179A86E76A56D78A66B76A46A77A46976A36A76A66775A46475A16376A16273A15E709E
5F719F5E709E5D709B5E719C5A6D97566C95576D94546C92556D91526A8C51698B4F6789
4D64864F66884F658C4D638A4F628A4C5F87485B834A5C84495B814B5D834D5C834E5C81
4B597E49567949557B48547A48547A47537B44517B45527C44537E41507B404D79414E7A
3F4C783C47743D45733F467240486F3D45693C42643B4060
6C6F68888B8274756D6264595F62576E7168888981898A84898A848487808B8C8692938D
959690A0A19BCCCBC6C7C6C1A7A6A1898883696A645E5F5960615C62635E61615F646462
6365626F716C6D6F6A696B666B6E655B5E5354584A5B5D505B5D4F6B6D5F7C7E707B7D6F
7D7F718182747B7D6F7274666669585A5D4C4044333135242A2C1E1F21132C2C20424034
3C3A2D3C382C3B35293B3529403A2C494637514E3F524F3E5D5A496E6B5A6B68576D6A59
64614E5F5C496963536E685A655F53645D53726E6589857C86817B6F6C6557574F606056
67695C737568787A6C6B6E5D7275647B7E6D7C7E708385777071635D5E5058584C47473B
45453B484A3F484840504F4A504F4B504F4B5351525856595454565A595E636267727176
807F848585878684878A86878C88877C77746B6361766E6B7E77718079717F766F827970
827C70827C707D776B7B756980796F88817989827A878078837F7686817B8A857F84817A
8D8A819592898D89808A867D76736A706E62858175938D7F8983736F6856726B59968E7B
9E9381A09581A59A8698907B58503D47402E6861517B7567918D818E8C8086837C7E7B76
75726D7C7974A5A09DA1999782797A7E73778E81888C7F8684777E61545B2F22293E3337
4C4243483E3F463C3B473F3C413C383F3A3643403B47443F46454043423D44433F41403C
41403E3F3F3D4343434343433D3D3F3E3F4144434847464B4A494E47464B4A494E48474C
35363A44484B5D5E60565A5B5052514D4F4C4747453E3E3C6769669EA09F88898D5C5D62
41444D474B5744495C454B61434A64454F6A444B68525B78636A87767D9A9297B7989DBD
979ABB989BBC999CBD9B9EBF9A9DBE9CA0C39CA0C39CA2C49AA0C498A0C499A1C698A0C5
9AA4C896A0C498A2C698A2C694A1C495A2C595A2C593A0C393A0C393A0C393A0C3919EC1
919EC1909EC18F9BC18D9ABD909DC08D9ABD8F9CBF8B99BC8A98BB8997BA8896B98797B9
8396B68396B68093B38194B48292B47E8EB07E8CB17E8CB17D8BB07A88AD7E87B07D86B1
7D89B37C88B07B87AF7E8AB27D89B37C88B27B87B17985AF7682AC727EA8707CA4707CA4
727BA46E7AA26B779F6A789F69779E67769F65749D65749D6576A162759F61729E5F709C
5F709E5C6E9C5C6F9A5D709B596C97576A94556892536990556B9050688A52698B4F6887
4F66884F66884D64864A60854B6186495F844A5D854A5E83495B814B5D814D5C834C5B82
4D5B804B577D49557D47537B49527B46527C444F7C404D7942517C41507B424F7B404D79
3F4C783C49753D45733D46713E476E3B4568393F5F353C59
6C72687F857B6669605A5D545D5E566C6D657F7E7A82817D8786848888868B8A88A4A4A2
C2C3BEC4C6C1C2C3BD888983595A5271726A7E7F7763645C53544E5F605A63645F656661
666863686A65656A64656A646B7069686E6463695F65685D54574C55574C686A5D646458
68655C7370677572696D6A616565594A4A3E3B3B3134342829291D3434283E3C303A382C
3836293B392C3B372B413D314441325250415C5B496564526867556A6957686556656253
635D4F625C4E645E52696357675E556259506A5F59746B64776E67655E544440354E4B3C
5E5D4B6766526C6A5580806874765E74765E82846F868775686B5A57594B5D5F5452534B
44453F4648434949494C4C4C50505252515657565C5958605C5B636A68737A788385848C
8D8A93908D948E89907D787E726E6F5C58575D585585807C87827C868279807D74848276
8B897C89877A7D7B6E7D796D827E7289857A898278888179867F798A827F948C89908B87
9B96928E898578757065625B5E5E5475756999978A8C8B796E6B58736E58958F799E9880
AEA68FB6AE979F97826A624D433B284E47345B5442595240777161837F73817D7476716B
87827E9B9692B2ADAA9B92937D7477867D8090858B857A806D626842373D2C212544393D
423839443C3A49413E47423C413C36413E3748453E49464147443F45443F41403C3E3D3B
413F404141434140453D3E433D3D453D404748494E4B4E534C4F544A4D5253575A484C4F
35393A494F4F5B5F62575C5F4D51524A4E4F5357584F53566C707373767B5A5D664C505B
474A59464B5E43485E474D67454A6749506D595E7C7278988287A79297B79BA0C09B9EBF
9DA0BF9C9FBE9BA0BE9DA2C09A9FBD9DA2C29BA0C09CA2C29BA1C19AA3C29CA5C699A3C6
9AA4C798A2C59AA4C895A2C595A1C796A2CA94A0C894A0C892A0C7919FC6919FC68E9DC6
91A0C9909FC88E9DC48C9BC28B9DC3899BBF899BBF8799BD8698BC8696BA8797B98595B7
8396B78295B68494B68090B48291B8808FB8808DB97F8CB87B88B27B88B27D85B37E86B4
8088B67E87B27E87B27F88B38089B27C88B07985AB7884AA717FA2707EA1707FA06D7C9D
707D9F6E7D9E6B7A9B6A7A9B68789966769865759765759762749862749A62719A61729D
5E6F9B5E6F9B5A6B99596A9857689656679356679354679153668E50668B52668B4F6688
5064894E65874B62844960824A6284496183475D824A5E83485C7D495C7D49597D4A5A7E
4C5A7F4B577D49527B48517C4A517D48517C444C7A434E7B3E4B773F4C763F4C763E4C73
3D4C733E4C713B496E3C496C3D4A6C3C4767363F5C333D58
646C5F60665A595C535A5B535D5E565B5A5576726F8E8A898D8C8A8D8C8A9B999AC1C0BE
DBDCD7CBCCC792938D65665E5052475E60556161575C5E53595A525F6058656660666761
666962676964666B676A6F6B6B706C707571777C766A6F695F615C5558515758525C5B56
5C595465625D69665F66635C3F3C33322F2639362D4542393D3D313E3E324745393D3B2E
3836293937283B392C413F304B4C3C6566566869577374626E6D5B62614F636152646054
605C50625E52625B51635C52685F5660564D5C4F49675A546B605A675D5450473E413B2D
4F4A3756513D4B4630666249706E557272587978637A7967605E4F55554957574F53524D
4848464A4A4A4C4B50504F5454535954535B55545C615F6A75737E85838E87868E8D8C94
908D94949198918C92635E62494546504A4A696363948F8CA4A09D95928D888782A5A69E
AEB0A5A3A5987A7C6F7A7B6D82837589877A89877B89857C827D778C87839994919E9996
9893907B77744F4B483D3C37494A4274766BAAAA9E7576665E5D49918F7AA39E8897917B
AEA892B9B39D98917E6B64523D3624423B2951483759503F776F62877F748B827B8C837E
A29A97ACA4A2A49B9C8B8285827C7E8B858790878A7C7376544B4E21181B271E1F363030
3D383545403C49463F48453C43403743433949463D47443B48453E44413A403F3A43423E
454344404042403F443F40453F3F4745454D4E4E564F4F5752555A6C6F7475797C595D60
3F43445155566B70735E6366383D4062676A7F8488666E715D6568474E54424953444A58
474E5E474E61474D654A506A4D526F5D6280767B9B9095B5979BBE969ABD9C9FC29B9EBF
9C9FC0A0A3C29DA2C29BA0BE9CA1C19BA2BF9CA2C29AA3C29BA4C39AA5C39BA6C69AA4C7
9BA5C89CA6CA98A5C896A2C898A4CC98A4CC95A1CB95A1CB94A1CB92A1CC929FCB8F9EC9
8F9EC98D9EC98B9CC78799C1889AC28698BE8799C18799BF8698BE8898BC8696BA8595B9
8494B88494B88493BA8291BA808FBA808EBB828EBE7F8BBB7E8BB87E8BB77D88B67F87B6
7F87B57E86B48089B47E87B07C85AE7884AA7986A97582A57281A27180A16F7E9D6D7C9B
6F7E9D6C7D9B6B7C9A677A986578966578966474956373946073946274986271985F6E97
5E6F9A5D6E9A586997566795586997576A9555669255689251648C51658A52668953678A
5165884D61844A6183496082496183486082495F844B5F824A5E7F495C7D4A5A7C48587C
4C5A7F4B577D48517A4A517B4A517B454E77444D78434F793F4D743F4D743E4C733C4C70
3D4D6F3D4D6F3B4A6B3A496A3B48683A456337405D37415C
505648585E505E615661635864645C615E59736F6C928E8B928E8B9C9895B7B3B2D4D3CF
C1C0BB96968E6B6B616363595A5A4E59594D57544B54544A5A5A5262625A605F5A63645F
6769646365626A6B6D7172746F7376777B7E7A7E81676B6E65696A696A6C595B5A60605E
6464626A696561605B54544C323228303026413E354F4D414D4D41494A3C494A3C414232
3C3D2D3D3E2C3F40304B4C3C585B4A6B6E5D6A6D5C6669566263515D5E4C5F6050636154
605E4F626051605C5060594F635A51675C56594C46534640655852766B675E5550423932
61594E6961545851415B5442726B597A7361746D5D6C645960594F564F495048454C4646
4C48494E494D5550565A555C57545D59586064636B706F777D7C828382878B8B8D8E8E8E
91908E9998969E9A977B767347423F4F4745867D7E9E9596A8A2A49694958E8E8EBBBDBA
CDD4CDC7CEC69BA3967177697C8373898D7E8C8E8189897D82827887847D96938E989491
8A8685706C6B4B474638373346474175766E80827757574B7270639F9C8D9D9A8B979183
969082A49E90989284797365504A3C48403351473B594F43776D64827771B1A3A0A99B9B
94888A968B8F9990958E888C8A8589858182817D7E635F5E3C3B391D1C1832312C393A34
3E3F3740423745453941413542433541433545463847483A44453745453948463A4A473E
4946413E3D39403E3F44424544424749484D4F4C5357545B6D6C7498979D95969A68696D
3D3E425D5E627F828772777B494E52666E7182898F5D666B455054404B51454F5947515D
464F5E474F624B53684F576E636A867F86A39398B89A9EC19B9DC39A9CC29CA0C59CA0C5
9DA1C49EA3C39EA2C59EA3C39DA3C59CA5C49AA3C49AA3C498A1C299A3C69AA4C797A4C7
98A5C898A5C897A3C997A3CB96A2CA96A2CC97A2CF98A3D0949FCC929FCC949FCD919ECB
909ECB8F9EC98D9CC78A99C48998C38A99C28A99C48796BF8695BE8794BE8995BF8692BC
8390BA8390BC8491BE808DBA808DBA818DBD808CBC808CBC7D8AB77D8AB77D88B67F8AB8
838EBB818CB97F8BB57884AC7682AA7884AA7683A67482A57281A26F7E9F6E7D9E6B7A9B
6A7A9B6A7A9B6C7C9E677A9B6477986277966174956073946171936373975F6E955E6D96
5E6D985D6B98596A96596A96546792556B94556890546A8F51688A506485516685526585
5064854F63844C60814B62824A6181485F814B5F844C60834C5F804A5D7E4A5A7C49597B
4B597C4956794852764A5478495377475175464F76414D734250754250753D4D713B4B6F
3C4C6E3B4B6D3948693B486A3C47673C476337415C383F59
545C4F5B6155686B607274697272686A67607D7A7595928D9F9C97C3BEBBDDD8D5D0CBC7
94918A66635C5E5B525C59505B584F5E5B5456534C5655505D5C5761605C5E5E5C646462
66686766686766676B71727775787D76798071747B6B6E736C6F746B6F7267686A6D6F6E
6B6C675F605A40403830302637372D3E3E324F4D415B5C4E5A5B4D4F5241484939434635
4445334647354A4B395C5D4B7174637073626265546164536263535E5F4F5D5D515D5D51
5E5F51606153605E525E5A4F615A52665D5661565040332D4C3E3B867B777065634F4440
6B605A6D635A5349405B51477D7369746A60695C546659535C514D483E3C493F3E4B4243
4E484A514B4F5750575952595B565D6D6A717F7C838281868787898D8D8B91918F91928D
908F8A96968EA5A29B918E8758534F433E3B766D6E8D8789ACA7ADA19FA49F9EA3B7BBBC
BAC0BED8E1DCD2D9D1727A6F7880738C92848D91838B8D828383798A8A82928F8A908C89
7D79785A56554C48474E4D495655506E6D68605F5A5D5A5396938CA09C93938F86918D84
8C887F8B877C8E8A7F7E7A6F494238524C40544C41483E35756862A29493B2A4A4998A8F
92858C968B93948A92928C908C8A8D81818160605E3A3A382C2D2830332C383B34363C32
393F353C3F343B3F313A3E303B3F3040443546483A44463843443645463849473A49473B
4A473E47423C4D4845514B4B4C4648534D4F6A6468746D748A838A97929889878C747275
615F6478777C898A8F7E81866C717772797F666F763D484E454F58435059404C58485462
485464465262525A6F6C748B8D94B09299B6989CBF9B9FC49B9FC59DA1C79FA3C99FA4CA
A0A4C9A1A7C9A0A4C7A0A6C8A0A6C89EA7C89DA5C99CA4C89CA4C99BA5C99DA7CB9BA4CB
9BA4CB98A4CA98A4CC98A4CE97A3CD939ECB95A0CD96A1CF939ECC939DCE939DCE929ECE
929ECE909ECB8E9CC98D9BC88D9AC68C99C58B98C48895C18693BF8794BE8793BD8591BB
828FBB8390BD818EBB7F8BBB818DBD808CBC7E8ABA7F8CB97D8AB77D8AB77D88B67D88B5
7F8AB77C88B27A86AE7884AC7884AA7682A87482A77280A37381A4707EA16D7B9E6A789D
69779C6B7B9F68779E65779D6375996276996375996072966174956171935F6F935F6E95
5F6E975C6B96596A95576893576A92556B92556B90546B8D4E65854C63824F6481516482
4F64834F64834F64834B607F4A5F7E4B5F804A5E814A5C804B5E7F495C7D49597B4A5A7C
4B5A7B4D5C7D4754764852754653764653764552753F4D72404E73404E733F4D743C4C70
3D4D713B4B6F3A476A3B45693A44673C4564373E5B363D59
555F575C635C6D736973756A6F6F65726F6688857CA09B95BCB7B1DDD5D2C9C1BE958D8A
7D7572726A6771696759545154504D5D59565F5D5E5C5A5B5E5C5D5F5F61606163626367
61656663676A696D7073767B6E71766A6D726C6F746A6E716D6E70707271717370767873
72736B5C5E5340423735372A4244374A4C3F5555496162546163555559484E51404D523E
4C4F3C484B38595A487172606F705E68695963645464655768665A646256605D56615E57
5E5E5658585077746D817C76716A646057525C534E483D393E332F736864786D6B504241
5244416B5D5A60514E5545456153525A4C4B5C4C4D625454514545423837473D3E4D4445
4D4747544E50554F515D575B6F6B6C7F7D7E8583848988868C8D8891928C90918B909189
8F918692948997978D82827A5E5D5862615D7874738D898A9B999E9F9CA3A7A6ACB9BABF
CDD1D4E7EBECDCE1DD969B957479728F92899DA09798999187877F85857D8C8984918E89
77746F4B48434F4C47635E5A66615D635E5A554D4B7C74729C94928D858388807E8C8481
89847E86837A8C887F868277646055645D53635A51594E48716664867A7C8D80878A7F87
8D838B8C858C8B868C8B898C88888A696B6A5456534E534F3D423C353C34383F37384035
3941363B4137393F33393F33393F333E4438464A3C47493C45453943433749473B4B493D
4A463B49423A554C475C514D584D4B5D51517B6F6F8E84858C8283857C7D7B7275756F71
7B7579817C828E8B9297979F8D9099666D77474F5A404A5646505C434F5B43515E4A5865
4956664F5B6B6B7388858DA4979DB7999EBC9B9FC29FA3C89CA0C69FA4CAA0A5CB9EA6CB
9FA5C99FA7CBA1A7CBA0A6CAA0A6CA9FA5C99FA4CA9DA2C89FA4CC9FA4CCA0A5CD9EA5CF
9CA3CF9BA4CF99A2CD9DA5D398A3D095A0CE96A1CF96A0D1939FCF94A0D294A0D4939FD3
939FD1919DCF909CCE8D99C98D9BC88998C38B98C48996C08897C08695BE8593BA8392B9
8392BB8493BE808EBB7E8CB97D8BB87E8CB97F8DBA7E8CB9808EBB818EBA828DBA7E8AB4
7C88B07A88AF7785AA7684A97684A97583A87480A6737FA57280A5707EA3717DA56A77A1
6D7AA46875A16B78A46776A164769E65779D64769C6072985F71955C6F905D6F935C6E92
5F6E955D6C93586A90596B91576B90586C8F586C8F5468895067874F6685526784516683
5063815164825063814D607E4B5E7C4A5D7D495C7C485B7B4A5D7D495C7C4A5A7B49597A
4A5A7C4A587B485578475477445277455378445279404E753F4C763F4C763E4B753D4A74
3C49733D49713D46713D446E3B436A3C4468383C5F363B5B
5B66605C665E696F656C6E637070648684789C988FC0BBB5E7E0DAD9D1CE827A78766E6C
8F8687817879756F6F625C5E5753545D5B5E5D5B6055545A58575D5B5C615F6267616469
5F626761666A686B70696E72686C6F656A6D686C6F696D6E6C706F737572747671747770
6F726765675A4E50434A4C3F5456495456495B5C4E6061535B5E4D5A5E4D555A46515642
585D49575A475B5C4A6567526263516364526866576866596B695C67675B64615856564C
4F4F456F6F65A3A399B5B2A98F8B82605C534F4840514A42463D365F5651655A563E3331
483A3A796B6B57474A37272A4334394E424656474E5649504B3F43493E424C42434F4647
534A4D524C4E564D50736D6F8781838B85858C88878E8A8791908B94938E9191898F8F85
8E8E848D8D838D8D8570716962635D72736E7573747D7B7E97959ABCB9C0C6C5CBE3E2E8
E8E7ECE0E0E2DAD8D9B0AFAD7F7E7CAAA9A5BCB9B49F9C9789867F85827D8D8A858F8B88
7875703E3B36635E5B75706D716967635A5B71666A8A7F838B8084857B7C867C7D89817F
86817D87827C8C887F8B877C7A766B6F6B60675E55675E576F6563817879898085898289
89848A8A85898886898888887779785C5E5D5B605C5C615D424741363D353C433B3D443C
3E443A3E443A3B41373C423840463C41473B444A3E44483A41433548493B4E4F41504E41
4743374C453B594F465B504A5D4F4C675956867877928686897D7D796F70776C70766D72
7069707E79809D9AA3A19FAA7375824B4E5D4B5161495062485162475363475363505B6D
4954665E697D8E96AD969CB6999EBB9EA3C1A0A4C79EA2C79EA2C7A2A7CDA4A9CFA0A8CC
9FA7CB9FA7CB9FA7CBA0A8CCA2A8CCA1A7CB9FA4CCA0A5CDA0A5CFA0A5CFA0A5CF9EA5CF
9EA5D19CA5D09CA5D09BA7D199A4D197A2CF97A2D096A1CF96A2D2939FD1939FD3929ED2
949ED3919DD1919BCE8F9BCD8D99C98B98C58A97C38A97C18895BF8594BD8694BB8594BB
8493BC8392BD8290BD7F8DBA7E8CB97F8DBA7E8CB97E8CB9818FBC808DB97D88B57C88B2
7A88AF7785AC7583AA7785AC7684AB7381A8737FA77381A86F7DA46F7DA46E7AA46D79A3
6C79A56976A26774A065749F63759D64769C62749C5F73985D71945C70935D71945B6D91
5C6E92596B8F57698D5A6C90576B8E566A8D576B8C55698A516887506786546986506582
51658050647F5162805162805162804D5E7C4D5E7C4D5E7C4C5C7D4B5E7E4B5B7C49597B
48587A47577946547946547942517845547B44517B3E4B75404D793F4C78404B783E4976
3E47723E47723E45733D44703C436D3D42683B3F643A3D60
58645857625463695B6A6C5F8181758D8A81ABA6A0DFDAD6C6C1BE8B85857A74768B8587
827E7F716D6E757374686669605F645F60645354595659605E61685D606763686E656A70
656A70646C6F656A6E5E6668656B6B636C6B676D6D696F6D7076727479737277706F756B
646A5C676B5C63655756584A595B4D5B5D4F5B5B4F5B5C4E5A5D4C5A5D4C585B4A585B48
676A57686A555D5F4A51503B53523E605F4B6B6A566A69576667556366535F604E4E513E
464938747766A9AC99BDC0ADB9BAAA8A8B7B4243354B493C555146524E43534C46443A38
443A3B4B40443D3037382B344337414D414B493F4A493F484B41494E43494C414554494D
554A5060575C796E74877E838B828590878892898A948C8A99949097928E938E8A938E88
93908985827B78757075747074736F7B7A787C7C7C6E6E7088878CB7B6BBD1CFD2E2E0E3
E3DFE0E0DADCE9E0E1C2B8B9A4989ACDC1C3C0B6B5988E8D8D8582837B788781818B8585
7874735F5B5A7D77797A74786960656D64698378808A7F87887D83877E81887E7F8A807F
8B83808881798A8379908A7E8884787F7B6F716D61716D61807D7486837C8A86838A8987
8C8C8A89898785878492949181868260656163686454595541464042443F46494244453F
3F423942453C44473E42453C46493E41473B42483A4047374145344E533F585B48515240
424333484637534D41584F46554A4473686690848492868885797D7A6F75776C74736972
726A75807A86837F8D66647255546254566555586B4D52664D52684C52684F556D585F79
6A708A888EA89499B6989DBA9CA1BF9DA2C29FA4C4A2A6C9A2A6C9A3A7CCA3A9CDA1A7CB
A1A9CDA2ABCCA0A9CAA0A8CCA2A8CCA2A8CCA1A6CEA2A7CFA0A5CD9EA6CD9FA7CE9CA5CC
9DA6CF9AA6CE9BA7CF99A7CE98A5CF96A3CD95A1CB97A3CD949FCC949FCD959FD0959FD2
949BCF919BCE939ACE8E98CB8F99CA8D98C68C94C28D95C38894BE8592BC8692BC8693BD
8592BC8491BD8491BE7F8CB9818FBC808EBB818DBD818EBB828FBC818EBB7D8AB77986B2
7885B17685AE7683AD7683AD7281AA707FA8727FA9727FA96E7CA36C7AA16E7AA46C78A2
6A77A16877A063729B64739A63759B6375995F73985E75975C72975B7196586E935A6E93
5C70955A6E93586C91576B90576B8E566A8D566A8B55698A536887546988536686536684
50647F50647F51627E50617D505F7C505F7E4E5D7C4C5C7D4D5D7F4A5A7C49597B48587A
45587944547642527643527943527B42517A424F7B414C79414C7A414978414978424A78
4047733F46723F46724146703F446C3F43683C3F623B3E5F
505C48525B486A6E5D76786A7E7C70A29F96C9C6C1D5D1CE8581806C6869807E81807E81
5A5A5C58595B6566686F7072686C6F52565954595C61666A5F64685E6369686D736B7076
656C72676F7261696B606968646D6C626B68656E696C75706B756D6E756D6A72676A7064
697060676E5C5C604F595C4B5F62516061535C5D4F5C5D4F5E5F515D5E50606153656658
6C6D5D72715F6A69575A5945555440555742605F4B60624D61644F61644F5F634C4D523B
3136204F543E878C75B8BDA6C0C3AE999C894447364F50405250434B493D4A463D4E4945
4B4341332A2D382F34463C44493F484C424B473F4A453E464D434B52494E51464C54494F
62575F7C7179877C848C818993888E9A8F93988D91978D8EA69C9BA19795938987938987
89817E78706D78706E7A75727872727A76778785887472757E7C81B7B5B8ECEAEBE8E4E3
ECE6E6EFE7E5F3E7E7CDBFBFA89A9AAB9D9D9486868D82808C8280827A77867E7C847E7E
827C7C7D79787C7678716B6F6E656A898085A2979F9F949A8E83878A8081897F808C8281
8E85808A817A8D847B8C857B959185A9A5998C8A7D7373677C7C7284857D8C8D878D8F8A
8F918C80857F7D827E8C918D6F7470575C586469655C5E5B494B4648494447464145443F
42413C42433B45453D4041394042373F4237464A3C434A383D45304E533D71745F6D705B
595A484544324C483C544D4359504B7C72708E848591868A8E8389847A83796F7A6C6471
655F6D625E6C5C5A684F4E5E504F5F52536553556A50556B4D516A5359736368857A7F9D
8F94B29BA0BE9EA3C19FA4C4A0A5C5A0A5C5A2A7C7A3A7CAA1A5C8A4A8CBA4AACEA4AACE
A2AACEA4ACD0A4ACD0A1A9CDA4A9CFA2A7CDA2A7CFA2A7CF9FA7CEA0A8CF9DA6CD9BA4CB
9AA6CC9BA7CD98A6CD97A5CC98A6CD98A6CD96A4CB93A0CA949FCC949FCD959FD0959FD2
949BCF949BD19299CF8F99CE8F99CC8C96C98D95C68D95C48893C18994C28792C08592BF
8390BD8491BE838FBF7E8CBB818FBE808EBD818FBE818FBE808CBC7E8CB97C88B87785B2
7684B17584AF7381AE7483AE7180AB7180AB7281AC7180AB6D7CA56A79A26E7BA56B78A2
67769D68779E65749B63759B64769A6074975F73965F73985C72975A7097596F965B7198
586E95596F96576A92596C94566A8F55698E54688B536788516586516586536686536686
5164825266814F607C4F607C505F7C4F5E7B4E5D7E4D5B7E4D5B804A5A7E49597D49597D
46587C43557943527944537C43527B42517C424F7B414C79414C7A3F4776404877414977
3E47723D46713D446E3F476E41466C3F43663B40603B3E5D
565F44565B4480826D8886777D7B6FAAA7A0BBB7B49493916E6E6E6C6D6F757678707173
4A4E4D4B514F646A686A7370626B68525B565C6560656E6B646D6C666E706C7477687073
636B6E656D6F636D6E656F6E66706F616C66646F6769756B636F63626D5F636E5E666F5E
6B7463686F5D6064536265526768566462535E5C4F5C5A4D62605469675B6C6960726F66
6E6C606C6A5E6B695D6A685B5C5D4D50534050513F575A47595C475C614B5459434D553E
3A422A3C412A747963A7AA95A9AC97888B784F5040504E414D4B3E4543374542394B4841
4E494546413E4842424B4545494345514B4D514B4F4B4549534A4F574C525C4F566D6067
7E737B8C808A90838D90838D988D959A8F959B90969A8F93AA9EA0ACA0A0897B7B695B5B
7E7070958787897A7D786C6E7A6F73766D70767074979296B4AFB3BEB9BDD3CFD0D7D3D2
E4DFDCEDE5E2DAD0CEC0B5B38B807C7A6F6B8980799087808E877F878078827B75817C76
85807A87827C706B68736E6B938A8B9E9596B1A7A8AFA3A5968A8A8F84828D82808D827E
8E837F90857F9186808F867F9C958DB0ACA3A19E978F8F878687818487808B8D88929793
9096927F8581777B7A6C706F5456556365647173705E5E5C4B4C47494A454948444A4742
43403B3D3C3743403B3D3D3539392F3B3D32434538464A3B474B3A484D3970735E797C67
5859473E3F2D4E4C3F514D425C5751766E6C7D7477837C839790989C96A2857F8D605C6A
5D596754525F504F5D4C4E5D50516551536852546D525671525774646B887E85A2939CBB
98A1C098A3C19AA3C29CA5C69EA7C8A3A9CBA3A9CBA4AACEA2A8CCA3A9CDA5AAD0A4A9CF
A0A8CDA2AAD1A5AAD2A3A8D2A3A8D0A3A8D0A2A7CFA2A7CF9BA2CC9CA3CD9DA4CE9CA5CE
9BA7CF9AA6CE96A3CD97A4CE97A6CF94A3CC94A3CC94A3CE929FCB929FCC94A0D2929ED2
929BD29099D08F98D18D96CF8D96CF8B94CD8A93CA8992C98891C88692C68591C58490C4
8591C5828FC38290C1808EBF808EBF7D8DBE7C8CBD7D8DBE7C8ABB7889B77886B77485B3
7586B47283AF7283B17283AF6D7EAA6D7EAA6F80AC7081AC6A7BA66C7EA66C7BA46779A1
66789E65779D63759D65779D6274986074975F71975D6F975C6F975B6E985D709B596C97
5A6D98596C97596B99576A9553699253669052658D53658B5163894F6185536687526585
52638150617D4F607C4E5F7B4E5E784D5C794E5B7D4D5B7E4C5A7F49577C47577B48587C
43557944567C44537A42517A43527B414E78404D79404D793F4C783E49763D48753C4872
3B47713A466E3743693946693A44673D46653C415F393E5B
686E526C70578587728785768482768E8E868B8A866767656365645E62636468696A6E6F
585E5C5A6360636C69616C68616C6665706866716B65706A636E6867726E6B74736B7375
687170656E6D666F6E68727167726E66716B677169646E65646E63636E60656D5E67705F
69705E696D5C6669566B6C5A6D6C5A686554655F51655F536D665C7069616F68606F6B62
6D69606D6A616E6B626A6A606C6E616062545153454B4F40565A495358444A523D49513C
444C37424A33686D59848975878A777275625D5E4E47483A44453749493D48483E4D4D43
524F4A5756515C585557535255515054504F545051554F51534D4F655C5F6D62687C7177
847A828B8189928690938890998E949B90949B90949C9293988C8CA193937A6C6B574948
8173728F8180928484867A7A7E74758A8182817B7BB4AEAEC1BDBCB0ACABC4BFBCD5D0CC
D6CECBDCD5CFD4CBC6A89D997C716B857A74918680948B8291887F8C837A867D76877E77
867F75857E74766F6978716BA29896D3C9C7BEB3B1A294918F817E8D807A93847F93847F
8F807D8F807D958784A79C98A89F9AA29D999C9994AAA9A5979893868883858784878C88
8C928E727874686D69646867595B5A6163626466634F514E444641464742494A454B4A46
42413C3E3D3842413C4141393E3E363F41364244374345384B4F3E4D5140565946575A47
4D503F4C4D3D4F50425452466A6762787370817B7D8C878D9C96A086838E5E5A6854525F
59576452515F4E505F4E51624E516451566A545871636983757A978990AD9CA2C2A0A9CA
A0ABCBA0ABCBA0ABCBA0ABCBA4ADCEA2ABCCA4ACD0A5ADD1A5ABCFA3ABCFA6ACD0A3ABD0
A3ABD0A4ACD3A2A9D3A2A9D3A2AAD1A1A9D09FA7CE9EA6CD9EA5CF9EA7D09AA3CC9BA4CF
99A5CF98A4CE96A3CF96A3CD97A4CE94A3CC919ECA93A2CD93A0CD93A0CD909CCE919DD1
919CD2909BD1919AD38F9AD28E99D18C97CF8A95CD8590C88693CA8693CA8491C88491C6
8390C5828FC38390C47E8CBD7E8EBF7C8CBD7C8CBD7B8CBA7888B97787B87585B67585B6
7788B67687B57482B17182B06E7FAB6E7FAB6E7FAB6A7BA66A79A4697AA56C7BA4697BA3
6678A062749C62749C63759D61759A5F73985F71995B6C975B6E985B6E99586A985A6C9A
5A6C9A5A6C9C586A9A56689854699652659052638E52648C52648C52648A526488546486
5262835162804E5F7D4E5D7C4E5D7C4E5D7C4E5B7E4D5B804C5A8147567D47567D44567C
43557B45577F41537B415079404F783F4C763E4B753E4B753E4B753D4A743B48723A486F
3C4A7138466B39476A3744663A456339425F39405C393F59
767E67797E6A777A697E807385867E8788828586816464625B5D5C595B5A5D6162626667
5F6362606664636969616A67626B68656E69666F6C6A736E6A756F6B767067706B6C7570
6F78756B74716B74716B74716A736E6A736E697069656C64697068686F67696F636C7062
696B5D6A6B5B6C6B596D6A576E69566B6653635C4A5B5444787063837B70746B626E675F
6D69606E6B62716E677070686B6D62676A5F64675E5B615552584C444A3C3E44363F4636
424B3A434A3A596050666D5D6468575B5F4E5054453F413345473A4D4F4247493E4A4C41
5655506566616766645D5B5C5D5B5C5654555553545250515B595A7270717E7A7B827E7F
8A84888D878B92898E968D9099909198908E99918F938987837A758479738176705E534D
655C556A615A7E7771908983938E88A6A39C99968FB9B6AFBAB5AFA5A09AB0A9A1C8C1B9
D2C9C2C4B9B3AFA29CA5989271645E83746F94858097888394878191847E8E807D8E817B
8D8078877A7280736B7F726AB5A8A0DED1C9A4958E92837C94837C95847D98857F96837F
8F7B7A9B8786B9A7A5CFC1BEC1B6B4A69C9BA49C9AAEA8A89995948786848787857F817E
7D827C797E786D726C6267636065615F6460575C583E433F343935393E3A3F4440434842
42453E41443D46474147484042433B41433843453A424437464A3C505445585C4D55594A
4A4E3F4E50435D5F526060566C6C64807D78928E8D9591928681876562694745504F4F5B
5254604E525E4C4F5E4A50604D52655B60746569827B819B9398B59DA2C2A2A6C9A0A6CA
A4AACEA3ABCFA4ADCEA4ADCEA5B0D0A6B1D1A5B0D0A5B0D0A6AFD0A5B0D0A5AECFA5AFD2
A5AFD2A5AFD2A3ADD1A1ABCFA1ABCFA0AACE9EA7CE9CA8D09CA8D29CA8D29CA8D29AA5D2
99A4D19BA6D39AA5D398A3D09AA5D297A4D095A0CD94A1CD97A2CF949FCD929CCD919BCE
8F9BCD8F9BCD8E9ACC8E9ACC8F9BCF8996CA8794C98693C88292C68293C78393C78292C6
8292C68191C47E8EC17F8FC07D8DBE7E8FBD7D8BBA7A88B57987B67785B47785B67785B6
7785B67482B37480B2737FAF727FAC717EAB707DA96D7CA76E7BA76C7BA46B78A26B7AA3
67769F6576A163749F6475A060739B5E719B5E719B5D709B5A6F9C5A6F9C566B9A596B9B
5A6C9C5A6C9E586A9C56689A57699955679552639151628E54638C54638A526188546287
546285536184536184515E81505D80515D834E5C834B59804B588247567F45577F43567E
44577F42557D41547C40527A3D4F773F4E773D4C753D4C733C4B723C4B723E4C733D4B70
3F4D703B4A6B3946683C47673B466239435E383F59363C56
71756475796871736575776C81827A83847E8485807A7B766D6D6B6B6D6A6A6C6B696D6C
6468676064635F6563606664616A67616A65666F6C6C75706B746F6D776F6A746C6B726B
6F766F6E74707176727378746E74706E74706C716B6B6D686E706B6E716A6D70676F7166
6F7062716F606C69586966556A64546B6555605A4A4F473A655D529289807A7369635F56
65625967675D6B6B636F6F676F706865685F62655C64675E575A4F3D40353C3F343D4133
3D43353B4133484C3E55594A4C50413C4031383C2D3E42334F51435355484E50434C4E43
5C5D556566616C6C6A7072717476756A6B6D5B5C5E5E5F616A6B6D797A7C818284878988
8989898787858C8B898F8E8A94918C97948D86817B79756C6E675F766F677770685D5950
5551484C49406360578B8B81A3A59AAFB1A694948A96968C96968C939185A9A59AAAA399
ADA49BA49B927B706A776A647B6E68897A7592838096878492837E91827D8F817E90837D
8F827A8B7E7683766D7D7067A1948BB1A49B95877E93857C9B8A839A898293807C8C7877
968283AD999AD2C0C0DCCCCDC8BCBCA69C9DA69D9EACA6A69894938D8988888785777873
72746F767B74777C7670756F696E68646963535A53484F48353B37393F3B424844424844
42474140453F43463F484B4442453C393C313E403542443945473A4E50435A5C5165675C
686A5F6264596868607070687B7A7594938E93929072707166646957565C4E4E5851535F
5357635056664F566851586B545B6E6A7086848AA29BA0BDA2A7C5A3A8C8A3A7CCA5A9CE
A8AED2A5ABCFA4ACD0A5AECFA6B1D1A4AFCFA4AFCFA5B0D0A3AECEA5B0D0A6B1D1A6B0D3
A3ADD0A6B0D3A5AFD3A3ADD1A3ADD1A0ADD09FA8CF9CA8D09AA6CE9BA7D19AA6D098A3D0
9AA5D29AA5D399A4D298A3D198A3D097A2CF95A0CD96A1CE949FCC93A0CD939ECC909CCC
909CCC8C98C88D99C98C9AC98B99C88795C68795C68494C78294C67D91C48091C58091C5
8092C47F91C37C8CBD7E8EBF7B8BBC7C8DBB7A88B77B89B67886B37684B37886B57684B5
7583B47482B3737FB1737FAF717EAB707DAA707DA96F7EA96E7BA76C7BA46B7AA56978A3
6877A26778A363749F6475A061749E5E719B5F729C5E719C596E9B5A6F9C566B98586A98
576999586A9A586A9C56689854669655679553649255669255648D536289526087536186
515F84515F84515F84515D834E5A82515D854E5B854E5B854C5985485782455681455681
46578242547C42547C41537B3D4F773E50763F4E753D4C733C4C703D4D713C4A6F3C4A6F
3C4A6D3C4B6C3946683B49663C476337415A363D57373D55
77796B78796B7575696F6F6580807881817985857D85857D7B7B737A7B757475706F716C
6B6D686368645C625E5A605C5F6561626962626B666A746C6B756D6C736C6C736C6B7069
6C716A6A6F6970726D787A757779767678757272706E6F6A70716C6F706B70716B717169
7272686D6D616B695C6D6B5E6E6F615353474A4A3E46433A44413A8380798E8B845F5C55
55554D61615965655B67675D6E6E6469695F60605657574B4F51434042344142343F4032
3D3E303E3F31413F324442354A4B3D3D3E2E2627172C2F1E4A4B3B535444525345545448
64655D6E6F6A7A7C7B848889A3A9A9A3A8AB767E80697174747C7F80888B858D8F8B9493
757E79616B637D847C8E948A9093888B8D8268685E5D5D536B6B6177776F696863494A44
45463E575A5174776E8B8E85A2A89EAEB4AA878A8184877C82857A808378A8A89CAAAA9E
9492866F6B605E574D685F567C72697C72698576718B7C7790817C9487818E837D8F847E
8D847B898077867C737B716882786F9A9087978A8293867E9788839A8B86938383827273
8C7C7DAC9C9FBDAEB1C4B8BCC6BABEAAA0A1AAA1A2ABA5A5938F8C8884817E7D79767771
6E716A6D7067757A73757B716D7369666C62596058525951404740404740454A464D524E
5358544247433E403B41443D44453D393A323B3B3146463C46463C4B483F56534C6B6660
79766F7D7A756C686576726F82817D9A99978B8B8B5455574D4E524F52594D4F5B4F535F
5158684E5669535B705E667D686F898087A3979EBB9EA5C2A0A6C6A3A9CBA6AACFA5A9CF
A4AACEA5ABCFA6AED2A5ADD1A6B0D3A6B0D3A5AFD2A4AED1A3ADD0A2ACCFA6B0D3A5AFD3
A2ACD0A4AED2A2AAD1A5ADD4A7AFD6A3ACD3A1A8D2A0A9D2A0A9D29DA6CF9DA6CF9BA4CF
9DA6D19CA4D29BA3D19AA2D098A3D097A2CF95A2CF95A2CF94A1CE919FCC909DCA8F9DCA
909ECB8D9BC88C9AC7899AC68899C58798C68697C58595C68294C47F91C38191C48090C3
7F91C37F91C37D8DC07C8CBF7A8CBE798BBB7A8ABB7889B77687B57687B57687B57384B2
7384B27283B17381B07280AF717FAC707EAB6E7CA96A7BA76E7CA96C7DA8697AA66778A4
6879A56679A46376A160739E61749E5E719B62739E60739D596C965A6D97596C97596A96
576894596A9657689457689456679353648F53648F51638B53658B506286526286506084
5060845161854E5E824E5C834D5A844E5B854F5B854E5B854C598348557F47547E46537D
49568046547B43527945547B415077404F763F4D743E4C733C4C703A4A6E3C4B723C4C70
39496B38486938476839486738466038445C343F55363E53
6B6C5E7172647775687472668482768381758A887C8B897D86847888867A84847A7C7D75
76776F6E716A656A635F645D626961666D65636D64656F66697068686F67666B64636861
626760686B646D6F6A6E6F6A71726D75767175747279787476757174736E74736E73736B
6F6F656C6C606B6D5F6D6F617375685E615644453D43443E43443F60615C7E7F7A7A7B76
6A6B6561625C61625C62625A67675D6262585755494B493C4647393E3F2F444233434134
4240333E3C2F3F3B2F3F3B2F4644354A48393839293C3D2B494A38484939505143555549
6D6E667679728C8E8BA7ABAAD3D9D9C9D1D3838B8D747E807B84897D868B828C8E808A89
6F7A744A554D636D648A9287788075686E6253564B65685F74776E65685F51564F454A43
43493F6E746A9EA49AA0A69C8C9288898F858A8D868C8F887C7F786E716AA2A39D999991
6E6E6668655E716C667069637F78707F766F7A6F6B8E837F9489859087828D86808D8680
8B8680858178857E78857E767B746C948B84968D88938884938884978988998A8D96878C
998D91BDB1B5BAAFB5B1A8ADB1A8ABABA5A7A7A3A29F9B989C9895979691706F6A66675F
6E71686C6F666C72686F75696C72665F655950564C4D544C4B504A4C514B4F54505E605D
6668675D5F5C46484540413B43443E3D3E363E3E344A4A404C4C4249463F55504C66615D
6F6C6775716E7975748E8A89838280757575696A6C4F53564F525754595F515561515765
515A6B4C576B5B667C69738C848EA9969FBC9FA8C5A0A9C8A4AACAA6ACCEA6AACFA7ADD1
A7ADD1A8AED2A7AFD4A6AED3A5AFD2A5AFD3A6B0D4A5AFD3A4AED2A3ADD1A3ACD3A2ABD2
A3ACD3A3ACD5A3AAD4A3AAD4A4ABD7A3AAD6A3AAD6A3AAD6A2A9D39FA6D09EA7D29DA6D1
9DA5D39BA6D399A4D297A2D096A1CF95A2CF93A0CD919FCC909ECB909ECB919FCC8C9AC7
8F9DCA8D9BC88A9BC78A9BC78899C58899C58899C78394C28595C68393C48090C37F8FC2
8090C37F8FC27B8BBE7B8BBE7A8ABD788ABC7989BC7789BB7486B67486B67587B77284B4
7282B37283B17283B16F80AE6E7FAD6D80AB6C7DA96C7FAA6A7BA76C7FAA687BA66577A5
6577A56779A76274A261749F61749F60739E60719C5F709B5C6F975D70985C6E965C6E96
5A6C94596B93586A92586A9257699153658D54668E52648A52648A506288506288506288
4D5F834C5E844B5D854C5B844D5C874C59854B58844D5A864C598549568049568048547E
4A567E46547B45537A45547B47577B4050743D4C733D4C733E4E723A4C703C4B723A4C70
374A6B35486835486836476535475F35445B374258343F53
6869596D6B5C706D5E77746587847583806F8A84748C86768C8676918B7D8E8A7E8B897C
8A887B76766A7274696E71666B7167697166656F64636D62636D62616B626269615E655D
5E665B61665F6567626B6C676D6E6871706B75716E7874717B7A767A79747173686C6E61
6A6C5E696C5B656A567579687E8273747A6C4E514640453E454A44494E4A6D6F6E808281
8385847A7C796769665D5E5952534D4C4D4546463C3E3F31434436434434444233444233
4340313D3A2B3836293F3D30454336444235424033464435464737454636545547525246
7C7E7384877E83867FBABFB9CED4D0AFB5B3818689737B7E81898C828A8D7C81856D7275
6A706E545A565F6561878E875960593C433B4E554D636B605D675C465143414C3E566153
6A7565A7AFA0AFB5A7959B8F87888092938D9F9E9C918F9079777A706E718C878B8A888B
5452536664658F8B8A8B85858B8683797471746F6B8F8A869E999595918E8F8B8A8C8B89
8D898884807D7F7B7A807C798883808F8A87918889948A8B9A90919E9296A79AA1B0A3AC
B5AAB2CAC0C8B6AFB6AAA5A9ABA7A8ADABACA1A19FA8A9A4BDBEB9B1B2AC696A625B5E53
5E6156575A4F6164596A6D6266695E585B5045483F474C45535550565855555756757575
8F8F8F84848251514F3839333D3E383F40384748404D4E464E4F474C4C4453524D5E5D59
6E6D697574708484828C8C8C787A795E62634F54574E535750555B545861545766505666
535C6D5961767880978F96B0A3AAC4A6ADC9A6ADC9A8AFCCAAAFCDACB1D1A8AECEA9AFD1
A9AFD1A7B0D1A9B1D5AAB2D6A7B1D5A5B2D5A4B0D6A5B1D9A4B0D8A3AFD7A3AFD7A2AED6
A3ACD5A3ACD7A3AAD6A3AAD6A2A9D7A2A9D7A4A8D8A4AADAA2A9D79FA7D59DA8D699A3D4
9AA4D79AA6D898A4D496A4D394A2D194A2D194A2D192A0CF8F9DCA8E9FCB92A0CF8E9CCB
8F9DCC8C9AC98C9AC98B99C88798C68899C78795C48694C38593C28492C18290C18290C1
818EC2818EC27E8BC07D8DC17B8BBF7989BD7788BE7586BC7586BA7387BA7387BA7185B8
7183B57284B47082B27183B36C7EAE6A7FAC6A7CAA687DAA697CA7697EA9697EAB6378A7
6375A56375A56274A46577A76274A45F719F5F719F5D709B5D709A5D70985B6F945A6E91
5A6C90586B8C586B8C586B8C566A8B52668953658950628851648C50638B51648C4F628A
4D608A4D608A4C5F8A4B5C884859854859854B59864B59864B59864A598445547D47547E
46547B46547B46547B44537A44537A3E50763E50763C4E743C4E723B4F72384A6E384C6F
384C6D364B6A33486735496433445E33435A344056323F52
5B594A53524057544366614E7E79667F7A66807B6787826E908976928D7A8D8A79908F7D
908E7F8586768284778084767E8176797F7371796C697368666E635D655A5E655D5E665B
5E665B5E645A5E615865685F6A6A606A6A606D6A6371716977776F797A7276786D67695C
656759676B5A59604E575E4C868C7EA1A79B62685E3138314248444349476066667D8383
83878885898A828685787A774E504B31322A393B30404133434434585949555442444331
474536403E2F3735283C3D2F4344364041333F4032454638474838474A39535547545649
87897EAFB2A7999C95A0A59E9A9F997F8581858B89888E8E848C8E737B7D6A6F72666C6C
696F6D6B716D727B7870797447524A3A453D4F5B515864584B574B3D493B626F5E7A8575
A7B09FA2A89A7B7E73989991A2A19CA8A4A3AFAAAE9C979D7B767D7671787B767C89848A
6964686662639793949F9B9C999393817D7C7F7B7A8D89889998969694958E8E90909092
8F8F918282827979798181818E8C8D928E8D948E90A39D9FAFA6ABB1A7AFB3A7B1CCC0CA
C7BDC6B8B3B9A9A4AAA6A4A7A9A7A8AEAEACABACA7C1C2BCDBDCD6B1B2AA595C51484B40
5053484D504552554A606358595C5152554A4E4F475556505E5F5A62626062615F706F6D
9897959C9B996864612D2C273A3A3242443946463C53554A5C5E535758505F605A62635D
7879748E908D7A7C7B626667565A5D575C604E53594A515B505662525866505568555C6F
666E837A8299959CB6A0A7C1A4ABC7A6ADC9A5ACC8A9B0CDA9B0CDAAB1CEA8AECEABB1D3
A9B2D3A6AED2A9B1D6A8B2D6A9B2D9A5B1D7A4B0DAA2AED8A6B1DEA5B0DDA5B0DDA4AFDC
A1ACD9A3ABD9A3ABD9A4ACDAA0A8D6A0A8D79FA5D5A1A9D8A0A8D79DA8D69BA7D799A5D7
9BA7D997A5D696A4D593A4D292A2D390A1CF8FA0CE8E9FCD8D9ECC8D9ECC8C9DCB8D9ECC
8C9AC9899AC88A98C98898C98999CA8798C68795C48694C38593C28391C28391C28290C1
808DC17F8CC07F8CC17D8ABF7A8ABE7888BC7889BF7687BD7286BB7387BA7488BD7185B8
7084B66E82B47082B26E80B0697EAD687DAC677CA9677CA9667BA8687DAA667BAA6779A9
6476A86476A86274A66476A86173A35D6F9F5F71A15C6E9C5D709B5D7098596D92576B8E
566A8B576A8A566989576A8A566B8A53678854668A52648A4F628A50638D50638D50638D
4B5E88495E894C5F8A495C87475A8546598447588447588446578346578244567E44537A
44537A4454784452794353774150773B4D71404F763D4F733A4C703A4E71394B6F364A6D
374B6C354A6933486732456333445E33435C324156323F52
3532212D2A17322D1959543E615F4868664F74725976745B837E6887856E86846F8C8B77
8E8D7B9091819193868F93858D90858A8D8281877D767D75686D666267605D63595D6359
61675B6266585F635563675967685A666759646557656559696B5E6B6F61707368696C61
5A5E505B61535A60523D45386E766B969D95656C65444A48494F4F444D4C5F6769788082
828888868C8A808682848B845A60562E3126383A2D494B3D5253437475657B796A696758
4F4D3E3B3C2C3435253A3D2C41433547493B47493B494D3E4B4F40494D3E4D51434D5143
818479ADB0A5A5A8A1979C9580857E828781888D89848A86727B76616A655D6661737C77
7F8A84646F675D6A6357645B4D5D534B5B5059695E5C6C5F4B5B4E4C5A4B8691839CA296
A2A59A88898174736FB0AEAFC0BBBFC3BEC4B8B3B9918F94807E83807E81757374888483
8B8784807B788A8582999491A19899948E8E8B85878581828C8A8D98969B939298929197
9091958586888283858C8E8D8F91909C9C9C9E9C9FB3AEB2C4BDC4C0B9C0BBB1BAC7BDC6
DDD6DDC1BCC2A9A4AAAFADB0B1B0AEB7B6B2CBCAC5C9CAC2A6A79F8082774A4C41595B50
5053484C4F4651524A55574C56594E5254495E5E56726F6A6D68645F5A577873707E7976
746F6B6E6B665E59553C393246443849493D4B493D5E5E52696B5E6365586D6F6475766E
8587827A7F7B5D61624B50534A4E574F535E52556451566954596D525870545A74676E8A
7E85A2919AB79CA5C4A2ABCAA3ACCBA2ABCAA6AFCEA7B0CFA7B0CFA8B1D0A7B0D1A9B2D3
A9B1D6A8B0D5A9B2D9A8B1DAA7B0DBA9B2DDA7AFDEA6AEDDA8B0E1A4AEDFA2ACDDA1ABDC
A1ACDAA1ACD9A1ACD99FAAD79FAAD89FAAD89DAAD79DAAD69DAAD699A6D39BA8D598A4D4
97A5D495A6D496A7D594A5D193A4D290A2D08EA0CE8EA0CE8EA0CE8C9ECC8B9DCD8A9CCC
8999CA8799C98898CB8698C88698C88496C68494C58292C38391C2818EC2828EC2828EC2
7E8BBF7E8BBF7C89BD7D8ABE7787BA7888BB7789BB7788BC7286B97185B77384B87183B5
7082B46E80B06F81B16C7EAE6C7EAE697BAB6A7CAC697BAB6375A56678A86476A86676A9
6575A86575A86272A56272A55F71A15B6D9B5D6F9F5D6F9D5B6E99576A92566C91546B8D
52698955698A55698A53678853678852668752648853658951638952648C4F608B4E5F8A
4B5E884A5D874C5D884A5B86465983475A84475A8444578146598144577F44587D42547A
4254784555774250754351743E4C713C4C6E3F4D723F4F733C4E72394B6F3B4A713A4A6E
39496D34476833466734446533446034445E344058323D53
1A190718170318160138361F3E3C2544422B45432A4B493066644D71715974735F868573
898A7A91928491938692948798988C95958B909189878A8172756E64675E5E61585E6156
6064566165566064556165546164536063505F62515E605260645562685A696C61656B5F
545A5060665C656A63515650596059767C78686E6C5359574A50504D56556A737279827F
7F85817B827B757C747D857A585E5234382A474B3C5355476163558F92819E9F918E8F7F
575A492B2E1D3337263F4332464A394D51405155465256454E55454C5343434A3A3F4537
84887A8F92878081798A8B85888A858587827B7D7A727471676C686066627C827E838C87
65706A5E696157645B58655C58685D5C6C6167776C5D6D605765566E7A6C969E918A8D82
8A8C819C9D95A3A29EC4C2C3C4BFC3B0ABAFC9C7CAB4B2B59292928585857B7A787D7976
8C87838B847E8E86839C94929F95968E8586837A7F8680848F8A90A09EA396939A908F95
9091958C90918E8F918D8F8E969897B5B5B5C0BEC1C5C0C4C0BBC1B4AFB5BCB7BEDAD5DB
EFE8EFCDC8CCADABAEBCBABBC1BDBABBB8B3B3B3ABA3A39B6C6E6356584D53534955574C
50514952534B4E4F4751524A5A5B536161596D6A65736E6A7169667169678B8381948F8C
68636045403C4E49454B48434B483F47473B535349656559626457717469878A81767972
767B755E626153585B50555B4D545E4E546255586B56586F565A75575C796A6F8F868CAC
9DA3C5A2ABCCA2ABCCA5AECFA4ADCEA6AFD0A8B1D0A9B2D1AAB3D2A8B1D0A9B2D3A8B0D4
AAB2D7A9B1D8AAB3DCA8B1DCA9B0DEAAB0E0AAB0E2A9AFE1A9AFE3A5ACE0A6ADE1A2ACDD
A0ABD9A1ACDAA0ABD8A0ABD89EA9D79CA9D69CA9D59BAAD597A6D198A7D29AA7D496A4D1
97A5D294A5D195A6D292A3CF91A4CF8FA1CF8EA0D08EA0D08D9FCD8C9ECE899BCD899BCD
8698C88799C98496C88496C68496C68395C58494C58292C38290C18290C1808CBE808CC0
808CC07F8BBF7E8ABE7C89BD7987B87987B87686B97686B97686B97385B77282B57181B4
7181B47082B26D7FAF6D7FAF6A7CAC697BAB6878A96777A86577A76577A76575A66373A4
6171A26272A36272A36272A36273A160719F5E6F9D5A6C9A5A6B97576A94596C94576B90
53678A54688B576B8E54668A53658951638756668A55658951608754638A525F89515E88
4E5D844D5C834A59804A598047597F47597F475A82465981465A7F43577C44587D42567B
44567C4252764351764250753E4C713E4C713F4D723E4E723D4D7139486F38476E3A4970
38486C36466A34446635456633446232425C323E56333E54
1516061415051615031B1A061D1C0824230E24230F28271334331F4A4C375E5F4F7D7E6E
8D8B7E969487959387908E829A968B9B978C9A968D9C999087847D625F565A5A505B5B51
5C5C505D5F515E60525D61505A5E4D5A5E4D5C60515B62525D63555D6558656B5F60665C
494E475B605A7173705D5F5E535756767A797B7F805F6362585E5C5A605C697069777E76
7C8278767C70747A6C7178684E52433F43344D5140505445505445727667797D6F7A7E6F
59604E3C433140493647503D525B48575F4A5D64525E66515B62505158464B4F3E404435
7476698A8C8182827A8884818483817E7C7D7371746765686C6C6E6B6C6E7E7F81818586
676D6B575D59626B66717B736D796F6F7B6F7884786975675A6658727D6F8D93877D8075
85887DBBBEB3C9CBC0BFC0B8B7B8B2A1A29CCDCCC8F4F3EFC0BFBB8C8B876B6764797572
908B879B93909C9291978D8C908486877D7E7C71777C73788E888CA29DA19590968C8A8D
8C8D8F8B8D8CA2A2A2AAA8A9C3C1C2E0DEDFD9D4D8B0ABB1A5A0A6B5B0B6D4CFD5E5E3E8
D6D1D5C8C6C7BEBCBDC5C4C2C6C5C1A4A39E817E776A6A6250524750504659564F514E47
49493F5252485F5F576161596665606D6A656D686567625F645F5C868080918B8B8F8B8C
726E6F504C4D55515251504E4C4D4844453F5557526F726B6B70696469627E837D6B706A
545A56555B5B565B5F51565C5559645A5D6C5A5C715759725E627F757A98898EAE979DBF
A4AACCA6ACCEA8AED0A9AFD1A9AFCFA9AFCFAAB0D0A9B2D1A8B3CFAAB5D3A8B3D3AAB4D7
AAB4D8AAB3DAA9B0DAABB2DEAAB1DFA9AFDFACAFE2ABAEE3ACAFE4A6ACE0A7ADDFA6ACDE
A5ABDBA3ABDAA2AAD8A1A9D7A0A8D69DA8D59BA8D49DAAD699A8D398A7D29AA7D495A3D0
97A5D294A5D194A5D393A4D290A1CF90A0D18F9FD08E9ECF8D9DCE8B9BCC899BCD8799CB
8797CA8898CB8898C98797C88595C68495C38593C28290BF8290BF818FBE808CBC7F89BC
7E88BB808ABD808ABD7F89BC7C86B97B87B97A84B97783B77682B67783B77683B8727FB3
717EB26F7FB26F7FB26E7EAF6C7CAD6B7CAA697BA96779A76576A46374A26475A160719D
63729D63729D62709D63719E626F9B63709C606E9B5D6E9A5C6A97596A965B6C975A6B96
586A9257698F56688E57668D56648B56648B59658D58648C566288566288545D84535D81
525C80505A7E505A7E4C597C4A587B49577A4A587D4A598048577E45577D43557D41537B
42537E42537E404F783F4E773E4D763A49723F4E793E4D763C4B7438476E39486F39486F
35456935476B35456735456637466532405B2F3B55303C54
111506131708151807191A0A1A1B09191A081614052321122A28193432235654477E7C6F
949084969286979185948E829892869A94889791859B948A9B978C6F6B606260545D5B4E
5B5C4C5D5E4E5B5E4B5A5D4A585D49595D4C5C60515C63535E64585A60545B6157666B64
686D66696B666E6E6E5F5F5F464847757678959597797B7A646965666B656F746D72786C
72786A7178687377666E72614F5342454938464A3B45493A3C423433392D363E314B5346
5E69595B665549564445523E525E4867735D6F78636E7762636C575B644F59604E4C5341
61685882867885857D82817C73726E6665636864656E696D716C706E6C6F716F727C7A7B
7B7B7B6F716E6466637C817B8B9187888E8281877B7D83756E746673796B84887A86887B
9DA192BCC0B1B8BAACAEB0A29FA193ADADA1DDDAD1FFFDF6DEDBD69E9A97736F6E797574
999393BDB4B5ADA3A4877D7E7D737483787C84797D81787B857C7F979193979193908C8D
8D8C8A9C9B99B9B5B4E7E1E1E9E3E3E4DEDEC9C3C57973758A8486B5B1B2C4C0C1C5C1C0
BBB7B6C1C0BCC0BFBBB9B8B4A9A8A38B8A856F6C655D5D5551514755554B5E5B5259564D
504D445252486E6B6474716A6C68656D696664605D585453514D4C6D6C6A8684857F7D7E
7B797C6361645B595C575757494B4A4042414C504F7074736A706E5D63615D6363565C5C
50555853585E5357625458645457685B5D725A5E77626683797C9B9095B5A3A8C8A7ABCE
A9AFCFAAB0D0ACB0D3AEB2D5ADB3D5ABB1D3ACB2D4AFB5D7AAB3D4AAB5D5AAB4D7AAB4D8
ACB5DCADB6DFADB4E0ACB3E1ABB1E1AAB0E2ADB0E5ABAEE3ACAFE4ABAEE1ACAFE2A7AADD
A5A9D9A6ACDCA4ABD9A3AAD8A3AAD89FA7D59EA9D79BA8D59BA8D59BA9D69AA7D497A4D1
97A5D294A5D395A3D295A5D693A1D2919FD095A3D4919FD08D9DCE8E9ECF8A9ACD8C9CCF
8999CC8797CA8797C88494C58696C78593C28593C28492BF818FBE808EBD818DBD7D89BB
7E8ABC7E8ABC818BC07E88BB7B87BB7B87BB7B85BA7882B77882B77781B67580B6737FB3
717DB1707DB1717EB26E7CAD6D7BAA6D7EAC697AA86879A56576A26778A46576A163749F
64769E62749C61709B606F98616E98626F9962719C5E6C995D6B985B69965B69965C6B96
596A9557699159689357668F57648E58648C5B678F5B648D586188566084555F82545E81
535B7F525C7F505A7D505A7D4956784856794B577D4A587F49587F47567F42547C41527D
41527D44527F43527D41507B3F4E793E4D783E4C793E4D783B4A753A49723A49723A4970
33456934466A354567374667374464354360303C56323E56
0C1405141A0C181C0D1D1F112021131D1E101B190C19170A2420143B372B736C628E887C
928A7F968E81978F829A92859B93869D96869C95859690808582716867556362505D5C4A
5C5E495F614B53553F5557415A5D485D604D5F6251686A5C606257585B5053564D61645D
82857E93948F8A8B866867653C3C3A6464648A88897573746E6E6C7F817C868982797C73
73766B737768727564676A59555847484A3C464A3C36392E2E342A272E261F292038443A
6270636A78695D6B5A49584552614C78877079876E758169737F696B77616C7562596551
55604F747F6F81897C7B81776B6E655E615A62615D6864616F6B686D686575706D877F7D
807B78716C696D696684837E8E8E869292888C8C808485777F8070848575989689908E7F
9C9B89AAA99792917D8E8D79BFBCA9CCC9BAE1DAD0E8E1DBD5D0CCA39D9D827C7E979296
A49FA5C4BFC5B4AEB28983878680829892949990938C8384857C7D8F85869C9291988E8D
948C8AC0B8B6DCD4D2F9F1EED1C9C6B8B0ADA8A39D6D686288847BB4B0A7ADA9A09B978E
A4A097BEBBB4BEBBB4A19E9977776F6969615D5D555A5A505A5A4E5F5F53656357605E52
57554966635A6C6C646D6D656D6C685E5F5A5252504747474648474D5150666A6B6B6F70
6B6F6E6062614E504F5456554A4B4D3F4344494D505F63665B60644E555B52565F555964
4D535F50566656586D5A5C73575B765D607F6166847B80A0969BBBA4A9C9A9AECEA7ADCD
AAB1CEACB3D0ADB3D3AFB5D7ADB3D5AEB4D8AFB3D9AEB2D8AEB3DBAFB4DEAEB2DFAAB1DF
AEB4E4ADB3E3ABB3E2AAB2E1AAB2E3A9AFE1ACB2E6AAADE2AAADE0ACB0E0A9ABDCAAACDD
A8AADBA8ACDCA7ABDBA4AADAA4AADAA0A8D79DA7D89DA9D99BA7D79CA8D89AA6D698A4D4
98A4D498A6D597A3D597A5D695A1D395A1D394A0D4939FD3909ECF919FD08E9BCF8D9ACE
8C9ACB8896C78393C68595C68694C5838FC18490C2838FBF8391C2818FC0808DC17D8ABE
7B88BC7C89BD7C89BE7A87BB7B88BD7885BA7883B97883B97783B77682B67682B6727EB2
707CB0717DAF717DAF7480B26F7BAB6C7AA76B79A66B79A66876A36776A16475A063749F
62759D62759D61739B61739B62719A62719A61709B5D6B985D6C975C6B965C6B965D6C97
57689358699458699557689356659056658E54618B56628A535F85546184546183515E80
535E7E4F5C7C4E5B7D4B5A7B4C5A7D49597D4A587F48578047567F48578246558044537E
45547F45527E43507C414E7A404D77404D773F4E7941507B394A753749713948713A4970
36486C35476B33436533426338456534425F303B57323C57
10180B151D0E1B1F11212316202014211F13201C111B170C1F180E3E362B776F64958D80
91897C9790809E97879C96869A95829E9986908B777E7C676C6B565D5F475F614B60624C
5C60474F533A393B2350523C5D5F4A5B5C4A5B5C4E6363575F5F555B5C545E5F5952534E
6E6F6A93948F8B8C876A6B663A3B3661615F7F7E7C6968665453518484829899947F827B
777A71777B6D6C6E615E60524245342F312337392C313429282E24262D251B251D2D3830
5C6A5D707E6F7482736776635F6E59808E77939F878C9880818D777B846F77806D6F7865
636E5D687363717C6E727A6F6E766B6C72686E6F6952514C5A5653726F6A87827F827A77
756D6A746F6B7A757185827B8A877E8D8B7E908D7E8D8A798F897995907DB9B3A3B9B2A2
A29B899A938187806D847D6AB1A996CEC5B6CDC3BABEB3AFB9ADAD94898D938890B7ADB6
BAB2BDBFB9C3A9A4AB969197AAA5A9B4B0B19C96968980818D8583948A89978D8B988E8C
B3A9A7D9CFCDDCD2D0D9D2CCACA59F8780788A83797F796D918B7FBAB2A79C938A91887F
ABA29BB8B1A9ABA6A083807969665F58585055524B59594F636155706E6178766A68665A
6260546A675E6D6A636A69646A6B664E504D474948484C4B434947404946555E5B646D6A
5F65634D5351484C4B4B4F4E4D5154474B4E4F525751545B4F535C515560525662535667
51536853556E585977595A795A5D806366897B7FA2A2A8CAABB0D0ABB1D1AAB0D0AEB5D2
ADB4D1ACB3D0ADB4D1B0B6D6AEB4D6AEB4D8B1B5DBB1B4DDAEB1DCAFB2DFADB1E0AEB2E2
ADB3E7AAB1E5AAB2E3ABB3E4A7B1E2A9B1E2AAB1E5A9AFE1AAB0E0AAAEDEAAAEDEA9ABDC
A7A9D9A7A9D9A5A9D9A5A9D9A4AADAA3A9DBA0A7DB9CA6D99DA7DC9BA7DB9BA7DB97A3D5
97A3D598A4D696A2D698A4D895A1D594A0D4929ED2929ED2929ED28F9DCE8E9ACE8D99CD
8B99CA8997C88595C88592C68593C4828EC08490C28490C2818FC0818EC27E8EC27C8CC0
7989BD7888BC7888BC7888BC7885BA7683B87582B77683B87681B77682B67681B77480B4
757FB4727CAF707AAD717DAF6F7BAB6C79A66B77A76B78A56775A26674A16576A260719D
61749E6477A161729D60719C60729A62749C5F6D9A5C6A975C6B965B6A95596893576894
56679355669255669255669157689352648C53628B546289515F84505E81525F814F5C7E
4E5D7C4C5B7A4D5C7D4C5C7E47577B47567D46557E47567F46558046558045547F465580
46537F43507C404B78424E783F4C76404D77404F783F4E7938497435467137466F39486F
35476D37476B374568334263344161334060333C5B313A57
141A101B1E131F1F15211E151F1D111D190E221C1021190E1E160B3E3629736C5C8A8371
928D7A9B998498968193927D94947C90927A7D7F676A6E5361674B5E6448656B5160664C
444A2E33391F383C234F523D5556445354465755495353495A5954646560656563555754
6163606C716B676C665F645E4B504A5A5F596D6F6A6F6F6D6362607B7A787F7E7C73746F
7D80797D80776C6D6555574A3D3E301F211326281A2B2F212B2F21252B1F1E241A272F24
576156768173848C7F838B7C757E6D818974A0A891A7AC969CA18D939683888B78818574
777E6E73796B72786E6D746C6F766E737872777C7654565157575571726D747371706F6B
75746F7E7D787E7E768A877E908E819392808B88758B8672968F7CB0A895D0C5B3C3B6A5
B7AA99AB9E8D8E7E6F89796AA59385BCAAA0B7A49EB19F9FBBA8AC9E8A939E8C98DDCCDC
B8ABBCA39BAAB9B3BFBCB9C2B3B1B6A5A0A48D87898882828D88858E8683A19997B2AAA8
C3BBB9C7C2BEBCB7B3A9A49E837F746662567E786C7B7368756B61AB9E968E817B8E807D
9789888C817F7D75726C67635C575155524B54504758554C656156706C61747065686459
635F5668635D69645E66635E61625D4C4E4B434746484E4C404B453E4943525D575A6561
535C5949524F4D53514B514F4F545754575C56596055555F545460575664575668595A6F
5656725655755D5C7E5E5C8166668C8284AA9D9FC5A8ACD1A7ADCFA8B1D0A9B2CFACB5D2
ACB5D2ADB6D3ADB6D3ADB6D5AFB8D9AEB6DAB0B5DBB1B6DEB0B5DFAFB3E0AEB2E1ABAFDF
ACB2E6ABB2E6AAB1E5A8B2E5A6B2E2A5B1E1A7B1E2A8B0E1A8B0DFA8B0DEA8AFDDAAAEDD
A7ABD8A5A9D6A4A8D7A4A8D8A2A8D8A0A6D8A4AADE9FA6DC9DA4DB9CA5DC9BA6DC97A2D8
95A2D793A0D595A2D794A1D6929FD4919ED3909DD2929ED2919DD18E9ACE8C98CC8B97CB
8896C78795C48795C68593C48491C5818EC28591C3828EC0808DC17F8CC0808DC27D8ABF
7D8AC17C89C07B88BF7D8AC17A85BD7883BB7782BA7782BA7481B87481B6747FB7727DB3
747DB4727CB16F7BAF6F7BAD6E7AAC6B77A76B77A96B77A76573A26977A66676A76272A3
6072A05F729D5F709E5E6F9D5E719C5E6F9B616F9C5E6C99596A965B6C985A6B97556692
56679355689254679155689253669051638B5062885161854E5E804E5E804F5E7F4F5E7F
4E5E7F4B5B7C4B5B7C4C5C7E47577B44567C46557E46557E45547F44537E44517D46537F
45527C424F79424F79404E75404E753F4D743F4D743E4D763A4C7437497137466F38476E
37466D354569364469364467334062354262343D5C313A59
1B1E171C1F1625251B2321151E1C0F1E1A0E231D0F231C0C1D1606423B2978735F7E7C67
86866E94967E8F937A787C63747A5E747A5E676D535F654B5F684B5E674C646D52404830
2A2F183A3F284B4E394F523F535446545448474539403D3460605882817C73746F656764
666865656A64686F68606760585F585F665F6A6F697577747B7B79797977676664676863
72736E5A5B555858504E4E44413F332A281B2826192B2C1E2C2C2025271A2123182E3126
4E514673766B8C8F8495998B8D9182828574949784A6A795AAAB9BAEAC9D9E9C8D898A7C
86867A8284797C7D7772756E686A6572746F7E807D6A6C695757556565636C6B697B7A78
83827E87868183807997948BADA99DA6A3928F8A77948D7AAFA794D5CAB8D5C8B7BEB1A0
C2B5A5AB9B8C88786998867AA49286B19F95C2AFA9B9A5A4B9A5A7B4A1A7B6A2ADE6D4E0
B2A4B1A69CA7D9D2DABCB7BD9F9A9E9995948C87848E89858984808B8680A09B97CDCAC5
CFCCC7ABA8A39B9891A19E959492866E6A5E7872666A62575C52499186807C6E6B746665
746666706464685E5D625A5859514E56514B504B45524E4567635A706C61746D65646057
56514B58554E5E5B565655514F4F4D484D493E4442444D4A45504C3F4A46515C585B6461
545E5D4E57564F55555055584E5356595C616E717A6464705756645B5A6C59576C5C5C74
5958775A597B6462876F6D928484A89DA0C3ACAED4ACB0D5ACB2D2ABB4D3ADB6D3ACB5D2
ADB6D3AEB7D4AEB7D4AEB7D6ADB6D7ADB6D7AEB6DAAEB6DBAFB7DEAFB6E0ADB4E0ACB3E1
ACB4E3ABB3E4AAB4E5A9B3E4A7B3E3A6B3E0A6B2E2A7B4E1A7B2DFA6B1DEA7AFDDA5AED9
A6ADD9A5ACD8A2A9D7A2AAD9A1A9DA9FA6DAA1A8DE9CA5DC9CA5DE9BA6DE9BA6DC97A4D9
94A3DA93A2D991A0D790A0D491A1D590A0D38F9FD3909DD18D9ACE8B98CC8C99CD8C9ACB
8997C68795C48795C48593C48491C58491C58490C2818FC08290C1808DC17F8CC07E8BBF
7A87BC7C89BE7E89BF7D88BE7B86BC7883B97782B87782B87380B77481B8717EB5737EB4
747DB4707BB16E7BAF6F7CB06C7AAB6D7BAC6D79AB6B79AA6674A56676A96474A76272A5
6274A45F71A15F6FA05F71A15D6F9F5D6F9D5F709E5C6D99596C97586B96596C97556893
576A9456699355689254679152658F4F628A50628A53658B4F61874B5D834F5F834E5E82
4C5E82485A7E485A7E495B7F485A8046587E47567D46557C44537C45547D43507A45527C
4452793E4D74404E753F4E753F4F733D4D713D4B723C4B723A497039486F38477038476E
37476B344468364469374568354264374260343D5C2E3754
1A1F191F221B2023182022141F2010201F0D23200D22200B1D1C0733331B64644A777A5F
7E8267959B7F9CA588656E51515B405E684D5E664E5C644C5F6750505841464B372B2F1E
31332547493B555749585A4D5052455153465555494242366E6C60928F86797971676661
5A5D565B605A676E67686E6A646D68666F6A6B746F6F757173787476787371726D6D6E69
61605B313129423F3857534A3F382E312B1F352F232E281C2B271B2A261B2E2A1F2B291D
3F3D317171657E7E749B9B91A2A2969A9B8D97988AA09E919D998DA4A095ADA99EA4A097
98938D8C898487847F817D7A736F6C74706D7A76757672717771717B75757B7275958C8F
999091908886908885ABA49EC3BCB2C1BBAFA79F92C2BBABDAD3C1DBD2C1C1B8A7B0A796
B7AE9FA9A091918879978B7F92867AA3978BC3B6ADB0A39BAA9D97B9ABA8C5B7B6DDCFCF
BFB3B3AAA09FC8C0BEA39B988D88828E89838780788C887F79756C8A877EAFACA3C8C8BE
BEBEB49C9C9279796F929286A3A097716E655D5950676058655E586B6360655B5A635958
6157586057585E56545C545258504E534B484E46434D4640605B556E6A616B66605A554F
4A47404948434C4B474C4D48454744414642444A484A50504B54534C55545157575C6164
565E614F575A55585F55585F54575E6669727F818E6D6F7E53566756596C5B5D725F6178
5C5D796162807879989191B3A5A8C9ABAECFADB1D4ACB1D1ADB3D3ADB4D1B2B8D8AFB8D7
B0B9D6B0B9D6B0BBD9AFBADAAFBADAAFBADAAFB9DCAEB8DBAEB8DCADB7DBABB4DBACB5DE
AAB6E0AAB6E0ADB5E3A8B3E0A7B4E0A6B3DFA6B3E0A6B5E0A4B1DDA3B0DAA3B0DAA3B0DA
A2AFD9A1AED89EABD89FADDC9DABDC9BA8DC9BA8DC98A5DA99A6DD97A6DD97A7DB93A4D8
92A3D792A3D793A4D890A2D48FA1D38FA1D18D9FD18C9CCD8C9CCD8A9ACB8A9ACB8A9ACB
8899C78697C58596C48394C28292C38191C48290C1818FBE808EBD7C8CBD7D8BBC7D8BBC
7C8ABB7E8CBD7C8AB97B89BA7B89BA7784B87683B77582B67683B87683B87380B5717EB3
727FB46E7BAF6D7DB06C7CAF6A7AAD6A7AAD6B78AC6676A96474A76474A86373A76171A5
6273A75E6FA36172A65F71A35D6F9F5B709D5C6E9C5A6D98596C97586B95586B95586B95
54679154678F56679256679252658F4F628D4F608C5162904D5F8D4B5D8B4A5B874B5C88
4A5D87495C86465983485B8345597E475B8045577B425478425478425478435377425276
4353773F51753F4F733D4F733F51753D4F733D4C733C4B723A49703A4A6E39476E39476C
38466B364469374467364366353F62343F5D353F5A313852
2328222328211E241821251721241320231022240F1E200B22240E2F311B4F513B70745D
898E77858D75868E766F79615660485E6850626A55545C475458473B3F2E333527353529
3E3E3451524A5B5C5457594E4E504566685B6C6E6157594B606153898A7C78786C616358
4A4D44565B546B706A6C726E6B74716D7673727878757B79747975767B777B7D7A777873
53524E2D2A2539342E39352C2F2820362D24342B222B23182C261A312B1F3630242D261C
3C382D716F637D7A739B9B93BABAB2B4B5ADADADA5AAAAA29B98918C8982A19E99BAB5B1
B6B1ADA09B9789848087827E847F7B77726E706B6779716E9189869D9392968C8D9C9092
9E92929E9391A59A98AEA39FCDC2BCD2C8BFB4AAA0CDC3B9DAD2C7C9C1B6B6AEA3ACA69A
AAA498A7A397A59E94A59F93928C808E887C9B9589A89F96B1A89FBCB3AAE0D5CFE0D5CF
C5BAB4A99E989C938C9289828B847C89827A80796F7A766B74716878786E95958BA7A99E
898B807D7F7473756A787A6F8989816A6A6259564F5B58535B56525A55525C54525D5553
5C56565954515A555258504E554D4B4C474449444148454057544F61605B62615C565550
484944464843474944474C48454B474349474851504A5352535D5E5A6264585D605B6064
575C625559625D5F6B686A77636572686A796C6F80616477595E725C61755C61775F637C
6266816F758F8F94B1A4A7C6A8ABCAADB0CFAEB3D3ADB2D2ADB4D1AFB6D3B2B8D8AFB5D5
B2B9D6B1BAD9B0BBD9AFBADAAFBDDAAFBCDCAFBCDCB0BDDFAFBCDEACB9DBABB7DDACB8DE
ACB8E0A9B5DFACB5E0A9B4E1A7B4E1A5B2DFA4B2DFA4B2DFA3B2DDA2B3DEA1B2DDA0B1DC
9EAFDA9EAFDB9CADDB9BABDC9AAADD9AAADD99A9DC99A9DD96A7DB93A5D795A7D992A4D6
92A4D690A5D492A4D490A2D28DA2D18CA1D08C9ECE8EA0D08B9DCD899BCB8999CC8898CB
8999CA8597C78494C58193C38292C58393C68090C17D8EBC7D8EBC7C8CBD7A8ABB7989BA
7C8ABB7A88B97A88B77585B67585B67484B77383B67282B57282B57282B57080B46D7EB2
6E80B26B7DAF6B7DAF697BAD697BAD6576AA6677AB6778AC6273A96172A86473AA6170A7
5F70A65F70A65F70A45D6FA15B6FA1596E9D586D9A586D98596C97576A94566C95536992
52658F55689252658F55689350638E4D608B4F608E5060914F61914C5E8E485A8A495B8B
4B5D8B495C87485B8646598445588045597E44567A44567A435579445476445478435375
4353754252743E4E723E50743D4F733D4F733C4B723E4C733B49703A486D3A466E39456B
37436B364268384168374165313B5E353E5D333A54343C53
272E26282F27262E23292F23282E20242A1C282C1E26281B26281B2F31244F514466685B
767A6C545A4C5A60526A706263695B5E64565F66565357484244363E3E323F3C3349463F
53504B5A595451524C494A44575A5371746B6B6F61606455555C4C646B5B676B5C616557
575D5361665F6C716B70757172767571757678797D7B7C8078797B797A7C808082757575
4D4B4C3935343B3633221D19241F1B352E28342D252D261C2F291D3633243E382A393327
3D392E6F6C638A8782A8A7A3C5C7C6C8CAC9B6BABBA6AAABA8ACAD9CA09F9799989F9F9D
B2B3AEB1B0AB9E9E96928F868A877E8581767B776C756E647F766D9A90879F928C9C8F89
A3948DA99A93AA9B96B8A9A4D2C3C0DDCEC9AC9F99A39690B0A5A1A89F9AA69E9BA79F9C
A19E999F9C95A6A39EC8C5BEA9A99F8A8A807A7A708C8A7EAEAA9FABA79CC4BDB5C7BEB7
B3AAA59A918C948B868E85807A736D77726C6C67615E59536C69627A7A7285847F84857F
74756F686B645E605B6B6D687E7F796B6C6655544F4F4E49524F4A57544F55504C56514D
574F4D55504D56514E54504D4D494645444043423E42433E4B4D485156504E534F494F4B
43494740494640494645504C454F4E434F4F4D57584854544D5B5C79848688909370757B
5D616C5C606C6C6F80989BAE9FA1B66F7188545871595F77595F775C627A5D637B676E88
7D849E979EB8A5ACC8A8ADCAA9AECBADB2D0AEB3D3AFB4D4B2B7D5B2B7D5B4B9D9B3B9D9
B5BBDBB2BBDAB1BCDAB1BCDAAFBDD8B0BED9AEBBDBAFBEDDAEBDDEAEBDDEABB9DEABB9E0
ABB7E1A8B3E0A8B3E1A9B3E4A6B2E4A5B1E3A5B3E4A0B0E1A0B1DF9FB1DFA0B2E2A0B2E2
9EB0E09CAEDE9CAEDE9BADDF9BADDF97A9DB96A8DA97A9D997A7D895A6D494A5D392A5D0
93A6D192A5D08FA2CD8EA0CE8EA3D08CA1D0899DCF8B9FD1899DCF879BCD899ACE8899CD
8798CE8397CC8495CB8094C98091C78192C67F91C37D8FBF7B8DBD7B8DBF798BBD788ABC
7989BC7888BB7787BB7585B97686BA7384B87283B77081B56F81B37082B46D7FB1697DAF
6A7EB0697DAF667AAD687CAF677BAE6478AD6578B06275AD6174AE6174AE6273AB6172A8
6273A96172A85D6EA25F71A35A6EA0566B9A596B995B6E99576C97556B94546994556A95
5267925166914F64915065924A5F8A4B608B4E608E4D5F8D4E608E4A5C8C4A5A8B4A5A8B
4A5B89495A88495A8845568246578347588345547D48578046557C47557A47557C465479
435176425075414F72404E713D4B6E3D4B6E3D4B703E4A723E4A723C456E3E47723B446D
3E4772333C65353C66353D64353D61333959333A56343A54
323931424A3F454B41393F35262C222C2F2633342E32332D2A2B262A2B2661625D6C6D68
6565634F514E5B5D58656A6461665F5D63595A5E50595B4E4B4B3F444438545148615E57
56534E4C4B465A5B554B4C466F72697A80765F6559596152545D4C5A6352646C5D5D6558
60685D676C656E736F72747372747374757779787D7A797E7B7A7F86878987878968686A
4141412F2F2D39383623221E24231E3838303B382F39372B3230233230213D3B2C434134
3C3A2E504D468C8B87B3B1B2C5C6CAC7CACFCACDD4B8BBC2ADB2B8AAAFB3A8ACAF9A9B9D
A5A7A4B3B4AEB4B4ACAEAEA4A5A396908E7F848172868070827C6C807969897F73938779
9C9082A3958AA89A91B8A9A4C0B1AEB9AAA7A19392978988958B8A978E8F9B9293938D8D
9A9693AAA9A5AAA9A5CCCBC7C1C2BC9B9C9484847C81817796938A9B978E9D9892A19A94
A7A09A918A84908983827B755C57535B58535F5B5855514E62615D73746F76787372746F
6F716C6769645557525A5C577D8079696C655D5E5852524A4F4F4754514A535049514C46
534E48524F4855524D52514C4E4F49383B343A3F39424743444A46444D483F48453E4945
3F49483E48473F49484652504E5A5A5661635C6668555F614A5557919B9DC6CDD3A5A9B2
60646F727483828395B3B5CAC0C2DB9498B34E53705158745E65815E688368728D7A849F
8F9BB3A5B1C9A8B2CDABB5D0ABB5D0ADB4D0AFB6D3B1B8D5B3BAD6B3BAD6B4BBD8B4BADA
B2BBDAB4BDDCB4BFDDB3BEDCB0BED9AEBCD7ADBADAADBCDDAEBDDEADBBDEACBADFABB9E0
ABB8E4AAB7E4A9B5E5ABB7E9A7B4E8A5B2E6A5B5E8A1B1E4A1B3E5A0B2E49FB3E59EB2E4
9CB0E29AAEE099ADDF97ABDD99ABDD99ABDB97A9D997A9D794A5D195A6D292A3CE93A4CF
90A3CD8FA2CC8FA2CD8EA0CE8EA3D08CA1D0899DD0899DD0879BCE869ACD8899CF8598D0
8396CE8398CF8295CD8196CD7F92CA7C91C67E92C57D91C37B8FC1778BBE768ABD788CBF
7589BE7589BE7687BD7586BC7286BB7185B87586BA7081B56B7FB16D82B16B7FB1697DAF
6A80B1687EAF657BAC657BAD667CAE6378AD6579AE6679B16174AC5E71A95F70A85F70A6
6172A86273A75F70A45D6FA15A6F9E566B9A5A6C9A596B99586B96576A95546694546694
5365935065945064965065944C618E4E63904F618F4D5F8D4B5E894B5E894B5D8B4A5B87
4A5B874A5B8747588447588446578247588347568145547D46547B44527945537A47557A
435176414F74414E71414E713F4D703D4B6E3D496F3C486E3F48713A436E3C45703A436E
3E4571373E68394168394166374061363D5A333A56353D54
484B4263665D6869614C4B463E3D38494844433F3E4945463A383D2E2B324D4A515A595F
66656B5F5E636565675F61605456514E51484D4F424E50424E4F4154554778796B828276
5A5A5037372D585A4F54564B63665B7B81755E6659535E50545F51535E50616B60626C61
646E65686F676F747071757475777677787A7C7C7E7E7E808586888084836264634C514D
2F34302328222F342E1E231C191E17393F35444A3E3D4335373E2E3C402F40423446483B
49493F474641969291C1BFC2C7C4CBC8C6D1D0CEDBD1D1DDCECED6BFC0C5B0AFB5AAA9AE
B2B2B2A8A7A3A5A49FAEABA2B0B1A3A4A5959493818988748C8B7685836E7D7B66837E6A
8C8773928B78A1978BA99F96A79C969A8F8D9B8F8F9C92938E8485887F82938A8D8E8888
9B9794B6B2AFBAB9B7C0BFBBBFBEB9ABAAA5928F8A94918C95908C95908C918C88908B87
95908A88837D7974706A676255514E5756526463616D6D6B6A6C6B666A69686E6C6E7470
6E74706A6F69595E5755584F5F62575355484F4F435152445253455152444E4F414E4F41
4D4D4150524553554A55584F464C40323A2F36403739433B3F4A443F4A443C47433E4847
3F49483F49484953524C54564B53566C7177787B826C6F7673767BA5A8ADD5D5DDCACAD4
8B8A98A09FAFD2D1DFDEDFF1C0C2D99B9FBC5B607E3F466357607D65708C848FAD97A5C0
9CACC5A1B1CAA5B5CFA8B8D2A9B9D2ABB9D3ACBAD5ADBBD6B1BDD7B1BDD7B2BDD9B2BDD9
B1BCD8B2BDD9B0BEDBB2C0DDB1BFDAAFBDDAADBADCAFBCDFAFBDE2ADBBE2A8B7DEAAB9E2
ABBAE5A7B5E2A5B6E4A5B5E6A4B4E7A3B3E7A3B4E8A2B3E79FB0E49EAFE39EAFE39EAFE3
9EB0E29CAEE097ACDB97ACDB96ABDA96ABD899ABD998ABD696A9D493A6D191A4CF92A5D0
90A3CE90A2D08FA1D18D9FCF8BA0CF8CA0D28A9ED1899DD2899DD28598D08598D08194CE
8095CE8096CF8095CE7D93CC7C91C87A91C77A8FC47B91C3788EC0768BC0768BC0768BC0
7287BE7388BD7287BC7287BC7086B86E84B57084B66E83B26E83B26B80AD6B80AF687DAC
677DAC667EAC657BAA647AAB6278A96177A86177A86278A96076A75F75A75E72A55E72A4
5F73A55E72A45C6EA05E70A05D6F9F5A6C9A5A6B99596A98576896586899566699556598
5262965263974E5F955162965163955062924F64914D628D495F88495F88495F864A5D85
475A82475B8044577F43567E43577C465A7F45577D45547B46547B45537A445076465278
424E74445174414F743E4C713E4C6F3D4B6E3D496F3E4A703B476D3A466E37436B37436B
39426B353E65353F63384363384361353F5A303A53323D51
6262587C7C7485827D55514E635F5E6D696A534E545A555C514E5937343F393742484852
6A6A7464646C65666A57585A41434033362F393B305254475E5F516F6F638C8C80919187
5E5E5442423844463B3F41364F52496E746A6F766E59635A4B554C4F5B515B655D5F6961
656F676B726B717672737874787A79787A777E807F818380878C886C716B3338322A312A
2D342C282F27272F241E281D101A0F3843355762544C5747404938424B3A4B514353564B
66675F767570AAA9A7DAD6D7D4D2D7D0CDD4D2D1D9D3D2DAD5D4DADBD9DECAC8CDB7B3B4
C2BEBDA6A39E85807A9390879D9B8EACAA9BB6B4A5A09F8D8A8975898B768988747A7965
7877628683709491829A9389979088AEA7A19F9795938B8990888687827F7C767686817E
A9A4A0C9C6C1BEBBB6BEBBB6BEBBB6BAB7B2A4A19C97948F8B87848F8B88918D8C8B8A86
8C8B877D7E7851524D4F504B4F514C5254517173728A8E8D8F9595737C79515A577D8681
8187836F766F585D5652554A5357494C4E404546364849394B4C3A4B4C3C494A3A494B3D
47493B5054465053484D5347444A3E333B2E37413639433A3B463E404B453F4A463E4945
444D4C464F4E4F555553575A5054576A6B709D9CA2A2A1A798979CB1B0B5CDCAD1D9D8E0
CACAD6D7D6E4F9F9FFE1E0F0BFC1D86A6E89515674555B7B6972917C87A5949FBFA3B0D0
A2B2CCA1B1CBA6B6D0A9B9D3AABAD4ACBCD5ACBCD6AABAD4ADBBD5AFBDD7B0BED9B0BED9
AEBED8AFBFD9B0BEDBB0BEDBAFBEDBAEBDDAAEBBDDAEBAE0ACBAE1ABBAE1AAB9E2A7B8E3
A9BAE6A5B6E4A2B4E2A2B4E4A4B6E8A2B4E6A1B2E69FB0E49FB0E49DAEE29DAEE29CADE1
9CAEE09BADDF98ACDE98ADDC96ABDA97ACDB99ABDB96A8D897A9D993A8D792A4D490A5D4
8FA3D590A4D68FA0D48C9DD18B9FD28A9ED1899CD4899CD48699D18497CF8497D18295CF
7E92CD8095CE7E93CC7C91C87C91C87C91C67A8FC4778EC2788DC2758CC0758CC2738AC0
7289BF7289BF7188BC6D84B66D84B66D83B46E83B26F84B17082B06E80AE6C7EAC6A7FAC
697EAB667CAB697EAD677CAB6478AA6276A86377A96377A96377A95F73A55E72A45C70A2
5C70A25C71A05E70A05C6E9E5A6C9A596B99596A98586997566697576798586599566398
5461965261985160974E5D944F5F934E60924D5F8F4B608D4B618A486086475D82445A7F
45597C465A7D44587D43577C42597B43577A43557B45547B47557C445279435176424E74
424E74424E74414F743F4D72404E733C4A6F3B496E3C4A6F3A486D3A486D37456C334168
354368344164323F6135426239446236425C313C52323D51
504B455A5551514C494943457E797D7674795F5C656967725B5B67353541393B47565A63
676C7260686B5C62624A504E262B252629223D3E365F60587B7C7492938B90918B6E6F6A
4B4C474D4E4941423D33342F484A475A5F5B666B67585E5C4B514F545D5A616765646A68
666C686C726E7176727678737B7D7A777974878A83949A90888E82626A5D1921161D251A
293124242F21232E201D291B182416404C3E626E605D695B5A65575E6659636B60646A60
777A71A4A59FBEBDB9D3D2D0CFCECCD2D1CFD4D2D3D4D2D3D5D4D2D7D6D2DEDAD7D9D4D0
D9D4CEBEBAB17E776F7A736990897F979388B3AFA4B4B0A5938F8483817486867A79796D
74756786877987877D85857B9F9F97D0D0C8B6B3AC86837C8380798B877E706B657D7970
AAA69BAFABA0AEAA9FB7B3AABCB9B0C2BFB8AEABA693928E8F8F8D8D8F8C8E908F8C908F
848A886D7371505956545D5A58615E4A5350646D6AA5AEAB9CA5A2818A873B4441636965
8C918D7E837C696C6350534845493B494D3E454837454837474A39464938454739444639
4446394D50454F52474F524944473E393F353E433C3A3F38414640454A46454A46454A46
494B4A4D4F4E5757575C5C5C5B5B5B797979B0AEAFB8B6B7A6A4A5A7A5A6BBB6BAD8D6DB
EFEEF4F4F4FEDFDFEBACAEBD7E8097595D786368866B7191858EAD9CA5C6A7AFD3A6B1D1
A7B2D2A6B4D1A8B6D3AAB8D3ABB9D4AEBCD7AFBDD8AFBDD8AEBED7ACBCD5ADBDD7ADBDD7
AFC0DCAEBFDBAFBEDBAFBEDBAEBFDBACBDDBADBCDDACBCE0ABBAE1A9BBE3A8B9E4A7B8E3
A7B8E4A6B8E6A4B6E4A4B6E4A2B4E4A2B4E4A2B4E2A1B3E19FB1DF9CAEDE9CAEDE9BADDF
9AACDC99ABDD98AADC98A9DD95A9DC96AADF94A7DF91A4DC91A4DE91A6DF90A3DB8FA4DB
8CA1DA8CA1DA8DA0DA8B9ED88D9ED68C9DD5889BD68598D38598D28295CF8191CC8393CE
8194CE7F92CC8091C97F90C67C90C57C90C37A8EC1778CC1788CC1758AC1758AC37388C1
738AC07188BE7186BB7086B86E84B66C80B26C81B06D7FAD7081AF6E7FAB6B7CA86B7CA8
6A7BA76879A76B79AA6A78A96875A96875A96575A96373A76374A86071A55F70A45E70A2
596B9D5B6D9D5C6C9D5D6E9C5C6E9C596B99596A98586997586695586697596597556195
556195556297536095525F94505D944E5E924E5E8F4C5E8C4A5F8A495F88465C83445A7F
43597E43597E41587A405779405779425679435579425478455579435377404F76435178
404E753F4D743E4C733F4D743C4B7239486F38476E38476E37466D37466D35446B334269
334367344265313F62323F6136415F34405A303A53333B52
2C242236312E2A21242C252C5A555C605D666967725C5C6850525E494D5851555E5B6366
5B63654F5855464F4A2F362F2C312A40433A5758506869617E7F79898A848D8E89656563
4B4B494747453D3D3D383838494B4A4D4F4E535554505453585C5B636766656968666B67
6B706C6E736D73766F74776E797C737C7F748A908299A08E8188766A73601922112F3827
353E2D2A35252732222A35272B372B4551455F6960606A62656C65878E879399958C918B
A1A39EC8CAC5C9C9C7CECDCBD0CFCBD3D2CED2D1CDD5D4D0D8D7D3D7D6D1DCD9D4DAD7D0
E0DCD3CECABF837C745E574F7F787084807795908A99948E89857C7B786F7B7B73787A6F
7C7E736F7166808277A4A69BB2B3ABBDBFB4ACAEA38E8E827D7D71817F73807C717D796E
8C867A969084B0A79EB9B2AABDB8B2B6B1ADA8A4A39997989495978F9394878B8E8C9194
828A8C676F715963625E68675D686459645E7C8580B4BDB8A7B1A9828C84363D354C514A
868B848B8E857174694C4E414A4C3F4F514347493B47493B45473943453744463B46483D
43463B4C4F4650534A51544B484B444649424A4D464647424546414747454B4B494B4B49
4B494A4C4A4B514F506361627E7C7D9E9C9DBFBDBEBBB9BAA9A7AAABA9ACB8B6BBDCDBE1
F4F4FED6D8E5ACAEBD7174876B6F886368856D7290858BAB9DA3C3A4ADCEA6AFD0A8B1D2
ACB5D6AAB5D3AAB3D2ACB7D3ADB8D4AFBAD6B2BDD9AFBDD8B0C0D9AFBFD8AFBFD9AEBFD9
ADC1DCABBFDAADBEDCAEBFDDADBDDEAABDDDABBBDFAABCE2A8BAE2ABBCE7A9BAE5A8B9E4
A7BAE5A6B9E4A4B6E4A2B5E0A2B5E0A0B3DE9FB2DD9FB2DD9FB2DD9DB0DB9BADDB9AAFDE
9AAFDE98ADDC97ABDD95A9DC95A9DE94A7DF95A8E291A6DF90A4DF8FA3DE8DA1DC8EA2DD
8AA0DC899FDB8B9FDC8C9FDA8A9DD88C9FDA899CD7899CD78699D38497D18393CE8393CE
8292CD8091C9808FC67C8BC27D8EC27C8DC17B8CC07C8DC37A8BC3798AC27487C17386C0
7287C07287BE6E83BA7286BB6E82B56D81B36D82B16E80AE6E7FAD6E7FAB6D7EAC6A7BA9
6A7BA96977A66A78A96875A96673A76875AA6673AA6372A96172A86172A65E6FA35D6FA1
5A6C9E5B6D9D5B6C9A5A6B995B6C9A5667955768965869975B6998556392546291546293
566294556394556195536095515E934C5C904E5E8F4B5D8B4A5F8A485E87475D84465C81
445A7F41577C41587A3E55773E55774256793F5376425478445478435377415077425178
414F763D4B723E4C733D4C733B4A7138476E36486E36486E35476D34466C314369314367
32456631446532426334436235435E354159323D53303B4F
1E181C2924282A232A1C171E23202948454E62606B46464E44474E5D62665B60635D6663
535D54353F342F372A373D31393F31595D4F76786D72726864655D63645E7F7E7A74736F
504F4D41403E3D3C3A3D3D3B3D3F3C4A4C495858565C5C5A6363616769646A6C676C6F68
71746B72756A75786D737768717564858A749FA48D989E845C624860694E4B533B464E37
353D28333A2A33392D32382E343932454A46646867767A7B8B8C90BABBBFC6C7CBBDBEC2
C2C3C7CECFD1CFCFD1D1D1D3D3D3D3D4D4D4D4D4D4D6D6D4D9D9D7DADBD6D8D7D2DEDED6
DAD7D0AFACA3736E6846433C5C595265625B6B6B6377776F7E7B7477746D7471687B7B71
77796E65675A95978ABBBDB0B6B9AEA2A698A9AD9EA5A7997D7E707573667C786D7B776C
827B738F8681A19694B1A5A5CBC0C4ABA2A79E979F9B969D94939B91919B83838D797C85
82858C868B8F7C81847177775D635F7E857EAEB5ADCBD3C8C3C9BD919789525648525648
666A5C77796C6F6F634D4D414B4B3F4E504546483D47493E44473C43463B444740454841
474A434C4F484F524B53564F4F504B4D4E494F504B504F4D4645434A46454E4A4B4E484A
4D474B514B4F5953577C777BA4A2A5BEBEC0C3C2C7B5B4BAADACB4B3B3BDBFBECCD3D4E6
D8DAEF9CA1B7646881575D77636A87747A9A9197B7A8AECEABB1D1ADB3D3ADB3D3ABB2CF
B0B7D4B0B9D6B3BAD7B1BBD6B1BBD6B0BCD6B1BCD8AFBDD8B1C1DAB0C0D9B0C1DBB0C1DD
AEC1DFACBFDDACBFDFADBDDFADBDE1ADBDE1ABBDE5ADBFE7A9BAE5A7BAE4A7BAE4A4B7E1
A5B8E2A5B8E2A3B6E1A3B6E0A3B4DFA2B3DE9FB0DB9EB1DB9DB0DB9BB0DB9AAFDC98AFDB
98AEDD9AB0DF98AEDD97ADDE95ABDC94AADC93A8DD93A8DD90A5DC90A5DE90A5DE8EA3DC
8BA1DB8BA1DB889CD7889CD7889CD7879BD68599D48499D28398D18398D18598D28295CF
8394CC8192CA8192C87E8FC37D8DC17C8CC07B8AC17A89C07A89C27C8BC47887C27584BF
7585C07283BB7081B97182B86E7FB36D7FB16D7FAF6F81AF6C7EAC6C7EAC6B7DAD687AAA
6A7CAC6878AB6777AA6878AC6373A76574AB6372A96271A86071A76071A56171A45C6C9D
5B6B9C5C6D9B5D6B9A5E6C995A6895576894556694566795576894556692536490546593
5462915263915260914E5E8F4E5E914C5C8F4C5C8D495B89495E89495E89475D86455B82
42587D41587A43577A45597C42567942567942567945577B425178425178414F76425077
404D77404D773D4C753D4C753A497035476D34466E34466E32466B33476C314568314568
2E45652D446330456231455E32445A324355303D4D2E3C49
1F1A2027222828232A211C230F0C133431386160664A4B4F5155566266655B605A595F55
4B5143333A2A3135244549385A5D4C898A7C9D9D919191854C4C4432322A605F5A7F7E7A
56555134332F3534303D3C38393A3552534E62615D666561696863696863707169717368
73756A74766977796C7B7F706F74607E836D8890786C755A545D42788068717961555D46
464E39414838373A2F383B323C3F384B4D4A7678779D9D9FB7B6BBC9C8CEC8C7CDC8C7CD
CFCED4CECDD3CECDD2D1D0D5D4D3D8D5D5D7D5D5D7D8D8D8D7D7D5D9D9D7D6D7D2E1E2DC
D5D6CE9C9C945F5F5737342D4242384B4B4155554B636359747168747168716D627C7A6E
7373677B7B6FAEAEA2A7A79BA4A699AAAC9FA5A799A2A49693948678766A716D62756E66
887F7A9C918F8B7D7D98898EC1B2B9A598A1988A97998E9C99919E88808F787280888290
9F9CA7B5B2BBACAAAF89898B7F7F7DB6B7B2CBCCC6D3D6CDC0C2B580827457594B636655
595B4D52544654544847473B49493F484A3F4A4B434D4E46484941464940494A44494C45
474A434D504950534C53564F52534D51524C53524E4E4A474A46434D4747554C4F534A4D
52494C60575C7F757DB8B1B8BAB7BEAAA7AEB2AFB8BBB9C4BCBAC7C4C3D3CCCDE2B8BAD3
9397B26064815C61816E74947C82A499A2C3A9B2D3AAB3D2AAB3D0AEB5D2AEB5D2AFB6D3
B3BAD7B3BAD6B5BCD9B4BBD7B2BCD7B2BBD8B1BCDAB0BEDBB2C0DDB1C0DDB0C1DFB1C1E2
B0C3E3ADC0E1ACBEE4ACBEE4ACBEE6ABBDE5ADBEE9ABBCE7AABDE8AABDE7A7BAE4A6B9E1
A7B9E1A5B7DFA2B4DCA4B6DEA3B5DDA3B5DDA0B1DCA1B2DD9DB0DB9AAFDC99AFDE97ADDC
95ADDB96AEDC95ADDD92AADA92AADA93ABDB91A7D990A6D88EA5D990A7DD8FA4DB8DA2D9
8DA2DB8CA2DB8A9FD8899ED7879DD6879DD68399D28197D08298D18196CF8297D07F94CD
8194CE8093CB7C8FC77D8EC47C8DC37B8AC17A89C27A89C27C88C27A86C27985C17985C1
7584BF7584BD7483BC7281B86F7FB36E7EB16D7DAE6F7FB06B7DAB6B7DAB697BAB687AAA
6A7CAE687AAC6779AB6478AB6374A86172A86273A96372A95F70A45F6FA25E6EA15C6C9D
5F6D9E5D6B9A5D6B9A5D6B9A5967965B6998576896566795566793556692546591546591
51628E51628E4F608E4E5F8D4E5E8F4C5C8D4B5D8B485A884A5C8A465B86475C87445A83
41577E43597E45597E42567B42547A42547A41557A42547A43527944537A424F79414E78
404D773F4C763D4A743B4A7339487137497137487336477233456D34476F33456B33476C
2E45652D44632C44602D435B2F4157314254313E4E2D3B48
2826292321242B262A2722261412152F2D2E6463615C5D585E5F595D5E5659594F59594D
535444353624393A28595846898675B5B2A3908C8077756946433C3B3B334F4E495C5B56
53544E41403B403F3A3F3C353E3E3668655C6B685F6E6B626E6B626F6C63737067757269
7373697A7C7187897E787C6E44483A4F56465E66576C75647C8776737E6D667160666F5E
636B5C4A52433A4034444A3E474A4153564D8D8E88B2B3AEC5C4C2C9C5C6CCC7CBCFC8CF
D2CDD3D2CDD3D3CED5D5D3D8D3D1D6D4D2D5D7D5D8D6D4D5D5D5D3D8D8D6DCDBD7D9DAD4
BDBEB685867E45453B2F2F254444384D4D414E4C3F514F427A77687F7C6D6B65596F695D
807C71989489B2AFA6A5A299A4A198A8A59C98988E9D9D93A6A69C8E8B82726B63736A65
8E85809E9391887A7A8E7D83B19DA6A5919CA18D999E8998907E8C7C6A7AA08E9EBEACBA
BEAEB9CFBFC9DACDD6D1C6CCABA0A4CAC1C2D8D3D0C1BEB98F8F8566665A4F4F43606254
5C5E51474B3D47493C4A4C414A4B434B4C444C4D47494A4446473F4748404B4A454F504A
4B4C4651524A56574F58595153534951514755524B4E4B444A45414A423F534B49594F50
6157588A7F83A59AA0BFB5BEABA3AE9C96A2AEA8B6CCC8D7E2E0EED5D4E6C9C6E18483A2
636483595C7D6E72978187AB9BA1C5A4ADCEAAB5D3ABB6D2ABB6D2AEB8D3B0BAD5B1BAD7
B2BBD8B4BDDAB6BCDCB5BBDBB3BCDBB3BCDDB2BCDFB1BEE0B4C1E4B2C0E5B1BFE4B1C0E7
B1C3EBAEBFEAACBFE9AABDE8ACBFE9ABBEE8ABBEE9AABDE8A8B9E4AABBE6A7B9E1A9BBE1
A8B7DEA8B7DEA8B6DBA5B3D8A3B1D8A2B1DAA2B1DCA1B2DE9DAFDD9AAFDE9BB1E297AFDF
96AEDE99B1E194ABDD91A8DA92A9DB92A9DB91A8DA8FA6D88EA5D78EA5D98DA4D88CA3D7
8FA4DB8CA1D88AA1D789A0D6899ED5869CD5859BD4839CD47F98D08096CF8096D08096D0
7E94CE7E94CE7E92CD7C8FCA7B8EC87B8EC87A8AC67888C47A88C57887C27584BF7685C0
7584BF7382BB7682BC7380B5727FB37280B1707EAF6E7CAD6C7DAB6B7CAA6A7CAA6A7CAA
697BAB697BAB657AA9657BAC6175A76074A76172A66173A56373A66171A46370A4616EA2
616DA15F6B9F5D699D5E6A9E5A679B5C699D59699C576798546694556795526492526590
5265904F628C4E618C4C5F8A4C5D8B4E5F8D4D5E8C4B5D8B4A5C8A4A5C8A485A88425784
43588343588345588243568043567E41547C40527A41537B44537C42517A424F7B424F79
42517A3F4D74404C743E4A743C4B743847703847723A4875374572344571354370344570
32466B3145682F43642F4260303F5C314057323D512D3949
3331363331343230333533343534324544405B5A555A5A526060565C5A4E59574A545243
5B58475956435E5B4A504D3C6D6759979185726E635D5852534E48423F3A41403B53524E
5554504C4B4653504B46433C5A574E84817877746B77756974726674726675726974746A
78786E818378797A724B4E4515181140453E5960596C766D6D776E626C63646E63687065
696F65646A6054574E56594E626459717368A3A59AC6C6BECECBC6CCC8C5D0CACAD9D0D3
D5CFD3D5CFD3D6CFD6D7D2D8D7D2D8D6D1D7D6D1D7D6D1D5D5D3D4D7D5D6E3DFDED0CFCD
9E9F9A63645E3F3E3942423A4E4E44515145504E41545245706E5F757263696355645E52
837F73A19D92AAA69D99968D9E9B94A9A69FA5A49FACACA49A9A9288857E6F6A64736B68
847A789186849789899B8B8EA49195A8939A97828B96808C937B88A6909CC8B2BEC1ABB7
C8B4BFEDDCE4FCEDF4DFD2D9988C90A59A9EB0AAAA908C89706F6A54554D484941505247
4A4D424A4D424A4D42484B42484B42494C434D4E4847484248484048484049494154544C
595A5260625760625756584B4D4D414C4C404F4D41514F434F4B424C453F544C49665E5B
78706EA89FA0B9B0B3ABA1A99C959DB2ACB8B9B2C2D2CEDFD8D5E6B5B3C88C8CA8616281
686B8C6C70938389AD9DA3C7A9B1D5A6B1D1A9B4D2AAB5D1ACB7D3B0BCD6B2BED8B2BED8
B4BFDBB2BDDBB3BCDBB4BDDEB4BEE1B4BEE1B0BDE0B1BDE3B2C0E5B1C0E7B2BFE9B1C0E9
AFC0EBB0C1ECAEC1ECABBEE9ACBFE9ABBEE8ABBEE8AABDE7A8BBE3A7BBE0A8BAE0A7B9DD
A6B8DCA8B8DCA7B5DAA5B3D8A3B2D9A2B1DAA2B1DCA1B2DE9EB0E09BAFE199AFE197AEE0
97ADDF97AEE093AADE91A8DC90A7DB92A9DB8FA5D78EA5D790A6D88EA5D78AA1D389A0D2
8A9FD48BA0D5899ED38A9FD4899ED3869BD2839AD08099CF8096CF7E97CF7C95CE7A93CC
7B94CD7B94CD7C92CC7B91CB798FC9788CC7788BC6778AC57588C37787C27687BF7685BE
7483BA7484B8747FB57581B5737FB17480B2717DAF6F7DAC6E7CAB6B7CAA6A7CAA687AA8
687AA86479A6637AA66278A76177A65F75A65D71A36072A25F71A16070A1616FA0606E9F
616EA25F6B9F5E6A9E5E699F5C699E58689C57679A56689A5668985368955065924F6491
4F648F4E638E4F648F4C618C4B5E894F628D495B89485A884A5C8C495B8B485A8A455785
44598643588544578246578344558043547F43527D41507B42517C424F7B414E7A44517B
4251783E4D743F4B733B49703B49703847703A49743B4A75374572364471374572354370
33456D2F43683143673242642F3E5F333E5A323C552F374C
4A494F46454A44444642424245464151524C56564C54544859574A59574A575445565344
696355767060756F61484234352F236F68607D75726863604D48453B37344544425B5A58
5D59585E5A57625E5B514D4A706F6A98999180817975786D72766874786A777A6F7B7E73
797C736B6E654A4D462527241E201F3E42415256575F6565626868636967676C68696E68
696B666E6F696665607D7A739B9B93A8A89EB8B8AEC7C4BBCBC8BFCCC9C2D3CECAD5D0CD
D7D1D1D6D0D0D7D1D3D8D2D4DAD4D8D9D2D9D6CFD6D4CDD4D5CBD3DBD1D9DCD5DCBFB9BD
7C777B5955564B47484D49484E4D4951514953534956564A5F605264655766645759574A
73716499998D94948A919187AAABA3C9CAC4BEBFBAAAACA77A7C776B6C667D7C7784817C
847F7B908885968C8A938886AB9D9CB9A9AA917E80A59294BAA6A8B3A0A2B5A2A6BBABAE
D1C2C7E7DAE1E8DDE3D7CED3777276565457817F807070706264634D5150444945434842
424740474A434C4F484E4F494B4C464B4C464C4B4648474249494146463E4242385B5B4F
67695C6A6C5E5C5E504C4E404B4D3F4E4F41514F42514F42534F444E4A3F4F4B4278746B
8F8C859E9B969F9B989A9697ABA9ACCDCCD2D0CED9BFBECC9394A676788D696D88666B89
707696868FB09FAACAA7B2D2A9B4D4A7B5D2ABB9D6ABB9D4ABB9D4AFBDD8AEBCD6AEBCD6
B2C0DBB1BFDCB1C0DDB1C0DFB2C1E2B4C2E5B1BFE4B0C0E4B0C0E4ADBFE3B1C0E7ACBEE4
ADBFE7ABBEE6ADC0E8ACBFE7AAC0E5A9BFE4A8BEE5A9BFE4A7BEE0A3BADAA3BADAA2B9D9
A4B8D9A4B8DBA4B6DAA4B6DCA1B3DBA0B1DC9DAEDA9DAFDD9DAFDF9AAEE09AAEE196ABE0
95A9DE95AADF94A9E092A7DC92A7DC92A7DC91A5DA8EA3D88EA2D58EA2D590A4D98CA0D5
8B9FD48A9ED38A9ED3899DD2889CD1859ACF8196CB8198CC8095CC7F96CC7D94CA7D93CC
7B94CC7790C87790C8768FC7758EC6758EC6778DC6748BC17287BE7388BD7387BA7384B8
7284B67282B3727EB0747EAF7680B1737DAE6E7AAA6E7CAB6D7BA86B7CA8697CA76679A4
657AA56378A36077A16279A56076A55F75A46075A45F74A15C719E5E709E5E709E5E6F9D
5D6D9E5B6B9C5C699D5D6A9E5A6A9E55669A5465995367995266985066954F65944E6591
4D64904E65914A628E475F8B465D89485D8A465B8A4658884A5C8A4A5C8A485987485987
47588645568246548146548144517D44517D444F7D45507E424D7A3E4B77404D7943507A
3F4E753C4C703C4C703C4C7038486C3A497039486F39487135446F34436E35446F34436E
2F406B2F406B303F683140672F3D60313C5C2D36532A344F
5B5C6155565B5152564A4C4B47494450514B56584D555549535446555344534F43524E42
6A64587A7468625B514F483E453E38605855776E6F6A64643E38383D39384F4D4E5D5B5C
625E5D64605F6864635E5D5963645E90938A7A80766A72656C74656972617D85769AA293
8E96895F65592B3029222421282A293B3C3E56575B5F63666667696A6C6B6E6E6C6F6E6A
6D69666E6965827B75A29994C2BBB3C6BFB7CAC3B9CDC6BCCCC8BDCCC8BDD2CBC3D3CCC6
D5CDCAD7CFCDD7CECFDBD2D3DDD4D9DCD3D8D7CDD6CFC5CEC4BAC3C0B6BFB6ACB5A59EA6
6F686F433E424A45494F4D4E51504C53524D54544C5B5D526365586466586163565F6154
7375678E9082808475898D7FB9BDAFEEF4E6E4EADEC1C7BD7A807661645B8D9087A1A29A
99999196968E9A958F7A766DACA59DC9C0B9AEA39DAFA19EC5B8B2AA9D97958A86B2A7A5
D8D0CEC5BFBFB6B2B3A3A1A26E6E6E4C4E4D6466655B5F5E575D5B4A504E3B413D3D433F
3F463F3F443D4D504953564D53564F4F50484D4E484A4A424A4A424E4E4449493F5E6053
686A5D6163565B5D4F484A3C4B4D3F4A4C3E504E41525043575348514D444F4B427B7670
A7A49F9594907B797A9B9B9DC7C6CBDEDEE6B2B2BE828493606376555A706F758F8087A3
939CB9A0A9C8AEB9D7A9B7D4AAB8D5ADBBD8AEBCD9AFBDDAAFBDD8B0BED9B2C2DCB2C2DC
AFBFD9B1C0DDB1C2DEB3C4E2B2C2E3B3C3E5B3C3E5B1C1E3B0C3E4B0C3E4B1C4E5AEC1E2
AEC1E2ADC0E1AEC1E2ABBFE0AABEDFA9C0E0A7BFE1A8C1E0A5BEDDA4BDDBA2BBD9A1BAD9
A3BCDBA1B8DA9FB5DAA0B3DBA1B4DE9FB2DD9FB1DF9BADDB98ADDC9AAEE098ACDF96AADF
95A9DE96AADF92A7DC92A7DC91A5DA92A6DB8FA3D88EA2D78EA2D78CA0D58C9FD78B9ED6
8B9ED6899ED5899CD4889DD4879BD08499CE8196CD8095CC8196CD8196CD7E93CA7D94CA
7D94CA7A91C77790C8758EC6758EC4758EC4768DC3748BBF7188BC7389BB7187B97387B9
7287B67587B57280AF727FAC7380AD717EAB707CAC6E7CAB6B7CA86C7DA96B7DAB6678A6
6479A66378A56176A36176A56277A66176A56274A45D6F9D5E719C5F729D5D6F9D596B99
596B995C6D9B59699A58689B57699B54689A54689B5268995066975066974D65934E6694
4A62904A629048608E475F8D465C8B475D8C475B8D445988495B8B475987455684485987
47588448568346538043507D47548045507D46517F444F7D3E49763D4A763E4B77414E7A
404E753C4C703B4A713B4B6F3A497039486F38476E37466D35446B37466F32416A32416A
31406B31406B2F3E673240672E3B5E2C39592C37552A3551
7D80877073786E72757377766F74706669625859515A5C5154564854554759574B5B584F
58544B544F4948403D544C4A6862626660625F595D4A4549363437504E4F595758626061
63626063625E65646065666066696072786C6C74656D78676A76626C786289957FA5B19B
84907C4E5948282E22292F252B302A393B385557566161616867656D6966726A67766D68
766B676D605A8C7D76A7968FC0AFA8C3B4ADC6B8AFD0C3BAD0C6BCD2C8BFD2C9C2CEC5C0
CEC4C2D1C9C7D6CDCED7CECFD5CFD3C2BCC0B4ADB5A7A0A89C949F8F899379747B6C6A6F
5D5B5E4947484F4E4A55544F51514956574F6062575F615666685B67695C565A4C4F5344
89907E959D88666E597E8870C3CDB5E2ECD3E3EDD5C6CEB79EA691A9AD9CB2B6A7B3B7A8
A7AB9C9B9F90969A8B828675949887B1B4A3ADAEA0C7C5B8BBB9AD9B998D8F8B82A7A49B
B8B5AE9E9D988E8F8A8888867577726769645C615B596059505A523C463D3842393D473E
3F49403C4439444C4150564A545A5053564B52554C4C4E434C4E4355574C53554A5C5E53
5E605555584D55584D494C414A4C414C4E434D4A4153504757524C5C5451635A5B766D70
A9A3A7807B8165646C8E8E98B4B4C0BABCC98C8F9E5B61715A5F73656B817F879E959CB6
ACB6CFB0BAD5B1BAD7AFBAD6AFBAD6B1BCD8B0BEDBB2C0DDB1BFDAB1BFDAB1C1DBB0BFDC
B3C4E0B3C4E0B3C4E0B5C6E4B1C4E2B1C4E4B3C3E4B4C4E5B3C4E2B3C4E0B2C3DFB1C2DC
B1C2DEB1C2DEB0C1DDAEC1DFACC1DEA9C1DDA7C0DEA6BFDDA4BFDCA4BFDCA2BDDBA1BCDA
A1BBDCA0B8DCA0B6DB9FB5DC9EB4DD9BB0DB9CB1DE9AAFDC9BADDD99ADDF97ABDD94AADB
94AADB93A9DA93A7DA93A7DA90A5DA90A5DA90A5DC8EA3DA8DA0DA8C9FD98C9FDA899DD8
8BA0D9879DD6879CD5859BD4859AD38398D18398D18196CF8194CE8194CE8295CF7E93CA
7C91C87D92C77B90C7788DC4788DC4778CC3768BC07388BD7489BE7288BA7288BA7086B7
7288B77186B56F81B16F80AE6E7FAD6D7EAC6E7EAF6E7EAF6C7DAB687AAA697BAD6779AB
6475A96576AA6374A86273A76374A86274A66272A56070A15F709E5F709C60719D60719D
5B6C985869955A6B97596A98596B9B54699853679953699A5268994F67974D65954C6494
4A62924A62924A6292495F90475D8E485E8F465C8E445A8C465A8C465B8A495B89465886
485B8647588445547F47548046537F44517D43507D43507D404D7A3F4D7A3F4D7A424F7B
404D773F4D743B48723B49703F4C763B497039476E39476E39476E38466D35436A324067
334168313F66303E65324065303D5F2E3C592C3A5429384F
8085897E8386858B8B8F9591919690666C624C4D4553554A57594C5E5E526360575D5A53
44413A3F3A36433B3962595A8F86897771735751553D383C4543445E5C5D5B595A61605E
60615C61625C65665E66695E6B6F617178686D76636B7761748068717D657C8870636F57
4A56403D49352D33252E3428353A33434540555553605F5D6A66636F67646D6361736864
786964766760806D678C7973A28F89B29F99B2A19AC3B2ABCABBB4D3C6BED3C6C0CEC3BF
CBC0BECBC1C0C8BFC0CDC7C9D4CED0B4AEB28A858B7C777D78737A65636857555A515153
4F4F4F4F504B4F4F4756564C55574A5C5E516F71646B6D5F6A6B5D686A5C6466585A5E4D
7F8470A7AF988489727D856DCBD4B9D8E1C6CDD6BBB6BBA4C3C6B1D4D7C4B9BCABAFB1A3
B1B5A69CA08F777E6C88907B9BA38CAFB49EB6BBA7E2E5D4CDCFC1A3A5979A9B8D9C9C90
97998E91928A8C8F888B8E8780837A61645B565C52555D524852473D473C3D473C424C41
404A413943383D453A4B534851594E545A4E52584C4F52474D504556574F595A52575850
50534C4E514A4F524B4C4F48494C454D4E484F4E4956524F625E5D625C5E6760676A636B
7B757F6864725E5D6B6E707F7E8192797C8D6B7083676E816E748A80889DA2A9C3ADB7D0
AFB9D4AFB9D4B0B9D6B1BCD8B3BEDAB0BED9B2C0DDB3C1DEB1BFDCB3C1DEB2C1DEB2C1DE
B3C2E1B3C4E0B2C3E1B4C5E3B3C4E2B5C6E4B3C4E2B3C4E2B3C4E0B3C4DEB3C3DCB3C3DC
B3C3DCB1C3DBB1C2DCAFC0DCACC0DBABC0DDA7BFDBA3BCDAA1BAD9A2BBDAA5BDDFA0BADD
A1BBE0A1B8E19FB6DFA0B5E09CB3DF9CB1E099AEDD9BADDF9DAFE19CAEE096AADC94A8DA
96ABDA95AAD994A8DA94A8DA92A6D98FA4D98FA4D98EA3DA8C9FD98CA0DB8CA0DD899FDB
8BA1DB859BD5849AD48399D38399D58399D38197D38094CF7E93CC7E93CC7E91CB7F92CC
7E91C97E92C77B8EC6798CC4788BC37689C17588C07487BF7386BE7186BB7186BB7287BC
6E84B66C82B36C80B26C80B26A7EB06C7EB06D7FB16D7DB06D7DB06979AC6878AC6978AF
6776AD6574AB6774AB6471A66370A5616EA2616EA26371A25F6D9C606E9B616F9C616F9C
5C6D985B6C975B6C98596A96556795526796556A995268975167985066974E64954C6293
4A6091495F904B5F924B5F924A5E91485C8F485C8F465A8D45598B475C8B485A88435681
46598442557F43547F46557E41537B41537B40517C3F507B3D4E793C4D783B4C773F4E79
424F793E4B753B4A733948713B4A733B487239467038466D36446B37456A3341662F3D62
313F64303E632E3C61303E61303D5D2F3D58303C542A364C
717679848A8A909692838A826E74684F55474B4D404D4F4259594D67675B6A675E59564F
413C3649423C39312E594F4D9F9594817977534A4B352C2D4E4848605C5B61605E676662
65665E65675C64685A676B5C6E7261727A656E765F6B755D7C866D7E886F6D775F333C27
323B282C3323282E222D3027363B3450524F5F5F5F6563646A66676E68686C636468605E
6C615F7469657C6D6A82736E85736F8E7C788E7C7A9B8987A69492C6B7B4CBBBBBC4B4B5
C4B8BAC4BABBC4BBBEC5BFC1CAC4C6C1BDBE9D9B9E8383857878785E605F575958555752
52554E5154494F51446062546366556669567A7B697779646D6C586B6A567C7B6781806C
73725E9C9E88AAA994A3A28DC1C0ACBDBCA8C1C2B0C9CAB8DDDBCCCFCCBDAEAC9FA9A79B
B0B0A4A5A5997B7C6CA0A18FB9BBA6B9BBA6BDBEACCBCCBADADBCBD9DACAAEAF9F959688
8F91848A8D828D908596998E8184794C4F44474A3F494F4540463C3F463E40473F414840
444B44394039363D36484F48535A52545C51545A504D53494C524853564F5558514F524B
4B4D484E504B4B504A484D49474C48494B4A4B4D4C575759656469605F655D5C645F5D68
5B5B675C5E6D5D6071606676676C7F656C7F656B81727A91888FA99CA3BDB0B7D4B0B9D6
AEB7D6B0BBD9AFBADAB3BEDEB2BFDFB0BFDCB1C0DFB1C0DDB1C0DDB3C2DFB3C0E0B3C2E1
B2C1E2B5C4E3B4C3E4B4C3E2B1C0DFB4C3E2B4C3E2B4C3E2B5C4E1B3C3DDB4C5DFB1C3DB
B1C3DBB1C2DCAFC0DCAEBFDDAFC0DEAABDDDABBEDFA8BCDFA5B9DEA2B8DFA1B7E0A1B8E2
9EB5E19FB5E49EB4E39CB2E39DB1E49CB0E59DAEE49BACE29CADE39DAEE299AADE98A9DD
9AACDE96A8D896A8D895A7D993A5D78FA3D68EA2D58CA0D58BA0D98BA0D98A9ED9879DD7
889EDA839BD7829AD67F97D38098D67E96D27E96D47F95D17C92CC7C92CB7B90C97A8FC8
7D90C87C8FC77C8CC77888C37787C27787C27686C27487C27285C07184BF7386C17186BF
6E83BA6D84BA6B80B7697EB56A7FB6687DB46B7CB26B7AB16C7BB26C79B06875AC6A77AE
6774AB6671A9666FA6666FA6666FA6636DA2636DA2616D9F5F6B9B5F6B9B5C6A975C6A97
5B6C975A6B965B6C975B6C985568935567955567955267945368975064965163954F6094
4F5F934E5E924E5E925060944E5E924B5B8F4B5B8E4A5A8D475989495B8B495B89455883
42588140567D3F557A41587A3F56783E55753E52753D51743C50753A4E733A4D753C4E76
394B71394B71394B7337497136477238477238477238477036456E35436A344269344066
344267313F622F3C5F313E60323D5B313C582F39522C364F
7F8585797F7D7E857E686E64414739434738535547595B4D5F5F5365655959564D4F4C45
5B5650615C563B342E4039339E979171696649413E3D3532514C4966625F676662696863
6A6A6267695E686A5D6B6D5F7072647B7E6D7D8170616554666A597E8271767A69454938
373B2C2A2E2021241932352C41443D565853646361656364696566696564635D5D5B5653
5A524F605654665B577065617466638173707F706D7A6A6A897979B7A7A7B5A5A6A49696
A99D9FA99FA0AEA5A6B5B0ADB5B0ADA19D9A908F8B93948F9E9F9A83847E72756E686B64
696B606A6C5F6667596F7060797A6876786376756176756078766176745F7A77647D7A67
74715E7C796693907DB4B1A0BCB6A8A9A599BCBAADCFCDC0CECABFCAC6BBAAA69D8D8A81
9F9C95A9A69DA7A599B0AEA1CCCABBCECDBBADAB9CADAB9CE1DFD2F1EFE2C1BFB28B8B7F
888A7F8E9085A6A89D91948966695E484B403D403746494040433C3C413B3F443E424741
434844383E3A2E34304248445A645C59635A565D5551564F4F544D525751464843454744
4D4F4C4D4F4C4A4C4B45494A43474A494E524B4E534E5158585B6453565F585A675E626E
575D6B585E6E5B627462697C646A80666C84787F999097B3A7AECBB0B7D4AFB8D7B2BBDC
B0BBDBB3BDE0B5BFE2B5BFE2B4C1E1B3C2E1B4C1E1B2C1E0B4C1E1B4C1E1B5C2E2B5C0E0
B4C1E3B5C2E4B7C1E4B8C2E5B7C2E2B7C2E2B4C1E1B5C2E2B5C4E1B4C3E0B3C4E0B2C3DF
AEC2DDAEC2DDAEBFDDAEBEDFACBCDEAEBEE0AABADEAABCE2A7B9E1A5B8E2A3B6E19FB4E1
9FB4E39DB1E39EB2E59FB3E69CB0E59CADE39EAFE79DAEE499AAE099AAE098A9DF99AADE
99ABDD96A8DA93A7D993A7D98FA3D58FA3D691A5D88EA3D8889DD4889DD6899DD8879DD7
869CD88499D88196D57D95D57F97D77D95D57D95D57A92D07992CB7B91CB7A8FC87B90C9
7B8EC67B8EC67A8BC37889C17889C17888C37585C17383BF7082C07082C07082C06E82BD
6F84BD6C82BB6A80B9677DB6697DB86A7EB9677AB46777B26B7AB36975AF6973AE6771AC
6671A96671A96770A7666DA4656CA2636DA2626C9F626EA05F6B9D5D6B9A5D6B9A5A6B99
5A6B97556893586B96586B96586A98556795556795536595536595516395516194506094
525F93525F93505D914E5B8F4F5B8F4C598D4D598B4B598A455586495A884A5B89425580
42557F3E547B3E54793E56784158783F56763C53733B52723B5274395072394D723B4F74
364A6F384C71374A7235487037497137487337467135446D35446D35446D35436A35436A
3644692F3D602F3D602F3C5E303E5B2F3A562E38532C334D
6A7370676D69666B655A5D54414338484A3D5353475B5B4F58584C4A4A3E44443A707066
7A7A7068685E4E4E4445453B68685E4E4E463D3A3343403951504B6B6A65696863696863
6B6A656D6C676C6B666D6C67706D687C7974807F7A4D4C474C4D4770716974756D606159
5D5F54393B3020221736382D4D4F445E5E56656460686463706A6A5D585547423F4A4541
4D4844504B4757504A635C546861597168617166606E635F736562B3A5A2978C8A857A78
8C828088817B97908AA4A0979D9990807C73716F6379776B98968A99998F8A8A8079796F
79766D7E7A6F6D6B5F6563577C7A6D8482737572636A67566B6A587978648685738B8A78
8A88797E7C6D817F729C9A8EAAA79EB2AFA8B3B3ABBEBEB6D8D5CECECBC49D9A95777672
93928DA2A19CAEABA4B4B1A8C2C0B4C7C5B9BCB8ADD7D0C6F2EBE1DAD3CB97938A817C76
8E8B868F8E89B1B0AB82837D3B3C3442433B42433D44464140423D444643434542414642
3F43423A403E313735414A455D675F5A645C585F58565D564D524C4C514B444643454545
4C4C4E4C4D4F4D4E52474A4F454952464D574D545E4C525E4A525D4B535E565D6D5F6877
565F70545C6F5D637961677F6A718B737A969197B7B2B8DAB3B9DBB0B6D8AEB6DAB2BCDF
B5BDE1B5BDE1B4BEE1B5BFE2B5BFE2B6C3E5B8C2E5B6C3E3B8C3E3B8C3E3B9C2E3B9C2E1
B9BFE1BAC0E2BBBFE2BCC2E4BCC2E4B8C1E2B7C2E2B4C1E1B5C4E3B4C3E2B2C2E3AFBFE0
ADC0E0ADC0E1AFBFE3AFBFE3ABBDE1ACBBE2A8B7E0A9B8E3A9B8E3A8B9E5A5B6E4A2B4E2
A1B3E3A0B2E2A0B2E49FB1E39DAEE29CADE19DAFE19DAFE199AADE96AADD95A9DE96ABE0
92A8DA93A9DB90A6D88FA5D78EA5D78DA4D88CA3D78CA1D88BA0D9899ED7889CD7869AD7
889CDB8598DA8295D78396DA8396DA7F94D77F94D77D92D37A8FCE7A90CC7B8FCA7A8FC8
798CC47A8DC5798CC4768ABF7788BE7788BE7687BF7485BD7184BE6F84BD6E83BC6F84BD
6C81BA6A7FB86A7EB9697DB86A7DB8687BB66878B46878B46877B26776B16773AF6672AC
6772AA6772AA656EA5626BA2626CA1636DA2646EA3636FA3616EA25E6EA159699C59699A
566898526796566B9A5469985368975267965466965163955163955163954F5F92505D91
535F91535F91525E90505C8E4E588B4B57894D57884D59894B57874A5686475584465481
44558042557F42557D41577E41557A3F53763D51743B4F72395072384F71394D723A4C72
394B73384A723648703749713B4A7339487134466E33456D37497133456B32446A35446B
3444683040642F3F63324063303D5F2F3A5A2C35522B3550
636C69686E6A5F645E50534A4D4F445353475152445556484E4F413334263A3A2E7D7D71
7C7E715D5F5247493C4F514653554A4B4D4247473F4F4F475C5D55696A626A69646D6C67
726E6B736F6E726E6F716D6E706A6E7772787873794C4A4F5452557070707777756E6F6A
5C5F56484B403D3F3445473A5A5C4F5D5F5461605B65646065615E494542403C394A4742
4746414A494454514A5B58515E5B52615D54655E56665F596A615C918785716966706865
76716B7672697D7970807C717A786C727064727064757367817F7388857C89867F7C7974
79746E7D787268635D68655C7F7B70868276726F605552435D5C4A7B7A68989785969485
8987788785788D89808A87809F9C97C1C0BCB7B3B2CDCCCAF7F6F4BFBDBE807E818B898C
ABA9AAADACAAAFAEAAB8B7B2C1C1B9DDDAD1F5F1E8FAF6EDD6CFC7A8A1996C676174716C
8685807C7B7673746E4D4E4835383146494244474044474042443F494B46474946414642
414642393F3B404642535C575C665E5E655E676E67686D67474C46454744484848454547
47464B4D4C524A4A52484B54484C58464C584E56634B53604C5662515A69556171586375
545F71575F745F657F666B887F84A2969BBBADB1D4B3B7DCB2B8DCB3B9DDB1B9DDB4BCE0
B5BDE2B5BDE1B7C1E4B5BFE2B6C0E3B7C1E4B9C3E6B7C1E4B8C3E3B7C2E2BAC3E4BCC2E4
BAC0E2BBBFE2BABEE3BDC1E6BBC1E5B8C0E4B7C1E4B4C1E3B1BFE2B1C1E3B1C1E5AEBEE2
AEC0E6ADBFE5AEBDE6ADBCE5ABBAE3ACBBE4A8B5E1A8B5E2A7B5E2A7B5E2A8B6E5A6B7E5
A3B4E2A1B2E0A1B1E29FAFE09FAFE29BADDF9CAEDE99ABDD95A9DC97ABE093A8DD94A9DE
90A7DB90A7DB8DA4D88DA4D88AA4D78AA4D78AA1D78AA1D78BA0D7899ED78A9DD7889BD6
889AD88698D88294D68395D78192D78192D78091D67E91D37B8FCE7C90CF7C90CD798DC8
7A8DC7798CC4788BC3778BC07889BF7586BC7687BD7586BC7185BA7184BC6F82BA6F82BA
6C7FB76D80B86E7EB96979B46878B36878B36979B46978B36877B06776AF6773AD6470AA
6673AA6774AB6570A6626DA3636EA4616CA2616EA35F6CA1606DA25E6EA25C6CA05A6A9D
586A9C586A9C586A9C56689A556797526494526494536595506292506091526091515F90
525E8E505C8C515B8C525C8D505A8B4F598A4E588B4C58884C56894B5787495587485484
46548144558143548040537D40537B40537B3E52773D51763A4E713A4E713B4D73394B71
384A70384A723648703749713B4A7137466D37466F36487033456D34466C33456D33456B
32446A334269303F66303E63313E612E3B5D2D365529324F
626B665F665F5358514F52475256484F51434D503F535645464936313421393C2B5D604F
66685A4446383B3F304E524454574C585B505B5C545F605862635B696A626E6D6873706B
7B76737F797B7771754841494E4852847E8A7B778549475267676F797C816B6F70676D69
5E665B586053555B4D575D4F5F63555F625760635A5659524B4D4840423F434341454641
4445404A4B465554505A59545C5C545B5B535F5C5763605B5F5C57625E5B5F5B5863605B
66656063635B61615967675D6D6D636C6C646F6F678685806F6E6A5A59576462636E6C6F
726E6F71706E6D6C686F6E697471687472666E6A5E504D3C59584471705C817E6B84816E
827F708D897DA49D95ADA5A2B3AEABCECACBDCD5DCE6E1E8CDCAD1AFACB5918F9AA7A5B0
B4B3BBA8A7ACABABABCFD0CBD9DAD2E8EADDE2E2D6DCDACEA9A99D78786E616157707169
676A614D53494D5349494F45444A40484E44454B41454B414B514750564C474C45434841
474E464249414D544C515850515850777E767B807A6E736D4146423E403D49494B444247
4342474C4B514C4C544B4B55474956494C5B4B515F4D55625A63725A63725962735A6275
5860755E667D6E748E7E83A09CA1BFAEB1D2B2B5D8B4B6DCB3B7DAB4BADCB4BADCB5BEDF
B5BDE1B8C1E2B7C2E2B5BFE2B6C3E5B8C5E8B8C2E5B7C1E4B7C1E4B5BFE2B7BFE3B6BEE2
B7BFE3BBC3E7B7BFE4B9C1E6B7C0E7B4C0E6B4C0E8B2C0E7AEBDE4ADBFE5AEC0E8ADBFE7
B0BFEAAFBEE9AEBBE8ADBAE7ADBAE7ABB8E5A8B4E4A8B4E4A6B2E2A6B2E2A5B2DFA5B3E0
A1B2DEA1B2DEA1AFDEA0AEDD9FAFE09DADDE9BADDF98AADC96AADF96A9E194A7DF94A9E0
91A8DE8FA6DC8EA5DB8EA5DB8DA4DA8AA1D78AA0D989A0D68A9FD6899ED58A9DD5879AD4
8598D38595D18694D38593D28492D38291D48190D37E90D27D8FCF7C8ECE7D8FCF7B8DCB
788CC7788DC67689C37689C17889C17786BD7584BB7585B97484B87382B9727FB6727FB6
6F7EB56E7DB46F7EB56C7BB26877AE6776AD6978AF6979AD6878AC6777AB6675AC6372A9
6273A76273A76172A85F70A65D6CA35D6CA35F6EA55E6DA4606DA4606DA25E6BA05A679B
5A679B5967985B699A59659758649455639255639253649252638F50618D54628F52608D
53608D505D8A4F5B8B4E5A8A4D598B4D598B4C588C4A58894A568A4C588A4A568A495587
45538444528144528142537F3F507C40517D3F507B3E50783D4F753B4D733B4A713C4B72
3A49703A49703A49703A49703A497035446B36456C37466F35446D38477033426D33426D
33426D313F6C303B682F3B652D39612E3B5E293253283150
6A6F6B565B554A4D444A4C41494B3D474A394C4F3C4E513C4649344245304B4E394F523F
4E513E4043323C4031494D3E585C4E5F625761635866675F6869616A6B636C6B6671706B
878380928E8D706B6F3230353D3A436E6C776B697462626C85888D7A7F825157555E6860
5E685D5B66585C64575C645762685C61675D4E534C434842404541414544434544434544
464845494B485252525656545859545758535958565F5E5C5A59575554525A59575C5C5A
5A5B56595A55565751595A5468696373746E7576716D6D6B5D5D5B5858586361666B696E
7371747171716E6F6A70716B7070687474687775685E5D4B60624C72745C7F7F6785836E
8A8774A49E8EB6AEA3B0A9A1CCC4C2F2E9ECECE2EACCC5CDA8A0ADAEA8B4B6B2C0ADA9B7
A29FAAAEADB3C5C4C9DCDCDAEDEEE8DEE0D5BABAB0C7C7BDC3C3B975776C5A5C5166695E
494F43424A3D464E41485043474F42444C3F4951444C544751594C555B4F53594F50584D
525A4F4D574C4C534B4951464E564B969D95979C967176703C413D3C3E3B4B4B4D4A4A4C
4A494E4D4E534D4D554B4B55494B584D4F5C4D505F4E5464565D6D586172575F725E667B
5E667D686F89888DAAA1A6C4AEB1D2B4B7D8B5B5DBB6B6DCB5B8DBB6BADDB8BCDFB6BCDE
B6BFE0B8C0E4B7C1E4B7C1E4B7C1E5B5C2E5B5C2E5B8C5E8B6C3E5B6C3E5B6C3E6B5C2E5
B1BEE1B5C2E5B3BFE5B4C2E7B3C1E8B3C1E8B4C2E9B2C1E8AEC0E8ACBEE6ADBFE7ADBEE9
AEBDE8ACBAE7AFBCE9ADB9E9ABB7E7ABB9E8A7B5E6A6B4E5A5B3E2A5B3E2A3B1E0A1B2DE
A0B1DDA1B2DE9FB0DC9DAEDC9EAFDD9CAEDE9BADDF98ACDF95A9DE94A9E093A8E192A7DE
90A7DD8EA7DD8AA3DB8AA3DB89A2D88BA2D8899FD889A0D6879CD3869BD08598D08598D0
8697CF8292CD8392CD8290CD8391CE8191CF808FD07E8DCE7D8DCB7B8DCB7A8CCA798BC9
778BC6768BC47487BF7487BF7889C17584BB7484B87582B67582B67481B5707DB1707DB1
6D7AAE6E7BAF6F7CB06C79AD6979AD6777AB6976AA6A77AB6875A96676A96575A96373A7
6071A55E72A55F73A85C70A55D6EA45C6DA35D6EA65C6DA55E6DA4616EA55D6A9F5B679B
5965975A66985C66995B659657629056639055628F54638E51608B4F608B4F5E8952618C
505F8A4E5D884B58854A58874E5A8C4C5A8B4B598A4A578B49568A4A578B475387465485
45538443518242507F404E7D3E4C7B3A4B773F4E793F4E77404F783C4B7238476E37466D
38476E39486F39486F39486F38477036456C35446D33426B33426D34436E31406B303E6B
2F3D6A2F3D6A303B692F3A672E3A642E3A602A34572B3455
6564605A595457544B4A483C4243334546344F513C50523C52543E565842585A444E503B
4C4F3C4A4D3C4C50415256475960505C62545C6052676A5F6C6F64696C636D6E68787973
898A858F908B7779764749463C3E3D4B4F4E6F73727B7F7E7A807C636A634F564E5F675C
5C665B5C665B60675F62676061635E5254513E403D3E403F44454746474B46454A444348
48474C4C4B50525053535154545255545255585357565457565455505050515151545454
545454525453525250555553686A657D7F7A7A7C79585856535351626061656364696768
70706E70716C70716C71746B74776C767A6B737766676C5673795F787C61808368939379
ABA990B3B19AB5B09DC2BCAEE9E2DAECE2E0C5B9BDB4A9AFB2A6B0B7ADB6B7ADB8A59DA8
ABA3AED4CDD5E8E3E9E6E1E5F0ECEBDBD7D4C9C5C2D7D3D0B8B7B35A5B554649404D5347
3D4536414A39414C3B424D3C434E3E434E3E4954444D5848515C4C565E51586055575F54
5A6159585F574C534C4B524A50574F7A8179777E77595E583E433D464B474D4F4C4E504F
4F50525051534E4F535152574F525B51535F4F5261525868535A6C565D70555B715C627A
686D8A8287A59FA4C2ADB2D2B2B5D6B3B6D7B3B3D9B9B9DFBABADEB8BBDEBBBDE3BABEE3
B8BEE2B8C0E5B8C0E5B7C1E5B7C1E5B6C3E6B6C4E9B5C5E9B4C7E8B5C8E9B4C6EAB1C3E7
AFC3E4B0C4E5AEC2E3B0C4E5AEC2E5AFC1E5AFC1E5B0C2E6ADBFE5ADBFE5AEBDE4AEBDE6
AABCE4ADBCE7AFBCE8ADBAE7AAB8E5A7B8E6A5B5E6A4B4E5A2B4E4A1B3E39DB2E19DB2DF
9DB2DF9CB1DE9AAFDC99AEDB9AAFDC97ACDB98ACDE96AADD95AADF92A9DD92A9DF90A9DF
8DA8DD8CA7DC8AA5DC87A2D987A2D7869FD5859ED4859ED4879ED4849BD1879CD38297CE
8396CE8497CF8495CD8293CB8192CA7F92CA7D90CA7B8EC87A8DC7778CC5778CC5788DC6
778CC37489BE7488BB7387BA7589BC7384B87484B57282B37181B27181B26E7FAD6E7FAD
6E7FAD6E7FAD6C7AAB6B79AA6B78AC6976AA6A75AB6976AB6976AB6875AA6575A96474A8
6273A76071A55F73A66074A75A6EA35A6EA35A6DA55B6EA6596AA05C6DA35C6CA059669A
5A689958669759659558659255628F57649054618D55628C515E88505F884E60884D5F87
4E5F8A4C5D884E5D88495A864C5A874D5B8A4B5988495788475586465485455384445281
45538242507F42507F4351803E4C793D4C773F4C783F4C763F4C76404D773C4B743A4972
3A49723A497237497136487037487336487032436E32436E31426D32436E31426E30416D
2E3F6B2F3D6A2C3A672E3B652E3C632B385B283255293454
605B57544F49433F363C3A2D41402E42412D504F3A58574257564152543E504F3B474836
4B4C3C4D503F5256475D61525D64545D64545F6354666A5B676B5D6B6F61787B707A7D74
7C7F78878C85939891757C74474E46424C44747B74767D76646B636168605D655A60675F
5F665E616861666B6762666551535246474945464A46474B46474C48494E49484E48474D
4B4A504E4D53504D54514F54514F545250555550565250535252544F4F514E4E50505050
5254535153524749485658557E837F757A765B5D5A5355525B5B596767656B6B696B6B69
71726D75767172756E777A71767C706D73656F7666828977828A737D826B838770B1B39D
C8C7B2C7C6B1E0DDCCFCF9EAEEE7DFC2BAB7BAAEAEBFB3B7BEB1B8B5AAB0998E969F949C
CABFC7EAE1E6F0E7ECF3EAEDF2E9ECCDC7C7ADA7A7B0ACA97B7A763F403B3B3E353B4135
393F31444D3C414A37404936434C3B47503F4D5546535B4C565E4F5B63565D63595D625B
5D625C6166625A5F5B494E4A4E534F5459555055514C514D464B474A4F4B4C514D4C514D
4D51505054534F5354515459565B6155596451546353586B555C6F595F775B617B6F7491
9398B6A1A7C7ADB2D2B3B8D8B3B8D8B3B7DAB5B7DDBABCE2BBBEE1BBBEE1BABEE3B9BFE3
B7BFE4B8C0E5B9C1E8B9C1E8B8C1E8B7C3E9B5C4EBB1C3E9B3C5E9B2C6E9B0C4E9AEC5E7
AEC5E7AEC5E7ABC2E4ACC3E5ACC3E5AEC2E5AEC0E4ADBFE3AFC1E5ADBFE3AFBFE3AEBEE2
AABCE2AABCE2ACBBE4AFBEE7A8B9E4A8B9E5A5B7E5A5B7E7A2B7E69FB5E49DB3E29EB4E3
9CB2E19BB2DE97AEDA98AFDB98AFDB98AEDD99AFE095ABDC95ABDD93AADE92A9DF8EA7DD
8CA7DC8AA5DA89A4DB88A3DA87A0D889A2DA879DD6889ED7879CD5869BD48499D28598D0
8295CD8194CC8194CC8195CA8195CA7F94C97F93C87C91C6798EC3798EC3798EC3778CC1
788DC2778DBF7488BA7488BA7488BA6F83B57385B57181B27183B36F81B16D7FAD6B7DAB
6C7EAC6C7EAC6B7BAC6C7AAB6B78AC6B78AD6976AB6A77AC6976AD6676AA6575A96373A7
6172A65E6FA35F73A65E72A75C70A55B6EA65A6DA5586BA3586CA15A6EA15C6EA059699C
57659656649555639257659256649156649155639052618C51608B505F8A4E5F8A4B5E88
4E5F8A4D5E894B5C874D5E894A5B874A5B87495A8646578544558344558343548242537F
42537F43548045538041507B3C4B763C4B74404D773F4C763E4B753F4C763C49753B4874
39467239477437457238467336477335467232457032457032457030436E2F416F304270
2F406C2C3D692A3B672C3B642E3C632C3A5D1F2C4C232E4C
45423B39362D343226312F20393824413F2A42402B4C4A354D4A37464533413E2F434134
4545394C4E41525647575E4E5D61505F63526367566A6E5D696E5A787C6B818576727668
787E729DA397B5BDB2A4AEA37E887D5F6B6169736B6D776F6B726B697069656A66676C68
64686765696A686C6D565A5D44484B41454845484D43464B484B504A4B504B4A524C4B53
4F4C554B48514F4C554F4C534E4B524E4C51504E535351545252544E4E4E4D4D4D4F4F4D
5153504E504D4449456166627278745E655E585D575E635D62645F6769646A6F6970756F
787B74787B74797C757F827B6C72686C72688C8F8693968B888B808B8E83AAACA1D7D9CE
E2E4D9E8E8E0FEFEF6E9E9E1BDBCB7BBB7B4C5BDBBC7BBBBB8ACAE988C8E8F8385A59999
B7ABABD4CAC9E6DCDBFBF1F0EFE5E4AAA2A07D78757B787352514C3F403843463D3E4438
3E4436424939454C3A454C3A444B394F5646585C4E5A5E505F625761645B63645F60605E
585A5967686A7171735B5A5F46474B414244494A4C4C4D4F444A48474D4B4A504E494F4D
4A504C4C525047504F4F575A5A6169555D684F5666545B6E5B637A626985747B98898FAF
A6ACCCA9B2D3ADB3D5AFB8D9AFB8D9B3BCDDB3BBDFB5BDE1B4BCE0B6BEE2B7BFE3B7BFE3
B7C1E5B7C1E5B8C0E7BAC1EBBBC4EDB8C4EEB8C5EFB4C3ECB5C7EFB3C6EEB1C4ECB1C4EC
B1C4ECB0C4E9B0C4E9AEC2E5AEC2E5AFC1E5B1C1E3B1C1E3B0C0E2AFBFE1B0C0E2AEBEE0
AABCE0A9BBDFA7B9DDA8BAE0A7B9E1A5B8E2A3B5E3A2B7E6A2B8E99FB7E79DB5E59EB6E6
9BB3E399B1DF98B0DE98B0DE95ADDB95ADDB95ABDC95ABDC94AADC93A8DD91A6DD8FA6DC
8EA4DD8FA5DF8DA1DE8CA0DD899DDA8A9ED98A9DD8899CD78698D68597D58699D48497D2
8194CF7E93CC7F94CD7E93CA7E93C87C93C77D92C77C93C57990C2788FC1778EC0768EBE
778DBE758BBC7388B77388B77388B77186B57688B87183B57385B77183B56D7FAF6E80B0
6B7FB16D7FB16D7DB06A7AAE6A7AAE6978AF6978AF6675AC6675AE6574AB6473AA6172A8
5E6FA55E6FA55D71A65C6FA75A6DA55A6DA75C6CA75A6BA3586C9F596D9F5B6D9F596B9D
5565965565965161925262935161925262935464955060914E5E8F4F5F904F608E4D5E8C
4E5C894F5D8A4C5D894B5C884A5B864C5D88475883465984435681455882465983435680
41547C40537B42547C404F763D4C733E4E723F4D723C4A713D49713D49713C48723A4572
3A45733844743844743945753846773444753244762F43753044762D41732C40722C4170
2B3D6B2B3E692C3D692C3B662E3C612A395A27355226344F
3030262D2D23312F2332302135322135321F3936233F3C2B3F3C2D3C382C3C382D3D3930
45423949493F4A4C3F4A4E3F5D5F516063526568576A6D5A707360797C697376657D806F
9EA293ADB1A3B0B6A8A8B0A3979F92757D72777E76787F78777D797075716A6C6B6A6B6D
70717573767B686B724F5259464950464950474B54494D56494E54494C53484850484850
4948504948504C4B534C4B514A494F4A494E4D4C515151534D4D4D4C4C4C4D4D4D4F4F4F
4C4E4B50524F4E534F6166626166625A5F595C615B686D67686D666A6F686B716772786E
777A717F82797C7F7673766D73766B85887D9EA1989EA198ADAEA6C2C3BDDADBD6E5E5E3
F4F4F2FBFBF9DADAD8B5B5B3AEAEAEB6B5B3C0BBB8CEC6C4A49C9A7F7775A29897A89E9C
9D948FB0A7A0B7AEA7C1BAB2B2ABA38480776E6A6163605745473C43453844483A3F4335
444B3B474E3E4D51424A4E3F494D3E565A4B5F615461635862635B63645E61625D5F5F5D
5151516E6E7088878C545358414247444549494A4E4B4C4E464C4C47504D4B514F4B514F
484E4C4952514953544A53584F5861515B67545D6E5F677C646B85747B979298B8A4AACC
AAB3D4A9B2D3ABB3D7AFB7DBAFBADAAFBADAB1BBDEB5BFE2B5BFE2B5BFE2B7C1E4B4C1E3
B6C3E6B5C2E5B6BFE6B8C1EAB8C4ECB7C3EDB7C4EEB5C2ECB4C3ECB4C3ECB3C5EDB1C3EB
B1C3EBB0C2EAAEC0E8AFC1E7ADBFE5AFBFE3AFBFE3B1C1E3AFBFE1ACBFE0ADC0E1ABBEDF
ABBDE1A7BBDEA5B9DEA6BADFA4B7DFA2B7E2A3B5E39FB4E39FB5E69DB4E69BB2E49BB1E3
9BB1E399AFE198AEDF96AEDE96AEDE94ACDC93A9DB96AADD94AADC92A7DC8EA3D88FA4DB
8EA3DA8DA2DB8DA0DB8A9CDA899CD7899CD7889AD8889AD88695D68595D38696D48194CF
8295D07E93CC7E93CC7C91C87C91C87D92C77C91C67B91C37A90C2748CBC768DBF768EBE
758BBC748ABB7286B87286B87387B97286B87485B97081B57182B66D81B46D7EB26B7FB2
6A7EB1697DB0697AAE6879AD6778AE6677AD6879AF6677AD6475AB6475A96172A65F70A4
5E6FA35B6FA25A6EA35A6EA35C70A55B6EA65B6CA4596AA258699D596A9E58699D57689C
5464975363965264965263975061955162965263975061954D5D914E5E924F5F924C5D8B
4D5B8A4E5C894D5B884A5B864C5B8648598446578245588245588245588245588043567E
3E547B3D53783E52773F51773B4D713A4C703C4C703A49703C4A713E4C733B4771384370
3B46743C46773842733743753642763441753040743242763041752E3F732D3E722C3E70
2C3E6E2C3E6C2D3E6A2D3C672B395E283758263451273550
2D2F243131273331253634273533243735263533263834293B372E3A332D3A352F3F3A34
46433C46433C43433B3E3E3449473B5654476B695C646255636152767465828071A19F90
A4A293A1A292ACAD9FAEB0A3A8AA9F9B9C94999A949698939193908C8E8D79797B76757A
8B8A9296969E898C954B4D594145504B4F5B484E5A4B525C484F57484C55464A53474A53
474A51494C534A4D52484B504A4B5045464A48494D5252544E4E4E4B4B4B4B4B4D4F4F51
4C4C4E4E4E50525355676968696B68696B686668656567626B6E6770736A74776C75796B
7A7E70797B6E71736577796B919483969988A9AB9EBCBEB3D6D6CCD7D7CFE7E6E2FAFAF8
ECECECDDDEE0BDBDBFB5B5B7B7B7B9B0B0B2BEBABBD3CFD0999596838280A8A4A1AAA7A2
8E8B827B796C6E6C5F6462536F6D5E616252585949515443454835484D394549384A4E3D
5155464E52434F51434E504355594B5B5E535F625963665F60635C5C5E595B5D5A5D5F5C
535554666769666769424345424649484C4D4C50514B4F50474D4D4B5151495251495153
4C54564C56584D565B515B64515B6555616F5E697B687387788097959CB6A6ADCAACB2D2
ADB6D5ADB6D5ADB6D7AFB8D9B1BADBB3BCDDB1BCDCB3BEDEB2BFDFB2BFDFB5C2E4B5C4E5
B6C5E6B4C2E5B4C1E4B6C2E8B5C3E8B4C2E7B6C4E9B6C4E9B6C4E9B4C2E7B6C2EAB7C3EB
B3C0EAB3C0EAB2BFE9B1BEE8B0BDE7AFBEE7B0BFE8B0BFE6ADBFE5A9BDE0ABBFE4A9BDE2
A9BCE4A5BBE4A3BAE4A0B7E1A0B7E39EB4E3A1B5E79FB5E69EB4E69FB5E79CB2E49DB1E6
9DB1E69BAFE49AAEE398ACE199ADE295A9DE96A7DD96A7DD94A8DD92A6DB90A5DA8CA2D4
8DA4D68DA4D88CA1D88A9FD6899ED7889DD68599D48599D48496D48294D28295D08093CD
8093CD7C8FC97D90CA7E91C97C8FC77C8FC77B8EC67A8EC3798DC2778DBF7489BE758ABF
778BC07589BE7586BE7586BE7386BE7184BC7184BC6D80BA6E81B9697EB5697CB46A7FB6
697EB56A7EB3687CB1667AAF6579AC6579AC6579AB6377A96176A55F74A36173A35F71A1
5E73A25D729F566B9A586E9D596E9D596D9F5C6DA35B6AA159689F58699F58699F55669C
55669E53649C52639B50619950639B4F63984F60964F60964E5F954E5E924D5D904E5C8B
4D5B8A4D5B884B5A854C5B864D5A8649588149588145577F47598144577F42557F3E547D
3E547D3E547B3D537A3B51783A5075384E73394D723A4C743B4A733C4B743B4874384571
3A45723843713842733B4578374176343E73363F76353E77343F77323F74303D72303D71
2F3F702F3D6C2C3A672E3B6728365D29375A273552293450
2C2F2631332831312733312535332634322536342835332739352C353128332F263A372E
46433A3E3E343C3A2E3F3D313E3C2F464435625F505956474E4B3A7C7968908A7AA29C8C
9D9787979181A09D8EA4A094A7A398AFABA2AFACA3AFACA5A7A49FA7A3A09A9695949091
A39EA2AAA8ADA3A0A77E7D8576747F7D7D876E707C65697263666D62656C5A5D6451545B
4E535753585C54595C4D52554347484145464347484C4D4F4B4B4B4F4F4F5050524E4D52
4A494E4747495D5D5F7272727779767678736D6E696C6D6772756C75796B7B7F70797D6C
797C6B7477667677658C8D7BA4A593ABAC9AC9CBBDDADCD1DADAD0ECECE4FCFBF7E7E5E6
C2C2C4CAC9CEC5C3C8A8A6ABACA9B0B2B0B5D6D4D9E5E3E6ABABAB939391C6C7C2C8C9C1
8F9184676A59444734414431454833494C37494C39474A37434631494C374D503D545746
5E6253595D4F53554A56574F595C535D605962655E60655F5E635D595E58525751565B55
4E534F54595551555441454443474645494A494D4E4C50534A4E514C51554D52584C5359
4F565E535C65555F6957616D5460705661736671857A859B929DB3A9B0CAACB3CFACB3D0
AEB7D4AEB7D6B2BBDAB1BADBB5BBDDB5BEDFB4BCE0B6C0E3B5BFE2B5C2E5B5C2E5B6C4E7
B7C5E8B5C3E6B3C1E4B5C3E6B6C4E7B2C2E4B3C3E5B5C5E6B4C3E4B4C3E4B5C2E5B5C2E5
B3C1E6B2C0E7B3C0EAB1BEE8B0BFEAAEBDE8ACBEE6ACBEE6ACBFE7A8BEE5A6BCE5A6BCE5
A4BBE5A3BAE6A2BAE8A1B9E79EB6E49CB4E29CB2E39DB3E59DB3E59DB3E59EB2E79DB1E6
9DAEE69DAEE69BACE499AAE299AAE295A6DE98A8E394A4DF92A5DD91A6DD8FA4D98CA3D7
8DA4D68DA4D689A0D4889FD389A0D6869DD3849AD4889CD78498D38094CF8196CF8095CE
8093CD7E91C97F92CA7E92C77C8FC77C8FC7788BC3798DC2788CC1788DC2768BC0758ABF
7489BE7588C07588C07386C07184BE7085BE6E82BD6D81BC6A7FB8697EB7687DB6677CB5
687DB6687DB4687DB4657AAF6378AD6278AA6377A96277A66075A25E73A06274A45C6E9E
5B709D5B709B596E9B5A6F9C596E9B5A6C9C596A9E59699D5A6A9E58689C56679D54659B
55669E55669E52629D4D5D985061994F60965061974F60944B5C904D5D914D5D8E4D5B8A
4E5C894D5C874A59844B5A854A598248578046557E465880465880445580445781425580
3E517C3F527D3F527C3D507A3A5079394F783A4D773A4B76394A753948733A4974394672
3A45723C44723A42713B43743A4072393F73393E75363B72333C73323E72323E702F3B6D
303E6D2B39662D3A672A376129375C2B385A2A355329354F
282D2631372D3133282D2D212E2F212E2F1F3132222E2F1F2D2B1C2E2C1D2C2A1B323323
3E3F2D34372431331E3A3C27393B254A4C36605F4A4A493443412A797460857E6B807967
8D8674908979968E81968E81979185A09A8EA19B8FA6A094A49E92A9A196AAA198A9A099
AAA19CAAA19CAAA09EA79F9DA49B9CA19B9D9E989C999498939196908F9489888E808185
787C7D848889878B8A727675535955515753555B59444847484A476B6B6B696768514F52
46464849494B5E5E5E767674787A7573766F73756A76786B797B6D7C7F6E808370767964
70755E787D66878A75A3A691BFC2AFC2C5B4DBDBCFEEEEE4F4F4ECFDFCF7EAE6E5D5D1D2
C8C3C7CEC9CFCBC4CC968F97817984AFA8B0D8D1D8E4DFE3C0BEBFA6A6A4B9BCB5A8ABA0
6A6E5F5A5E4D4247334247313E432D4346314649364C4D3D4D4E3C4F504057584A5C5C50
6062575D5E565B5C565F605B5E605D5B605C5E635F5F645E5E635D585F585259514D544C
434A42474E46464B453D423E42444145474647484C4C4D5253565F545662515360555668
56596C5E63776B7187666E83616C806572857C889E9DA9C1A0ACC4A8B2CBADB4CEAFB6D2
B1B8D4B2B9D5B7BDDDB7BDDFB8BCDFB8BEE2B6BBE1B7BCE4B8BDE7B7BEEAB6BDE9B8C1EC
B8C4ECB8C6EDB5C3E8B6C4E7B4C4E5B4C7E5B4C7E5B3C7E2B2C6E1B2C6DFB4C5E1B3C4E2
B2C2E3B2C2E4AEC0E4B0C2E8ADC0E8ACBFE7ACBFE9A9BFE8A7BCE7A6BDE7A6BDE9A6BDE9
A5BDEB9FB7E59DB8E79CB7E69CB7E49BB6E39CB4E29BB3E39BB3E39BB3E39DB3E59BB0E5
9BAEE699AAE298A8E398A8E398A8E397A7E298A8E496A6E490A3DE8FA4DD8FA4DD8DA3DC
879ED488A1D786A0D386A0D3859ED4839CD28197D18298D28197D17F95CE7E94CD8096CF
8095CC7D92C77E92C77F93C67D91C67C90C57A8FC4778CC1768CBE758CBE748BBF738ABE
7087BB7287BC7388BF7188BE6F85BE6D83BC6B81BB697FB9697FB9687EB8667CB5667CB5
667CB5647AB3657CB2657AAF6378AD6177A96074A66075A46075A46173A35F71A15D6F9F
5D729F5C719E5A6F9C5C6E9C5D6F9F5A6C9C596B9D586A9C57699B57699B56689A536597
53649855669A54639A505F965262965262964F5F935161944B5B8E4A5A8B4D5D8E4D5E8C
4C5D884B5D85495B834A5C8444577F42557D44577F465880445580435480435482435482
4152803E4F7D4050813F4F803C4C7D3C4C7D3E4C7D3C4A793D4B7A3B48753A47743E4977
3B43713D44723C43713A416F3B3F6E3C40703A3E6E343A6A353D6E323D6B313C6A2E3B68
2C3B662B3A6329366029375E2B385B2A37572C355229334C
2E332D393E382F302A26281D2A2A1E28291B2B2C1C2B2C1C2B2C1A282B18242714272A15
292C17272C152B30192F351B2C3017474B30686A526969515C5C4475735E736E5B716A58
7E7767706959766E638C84798A8478878175878175928C7E968E819B9484948B7C8A8074
887E72897F738F857B8F857C928781958A869B9190A69C9DB2A9ACB3ADB1948F9578767B
79797B9192949498977F83826468675F65636268665A5E5D5E605F7A7C7B6A6A6A505050
4B4B4B55555365656375767170716B6D6F6478786C78796B7E7F6F7D7E6E747563777964
838671989B86A8AB96C2C5B2D1D4C3D5D7CAEBEBE1FBFAF5FAF9F5D9D8D6C3BFC0D3CDD1
D0C9D0C7BDC5CCC2CBB1A5AF837781AEA4ACD0C6CECDC7CBCCCACBB1B2AD91928C5B5E53
41473949503E474F3A3E46313E462F444935494C3952534356574756574965655967675D
5F60585C5D575E5E5C5D5F5C5A5E5D585C5B5A5E5D575D59565C58565D564D544C474E46
41484041484041484140453F42474342464548494D4E4E565658645557665E5D6F5C5A70
63637B797B949195B07D849E7178927F89A296A0BBAAB4CFAAB4CFABB5D0ADB7D2B0B7D3
B2B9D5B3BAD6B7BCDAB4B9D9B7BBDEB8BCE1B9BCE5B9BCE7B9BCE9BABEEDB9BDECB8BFED
B8C1ECB7C3EDB7C3EBB6C4E9B5C5E6B1C4E2B2C5E3AFC4DFB1C7DFB0C6DEAFC3DEAFC3DE
AFC2E0AEC1E1ADC1E4ADC1E6AAC0E7AAC0E9A9BFE8A9BEE9A8BDEAA6BBEAA6BAECA5BBEC
A3B9EBA0B7E99FB6E89EB5E79EB6E69CB4E49CB4E49AB2E299B1E199B0E299AFE198ADE2
97ABE097AAE299AAE298A7E297A7E296A6E196A6E494A4E28FA2DD8EA2DD8DA1DC8CA2DC
89A2DA88A1D9849DD3849DD3829DD2819AD28096D08197D17F95CE7E94CD7D93CC7E94CD
7E95CB7D92C77F93C67E92C57D91C47B8FC2788EC0788EC0768CBD778DBE748ABC7489BE
7288BA7186BB7287BE7287BE6D83BC6C82BB6C80BB6D81BC6A7EB9697DB8677BB6687DB6
667BB4667BB46479B06378AF6579AE6175AA6276A96273A76173A56072A45E6FA35B6D9F
5B709F5D6F9F5D6F9F5C6E9E596B9B596B9B5A6C9C576999556795566896556795546694
5567975567975161945161945464955363945363944F5F904F5D8E4D5B8C4D5E8C4E5F8D
4C5F89495C86485B85465C85445A8341577E455882455882435480415280445283445283
465485414F80445084424E823F4B7F3E4A7C3F497E3F497C3E48793C47753C47753C4472
3C43713E45713F43703C406D3B3E6B3C3F6A3B3F6C383F6B343B67343D68323E682C3963
2B3A632C3B622B39602A385D2A37592B36542B35502B324C
2C2D2F3D3D3D2B2B2927262128292124261B26281B25271A24261825291A232716222A15
242C15262E17262E173038203D422B494F3571755E92947E7A7C676E6D5B727061706E61
69675A5F5D5068655C79766D726E63726E636E6A5F7A766B7D7A6B7572617771616F6A57
6E6956706B58756E5C766F5F796F657E746B897E7A958A88B0A6A7AFA4A88A81863F3A40
4B494E6C6B707D7E837F82877F8287787C7F6C717473787B7A7E7F6266674E504F525451
5C5C5A60615B63625D716E67726F667773687F7B6F7E7A6E807A6E827C708B88799A9889
A7A89AB6B8AACACCBED0D2C5D9DAD2E6E7E1FBFCF7F3F3F1D4D2D3BFBABEC6BFC6D8CED6
C9BFC8CABFC7F1E4EBE0D3DAA69A9EBDB1B5D9CDD1CEC5C6B8B4B17F7E7956575150534A
454B3F464E3F454E3D3E4734444D384C543F5358445C5F4C5F625160625464665963655A
5D5E565D5E585D5F5C5F615E5C625E5157554E54525157554F58555059544F585348514C
424C44404A423E4840424942434945474D4B4F53564E51584D50595A5C697E7D8F7F7D93
8080989292AC9596B2888CA98E92AFA0A5C2ABB2CFB0B7D4AFB6D3ACB5D2AFB8D5AFB8D5
B2BBD8B4BBD8B6BBDBB7BCDCB7BBDEB8BCE1B9BBE2BABCE5BABBE7B9BCE9BABCECB9BDEC
B8BFEBB7C0EBB7C0EBB4C0E8B3C3E7B2C2E4B2C2E4AEC1E1ADC2DFAEC3E0ACC1DEADC2E1
ABC0DFAABEDFABBFE2AABEE3ABBEE6A9BCE6A8BAE8A8BAEAA8BAECA8B9EDABBCF2A5B6EE
A4B5EDA3B4ECA1B4ECA0B3EB9EB3E89BB0E59CB2E49AB0E297AEE098AFE398ADE296ABE0
96AADF96AADF95A6DC95A6DE97A6DF96A5E092A2DD91A1DD8DA0DB8DA1DC8CA0DB8AA0DA
87A0D987A0D9859ED6839CD48099D1819AD38197D18096D07E94CE7C92CC7D91CC7D92CB
7C91C87D91C67C90C37F90C47D8FC17C8EC07A8BBF7A8BBF788CBE768ABC7589BC768ABD
7488BD7286BB7184BC7285BF7184BE6D80BA6B7EB96B7EB96B7BB96B7BB76979B56B7BB6
6A7AB56778B06576AE697AB26677AF6071A95F70A86273AB6071A76071A75D6EA45D6EA4
5C6DA16071A55E6EA15A6A9D596B9B5A6C9C5A6C9A54669455689353669053669053668E
53669052658F52659052638F51628E515F8C52608F4E5C8B4C5D8B4A5B894A5A8B4D5F8D
4A5F8C475C87465B86445B85435A84425982425782435883435681435482435182425081
445080455181404A7D404A7D3F497C3F497A3F467A41497A3F47763C44723E46743C436F
3D44703B426C3E436D3C41693E436B3C41693A3F69353C66313862323B642F3B632C3A61
2C3B622D3C632B39602B395E2C395B2E39592D36532C334F
27262B2B2B2D25252525242024251F23241E25261E24251D24271E25281D22281A23291B
242D1C29321F3037254148365F67526C745D7479658285727B7E6D787A6C7476686E7063
68685C6A6A5E6A6A606D6D637070667070646E6E627171657475656A69576D6C5A6C6B57
6C6B576A69556E6B58726F5E7670627872668D867EACA39EB0A6A4988E8D8D8487514B4F
4D484C62606578777C7F7E848B8C918A8B908286898A8E91898D8E65696A4C4E4D585A57
62635E67666169665F6E6A61756E64797268857E748C84798F867D9C9489B1A89FBFB8AE
C7C3BACCC9C2D4D4CCD1D0CBE9E8E4F6F6F4E9E7E8D1CFD0BBB9BCC6C1C7CAC3CACBC1C9
D0C6CEDACFD5F9EEF2F6EAECC7BDBCCBC1C0C7BDBC9893907B78735B5B534C4D4550534A
484E423C44373F473839423148513E5A63505F665461685665695863675863675963665B
61645B5E615A5A5C575257515259524F55514C52504F55534D56534C55524B5451434C49
424B48434C47404944434C474A534E4F55534F54574B5054585D636668748D8F9EBEBFD1
B9BACF9E9EB68A8AA69596B4A7AAC9AAAFCFADB2D2AEB4D6B2B8DAAEB7D8B0B9DAB1BADB
B1BAD9B3BCDBB5BBDBB8BEE0B6BCDEBAC0E2BBBFE4BBBFE5BABDE6B9BCE5BABDEAB8BCE9
B7BEEAB8BFEBB6BFEAB6C2ECB4C2E9B4C4E8B3C3E7B0C2E6AEC2E3ADC1E2ACC3E3A9C0E0
A7BEDEA9C0E2A7BDE2A6BCE1A7BDE4AABDE7A8BAE8A8BAEAA6B8EAA6B7EBA7B6EFA6B5F0
A5B4EFA3B2EDA2B2EDA0B0EB9DB0EA9CAFE79AADE59CB0E598ADE296ADE197ACE197ADDF
95A9DC95A9DC93A7DA92A6DB93A4DA94A5DD92A3DB8EA1DB8DA0DB8A9ED98B9FDC8A9EDB
889EDA889EDA869CD8849AD68298D48096D07F95CF8298D28197D17B91CB7E93CC7D92CB
7D90C87C90C57E8FC57C8DC17C8EC07C8EC07888BC7888BC7888BB7787BB7787BB7786BD
7584BB7483BC7382BD7281BC707FBA707FBA6F7EB96B79B66C7AB76A78B56978B36A79B4
6B7AB36877B06675AE6675AC6675AE6170A96372AB606FA86172AA5F70A85F70A85B6CA4
5C6DA35F6EA55D6A9F5D6A9F5B6B9E576999586899586A9854659152638E54668E53658B
51638B53668E53648F53648F50618C52618C54628F4F608E4C5D8B4C5C8D4A5A8B4B5D8D
485D8C455B8A445A89455B8A43598841588440558241568342548240528043518042507F
434F7F43507D404A7B404879424A794149784046763F45753F47753C45703C436F3D4470
3C436D3A416B3E456F3941683941683C446B394168353D64343D64323B622F3B632D3961
2C3A5F2A385D2A365C2A375A2D375A2F38572D34502B324C
27282A24262520201E21211F24252021221D20201E21211F252724252722252722292E28
2E352D2E352D363E334B53466E76677980707A80727D81727C80727B7F70787C6D717566
6E70637072657072656F71647072647173657173657174637376656F705E6D6E5C6C6D5B
686B58696C596C6F5E6D705F6C6D5F8C8D7FBEBEB2EAE7DEBDB9B0A29D97B0A8A5837B79
5E5956726C6C7A76777571727C7A7D9090929092918E908F8385846B6B695B5A5864635F
64635F6A6762726F68747067746D658279729E958EB1A79EB2A7A1B5ABA2C9BEB8D4CBC4
D5CDCAD6CECBDCD7D4E1DCD9F5F1F0E0DEDFD0CCCDBFBBBCC7C3C4CAC6C7C7C1C3C7C1C3
CCC6C6D8D2D2DFDAD7E2DDD9D9D6CFC3C3BB8A8A8265665E56594E5053484D5045454B3F
3F473A3B4336353D303F4738515C4C606B5A646D5C636C59636A58636A5A63695B616759
63695D646A5E484E443E443A4247404B50494D524C4D524E4B514D494F4B3F45433F4543
434947464C4A444A48474D4B5359574F55554D535350555860656984898FA0A3ACBABCC9
C0C1D3A1A3B8999BB4ABACCAACAFCEADB2D2AFB3D8B2B8DCB5BAE0B2BADFB1B9DEB3BDE1
B2BCDFB3BDE0B4BEE1B3BEDEB6BFE0B5BEDFB8BEE0BAC0E4BBC1E5BDC3E7BABFE7BABFE7
B6BEE5B7C0E9B5BEE9B6C2ECB4C1EBB1C0E9B0C2EAB0C2EAAEC2E7AEC5E7AAC2E4A9C3E4
A7C1E2A8C2E3A8C2E5A7C1E4A7BFE5A5BBE4A6B9E4A6B8E6A5B7E7A5B7E9A6B5ECA4B3EC
A2B1ECA2B1ECA2B2EEA1B1ED9DB0EA9CAFE99BAEE89AADE597ACE197ACE197ADDF97ADDE
93A9DA93A9DA94AADB90A6D88EA4D68FA4D98EA3DA8DA2DB8CA0DB8B9FDC889CDB899CDE
889BDF879ADE8396D88396D88397D68195D28094D18094D18094CF7C91CA7C8FC77C8FC7
7D8EC47F90C67E8DC47C8CC07C8CC07B8BBF7D8ABF7986BB7A87BC7885BA7885BC7985BF
7783BD7884BE7781BE757FBC727EBA6F7BB7707CB8707CB66C78B26C78B26B78AF6C79B0
6774AB6875AC6976AD6976AB6473AA6372A96071A76071A76172A85F70A6606FA85D6CA5
5D6CA35D6CA35E6BA25B689D5E6B9F5A6A9B5A6899596A9857659255648F57668F56658E
54638C53658D54638C50628A53648F50618C4F608B50618D4D5E8C4C5E8E4A5C8E48598D
475B8E465A8D465A8F44588B465A8D42568843558542548243558344578244527F414F7C
3F4C78404D79414D77404C76404C76404C764048763D46713E47723C45703B446F3B446F
3B446F3740693C456E3A436C37406939426B38416A333C65313D63303C622E3A602E3A60
2B385B2C395C2D375B2C34582E37562F36532B324C292F47
2024232123201D1D1B1D1D1B21211F1E1E1C1D1D1B1D1D1B20221F222421252724272926
262B25444943666B65696E676F756972786C7A7E707C80727C80717D8170828574868978
8689788588778384748386758588778487768386758184738083727D806F7C7D6D717463
6B6F606D7162666A5C666A5C84887ACBCFC1D9DBD0E3E5DACBCBBFBFBDB1B8B4AB867F77
746D677D7670766E6B6E69667B7575A4A09FA0A09E8383815E5E5C5E5F5A64635F676662
656460706D6874716A736F666D69608B847CBBB2ABC9C0B9BDB2ACC1B8B1D2C9C2DED5CE
D4CDC7CCC4C1E0D8D6F6F0F0EAE6E5B6B2B19F9B9AB4B0AFC0BBB8CFCAC7CFCBC8D6D2CF
CBC7C4BEBBB6BAB7B2AFAFA7A1A29A7A7B7346493E4D50455A605241473943493B43493B
373D2F363E2F343A2C495142636B5C636B5C61695A5F68575E675660685961675B596154
5961545B6356464E413E463B444A40484D464A4C474A4C47474C48454A46424443464749
4D4E504F50545051554E4F5454555A55565B4F525752575D70777D989FA7A3A7B2A0A3B2
A5A8B9A1A6BAABAFC8ADB1CEADB2D2AEB4D8AFB4DAAFB7DEB1B8E2B3BAE4B3BCE5B3BCE5
B2BEE4B2BEE4B3C0E3B3BDE1B4BEE2B6C0E3B6BEE2B9C1E5B8C0E4B9C1E5B8C0E5B9C1E6
B7C0E7B5BEE5B6BFE8B4C0EAB3C0EAB0BFE8B1C0EBAFC0EBADC0E8ADC3EAA8C0E6A5BFE4
A7C1E4A5BFE2A5BFE4A6BEE4A5BCE5A3B8E3A5BAE5A5B7E5A5B7E7A3B5E7A5B6EAA2B3E9
A1B2EA9DAEE6A0B0EB9BAEE89CAFE99BB0E799AEE798ADE497ACE396ABE093A8DD93A9DB
91A7D991A7D991A8DA8EA5D78CA3D78DA4DA8CA1DA8BA1DB8AA0DC889DDC879ADC889BDF
8699DD8699DD8394D98395D78193D37F91CF7D8FCD7F91CF7D90CB7C8FC97B8EC87C8DC5
7B8CC4798AC27A8BC3798AC27B8AC17988BF7887BE7887BE7986BD7683BA7882BD7882BD
757FBA7781BC737BB9737BB9717BB86F79B6707CB86F7BB56C78B26B78AF6B78AF6774AB
6672AC6571AB6774AB6673AA6170A76170A75E6DA45F70A6606FA65F6EA55E6DA45D6CA3
5C69A05D6A9F5B689D5B689D5B689C5A6A9D58689956679554659155669155648F52638E
52638E51628D50618C4E5F8A4F628D4D608B4D5E8A4D5E8C4A5C8C4A5C8E485A8C47588C
47588C48598D46578D42538942538743558743538445568444558143548044527F404F7A
3C4B743E4C733D4B723D4B703C4A6F3B49703D49713B476F3C456E3B446D3A436C3A466E
37436D36426C36426C36426C323E6835416B34406A313D67313D652D39612D395F2D395F
2A375A303A5D2C36592B36562C35542C36512C344B283045
21232021232023232121221D22231E1F201B1F211C1F211C20211C1E1F1A252620292C25
1D20194F524B898C857F827971746974786A7C7E707D806D7D806B7E826B898B7590927C
92917C94937E94947C979681989783979886989989949786939587949889909285787A6D
73776974776C71746B898C83C6C9C2E5E8E1E2E3DBE0E1D9EAECE1D8D8CCA5A3977A7369
827B71746B62675E576E676185807C9895908C8B877677725657525C5F5862655E6A6D66
6A6D6672736D77767172726A75756B95958BC4C1B8C2BFB6BFBBB0D1CDC2D1CDC2D2D0C4
CBC8BFD7D4CDEBE8E3F1EEE9C3C0BB93928DA09D96C3C0B9D0CDC4CCC9C0D0CCC3D7D4CD
CECBC4ADACA78685806A69646A6B6545484135382F383B303D41333C4031444839404433
3C402F3B42303C40315A60526A7062666C5E6066585D63575D65585E665B5F665E515850
51594E4E584D485247444E454950484A514A454A444648454648474949494C4A4D4E4C4F
5A555B5A555C5E58645A54625A56645B576657546553546662657683889B8A8FA29499AD
AAAFC5ABB1C9ACB1CEABB2CFAFB5D7AEB6DBB0B7E1AFB8E3B1BAE5B1BAE5B1B9E7B3BBE9
B5BEE9B3BCE7B6BFEAB3BCE5B3BCE5B3BCE3B5BEE5B8C2E6B7C1E5B7C1E5B6C0E4B4C0E6
B6C2E8B2BEE4B2BEE6B1BDE5B2BEE6B2BFE9B3C0ECB0BDE9AFBEE9ADBEE9AEBFEBABBEE9
A7BAE4A9BCE6A8BBE6A8BBE6A6BBE8A5BAE9A3B8E7A3B8E7A2B7E6A0B5E4A2B6E89FB3E6
9FB3E69CB2E49AAFE499AEE399AEE398AFE397AEE496ADE397AEE495ABE492A8E190A6DF
90A6DF90A6DF90A6DF8FA5DE8AA3DC88A1DA889EDA899FDB879CDB879CDD899CDE8699DB
8597D98597D78594D58494D28393D18494D08090CC7D8DC97F8DCA7D8BC87F8DCA7D8DC9
7C8CC87C8CC87989C57689C47989C47689C37689C17889C17786BF7180BB7581BD7581BD
747EBB757FBC747CBB737BBA727AB96D77B46E7AB66E7AB66C78B46B77B36975B16773AF
6571AD6773AF6270AD5F6DAA6170AB5F6EA95D6CA55F6EA55F6CA3606DA2606DA25D6A9E
5D699D5B689C5B689C5B689C58689B556799586A9A54669451648F5265904F648F4E638E
4E638E4B628C4C618E4B608D4A618D4A5F8E4C5E8E4B5D8F4D5D9049598C49598C49598C
4656894A578B48558A465286445082445082414D7D44517E44527F44537E43527D3D4C75
3D4C753E4D743D4D6F3D4D6F3A4D6E384A6E39496D3A486D3B476D3A466C3A466C37456A
37456C323F6934406A35406D313E6A323F6B323D6A313C69303D692D3A642D3B622B395E
2C3A5F2C395C2936582A38552937522C38502C374B283345
2929292B2B2927272528272328272327262226272226272226272122231B3A3B334D4F44
4C4E43696B609292888080767A7A6E7B7C6E7D7E6E7F806E80826C86866E8F8F7795937A
96947B97957C97957C99977E9A98839D9C8A9D9B8C9697899496899A9C8F8B8D826F7166
6F706874776E8F928BC5C8C1DFE1DCE5E7E2E2E4DFE1E4DDECEFE6CED1C682827679776A
8886796260534F4B405D5B4F62625865655D62635D62645F6C6F686F746D6B726A767D75
7B7E777B7E777B7C765E5D5865665EABABA3C1C1B9BEBBB2C2BFB6CBC9BDC5C2B9CFCDC1
DAD7CEEAE7DEE2DDD7E2DDD7ABA8A1807D74B1AEA5BFBDB1C5C3B6CDCBBECDC9BEC5C2B9
CECEC6BDBCB754534F43443F6F716E4A4C47383B343D40373C3F34414537494D3E464A39
3F43323D44323F43346B6F606C706165695B6367596063585C62585F645D5D625C454C45
4A514A5259525158514D544D4D544D5057504648434646444D4C4A4D4B4C514B4D5E585C
61575F5F555E5F5464605768615A6C5F5A6E625E755F5D755C5E757E829B9296AFA5ABC3
ACB2CAAAB1CBADB4D0AAB3D2ADB5D9AEB8DCB0B9E2B0B9E4B1BAE5AFBBE5B2BAE8B2BAE8
B4BDE8B4BDE8B7BEEAB5BCE8B7BEE8B5BEE7B5BEE5B5BEE5B3C0E3B4C1E4B4C0E6B2C0E5
B2C0E5B1BFE4B1BFE6B0BEE5B0BEE5B1BFE6B0BDE9B0BDE9AEBBE7AEBCE9ADBBEAACBAE9
ACBAE7ABB9E6ABB9E8ACBAE9A8BAEAA4B9E8A1B6E5A3B8E7A4B9E8A1B6E5A1B7E69EB4E3
9DB3E49CB4E49AB2E298AFE199B0E298AFE395AEE495AEE492ABE393ACE493A9E392A8E2
92A8E293A9E392A7E08DA3DC8BA1DB8AA0DA879DD9879DD9849CD8869CD8859AD98599D6
8597D58396D18292D08292CE8393CF8492CF8391CE808ECB818CCA828DCB7D8BCA7D8BCA
7A8AC87A8AC67A8AC8778AC57588C37487C27386C07285BF7686C17483BE7580BE7782C0
7581BD7480BC7680BE747EBC727CB96E7AB66D79B56A79B46978B36877B26873B16573B0
646FAD6472B16371B0606EAD606EAB606FAA606CA6616EA5606DA25F6CA0636FA3606C9E
5D699B5D69995C689A5B699A566697566697556797556795526492526590506592506592
4D64904B628E4D63924D63924D63924C62914E60924C5E904D5D904858894B588C4A5889
4B598A4B57894A54874852854B5384475280464E7D424D7A434E7B44517B43507A3D4C73
3A4C723B4D73394B6F3A4D6E384C6F394B6F384A6E3C4C703A486D38466B37456A38466D
37446E35426E36416E35406D33406C33406C323D6A313C69303D692C39632D3B622B395E
29375C29375A283758283756273751283851273349263346
2725282725282924282824252822222924212824212827232C2B262E2E265A5A50737367
8081738283758583768280737F7D70807E6F82807183827083826E8B8A759795809A957F
99947E9B977E9B977E9D9882A09B88A09D8C9F9C8D97958898988C9B9B8F81817767675F
71726C999A94CDCEC8E6E7E1E5E6E1E3E5E2E0E2DFEBF0EAD8DFD799A1967E84787D8375
797F716971625C6254545C4D545C4F525A4F525951565D55686F686A716A7C837C989F98
93959090928D81827D55565065645F9B9A95D2CFCAD4CFCBD7D2CCAEAAA1ABA49ECCC5BD
E9E2DCDED7D1C6BFB9D2CBC5BDB6AE9D968CCEC7BDB4B0A4AEAA9EC1BDB1C4C2B6D6D3CA
CFCFC78C8D873333313537345456553F4440373B3A393E3A3C413B3F453B474D4152584A
5059484F58474D5444686C5D696B5D6466586365586264595D60575A5D565B5D58484D49
494E4A515652555A565156505156505A5C574A4B464948445753505751516056576D6266
6C6167675C645E53617169787D76886D687E64627A63637D737792999FB9AAAFCCABB2CE
ACB3CFA9B3CEAEB7D4ABB6D4AEB9D9AFBCDEADBADDB0BCE2B0BCE2AFBDE2B0BCE4B0BCE4
B5BEE5B4BEE2B6BEE3B7BFE4B7BFE4B7BFE4B5BFE3B7C1E5B2BEE4B2BEE4B2C0E7B1C0E7
AFBFE3AFBFE3AFBFE3AFBFE3AFBEE5AFBEE5B0BFEAAEBBE7ADBAE7AEBBE8AEBAEAADB9E9
ACB8E8AAB6E6AAB7E4ADBAE7A5B6E2A3B6E1A3B5E3A1B3E1A0B5E2A0B5E29FB6E29DB4E0
99B1DF99B4E199B4E197B2E196B0E196B0E395ACE294ABE193A9E294AAE394A8E392A6E1
93A7E293A8E190A3DB8FA2DA8A9FD8879DD689A0D6879ED489A0D6879ED4849AD38299CF
8398CF8297CE8093CD8093CD7F92CC8494CF8290CD7F8DCA7F8DCC7D8BCA7D8BC87C8AC7
7B8BC77787C27787C37888C37686C17787C27888C47585C17484C07484C0717FBC717FBC
7180BB7180BB6F7FBA6F7FBA6C7DB56D7EB66A7BB36879B16979B46878B36573B06575B1
6573B26271B26271B26070AE6070AC5D6DA8606FA8606FA65E6EA15A6A9B5E6C9D5D6999
5E6B985E69975C67955C6795586494586494596595556392556392516290516192526293
4F61914C61904D61934D61934D62914B608F4C5E8E4D5D8E49598A4859874A58894B5787
4955854A54854B53844C54834C53814B547F484F7B47507B45517B445078434F773D4B72
3D4C733B4D75384A723A4C743A4C7437497137496F394B7137497133456D33446F364570
34426F33416E34416E323F6C313E6B313E6A313E6A303D67303C642C38602E3A602C395C
28365928365926365726375526375328385224324C213047
1F1D222523262924282822242B22232B26232C27232D2A232F2C2546433A7E7C70878578
878576817F70828071828071807E6F7F7D6E817F70807E6F8685738F8E7C989582989582
9A95819D98849E97849F9886A39D8DA29C8EA09C909C988C9F9D909191856C6A5E79766D
95958DD3D2CDEBEAE5E7E6E1E3E2DEE4E4E2E5E7E4EDF2EEB5BCB5768077808A817E887D
798579808C7E6F7B6F6571655F6B5F616D63636F655E685F6F79718A9189B8BFB7D4D9D2
BFC2BBADAEA885847F66665E8380799E9B94C9C4BECAC5BFC4BFB9716C66837C76B4ADA7
CCC5BFCEC7BFCEC7BFD3CCC4C8C1B7DAD4C8D7D1C58682769A968AA7A59999978BB1B1A7
A8A9A36E6F6A3C3E3B393B3A3739383034333A3E3D3D4140414642424740454B4161675B
6D756869716263695B6A7161666A5B6266576266586063585E61585457505153504F5150
4C504F5051535456555454545353515656545756525753505C5754685F6071676871666A
6F646A6E646C726775898292888397706E846E6E887A7B97969BB8A5ACC9A8AECEA8B1D0
ABB4D3ACB7D5ACB7D7ACB9D9AEBBDDADBBDEAFBCDFADBBE0AFBDE0B0BEE1ADBBDEB1BFE2
B3C0E2B4BFDFB6C0E3B6BFE0B8C0E4B7BFE3B6C0E3B3C0E3B3C0E3B0BEE3B0BFE6AFBEE5
B0BFE6B1C0E7AFBEE5AEBDE4B1C0E9AEBDE6B0BFEAACBAE7ACB9E6ACB9E6ADBAE7AAB7E4
ABB8E5AAB7E4AAB7E4A9B6E3A9B8E3A5B6E2A3B4E2A3B4E2A2B4E29EB3E09EB3E09CB3DF
9BB3DF97B2DD97B2DF94AFDE94AEDF93ADE094ABE194ABE192A8E190A6DF90A4DF91A5E0
92A6E191A6DF8FA2DA8FA2DA8CA1D8899ED589A0D4879ED2879ED2839ACE8299CD8198CA
8298CA8298CA8295CD7E91C97E91C97F92CC7E8EC97E8ECA7D8DC97B8BC77D8BC87C8BC6
7A8AC57887C27786C17786C17786C17786C17583C07482BF7383BF7484C07080BC7080BC
6D80BA6C7FB96A7FB86A7FB6677CB1687DB2657AAF6579AE6679B16676B16575B16474B0
6373B16171AF6171AF5F6FAD606EAB5F6EA95E6DA65E6DA45C6C9F5B6B9C5E6C9D5B6998
5B68955B66935C67945A6592596492596693586592576393505E8D52608F566495526293
4E60904E60904D5F8F4C5E8E4C5E8E4B5D8D4B5B8C4C5D8B4859874859874957864B5787
4955854A55834A528149517F49527D4A537E475079464F78424E76425077434F773F4D74
3E4D763C4E76394A7538497438497436477236477237487335467132436F35437232406F
34426F35426F34416D313E6A303D69303D672F3D642E3C632D395F2C395C2B385B29375A
27355828365926365824345527385628375424324D212F49
2220232A282B2E2A2B2F2B2A37322E37322C343027332F24484439736F638F8C7D888677
807F6D7E7F6D7F806E7E7F6D7D806D8184737F82717E80728485758D8E7E8E8C7D939182
9895869A97889993879B9589A09A8E9E988C9F9B8F9E9A8EA4A295747265575347A8A69A
C4C1B8DDDAD1E2DFDADDDCD7DAD9D5E3E3E1F2F4F1E1E5E4898F8B6268647D868187908B
959E99848E86626D6769746E69746E69746E737C776D776F8F968EB4BAB0D3D6CBE5E7DC
DCDCD0ACAA9D7672667A766A949084B1ADA1C6BFB5B6AFA58C887D5B574E7B776EA7A39A
CECBC2D8D6CAD7D7CBD1CFC2CCCABBDAD7C8AFAC9D6B695C8A887C807D7456534C666560
64656040403E4343433F4140363837393B3A4143424749464547424D524B565C52666C62
6B7368656D60636B5E6068595B63545C64575F655B5D625B5F645E5156524E5251505455
53545856575B57565B5654595351545C5859676163666062665D606D6465797071797073
787178817C8387818F8B88998684997878907E7F9B9499B7A3A8C8A9AFD3A7ACD2A9B1D8
AAB3DAABB7DFAAB6DEABB9E0ADBBE2ADBCE3AFBDE4AFBDE4B1BFE4B1BFE2ADBCDDAFBEDD
B1C0DFB2C0DDB1BEDEB4BFDDB4BFDFB5C0E0B4C1E1B2BFDFB2BFE2B2C0E5B0BFE6AEBDE4
AEBDE4ADBCE5AAB9E2ADBCE5ABBAE5AEBBE8ADBAE7AAB8E7ACBAE9ABB9E6A9B7E4A9B8E3
A8B7E2A7B6E1A7B6E1A6B5E0A6B4E1A6B4E1A7B5E4A2B3E1A4B5E39FB1E19BB0DF9BB1E0
99B1DF97AFDD95B0DF93AEDD94ACDC93AADC93AAE092A8E191A5E092A6E190A4E18FA3E0
8EA2DD8B9FDA8DA2DB8CA1DA8A9FD88BA0D7889DD28A9FD4869DCF849BCD8399CB8096C7
8195C78195C88096C87C91C67C91C67B90C7798EC57A8FC8788BC5798CC67989C47989C4
7988C37887C27984C27883C17883C17684C17684C3717FBE7080BC6E81BC6E81BC6B7FBA
6A80B9687FB5677EB4687FB5677EB2667DB16178AC6479AE6378AF6174AC6575B06474AF
6272AE6272AE6270AD606EAB606CA8606CA85F6BA75E6AA45B689D5E6B9F5F6CA0596798
58669559669359669259669258659157669157669155639051628E50618D536492526391
4C5E8C4D5F8D4C5D8B4A5C8A4D5F8D4A5C8A4A5B89495A86475A85465783485685485685
47558248558145527E43507A46537D46547B45517B424F79414F763D4C73404E753B4A73
3C4E763A4B763B4A753A49743948733A4974384673384673374471344070384474364272
36437035426E323F69313F66303C642F3B612F3D602E3C5F2C3A5D2A385B29375A2A385B
29375C26365A253358253358253356233253253350242F4B
302E2F38373536322F3A37323F3B323C382D3B342A4A463A6F6B5F807D6E827F707E7C6D
7C7D6D7C7F6C797C6B7A7F6B7C806F7E82717F83728486788D8E808F9082908E81929083
9894889B948A9C938C9E958EA097909F968D9E978D9F9B8F9D998D6B675B625E52ABA79C
CAC8BCE1DED5DFDCD7D7D6D2D5D4D0DEDEDCDCE0DFA5ABA9737977757B798A9390929B98
9CA2A08086825E6460636C676B716D6F7571727874727771BEC3BCCED1C8DBDDD2E7E7DB
D2D0C38683746A64568E887AAFA99BB4AEA2C3BCB2BCB5AB7C786F6B675E85807ABFBAB4
DBD8CFD2D2C8D4D4C8DADBCDBFBDAE9B998A908E8194928596948854544A26261E41423C
43443F3D3F3C3C3E3B353734353734373C3840423D4B4D485355505D6059636861676D63
61695E596156576156586257555F54576156596058575E575A5F59575C58595B5A59595B
5F5D6067656A6560666059605D54596D646980757B7D7278786F747D74798A81868A838A
86818885828D8987958786988182978D8FA89FA4C1A9AECCA6ACCEAAB0D4A9AED4AAB2D9
ABB4DDACB8E0ABB7DFACBAE1ADBBE2ABBAE1AFBEE5B0C0E4AFBDE0B1C0E1AFBEDDB0BFDE
B2C1DEB0BFDCB1C0DDB3C1DEB1BFDCB1BFDCB1BFDCB3C0E0B0BDDFB0BEE1B1BFE4AFBDE4
B0BDE7ACB9E3AAB9E4ACBBE6ABBAE5ABB9E6AAB8E5AAB8E5A7B8E4A8B9E5A8B9E4A3B4DF
A6B8E0A3B6DEA4B6DEA3B4DFA1B2DDA2B3DFA1B2DEA1B2E0A2B2E39DAFDF9BB0DF9AAEE0
98AEDF95ADDD94ABDD95ACDE94ABDD94ABDF90A7DD90A6DF90A6E090A4DF8FA3DE8FA3DE
8CA0DB8A9ED98B9FDA879CD5889DD6869BD2859ACF879CD1859BCD849ACC8197C88094C6
8094C67E92C47D93C57C92C47D93C57D93C57A8FC4798EC3768BC27588C0798AC07687BD
7887C07C88C27882BF7781BE7581BD7782C07381BE7381BE6F7FBB6E81BC6A7DB8697EB7
6980B6647DB3667FB5677EB4647BAF637AAE637AAE6479AE6277AE5F72AA6374AC6372AB
6372AB6271AA636FA9626EA8626EA8606CA6606AA55F6AA25A679B5B699A5C6A9B586695
5866935A689556659058679057669154668E56689053668E51648E4F628C50638E4F628D
4C5E8C4C5E8C4A5C8A4B5D8B4C5E8C485A88475A85495C87485B86445782465783445581
46578243557D3E507841537945577D42547A4251784150773E50763C4E743C4E763B4D75
394A753A4B763B4A753B4A7538477238477236447139467334416E36437033406D35426E
35426C33406A313F66313F64303E612F3D602F3E5F2C3C5D2E3D5E2B3B5C29395B273759
29395D28385C23335722325623335423325123314E242F4B
3F3E394040383E3B34403C33413A30453F334C483C5955496C685C757366727063757668
7A7C6E777B6A777B6C7B7F6E8084757E8271838675898C7B909181959384959185989286
9A92879C92899C8F89A1928DA1948E9B8E86958B82928A7F8D877B716D61777368AEAAA1
CECBC2DEDBD2D5D4CFD1D2CDC2C4C1AFB3B29EA2A1757B7B80868690999688918EACB2AE
B1B6B28385806365606D6F6A7778737D7E787F807AA5A6A0DDDED6CECFC7EDEFE4F3F3E7
ACAA9D6563547774659C988CA5A196979088D8D1CBDAD2CFA29D9A8C8784736E6BABA6A3
CAC5C1D0CDC8D8D5CEDAD7CEACAA9EA2A094B0B0A498988C69695F2323191F201833362F
373A333439332F342E2C332C373E363B423A40453E43493F5F655B696F655F645D5A5F58
575E56535A53555C55596059566057586259555C554E534D5355506A69656B67666D6767
7E7576877C807B6F7350444868595E827378897A81897C83897E86887E8789818C8A8490
8684918483918284938285988E93A9A3A9C3A8ADCAA7AECBA8AFCCAAB0D0ACB2D4B0B6D8
ADB6D7ADB8D8AEB8DBB0BADDAFBCDEADBCDDAFBEDFAFBEDDB0BFDEAFBEDDAFC0DCAFC0DC
AFC0DCAEBFDBB1C0DDB1C0DDB2C0DDB2C0DDB3BEDCB3BEDCB4BFDFB1BEE0B1BDE3AFBDE2
AEBCE3ADBBE2ABBAE3ABBAE3A9B8E1A8B9E4A9BAE5A7BAE4A6B9E3A6B9E3A5B8E2A1B7E0
A1B7DEA1B7DCA3B7DCA1B4DC9EB4DB9EB4DDA0B3DDA0B5E09DB2DF9CB1E099ADDF98ACDF
9BB1E396ACDE95AADF96ABE094ABDF94ABE190A6DF91A7E191A7E08DA3DC8FA5DE8CA2DC
899FD98AA0DA889ED7889FD5889FD3889DD2889ED0879BCE8498CB8397CA8296C98296C9
8094C77E92C57E92C47D91C37E93C27D92C17B8FC17A8EC1798DBF798BBD798BBD7888BB
7A87BB7A87BC7984BC7782BA7682BC7682BE7483BE707FBA7282BD6E81BB6C7FB96A7FB8
6A81B7687FB36980B4687DB2667BB06378AD6479AE6276AB6475AB6473AA6673A86673A8
6673A86471A66370A5636EA4616EA35F6CA15F6CA05C6A9B5B69985C6A97586995566792
56689055678F54668E55698E54678F51678C52688D52688D4F658C4D638A4D638C4D638C
495E89495E8B475C89485D8C485D8A475C89475C87465983475A8445588243568042557D
41577E3F557A40547941557A40567B3D54763F53763E52773D51763D51763C4F773A4C74
3A4B76394A753A497438477237466F37497135467138477035446D34436A304268334569
3244682F41652E41622E41622B3E5E2C3F5F2B3E5F293C5D2A3A5C283B5C27395D26385C
273A5B25385923365722355524385324364E2231481F2E43
3532294543374A483C4440344D493D5754455451424C4A3B575546606153636456717264
747668767A69787C6D7C80718082748283758788788C8A7B8F8D7E959185968E83988E84
988B82998C849889849886829684808F80798679717E746B80766C81786F827972AEA79F
D2CEC5D2CDC7BCB8B5ABAAA89F9F9F9395948A8B8D8387889195968F9394B7BBBAE3E5E2
9C9D9862615D75726D7C79747F7C777E7B7499968FBDBAB3D5D5CDD7D8D0EFF1E6CACCC1
8082747C7D6F8D8E8087877B939389A5A29BC2BDB9BCB7B3AEA9A68C8885666060A29C9C
BFBAB7D5D0CDE6E2DFDCD9D4C6C3BEB0B0A87A7B735B5C543E3F3723241C1F22192A2D24
282E2423291F2227202C342940483D454D423A4036393F355B6157595F554C514A51564F
555A545257515A5F5B5D625C585D575B605A585A5553544F5958547F7A77837B79867C7A
8C80808D7F7F8271776B5A608471778A79818D7D888F818E8D82928C83948A8395898699
8583987F8295808297969BB1A4AAC2A7ADC7A6ADC9A8AFCBACB3CDB0B6D0B0B5D2B2B7D4
B0B7D3B2B9D5B0B7D4B2BBD8B3BEDAB1BFDAB0BED9B1C1DBB0C0DAB0BFDCAFC0DCB0C1DD
AFC3DEADC1DCB0C1DFB1C0DFB1C0DFB3C0E0B5C0E0B3BEDEB2BFDFB0BDDFAFBDE0AFBDE2
B0BEE5ADBCE3ACBBE4A8BAE2A9BBE3A8BBE3A9BCE6A7BDE6A5BBE2A5BBE4A2B9E2A1B8E1
9FB8E0A0BADFA0B7E09FB6DF9BB4DC9BB4DC9DB4DE9DB4E09BB1E09AB0E19AAEE199ADE2
99AEE398ADE497AAE297AAE295AAE193A9E291A7E094AAE390A9E18EA7DF8BA4DC8BA4DC
89A2DA87A0D8859ED4879ED2879ED2869DCF889ED0879BCE8498CB8296C98394CA8192C8
8192C87F93C87E92C77C90C37D91C37C90C27D91C47B8FC2798DC07A8CBE7A8CBE7688B8
7787B87888BB7A87BB7986BB7683BA7281B87382BB7283BB7182BA6E81B96C7FB76C7FB7
687DB2697EB3677CB1687CB16579AE6478AD6576AC6778AE6473AA6471A66671A76773A7
6774A86471A5626FA36370A4606DA15F6D9E5E6C9B5C6A995D6B985C6B96586994586994
58699456699355669154679154679151679050668F51679050668F4E648D4E618C4E618C
4C5F8A4C5F8A4B5D8B495B894A5F8A495E89455B84435980475A8245588042557D3F557C
3D557B40587E3F557C3E547B3E567A3D55793D53783C52773A5077384E753D5078394C76
3A4B763A4B7637487335476F37497137496F37496F36486E36486C324667324667344869
3246672F43643346672F4263293D5E2A3E5F2C3E622B3D61283A5E283A5E26385C24365A
26395A25385824375722355327385226364D222E44233043
39352A4644384442364543365B594A585947464833494C37515441575A475A5B4B6B6C5C
6F70607273617475657677677C7A6B7F7C6D878175888075867E738A8077897C748C7D76
8C7D7681726B81706983726B7E6D667A69627E6D667C6D667768617568608D807AA09591
ABA29D9F9593928A88969090A19B9D9B969A908B91929095A6A4A9BCBABDE2DDE1CDC9CA
787272847C7A8D85828C82808A817C7B726BA9A099D0C9C1DEDAD1D1D1C7C8C9C195988D
82887C7E847672786A80867A9FA599AEB4A8999C9376776F8E8D889F9E99A7A3A0C3BFBC
D1CBCBE7E1E1E5DFE1D3CFCEB8B4B38685833C3D3833342F32352E292C2324271E2B2E25
272A21212419292C2343493F5C6258585E54343A3030362C585B5251544D4F524B535550
5658555858565F605B5D5C5857565263625D635F5C5C57546F676488807D8A807E8E837F
9082818C7E7E89787E8A79818E7C888F7D8D9081949082998E849F8E85A28A85A38885A4
797D9A8085A2989DBBABB0CEA9B0CCA8AFCBACB2CCABB1C9B0B6CCB2B8CEB0B5CBB3B8CE
B3B8CEB4BAD0B4BAD2B4BCD3B3BDD6B3BFD7B1BFD9B2C0DAB2C2DBB2C2DCB0C1DDAFC3DE
B0C3E1AFC2E0B1C1E2AFBFE0AFBFE1B1C1E3B1BFE2B1BFE2AFBFE1AFBFE1AEBEE0ABBEDF
ABBDE1ACBEE2ACBEE4A8BCE1A8BCE1A8BEE5A8BEE7A5BBE4A4BAE3A5BCE5A1B9E59EB9E4
9AB7E19DBAE49BB8E49AB7E39AB7E398B5E19AB5E49AB2E298B0E099AFE198ACE198ABE3
9AADE599ACE697AAE497AAE494A9E294A9E290A6DF91A7E08DA6DE8AA5DA89A4DB89A4DB
88A3DA86A1D685A0D586A0D3849ED1869DD1879CD18398CD8599CE8195CA8495CD8192CA
8394CC8090CB7E8EC97F8FCA7E8EC97D8DC87B8EC8798CC6778AC2788CC1768ABD7589BB
7789BB7688BA7787BA7686B97585B97283B77283B77384B86D81B46D81B46C80B5677BB0
6C80B36A7EB16A7EB36A7BB16677AB6677AB6777AB6777AB6673AA6471A66671A76874A8
6573A46472A36270A16171A25F6FA05D6E9C5E6F9D5C6D9B5C6D995B6C98596A98576798
55659656669759669A5666995666995262955262965364985163955062924D5D8E4D5E8C
4F608B4D5E894C5D884B5C87495C844A5D85475A82465981445A81445A81415780415881
3E557E3F567F3E557E3F567F3D547D3B527B3D547E3D547E394F78394F783B4E78394C76
3A4D77384B73374A7235487035496E35496C35496C374B6C364A6B334A6A334A6A304769
32466934486D31456A2C3F672B3E66283B632B3D632B3D632C3B622E3D642B3B5F28385C
27375926355625345325335029354F27314A283047272D43
47453949473A4C4A3D4E4F3F5354425456415456405B5D475B5E495E604B5F5E4C6A6859
6968566C6B59696856706D5E777163767064787065746B62746A6172685F73665E70635B
71645C6F62596D605771635A72645B72645B7B6E66766961584B435A4D45837572897B78
786D6B6B615F8E84839C9293978E919C9396979195A9A3A7CBC6CAE2DCDED6D0D29E9694
827A778D847F8A7F7B8B807A897C74A99C94CCC2B9CAC0B7B4ADA3ACA89FA0A09886877F
888E84949A90656B6173796FBCC2B6B4BAAE7B7E73696B60B9B9B1BCBCB4C3C0BBCBC6C3
BCB6B6BFB9B9C5BFC1A19CA07270715B5B5B333331282A25272C25292E272D30272E3128
282B202A2D223C3F34595C5364675E5E61583B3E3542453E56575151524C53524E575652
5A59555C58555E59565C57545C57536F67646E66645E5453786E6C988E8C988D8B988D89
9B8D8A91838288777D93838D90808D8D7F908E80978B819A8F86A58A84A68480A37D7D9F
7E83A3A1A7C7AAB0D0A8AECEAAB1CEABB2CEAEB4CEADB3CBB0B6CCB1B8CBB2B7CDB3B8CC
B3B8CEB2B8CEB7BDD3B5BDD2B3BED4B5C0D6B5C1D9B2C0DAB1BFD9B1C1DBB0C1DDAFC0DC
B1C2E0B2C3E1B1C1E3AEBEE0ACBEE2ACBEE2AEBEE2ADBFE3ABBDE1AEC1E2ADBFE3AABCE0
AABEE1A8BCDFA9BDE2A9BDE2A6BCE1A5BBE0A5BBE2A6BDE6A3BAE3A2BBE49EB9E49DBAE6
99B8E69BBAE898B9E696B7E496B7E495B4E295B1E197B1E297B1E298AFE198ADE294A9E0
99ACE499ACE494A7DF93A8DF92A7E091A7E090A6DF8EA7DF8CA5DB8AA5DA89A4DB87A2D9
87A2D7849FD4869FD5869FD5859CD2839AD08398CF8295CD8093CB8293CB8291CC8291CC
8191CC7F8FCA7F8FCB7C8CC87D8BCA7E8ECC7B8BC9798CC7778BC6768BC4768BC2758ABF
748ABC748ABC7488BA7286B86E82B47084B67183B56F83B56D81B36B7FB16D7EB26A7BAF
6B7CB0687CAF6B7CB06879AD6576AA6577A96676A96575A86474A86373A66370A46472A3
6474A55F6FA05E70A05E70A05E709E5C6E9C5A6C9A586A98596B995A6B995C6C9D58689B
56669955659858659A56659C59669D52619852619A5261984F5E954E5E924F5C904F5D8E
4F5D8A4C5B864E5D884B5D854B5D85485C81475B8044587D455880445A81445A83435A83
3F567F4057803F567F3D547D3E547D3D537C3C517C3D527D394E793D507A3B4E78394C76
3A4D7535487037496F364A6F364A6D364A6D35496A35496A35496A3347683145682D4164
32446A35476F2E3F6A2D3E692A3B672839642C3B642D3C652C3B642F3C662C3A6129375C
2A385B27365527345427324E29334E2A3249272D45272C42
4E50424C4E404F52415354425C5D4B6365506867526766516A68536B68556D6757706A5A
6D67576D67576D6759716B5D777165716A606F685E70695F726B61716A606F685E635D51
605A4E6A6458625C505A5448615B4F68625670695F6C655B453E344A4138726964746B66
685F5A655E587F7774918986938B89978F8DA6A0A0BAB6B5C3C2BEB7B6B19E9B94848077
817A70827C6E968E81A7A090A59C8DACA394B7AB9DA2988C887E748A8178857E7887827E
918D8A95949073726E71706BE1E1D9CECEC686867CA8A59CD6D2C9D8D3CDBFB7B4B1A9A6
B0ABA8AEA8A88682835452533E3E3E383A392E302D2E332D2E332C2830252C32282E342A
2A2D2433362D4E4F475A5B555D5E585D5E584C4D4750514C5A59555A56535A55515D5854
5F57545E56545F5554625857645858625656625656776D6C938988A49A999D9191958786
988D8B9A8E8E9D8E939F929B9B8F9D908596887F948A859C8985A084819E8584A39293B2
A2A7C5A9AECCA9AECCAAAFCDAEB3D1ADB2CFAFB6D0AEB6CDAFB7CEB0B8CDB2B8D0B3B9CF
B2B8D0B5BDD4B5BDD4B7BFD6B2BDD3B3BDD6B2BED8B1BFDAB3C1DEB3C1DEB0BFDEB1C0DF
B0BFDEB0C1DFB1C1E3AEBEE0ACBEE2ACBEE2ACBEE4ABBDE3ABBDE3ABBFE2ACBEE4AABCE0
A9BBDFA7B9DDA8BADEA7BBDEA5BCDEA3BADCA3BBDFA0B8DE9EBAE19CB9E19CB9E399B8E4
98B7E597B8E594B6E395B7E495B7E495B6E395B4E296B2E195B1E095AFE094ABDD95ACE0
97ACE194A9DE92A7DC92A7DC90A5DC8FA6DC8FA5DE8BA4DC8AA3D989A2D888A1D7869FD5
869FD7859ED6849AD3869CD5869BD48598D28497D28595D18393CE8191CC808FCA8190CB
808FC8808FCA7E8DC87E8DC87D88C67C8AC77B8BC7778AC5788CC77488C37288C2748AC3
7289BF7188BC7188BA6F86B86D83B56F85B76E82B46E82B46E83B26E83B26D7FB16A7CAE
6A7CAE6C7EB06B7DAF687AAA6779A96678A86476A46375A36375A36173A15E709E6072A2
5F74A35C72A15A719D5A719D5A719D59709C576C99556A97566B9A56689857679A57679A
5666995567995464975364985363975363975161955262964F5F935060944D5D914C5C8F
4B5B8C4D5E8C4D5E8A4C5D884A5C844A5C84485A8244577F44577F44577F44577F42587F
3F557C40567D3F557C3F557C40537B3F527A3E517B3E517B3D507A3F51793A4C74394B73
3A4C72384A703B4B6F39496D36496A36496A354869344768334667334569324266314067
2F3E6733426B303D69323F6C2F3D6A2C3966323D6A2F3A672D38652E3A642C38602C385E
2C395C2B38582A355529345028324D2A3249272D45252B41
4B4F40515546555948595C4960614F62644F6764516966536C67546C665670695971695C
6F675A706A5C706A5E736D617770666C685F79766D88857C827F76737165737367606153
5152445B5C4E57584A4445374B4B3F67675B6C6C606E6E624F4C4349463D67635A6A655F
67625C68645B84807797938A99948E8F8A8496918DAFAAA6A7A79F9191878E8E848C8A7E
8A867A817E6F8683729F9C8BA4A18E9F9A877C7764766F5F7971647A7468787169837B78
90888697928FA09A9AAFAAA7E5E0DCEAE5DFC3BEB8DED9D3F0E9E3EAE3DDD3C9C7B3ABA9
A8A3A094908F4442433030303737372A2C292429252F342E2F362E262E232B312732382E
34372E3B3E3552534D5C5D575D5E585F605A5A59545958535C5B565F5C57605B555F5A54
6059535E55505E53516257556355545E504F736565AFA1A1A195959D91919F9093948588
9586899E9294A2959EA99DA7AAA2B18A8695746F8383819785859D8688A19394B0A4A8C5
A9AECBACB1CFABB0CEADB2D2AEB3D1AFB4D2AFB6D2B2B9D5B1B8D2B3BAD4B1B8D2B0BAD3
B1BBD4B1BBD4B4BED7B4BED7B4BED7B4C0DAB2BDD9B1BCDAB2BFDFB1BEDEB2BFDFB1BEDE
B3C2E1B0BFDEAEBFDDADBDDEACBFE0ACBFE0ABBDE1ACBEE2A8BADEAABCE0ABBDE3ABBDE3
A9BBDFA9BBDFA9BBDFA5B9DCA4BBDDA3BADCA1B9DD9FB9DE9FBBE29BB8E09CB9E39CB9E5
9BB8E496B5E394B5E293B4E194B3E193B2E097B3E296B2E193AEDD94AEDF95ACDE95ACDE
94A9DE94A9DE93A8DD91A6DD90A5DC8EA5DB8DA3DC8EA4DD8BA2D88CA3D98AA1D7889FD5
869CD5879CD5869BD48598D28699D38396D08494D08494D08595D08292CD8291CC8291CA
808FC87E8DC67E8AC47E8AC47C88C27B8AC37888C37689C37489C27388C17389C37288C1
7089BF6D87BA7188BA7087B96F86B86D83B56B7FB26F80B46F81B36E80B26E7EB26B7BAE
6A7AAD6B7BAE6979AA6779A96678A86577A56476A46376A16277A26075A05F74A15D72A1
5D73A25E74A35C72A15B71A059719F596F9E586E9D576C9B556A99576999576798566697
566697576896536394536394526293516192546293536192525F935060934F5F934E5E92
4C5C8F4B5B8C4A5B894A5B87495A8548598448598445577F43567E43567E42557D44577F
41547C40537B42547C4052784153793F51774150793F4E773F4E773D4F753F4E753A4C70
3B4D713C4C703C4A6D394869384869364969384869364668364668364668324065344269
334168323F69323D6A333E6B323D6A303B68333B69333B692E39662C37642C386229355D
2835582A375928355525335028344E27334B212C4221293E
616759686F5F7175646C6F5C6B6C5A6869576B68576B68596966576C685C6D675B726C60
746D63746D63756E66757168706C6364615A808078BDBEB6B1B4A984877C73766B6C7062
4C524452584A575D4F484E404A50445E6458676A5F6C6F6466696055574C5D5D5367675D
68685E6B6B5F8785799E9C90A2A0939894899A968DA09C939A988C8F8F8395958B8F8F85
838377808275797D6E7D8172858978767A696265526768566D6E5C7573646A685B747067
8A837DBAB2AFDFD7D5F1E9E7EBE3E1F1E9E7F3EEEBF9F4F1F9F1EED8D0CDC1B9B7B0A8A6
8F8B8C6462633B393A3737373636342D2F2C272C282C332C2E352D2C3429323A2D3D4538
41473D4C5248575A515F625967686063645C59595154544C5959515B5B515C5C505B594D
5D594D5E574D635A53695E58453734423330968484BBA8AA978788867679938288988990
9889909F929BA79CAAB2ACBAA9A5B4777686615F747A7C918A8FA59A9EB7A4A8C3AAAFCC
A6ABC9ABB0D0AEB2D5AEB2D5AFB5D7AFB5D7B0B6D6B1B8D5B0B6D6B4BADAB1BAD9B2BDDB
B1BCD8B2BDD9B2BDD9B4BFDBB3BEDCB1BFDCB4C1E1B2BFDFB2BFDFAFBCDCB1BFDCB2C0DD
B2C1DEAEBED8ADBED8ADBED8AFC0DCAFC0DEADBDDEACBCDDADBDDFAABDDEAABCE0A9BBDF
A6BADFA6BADFA7BBE0A4BADFA3B9DE9FB7DB9FB7DB9EB6DCA0B9E19EB7DF9DB6DF9CB4E0
9EB6E29CB4E29AB2E298B0E098B0E098B0E098AFE196ADDF93AADC99AEE396ABE094A9DE
94A7DF94A7DF94A7E191A4DE90A3DD8EA3DC8EA3DC8EA3DC8DA2D98BA0D7889DD6899ED7
869BD2879AD2879AD28798D08798D08494CF8393CE8393CE7F92CC7E91CB8091C98091C9
7F8EC7808FC67F8EC57C8BC27C8BC2798AC0788BC3758ABF7489BE7289BB7289BD7087BB
6F89BA7088B87187B96F85B76F84B97084B9707FB67180B76E7DB46E7DB46E7BB26C79B0
6976AD6B78AD6976AA6777A86878A96677A56375A36274A26075A06075A26274A45E72A4
5C70A25D71A4596DA05C70A35A70A2586EA05A6EA358699D566898566896576896556692
57689357668F54638E54638E55628E55628F566390556191525E90505E8F4F5F924D5F91
4C5E904A5C8E475989485A88495B89465984475A8546598345568145568146578243547F
46558043527B44537C42517A404F76404F76404D77404D773E4B753D4C733F4D723D4D6F
3A4A6C3B4B6C3B4A6B3A4968374866374866374866374768384768364566334164334164
344066313D65333C65323E68303C66303B68323A683038672C37642A37632A376327345E
27355C26365A25355725365424354F24344D2130451F2E43
7073687276687D7F71767767706E5F6B6A586D6A596D67596864586965596A64586F695D
766F65736F647672696B68616E6B6485857DA2A39DCBCEC7D5DAD3B3B9AF878F84656D62
474F424F574A565E514E56494E5448585E5273766D77787074756D73746C6C6C6476766E
7E7E7677776F8A8A828181779191879F9C93817E7583807786867C86867C7C7D75696A62
63665D6C6F6673796F899184919C8E7A85755B6453676E5E737766797C6B7273657C7A6E
A19D94D0C9C3EAE0DEECE2E0EEE6E3F0E8E5FFFAF7F6F1EEE3DEDBBEB9B6B6B1AE9C9696
6F6D6E4A48493735363636343234312A2F292A2F292F362E2F372C30382B373F3240483B
454B3F555B4F5D60576164595F61565C5E5359595156574F595B505A5C5159594D5A5B4D
58594B626053665F55665D5462575160524F8C7C7C8B787A826F737B6A70897882978792
9C8C9996899A9990A3A7A2B69390A36263776969818387A0979BB4A5ABC5A8ADCAA9AECC
A7ACCAA9AFCFAEB2D5ADB3D7AFB5D9AEB6DAB1B7D9B1BADBB0B8DCB3BBDFB2BCDFAFBCDE
B0BDDFB1BEDEB2BDDDAFBCDCB1BEDEB0BDDDB1BEE0B2BFE1B0BDDDB1BEDEB0BEDBB0BEDB
AFBEDBADBDD7ADBED8ABBCD6ACBDD7ADBEDAACBDDBABBCDAAABADBA8BBDCA7B9DDA7BBE0
A6BADFA5B8E0A3B9E0A3B9E0A3BBE1A2BAE0A0B8DE9EB6DC9CB4DA9DB4DD9DB4DD9EB4DD
9CB1DC9EB3E09CB1DE9BB0DF99AEDD98ADDC97ABDD96ACDD96AADD98ACE196AADF93A6DE
94A7DF93A6DE94A7E191A4DF8FA2DC8EA1DB8EA1DB8DA0D88BA0D78A9FD6889BD3889BD3
879AD2879BD08798D08596CE8697CF8293CB8393CE7F92CC8093CD7E91C97E91C97E8FC5
7C8DC37C8DC17B8CC07B8CC0768ABD778BBE758BBD748ABC738BBB738BBB7088B86E86B6
6D88B56D85B37086B57084B66F83B67084B7707FB66F7EB76D7CB56D7CB56F7BB56D79B3
6C78B26875AC6976AB6676AA6777AA6577A76476A66476A46075A25E73A06173A35E70A2
5B6FA15E6FA35B6CA05C6DA35B6FA45A6EA35A6BA1596A9E586A9A55689356679353648F
55648B55648B54628955638A535F8755618B56618E576290525D8B505C8C4E5E8F4C5C8F
4C5C8F4C5C8F475788475989485A8A46588647598746598447588443548042537F42537F
45547F45527C44517B445279414F76414F76414D75404C743D4B703E4C6F3E4C6F3C4B6C
39496A3A4B693A4968384967374866374866364667364667364566344364324162313F62
303D60323E64343D64323B62303C622D39612D36612E37622C38622A376129366025345B
26345926365A27375927375822334F2638502131481C2D41
716E6779766D807C736E6A5F6C6658676151665F4F676050655F4F666050665E51696355
7370616F6D606B695D6C696088857EBAB9B4D3D4CFD3D5D2DCE1DDD6DCD8B2BBB6868F8A
4C564E5A64596A72676F7569686B606D6F648B88818E898585807C8E8684877F7D82797A
857F819B9798A5A1A27E7D7B656563767674535351595B565E615A5D60595658534D4F4A
5456515456516D726E9BA19DB3BCB79CA69E596058646A60868C80878B7D8486797E7E72
BAB8ACDBD7CCE4DDD5E4DDD5EFEAE4F1ECE6E9E4E0DFDAD6D3CECAAEABA6928E8B6B6A66
4E4D4B34343237373533353030322D2E332C2C312A31372D373D2F373E2E3F46364F5646
515749565C4E63665B64685A565A4C565A4C5B5D525B5D525A5C51585B5057594E5B5D50
56584B5D5D516F6D617571667F7870978E897E73717769698A7B808F7F898979868E8091
9485988A7C9380768F867D988B87A272728E7776959296B3A7ABC8AAAFCCA8AFCCAAB1CE
AAB1CEA8B1D0AFB5D5ACB5D6ADB5D9AEB8DCB0B8DDB0BADEAFB8DFADB9DFB1BDE5AEBCE1
AFBDE2ADBBE0AFBCDFB0BDE0B0BDDFAFBEDFB1BEE1B0BDDFAFBCDCAFBCDCB1BEDEB0BEDB
AEBDDAAFBEDBACBDD9ACBDD7AABED7AABED9A8BBD9A8BDDCA7BBDCA6BADBA7BBDEA5BBE0
A4BAE1A4BAE3A0B6DFA0B6DFA2B8E1A1B7DEA2B8DF9EB4DB9DB3DA9CB2D99CB2D99FB2DA
9BAED89EB1DB9CAFD99BAED99AADD898AAD897A9D997ACDB97A9DB98AADC98A9DD96A7DD
93A7DC91A4DC8EA3DC8EA2DD8CA1DA8DA2D98CA1D88BA0D78B9ED6899DD28B9CD28A9BD1
899AD08697CB8697CD8697CD8296CB8094C98194CC8194CC7F94CB7E93CA7E93CA7A8FC4
788EC0798FC1788EC0778DBF768CBD748ABB758DBD748CBC7189B97088B66F8AB56D88B3
6C88B06A86AE6E87B07087B36D83B26D81B36E7FB36B7CB26D7EB46C7DB56A79B26978B1
6877B06576AE6576AE6576AE6576AC6175A86074A75E72A46074A65F74A36072A25C6E9E
5B6D9D5C6EA059699D5A6A9E5C6CA05B6B9E58689B59699A556893586B9557689354638C
556388556388546086546086546086546088555E89535E8B515C8A515D8D505C8E4D5B8C
4B598A4B598A49568A48588B49598C475788475788475788465687445583425381415280
44537E44537C45537A4553784050723F4F71404E71404E713F4C6E424F6F3E4D6C3B4A69
3C4B6A3B4A6938496737476836466736496A35476B354569354366324063313E61323F62
333D61333D60343E61323C5F313C5C2E39592E385B2D375B2835582A375A2B385B273558
26335527365726355627365725345122324C202E481B2A41
746D6779726A837C746E655E635B505F574A615A4A625B4B5E5848585242544D3D5D5747
6A67586866576B695D88857CB9B9B1D9D8D3DDDDDBD3D5D4D1D5D6DCE2E2C7CFD1909A99
75807C88918C8A918A959A9391948D858680817D7A7D7777786F707C73746C61654A4048
6A636BABA5AF918B956D6A713D3E434F535645494C4C50514A4E4D484D49464A494B4F4E
5658554D4F4C787A79B1B5B4B8BEBA9EA59E40433C6B6E6593968B9FA19488887C7A7A6E
AEAC9FCFCBBFDAD3C9DCD5CBEBE8DFE1DED5CBC8C1BAB7B09E9D9883827D5F605B52534E
4949473A3C393638332E332D3237303B4039373D33343A2E404638424939484F3F525947
535A4A6168586F736460645555594A55594A5A5C4F5C5E51595B4E57594C57574B5C5C50
58584C6563577E7A6F8F8B82847D7778706D655B5A7B7074998C959D919D988D9D8B7F93
7C728A766E8679738D7A769183809D8687A59A9BBAA1A4C3A6ABC9ABB0CEA8AFCCAAB1CE
A9B2CFABB4D1AEB7D6ABB6D6ACB6D9ADB7DBAEB8DCAEB7DEACB8DEADB9E1AFBBE3ADBBE2
AEBAE2AFBBE3B0BCE2AEBAE0AFBCDFADBADDAEBBDEAFBCDFAFBCDEAFBEDFB0BDDFAFBEDF
AFBEDDADBEDCAABBD9AABDDBABBEDCA8BDDAA6BBDAA7BEDEA3BADCA3BADCA3B9DEA3B9E0
A2B8E1A2B8E1A1B6E1A0B5E0A1B6E1A1B7E09DB3DC9EB4DB9DB3DA9CB2D99DB1D69CB0D5
9BAED69BAED69AADD59AADD599ACD697AAD599ACD797A9D796ABDA94A9D893A7D995A9DC
93A7DC90A3DB8CA1DA8BA0D98BA0D78A9FD6889DD48BA0D7889DD4879CD1879BD0869ACF
8599CE8195C88195CA8195CA8296CB7F93C88194CC7F94CB7D94CA7D94CA7D92C77B90C5
7990C2788FC1778EC0768DBF768EBE748CBC768EBE728AB87189B77088B47088B46D89B1
6E8AB26B87AF6D86AF6B84AD6D84B06D83B26C80B36B7FB26B7FB46A7EB3687BB36878B3
6677AF6575B06477B16174AE6376AE6074A96074A95F73A65E72A55E72A45D6F9F5D6F9F
5B6D9D5D6F9F5C6C9F5D6A9E59699A576896576896566994576A9455689057698F56668A
556587546486536184546287515F84536186525E86505C864E5B87515E8B4F5D8C4D5B8A
4B598A4B598A4A58894757884C5A8B47578847578845578746578544568441528041527E
42537E42547A4352794252763E51723C4F6F3F4F703E4F6D3E4D6C3E4D6A3D4C693B4A69
3C4B6A39486738486939496B36466835456932446A334269324168334166323E64323F62
303D602F3C5E303A5D2E3B5B333E5C2E3C592F3A5A2B38582936562936562B385A273456
28355527345426335327345426344F25314B212B441E293F
776E677D746D786F68504740443B344F463D4E463B4B4539494335423F304943355C5648
6864586460548C887FC4C1BCD9D8D4D4D3D1D7D7D9D5D6DACDD0D5D0D5D9BABFC5A7AEB4
ADB5B8AEB6B9B0B8BAB3B8BB848A8A575B5C5E5F61575558575256575258373038443E4A
726E7C7D7B8957556351505E494B5742464F3F434C464B5143484B44494C45494A474B4C
5A5C5B646462979893CFD2CBAEB1A882857A6262588C8980A4A296C8C4B89E9A8E918D81
B9B5A9DAD6CACBC7BCB3B1A5C2C2B6ADAFA28E908585867E70736C52554E444740464B44
3C413B393E383B403A272C26383D364B524A3F473C384033474F404C55444C5343505745
575B4A636756616554585C4B565A495357465558475A5B4B56574959574A5F5B4F5B574B
6A6458807A6E8C837A7F7671665C5A706667857A808F858E978F9CB5AEBEBFBBCC9F9DB2
76778C66687F7678917B7D968B8FAA9AA0BAA4A9C6A8ADCAA8AFCBAAB1CDAAB1CDACB3CF
A9B3CEABB4D1ACB7D5ABB6D6AEB8DBABB8DAAEBBDDABB8DBAEBBDEAEBAE0AEBAE0AEBAE0
B4BDE4B2BBE2B3BCE5B2BBE4B3BCE3AFBBE1AFBBE1ADB9DFADBBE0ADBDDFAEBCDFACBCDE
AABDDEA9BDDEA8BCDDA5BCDCA7BEDEA3BBDDA2BADEA2BADEA1B9DDA2BAE0A4BAE1A1B7E0
A2B8E1A1B6E1A1B6E3A0B5E0A5B8E3A1B4DFA1B4DFA0B3DDA0B3DD9EB1DB9DB0D89DB0D8
9CB2D79AB0D596ACD198AED395ABD295ABD497ACD795AAD591A8D491A7D693A9DA92A8DA
92A7DC8FA4DB8EA3DC8DA2DB8B9ED68A9DD58A9FD88A9FD6869DD3869DD3839CD2819AD0
829BD18198CC8097CD7F94C98095CA7D92C77F94CB7D92C97C93C97B92C87C91C8798EC3
788FC37690C1758FC0718BBC708BBA708BB8758DBB748CBA7189B56F87B36F87B36E86B2
6E86B26D85B16F86B26E84B36981B16B82B46A80B2687DB2697EB3667BB0657AB1677AB2
6376B06275AF6275B06174AF6272AE6171AC6071A95F70A65D6EA25E70A25E70A05C6E9E
5C6E9C5D6F9D5B6C9A5A6B99596C97576A94576A94546A9153698E506789566A8B526586
526585516484536385516183516183516185516087505F884D5E894F608C4C5D89495A86
495B89485A88475987475A854A5B874457814558834257824457813F557E3F527C40537D
40537B3E52773E52773E52753A51713A51703B506F394E6B384B69394C6A3D4C6B3B4A6B
3A4A6B39496B37476937476B354368354368324168303F66303F66303F66324067324067
303E652E3C61303C622E3C5F2C395B2C3B5C2D3A5C293859293859273657293859273657
28355527355228335128314E28324B283047252B4121283B
7E776D746D63675E574C433C494039443B32443B32453D323D372B3F392D5B544A615A50
5A5349827E75BEB9B3D4D1CCD4D0CDCECDCBD0D0D2CECDD2C8C9CEB9BCC3B2B5BCB0B4BD
B0B4BDB5B9C2B6BBC18E959B7B8288757A80676A7156565E5C5D6257565C4F4D58716F7C
7775825F5E6C51505E52525E4A4C58565A63535760474C5243464B474B4E444849494B4A
5F5F5D80817CABACA6C0C2B7939387898A7C89877A908C81C3BFB4D7D3C8B2AEA3BBB7AC
E3E1D5CECEC29B9B918385788C8E816C70625256485154494F5247484E44474A41454A43
40453E3E433D373C362F342E4C514A4F574C4951444A52454D55464C55444D5444515846
565B47595E4A595E4A545847515544525544535446565447514F42696559777165625A4F
70675E978D848D827E756A6874686A867B81A59BA4A49CA9A4A0AFACABBD9394A871768A
60667C666E837E869B9098AF9CA4BBA2AAC1A5ADC4A7AFC6A7AFC6AAB1CBACB3CDACB3CF
ACB6D1ADB7D2ADB8D6ABB6D4AAB7D7ACB9D9ADBADAADBADCAEBBDDAEBBDEAEBBDEAEBBDE
B0BCE2B1BDE3B4BDE6B3BCE5B1BDE5B0BCE2AEBCE1ACBADFACBCDEAABDDEA8BADEA9BBDF
A8BCDFA5BCDEA6BCE1A5BDE1A4BCE2A1BBE0A1BAE2A2BBE3A3BAE3A2B9E2A2B8E1A1B6E1
A0B5E09EB5DF9FB4E19DB2DF9DB2DD9CB1DC9DB2DD9CB1DC9BADDB9AAFDA9CB1DC9CB2DB
9AB0D997AED796ADD696ADD693AAD396ADD795ACD892A9D58FA7D58DA8D58CA3D58CA3D5
8EA5D9899ED58CA1DA8A9FD8889DD6889DD6889ED7879DD6849DD3819CD1819CD17C9ACE
7E99CE7E99CE7E97CD7D96CC7A94C77D94C87D94CA7B92C87C93C97B92C8798EC5788DC2
768DC1748EBF738ABC718CBB738BB9738BB97189B7728AB87189B56E86B27086B56E86B4
6E86B46B83AF6B83B16A82B06880B0677FAF667DAF687FB1677EB0657CAE657AAF6479AE
6376AE6477B16174AF6073AE6373AF6070AB5C6CA75D6EA65C6DA35F70A45E70A25D6F9F
5C6E9E596B99596B99596C97576D96546C92536B91536B8F50688A516A895168884E6585
5266875165865064874D61865064894D61864D60884B5E884C5F8A4C5F8A495C87475C87
465B86465B86455A85465C85495C8442587F41577E40567D41577E3E547B3F557C3F557C
3E54793C52773B51763A5075395173395173384F6F384F6E384D6C384D6C3F4F713A4A6C
39496D3A4A6E35456935456937456A35436A324168324168303F662F3E652F3D64324067
35436A2F3D622F3D622C3A5D2C3A5D2C3A5D2B395C2A385B2B3A5B283758273657283756
2635542634512B365229334E293148293144282F4122293B
8283756E6F61514F433B372B423A2F3A32273B31273E342A473D34544A415C514B574E47
878078B3ACA6C6C1BDD3D0CBDBD7D4D4D3D1D3D3D3CDCDCFC3C3C5BBBCC0B1B2B7B2B2BA
B2B2BAB6B9C0A7AAB38D919AA6ADB5B2B9C1797D885B5F6A70747D71767C70757B71747B
5F626954555A57585D56575B7172768283886B6C714241464240434747475353515B5C57
5758527F7F75A9A99D9FA0929492839B998A706E5F7D7B6EB7B4ABCCC9C2C8C8C0E1E2DC
DFE2DBAEB3AC8C948980887B656B5D404737464D3D494D3E4C50414D51434A4C3F474A3F
4649403D4039383A353D423C4E534C4F554B4D53474A50444850414A53424B5240545945
585B48535643535645585B4A5456485353474E4B424E4943534C467C736E8B827D716662
796E6C998E8C877B7B80747890858D9C909CC2BAC9BBB4C49390A36B6C8065687B5F6679
5A6277717C908F9AAEA0ABBDA1ACBEA0ABBDA3ABC0A5ADC2A8B0C5ABB3CAABB3CAADB4CE
ADB7D0ADB7D2ABB7D1AEB9D5ABB9D6ACBAD7AEBCD9AEBCD9AEBBDBAEBBDDB0BDE0AFBDE0
AEBCE1AFBDE2AEBCE1B0BEE3AFBFE3ADBDDFA8BBDBA8BBDBA9BEDDA8BDDCA6BADBA5BCDE
A7BEE0A2BADEA1B9DFA1BAE2A2BBE49EBAE2A0BBE69FBAE5A1B9E59EB6E29FB6E29FB6E0
9FB6E09BB4DD9DB4DE9CB3DD9CB3DD9CB3DD9CB3DF9CB3DF9AAFDE9AB0DF99AFDE97ADDC
99AFDE98B0E094ACDC93ABDB91A9D990ABDA90AADB8FA9DA8CA8D88BA7D78BA4DA89A2D8
8AA3DB899FD9899FD9889ED8859ED7869FD8859ED7839ED5809BD07D9BCF7E9CD07B9BCE
7D9BCF7A98CC7B99CD7B96CB7B97C97A96C87A94C77B92C67990C4788FC3778CC1778CC1
778CC17289BB748ABC738BBB7288B77288B76F85B47086B57086B56F85B46C84B26B83B1
6C84B26782AF6883B06883B06580AD647FAC647FAC637EAB647FAC667EAC647AAB6278AA
6175AA6276AB6273AB6273AB6271AA6170AB606FAA5E6DA65D6EA45E6FA55C70A35C70A3
5B6FA1596F9E566D99546B95526B934F698E516B904F698C4D678A4E688B4D65894D6589
4E64894D638A4D628D4C618C4D628F4A5F8C4B608D495E8D485D8C495E8D495E8D455A87
475C87485F88475E87445C82445A7F40587A3D55773E56783E56783C54783E567A3E567A
3D537A3D537A3A5077394F76395177385076384E75354B70354B70374B7037496F37496F
384A7036486E35476D33456B38476E36456C3143692E40662F41652F41652E3E622F3F61
2F3F612E3E5F2B3B5C2B3B5C2B3B5C2B3B5C28385A29395B283859263755263755273856
26375524355123334D25334D232F45243142212D3D1F2837
797A6C5E5F514945393A34283C3429382E2435281F453830594C44574C464E433D5A514A
A49D95BCB8AFB9B4AECAC7C0D5D4CFD0CFCACFCECCBCBCBAB2B2B2B4B4B4AFAFB1B1B0B5
ACABB1AAABB0BEBFC4C4C7CEC9CED4B6BBC15F636C60646D6F767C6B7376697173636969
5157574C504F5658554E504D8E908D8989877474744A494743423E4E4D495B5C56606159
58584E7576689290819998869E9D8B8B8A786866578C8A7DA9A99FDDDDD5DEDFD9D0D2CD
BBC0BA9EA59E768077566055494F4140473745493A4B4F3E54574656584A5052444D4F42
4B4D4244473E444740484B444E514851574B505648494F414A51414D5442555948565B47
5C5F4C4649384548375051434F4F434A473E4C47415E5653665C5A685E5C786C6C908484
928484867A7C7B6F738E8389ACA0AAADA2B0B2ABBBA6A3B6706E834E50655D6477687085
7B869C8C99ACA0ADC09EABBEA3AEC0A4AFC1A4AFC3A6B1C5AAB5CBAAB5CBABB5CEACB6CF
ADB7D2ADB9D3ADB8D4ACBAD5AEBCD7AEBCD7AFBDD8AEBCD7AEBDDAB0BFDEAFBEDFAEBEDF
AEBEE0ABBEDFA9BCDDACBFE0ABBFE0A9BEDDA6BDDCA7BFDBA4BED9A3BDD8A4BDDBA3BCDB
A5BDDFA1B9DD9FB9DEA0B9E1A1BAE3A1B9E5A0B8E4A0B8E69FB7E59FB5E49EB5E19EB5E1
9DB4DE9CB5DE9CB5DE9BB4DD99B2DB99B2DB9BB3DF98B0DC98B0DE97AFDF94AEDF94AEDF
94AEDF96B0E391AAE092ABE190A9DF8EA7DD8FA8DE8DA9DB8AA6D889A5D78AA3D989A2DA
89A2DA87A0D8899FD9859ED6859ED6839ED5849FD6839ED5829DD27E9CD07E9CD07A9ACD
7C9CCF7997CB7896CA7896CA7694C87795C77893C87791C47B92C6788FC3788DC2758ABF
778CC1758ABF748ABC748ABC7389BA7086B77086B77086B77086B77086B76C83B56A81B3
6883B26883B26682B16581B06481AD617EAA617CA9637EAB627DAA607BA8627AAA6177A9
6175A85F73A66172A86273A96271AA606FA86170AB5F6EA95D6EA65D6EA45B6FA45A6EA3
5B6FA2596FA0566C9B526A96516A935069914F68904D678C4E688D4D678C4D658B4C648A
4E658E4E658F4E63904D62914B5F91495F904B6192495F90465A8C485C8E475C8B445986
475E88475E87455C85425A8041597D40587A3E56783D55773E56783E567A3E567C3E547B
3D537C3D537C3A5079384E773A4F7A394E79364B76324871374A74364971374971374971
36487035476F33456D31436931436933456B32446A2E40663042662E40642C3E622B3D61
2C3F60283B5C263959283B5B29395A283859273759263657263657263755263755263753
24355322334F23334D24344B243346263344222E3C1B2733
5C564A4A44383C3429362C22382E2433261E40332B53463E51473E4F463D423B31484439
949085A9A79BC4C2B6CECEC2C9C9BFBDBDB3B8B7B2AEADA8A5A49FABAAA6A6A5A39F9F9F
9C9C9CA4A6A5C7C9C8C7C8CAA2A6A77A7E7F595D5E5D61626165646167655B615D5E6460
6269615B6157585B525154496A6C617D7F7485877C53554A3E40334F5144505245585A4C
6566568182728C8B799B9885A8A592918E7D8C8A7BA3A194AFAFA5E3E3DBE5E6E0C7C8C2
9FA29B7A7F78545952454B4140463A393D2F4547394D4F4155564857584A565749535547
5355484E50434345384F53455458495155465054454F53444E5241545847595D4C5A5D4C
5C5F4E46493845463846463A49473B4D494055504A645D57625856635957857979998D8D
928686887C7E8B7E85A2979FB2AAB5AFA9B7A29EAF8584966061765B60766B7189848CA3
929CB596A2BA9EAAC29CABC0A2AEC4A7B3C9A8B4CCA8B4CEA7B2CEA9B4D0AAB5D3AAB8D5
AAB7D7ACB9D9ADBADAACBBD8AEBDDAADBDD7ADBDD7AEBED8ACBDD7ADC1DCABBFDAABC0DD
ABC0DDA9BEDBA6BDDCA6BDDCA6BFDDA3BEDBA4BFDCA3BEDBA1BCD7A2BDD8A5C0DDA2BDDB
A4BFDD9FB9DAA2BADEA2BAE0A2B9E29FB6E0A0B7E39FB6E2A0B7E3A0B5E2A0B5E29EB5E1
9DB4DE9BB2DC9BB2DC9BB2DC99B1DD99B1DD97B3DB96B1DC94B1DD91ADDC91ADDD92AEE0
91ADDF93ACE292ABE391AAE291AAE28FA8E08EA7DF8BA4DA8DA7DA8AA4D78CA3D78CA3D7
8CA3D78AA1D588A2D587A1D4849ED1849ECF839DD0809CCE809CCE7F9DCF7C9ACC7A98CA
7B99CD7997CB7896CA7795C97593C77492C67691C87893C87A93C97790C6778DC6768CC5
768CC5748BC17388BF7287BE7287BC7186BB7286BB7083BB6F84B96F84B96E85B96B82B6
6781B46680B36680B3647EB16581B36480B2607AAB607AAB617BAC617BAC5F76A86178AC
6277AC5F74A96276AB6276AB6475AD6171AC5F6DAA606FAA5E6EA95D6EA65C6DA35C6DA3
5B6CA05A6EA0566B9A536895556A95536A935168915067905168915269924F668F4D648D
4F66904D648E4E63904E63924B5F914A5E904B5F924A5E91455B8C475D8E485E8D465D89
455C86445B84435C84425C81415B80405A7D40587C3D55793D557940567D41547E41547F
3F527D3E517C3B507B394E793B507D3D4F7D394B79384A783B4C78374873354671394873
38477038477036456C34436A33456B3244683143692E40663044692B3F642A3E63293D62
2B3F64293D62293D60273B5E283B5C253859253859233656243455273856273653263650
26355224344E23334A233448253545293646202C381C2630
3C332A3A3128342A2132281F34292342352F4D403A4F423A4A4037453C333029212B271C
837F74A7A397C0BEB2BDBBAEB3B1A5A9A79BA8A69A9E9B9293908795958B9B9893A7A6A2
B2B1ADBDBEB9B8B8B69C9E9B7676746C6C6A636361636361646663646661646661696C65
70736A66695E595D4F6365586F7163797B6D797B6D5256454044335358445A5D4A636653
7B7C6A888A7583826E84836FA8A793B8B7A59FA0909394869EA092C1C3B6C0C2B79DA097
52554C3F42393E413841443B474A3F494B3E4C4C4052534554544857574B5A5A4E585A4C
5A5C4E4E52434B4D3F545847575B4A53574655594855594A55594A585C4D5B5D505A5C4F
5456494D4F424A4A404E4B42504C435A534D5E57515D544F534947655B59A59999B1A5A5
988E8D998F90A1969CB5AEB6B9B3BF8F8B9A76738665667B61657E6F758F858CA89AA3C0
9CA7C39AA8C39EACC6A1B0C7A4B3CAA6B5CCA5B3CDA7B5D0AAB8D5A8B6D3AAB7D7AAB7D7
AAB9DAAAB9DAACBBDCACBBDAAEBDDAABBCD6AEBED8AEBFD9ACC0DBABBFDAAABFDAA9BEDB
A8C0DCA8C0DCA6BFDDA3BCDBA5C0DEA3BEDCA4BFDDA2BDDBA5C0DEA3BEDCA3BEDCA3BEDC
A5BDDFA1B9DBA1B9DDA2BADEA3B9E0A0B6DFA1B6E1A1B6E1A0B5E0A0B5E0A1B6E39FB4E1
9CB1DC9AB1DB9CB3DD9AB1DD9BB2DE99B1DD95B0DB96B1DC94B1DD91ADDC92AEDE91ADDF
91AAE090A9E18FA5DF92A8E293A9E390A6DF90A5DE8EA3DA8FA4D98EA2D58EA2D58CA2D4
8BA1D28CA2D38BA3D389A1D1879FCF869DCF879ED0839DD0839DD0819BCE7D99CB7B96CB
7E97CD7D96CC7B96CD7994CB7792C97792C97792C97891C97790C8768FC7798FC9778DC7
768CC67288C27185C07388C17287C07287BE7386C07184BE6E83BC6E83BA6E83BA6A81B7
6A81B76980B66A81B76A81B76780B66780B6647BAF657CB0657CB0637AAE6479AE6378AD
6377AC6276AB6475AB6273A96172AA6071A95F6EA95E6DA85E6FA75D6EA65F70A658699F
57689C596B9D596B9B546996566B98556A955267925167905369925168915067904E658E
4D648E4D628D5062905062924B5F914B5F914C6092495D8F485C8E465C8D465B8A445A89
455C88435A86435A84445D86435C8441588141588140567F40537D425580445583435180
4351803F507C3E4F7B3D507B3E517C3D4E7A3A4B793A4B773B4C77394A7537466F384770
39487137466D38476E35446B3244683143673042683143693143692C40652C3F672C3F67
2A3D652B3E662B3F642D41662A3C6026395A283B5C253859273758263755253451283852
29375227354F28384F233247213141273444202C3A1B2531
362F27373028352C2739302B3B322D4A3F3B4A3F3B493E3A413833362D263D342F362D28
5249427F786E948D859F988E908C80928F80908D7E868374787566828073949087B5B2AB
E3E3DBDDDCD7908F8B6B6C6771706E777674716F706C6A6B6968666867636D69666F6C67
716E676D6D636B6B5F6B6B5F6C6D5F62655453564556594651543F5A5D48686A55747661
83857080826D7A7C67868872A4A792B7BAA58E937F6E735F7E836FB1B8A6A7AE9C656C5C
2D312235392A3D413347493C50524553534752504453514554544A55574A56584B585A4C
565A4B4B52404E5241545C47575F4A535A485458495A5E50595C51585B52575852555650
53544E4F504A504F4B53504B544F4B58504D5A504E5A4F4D5146425A4F4BAFA5A3C3B9B7
A9A19FAAA4A4C4BEC2CAC5CCB6B2C06766785A5B706364807277958288A89BA4C59BA6C6
9FAACA9CAAC79FADC8A1B1CAA4B4CBA5B5CCA6B4CEA8B6D1A8B6D3A9B7D4A8B6D3A8B6D3
A9B8D7AABBD9ABBCDAADBEDCACBDD9A9BDD8ADBEDAAABED9ABBEDCAABDDBAABFDCAABFDE
A7BEDDA6BDDDA7BEE0A7BFE1A7BFE1A5BDE1A5BDE1A4BCE2A3BBE1A3BBE1A3BBDFA3BBDF
A5BBE0A2B8DDA2B8DDA3B9DEA5B9DEA5B9DEA2B5DDA3B6DE9FB5DEA0B6DFA1B4DF9EB3DE
9AAFDC9AAFDC9BB0DD99AEDD97ADDC96ACDB97AFDF97AFDF95ACDE95ACDE94ABDF94ABDF
92A9DF91A7E08FA3DE91A5E08EA1DB8FA2DC92A3DB91A2D892A2D591A1D28F9FD08FA1CF
8C9ECE8A9FCE8C9ECE889CCE889CCE869CCE8499CE849BD1849BD18299CF7F94CB8095CE
7D93CC7D93CC7E94CE7B91CB7A93CC7891CA7A90CA778DC9788ECA768CC8758AC97388C7
7388C7758BC77488C57387C47587C57386C17184BF7285BF7083BD6B80B96D82B96C81B8
6D82B96B80B76A7FB6687DB46A7DB5697CB46A7BB16A7BB16879AD6677AB6474A86272A6
6778AC6475A96474A86272A66171A55F6FA35F70A45C6DA15D6EA25C6DA15B6FA2596DA0
566A9D566A9D54689A566A9C55699B556A995368955166915065905065905166914E638E
4E638E4F648F4F618F4F618F4F61914F61914D5F8F4D5F8F4D5F8F485D8C46588A45598B
465B8A465B8A40558442588740568540568544568440528040517F435180445082434F7F
424F7C404D79414E7A3F4E793D4C753D4C753B4A733B4A733A49703B4A71384A70394B71
36486E34466C30426831436932446A3042683140672F41672E40662F41672C3E662C3E66
2B3D63293B612C3E66293B612C3B622B3B5F2C3C60273759263657263755243352253451
25354F24344E283650223148223146233043222D3F212A3B
38332D3F3A343C3731443F3B473F3C49413E443A38443A383E373127201A3F36314D443F
332C246A635B837C74837C72736D617471626E6B5C6C6A5B676556646253858376B7B5A9
BDBDB3ADADA37B7B73605F5A73726E7675717D797A7975766A66656A64646D6865716C68
746F69747067706D646C6A5E606153595C4B5457465558455E614C6A6E5775796272745E
6F715C6A6C57787B68989B88C6CBB7B8BCAB676E5C4E5543878E7CACB3A19BA491404735
242819303425393B2E4E504355554954544855524954514854564B56584D53554A525648
525949525949535A48525947545B49585F4D54584A56594E585B5254554F4E4F4A52514F
555452565553595353585252564E4C544A485348465F5452655A586E63618F8583A79F9D
B6B0B0B4AFB3CAC7CEBBB9C49D9CAC5C5F725C5E77696E8B888EAE99A2C39FA9CC9EA8CB
A3ADD0A3B0D0A3B1CEA4B2CDA8B6D0A7B5CFA8B4CEABB7D1AAB5D1ACB7D3ADB8D4A9B7D4
AAB9D6A9B8D5A9BAD6AABBD7A9BDD8A7BBD6A8BBD9A8BBD9AABDDBA9BEDBA8BDDCAABFDE
A8BFDFA5BCDEA6BDDFA7BDE2A6BCE1A6BCE1A7BAE2A7BAE2A5B8E2A7BAE4A5B8E0A4B7DF
A5B8E0A5B9DEA4B8DDA3B7DCA3B7DAA2B6D9A2B6DBA2B6DBA0B4D99EB4DBA2B5DFA2B5E0
9EB3DE9CB1DE9EB0E098ADDC99AEDD98AEDF98AEE098ADE296ABE096ABE096ABE095AAE1
94A7DF92A5DF90A3DD90A0DB91A1DC92A3DB90A1D792A2D693A3D691A1D28E9ECF8D9FCF
8EA0D0899BCD8B9DCF8B9CD08B9CD28699D18396CE8497D18396D18194CF8093CE8191CD
7E91CC7B8EC97B8EC97C8FCA7B90C97C91CA7B8EC97A8DC8788AC8768AC77589C87488C7
7589C67286C37488C77387C67385C57183C17083BE6F84BD6C81BA6C81B86B80B76B80B7
6B80B56B80B56A7EB36B7FB4697AB0697AB06C7CB06C7CB06878AB6676A96774A86471A5
6575A66373A46370A46272A56272A36171A25F71A15C6E9E5B6D9F5C6EA05A6EA0586C9F
586C9F566A9D54689B54689B54689A54689A55679756689653659351669151648F4E638E
4E618C51648F4E618C4E608E4E608E4D5F8D4B5D8B4A5C8C4A5C8C4B5D8D47598B46588A
47598B47598B47598B455789425689445688415184455384445283434F7F424E7E46517F
434E7B414D77414D75414F763E4C713F4F733D4D713A4A6E38486C384A6E36486C36486C
35476B3244682F416730426832446A32446A34436A3140673042682E40662E3D662E3D66
2E3C632C3A612E3B652A39602A385F2B395E2B395E29375A263457263556263556253252
26345124324F24324D25334E26324C253149252D4420283D
43453A484A3F46463E47443D443F393D3832302B272D28243330292A271E363229423E35
3B372E615D52787469706C61605C5159574B514F435A5A4E5C5D4F444537606153A1A294
898B7D7D7F716F706269695D6F6C636F6C657A75727B7673625C5C655C5D6A6162706866
726A68716C6868656065625B5F5F555D5F52595C4B585D497378627B806A7F836C545742
494C39636655919385B0B2A5CCD0C2C3C9BD6A6D625E6156999F93999F93656B5F2F3529
2B2E2323261B393A3251524A50524750524752524A55564E56574F51544B4F524950564C
545A4E535B4E535B4C4F57484F5847535A4A56594E54574E55564E54554F504C49504C4B
5852545F595B655A5E63595A594F505347474F43436155557468687A6E6E7D7374837A7D
969197A09DA6ADABB88587966C6F82686E847B819B8990AD9CA5C4A0ABCBA3ADD0A1ABCE
A6B0D3A8B1D2ABB4D3AAB3D0ABB2CFACB3D0AEB3D1AFB4D1ACB1CEB1B6D3B0B7D3ADB6D3
ACB7D3ADBBD6AABAD4AABBD7AABED9A8BCD7A7BCD9A5BAD7A8BDDCA8BDDCA7BBDCA9BDDE
A6BADDA8BCDFA6BADDA9BBDFA7B9DDA9B9DDABBAE1AAB9E0A5B7DFA6B8E0A6B8DEA4B6DC
A4B6DCA6B8DEA5B7DDA4B6DCA4B6DCA3B5DBA2B4DAA1B5DA9FB3D8A0B4D99FB3D8A1B4DC
9FB2DD9CAEDC9BB0DF99AEDD9AAEE098ACDE97ABE096A9E196A9E195A8E096A9E197AAE2
96A7DF96A7DF93A4DC92A3D98FA0D690A1D78FA0D68CA0D58CA0D38A9ED18CA0D38B9FD4
8DA1D6879AD28699D38B9BD68797D38797D38696D28595D18393D18292D08492D18391D0
8290CD808ECB8190CB7F8EC97E8DC67E8DC67F8EC77D8CC57D8CC57B8AC37887C27686C1
7787C37386C17486C47486C47185C27084BF7084BF6E84BD6B82B66980B46980B4697EB3
6C82B46A7EB1697DAF697DAF6A7CAC697BAB6A7AAD6878A9697AA86879A76775A46573A2
6475A36576A46273A160719F6172A06072A060719F5C6D9B5B6D9D5B6D9D5B6D9D5B6D9F
5B6D9F596B9D56679B56679B56689A55679957679A57679854659354669452638F51648F
52638E51628D50618C51628E4F608C50618D4D5E8A4A5B894A5B894D5E8C4A5A8B48588B
47578A47578B49568B47548944538A44548844518644508444508044517E45527C45537A
445277425075414F724251723F4E6F3E4D6E3D4D6F3B4B6D374A6B394B6F384A6E34486D
364A6F34486D32466B31456A33476C31456A34466C33456B303F66324168303D672F3C66
313D65313D652D39612A385F29355B2A375A2B385B2A375A293659273457273457293356
263053253050242E51242F4F262F4E27304D252C48252B45
40473743473947493E43433937372D27271D20201823231B2E30252C2E232D2D233B3B2F
35352948483C5E5E525D5D5159574B49493D47473D51534855574C44463B66685B8D8F81
7274666C6F5E68695B68695B6B685F6C696275706C706B676A62606E6566706768706768
6A656269646169656261605B5C5D5562645964685A6A6E5F848879717564515443333625
51534586887DACADA5BEBFB7C3C6BFC7CAC38689827D807990938C6A6D6633362F32352E
2A2D2611140D3A3B364E4F494E4F494B4C4650514B55575251534E50524D494E4851564F
52595152595151594E50584D50584B525A4D53564D53564D53544E53524E534D4D504A4A
574E5161565A6A5F656C5F66584C5053484C53484C665B5F7E73777F7679817A817C7680
7C78867A77887A7B8F696B8261657E79809A949DBA9BA4C3A0ABCBA2ADCDA4AED1A4AED1
A9B2D3A8B1D2AAB0D0ABB1D1AFB4D4AEB3D1AFB2D3B1B4D3B0B4D1AFB4D1AFB4D2ADB4D1
ADB6D3AEB9D5ABB9D6AAB9D6AABBD7A8BBD9A8BDDAA6BBD8A7BCDBA7BCDBA6BADBA8BCDD
A6B9DAA7BADBA6B9DAA9B9DBA8B6D9A8B6D9ABB9DCA9B7DCA6B6DAA5B4DBA7B6DDA5B4DB
A1B3D9A4B6DCA3B5DDA3B5DDA4B6DEA2B4DCA1B3DBA0B2DA9FB1D79EB2D7A0B3DBA0B3DD
9EB1DC9DAFDD9CAEDE99ADDF98ACDE96AADD96A9E194A7DF95A8E096A7DF95A6DE94A5DD
95A4DD95A4DB95A4DB93A2D991A0D78E9FD58E9FD58A9DD58A9DD5899ED58A9FD8889DD6
8A9ED9869AD58799D78799D98695D68696D48493D48393D18392D38292D08290CF848FCF
818CCA838FCB838FC97F8BC57E8BC27E8BC27F8AC2808BC37E8BC27D8AC17985BF7A86C2
7786C17383BF7282C07082C07184BF7185C06C81BA6B81BA6980B4687FB3687FB3697EB3
6B7FB2677BAD687CAE687DAC6A7CAC687AAA6878A96676A76879A76576A46374A26475A3
6374A26374A26172A06172A06072A05D6F9D5F6FA06070A15E6E9F5C6C9D5D6D9E5B6B9E
5B6B9E58689B57679A57679A53639656669754649555659654659353649252638F50618D
4F608B4E60884F608B50618C4D5E894F608B4B5C884A5B87495A884C5D8B4C5A8B495788
49568A49568A4A558B47528845528747548845518545518345527F43507C435178425077
425075404E733E4C6F3F4D703E4C6F3C4A6D3B4B6F3B4B6F38486C384A7037497132446C
34476F34476F34466E34466C32446C32446C30426A34436C32416A32416A303D672F3C66
2F3B65313A632D39612D39612A365C2734572933572C365A2933572A3458283256263054
263054283055252D52232B4F252E4F252E4D262D49222842
414836484F3D45493A3337281A1E101115071E2116282C1E292F212B31232D312335392B
35392A494D3E5C5E51595B4E57574D4D4F445B5C5463645C67686064675E6B6E656E7166
65675C64665965655965655B66635A68655E6E696576716D726D6A76716E6E6966585350
5C58555D5C58605F5B65646063645F6668636F726B7679727B7E776667614B4C466D6C67
999894B6B5B1BDBCBAC7C7C5B6B6B6ACACAAA6A6A4797A7545464133342F31322D30312C
2728231516113232304A4A4850524F4D4F4A464843484A47494B48484A474449454F5450
4F55514B554D5057504F564F51585051585052554E51544D50514C4D4C48524C4C544B4E
52474D685D638378806C6169524650554B54554E56625B6377727987818B938F9D8B869A
656178625F7A696887676A8B7277978E94B4A1AACB9EA9C99EA9C99FAACAA2ABCCA6AFD0
ACB2D4ACB2D4ADB1D4AFB3D6AEB2D5B0B5D5B1B5D8AFB4D4AFB4D4AFB5D5AEB4D4B0B6D6
AEB7D6ADB8D6A9B6D6A9B8D7AABBD9A7BADAA7BCDBA8BDDCA7BCDBA8BBDBA7BADAA8BBDB
A9BAD8AABBD9A9BAD8ABBAD9A9B8D7A9B6D6A9B8D9A7B5D8A6B6D8A4B6DAA5B7DDA4B6DE
A1B3DBA2B4DCA2B3DEA3B4DFA4B5E1A3B4E0A1AFDC9EAFDB9EAFDA9EAFDAA0B1DD9DAEDC
9EAEDF9EAEE19CACDF99AADE99AAE098A9E197A8E097A7E295A5E096A5E095A4DF95A4DD
98A4DE96A2DC94A0DA92A1DA91A0D9909FD88F9ED78D9DD88B9BD7899CD78799D78698D8
889CDB8498D78497D98497D98395D78092D28092D48291D28292D08090CC8290CD8190CB
8490CA818EC5828FC4828FC47F8CC17F8CC17D88BE7F8AC07D8AC17B87C17A86C27984C2
7883C17785C47482C17181BF7083BE6F82BD6E81BC6A7FB86A7FB86C81B86B80B76A7EB3
6A7EB36A7EB1687CAF667AAC687AAC687AAC6779AB6476A86779AB6577A96374A86475A9
6273A76172A65F71A36072A46072A45D6FA15F6FA35F6FA35F6CA05E6B9F5F6CA05E6B9F
5D6A9E5B699A5A689958669556679553649256649356649355669253649050618F50618D
4D608A4D608A4C5F894C5F894B5E884C5F894D5E89495A86495B894C5D8B4957864A5887
4A588949578848548448548446528246538044517E44517E45527E44517B414E78424F79
4150793B4A733D4C753E4D763B4A753C4B763C49753D4A763B48743A4875394774354370
36457039487336457036456E35426E34416D313E6A313E6A34416D34416D2D3A662E3B65
2E3A642C38622E37602E37602E37602B345B2A335A2A335A273057273057253255222F52
233053242E52242E52222C4F242F4D242E49252D4422283E
5257435458473C402F202415181F0F13190B22281C2D33272C3425343C2D33392B373D2F
3E42334E5243686A5D60605654544A57574F7171697978737F807A7A7B7563645E5E5F59
61615961615963635B61615964615A6D6A656E6B66615E595F5C5768656054514C282722
43443F5F605B66676263645F6B6C6771736E7D7F7A7B7C776B6C675F605B878682CAC9C5
D9D8D4CECDC9A4A39FA3A29E8C8B896A6A686D6C6A5D5C5841423D3536313B3C37323230
2C2C2A2729283131314646464F5150474946494B484E504D5052514E504F464A494A4F4B
4A504C4B514D4D524C4E534D51585152575050554E4F524B494A444A4945514C49504A4A
6A61647D7477696065584E565A50593C353D625C667E788267646F807C8B948FA3706C85
544F6D615D7E67658A7D7DA39395BB9DA3C79FA7CB9EA7C8A0A9CAA3ACCBA5ABCDAAB0D0
ACB2D4ABB1D3AEB2D5AEB2D5AEB2D5AEB2D5AFB3D6AEB4D6AEB4D8ABB3D7AEB6DAADB5D9
AEB8DBACB9DBABB8DAA9B8D9A9B9DAA7B7D8A8BBDBA6B9D9A6B9D9A7BADAAABADBA8B9D7
A8B9D5A8B9D5AABBD5A8B8D2A7B7D1A6B5D2A6B5D4A7B7D8A4B7D8A5B7DBA6B8DEA0B1DC
A1B2DDA2B3DFA0B2E09FB1DFA0B2E29FB1E19EAEDF9FAFE09DAFDD9CAEDC9EAEDF9BABDC
A0B0E39CACDF9CACE09BABDF98A7DE97A8DE96A7DF94A5DD94A5DD94A5DD93A2DB92A1DA
93A2DB909FD88E9DD88F9ED98F9ED98D9CD78C9BD68C9CD88999D58999D78799D98698DA
8396D88295D78396DA8093D58193D58092D47F91D37F91D17F91CF8090CC8090CC7E8EC9
7F8EC77F8EC57F8EC57D8DC17D8DC17C8CC07C89C07A87BE7988C17887C27785C27984C4
7984C27984C27782C2717FBC7181BC6F7FBA6E7EB96C7CB7697CB66A7DB56A7DB5677AB2
677BB0697DB2677BB0667AAD6579AC6579AC6576AA6276A96475A96175A86172A65E72A7
5F73A85F73A85D6EA25D6EA25E6FA35E6FA35F6FA35E6BA05B669C5B679B5D699D5C689C
5A66985A68975A689757659255669253649058669357689453649052638F526391506290
51648F50638E4A5D884C5F8A495C87485B864A5B874A5B874A5B89465785485685495786
48568548558249568348558148538046537D45517B424E7846527C424E78424D7A424D7A
424F7B3E4B773E4B783E4A7A3B47773B47773C46773B45763C46773A44753B4576374172
39447237427038437136416E343F6C37426F323F6B33406C33406C3140692D3A662E3B65
2B38622B375F2C386029355D2C355E273057283158293259273057262F56262F56243056
273057262F56232D51222C4F242F4D242E49272F46232A3D
5457464C4F3E3B3F3025291B1D231521271B2D33292A30262F372A434B3C3F45374C5042
56584B6363577572696E6B646E69637974708E898595908D918C89645F5C3E39364C4744
5956515F5C575B57545A565363625E6D6C6759585339383343443C53544C393A32020300
20231C5E615A6D70696D6E6871726A7F807885877C7171677C7C7296968CBFBCB3EDEAE1
E4E2D68A887C514E4568685E5C5C5446463E5756515958534445403D3F3A3B3D3A333534
2E32313337383B3C3E4143424747474646465050505252525353535254534A4F4B484D49
4C514D4B504A4D50494F524B4E534C50564C4B514742483E42453C484B4253534B5F5C55
75706C67625F514B4B5D57596D676B3F383F645F66837D876E6874827B8B7C748B5D5773
666181726E8F8987AC9C9ABFA3A3C7A4A7CAA5A9CCA3A9CBA5ABCBA6ADCAA9AECEA9AECC
ACB1D1ACB1D1AFB3D6ADB1D4ADB3D7ADB3D7AEB4D8B0B6DAADB5DAADB7DBAEB8DCAAB7DA
ADBADDACBADDACBADDA8B6D9A8B8D9A7B7D8A9B9DAA6B9D9A5B8D9A6B9D9A6B9D7A5B9D4
A4B8D3A6BAD3A6BAD2A8BAD2A9BBD3A4B5CFA4B5D3A4B4D5A3B6D7A3B5D9A3B6DE9FB2DC
A1B3E19FB1E19BAFE19DB1E39CB2E49DB2E79DB1E49CB0E39AAEE097ACDB9AACDE9AACDE
9BABDE9CACDF9BA8DC9AAADD97A7DA97A7DA97A8DC94A5D990A4D78FA3D68FA3D88EA2D7
90A3DB8C9FD78A9DD58C9FD78DA0DA8B9BD68A9AD68898D48898D4899BD98597D78496D6
8496D68395D58395D78496D88092D47F91D18294D68193D57F91D17D8FCF7E90D07C8ECC
7C8FCA7C8FC97C8CC77A8AC57689C37689C37686C27686C27484C07484C07484C27583C0
7783BF7682BC7581BB727EB87380B7727FB6717EB56E7DB46A7BB16B7CB4697AB26879B1
677AB26477AF677AB26478AD6579AE657AAF6175A86278AA6175A75E74A55E72A45E74A6
5C72A45C70A35D6EA25F70A45D6FA15C6EA05F6FA25A679B5A669A5B67995C66995B6797
59669359669257669155648F52638E54659054659053648F51648F50638E4F618F4D5F8D
4F618F4B608D475C89465B88475C89485A88495A884A5B89485987475584475582485582
49568349548249548149557F4A537E46527A454E77454E7748517A444D78424A78424A78
434B7A3F47763F477841497A3F467A3E45793B42763A41753D43773A40743A4072393F71
384071373F6E373F6E353D6B353D6B36426C313E68303D672F3E67283A602B3A632C3B62
2A396028385C26345927355A28345A2835582832562B3559293259252E55242D54262F58
262D57262E55252D54252D52262F50252E4B252C4623293F
5D5E505151454446392F32271B211723291F2B3029292E27383E34484E444D5045626459
67675D6D6D6577726E7974707F77748179778E8684787272595353494343494343514B4B
5A55525A5552413B3B403C3B4F4E4C48474335342F27271F30312933352A36372F2A2B23
4C4C445F5F5765655D6B6B6179796F7C7C707D7B6F7E7C6FABA99CCAC8B9CECCBDB3B1A2
8583745E5C4D5957485B5C4E57574B51514557574D595A524D5049494B4640423F2F312E
2D31303236353C3E3D4446454B4B4B4B4B4B505050515151514F505151514C4E4D4B4D4A
4E504D4A4C474748424B4E4750554E5257504B5147383E34444A404C5248585B5464655F
605F5A4E4D484E4A47595554716D6E534E5269666D817E876B6775676374676279605C77
63607F8382A29D9DBF9F9FC1A3A3C5A4A7C6A6A9C8A6ABC9A6ABC8AAAFCCAAAFCCAAAFCC
ACB1CEABB2CFACB2D2ADB3D5AAB2D6ADB5D9ADB5DAADB5DAABB5D9ABB8DBABB7DDA9B7DC
AAB8DBA8B6D9ABB9DCAAB8DBA8B8D9AABBD9A9BAD8A7B8D6A5B8D8A7BAD8A5B8D6A4B8D3
A5B9D2A4B8D1A3B7CFA5B9D1A7BBD3A5B9D2A5B6D4A5B5D6A4B4D6A5B5D9A3B5DDA2B3DF
A2B3E19EB0E09DB1E39CB2E49BB0E59AB1E59BB0E59DB3E597ADDE96ACDB98ACDE99ABDB
97A9DB99ABDD99A9DC97A7D897A9D995A7D795A9DB92A6D890A6D78FA6D88EA5D78EA5D9
8CA3D98DA2D98BA0D98BA0D98A9FD8899CD6899CD6889BD5879AD48699D38699D48496D4
8496D48395D38395D38395D58092D07F91D17E92D17D91D07D90D27A8FCE7C90CF788DCC
7A90CC7A8ECB798DC8788CC7778BC6768AC57688C67486C47284C27284C27585C37383BF
7382BB7683BA7380B77481B6737EB4707CB0707CB06F7CB16A7AAE6A79B06A79B06C7BB4
6879B16376AE6679B16276AB6479AE647AAC6076A86076A75D73A45D75A35D75A35F77A5
5B73A15B71A25C70A25D71A35D6F9F5C6E9E5E6E9F5C6C9D5E6C9D5967965965955B6895
5C6B965B6A9555648D50628A50628A51638B51628D52638E4F628C4E638E4E618C4A5F8A
4C618C4C618C495E8B495E8B485D8A465B884B5C8A4A5B89485685495784495683495682
48558249548146527C48547E47537B46527A455177434F75444D76444D78454D7B3E4675
4048774048793D45763E457940477B3E45793B42763D45763B41733A40723C42743A4070
38406F38406F373F6E38406E353E69344068303E65303F662B3D632A3C62293B6126385E
283A5E27395D28385C27355A273558253356273457293357293259273057252D54262E55
262E55262E55272F54252D51283152262F4C232A441E263B
5D5D555959514F504832352C1318111D221B22241F32342F575A5360635C6465606F706B
74736F7372707872727872727F79797C76767E78786662635C58595652533D3938353130
4B4744403C392A26232C2827322E2D332F2C2F2C272E2B242C27213430274C483F534F46
655E566A635B6A635B6F6860736C62726C607D796DA3A091C7C4B59897856E6D5B504F3D
3E3D2B4546345152424F504056574954564956584D585B5255584F4F544D494C45454841
3A3F383B40394345404C4D4851504C4F4E4C4F4D4E4F4D4E514D4E5250514E4C4D4A4A4A
4D4D4B464644434540494B464B504A4950494D534F494F4B4F55515258544F5352505551
4E534F4A4F4B484A47494B4A6565656C6B706F6E766E6C77605F6D615F746868806F6F8B
898AA69FA3C0A0A5C2A3A8C5A2A8C2A5ABC3A8AEC6A7ADC5A9B1C6AAB2C7ABB3CAA8B3C9
A9B3CCABB5CEAAB5D1ACB7D5ADB8D8ABB5D8AAB7DAA8B5D8AAB7DAAAB8DBA9B7DAAAB8DB
A9B9DAA9B9DAA7B8D6A6B7D5A7B8D6A6B7D3A9BAD6A8B9D5A5B9D4A5B9D4A4B9D4A4B9D4
A3B7D2A5B9D4A6BAD3A5B9D2A7B8D2A6B7D3A8B7D8A6B4D7A5B3D8A5B3DAA5B2DEA3B0DD
A3B1E0A1B1E29DADE09CADE198AEE099AFE199B0E298B0E096AEDC95ACD895ABDA94ABD7
94AAD994AAD994A9D893A8D792A8D791A7D690A8D890A7D98DA7D88BA5D68AA4D78AA3D9
88A1D98AA0D98AA0DA899FD8889ED7889DD6859AD1879CD3859ACF8499CE8598D08396CE
8394CC8495CD8194CE8194CE7E92CD7E92CD7B91CD7B91CD798ECD778FCD7A8FCE758DCB
758DC9768FC8768CC6778BC6778BC87589C67689C47487C27386C17285C07383BF7383BE
7283BB6F7EB56F7FB36F7FB3717FB0707EAF6E7CAD6C79AD6C79AD6979AD6A7AAE6978AF
6776AD6576AC6377AC6074A96176AB6278AA5D74A65E76A65F77A55C77A25C78A05B779F
5A769E5B749D59709A59709A5A6F9A5B709B596E9B5A6C9A5A6B99566793556692576893
56679256689052648C51648C51648E4D608A4F608B4F608B4F628C4E618B4B618A4A6089
4A6087496187465D86485F88475D86465C854A5B87475884485683485683495683475481
47548046537F45527C45527C44537A435279455378425075435178414E783F4A783E4879
3F497A404A7D3E487B3D477A3C46793C46773C47753A457335406E39447237426F37426F
36426C35416B36426C35416B354167313F642E3E622E40642C3E62293D60273B5E273B5E
283A5E24365A24365A27375B27355A253358232F55253157253255243154283256242E52
252F52263053242F4F25304E27324E253149212C401A2537
68686063635B6060582B2C241619122D30292B2E27454640595A5467686370716C787876
767475747275787377847F837B767A4D4B4E6E6C6F82808360606244444626262631312F
3E3D3B3736322824212925222C282727232028231F201B1728211B6B645E685F5A645B56
6A615A6A615A6B605C685F5A5C534C615A508C857B958E847D796D595549514F403B392A
31322250514155564851534555574955574A575A4F575A4F56595054574E50534A4A4D44
42453C43463D494A4455544F52514D4D49464D49484D4749504C4D504C4D4D494A4B494A
4C4B4941423D40413C494B46494E484F54504F54504A504E4E54544E54544A5050494F4F
474C4F484D504A4F52454A4D6063686D70775C5F68555965585B6C5A5F727A7F959397B0
9BA1BB9FA7BEA1A9C0A0ABC1A1ACC0A3AEC0A8B0C3A9B1C4A7B2C4A9B4C6A7B4C7AAB7CA
A9B5CBA8B7CEA9B7D1A7B5D0A9B6D6AAB7D9A9B6D8AAB9DAABB8DBA9B8D9ABB8DBAAB9DA
AABBD9A7B8D4ABBAD7A9B8D5A8B7D4A7B6D3AAB9D6AABBD7A5B6D2A4B8D3A4B9D6A2B7D4
A2B7D4A3B8D5A2B7D4A2B7D4A2B5D5A2B5D5A3B3D7A5B4DBA5B3DAA3B0DAA3B0DDA1AFDE
A1AFDEA0B0E19EAEE19BACE09AAEE198AEE098B0E098B0E097AFDD96AEDA98AEDD95ADD9
90A8D690A8D68FA7D58FA7D58FA7D58FAAD78EA9D88CA6D789A5D589A5D787A2D786A1D6
869FD7849DD5889ED7899FD8889ED7849BD18499CE869CCE8298CA859BCD8599CC8094C7
8293C77F90C48094C98296CB8196CD7D92CB7B91CB7992CB778FCB798FCB7A8FCE768ECA
778FCB758EC7748AC6748AC6748AC67589C6778BC67589C47185C07386C17386C07184BE
7081B96D7EB46D7EB46E7FB36C7EB06C7CAF6D7DB06B7BAE6979AD6878AC6978AF6776AD
6978AF6675AC6475AB6074A96175AA6076A85F75A75E76A65E76A45B739F59759D5A769E
5A739B5A739B5970995970995B709B5A6F9A566B96546994566994556893556893566993
54679153669051648E52658F5366904F628C50618C51638B50638B4E62874B5F844A6085
4B6284495F84495F84495F86495C84495C864A5B874A5B894957864A58874A5686445281
44527F44527F45547F41527D42547C43557D3F51773E507641507941507B3F4C793F4B7B
3D4B7A3C4A793E4A7A3B47773B49783A487538477237467136457035446D34436C34436A
344269313F64334168354368334166313F622F3F612F3F632F3F63293B5F293B5F283A5E
27375B243458233357243458263459253358253157263258222E54243154263356222F51
253254233050212F4C23314C22304A2130451C293C1B2839
5F5F5354544854524634322633332735372A3133264040364040365E5E5673726E787775
7371747674798582898281895D5D653C3F4662656C6A6D7252555A494D50393A3E343537
34343230302E2C2B272E2A272A262327221F2C2421251D1A443A386E64626B5F5F695D5D
564A4A473B3B5248495248473E36344D45425F57545E56535C5753484540423F38302D26
2A2A2050504657594E585A4F56584B55594B57594E585B5256595050534A4F50484B4C44
45464041423C49494159565154504D4B46434F4647483F404A44444943434D4747504C4B
524F4A4B484343403B47464150514B55565152545150524F5254534E5253474C4F44494D
40474D464D55474E56484F574F5660535965535B68525969616A7B7A8394979FB49CA4B9
9CA7BD9FAABE9FAABE9EABBCA3B0C1A3B0C0A5B2C2A5B2C2A4B4C3A4B6C4A6B6C6A7B8CA
A7B8CCA8B8CFA8B8D1A8B8D2AAB8D5ABB8D8ACB9D9AAB7D7ABB5D8A9B6D6A9B3D6AAB7D7
A9B6D6A9B8D5AAB8D5AAB8D3A8B6D1AAB8D5A8B6D3A9B8D7A7B8D6A5B8D8A4B8D9A2B9D9
A0B8DA9EB6D89DB5D79FB7D99DB5D99CB4D89DB3DCA0B5E0A0B3DEA0B3DE9FB1DF9DAFDF
9BADDD9AAFDE98ACDE98ACDE97ADDE97ADDE98AEDF97ADDE96AEDE97AFDD94ACDC92AAD8
8FA7D78DA8D78DA8D78AA6D58DA9D88BA7D689A5D589A5D589A3D689A3D687A0D6869FD5
85A0D585A0D5839CD2839CD2869DD3839ACE8499CE849ACC8399CA869CCD8397C98094C6
8296C87F93C57E92C48094C77D92C77C91C67B92C87A90C9788EC87A8EC9798DCA788CC9
778DC9758BC77489C87187C37389C57389C57389C37187C07086BF6F85BE7085BE7085BE
6F82BC6E81BB6C7FB96C7FB9687BB36A7BB36A7BB36B7CB46879AF6778AE6778B06576AE
6877B06776AF6776AF6172AA6172AA6073AB6276AB6175A85E72A55D73A45C71A05C71A0
596E9B5C719C5B709B5A6F9A5C6E9C5B6D9B586A98586A98546996536895536895536895
56689655689355669255669254679150638D50638B4F63884E62854E62854C60814C6081
4C60814A5D7E495B814E5D864B5D854C5D884E5C8B4C5A8B4B588C49568A48558A435084
45538444548543538443548242537F4255803B4E783D50783E4F7A3D4E793B4C783C4D79
394A76394A763B4C783A4B77384B76354872384B7537497135476D35476B334569314465
344466304062354366344265323F623340632F3D62303C64303C642F3B632F3B632E3A62
26345B26345B27355C28365D26345B28345C243259243257202E53233156223055233154
2332532332511E2D4A1F2F491E2E451E2D401C2C3C1C2C3B
5050444E4E424543373533273E3C2F3634272C2A1D36342834312867645D73706B6D6968
696566807E83918E95807F875659624D505955585F55585F585B604E52553B3F42313234
2A2A2A2626242827232A262325211E25201C251D1A322A275C54517A706E6E64634A403F
281E1D291F1E33292A3128292C272435302D3E3936403B38413D3A35312E332F2C31302C
2A29244C4D47575852595A52575A51575A51595A52595A545558514F504A4A4B454A4944
46474143443E4645404F4C474C48454B4643484242413B3B403C39433F3C464241514C49
55504C514C4843403B504D485857525B5C575D5D5B5E605F545655494D4E44494D43484E
3E454F464C58464E5B454D5A4950605D6476666D80646C7F7B839695A0B49BA3BA9BA3BA
9CA7BD9DA8BEA1ACC0A1AEBFA3B0C1A4B4C4A2B2C2A4B5C5A2B3C3A5B8C7A6B7C9A7B8CA
A5B7CBA6B8CEA9B9D2A7B7D1AAB8D5ABB9D6ACB7D7ACB7D7ABB6D6ABB6D6AAB5D5A8B5D5
A8B5D5AAB7D7A9B7D4A8B6D3A8B6D3A8B5D5A7B4D6A8B7D8A6B6D8A3B6D7A5B9DEA0B8DC
9CB4D89EB8DD9CB6DB9DB7DC9BB5DA9BB4DC9BB2DC9BB2DE9CB1DE9AAFDC9AAFDE99AEDD
9AAFDE97ABDD96ACDD97ADDF95ABDD95ABDD94AADB95ABDC95ADDD95ADDD92AADA92AADA
8FAAD98DA8D78BA5D68BA7D78CA8D888A4D488A4D488A2D587A1D486A0D387A0D6859ED4
859ED4859FD2839DD0849ED1829CCF8299CD8299CB8198CA7F97C78098C88096C77F95C6
8197C87C92C37E94C67C92C47A90C27A8FC47990C6788EC7798EC77A8EC9798BC97587C5
768AC7758BC77387C47187C37187C16F88C16F85BE7087BD6E84BD6C83B96F84BD6E83BC
6B80B96B80B9697DB86B7EB8687BB5677AB46679B36578B26477AF6275AD6677AF6475AD
6675AE6675AC6675AC6372A96372AB6473AC6372A95E6FA55E6FA35F70A45E70A25D6FA1
5D6F9F5D6F9F5B6D9D596B9B596B9B5A6C9C566898576999566896536895546696536595
54669454669454659353669153669051648C52658D4F63864D61844E62834B5E7E4D6080
4C5F7F4C5C7E4D5B804E5C834B5A834D5C874C5A874B57874753854C588C49548A465187
4451854350844451854151824152803F507C3D4E793E4F7A3D507A3C4F793A4D77394C76
384B75374A74394A75394C76364C75364C75384B73364A6F35496C3347683345692F4263
3144652F4263334164313F622F3B612F3B612D39612E37603039643138643039622F3861
2C355C2B375D29355B273359253157263258273359243257213155213155223256213153
2232531E2F4D1D2C4B1C2C461E2E451F30421A2A3A1A2A39
494A424E4E4647443D403D344543373834292723182A261D39352C68635D706B676A6562
7D7777908C8D908B8F828085706F756B6C715B5C614F50544C4D513C3D3F2B2C2E242426
24242426252328242128242123201B201D18312C2858534D6A655F554E4828201D170F0C
1C150F221B152019131E191328231D312E2736332E36353034332E2F2E292F2E2932312C
3637314849435556505C5D585F605B5B5C575758534F504B4E4F4A4E4F4A464742464742
494A45494A454A4B464B4A464948464847454443413C3B393B3C373B3C3741403C4C4845
514D4A54504D4C48455753506A696570706E7777757B7D7C616264383C3F3E434940474F
4147534A505E4B506344495D464B6183889E8A8EA78589A2969AB59FA3C09DA1BEA0A4C1
A0A5C3A2A7C4A3AAC4A4AFC5A5B0C6A5B2C5A3B2C5A2B3C5A3B4C6A5B8C9A2B4C8A4B6CC
A7B9CFA7B9D1A6B5D2A8B6D3A8B6D3A9B7D4AAB5D5ABB3D7AAB4D7ACB6D9A9B6D8A7B4D6
A8B5D7A6B5D6A7B6D7A7B6D7A6B4D7A5B3D6A6B4D9A6B6DAA4B3DAA1B3D9A2B5DF9EB5DE
9DB4DD9AB3DB9CB5DD9BB4DC9AB3DB9CB5DE9CB3DF9AAFDC9AB1DD99B0DC98ADDC99ADDF
98ACDE97ABDE93A7DC96AADF95A9DE94A8DD93A9DB95ABDD92A8DA93A9DB93A9DB92A9DB
8EA8D98CA6D78CA6D989A3D68BA5D887A1D487A1D4889FD3869DD1849BCF879ED2849BCF
859CD0869DCF839ACC819BCC809ACB809ACB809ACD7E98CB7F99CA7C96C77E95C97E95C9
7C96C97B95C87C93C97C93C9788FC57990C6798EC5798EC7798CC6788BC67688C67688C6
7487C27589C47588C27287C07388C16F86BC6F84BB7085BA6F84BB6D82B76D82B96D82B9
677CB3687DB4687BB56A7DB7677AB26679B1697AB2697AB26778B06576AE6372AB6978AF
6776AD6575A96774A96572A76471A66673A86572A7606DA2616EA36171A56070A46070A4
5C6DA15C6DA15A6B9F596A9E576B9D586A9C57699B59699C576798556797576798556797
52649252649251648F51648F51648E4D638A4E61894F63864C60834A5E7F4C5F7F4E5E7F
4E5E7F4C5C7D4D5B7E4C5A7F4A587F4A57814956804A5582485381495384495386475186
495386454F82434F81414D7F42507F414F7C3F4E793E4D783C4E763B4D753B4D75394B73
394B733A4C743B4A73364870374971364971384A72384A7233476C32466932466B304469
33456B30426A313F662D3B622F3B652E3A64303962313A632F38632F38612E365D2F375C
2E365A2D375A2C36592A34572832562532552633562533562434562232541F31551F3253
2134542132501E2D4C1C2B481E2D441F2E411F2C3D202D3D
42443F4A4C4748494342423A47473D3E3B322B281F25221B38332D5B565266615E7A7474
8D89888D898A837E827775787473786E6D7259585D5252544040422B2B2D222224252525
25242224231F2723202B2823221F1A2D2822504B4566615B4B464026211B211C1617120C
1C17111F1C131D1A13201D1425221927271D33332B3B3C343A3B3332332B32332B33342C
3639304B4E4553564F5B5C565859545859545556514A4B464A4B464B4D48464644464845
494B484B4D4A494B48464845484A47484A454547423A3C37393C353B3E3744453F494843
4F4E4952514D504C4B5F5E5C7878767F81808F91908F93947E8285383D413A4147444B53
4349554A505E4A4F62454A5E454A608B8DA69394B08E8DAC9998B8A1A0C0A3A2C2A3A3C5
A3A3C5A2A5C4A5AAC7A4ABC5A7AEC8A6B1C7A5B1C7A7B3C9A4B3C8A4B5C9A4B4CBA6B6CD
A5B5CEA7B5D0A6B4D1A7B4D4AAB5D3ABB6D6ABB5D8A9B3D6A9B3D6A9B6D8AAB7DAA8B6D9
A7B5D8A5B5D7A5B5D7A6B6D8A2B4D8A2B4D8A3B5DBA4B6DCA4B6DEA1B4DCA1B4DE9FB5DE
9DB4DD9EB5DE9CB3DC9CB3DC9BB2DB9CB3DD9BB0DB99AEDB98AFDB98AFDB99ADDF9AAEE0
97ABDE98ACE193A8DF96ABE294A9E294A9E094A9DE93AADE91A8DC94ABDD90A7D991A8DA
8FA9DA8DA7D88DA4D88CA3D78CA3D789A0D48AA1D589A0D6879CD1839ACE859ACF849BCF
869BD0879DCF869BD0849BCF829CCF809ACD8099CF7E97CD7F98CE7C97CC7D96CC7C95CB
7C95CD7A93CB7A93CB7C92CB7C92CB7A91C7798EC77A8DC7788BC5788BC67888C67688C6
7588C37689C37588C07184BC7588C07285BD7184BC7286BB7083BB6F83B87184BC6E81B9
6B7EB66A7DB56A7AB56C7DB56879AF667AAF6778AE697AB06778AE6879AF6776AD6777AB
6676AA6474A76875A96775A66573A46472A36470A4636FA3626FA36370A46070A35E6EA2
5E6EA25A6B9F5B6B9F58699D58699D596A9E58689C57679A586899576798546495556596
55669451629051628E5265905265904E618B4E61894F63884B5F824C5E824E5E804D5D7F
4F5F814D5D7F4B597E4A587F4A587F4C59834B58824A57814954814954824B5384495182
4B5384485081464E7F444E7F424F7C3F4C78424F7B414E78404F78404F763E4D763B4A73
3C4B743C4B743A497436477237487336477234477135487032456D31456A31456A2D4166
30426A2E4068303F682D3A642F3A672F3B65303964303962313A653039622F375E30385D
2F375B2C35562E37582934542731542832552633562331542533562232562131551E3152
2030511D2E4C1E2D4C1D2B481D2C43212E411E2B3C1C2838
404642444A46494E48444942484E443D40372A2D241A1D163E3F39676863767674888888
82828278787A7373757171736A6A6C5657594546483F40422D2E30252726252525282826
24231F201F1A25221D2C27212F2A244A433D4A433D322B2527221E1A15111E1B161F1C17
1D1A151B1B131D1C171E1E1620201822231B373830494A42494B403D40353B3E33393F33
42483A50564855584D56594E55584F54574E4E514A4A4C47494B46454A44474946484D49
4C514B484D47444943444943484D47454A433F443D393F353B41353F453943463D474840
4E4F474A4B4551504C71716F8282828E8F919394988A8E9171767A2D35383E454B474E56
464F565059625359675C62726C6E839A9AB2A09DB89F9CBBA49EC0A9A3C7A8A4C7A8A4C7
A8A7C9A8A8CAA9AAC9A7ABC8A9ADC8AAB0CAA7AEC8A9B0CAA8B2CBA8B2CBA9B3CEAAB4CF
AAB3D0A9B2CFABB4D3AAB5D3ABB4D5A9B4D4A9B3D6AAB4D8A6B3D5A7B6D7A9B7DAA6B6D8
A4B7D8A4B7D8A2B6D7A2B6D7A1B5D8A0B4D7A1B5D89FB3D6A1B5DAA0B3DBA0B3DB9FB2DC
9FB2DC9CB1DC9EB1DC9EB1DB9BB1DA98AED79AB0D998ADD897AEDA95ACD896ACDD95ABDC
96ACDE96ABE095ABE492A8E194AAE490A6DF92A8E18FA8E08FA8DE8DA7DA8DA7DA8CA6D9
8BA5D689A3D48AA1D38CA2D48CA2D4899FD18A9FD4889DD28699D1869BD28497CF8297CE
8598D08498CD8497CF8497CF8297CE8196CD8196CF7F95CE7D96CE7C95CD7E94CD7C95CD
7A93CC7A93CC7B91CB7A8FC87B90C97B90C97B8EC97A8DC87989C57787C37785C47888C6
7787C37686C17687BF7485BD7485BD7283BB7384BC7283BB6F7FBA7081B97181BC6E7FB7
6E7FB76D7EB66C7BB46A7BB3697AB0697AB06675AC6878AC6878AC6878AC6777AB6575A8
6575A86575A66876A76775A46273A16371A0636F9F5F6B9B5F6D9C5E6F9D5C6C9D5C6C9F
5E6EA15B6B9E5D6A9E5A6A9D59699C58689B58659959669A566697576798596796556392
57659454629153619052638F51628E50618C4F61894F61894E60884C5E86505F864C5C80
4F5D844E5C834D5C854A59844756814958834A598449588348558245527F46517E47527F
48547E49527D49517F474F7D424B76404C76424E78424E78434F79424E78404D793E4B77
3E4B783A48753947763647753A4B7734477234497433497230466F2F456C2E44692B4166
3044692F41672F3E65313F662E3B65313D67313A652F38632D365F2F38612E375E2D375B
2F395C2C36592A3457273154293356253254253255212F54223055223256203054223254
2231521E2D4C212E4E1F2A461F2B43212C42222A3F1D2538
424844454C45484D46484E4452584E454B412B3029191E183A3F39777C789294937E7F81
76777971727469696B656567545557444547393A3C3638372B2D2C1F211E232321282924
27262122211C322F284F4A443E3A31322E253029231D18121D18141F1C171E1B161B1A15
1C1B161819131A1B1520211925261E23241C32332B4A4C414E50454A4E404A4E40484C3E
4D5444535A4A54584A4F53455052454F52474A4B43474A43484A45464B45464B47494F4B
474E47424942404740434A42474E4641493E3C4439363C30363C2E41473946493E53564B
5758504A4B4348494471716F979998A4A8A990949763686C444C4F373F42474E54475057
4A535A505962575F6A6F7583898C9F9D9DB5A09DB8A4A1BEA8A2C4A8A2C6A8A2C6ABA7CC
AAA9CBABAACCACACCEADAECDABACCAABAFCCABB0CDA9AFC9AAB1CBAAB1CBAAB1CDABB2CE
ACB3D0AAB3D0ACB5D4A8B3D1AAB5D5ABB6D6A9B3D6A7B4D7A6B4D7A5B3D6A8B8DCA9B9DD
A4B6DAA3B7DAA3B7DAA0B6DBA1B5DA9EB4D9A0B4D99FB3D8A0B3DBA0B3DB9FB1D9A0B1DC
9CAFD99DB0DB9EAFDB9EB1DB9CB2D999AFD697ADD699AED995ACD896ACDB96ACDD95ABDD
95AADF94ABE193A9E292ABE492A8E290A6E091A7E18EA7DF8EA7DD8FA8DE8FA6DA8DA4D8
8CA3D58CA3D58BA1D3899FD18CA2D4889ED08A9ED3889CD18699D18699D18699D38396D0
8295CF8396D08595D08595D08093CD8194CF8093CE7F93CE7E94D07C92CC7D93CD7E94CE
7B91CB7C92CB7B90C97A8FC8798EC5798EC57A8DC77B8EC87888C37787C27787C37686C2
7888C47888C37686C17687BF7585C07080BB7483BE7281BC707FBA6F7EB96F7EB96E7DB6
6F7EB76F7EB56C7BB26B7AB16A7BAF697AAE6676AA6575A86777AA6474A76777AA6575A8
6474A76474A76673A76373A46272A36272A36270A1616FA05D6D9E5C6C9D5A6A9B5B6B9E
5D6A9E5E6B9F5D6A9E5C699D59669A5A669A5A669A59669A5866975B699A596595586494
596595556191535F8F535F8F556191515F8C4F5E894F5E894E5D884F608B505F884A5982
4C59834D5A844D5C874B5A8549578448568347588447588445538043527D44517B47557C
46547B46527A48517A4A537E434F77404C74404C74424E76414D77404B783E49773B4875
3B47773A46763745763747783749793648763348753249732D446E2C436C2C42692B4166
3044692F41653141652E3C61324067303E65323B643039622C355E2B345B2B345B2C355C
293659293659273155293357283558253157273359233158212F562230571F2D52223053
2130511C29491F2A4A1D2844202A43242C4322283E1F253B
464C424A504650534A5659505E615861645D4A4C474547446F7470818584797A7C6F7074
7475796A6B6F6161635252544040403030302D2D2D35353530322F1C1E191C1D172B2A25
34342C33332B4340394E4B442F2C231E1B121E19131C1912201D161E1E16191813161711
191A12171A111A1D1420231A2728201F21162A2A2046463C4F5146525447505245515345
5052445355474D4F41484A3C4A4B3D484A3D484840494A444B4D48474C46484D49494F4B
464C48404A42414B433F494040473F3D453A3E443A373A2F40443645493B484A3F66685D
66685D5F605860615C71716F939594A6AAAB777B7E494E523D45483E474C444D544E575E
646D76636D777B85918990A0959CAE999EB4A1A3BCA3A4C0A3A2C1A7A6C6A9A8CAA9A8CA
A9A7CCACAACFACAACFADADCFABABCDABAECDADB2D0ABB0CDA8AFCBABB2CEA8B1CEA6AFCC
AAB4CFA8B4CEA8B3CFA7B5D0A6B4D1A7B4D4A6B3D5A5B3D6A6B4D7A4B4D8A4B2D9A5B4DD
A3B4DFA2B3DEA4B5E0A1B4DFA2B3DFA0B3DEA2B3DFA0B1DDA0B1DCA1B2DD9FB0DB9FB0DB
9DAED99CADD89BAED89DB0DA99AFD699AFD698AED797ACD795AAD795AAD995A9DB92A8DA
93A8DD92A9DF94AAE393A9E293A9E290A6DF8FA5DE90A6DF90A7DD8FA6DC8EA3D88CA1D6
8CA2D48DA1D48A9ED18B9FD4889CD1899DD28C9DD58598D08699D1869BD28598D28295CF
8696D28393CF8393CF8393CF8393CF8294D27F91CF7E90CE7C90CF7C90CD7D91CC7C90CB
7C91CA7A8FC67A8EC37B8FC4788CBF778BBE778BC0788CC17589BE768ABF7588C07487C1
7285BF7285BF7285BF7285BF7383BF7080BC7280BD6F7DBA6F7EB96F7EB96F7BB56E7AB4
6D7CB36C7CB06B7BAF6B7BAE6A7AAB6878A96A7AAB6777A86777A86474A56676A96575A8
6471A86572A96271A86170A76271A86172A86170A75F70A65F70A65B6CA05C6DA15C6DA1
5B6B9F5E6BA05B689D5C679D5B669C5C659C5A639A5B659A5A6497596597576192576192
586391576290535D8E535D8E535D8E515D8D4F5B8B4F5D8C4F5D8C4F5D8A525F8C4C5985
4C59834B58824A57814C598349588347568147568146558042537E40527A46557E45547B
46557C44527942507745537A4251783E4D743E4B753F4C763F4C763F4C783E4B783C4878
3B47773945753846773646793547793547773146753045742C436D2E456E2C42692C4267
2F43662F42632F3F602D3D5E2E3D5E2F3D602E385C2D365D2F385F2B345B2B345D2C355E
2B345F27305B262F5A27335D24315B24315B25325C23305A202E55233158212D53212E51
1F2C4E202D4D212C4C212A47252C462129401F253B20253B
42453C4A4D4456574F5C5D555F605862635D6E6E6C73757478797B727375727176747378
6D6C715F5F615A585B403E3F32312F2B2A282D2C2A34332F36373210110B11110935352D
40403844443C4B48412D2A2317170F2020181F1F171F1F171F1F171B1C14171812181913
171A13181B141F221B23261D22231B1F201832322A4C4C424F514655574A525246515145
50504445453941413548483C4A4A3E47473B47473F4C4D474D50494A4F49454C45454C45
444E46414B4340473F424A3F41473D3A4034393C314143364A4A3E48483C5D5D517B7B71
80807676776F73746E83847F969895838786545A5A4C54564F595B4D565B3A434A5B646D
8A929D79838F8891A0939CAD969DB0979DB39FA5BDA1A5C0A3A7C4A4A7C6A6A6C8A8A8CC
ABABCFACACD2ABABD1ACACD2ABAED1ABAED1AAAFCFA8AFCCA7B0CDAAB3D0A7B2CEA7B2CE
A6B4CFA6B4CFA5B3D0A4B3D0A4B3D2A5B4D3A6B5D6A5B3D6A5B5D9A3B3D7A4B3DCA3B2DB
A1B2DDA2B3DEA2B3DFA0B1DDA2B3DF9FB0DCA0B1DDA0B1DDA0B1DD9DAED99DAEDA9DAED9
9DAFD79BAED69AADD79AADD799ACD498AED598AED797ACD794A9D695AAD998ACDE94AADC
95AADF93AADE93AAE093A9E291A7E08EA4DD8EA4DD8FA5DE8EA4DD8FA4DB8DA2D98EA2D7
8CA0D58A9ED38C9DD58D9ED68A9DD58598D28A9AD58999D48598D08598D28696D18494D0
8595D38595D38694D38494D28494D28393D18291D27E90D07F91CF7E90CE7F92CD7B8EC8
7B8EC67A8FC47A8EC1778DBE778DBE758BBC768CBD7589BC7589BC7589BC7388BD7186BD
7184BE7083BE7285C07284C27181BF6E7EBC7080BE6F7DBC6E7CB9707EBB717DB96E7AB4
6F7CB36C7CB06878AB6C7CAD697AA86778A66879A76777A86676A76575A66575A86474A8
6271A86271AA606FAA5E6DA85F6FAA6070AB5F6FAA5F70A85F70A85C6DA35A6BA15A6A9E
5A6A9E5B689D5D689E5A659B5B649B5B649B5A639A58629759659757639356609156618F
56639054618E535E8C515C8A515B8C505C8C505C8E525E904F5B8B4E5A8A505C8C4F5C89
4D58854A57834954814B58824A57834756814756814857824455803F517942547C41537B
40527A40527A41537B3F517940527A3C4E763D4C753C4B743B4A733D4C773B49763B4978
3A46763A46763846773845793646793345773345772E43722E43703045702C426B2A4067
2C4063273B5C2C3F5F2C3C5D2C3C5D3040612C3A5D2A375A2C395C2A375A29355D29355F
2A366026315E29346128336025325F23315E25325F23305C23305A23305A212D55202C52
1F2C4F1E2B4D1F2A4A202948212B441F273E191F351A2036
494B465355505D60595D605966676173746F7C7C7C7E7E806F6E736C6A6F716C72686367
5D585C4D494A4B47483E3A392D29262825202C29222B2821221F180F0C0514110834312A
413E373C39342F2F271919111718101D20191C1D17191A14191A141A1B151718131A1B16
1A1C171B1D1823252028292426282324272032332D4B4C4450524753554A5353494F4F45
46463C36362C38382E46463C46483D43443C46473F484B44464B44454C44434A42414840
4148403F473C3F453B40463A4043383D3F323D3D314341344844384A463A645E5289857A
9C99908C8C847E7D787D7E79797B78646867454B4B4B5355535D5F525B623F485168707D
9DA4B48B92A48B93A6949CB198A0B79AA1BB9EA5BFA2A7C4A2A7C5A5AACAA5A8CBA6A8CE
A9ABD1A9ABD2A9ACD5AAADD6A7ACD2AAAFD5A7AFD3A4AFCFA3B1CEA5B4D1A4B3D0A4B3D0
A4B3D0A4B3D0A3B2D1A2B3D1A2B2D3A4B4D6A4B4D6A3B3D7A4B4D8A4B4D8A2B2D6A0B2D6
A2B4D89FB1D5A0AFD6A2B1D8A2B4DAA0B2D8A0B2DAA0B2DA9DB0D89AADD59DB0DA9CAFD7
9BAED697ADD496ACD598ABD598ABD398ABD396ACD596ACD595ACD693AAD694A8DA93A9DB
92A7DC91A8DC8FA8DE8EA7DD8DA6DE8EA7DF8CA5DE8DA6DF8BA4DD8DA3DC8AA0D98CA1D8
8CA1D8889DD48B9ED8889BD5879AD48699D48A9AD68896D38696D18595D08795D28896D5
8593D28694D38691D38492D38492D38392D38191CF8090CE7D90CB7B8EC87D90C87B8FC4
7B91C37890C0778DBE768EBC758DB9778FBB758DBB7288B97288B97288BA7186BB6F84BD
6F82BD7383C17082C27284C66E80C26D7EC36E80C26D7CBF6E7BBF6E7CBD6F7ABA6F7AB8
6E7AB46E7BB26979AD6777A8697AA86677A56677A56576A46474A56575A66676A96272A6
6172A85F70A8606FAA606EAB6070AC6070AB5D6CA7606FA85C6BA25C6CA05A6A9D5C699D
5A679B5B689C5D699D5C669B5A669A5B679B57649855629655659655669453649052638E
53648F4F608B51608B53608C505D8A515E8B525E8E4D59894D59894E58894E588B4F598C
5058894A55834E56854A558249568349568346548146558045568141527D41547E40537E
40537E3E517C3F527D3C4F793C4F793C4F793C4D783C4D783B4A753C4B763C4B763A4875
3846733846753945753846773644753545763444773141743242732F416F2E416C2C3F69
293F66293D62273B5E263A5D283C5D2A3E5F293C5D283B5C2B3B5C26365825335827355C
28365D26335D26335F27346024325F22305F24306023305D222F5C222F5C1D2A56202D57
1D2B521D294F1E2B4E1E29491E2A441D283E1921361D253A
545655575958595B58696B6885858386868678767978767B746F766A656C635C635A5156
4B42473C363836303035302D322D291E19131D19101F1B1218140B17140B1D191029261D
292621201F1A1D1C171B1C161C1F181D1F1A191B16191C151518111518111D1E181F201A
1F211C1F211C2424222929272B2C27242621383A354B4E474D4E464B4C444E4F474F5048
3E3F373738303E3F3742433B46473F42453C40433C3F423B3D423B40473F414840424A3F
3F473C3C42363F42373F43353D3F323C3E3041423445433449433548423461594E807A6E
87837A7B78716E6D686464625759565157554D56554E585A4C575B59636C676F7C8A91A1
A0A7B999A1B498A0B79BA3BA9FA6C0A0A7C3A1A8C4A4ABC8A6ADCAA9AFCFA7ADCFA5ABCD
A9ADD2AAB0D4ABB0D6A8B0D5A6AED3A5AFD2A5AFD2A5B2D2A3B2D1A3B4D0A5B4D1A4B5D3
A4B3D2A2B2D3A3B2D3A5B5D6A2B2D4A3B3D5A2B2D4A3B3D5A2B2D6A3B3D5A2B2D4A0B3D4
A2B2D4A1B1D3A2B2D6A2B2D6A2B2D6A2B4D89FB1D79FB1D99DB0DA9FB2DC9FB2DC9DB0DA
99AFD898AED799AED998ABD699AAD699AAD598ABD695AAD596ABD694A9D493A8D793A7D9
91A7D990A7D991A8DC8CA6D98DA6DC8DA6DC8DA6DE8AA3DB89A2DA89A2DA8CA3D98AA1D7
8BA0D78A9FD8899ED7869BD48699D38497D18898D48998D38796D18897D28792D08893D1
8792D08893D18691D1848FCF8590D08492D1818FCE7E8ECA7E8EC97D90C87E8FC77A8EC3
7A90C2768EBE778DBE768EBC768EBA748FBA748CBA738BBB748ABB7288BA7287BC7083BD
6F7FBB7383C16F81C17082C46D7EC36C7DC26C7EC06E7DC06F7EC16E7BBF6D78B86C77B5
6E7AB66C7BB26A7AAE6979AC6777A86879A76576A46475A36676A76676A76676AA6172A6
6273A96172AA6271AC6271AC6070AB5E6EA95C6BA45B6AA15C6CA05D6DA05D6B9C5B6998
5C6A995B69985C689A5A669859679858669755659651639153659354679253669053668E
51648C50628A516089516089505F88525F89505D894D5A864D58854E5987505889505889
5058874B56844954824853804A578447568148568346578243547F4457814255803E537E
3E53803C517E3E507E3B4E793D4F7D3D507B3E4F7D3D4E7A3B49763B4A753B49763B4976
3946733A477439457538447438467536447536447534427330416F2D3E6C2E3F6B2D406A
2A3D652B3F642A3C62293B5F273B5C283C5D293D5E273A5A273A5A263959273759273759
27375B26365A25345B24335C22315C21305B24315D222F5B222F5B222F5B1E2B57202D57
1D2B521D2B501F2D521A27491A28431B273F19243A1A2237
5054555051537172747E7E807E7E8078787A6E6C716F6A716E676F5C525B4B3F49463B43
453A4030272A241B1C211C19201B171A171017140B14110812100419190D221F16212117
1C1B1611120C151611151712181A151B1D18191B16161B14151A1315180F1F2018202018
20211B23241E2726222726222E2D2B3232303F3F3D4C4C4A484944474842484943484B44
45484141443D3E413A3E413A4447403F423B343730383B34373C353A3F3840463C43493F
40463C3C42363B3E333F41343F43343D402F3F40304E4D3B534D3D4A443651493E767064
88847B706D665A59555656545155565156594B55574A555B58626B707D868891A098A1B2
98A0B39CA4B99CA4BB9EA5BF9FA6C29FA6C2A0A9C6A1AAC7A1AAC7A5B0CCA7B2D0A4AFCD
A4AFCBA6B1CDA8B3CFA6B4CFA4B2CFA4B2CFA4B2CFA5B2D2A6B3D3A6B5D4A5B2D2A5B4D5
A5B2D4A3B1D4A5B2D5A4B2D5A5B4D5A5B4D5A4B3D4A5B4D5A3B1D4A3B1D4A2B0D3A1B1D3
A3B1D4A2B0D3A3B1D6A1B1D5A0AFD6A1B0D99FB0DB9FB0DC9EB0DE9EB0DE9BB0DD9DB2DF
9AAFDE99AEDD9BADDF9AACDC97A7D897A7D897A8D696A8D696A8D696A8D695A7D593A8D7
93A8D590A6D590A6D78FA5D68FA5D68EA5D78EA5D78DA4D88CA3D78BA2D68CA3D78CA3D7
889FD389A0D6889FD589A0D6869BD08398CD8599CE8596CC8695CC8796CD8894CE8793CD
8791CC8791CC848ECB8590CE848FCD828ECA828ECA7E8DC87F8EC77D8EC6808FC87D8EC6
778BC0768BC0768ABD758BBC758DBD728ABA748ABC7086B87288BA7388BD7285BD7184BC
7484BF7282BD6E80BE6E80C07180C16E7DBE6F7EBF6C7BBC6D7CBD6C7AB96D7BBA6C7AB7
6B7AB56B7AB36A79B06778AC6678AA6678A8687AAA6375A56375A56274A46778AC6172A6
6273A96071A7606FA86170A95E6FA75D6EA45C6BA2606DA25C6C9F5B6B9C5B6C9A5B6C98
5A6B965869945869945667925667925568925467915167904F658E50668F52658D54678F
51638B52648A5362895262864F5D82535F85525E844F5B814E5A804E5A824E5A824D5983
4E5A844C598344537C45547D44558045577F45568145577F42547C4356804255803F527D
40528040528040517F3F507E3E4E7F3C4D7B3D4D7E3E4F7D3D4B7A3C4A773D49793C4976
3944723A47743A467638447436447336447334427134426F32416C303F6A3140692C3E64
2C3E642C3E622D3D612C3C602B3B5D2B3B5D2B3B5C293C5C283B5B263957283859253556
2538582437572033532134542232542030542331542230532131552030541C2C501D2D51
1D2D511A2A4E1C2C4E1C2B4A1A2A4419283F19243A192438
696D7063676A6263676F6E737372776A696E615F645D585E524B52423B423D333B362C34
332A2F231A1D1E18181E191619161115150D14140C11110712120616160A1F1F151E1E16
1B1C161516100F110C11130E131510191B161D2019181E141B1E151C1F141F1F15212117
21211925241F2B2A252928242F2E2A3C3B39434240454543444442434341434542444643
43484440453F3D423C383F38393E38393E37383D363B4039383D36373D33383E343A4034
393F333C42363E42343E42343D41323E41303839294C4A3B615E4F5653444F493D625E53
6A665D57544D5655515153524E525350585B555E6566707973808987939F97A3B397A2B4
99A6B99AA6BC9DA7C09CA6BF9EA8C3A0A9C6A0A9C8A0ABC9A1ACC8A1AFCAA4B2CDA1B1CB
A3B3CCA4B4CDA5B5CCA6B6CDA4B4CDA4B4CEA3B2CFA5B3D0A6B3D3A6B3D3A7B4D6A8B5D7
A6B3D6A3B0D3A6B3D6A5B3D6A5B3D6A4B4D6A6B4D7A5B5D7A2B2D4A1B1D3A0B0D4A1B1D5
A3B1D6A1AFD4A1AFD6A2B0D7A3B2DB9EADD89DAEDA9BACDA9AACDC9CAEDE9AACDE99ADDF
98ACDF97ABDE99AADE97A8DC98A8DC97A7DA97A7DA97A7D894A6D695A7D595A7D593A5D3
93A5D390A5D28EA3D08EA3D28EA3D28DA1D38EA2D58DA3D58A9FD4899ED3889FD38CA3D7
89A0D6869DD3879ED4879ED2849BCF849BCD859BCD8397CA8394C88696CA8595C98592C9
8693CA8691C9858FCA848EC9828ECA838FC9838FC9838FC9808FC87D8CC57D8CC57E8DC6
7B8CC4768ABF7589BE7589BC758BBD758BBD7489BE7388BD7287BC7589BE7387BC7384BA
7586BC7283BB7181BC6F7FBB6E7EBA6E7EBA7381BE6F7EB96C7BB66C7BB66B7AB56B7AB3
6B7AB16D7CB36978AF6677AB6677AB6779AB6779AB6577A76476A66072A26274A66173A5
6072A46072A45F6FA36070A36171A55E6EA25E6BA0626FA35E6C9D5B6B9C5B6C9A5B6C98
596C96596C96576A9456699356699154678F52689151679051679055689253669051628D
52618A516089526087535F85515D83525C80515B7E525C7F505D804D5A7D4D597F4C587E
4B59804B5A8147598143567E43567E44577F42557D43568043568045588241547F41547F
3E507E41528040517F404E7D3F4D7E404E7F3F4D7E3F4D7C3B49783D49793E48793B4674
3944723D48753A477438457235437034436E35446F34436E32416A324168303F662F3F63
2F3F63304064313F642D3B602D3B5E2C3A5D2A3A5B2A3A5B28385928395729395A273856
2637552738562435532132502332532332531F2E4D21304F2130511F2D501E2C4F1F2D50
2030541F2F531D2B4E1F2E4D1F2D4A1B27411B253E1C243B
686E6E6E74746D6E725D5E62545559555459555459525053474548302E312F2D302B292A
21201E1C1B191B1A1619181416171116171118191315160E13140C1819111E1F171D1E18
15161010110B0E0F090F100A1617111718101C1D151E2116202217222417222216232319
22221822231B2B2C242D2E2831322C3B3A3641403C4342404141413E403F3D3F3E3F4140
3E42413D433F373D39353F37353C35343B34363D35383F37394136363E33373D33343A2E
30362A363C2E3C42363F43353E42344347393A3C2F3E3E326364566464584E4C404D4D43
59594F5F60585E605B505551484E4E4D555868717877818B8692A08E9AAA919EB195A1B7
97A6BB98A7BE97A6BD9BA9C3A0ABC7A0ABC79DABC89EADCA9EADCA9EADCAA2B2CC9EAFC9
9FB1C9A1B3CBA3B5CBA4B6CCA3B5CBA2B4CCA3B4CEA5B4D1A1B0CFA4B3D4A5B2D5A5B2D5
A9B6D9A7B4D7A4B2D7A6B5DCA5B4DBA0B2D8A3B2D9A0B2D8A0B2D6A1B3D99FB1D9A1B3DB
A0AFD8A2B1DAA0AFDA9EADD89FAED99DABD89CACDD9BADDD9BADDF98AADC9AABDF97A8DC
99AAE099AAE099A8DF97A6DD97A8DE95A6DC96A6DA97A7DA96A8DA94A6D697A7D894A5D3
92A4D291A3D191A3D18EA0D08FA1D18D9ED28D9ED48D9ED68D9DD8889BD5889CD7889ED8
859ED787A0D9849DD5819AD2849BD1839ACE849ACC8397C98094C68294C68394C88292C6
8292C68592C78590C88590C8848EC9828EC8838FC97E8DC67F8EC57F8EC57D8CC57C8BC4
7A8BC17B8CC2798AC07889BF778BC07387BC7286BB7286BB7185B87485B97384B87383B7
7484B87281B87180B97180B97180B76E7DB4707DB46F7CB16C79AE6E7BB06B78AD6C79AD
6B78AC6A7AAD6676AA6677AB6677AB6377A96377A96175A76176A56075A45F719F6072A0
6375A361749F5F709E5F6D9A616F9E606E9D606CA0616EA25D6B9C5D6B9C59699A576999
566B98556A9752679452679451669352679453659352649252649253649250618F536190
525F8C535E8C525A88545B87545C83535B80525A7E525A7E505A7D505A7D4D5A7D4B597E
4B5A81485A80475981475A8442557F40567F42588143568140537E42558042538140517F
415280414F7E3F4D7C424F7C3F4B7B404C7C404A7B3F497A3D47783D48763D48763A4572
39467038456F39467238456F34436C34436C334269324168334166344265303E612E3C5F
2D3D5F2E3E602C3C5E2C3C5E2D3B5E2C3A5D29375A2A385B29375A29385929375A293658
2936582A3759283255273154222F51212E50212E4E1F2C4C202D4D202D4F212E501D2A4D
202C52202C521E284C222A4E23294B2027441C213E1D213C
70747765696C636468605F645150554544493E3E403636383737393030302C2C2C2A2C2B
1B1D1A131510141611171914181A15151811191C15191A14191A141A1B151D1E181B1C16
1516110E0F0A0D0E0912130D1516101819131D1E161E1F171F211624261B25251B232319
1E1F17292A222E2F2732332D3B3C363F403A42413D4544424141413D3E403B3C3E3A3B3D
393D3C393F3D353B39353B37343A36323932333A33353C34383F37343C3130362C33392F
343A2E33392D383E343A40363F453B44473E43463F464942575A534F524B474842454641
6365607F8480868A894B4F5051565A6B6F787F85919097A7949CAF939EB2949EB797A3BD
94A2BC97A5BF99A7C19BA9C39EAAC4A1ADC79DABC69BABC59CACC69CADC7A0B1CB9FB1C9
9DB1C99DB1C99EB2CAA1B5CDA1B5CDA0B4CCA1B2CEA5B6D4A4B3D4A4B2D5A3B1D4A4B2D7
A6B2D8A4B2D7A3B2D9A1B3DBA3B5DD9FB2DA9EB1D99EB1D99CB0D59BB1D89AADD79CAFD9
9EB1DB9EAFDA9EAFDB9DABD8A0AEDB9BACDA9AAADB98AADC98AADC97A9DB97A7DB98A8DC
96A7DD96A7DD98A7DE96A6DA94A5DB93A4D894A4D793A3D692A4D493A5D594A4D58F9FD0
91A3D18EA0CE8EA0CE8D9FCF8D9FD18E9FD38C9DD38D9ED68B9BD6889BD5879BD6859BD5
8399D3839CD5819AD38298D18299CF8297CC8298C98398C77D92C17E93C28294C68193C5
7F91C38191C48390C5828FC4828FC4818EC57E8DC4808FC67F8EC57B8AC17A89C27A89C2
7889BF7A8BC17788BE7687BD7889BF7788BE7386BE7586BC7283B77383B67282B57181B4
7282B57282B6727FB47380B5717EB36D7DB06F7CB06F7CB06D7BAC6A78A96977A86A78A9
6A78A96777AA6777AB6475A96579AC6278AA6276A96377A95F74A35E73A05E73A05E739E
5F729C60739D5E6F9A5E6F9A5E6D985F6E995F6B9B5F6B9D5B699A5C6A9B5A679B58689B
586A9A5469985166954E6392506292536595546698536396516192515F90546293525E90
545E91555D8E545A8A535A88545B85535B82525A7F4F597D4D577B4E5B7E4D5B804A5A7E
47597F475A824558804457814157803F557E40558041568143568142548240517F40517F
43517E404E7B3F4C78414E7A404B783F4A774048764048763D48753E4A743E4A743A486F
37456C37456A36446B36446B344269344269334166324065323F62313E61313E612E3C5F
2C3A5D2C3A5D2B395C2B395C2D3A5D2B385B2B385B2836592A375A2A375A2835582B3559
2A34582933572931562B3358283256212B4E212B4E232E4E202B4B202B4B212B4E212B4F
212B4F20284D21264C1E24482125482023441B1C3A1D1E3C
737077605E63605B61635E625452573F3D423634393230353130352C2C2E2122241C201F
151B170C120E0C110D121711171C16151A14171C16181B14171A131B1C161C1D181C1B17
1717150D0D0B0C0C0A0E0E0C181715181713191A151D1E191D201921221C22231B24251D
1E1F192728223C3D373A3B363D3F3A41423D3E3E3C434341454545424242444446414244
3C40413A3E3F393A3C383A39353938333736313534363B373339353239322E332D2E332C
333A32363D36363C383B413D444A464B4F4E484C4D484C4D474B4C44484B43464B43464B
575A5F8A8F95989DA37F838C4D4F5B7C7F8E9497AA989DB3989CB7999EBC9BA0C09BA1C1
9CA5C49CA7C39BA7C19BA7C19EAAC2A3AFC7A0AEC89FAFC69DADC49CACC39FB1C79FB1C7
9CB1C69EB2CA9EAFC9A0B1CB9EB2CBA0B4CF9EB1CFA1B1D2A4B2D5A5B3D8A4B2D7A3B2D9
A4B2D9A2B1DAA2B1DAA1B2DD9EB1DB9CB2DB9BB1D89BB3D99AB2D899B1D799AFD898AED7
9AB0D999AFD89CAFDA9DAEDA9DAEDA9CADDB98A8D997A7D898A8D998A8D998A8DB96A6D9
96A8D897A9D997A7D896A7D596A6D798A9D795A6D494A5D394A6D492A4D292A4D290A2D0
8FA1CF8CA1CE8BA0CF8CA1D08B9FD18B9FD1879BCE889CD1899CD4879CD3869BD28398CF
869BD4839AD08198CE8299CD8197C98296C88395C78193C38092C28092C28095C47D92C1
7D92C17F91C17F91C17D8FBF7D8FC17E8FC37B8CC07A8BBF7B8CC07B8CC07A8BC1798AC0
7788C07687BF7788C07485BD7485BD7586BE7485BD7384BA7484B87481B67481B5727FB3
7380B47380B4737FB3717EB2727FB3707DB16D7DB06A7AAB6C7CAD6878A96878A96878A9
6878AB6778AC6677AB6377AC6479AE6178AC6076A86076A76076A55D74A05C739F5C739D
5C729B5C72995B71985A6D955C6E965E70985E6D985C6A975B67975A66965C689A5A6899
56669755659657679A516395506093556598536397536095525F93535F93525E92505C90
515B8E535B8C525A8B515988515C894E5A844D5B824C5A8149577C4B5B7F47597F46587E
455880455B8242587F41577E40567D40567D42557F42557F3D537C41547F42537F3F507C
41507B404F78414F763E4C733D4B723F4D743E4A723B476D3A466C3A476A3F4D703A486B
374568364668344267334166344267323E642F3B61313D63333C63333C63333C63333D61
313B5F2B385B2D3A5D2B385B2D375A2E385B2C36592A375A2B35592A335A283158283158
293259293259252E55263054293357252F53262E53252D51222C4F1E284B20284D20284D
222A4F23294D23294D24284B2326452226431F203E1D1D39
6661655B565A5C58595E5A5B534F50353034322D312F2D302B292C2525271A1B1D141819
161C1A141A180A0E0D0C110D161B17151A161719161719141618131A1B161B1B191D1C1A
1A1A1818181614141211100E1716141919171919171D1F1A20221D1F241D21241D22251C
292C2534373041423C3E413A3C3F383E403B40413C40403E41413F4343434242423B3D3C
3F41403F4140393A3C38393B35393A343839313536343839333939303634313534303433
313534343A3A313538454A4E575A5F5154594A4D54484B54474A53454954484A57454955
474958767887A8AAB99899AB6263758485999C9CB69D9EBC9A9DBC9A9DBE9B9FC29BA1C3
9BA4C39DA6C39FABC59DA9C19EAAC09EADC29FAEC59FB0C4A0B1C5A2B3C79FB1C7A0B2C8
9EB3C89EB2CAA0B1CDA1B2CE9EB1CFA1B4D2A0B3D39FAFD1A3B3D7A3B3D7A3B2D9A2B1D8
A2B1DAA0B2DAA0B2DA9BAED69CB2D99CB2D99AB2D89CB4D899B3D899B3D898B0D696AED4
9AB1DA97AED798AED799ACD79BACD899AAD699AAD897A7D899A9DA98A8D995A5D697A7D8
95A7D595A7D596A7D398A9D597A8D496A7D395A6D294A5D195A8D390A3CE90A2D08EA3D0
8DA2CF8AA1CD8BA1D08BA3D1899FD08AA2D2879DCE879DCF889ED0879DCF879DCF849ACC
849ACC869CCE8498CB8397C98095C48193C38394C28394C28192C08092C08193C17E93C0
7D92BF7D92BF7B90BD7E93C27B8FC17C90C2788CBF788CBF798ABE798AC07889BF7889BF
7A8BC17687BD7889BF7586BC7485BB7384BA7283B97483BA7282B67282B57380B47282B5
7381B2707EAF717FB0707DB1707DB16B7BAE6D7DB06A7AAB6A7AAD6878A96979AC6878AB
6676A96677AB6475AB6478AD6277AC6075AA6075AA5D73A55F75A65E74A35C739F5C739D
5A719A5B729B5A7099596F965C6F975C6F975C6E965D6C975A68955B69965B67975B6797
586695576594566493546593536394556394566397546195525E90546092525E924F5B8F
4F5B8D4C58884F5B8B4E5B884C5B864A59824B5A834D5C834B5A8147597D495B8145597E
465A7F475B80465A7F44587D42567B41547C42547C43547F3F527C41547E42537E41507B
404F783E4D74404E733F4D723D4B703D4B703F4C6F3E4B6E3C496C3A496A3D4C6D39496A
36466836466837476934426737456A354368323E64303C62313A61323B62353D64363E65
323B62313B5F2E385C2D375B31395E31395E2E385C2D375B2C355C293259272E5829305A
28315A273059273059252E55262F56262F56272F56252D54222C501F294D20284F21294E
222A4F242A4E23274C252A4A26294821254220213D20223B
53544E54554F57565144413C3B38332F2B282B27262F2B2C2A282919171A131315141318
1213151213150D0E100B0C0E1112141617191414141111111616161B1B191A1A181A1B16
1D1C1A1B1A1814131112110D14130F1718131B1C171F221B1F261E1D251A1C2216252B1F
2C3224363C303E41363D4037363930393C353C3E393C3E393B3D383D3F3C3C3E3B393B38
3C3E3B3E403D3B3D3C393A3C35393C33363B2E33372E33392F343A2F343835383D313439
2E31382D30373636405B5D6962616F5756644C4B5B4948584847574647594D4B604C4D61
49475D5C5A709D9BB39C9AB28F8DA59A97B29E9EBA999AB99EA1C29DA0C19DA2C29FA5C5
9CA5C29DA9C39DACC39DACC19DACC19DAEC09DAEC29EAFC39FB0C4A0B2C6A0B2C89FB1C9
A2B4CCA2B3CDA1B2CEA2B3D19DB0D09FB2D3A1B1D5A0AFD6A2B1D89EB0D69FB1D9A0B2DA
A0B2DA9DAFD79DB0D89AB0D59CB2D79BB3D798B0D499B1D396B0D398B2D597AFD398AED3
97AFD596AED497ADD498ABD599AAD599AAD699A7D499A7D697A8D696A7D596A6D795A5D6
97A9D792A7D494A6D495A8D393A6D194A7D194A5D194A5D195A8D390A3CE8EA3D08DA2D1
8CA2D18AA2D08AA2D289A4D3879FCF86A1D088A0D0869ECE869ECE869CCD869CCB859AC9
8398C78597C58495C38495C38394C08293BE8394BF8293BE8293BE7D90BB7F92BD7F92BD
7D92BD7B90BB7A91BD7A90BF7B91C27A90C2788CC1778BC0798DC2768ABF798AC07788BE
7887BE7787BB7686BA7686BA7486B87385B77484B77585B87484B77082B47181B47082B4
7181B46E7EB16E7EB16D7DB16C7CB06B7CB06B7CB06A7CAE697AAE697BAD6878AC6B7BAE
6575A86474A76474A86374A86273A76273A96172A86071A55E72A45E73A25D72A15B709D
5A719D59709A5A719B5A719A5A70995D7098586B93596B93596A955A6B965A6994586792
59669055648D57668F56658E56659056638F55628F55628F525F8C535F8F515F90505E8F
4C5D8B4C5D894B5C87475A82485B83495D82485A7E495C7D485B7C4A5D7E495B7F46597A
45587946597949597B47577944547843527944537A43527B43527B42517A43527B404D77
404D77414F763E4E723F4F733F4D703E4C6F3F4D723D4B6E3B496C38486A39496B38486A
36466A33456934466A38486C36466A354569344269303E65303C64303C64353E67363F68
313A613039603039602F385F2F385F2F385F2B345B2D365D2E355F2D345E2A315B2A315B
29305C282F5B272E5A282F59262F58242D56242D58242D58212A53212A531F2851202952
222B5221294E21274B24284B252A482226411D213A1F243A
52554C4F524948494134342C2A2A2225221D221E1B221E1D1E1C1D181818131114131315
1313151414160F0F111212141313151515171212140D0D0D1111111B1B191B1D181A1C17
191A1518191413120E13120E181914171914191C151A1F181F261E1D271C182015232B1E
32382C3A40343A40363B3E3732352E393B3640423D3D3F3C373934363833363833353732
383A353C3E3B3A3C3B393A3C33373A3033382B2E352E333930353B30353935383F2E3138
32323A37373F2E2E386A6A746A69775B5A68595868504F614B4A5C4E4C614E4C624D4B61
4D4B637371899C98B39894AF9692AD9D9AB79E9DBC9C9DBC9C9FBE9C9FBE9DA2C29DA4C1
9CA6C19AA8C29CABC29DAEC29DAEC29CADC19CADC19DAFC39EB0C49EB0C69CAEC49DAFC7
9FB0CAA1B2CC9FB0CCA1B2D09EB1D19EB1D29DAFD59BADD39FB1D79EB0D69FB1D99DAFD7
9BADD59DAFD79BAFD49AB0D599B0D298B0D299B1D396AED098B0D297AFD19AB0D598AED3
97ADD297ADD296ACD397AAD298AAD29BAAD39BAAD598A7D298A6D395A6D295A6D294A5D1
93A6D191A4CE8FA2CD8FA2CC90A3CD8EA1C98FA0CB8FA0CB8FA2CC8C9FCA8A9FCC8CA1CE
8AA0CF89A1CF88A0D088A0D0859DCD849FCC859DCB839BC9839BC9859BCA8A9FCC8499C6
8398C38497C28596C28394C08293BE7F92BA8192BD8091BC7F92BC7F92BC7D90BA798FB8
798FB87A8FBA7990BC798FBE7A90C1778DBF768ABF788CC1788CC1768ABF7788BE7586BA
7787BB7585B87282B57284B47183B37183B17082B07082B07082B06E80B06F81B16D7FAF
6C7EB06D7FB16A7CAE6B7CB06B7CB06A7BAF6B7CB06879AD6879AD6778AC6878AC6878AB
6774A86774A86673A76272A56373A76171A56170A76272A65D6EA25E70A25E70A2586D9C
5B709F5A6F9E566B98556A97576C97586D98566993566993576A94576A9457699155678F
57668D57668D56658C54638A55648B52618853628B55648D525F8B505F8A4F5D8C4C5D8B
4C5F8A4B5E88485E85465C83455B80465C8144587B485B7C45597A495C7D4A5A7C465678
455576465677475578455376455378435178435178425077414E78424F79414E783F4C76
3E4B753E4C73404F763C4B723D4B703C4A6F3C4A6F3A486D3B4B6F39496B3A4A6E36466A
35456933456933456B34466C34466A2F4165314067303F66313F662D3B62303C66333F67
2D39612C385E2B375D2B375D2A365C2B375D28345C2A335C28315A29305A2A315B29305A
282F5B262D59252C58252C58252C58232A56242D58232C57202954212A53202952212A51
202950202A4D20264A2026462027431E243C1D23391D2437
51564F3D423B31342D2A2B2523241E1A19141514101415101313110E100D131313141615
161817181A191A1C1B1B1D1C191B1A17191811131211110F161614191B181B201A191E18
151A1312171011140D13160F141912131811161B15171E17181F181B221B1F241E262B25
373934363835393B3A3C3C3C3B3B3B3F3F3F3E3E3E3A3A3A373735353533353734363835
383A35393B38393B3A3637393031333132362F30342F33362F33342F3332323335303231
3337363A3E3D41454661656667686D6161695B59644846534A49574F4E5E524F62676479
79778D8B89A19894AD9995B09B98B39A9AB49E9EBA9E9FBD9EA2BF9CA1BE9CA1BF9BA2BE
9DA7C29AA8C29AA8C29AAAC19CAEC49DAFC59CAEC499AEC39BB0C59DB2C79BB0C59CB1C6
9FB1C99EAFC99DAECAA0B1CFA0B0D19FB2D39DAFD39BADD39CAED49DAFD59DAFD79CADD8
9BADD59BADD599ADD29AAED396AACF96ACD198AED395ADD195ADD196AED299AFD697ADD4
98AED398ACD198AAD09AA9D096A5CC97A5CC97A4CE95A4CD94A3CA92A1C893A2C992A1C8
8FA1C78C9EC28A9CC28A9CC2879BC0869ABF8396BE879AC28396BE8295BD8497C18196C1
8398C58097C38197C6849AC98298C77F97C38097C38097C38198C48297C48196C38095C2
8297C28095C08196C17F94BF7F94BF7E94BD7D92BD7D93BC7C92BB7C92BB7D92BD7A8FBA
798EB9798EBB768BBA778CBB788CBE768ABC768ABD768ABD7889BD7687BB7889BD7789BB
7789BB7486B67183B36E83B06F84B16E83AE6E83AE6E83AE6A7FAA6A7FAC6B80AD6A7FAC
6A7FAE687DAC6B7DAF6C7EB06B7CB06778AC6979AD6777AB6577A96476A86676A96676A7
6676A76775A66472A36371A26471A56471A56370A56471A6616EA35E6EA16070A35D6DA0
5D6DA05C6EA0586A9C586A9C56689A57699956689655679552679253689356699352658D
53678C52668952668952648850628651638750628652648A5160894F608B4D608B4B5E89
4B5E894A5D87485E85485E85465C83455B80465A7D465A7D45577B45577B47577B455579
44527545537648547A44507844527943507A43507A424F79414E783F4C76424E78414D77
3D4A743E4B773D4A763C49753B4A733B4A733B487239476E39476C39476C3B497038466D
35436A35446B334269334269334269303F662F3E652F3E652E3E622F3F632D3B622E3C63
2D3B6229375E27355C26345B25335A26345B26345B27335B293259272E582B305A292D5A
272B58262A57282C59272B58262A57222653232A56232A54212852222A511F294D212B4E
1E2B4D1D28461D28461D27421C273D1F273A1C25361B2433
343A362F342E292E2820221D1A1D1611140B0F120B0E110A0E100B0F110C131510151712
1A1C19191B181A1C171C1E191B1D18181A1514161112140F1A1C171A1C171920191D241C
181F17161D1510170F131A12151C14161D16181F18181E1A1A201C1B211D2125242A2E2D
3739383B3D3C3D3D3F3D3D3F3A3A3C373739343434363636363634353533353734383A37
383A353A3C373537363537363032313436353737373335342C2E2B282A27383838373735
363835636562686A696566686B6C7076777C3D3D4730303C3E3D4B47465659576C706E84
8C8AA08F8FA79693AE9898B29999B39B9DB69CA0BB9FA3BE9BA0BD9DA4C09CA3BF9DA4C0
9DA7C29CA8C29AA8C29BABC49DADC69FAFC89BADC59AACC29DAFC79BAFC79CB0C89BAFC7
9DAEC89FB0CA9FB0CE9EAECF9DADCF9DB0D19EB0D49AAED39CAED69CAED69CADD89BACD8
9AABD69BACD799ACD69AADD798ABD398ABD399AFD697ADD497ADD496ACD592A8D194A7D1
95A8D096A8D098A7D096A4CB97A3CB96A2CA95A1C9939FC7909EC58F9DC48C9ABF8B99BE
8997BC8A98BD8695BC8395BB8294BA7D91B67D90B87D90B87C90B5788BB3798CB47A8DB7
7B8EB87B8EB97C8DBB7B8EB97B8EB97D90BB7E91BC8093BE7F91BF7F91BF8092C07E93C0
7F94BF7E95BF7D94BE7E95BF7E95BF7C93BD7E95BF7D94BE7A91BB7990BA7C93BD788FBB
798EBB778CB9768BBA798EBD768BBA7388B77488BA7589BB7486B87688BA7688BA7587B7
7587B77486B67085B27085B26F84B17085B06E83AE6F84AF6D82AD6D82AF6C81AE6C81B0
6A7FAE697EAD6A7CAE6B7CB06A7BB16776AD6B78AF6B78AD6676AA6274A66474A76474A5
6475A36674A36674A36573A26472A36371A26370A46370A5606DA1616EA2606DA15E6B9F
5F6CA05B6B9E59699D58689B57679B59699C556797546696576997566B9655689252688F
50668B4F668853678A51658851638750628651638952648C4E5F8A4F608B4B5E894B5E89
495C874A5D87495C86465C8546598346598146598144587D44567C45577D45577D46557C
44537A44537A45537A445279425178425178425178435279425077404E75414E78414E78
3E4B773D4A773E4B783C4A773B497638497538477235446D38476E38476E36456C36456C
35446B35446B324168303F663241683140672E3D642C3B622C3C602D3D612B3A612A3960
2A396028375E28376025345D24335A23325924325927335B263258262F562A2F592B2F5C
2A2F59282D57292D5A282C59262956212552222653222953252C56232B52202A4E202B4B
1F2D4A1B294417253F18243C1B283B1A2737192533192531
2C302F2B302C232824191E1812180E0E14080B11050D13070C12080E130C12150E171A13
1A20161A2016151811191C13191F15181B1016191013160D181E14171F14181F1719231A
141E15131D15101A12121C14151F1719231B1A231E1A231E202924262D262B302C313632
3537343739363737373535353636343434322E2E2C2F2F2D32342F363833393B36393B36
383A353739343637323536313232303434323A39373A39373635333E3C3D454044413C40
413F4268686A6F6E735D5E635F5F676E717A5355624E505F55566A65667B7C7C948E90A9
9496AF9597B09498B3989CB79A9EB99BA1BB9AA1BB9FA6C09AA4BD9BA5BE9EA8C39BA5C0
9BA7C19CA8C29BA6C29CA7C39FAAC69CAAC59EACC79DABC59CACC69DAEC89DAEC89DAEC8
9BAFCA9BAECC99ACCD9EB1D29CAED29BADD39DAFD79AABD69AABD799AAD699AAD89AABD9
9AABD99AABD99AAADB98A8D997A9D797AAD596A8D699ABD997A9D795A7D797A7D893A4D2
92A3CF94A2CF95A0CD959EC9959EC9949BC79198C48F96C28D96C18B94BF8C93C1888FBD
878FBD838EBB7F8CB9808EBB7C8AB77A8BB7778AB5778AB4788AB27587AF7587AF7483AA
7584AB7785AC7985AF7783AD7783AD7885AF7885AF7A87B37986B37987B67987B67B8CBA
798EB9788DB87990BA7A91BB7A93BC7A91BB7990BC788DBA7A8FBC7A8FBC7B90BD7A8FBC
788AB87A8DB8798BB9788AB8788AB87587B57587B57486B47284B27385B37385B37385B3
7385B37284B26E83B27085B26D84B06A81AD6C83AF6D84B06C83AF6A81AD6A80AF697DAF
677BAD6A7BAF6A79B06877AE6776AF6776AF6874AE6B77B16574AB6373A76471A56472A3
6573A26573A26472A162739F5E6F9D60719F6070A16171A26070A15E6E9F5E6C9D5B699A
5C6A9B5C6A9B5B689C5D6B9C57649856649556669757679857689656699457689354678F
4F658A51658A52648A51638955648B52618A52618C52608D4F5D8C4B5C8A4D5E8C4C5D8B
4A5B89495A8848598746588646578346578345568242537F41547F40537E40537E41547E
41547E40537B40537B4054793F53783F53763F51754052763F4F733C4C70404F76404F78
3C4A773947763B49783A487935477735477735467433447035467135467134457031436B
30426A30426A2E40682C3E662E40663042682D3F65283A602B3B5F2C3C602B3B5F29385F
2A385F27345E29375E27355C243259233158253159232F57232F55283158273059252C56
252D54252D54272C56272B58252958212552212552242953222953242C53202A4E1E2949
1D284617254017263D18273C18283814243313212E16242F
25292A2B2F302329271117130F160E11190E0E140A0C12080D13090F150B12150C181B12
191F131A2014171A0F1A1D12171B0D181C0E1A1C11181B10191F151B2318141B14151B17
121814101614151B19151B19171D1B161C181B211F1E2422222824272E27323733383A37
37393637393434363132342F36383331342D2F322B2F312C30322D3335303A3C373A3C39
36383535373434353033342F3635333B3A383B3A383938363C3A3B484445534E544A454C
403D445A59615957625B5B675C5E6B5D606F575A6D5A5C715F617A767A958A8EAB9195B2
9297B4959AB7949BB7969DB9989FBB96A0B997A3BD97A3BB96A4BE98A6C099A7C19DA8C4
9CA7C39BA6C29CA5C49DA6C59DA8C69DA8C6A0ABC99FAAC89EACC99EADCA9EADCC9FB0CE
9BAECE9CAFCF9AACD09CAED29CAED49AACD49AABD698A9D59AABD79AABD998A8D99AAADB
9CAADB98A8D99CA9DD98A8DB97A7D897A8D697A7D898A8D995A5D695A5D696A4D593A1D2
919FCE919ECB919CC98C94C28C94C28C93C18C90BF888CBB848BB9848ABA8689BC8689BC
8187BB7F86BA7E88BB7C88BA7A88B97987B67586B47384B07485B07385AD7887B07584AB
7583AA7682AA7982AB7780A9757EA5757EA7757EA9777FAD737EAC747EAF737FAF7684B3
7284B26E83AE7085B27188B27188B47188B47287B47688B67688B67789B9788ABA7789B9
7789B7788AB87789B77688B67385B37386B17588B37487B27386B17385B37284B27183B3
7284B47183B36E82B46C80B26A80AF687EAD6B81B06A80AF6880AE6880AE677DAE697DAF
6B7CB0697AB06A79B26A79B26776B16776B16874B06874B06877B06473AA6373A76171A4
6371A26172A060719D61729E60719D5F729D60719D5B6E995D6E9A5C6D995B6C985B6998
5B69985D6B9A5B69985C68985965955A669658669558669556649155648F57668F52648C
51658A50638B52648C53628B55648F54638E505E8B515F8E4E5C8D4D5B8C4D5D8E4B5B8C
4B5C8A4B5C8A4A5B8944558344558344558344558343548243548244578241547F40537E
40537D3D537A3D537A3E54793E54793E55773B52743D51743D4F733B4D713D4C733F4E79
3D4B783C4A793B497A35457633457734467632447432437131437131446F32457030436D
2F406B31436B30426A30426A2C3F672C40652A3C62293B612B3A612A39602B3A6129385F
2C396329366025335A25335A25335A243257243259233156243056243056253157252E55
242E52272F54272F56252C562128541F26522027512229531E2750222B521E284C1D2848
1D28461B264219283F192A3E19283B15253414222F14222F
1A1F251E2327191E21171D1D171B1A181D191B1D1A1C1E19151712171A13191C131C1F14
1C20121E22141E20131B1D101B1D101C1E111D1F141F20181B1E1720251F171B1A0F1314
161A1D171A1F1D20251B1F221A1E211E22232122242729282B2D2A313330373934393B36
383A3534373032352E2F352B31372D32382E2F352B2F342D2E332D2F342E353A36383A39
3335343333333333353232343232343B3B3D40404042424248484A4F4D524E4B52423F48
3E3C4743414E413E4F5655675D5E735759705556726A6E8B7F82A1888DAD8E93B39096B6
8F98B7949DBA949FBB92A0BB93A1BC92A2BB94A4BE94A6BE91A2BC94A5BF97A6C399A7C4
9AA7C79BA8C89CA6C99DA7CA9FA9CC9EA8CB9FA9CCA2ACCF9FACCE9EABCD9EABCE9DABCE
9DADCF9BADD19AACD09BADD39AAED39BAED69BACD79AABD69DACD79CAAD79BA9D89BA9DA
9EAADE9AA8D99CA8DA99A7D89AA8D99AA8D999A7D698A6D597A5D493A1D094A2D1909ECB
8C9AC78897C28A97C38794BE818EB8818DB78088B68188B68086B67D83B57D80B58083BA
7E83BB7B80B87980B67983B87480B47583B47583B2717FAE717FAC7382AD707FA8707FA8
7380AA7482A9737FA7727EA6717DA5717DA5737CA7737BA9717CAA707BA96C79A66E7CAB
6E7FAD6B7DAB6A7CAC6A7FAC6A7FAE6E80B06D7DAE6E7EAF6F7FB06E7EAF7080B37080B3
7181B47284B47385B57287B47085B26D82AF7287B47186B37284B27284B47383B67383B6
7082B46F80B47182B86D81B66B80B56A7FB4697EB36A80B2677EB0667EAE677DAF677BAE
697AB06778AE6776AF6776AF6A76B26672AE6873B16A76B26874AE6574AB6574AB6273A7
6373A46173A160739E61749F5E719B5D739C5D709A5A70995A6D975B6E985B6E98596A96
5B6C985C6D995A6B975C6A975C69955B68945A67935C69955A679358658F58658F56658E
54638C51638B50618C52638E51628E51628E4E5F8D50618F4D5D8E4D5D8E4B5B8E4B5B8C
4A5B89495A8849578648568347558248568344527F42537F45568244558043547F40537B
3F527A41557A3E54793D53783E54793F557A3A5075374D72394F743C4F773C4D783B4C78
3E4C7B3D4B7A3B4B7C39497A35457635457638467735437234457332436F30436E2F426C
2E3F6A30416C2F406B30426A2F426A2B3E66293C64293C642C3E66283A622938612A3962
2C3B6429386125345D29375E28365B273558253358233355243255202E51243255253356
243153242E51252F53263054222C501E2B4E212D531D2B501F2B511D2A4D1C26491E2748
1D28461D28441F2A461C2B421B273D1B283B162334162232
181C25161B21191E221C2023181C1D1A1E1D1E201F1B1D1A1B1D181B1E171B1E151D2015
1E22141D21121F21131C1E111A1C0F191B101D1E161D20191C1E191B1D1A1C1D1F191A1E
1D1E232122272021262223281E1F2421222628272C2D2D2F3232323434323A3A383A3C37
3C3E392D322B2A2F282A32272C342930382D2F372C2D342C2F362F323834353938363A3B
3334383031353132373334392E2D332E2D334F4E545B5A6055545A44434935343C393742
3B39443D3B494342524A485D494A5F494B646869857C809D888DAB8E93B38F95B59197B7
8F98B5929DB9919FBA92A2BC91A1BA92A4BC94A6BE91A5BD8FA3BB93A4BE96A7C397A6C3
9AA9C899A6C698A5C797A4C69AA7C99CA9CB9EABCDA0ADCF9DAACC9DABCE9EAAD09BA9CE
9CACD098AACE9BADD198AACE99ADD098ACD199ABD39BADD59CABD49BAAD59BA7D79CA8DA
9CA8DA9BA7D99AA6D698A4D497A5D698A6D798A4D497A5D495A3D096A4D1919FCC8C9DC8
8A9BC68799C18597BF8496BC8193B9808FB67F8CB67E8AB48189B77D83B37C82B67D82B9
7B80B87B80B8787FB67882B77480B47783B57480B0737FAF707DAA7280AD7180AB7281AC
7380AC727FAB727FA9717EA8727FA96E7BA5707CA6707CA66D7AA66C79A56C79A56B7AA5
6B79A86879A76878A96878A96676A76979AA6977A86B79AA6977A86B79AA6977A86777A8
6A7AAB6B7CAA6B7DAB697EAB6C81AE6A7FAC6A7FAC6C81AE6F84B37183B37182B66F80B4
7081B57283B96F80B86B7EB6697EB5677CB36B7EB6687CB1667CAE697FB1677BAE6778AC
6778AC6677AB6776AD6473AC6773AD6571AD6874B06672AE6571AB6574AB6473AA6172A6
6375A76173A35F719F5E719C5C6F9A5B719A5B719A5A6D95586B93596C94596C94586B93
586A92596B935A6B965A69925B6A915A688F5B678F5C688E5A668E5A668E5A688F57658C
55648B51608951628D50618D51628E4F608E4E608E4B5D8D4C5C8D4D5D8E4A5A8D4B5B8C
495A8848598749578448578249568248558146557E46557E42537E42537E43547F42547C
40537B41547C3E52773F537842557D3E547B3B5178384E75374D763A50793E4F7B3B4C78
3E4C793C4A793D4B7A394A7835437234427137437337437337457431427031426E31426E
30416C30416C31426D2E3F6A2E41692E41692B3E66293C64293C642638602637622A3962
28376026355E23325B23325928365B253356243255243255223053212F52233154233154
233053243154233053233053212F52212F521C2C4E1B2B4D18284A1826491D274A1C2649
1D28481C27451D28461F2A461E2A42172238162137172236
0F12190F1217191D20191D1C1B201C1B201C1D1F1C20221D20211B1F20181E21181E2116
171B0D15190B191B0E1A1C111B1E13191C11171A11171A131E201B1F24201F21201F2022
1E1F212223271E1F232223271F232623272A343539343539343537333436353736373936
353A342D342C2A31292B322A2C332B2B352C2C362D2E3830313A37333C3B32373A2C3135
2A2D342A2D362E313A31343D29293530303C5E5E6A75757F53515C2A2931282631393742
3937423A38454745534D4A5B504F616361778181998688A18C92AA8E95AF9399B3939AB4
919BB4939FB594A0B892A1B893A2B795A6BA96A6BD93A5BB95A7BD96A8BE95A7BF97A9C1
97A8C299A9C397A7C198A8C298A7C499A8C59CABCA9CABCA9DACCB9CACCD9CAACD9AAACE
9BABCD9AADCE98ABCC98ACCD98ACCD96AACB98AACE99ABD199A8CF9AA9D29BA8D49BA8D5
9BA5D69AA4D599A3D498A4D496A4D595A3D495A3D296A4D396A4D192A3CF8E9FCA8DA0CA
8BA1C8879DC2869CC1869DBF829ABC8198BA8193B9808FB67F8DB47E8AB48088B67E86B7
7C83B77C83B77980B4777EB2737DB0727CAD747EAF717EAB717EAB6F7CA96F7CA96E7BA8
6D7BA86E7CA96B79A86C7AA76C7DA96879A46678A0687AA26678A06678A069789F66759C
6877A26674A16674A36573A26472A16573A26571A16571A16774A165729F64719E616F9C
63729D60719C61729D60739D60739D6275A06277A26378A5667BAA677CAB6A7EB16A7EB1
6E82B76D80B86A7DB76A7DB76C81BA6A7FB6677AB2687CB1667AAD6879AD687AAC6878AB
6676A96777AA6774A96875AA6574AB6372AB6473AC6271A86372A96474A86171A56272A6
6172A66072A45F6FA060719F5D709B5E719B5C6F995B6D955C6B925C6C905B6B8F57698D
5B6A915B6A915A6A8E57678B5A6A8C566688556485586786576687576687566487576588
54648853628950618C4D5E8A50638E4D5F8D4B5D8D4A5C8E4B5D8F4B5D8F4B5B8C4A5A8B
4B598848568548568348578248578249588147567D47567D44537C45547F42537E42537E
42537E3F507B3E4F7B41527E42537F3F527D3D4F7D3A4C7A364B763A4F7A3E4F7B3C4D78
3D4C773D4A773B487538467339467337447135426F35426F35426F34426F313F6E31426E
30416C30416C30416C2B3E68283E65293F662A40652C4267273D6225395E26396124365E
24365E25375D25345B243458263459273558273154283255233052233053222F52212D53
242D56232F57232F59212E581E2D541D2C53192B5117294D16294A18284A172647182547
1A27471C27451B26441E27441D26431B223E161D39111834
14181B1216171A1C1B1D1F1C1E231D181D161E201B20231C24272014170E15180F151B11
10160A0F150914170E171A11191C13141A1014170E171C151D221B2328212527221E201B
1F211E232522222423232524212322292B2A3436353233353132342E32312D2F2E2D322E
2E34302C332C2B322B2D342D2D342D313B33343A36343D3839424131393B33383C2A2F35
262A33292D362C2F382A2C382F313D494B586362704D4C5A3736443636423C3A473D3D49
403F4D464553535262605F7179778C84859A8F90A58D92A88F95AB9098AD9199B09199B0
949FB3949FB393A0B394A1B496A3B694A3B694A3B896A5BA98A9BD99AABE98A8BF98A8C1
98A8C197A7C099A9C39AAAC498A9C397A8C498A9C598A9C598A9C79AADCD99A9CB98AACE
99ACCD98ABCC97ABCC98ACCD96AACB96AACB94A6CA97A9CF97A6CD98A7D097A6D199A8D3
97A4D196A2D296A2D295A1D194A2D393A3D493A1D092A3D18E9FCB91A4CF8EA1CB8CA2CB
8BA3C988A0C48AA2C6879FC1869EC0879FC1899DC28799BF8796BD8895BF8792BF828DBB
808ABB8189BA7E86B77C84B57782B07782B07883B1747FAC717EAB6F7CA96F7BAB6C7AA9
6C7AA96A7BA96A7AAB687AAA6678A66679A36578A26679A165799E63779A64769A657599
64749863719865719B636E9B626D9A636E9B636E9B636E9B64709A626E98636F995F6C96
5E6C935E6C935A69925F6E975B6C975D6E9A5C6F9A5F719F5E73A26175A76276A96276AB
6679B1687BB3687BB5687BB5687DB6657AB1667AAF677BAE6576AA6678AA6779A96476A6
6778A66878A96878A96575A86575A96273A76373A76071A56171A56272A66171A56374A8
6071A55F71A36070A35F6FA05D6F9D5C6F9A5D6E995A6C945D6C935D6D915B6B8F56688C
5B6B8F5A6A8E58688A57678959698B546485576685586786556483526381536283546486
51618553628952618A51628D4E5F8A4E5F8B4C5D8B4C5D8B4B5C8A4A5B894A5B89475884
495A86495A85495A8543557D45577F45577D46587E44567C43557B40527A42537E43547F
3F507C41527E3E4F7B3D4E7A40517D3C4D793C4D7B3B4C7A394C773A4D783849743A4C74
3A49743D4A743A477338456F34416D33406C35426E33406C34416D33426D32406D32416C
2E3F6A30426A2E40682B3D65273B60273D62293D60263A5D25395C263A5F24385D27395D
23355925355724345623335423325327345427325026314F253050222D4D252F53252E55
212A53222B561E29561C29561B2A551C2B561B2A5316285018274E19294D152348152346
1926481926461722421821401E25421D2440151C38111834
151A16161B151A1D161D20191F22191D201721241D25282122251E161B14191E17181F17
161D15141B13171E16141B13181F171A22171C22181D2317242A1E292C21292B1E27291C
272B1D262A1C2A2C212A2C212E2F2732332B32332D2D2F2A2F312C2D2F2A2A2F2B2D322E
2F35312D332F2F34302F3430313632313733353938383E3E3A40403A3F423B3E43373A3F
30353B2F343A2F343A3C40494A4D5652546051505E4544544140523E3F513F3E50454658
45465A48495E595B70797B92888DA38B8FA88E92AB8F95AD929AB1949CB3939AB4929DB3
95A0B494A1B496A3B697A4B594A1B298A3B59BA6BA9BA6BA9DA9BF9BA7BF9CA8C29CA7C3
9BA9C49AA8C39BA9C69BA9C699A8C597A8C697A8C698ABC996A9C797ACCB99ACCD96AACB
97ABCC97ABCC96AACD98ACD198ACD197ABD098AAD098AAD296A8D096A8D096A7D296A7D2
95A6D295A6D296A4D393A4D293A4D292A4D292A3D191A3D18DA0CB8EA3CE8DA3CC8BA1CA
8AA2C88BA3C78BA3C789A1C588A0C6889EC58C9FC9899CC68A9BC78899C78B99CA8997C8
8692C48791C48590BE7F8AB77C88B27B87B17884AE7682AC7580AD727FAB717EAB6E7CAB
687AAA687AAA6779AB6378A76277A46177A06177A05E7499597092607594617494637394
637394637092667094646C91656E95666F96666F96666F96626B92646D94646D94626B92
656E955F6B935E6A945E69965D6A975D6A975E6C9B6270A16070A36171A55F6FA35D6EA4
6071A96677AF6778B0697CB4687DB4657AAF677BAE677BAD6479A8667BA8657AA5657AA5
6679A4657AA5677CA9657AA96176A55F73A56375A76074A66173A56072A45F70A46273A7
6072A45F71A35F71A35E70A05A6C9A596C975B6E995B6E985E6F9A5C6E965B6D955A6E93
5C6E925A6C9056688C576A8B55688956668857658859678A546486516485546488536589
516389536289516087505F865362894E5D844F5E874F5E87505F884E5D864C5B844A5C84
495C84465A7F465A7F44587D485C8145597E43577C42567B43577C41547C3F527A41547C
3F527C3F527C3E517B3C4F793D4E793C4D783E4D763C4E763A4C74394B73394B7337496F
394B7339486F36456E36456C35446D35446D35446D35446D34436C32416A314069324168
3241683141652F3F6328385C273A5B2A3D5D29395A283859273A5B26395A273A5B273758
26375526355227365325354F24344D25354E26354C26354C24324C22304B242F4F232D51
242C53212A552028561D28561C26571A26561B27571B29561B28541C295318254F16244B
1826491926481A25451823411A243F1C233D171D35161C34
191C151D20191F221923261D25281D20231A23261D252A232429231F241E1D241D1D241D
1A211A19231B172119181F18171E17181F171C241922281C292F212A2E202C30212C301F
2A2E1D2B2F202F312333352836382B373A2F32332B2E312A30332C2E302B2C312D313632
363B37323733333834313534333736313536383C3F43474A42454A35383D33363D35383F
2E33392E3339383C4552555E5B5D6952546049485848495B4A4D5E3C3F523D40533C4155
3E43594248606A70888E96AD8C93AD8E95AF8E95AF9097B1939BB2939EB4949EB7949FB5
96A3B698A5B897A4B796A3B698A3B79AA5BB99A4BA9AA4BD9CA6BF9DA7C29CA5C29EA9C7
98A6C39BA9C699A7C49BA9C698A9C795A8C697AAC896ABC895AAC797ACC996AACB97AECE
95ACCC95ACCC99AFD498AED397ADD495ABD299ACD49AADD598ABD398ABD397AAD495ABD4
95AAD596ABD699ABD994A9D692A7D490A5D291A6D38FA4CF90A5D08FA5CE8CA2CB8FA5CC
8EA6CC8BA3C788A0C489A1C7889FC8889EC7879CC7899BC9889ACA8799C98A9ACD8A9ACD
8B99CA8A98C78A97C48A97C18391B88290B7808DB77F8CB67D8AB47D8AB67C8AB77586B4
6F81B16C81B06B7DAF657AA96479A66277A26177A05A70955970925B6F905C6F8F5D7090
627391606F8E636D90626C8F626C90626C90646E92626C90616A91616A91626B92626B92
626B92606C945F6B955F6A975D68965B67975F6B9B5D6B9C5E6B9F5C6C9F58689C5B6B9F
5C6DA16172A66374A86576AA6175A86478AA677CAB667BAA6479A6667BA6667BA6657BA4
657BA4657CA6647BA7637AA66177A65E74A36177A65D73A25F74A35E73A25F73A55C70A2
5D72A15C71A05B709F5A6F9E596E9B586D9A576C99586D98596E99576D96596F98576D96
586E95586E9355698E55698E566A8D53678A55678D55678D53658B52668B52648A53658B
52648A506288526188526085536186515F82515F845060844F5F834F5F834C5C80485A7E
485C7F435A7C44587B435A7C465A7D445B7D41557841577C42587D3F557A40537B3F527A
3F527A40537B3E547B3A4E733C4E763D4F753E4D743B4D73394B71394B73384A72354870
384B73374A7236497134476F36487032446C32446C32446C32466B2F43662F4165324266
3242643040612E3E5F2C3B5C2C3B5A2F3E5D2C3B5A2C3B5A2B3A5B29395A2A3B59273856
29385526365027375025354E25354C24354923344825354C27364D22304A202E4B202D4F
232D51222B54202C561F2A571E29571C2956202D5A1B28551926521C295318254F19274E
1725481827461A28451B274119253B1F2A3E192134181F31
22231D23241E23241C292C23292C2323291F22281E262C22252A2321282020251F212821
1F261F1B221B171D19191E18171C16171C15232821262C22272D212B31232D33252F3324
2D31222D3122323427383A2F383B30383E342F322B272C262A2F292C312B2C2E2B343633
3537363335343335343233353233372A2E31292E324F5458565B614C51574E515A4D5059
44475040434C393B4751535F6769764E505F444655474A5B484E5E444B5D4750613D485A
4A566C737F978692AA8A96AE8995AD8B97AF8E98B1939DB6939EB4939EB295A0B695A0B6
97A4B793A2B597A3BB96A2BA98A4BE99A5BF9AA5C19BA6C49AA5C39AA5C398A3C198A5C5
9CA9C998A5C599A8C59AABC797A8C695A8C695A8C694A9C696ABC895ADC994ABCB93ACCB
92ABCA94ADCC95ADD195ADD195ADD196AED294AAD197ADD496ACD595ACD594ABD493AAD3
92ABD490A9D291AAD391AAD38EA7D08EA7D08DA6CF8DA4CD8BA2CB8AA2C888A0C68BA3C9
8BA1C688A0C486A0C3849EC3869FC7849BC4859AC58297C48297C68297C68799C98395C5
8697C58899C58798C38799C18496BC8294B88594BB8594BD8392BB8392BD808EBB7E8CBB
7B8CBA7A8CBA7787B87486B67183B17285B07184AE6B7EA66B7FA46A7EA3687A9E65779B
65779B637599647498647297647297637196636F95657199616D97626E985F6B935E6A92
616D95626F99606D995E6D985D6B98576896586997596A98596A9859699A5B6C9A596A98
586A985A6C9A5D6E9C5E709E6072A06275A06477A2677AA5657BA4647AA3647BA5677EA8
647BA5637CA56078A46078A66078A65D75A35F77A55D75A15E75A15D74A05B729E5C739F
59709C586F9B59709C59709C59709A576E9A556D99546C98556D99566E9A536E99536E99
546D96556E965269924E668C4E658E51689151679050668F4F658C4F658C50638B51648C
50638B4F6189505F865161854F5F834E5E804F5F814E5E804D60814B5E7F495C7D475A7B
455879465A7B45587943577843567743577843557943577A3F557A3E54793F527A42557D
3E52773C50753E52773C50733D4F753E4D74384A703A4C72394B73394C76374A75344976
3249753148743249732F48713047702F476D2E466C2F476B2F47692E45652C40612E4161
2E3E5F2E3F5D2F3E5B303E5B2F3D5A2E3C592D3A5A2C39592B3A59293857283756273655
24355126375125374F22344C21334922344A22344A22344C24344D20314B20314D20314F
1F2E4F1E2C4F1D2B501F2D521D2B521F2D541B295018264D18244C19254B19254B192648
18274418284218283F1726391B2B3A1A2833132029121F27
27262121221C2829212D3027282E24242A2021271D252B21262E23232B20232821222720
21261F1A1F181B1D181E201B1E201B1F221B2C2F282E31282D30252E342830362A2E3428
2B2E232F322733362D393C33373C352F342D292E28252A24252A242C2E292F312C343432
3232302E2E2C3030303331342D2B2E3130353D3E433D40455A5A627A7D8474747E52555E
44475052555E4D4F5B61636F5D5F6C4548573D3F4E484B5C464D5D40495A4651635C697C
77869B8291A88392A98796AD8C98B08B97AF8E9AB48E9AB28F9BB1919DB3939FB596A2B8
95A4B794A3B898A4BC97A3BD97A3BD97A2BE96A1BF99A4C49AA5C596A3C397A4C496A3C3
99A6C696A5C498A9C798A9C796A9C795A8C695A8C693A8C597ACC996ABC894ABCA95ACCC
95ACCC93ACCB91A8CA94ACD094ACD094ACD094ACD293ABD190A7D092A9D293AAD391A8D1
90A9D292ABD490A9D28FA8D190A9D28EA7D08BA4CD8DA6CE8AA3CB89A2CA8AA1CA88A0C6
8AA0C5879FC3859FC4859EC6859EC7839CC5839AC68399C88298C78197C68397C98196C5
8297C48496C48497C28396C08396C08194BC8194BE8093BD8293BF7E8FBD7F8FC07E8EBF
7E8EBF7E8EBF7C8CBD7989BA788AB8778AB57487B27184AE6F82AC6E81A9697BA36A7CA4
687BA36578A06678A065779D64739A637299637198616F965F6C965E6B95616E985D6B92
5E6C935F6E955B6A935D6C955D6B985768945A6B975A6B97586995596A96596A96586994
5869945B6E985C6D985A6B965D6E9961729D6475A06475A06376A06477A16176A16378A5
6178A46179A75F77A75E76A65D75A55B73A35A72A059719D5B739F5A739C5A719B59709A
59709A576E98586F99576E98556E97556E97546C98536E99526D98506B96516C97506B96
4E6994506992516A925067904E658E51689151689150668D4E648B4E648B4F628A4E6189
4D61864E60864B5D834A5C804C5C804E5E804D5D7F4A5D7E495C7D475B7C495C7D485B7C
475A7A485B7B43567743567745587842557642547843557B4054793F557A42557D3F527A
3E52773D51743E52753C4E723E4E723D4D713A4A6E384A70374971394C76374A75334875
3045723047733047733049722C456E2F48702C436C2C446A2B43652B42622E41622F3F60
2D3D5E2E3D5C2F3D5A303E5B303B59303B59303B592A37572837562A39582A3958243553
26375525365424355121324E20314B22334D22334D21324E21324E21324E20314F1F304E
2131521B2B4C1C2B4C1D2D4E1B2A4B1C2B4C1B294C1B2A4B1B284A172446192646192744
17254016263D17263B1929391B2B3814252D0E1D24112025
2425201D2019272A212C2F26272D231F251B1E24181E241820261A242A1E272B1D282C1E
14180A15180D24251D26271F24251D24251F30312B32352E34372E36393031342D2E312A
282B2430322D363833333832333A332F362F2E3430262B27262B252B2D282E2F2A2E2D29
2F2B28302C29352F2F312829312829453C3F2D24293731358B868C9290958483893F4045
393C4365686F52555C464B5132363F222933323642494F5D4249594E5768677284758295
8692A88793AB8791AA8A94AF8E95B19097B38C95B28F99B48D99B1909CB292A1B692A1B6
91A2B493A4B693A2B794A3BA93A2B995A3BD96A4C196A4C197A4C498A5C599A6C898A5C7
97A6C796A5C697A7C997A7C996A6C796A6C795A6C493A6C495A8C695A8C696A6C795A8C8
97AACA97AACB95A9CA96AACD95A9CC93A9CE8FA5CC91A7CE90A6CD90A6CD8FA5CC90A6CD
91A7D092A8D192A5D092A7D290A5D290A5D28EA3D08DA4D08BA2CE8AA1CB889FC989A0CA
879EC7869DC6849BC5849DC6839BC7839BC9829ACA829ACA8199C98098C87E94C67E94C5
8096C77E92C48094C68094C67F93C57E92C47D91C37E92C47C90C27C90C37E8FC37E8FC3
7D8FC17C8EC07D8FC17C8EBE7B8DBB798BB97A8CBA778AB57487B27386B07083AD7083AD
6D80AA6B7EA86B7CA76877A26576A164769E62749A5F71975D6F956072985D6F955B6D91
596B8F5B6B8F5A6A8E5A6A8E59689157668F5A69925968935968935A6994596893566890
586A92586A925968935867925B6A955F6E99606E9B616F9C6273A16273A16373A46373A6
6173A56175A85F73A85E73A85E73A85C71A65D73A55B71A25A719D586F9B576E9A59709C
586F9959709A576E97576E97536A93546D96516995526A96526A96526993506791506791
5067914F668F4F668F51678E51678C4F658A5067895266895064875064854E61824D6081
4D60814E61824D60814A5E814B5D814A5C80485A7E485A7E485B7C46597A485B7B465979
48587947577845557748587A43567741547543557B41537B3C4F773F527A3F51793F5177
3D51743B4F703B4E6F3D4D6F3C4C6E3C4C6E3B4B6D39496D3A4A6E3B4A71394871344570
3445703447723346713346712D426D2D436C32456F30426A2C3E642B3D612C3C602C3A5D
2D3C5D2E3B5D2E3B5B313C5C303B5B2E39572C3A572B3956283756283756263657263658
253557243456223254212F52233154253356243255223053212F52222F51202D4F212E50
202D4D1F2E4D1E2B4B1E2D4C1C2A471A28451826431B29461A2845182641182641192742
14223C15243B19253D1C283E1E2B3C152330101C28111D29
23241F1F201B2A2B2531342D282B24151B111B1E151A20141D2317252B1D292D1E303425
2224162123152B2B1F34342835352B2728202D2E262F322B32352E3439333335302D322E
30322F2D322E2C312D2B312D2C35302C35302A332E252C25272C26292B262C2D272E2D28
2E2B26302B27302826322827392F304036373E333754494D8D878B79747A605F64393A3F
2A2D3233383C30353B31383E313A41333C45434B56525A675F6877767F9081899C838EA2
8792A88792A88B92AC8E95B19297B59097B49299B6929CB7919DB5919DB58F9EB38FA0B4
92A3B793A4B893A4B893A3BA92A2B993A5BD93A2BF95A4C397A6C595A4C595A3C698A6C9
9BA9CC98A6C998A8CC97A7CB96A6C896A6C796A6C793A4C293A2C196A5C495A4C596A5C6
94A4C591A4C493A6C794A8C991A5C893A7CC8EA4CB8FA5CC8EA4CB8CA2C791A4CC8FA2CA
8EA1C98EA0C892A3CE93A4CF96A7D393A6D191A3D190A5D28EA3D08DA2CD8A9FCC89A0CA
889FC8859CC5849BC5859DC9829DC8819CC9829DCC7D98C7809BCA7D98C77F97C78098C8
8197C87D93C57E92C57F93C87E93C87D92C77B90C57C91C67B90C57A90C27A8EC37B8FC2
7B8FC27B8FC1788CBE788DBC788DBA788DBA788DBA798EB9758AB5758AB57489B47588B3
7386B17184AF7081AD6F80AC6F80AB6D7EA9687BA363779C6276995E72955E72955D7194
5B6E8F5A6D8E5C6C8E5B6B8F5A688F58668D58658F58679058679056658E55648D55648D
55678F54668E55648F53628D5665905667925B6A95596A965D6B9A5F6FA0616FA05F6FA2
5F70A45E6FA35F73A85E72A75D71A45D71A45E72A55C70A25B709D5A6F9C596E9B586D98
576C975A6F9A576D96586E97576D96556B94536A94536A94556A95536893526792526891
51679051678E51648C51658A5165885165864F62835063845063834F62825063834C5F7F
4D60804C60814A5E7F4A5E81495D80495D80495B8146587C46587C46597A485B7C485879
48577847567749597B47577944547640527643527940527A3D4F773E51793E50783D4F75
3B4D713B4E6F3B4E6F384B6C3C4C6E38486A39496B3B4B6D3A4A6C3A4A6E38486C38476E
38476E37497134457034457030436D30416C303F6A303F683140672D3C632E3C63303E63
2E3C5F2D3A5C2F3C5F313B5E303A5D2A37572D3A5A2C39592C3B5A2B3A59253455253556
253557223254223055212D53232F55253157222E54212D53262F56263054232D51242E51
2330521E2B4B1D2A4A1D2C491C2C461828421727411929421A284219283F19283F18273E
1B273F1A263E17233B1C283E1D2A3D162334101C2C111D2B
27262224231F2C2B2733322E30312C22241F252620262920272A1F2C30222C3021343827
3134232F32213033223336253436282B2F212C2F262F322B2F342D2F362F2F34302D3331
2B2F2E272D2B262C2A232C2926312B25302A263028242B242930292A2F282C2D282D2C28
2F2E2933302B332E2B463D3E4C43464E45485F565B655C616D666D57555A414247393C43
393E44343B413942493E494F3A474F3B485149535D646E7A788190848D9E8991A48F95AB
9096AE8E94AC9197B1959BB59299B59299B5939AB6929CB5939FB7939FB592A1B8909FB6
92A2B993A3BA93A5BB92A6BE90A4BD91A5C095A6C294A7C595A8C893A6C796A6C899A7CC
9CAACF99A7CC98A6CD96A4C998A6CB96A4C794A2C593A2C398A5C798A7C896A5C694A4C5
91A4C493A8C791A5C694A8CB91A5CA90A6CB8FA5CC8FA5CC8DA3C88CA3C58FA3C88EA2C5
8EA0C48C9EC28E9DC4909FC692A1CA8E9DC68E9DC88C9DC88B9CC7899CC68A9DC8869BC6
869DC6829BC3819AC3839FC7819EC67E9BC5809DC77E9BC57E9BC77E99C67F97C5839BC9
8098C6839BCB8197C97F95C78094C97E92C77F93C88195CA7F93C68094C67D91C47C90C2
7C91C07C91C0798FBE788FBB7890BC7992BB7992BB768FB7768DB6758CB6768DB77489B6
7388B5788AB87586B27384B07485B06F82AC7083AB6B7FA4687FA1647B9D65799C617598
6175985F73965E70945C6E945D6C9358679058679059689157669152638E54638C53628B
53658D51638B50628A50628A4F618951648C53658D556892576893576A955D6E9C5F71A1
5D6F9F5E73A25C71A05D72A15D729F5E73A05E70A05E709E5E709E5F729D5D709B5C6F99
5A6D975B6E98576A945A6D97586A92576991576893576893566993556892536690546791
55689054688D5264885366875366865164845262845063844F62825065845064854C6081
4C60814B6284475D82475D82455B80495F844A5D8545597E45597E45577B45577B48587A
4A597A47567746547745537646547942517845527C42517A3F51793F51793F4E753C4E74
3D4F733A4C70394C6D384C6D394C6C374A6A384B6B394C6C35486836496A36496A344768
36496A36486C35476D34466C3042682F416732416A303F683140672F3E65303E65324067
313F64303E61313D63303D602D3A5C2C395B2D3A5C2D3A5A2E3B5B2B3858273454293857
273657263556222F51242E51263054283256273155252F53262E53272F54252D52212B4F
222F52202D4F202F4E1C2D491E2F49192A44192B43182A40192A3E16273B16273B19283D
1A263E19253D18223B1B253E1A253B182337121A2D131C2D
27241F2B2823322F2A36332E31302C2E2D282C2C242B2D222C2E212F3324303423313622
303521323723323522333824323625252B1D292C212F352B2D342D2D342D2D3331303634
292F2D232927232927212A27252E29252E292930292A312A2B30292B2E272B2C272A2925
31302B423F3A3832324C46466C66686E686C867D82655E65322D3337343B3A3A42353841
3135402C333D353E47444E58414D594A5863626E7C7783917C8898878FA28B93A88C94A9
8F95AD8E94AC8F97AE9299B38F99B28F99B2929CB5919BB4939FB5909FB691A0B790A0B9
92A2BB92A4BC91A5BE90A4BD8FA4BF91A4C293A6C692A5C594A7C893A5C998A8CC95A5C9
9AA8CF98A6CD99A7CE97A5CA95A3C895A3C894A2C796A4C797A5C894A2C597A5C896A6C8
92A4C891A5C890A4C98FA3C88EA4C98DA3CA8FA5CC8DA3CA8EA4C98DA4C68FA3C88FA3C6
8CA0C38FA1C592A2C68F9EC5909FC6909FC88E9FCA8D9EC98C9DC88C9FC98A9DC8899EC9
889FC9859EC7839EC9819EC884A1CB80A0C77D9DC67E9EC7809DC77E9BC57E99C48098C4
7E96C27E96C28096C58096C58195C77F93C57D91C37C90C27C91C07D92C17E93C27C91C0
7B90BD788FBB768DB9748CB86F8AB5728DB8718DB5718DB5728BB4728AB6748AB97388B7
7287B67486B67586B47384B07485B17285AF7384AF7184AC7084A96E82A76C80A5697DA2
697DA2697DA265779F64769E64769E60729A63729B5D6F975E6F9A5C6D985C6B945A6C94
5B6D95586A9053658D54668C50648953678C51648C52658D556691576894596A985F709E
5E709E5E709E5E709E5F719F60739E5D709B5F709C5F709E5F709C5E6F9B5C6D995A6B97
5A6B975A6B97596A96596A965A689559689358679258679255669155669154659053648F
55678F54668C5565895262845565865565865262845161835265864F62834C5F804C6083
4B5F824B5F84495C84465C83475D86465C85495C86465983455880485A8247567D46557C
47557A47557A45537844527943517843507A43507A42517A3F517941537B404F783B4D73
3A4C723C4E72374B6E3A4E713A4E71374B6E374B6E374B6E35496C364A6D36486C35476B
36486C33456932446A34436A35446B35446B36436D33406A303E65313F66303C66323E66
2D3B60303C622F3B612F3B612C395C2C395C2C395C2E3B5E2B385A2A37572A3855293754
273552273552242F4D27304F283152283152272F53262E52262E52262E53242C51212A51
212E511E2C4F1B2A4B1C2D4B1A2B47172B44182943172941192B4117283C17283C19283F
18273E19253F1A243F1A243D1B253E19243A161E33161E31
342F2935302A35312839352C39352C37342B363428323023323323313423343925343925
3338243139223439233038232F36242932212B31252D352A2D342D2A312A2B2F2E2E3231
2B2F2E232726232726232726232824282D272C2E292A2C272C2D272C2D2526252021201B
2B28234E4945666060635D5D6E65686C6368635C63544D553A343E3A37423535412E303D
3033422C3242363D4D525B6C515C6E525D6F7481948491A48390A38592A58894AA8A96AC
8B97AD8D99AF919CB2909CB28C9BB08F9EB38E9DB28E9DB28F9FB68E9EB58F9FB890A1BB
8DA1BA90A4BD8FA4BF8EA3C08FA2C292A5C594A4C694A4C894A4C894A3CA96A4CB99A7CE
98A6CB98A6CB96A6CA97A7CB95A5C994A4C893A3C794A3CA94A3CA94A3CA95A4CD93A5CD
93A4CF91A2CD90A1CC91A4CE8DA3CC8DA3CC8DA4CD8BA3C990A6CD8FA5CA8DA3CA8BA1C6
8AA0C58CA0C58FA3C88DA0C8889EC5879DC6899EC9869BC6879CC7879CC7879CC9849BC7
8199C58199C57F9AC77B98C47C99C57D9AC47998C47A9AC37898C17A97BF7B97BF7B97BE
7894BB7C96BB7B92BB7D94BD7E95BE7D94BD7E93BE7D92BD7A8FBA7A8FBA7C91BE7D92BF
7B90BD778EBA778DBC758DBD748CBC768EBE738BBB728ABA748ABB748ABB7589BC7387BA
7484B87683B77683B77583B47684B17283AF7583B07182AD6F80AB7183AB6F81A96D7FA7
6F80AB6B7CA7687BA5687BA56679A36578A26475A06376A062759F60739D61739B607298
6072985C70935A6C92586A9057698F57698F5668905768935765925765925A68975A6899
5E6C9B5E6C9B616D9D626E9E616F9C62709D606E9B606E9B616F9E5E6C9B5D6B9A5C6A99
596A9859699A5B699A5C699D57679A56669758669758669559679657659254628F55648F
55648D55648D516389526188536387536186526087526087515F86515F845161854F5E85
505F864C5E864A5C844A5D87495C87465984485987495A88475884485683485782475480
48538046517E45507D45507D43507C44517B4150794251783F51793F51793E4F7A3B4C77
384A723A4D75374A72374A72394C74394C76384B75374A75344571354674364471364471
38467335437032406D323F6B35426E36436D35406D34406A333C65333C65323963323963
333B623139602F36602D345E2D365F2E37602E37602D365D2C365A2C37572C37552C3552
2A335029324F27314C27314C242E49262F4C283150252E4D252E4F222C4F1F294D1D2A4D
1F2B5119274C1B294C19294B19294A192A48192847192845182744192742182641182641
18264117254016213D17223E19233E19233C182037161E33
34312837342B373328383428383629373526383524373624373924363924353823363B25
353A243439233439232F37222D34222D34242C32262B31272B30292E332D2D322E2A2F2B
252A262328242227232429232528212528212A2D262A2B23292A222B2C242A2A2232322A
3C3932403D38605C59948E8E8983855C565A474248353037322F3A373542373644373948
3F425342475A4A4F636B7285767E93707B917B869C8591A78490A68594A98594A98897AC
899AAE899AAE8D9CAF8E9DB08D9EB08EA1B28E9FB38EA0B48D9FB58FA1B78FA0BA8EA2BB
8CA2BA8FA5BD91A6C18EA3C090A3C192A5C596A6C894A2C595A3C894A2C793A1C695A3C6
95A3C696A6C895A5C793A6C790A3C493A6C791A5C891A5CA91A5CA91A4CC91A4CE90A3CE
90A3CE91A4CF90A1CD8FA2CD8FA2CD8CA2CB8CA2CB8BA1CA8BA1C88CA2C98DA3C88BA1C6
8AA0C5899FC48BA1C88AA0C7869DC6859CC6879ECA849BC7839AC6849BC78298C78298C9
8098C87E96C67D97C87995C47995C47A97C37A96C57897C37996C07996BE7A96BE7A96BD
7A96BB7A96BB7B95BA7B95BA7B93B97D95BB7E95BE7E95BE7D94BE7D94BE7D94C07E94C3
7F94C37C92C37D93C57990C2768DC1768DC1768DC1738ABC768CBE768CBE7489BE7488BB
7485B97585B97683B77383B47182B07283AF7283B17182AE6E81AC6C7FAA6E81AC6C7FAA
6D7FAD6E80AE6D7FAD6B7DAB6A7CAA6A7CAA667BA8657AA5697BA96679A46879A46779A1
63769E63769E61739B60729A5E6F9A5E6D985E6C9B5C6A995E6C9D5A68995B679B5B679B
5E6A9C5F6B9D606C9E626E9E616D9D606D9A5F6B9B5F6B9B5F6D9C5E6C9B5A68995C6A9B
58689958689B5A679B59669B58689C55659856639756649557659455639054628F54628F
54638E52618C53628D505F8A53608A54618B4F5C88505D87515D87515E884F5C864E5D86
4F5E874B5D854A5B864A5B87485A88465886475788465687485685475584495784485582
46538045527F43507D424F7B424F7B42517A4150774251783F51773E50783D4E793B4C77
3A4C743B4E763A4D77364973374874374874394A78384977374576374576384476374375
374375374375353F72323C6D313B6C333E6C343C6B353D6B343B69343B67333A66323663
3237613338623135622E35632B33612C34622B33612D36612C355C2B35582D36572A3352
2B324F29304C29304C29304A26304926304B242D4A242D4A232E4C212E4E1F2C4E1E2B4E
1D2B4E19274C1A284D1A284D19274A19274A19274A1725481A274A1926481A2749192646
17244416244116244117224017223E19233E141B35121A31
30302636362A343527353626393A28343621363520363520363822373B24353922343620
3335203436213235203336233134233135272F32272E31282F322B2E312A2F322B262920
21241D23282122281E242C21252B1F20261A262C1E282C1E292D1F2B2E232E30252C2E23
34362B42433B787772ADACA864636139393B39383D31303632323C353743393B48343746
3C3F504A4F62585D716E7387787D937D839B838EA4838FA78692AA8594AB8796AB8697AB
8598A9879AAB8A9DAE8B9EAF8B9DB1899EB18A9CB2899EB38A9FB48CA1B68DA1BA8BA1B9
8CA2B98DA6BC8FA5BD8DA3BB90A6BE8FA3BC92A3BF94A5C394A3C495A4C595A4C394A3C2
93A4C293A7C290A5C090A5C28DA5C18FA6C58EA5C48EA5C58BA3C78BA3C98DA3CC8CA2CB
8BA0CB8EA3CE8FA1CF91A3D18C9ECC8DA0CB8C9FCA8AA0C9899FC6889EC389A0C2879EC0
869EC0869EC088A0C4869EC4869CC5869BC6859BCA8399CA8199C9829ACA8197C98197C9
7F96C88097C98097CB7A94C77B97C77995C47A96C67995C47C97C67994C17994C17994BF
7894BC7A96BE7893BE7893BE7991BD7A92BE7A92BE7B93BF7A92BE7991BF7C94C47B92C4
7C91C6798EC37C91C87C91C8768BC2768BC2758AC1758ABF7288BA748ABC7389BB7288BA
7286B97084B67084B66D81B36E83B26C83AF6C82B16C83AF6980AC677EAA697EAD687DAC
687CAE687CAE677BAE677BAE677BAE677BAE6278AA6278A96478AB6579AB687AAC6678A8
6777A86576A46775A66573A46673A76370A4606DA4606DA45F6CA35E6BA2606DA45C69A0
5F6AA05C679D5E6A9E5F6B9D606C9E5F6B9B5D699B5F6B9D5D699B5C689A5B679B59669A
58689B59699C5A679B57649855659857679857659656649356639055628F55628F54618E
53608D515E8B525F8C53608D505D8A525F8C515E8B505E8B505D8A4C5B864D5C874A5B86
495A854A5D87475A85485B86475987455785455787435585455684445583435482445281
43517E43517E42517C4150794251783F51753F51753E50743E50743C4E723B4A713B4D73
384A723E50783B4C773546713847723847723946733C48783B4576384275394376374174
394076394076383F75363D73303A6F313B7030376B323A6B31396A313968323A68313866
3037652E35632E34642E36652C346328305F2B31612A315F2A315D2A32592C31572C3254
2C3252282F4C272C4A262D49242E49252F4A222B48232C491F2A461E2C491D2A4A1E2D4E
1B2A4B19274A1B274D1B274D19254D1B274F1A265019254D19274E19274C17254A182649
18264916254614234416234317223E1A243F111832131931
2C2E212C30222D312231362230351F30351E343620353721363A2334382134362131331E
35332434322532332532332531312532342933342E33342E2E312A272A23272A21262920
25281F252B1F242C1F242C1D222A1B222B1A252E1D242D1C222B1A272E1E292D1F282C1E
414439777A717879734B4A4631313130313332333731323733363D3337403E424D434955
515765585D706B7084797E9284899F888EA6848EA78793AB8695AC8493AA8797AE8595AC
8698AC859AAD8A9CB0879CB18C9EB48BA0B5899DB58B9FB78CA0B88DA1B9899FB78DA3BB
8BA4BA8AA3B78DA3BA8DA3BA8DA3BA8DA3BA8FA3BB91A2BC91A2BE93A4C094A3C091A2BE
90A4BF8EA3BE8AA2BC8CA6BF8DA7C28BA6C38CA5C389A4C287A1C289A3C688A0C6879EC7
8A9FCA899EC98C9ECC8B9DCB899BC98B9DCB8A9CCA8A9DC8869CC5859BC2869CC1869CC1
849CC0859DC1859CC5859CC6859AC7869BCA8296C88399CA8299CB7F96C87F94C98095CA
7F94C97C93C77E95CB7C93C77A94C57995C57993C47A94C57893C27994C37893C07893C0
7792BF7893C07590BD7590BD7691C07691BE7691BE7792BF7691BE7590BF788FC1758CC0
778EC2758ABF778CC3768BC27388BF6F84BB7085BA7186BB7086B86F85B77087B96E85B7
6C84B46F87B76C84B46984B36B86B36883B06883B06883B06880AE647CAC6A80B1687EB0
677BAE677BAE667AAF677BB06376AE6578B06276AB5F73A86576AC6677AD6776AD6676AA
6777AB6373A76572A76572A76673A86370A7616EA5636FA9616DA7606DA4606DA45F6CA1
616CA25F6B9F606CA05E6A9C5E6A9C5C689A5E6A9C5D699B5D699B5A66985A6698576395
5866975765965866975A689956679556679356649157669155628C55628C55628E525F8C
515E8B53608D546090515D8D505C8C505E8D505E8F505E8D4E5C8B4B5C884B5C88495A85
495C86485B85465983495C87485B86435583445684445684455684445583425381425482
4152803D507B40537D3E517B3D50783E52773E52773D51743C50733A4E713C4E72384A70
384B733A4C74394B733B4A733948713A49723845713A45723B437238406F394172394172
383F73373E72394074363D712F396C313B6E2D376A2E3569303869303867313968313967
3138662F36642F35652E36652C34632A32612A306029305E29305C2A315B2B30562A3054
2C3254262C4C262D4A272E4B242E49232F49212C48202B471E2C471D2B461D2C491C2B4A
1C2B4A1A294A1A274A1B274D1B274F1C28521B27511B265318244E19254F17234B18244C
18264B162447142144132040172240151F3A13193113192F
2A2E1F262D1D282F1D28301B2B351D2D371F3136203136203639263336253536282D2D21
2F2C25322E2B2F2B282F2E2A37363433323031312F2F2F2D272924252722242922262B24
252B2121291C21291A222B1A1E2918202B1A222D1C222D1C202C18212A173A41315C6052
64675C55564E3F3E3A42413F2C2C2C2D2D2F292A2E2A2D322E3339262D354B525C5B616D
565C6A565D6F747B8E7F859B838BA2828DA3858FA88692AC8492AC8494AD8595AE8595AE
8595AE8A9CB48999B3899AB68B9AB78B9CB8899AB88D9EBC889CB78A9EB98BA0BB8BA1B9
89A2B88AA3B98CA5B98BA4B889A2B68DA6BA8DA3BA8BA1B98CA0B990A4BF8E9FBB8CA0BB
8BA0BD8BA3BF8AA4BF88A3C08AA5C287A4C289A4C288A3C189A3C488A2C588A0C6889EC7
889BC6899CC78C9DCB8C9DCB8B9CCA8C9DCB899BC9889AC88499C68398C58499C4869BC6
859AC5879CC98499C6869BCA8599CB8498CA8397CA8599CC8195C77E94C67F93C88195CA
8194CC7E93CA7A91C57C93C77A94C57892C37A94C57993C47994C37893C27893C27792C1
7590BF7590BF748FBE7792C17793C37894C37894C37591C07592BE7390BC748FBE768EBE
758DBD758BBA7589BB7185B77084B76E82B56F83B66D81B36B7FB16C82B36981B16580AF
6581B06480AF6180AE6180AE607FAB5F7EAA627EAD617DAC617CAB627AAA6379AB6379AB
6579AC6478AB6576AC6475AB6475AB6574AB6271A86271A86773AD6673AA6471A86572A9
6471A86471A86372A96272A66373A76171A45E6EA16070A36272A55F6FA05E6C9D6270A1
606C9E5E6A9A5F6B9B5C689A5C689A5B67995C689A5A66985A6696596595586494586494
56629254629156649156649156659055648D53628B53628954648854638A54618B54618D
53608D525E8E515D8F4F5B8D4F5D8E4E5C8D4D5A8E4C5C8D4B5B8C495A88495A86485985
495C86475A84465983475A8447588342537E4556824556844354823F507E3D4F7F3F5483
4254844257863D548038507C38517A3A537B3A517A395079354D73354D73374D74344A71
354B72354B72384B73384A7038486C38486C37456C36446B36426A35416B38406E35406D
343F6C36436F35426E323F6B2E3B672F3C69323D6B2E39672E39662F3A67313967323B66
313A652F36622F36623037632B325E29305C292D5A282C592A2F59292E562A3054292F51
262F4E252E4D242F4B212C48212D47202E481F2D471E2C461B2B441929421C2A471C2A47
1A29461A29481C294C1C254C1C254C19224B1A234E1A234E19224D18214C161F481A234C
192249182246161E43151D41151E3B161D37161C32151A2E
2A2E1F292D1C272E1C29301E2A331E2C361E2E36212D321E3134233133253131252E2E26
2C2B272F2B2A2E2A2B312D2E312F302F2D2E2E2E2C2B2B29262722282B242A2D262A2D26
22281E21271B21291C232B1C222D1D202D1C212C1E212C1C1B2615363F2E5C62545B5E53
4C4E4334352D33322E353432302E2F3535373637393C4043383D43464D556D747C6E7480
6B7380798092838BA0828DA3838FA5808FA68493AA8494AB8393AA8395AB8496AE8698B0
8797B08999B38C9BB88A99B68B9AB78B9CB88A9BB98B9CBA8C9DBB8A9DBB889BB98A9EB9
8A9FBA8DA3BB8FA5BD8DA3BB8BA1B88BA1B88BA3BB8CA1BC8CA1BC8A9FBC8CA1BE8DA2BF
89A0BF89A2C088A1BF87A2BF87A2BF87A5C186A3C185A2C088A3C189A4C28CA4C8869CC3
8699C3889BC68B9CCA8C9ECC8EA0CE8EA0D08D9FCF889CCE879BCD889CCE869ACC8397C9
8498CA8599CB869ACD8599CC8599CC8599CC8798CC8697CB8094C77F93C68195CA8195CA
8094C97B90C57990C47A91C57993C47993C47993C47994C37691C0738EBD7590BF7590BF
7590BF738EBD728DBC738FBE708CBC6F8EBC718DBC718EBA6F8CB86D8AB6708BBA6E89B6
7088B66F86B26F84B37085B46E83B26C81B06B80AF6D82B16C81B06B81B06880AE6681B0
6480AF6180AE6182AF5F80AD6182AF6081AE6281AF637FAE5F7BAA607BAA6279AB6379AB
6278A96579AB687CAF6478AB6879AD6678AA6575A96474A86676AA6272A66373A76474A8
6373A76273A96071A75F73A65F73A65C70A25D71A36075A45F71A15E6E9F5F6D9E5F6D9C
5F6B9B606C9C606A9B5C66995F699C5D679A5C689A5D699B5A6698596595586496596595
59659555628F54628F55639055648F55648D51608954638A55648B54638A52618A525F8C
525E8E505C8C505C8E4D598B4B588C4D5A8E4C598D4B5B8E4A5A8D4B5B8C475886475886
47588448598446578241537B43557D43557D46558045568143517E3E4F7D3D4F7D3E5382
3E53823E53823C528139517D38507C3A527E3A517D364D77384F79374E78354B74364C75
31477032486F35487034486D37496D334667324264334365314163334164334166324065
3242662F4165324266303F662F3E652F3E652D3A642D39632C39632E3B65313A652D365F
2D365F2C355E30355F30355F2E335D292E582B2E592A2D56282B54282C52292F53262C4E
282E50242D4C222D4B212F4A1F2D481F2D481D2D471C2C461C2C451D2D471C2B48192847
1B2A491A29481A274A19254B19254B152147172049171E4819204C1A214B1A214B1B234A
161E43191F43191F431A1E41171C3A151B3514192F101529
2C2C202A2B1D2A2C1E2E31203034232C341F2C301F2A2E1D2C2F1E2F31232E30232D2F24
2B2C242B2A252928242928242B2A262D2C2832312D2C2B262827222A2A222C2C242A2A22
24251D23261F21261F252C24232A22212B222229222229221F261E343C31696E674A4D46
3D3E38292A242D2C2831302E3433313A3A3A4345444142444E51566D72786F767E737A84
78808D80899A7E899D7A89A07D8DA47F91A78193A98095A88095A88297AA8196AB8398AD
8698AE8799AF899BB38B9DB58899B38B9CB68A9BB78B9CB88B9CBA8D9EBC8A9BB98B9BBC
8B9BBC8D9DBE8D9DBE8D9DBE8B9EBE8DA0C08B9FC08CA0C18CA0C18AA1C18BA2C289A0C0
87A0BF87A0BF87A0BF87A0BE88A1BF85A0BB87A2BF849FBA87A1BC8AA4BF8CA3C389A0C2
8AA0C5899FC88A9DC88A9FCC899ECD899ECD8A9ED1879DCF879DCF879DCF859BCD8399CB
8399CB8298CA8498CD8296CB8296CB8094C98293C98091C77E92C77E92C77C91C67B90C5
7B90C5788FC1778EC0758FC07690C1748EBF768EBE768EBE738BBB738BB9738BBB748CBC
728DBA6F8AB76F8CB86F8CB86D89B86E8BB76F8CB86E8BB76E8BB76D8AB46D88B56B86B3
7088B67187B66E84B36D83B26D83B26E85B16E83B06E83B06B80AD697EAB6980AC677FAD
6681B06480AF6581B16581B16281B05F7EAD617DAD6480B0617DAC637EAD637EAD647CAA
6179A5647BA7667DA9667DA96378A5657AA56779A76277A46378A55E75A15E75A15E76A4
5B73A35A71A35A71A35C73A55A71A35771A2586FA1596FA15A6EA15B6D9F5D6DA05E6C9D
5A68995C689A5C66995D679C60679D60679D5E689D5C669B5864985965975963985A6497
57639557639553619254629354629154629153619053618E51628E4E5F8B4D5E8C4E5C8B
4F5D8E4C5A8B4E5A8C4D598B4D598D4A568A4C578D4A578C4A578C4B588C485589475488
48568749578646558044537C43527B42517847547E47567F424F7B41507B3E4F7B3D4F7D
3C4E7C3D4F7D3B507D3B507B394E79384D7A3A4C7C3A4A7B39497A3A4B79354674364775
34477234477235487033476C334A6C2E45652D44632E45642C44602E43602E43602E4360
2C3F5D2C415E2D405E2C3F5F2C3F602B3B5D2D3B602A385F2C3A612C3A612E37602D365F
2B345D2A335A2A2F572E335B2E315A2B2E572D2F582B2D562C2B55292B52292D52242A4C
242A4C202948212A491F2A481C2A471E2C491C2B4A1C2B4A1A2B49192A481828491A2A4B
1B2B4C1A2A4B17254816244717274B17254A142046151E45172049182047192146191F43
191F431A1E411B1E411B1E3F181C39191B3416182F121429
322F262B2B1F2B2B1F2C2E202D31223034232B2F20292D1C2A2D1C2C2E202C2E212C2E21
2D2F242D2F242B2C2426271F26271F2A2B232E2E262F2F272A2A222B2B2329291F292921
2728222627222325202328241F2322212524222627212524292F2D2F343036383530322F
2E2E2C31322D3534323534323533344444446A6B6D494D5026292E74797F939AA47C848F
7A81917C87997C889E7C8BA27C8EA47E90A68095A88095A88297A88297A88597AB8597AB
8799AD899BAF8799AF8698AE889AB28A9CB48B9CB68C9DB98D9CBB8B9ABB8C9ABD8B99BC
8D9BC08D9BC08B99C08B99C08C9BC28C9EC48FA1C98B9EC6899FC6889EC5879FC5869EC2
89A1C5859DBF849CBE879EBE879EBD869EBA87A1BC859FBA869EB889A1BB889FBE89A0C0
8EA2C58CA2C9899EC9899ECB879ECA8197C68298CA859BCD849BCD849BCD849ACC8399CB
8399CB8296CB8296CB8296CB8192C88192C87F90C67E8FC57D8EC47C90C57D91C67B90C5
798EC3788FC1788FC1718BBC728CBD748EBF748CBC768EBE738BBB7189B97088B87189B9
7189B97189B76F8AB96E89B66C87B66D88B56E89B86D88B56C87B46D88B56F87B76F87B7
7086B77086B76F85B66E84B57086B76D83B26E83B06E83B06C81AE6A81AD667DA96880AE
667EAC647FAE627DAC5F79AA607CAC5B77A75D77A85D78A75E79A85F7AA96078A65B73A1
5C739F5F76A06077A15F76A05F769F60769F6278A16278A16279A25D769E5B749D59749F
5974A15A75A45A74A55872A35872A35771A45A74A75A71A55C70A55C6DA15C6CA05C699E
5B689D5B689D5B669C5B649B5F669C60679D5B659A596599576397566296566296546094
5763955664955461955461955260915161925161945161944F5F904C5E8E4F5F904D5D8E
4D5D8E4E5C8D4E5C8D505C8E4E5A8C4C588A4B558A4C568B4C588C4B578B4A568A495589
48548647538346517F45507D45517B44517B45517B46537D43507C43507C3F4D7A3F4D7C
3D4E7C3D4E7C3C4D7B3A4B773C4D7B3B4C7A3D497B3D497B3A46783B4777394577384675
38467535467236477233476C32496B2D46652C45632B44622D47622E48632C465F2A425C
2A425C2A3F5A2A3F5C2A3D5B2B3E5E2C3C5E2B395E2C385E2C385E29355B2E37602D345E
2C345B2931582A2F552C30562D2F582C2E572C2B552E2D572D2C542A2C53282C52252B4F
262C50222B4C20294A1E29491D2A4C1E2B4D1A284B1A284B19294B17274919294D1B2B4F
1B2B4D19294B182649142245172749162648152147162346161F46141C411820441A2044
191F411A1E41191C3D1C1F3E181C39191D36181A3113152A
2D2D252D2E262A2B232C2E232C30222B2F202A2E202C3021232718272B1C292D1F282C1E
292D1F2B2F212B2E2324271C1F221724271C27291E292B20292B20282A1F26271F26271F
2829232C2D282A2A2827272727272924252925262A292A2E25292C2B2F32303135303133
2D2E3031323437373936373937383C4F50546F72776E7178595C656F737E8E94A2808797
82899B818C9E818DA38291A88291A88494AB8394A88495A98796A98796A98796AB8897AE
8A99B08998AF8A99B08999B08B9BB48A9AB48A9BB78C9CBD8C9CBE8B9BBD8D9BC08A98BD
8C9BC28E9DC68C99C68E9BC88A99C48A9BC68C9DC98D9FCD8A9FCC8A9FCA8A9FCA899FC8
8AA0C9899FC6869CC1889CBF899EBD869BB8899CBC8598B68398B3859AB58499B8899DBE
8B9DC18B9FC4869CC5879CC7859CC6819AC38197C68197C88399CA8096C77F93C58094C6
8094C68193C58293C78192C88190C7808FC6828FC68390C78091C97F90C87F90C87D91C6
7B90C5788FC37990C2748BBD768EBE748CBC748BBD748BBD778DBF768CBE7389BB748ABC
7389BB7288B97389BB7086B77086B86E84B56F85B77086B76F85B67086B86F83B86F83B8
7083BB6E81B96D80B86D80B86E83B86B81B36A80B16A80B16B81B06880AE6981AF677FAD
657DAB647CAA647CAA637BAB637BAB637BAB627AAA5F77A76278A96278A76377A96577A7
6375A36477A26278A16278A16278A16477A16578A06379A0627AA05E759E5F76A06179A5
6179A75D75A55E75A75C73A55C73A75D74AA5C73A95F74A96074A95F70A65C6DA35D6CA3
5A69A05C69A05D68A05B669E5B649B5B649B5B679B586498586496576596566495536192
5462935363945262955464975161944D5F914E5F935061955162964A5E914C5D914C5E90
4D5F8F4D5D8E4E5C8B4D59894D59894C56874D55844C54854E56874E55894A51854D5586
4A55834B53824A5080494F7F474F7D444F7C464E7D46517F454F80444E7F424E80424E80
424C7F404A7D3E4A7C3C48783E4A7C3E4A7C40477B3F467A3D45763F47763F47783C4775
3B46733A477338477035446D33476C31486A2E45672C44662B44632A4562294461294461
2B45602B42612C40612C3F602E3E602C3A5F2B375D2F38612E37602E355F30355F2F345E
2C31592A2F572C30562B2F552D2F582D2F582C2E572B2D562A2E542A2E54272C52242C51
232B50232B50232D511E2B4E1F2B511F2B511D294F1D294F1C2A511C2A511C28501D2951
1C284E1C284E1B274D1A274A162447182547142144192346171F44161E42171F43161F40
182142151E3F181E40171D3D1B223F151C3610162E11162C
26272127282223241C26271F27291E24281A292D1F282C1E232719272B1D26291E282B20
26291E292F23272D211C22161C1F141D201521251722241925271C25261E26261E2C2B26
2E2D282524202A26252D2B2C2D2B2E2C2A2F2B282F2C2B312C2D322D2E332F2F37313139
32353C3C3F4644474E4548513A3E47494D58777E88828894737B887A8191848B9D81899C
848C9F848FA3848FA58591A98692AA8793AB8692AA8894AA8893A98994AA8B97AF8B97AF
8C98B28B99B38C9AB48999B28B99B38C9CB68E9FBD8B9BBC8D9DBF8D9DC18B99BE8E9CC3
8A99C08C9BC48F9CC98E9ACA8D9BC88A9BC78D9ECC8B9DCB8A9CCA8A9CCA899BC98C9FCA
899CC6899CC4889AC0889ABE879ABA8494B58494B58293B17E91AF7E92AD8093B18194B4
8093B48294B88093BB7A90B97B92BB7B92BB7C91BC7D92BF7E93C07E93C07E93C07A8FBC
7F91BF7E90BE7E8EBF8090C38090C48090C48491C68592C78291C88192CA8091C97E8FC5
7D91C67A8FC47B91C37990C2778FBF7890C07991C1768EBE778DBE788EBF788CBE778BBD
768ABC758AB97488BA758AB97589BB7388B77688BA7486B87486B87385B77485BB7384BA
7384BC7182BA7080BB6F82BA6D82B96D82B76B80B56B81B36A81B36A81B36981B1677FAF
677DAE687EAF667CAB6479A8687DAC687DAC677CAB667BAA687AAA6678A66676A76879A7
6576A26879A46879A46778A36576A16778A36778A361749E6177A05C729B5B709B5D729F
5B729E5A709F586E9F586EA0586DA2586DA2586CA1586CA15C6DA35F70A45E6DA45A69A0
59699D5B6AA15B689F5C69A059669B59669B59669A576498586697596798556394536192
5464955262935262955262955060934F5F924F60964D5E945061974F60944F60944D5F91
4C5E8E4B5D8B4C5D8B4D5B884D5A874C57844F58834C55804D55834E54844D53834D5482
4A52804B52804F53824E52824A5080495180474D7F485081474E82444E83454C82454C83
454C8342498041487E3D477C3E487D3F497E3F467A3E44763E44763F45754148763F4672
3D467139456D36426A36446B36456C32446A32466B2C42672A42642741622741622A4465
2A43622940622D41642D3F652D3D612E3C612E37602D365F2F36602C335D2E335D31345D
2E315A2E315A2C30562E32582E315A2C2F582C2F5A2C315B272F56252D54232C53232C53
252E55232C531F2B511E2A501F2B511F2B51202C541E2A521C28501E2A521F28511E2750
1E274E1D264D1A234A1A234A1B25491A2448192347192347192146192145192145182044
162141141F3F172041161F4019223F161D3913193111172D
2728222A2B2528282028292127291E25271C27291E27291E24271C24271C25261E272A21
23261F21241D24271E1D2017191C131E211822241925251B25251D25241F26231E292621
302B272B26222E2925342F2C373131373236302B31302D342F2E362E2E362C2C36343642
4145514A4D5C4C52604F556541485B3D45587782948B98AB7F8BA179859B7F8BA1808CA2
828EA4828EA48691A78590A6858FA88690A98990AA8A91AD8B92AE8B92AE8B95B08B97B1
8C97B38B99B48999B3899AB48B9BB58B9CB88B9CBA8B9BBC8D9DBE8B9BBD8E9CBF8A98BD
8D9BC08B99C08C99C38C99C58C9BC68B9CC88A9BC7899AC68899C58899C58B99C68A98C5
8B9AC58B9AC38998BF8696BA8797B98393B47D8DAE7B8CAA798AA87A8BA7778AA87487A7
7386A77587AB7688AE7284AC7184AC7285AD7386B07487B17588B27386B07689B17588B0
768CB5758BB47689B47689B47688B6798BB97C8EBE7D8DBE7C8CBF7A8ABE7889BD7889BD
788CBF7A8EC1788CC1758BBD758DBD748CBC758DBD738BB9748CB8748CB8748BB5738AB4
768BB6778DB6778AB5788BB57689B4798CB67788B47586B27785B47886B57885B97383B6
7484B87282B66F7FB36F80B46C80B5687DB26B80B76C81B86A7FB66A7FB4667BB0697EB3
677BAE6377AA697BAD6779A9687AAA697AA8697AA86977A46475A16576A26475A162739F
63729D65749F64739E64739E64739E63729D64729F62709D5E6F9D5E709E5D6F9D5C6E9C
5A6F9C5A709F576C9B5A6C9E596B9D5A6A9D57679B57679B57679A59699C5D6A9E5A6A9D
59699C56669956669A56669A56669A566699556598526295536396556598546495536394
536394526293536094556296536094525F93515E95505D944F5F934E5E914E5E914B5D8F
4B5D8D495B894A5B874C5D8849588149587F4A587D4C587E49557B4A537C4A517B4B527C
4B527C4A517B4C507D4C507F494D7C484E7E494C7F454B7F454A81454C83444983464C86
454B874349854147834046823D467F3C457C3E457B3C44753B43743B43713C436D3C446B
3B446B3A466C37436937436935436834436A2F41692F426A2A4067284066284066284066
284066293F662D40682B3D652B3A612B39602E37602E37602E365D2830572C31592E3359
2D32582D32582B30582C31592E335D282F59252C58242D58232F59212E58202D57202E55
212F561F2D521E2C511D2B501E2C511A284B18264B1D2A4D1B284B1D274B1D264D1D264D
1D254A1D254A1C244B1B234A1C244B1921481D254C1A2249172047172145182246192347
151F42151F42141C40161C3E151B3B1A1F3D171B36191D36
272823272822292A2427282027282022251A24271E26292023261D24271E24251F22231D
20221D20221D1E211A23261F22231D23241E23241C26261E27262126252027262225221D
26231E27241F35302C38343136322F3834353230333330372F2E362B2B3530323E383B4A
4349594D54664F5669485065474F665E6A8276859C8494AD7D8DA67A8AA37F8FA88291A8
8493AA8493A88591A78792A88792A88A92A9878EA8888FAB8B92AE8992AF8A93B08D98B4
8A98B38A99B68899B5869AB5899AB8879AB8879AB88A9DBD899CBC8A9DBE8C9CBE8B9BBF
8A9ABE8C9BC28A99C28799C18596C18899C48899C48998C38A99C28897C08A97C18A97C1
8B99C08A98BF8997BC8795BA8391B47D8DAF7D8DAE7C8CAD7B8CAA6C7F9D687B996B7E9E
6C7F9F6C7C9E6D7DA16B7AA16A79A06877A067769F6779A16779A164779F6578A0687BA3
6B7EA66C7FA76F82AC6C7FA96C7FA96F82AD7184AF7283B17687B57484B57686B97585B8
7587B97788BC7687BB798ABE768ABC7288B7758BBA7289B57289B3768DB6758CB5748AB3
7389B0768CB3758BB2758BB2778AB27689B17789B17284AC7483AE7785B27684B37383B4
7181B47181B47181B47080B36D7EB26A7EB16B7FB46A7DB56C80B56E82B76B7CB26B7CB0
6A7BAF687AAC6979AA6B7CAA6B7CAA6C7AA76D7CA76D7CA76B7AA565779F64779F687AA2
6877A06877A06675A06776A16774A06774A16672A26775A46373A46373A46171A46171A4
5C6E9E5A6F9E5D6FA15E6EA15E6B9F5D6A9E5C699E5B689D5A679B59669A58659959669A
57679A58689B58689B55659956689A546698546698536597526496556799546495536394
516192516192546092556193546092546092535F91515D8F515D8F4F5D8C4E5C8B4D5B8A
4B5C884B5C874A5B86495B834C5B8448577E49577C4B597E49557B48547A49527B49527B
49507A4A517B464D7949507C474E7A464D7B474D7D454B7D454B7F41487E42477F41487F
4248823F48814046803F457F3C457E3D487E3C46793B45763B46743A467039456B384568
3B486B3746673746673544653644673545693140672D3F672B3E66283E65293F682A4069
283E67273D662C3F692C3E662E3D642B395E2C385E2C385E2C365A2933572B33572B3357
2C34582A3458293357283158262F56273059222D5A1F2C58202D5921305B1F2E591F2E57
202D571F2D541E2C531C2A4F1C2A4F1B294E1A284D1C284E1D2A4D1C264A1B244B1C254C
1E264D1E264D1D224C1D224C19204A19204C1A214D1A214D1A234C1A234C18214A172047
151F43131D40161E42161C3E141B3814193612162F13152C
26282523252225272224292223291F21271D20261C21271D21271D25281F27282221221C
23241E24251F21221D25262129282425262126272223241F25262125272221232021231E
20221D1F211C292A25393B36333530292B282F2F2F2E2F332E2F342B2E373133403D404F
3D435351586A585E74555D7459657D68778E7888A17787A17888A27A8AA37B8BA47C8CA3
7F8FA6808FA48491A48491A28491A28691A38590A48590A68692AA8694AE8694AF8797B1
8796B38798B68497B5869BB8889BBB859AB98499B88599BA879BBC869ABD8799BD869ABF
8498BD849AC18399C0869CC58399C0879DC4879AC2899BC18799BD8699BA8797B98A9ABC
8B99BC8997BA8797B98494B67D8DAF7989AB7888AA778AAA7588A87386A66E81A16C7F9F
6E7E9F707FA06E7C9F6D7BA06C7A9F68769D65729C66739D65749D65779F61739B61729D
62739E60719C6475A06677A263749F6475A06576A16977A46876A36C78A86B77A76E7AAC
6F7DAE707DB1707DB1727FB37785B67181B27486B67287B47487B27689B3788BB5758BB2
7389B0768CB3778DB2748CB07389AE7389AE748AB17588B06F82AC7083AE6F82AD7082B0
7082B26D7DB06D7DB0717EB26F7FB06B7BAC6B7BAE6C7CAF6C79AD6D7AAE6E7CAD6B79AA
6979AA6C7AA96A78A56A79A46A79A46978A16978A16A79A068779E64769C65799E667A9F
65779D63759D62739E62739E64729F62709D6674A36674A36575A66373A66272A6616EA3
5D6DA15D6DA1616EA3606DA25E699F5C679D5C679D5A659B5C679D5E699F58659A58659A
59699D546698546698556799536498536498546599526397506496526496556596516192
4E5F8D50618D53608D525F8C52618C515E88525F89515D87535F89515D874F5B85515D87
4F5D844E5C834C5A814B5A834C598349568047557C48567D47547E48547E47537D44507A
49527D464F7A47507B464F7A464F7A454E79454E79444C7A434B793F4A784149783E4879
3E4A7C3F4B7D3E4A7C3B477939477838467538497734457135467136487037496D344768
3649693346643144623144622F42602F42622F42632A3C60293B5F293D622A3D65293C64
2A3D672B3E682A3D652A3C62293B5F293C5D273759283758283756233251253252273454
25345326355426355624315425315726325A222F5B212E5B202D5A1F2C59222F5C1F2C59
1F2A571F2B552029541F28512029521C28501B274F1B274F1A264E1D264F1C255019204E
1D24521C23511F23521B1F4E19204E1A214F191F4F181E4E18204E16214E16224C152149
152245151F42152040161F3C171E38151B3113182B111425
232728202423212622242925252A241E251D171E17181F171B20191E231C21241D20211B
21221C21221D21201C2322202424222525252525252628272223252226251E24241F2523
1D23211B211D2026222A302C282E2A242A28252B2B2B3033373C42363D47363C4A3B4252
3037494C54676870875C667F6C789077859F76849E75839E7987A27989A37989A27C8CA5
7D8DA47D8EA28190A38090A08191A08292A18493A68291A68292A98395AD8192AC8293AF
8495B38396B68398B78398B78398B78299B98097B7849BBB839ABC849BBD849ABF8298BD
829AC0829AC08299C2839BC1829AC0839BBF849ABF889CBF859AB98598B68598B68697B5
8697B58596B48697B58090B17989AA7686A87386A77386A77184A46E81A16F82A26F7FA0
6F7E9F6F7E9F6E7B9E6B779D6B779F6A769E69759F6774A064739E64739E60719D5F709C
5F709C5C6D995D6E9A5D6E9A5667925869945C6A975866935764915A66965F699A5E689B
606C9E616D9F616D9F6672A46E7AAA6C78A86F7DAA6F80AC6F80AB6E80A87587AF7B8EB6
7588B07288AF7389B0728AB0738AB36C83AC6F84AF7186B17085B06E83B06E83B06D82B1
687AAC6678AA6A7AAD6878A96A7BA96A7BA96977A66B79AA6D79AB6C78AA6D79A96C7AA9
6B79A86A78A56A78A56675A06678A063759D62749C62769B62769B6074995F759C62789F
5E749B6376A06679A46375A35F709E6171A26171A25E6EA15E6FA35E6FA5606FA85E6DA6
5C6BA45C6BA45B6AA35B6AA35968A157669D58679E57669D56659C57679B56659C526399
546599536498536498526397526397506195526397526496506496516395526293526391
4F608E50618D51608B505F8A50628A526188505E834F5D824E5C814F5B814F5B814D597F
4E5A824D5B824C59834A59824A578348558147548147548146538048558245527F45507E
444F7D444F7C444C7A444C7A454E79404C76424E78414D773F4B753F4B753E4A743E4B75
3948733B4A753B49763E4C7937487435467235467233467133467036497335487033476C
3347683247662E43622F44632F44612D42612E41612A3D5E2A3D5E2B3D612C3E642A3C64
2B3E662B3E662B3D632A3C60293B5F2A3D5E26395A273759253556243553243553243553
22355323365424345523315423315624325923305A212E5A1E2B581E2B581F2A58202B59
212C59232B592229552027531F26501D264F1C254E1E27501C255018214C1C23511A214F
1C23511D24521B1F4F1A1E4E181F4D171E4C181E4E161E4D15204E15204D15214B142249
132146122142101D3D121D39141F35161E31141C29141A26
25262A1E1F2320212325292A2C30311C201F090F0F0D1311151B17191E1823252020221D
21221D22231E1F1E1C1E1E1E292A2C2C2D312B2C3125282D23262D21262A21262C20282B
1B25261923241C28281E2A2A1F2B2B1D2929152022182629606D736B7881232F3D243040
2E394D465167636D866C78926F7B9575819B76829C79859F7A85A17A85A17A88A27C8CA5
7C8CA37B8DA17C8EA27F92A38093A48194A58295A67F94A78095AA7F95AC8094AF8093B1
8295B58295B68296B78299B98198B88199BB8098BA8199BB8098BA8199BB829ABC8199BB
7F97BB829ABE829AC0829AC08199BF7F97BB7F97BB8198B88098B48398B3859BB38599B2
8498B08397B07F93AC7488A37586A47282A37383A46F82A26E81A16D80A06D7D9E6D7C9D
6C7B9C6A789B69779E68749E6873A067729F6772A06874A46573A26573A46471A56370A4
606E9F5E6C9D5F6D9C5E6C9B5B6C9A5B6C9A5A68975965955B67975B6799596396586295
5B65985C66995B6596606A9B626D9B646F9C64719B63709A65729C62719A67769F6B7AA3
6B7AA5697AA6697BA9667BAA677DAE657BAC6A80B2697FB1697FB1697FB16A80B26A80B2
677BAE6879AD697BAD697BAB697BA9697BA96A7BA96B7CAA6D7BAA6C7AA96B79AA6B79AA
6878A96779A76274A26274A26176A16077A15F769F60789E5D759B5C759D5C739D5D749E
5D74A05F74A35D71A35D71A45C70A35E72A75B6FA4576BA0576AA2576AA4586BA65B6EA9
576BA85569A65569A65468A35369A3546AA3546AA350699F4E689B50679B50679B51669B
4E64964F63965064975064975064974E62955163955264945264945062924F5F90516290
4D5F8D50638E4C5F8A495C864C62894E62874D5F834D5D814E5E804D5B7E4C5A7F4A5980
4A5982495883495784475884465483455384414E824653884451863F4C80424E82444E81
454F82474E82454B7D434B7C424A79414977434C77414A753D49713E4A723C4A713B4A71
39496D38486C3A49703C4B74384772364471364471324371364775354674364775354674
33446F35467131436B31456A3044672940622B3F622A3E5F293D5E293D60283C5F2A3E63
293B612C3E642D3D6127395D27395D27395F26385E23355B223458203256203354203354
1E3151213454203354213153233357223256212F56202E551F2B551D2953202954202954
212A55232A562229551F26521D244E1F26501E254F1B244B1B244D1A234C19204A1C234D
1B224E1A214D1B1F4E1A1E4D1A214F181F4D171F4E161E4D131E4C13204C121F49112047
1020440F1F410D1C3B10203A0F1E33111E2F131D29131B26
28272D222126201F242223271B1C20161A1D14181B1A1E1F1A1E1D191E1A1F211C1E201B
1F201B1E1F1A1B1A182020222F30342E3136282B3222252E21252E20242D1F262E1D242C
1821261924281B262A202B2F1D2A30202D332332394250594F606A4757662C3C4C3A495C
4E5D726A799076829A75819B77839B7D89A17B879F7D89A17D87A07D89A37B8AA17D8DA4
7C8CA37D8FA37D92A57C91A47E93A67F96A87F95AA8096AD7F98AE7E96AE7F94B18194B4
8093B37F92B38094B58097B78097B78098BA7F97B97F97B97F97B97F97B97D95B77F97B9
8098BC8098BC8096BD8197BE7E96BA7D95B97D95B77D96B57F96B57F97B38199B37F97AF
859BB38096AE788DA87487A57184A47080A16E7EA06C7FA06C7FA06A7D9E69799B667698
65759964749863729B64719D616E9B5F6C99606C9C616F9E5F6D9E606DA15E6B9F5B689C
5A679B586697586697576596566697566493556191566292566091535D8E545B8F535B8C
545C8D515C8A515C8A525D8A55618B556189535F8557638958648A58668B5D69915E6B95
606D995F6C99616FA06070A36172A66074A96679B16477AF6578B0687BB3687DB46A7FB6
687CB1697AB0697AAE6B7DAF6A7CAE697BAB6979AA6B7BAC6A7AAB6A78A96D7BAC6A7AAB
6575A86577A76476A85E73A25E74A35D75A16077A35F78A15C759E5B749D59719D5A709F
5A70A15B71A35A6EA15B70A55B6FA45D72A95A6FA6596EA55A6DA7596CA7596DA8596DA8
566CA8566CA8566CA8526AA6526AA6536CA5526DA44F6A9F4E6A9C4D6999516B9E4E6597
5167985266985465995465995466985163955363945262934F5F904D5E8C4D5D8E4C5D8B
4A5C8A4B5E894B5C884B5E89475D84475D84495D824A5C82495B814B5D81485A8046587E
45577F455681445583445583425283405083424F844451863F4F833E4E82414D81445084
454F82454C80474D81454B7D454D7C424A78444C7A434C773F4B733F4B733D4B723B4A71
3A4A6E36466A34436A36456E3A49743A4877364475354374334074374478334075354276
33437633437432437130436E2E446D2A40652C40652B3F62293D60293D60273B5E27395F
2B3A612E3D642C3A612A39602E3D6428376029386124365E22345C2034592133591E3054
2133571E3054203054213155213155202E531F2D52223055212D531F2B511E274E1F284F
222A512129502328501F244C1F274E1E264D20284F1E264D1B234A182047192148192148
1C244B1D244E1C214B181C49141B47171E4A18214C17204B14204A14214B101E45101F46
0D1D410B1B3C0E1D3C0C1C360D1E32122232111D2B141E28
252328201E23232126201D241B191E17161B1B1B1D1F20221D1F1E191B181D1E191E1F1A
1E1D181B1A161F1E1C4240434241462F303520232A1F22291F232C1C232B1E222B181F27
161F261821281A232C202833232D39323E4E3F4C5D4653663B4A5F25364A1F2F46415168
71819A76869D75849B76859C7C889E7B889B7C899C7D8A9D7D8A9D7D8A9D7D8CA17B8C9E
7C8D9F7C8FA07B90A37B91A67E94A97E97AD7A92AC7B93AD7E96B07F97B38196B58095B4
8093B38295B58396B68297B68297B68299B97F96B68097B77F97B98098BA8096BB7F95BA
7D95B97E96BA7F95BC7E94BB7D93B87B91B67D93B87E95B77F98B77E97B6829BBA819AB8
8299B87E95B5758CAC768AAD7486AA7284A86D7FA3697B9F6B7DA16A7CA063759B62749A
6074995E71995E6F9A5D6E9A5C6D99596A985A6B975C6A995A68975A689959699A576798
5666975868995666975566945765945866935A67945863915A6291596190585F8D59608E
585F8B576089565F86576185536082505D7D515E7E515E7E515E7E546183566084596289
5A638E5B63915F67985D679C5C679D5C69A05F6BA55F6BA75F6EA96372AD6272AE6474B0
6575B06473AE6978B16A7BB16879AF6879AD6777AA6777AA6979AC6878AB6878AB6979AC
6777AB6779AB6576AA6175A76175A75E74A56175A75D73A45D73A25C72A15C72A35C70A2
5A6EA15C70A35D6EA25B6FA25C6DA15B6FA4596DA2596CA4586DA4586DA6586DA6576CA5
566AA55468A35468A35367A25367A25369A25167A04F669C4F669851699952689A506496
536595526494526293526293546293515F90525E8E546090515F8E505E8B4F5D8C4C5A89
4E5C8B4D5E8C4F5D8C4E5C89495A86495A85495C87495C86475A84485B85465981465981
45588245588241538142548242548241538141518240517F40517F3F507E434F7F455181
444E7F444C7B454B7B454B7B444B79434A78414978414978414C79424D7A3E4B773D4C77
3A497437487336457036447139477637447837427836417936407B37417C333F79344178
3342792E3F733042742C416E2C416C2B416A2A3D67293C642A3E632B3D632B3A6127365F
2A37612936602A36602B37612B376128356125325F26346122335E22345C213059223158
213057213057243259223057212F56212D55202C54202C52202C521F2C4F212B4E232D50
212A4B2026481F25471C224422284C23284E1F274C1B23481921461D22481D22481C2147
1D22481B20461A1F451A1F45161E43161E43151F43162044152245132043101D400F1D40
0D1C3D0E1D3C13213E101E39101F36142134121E2E121C28
211C201B191C1A181D221F2618161B1A191E1D1C212424262020221717171B1B1931312F
1A1B161D1C1A4543446262645757591D1E221C1F241F24281C212719202614191F151922
1920281A212B1C222E23293721283A272F442F39522F3B552B39533747614E5E7861738B
71819A72829972819876859A7A879A7986997B889B7E8B9E7D8A9D7B8A9D7C8BA07C8DA1
7C8EA27C8EA27A8FA47C92A97C92AA7D95AF7B93AF7C93B27D95B17E96B28095B47F94B3
8093B38295B58295B58396B68396B68095B48195B67F96B68097B98097B98197BC8298BD
8098BC8197BC7F95BC7F95BA7D93B87E94B97F95BA7F95BA7D94B67F96B87F95BA7E94B9
7F95BA8096BB7E94BB7D90B87B8EB67B8DB57B8DB5788AB07488AD778BB07385AB7486AE
7386AE6D80A86E81AC6D80AB697BA96779A76779A76678A66475A36474A56274A45E70A0
5F71A15D6F9F5B6C9A5B6C9A5D6B985B68945E69965B648F59628D5A618B595E88595E86
555D82545C81525C7F535E7E4D5876485671475572485371475270444F6D404A6D404A6E
464E754047734F5382555B8B52588C52598F565D94535C955A639C5F69A45D67A2626CA9
6872AD6571AB6975AF6D7AB16E7DB46A7AAE6878AC6878AC6676A96575A86878AC6575A9
6676AA6575A96474A86071A56172A66172A65F70A46071A55F71A35A6EA05D6EA25E6FA3
5F71A35C6EA05D6FA15E70A25A6B9F56679B596A9E596DA25B6FA4596EA5596CA4556AA1
576AA2576AA45366A05366A05568A25669A354679F52669B506497526698546698536595
56669757659454629155619155619155628F525C8D535E8C515C8A515E8A515C8A4E5B88
4F5B8B4D59894F5B8B4E5A8A4D5A874B59884B5C8A495B89485A88445782445782425580
43568144578244578244578243548040517D43547F42537E42517C43527D43507C44517D
46517E48507E454D7B424977444B79444B793F47783E46773F4A783F4A78404B793D4A77
3C4A773947743745723543703A46763945773A447938417838417A39427B354078343F77
323F742E3E712F3F722D3F6F2F416F2D406B293C672C3D692B3C67293A652A3964293662
2B38652A35632A35632934622B36642C376529346229366327346026355E222F591F2C56
26345B26325A232F59232C57212A53222B54232C55212A53232C53222C50222C4F222B4C
2029481F26431F28451B24431C25461F274B1B23481B23481D254A1A22471A22471C2449
1C24491921461A2247171F44151D41171F43192346162043142143152244142143101D3F
0D1A3A0F1C3C121D3B141F3B152139152034091223091221
211F221A1A1C17161B1E1D221E1D222021252021251F20241E1F23191A1C19191B212121
1717191414163535373131332526281A1E1F2024251F24271E23261D25271E23271A1F25
1C2029202731383E4A353B4B292E4233394F4248623C435F3F4A6653617C697792708099
75839D77869D77869D79889D7A899C7B8A9D7C8B9E7D8CA17B8A9F7E8DA27E8DA48090A9
7E90A87E8FA97D91AC7D92AD7C91AE7E93B08196B58095B47E96B27C94B07F96B58095B4
8093B38093B18194B28396B48396B48194B48093B48194B58193B78296BB7F95BA8096BB
849ABF8399BE8296BB8195BA7F96B87E95B78094B77E92B57E92B77F93B88093BB8093BD
8093BE8194BF8194BF7F92BD7F92BC7E91BB7E91BB7B8EB67B8DB37B8DB17C8CB07789AF
7A8CB47588B07285B07386B17085B06B80AD6E83B06D82B1697EAD697EAD677CAB6277A6
6277A66476A660719F62709F616F9C5F6C98616D955F688F5C658C5D678B586182586182
586182515A7B4C55764E59774B56723C47633C47633C45623B44633C45643942613B4465
3D43673D426842456E474A73454875494C794D4F7F4E5282535787545A8A555B8F575D91
5B60975C63995D679C5D699D636FA3636EA46774A96774A96774A96373A76575A86474A7
6474A86474A86373A76272A66474A76171A46370A46370A46171A46072A46171A56070A3
6070A15E6E9F5E6E9F5E6E9F5A6A9D5A6A9D5B6B9E596A9E5B6CA0576BA058699F55699E
5A6BA15869A15767A25565A05869A156679F57669F56659C55659957679A546497566495
56649557639355628F57629055608E545F8C525A89545C8A565F8A515D87525A884F5A87
515C8A4E59874E5889515D8D4F5B8B4E5A8A4C5A8B4C5A8B49598A465886435583435583
45568445568245568245568146558044537C435279435279414F7643517844517B47537D
48517C48507E454D7B424A78414977434B79424A7B434B7C3E48793D4778404A7B3D4876
3C49763A47733A47733B487437426F36416E38406E363E6D3840713840713A4273394172
313B6C323C6D323C6D2E3A6A303C6C2E3C6B2B396A29396A29396A2B3B6C283869283667
2836672834662733632A34652A34652A3261293160272F5E2A32602D366128315C262F58
252C56252C56262D57252C56222A51242C53272C56262B55232A54232B52222A4F20284C
232C4D1F28471F2A481B26441B26461C26491A24481721451B244B1B244B1A234A1B244B
1B244B192249182148182047151D44192148192347172145151F43162044141E41131D40
121F41101D3D131E3C131E3A141E39152036131B2E151C2E
1E201F1B1D1C1618171B1D1C1D1F1E1F21201E1F211C1D1F1C1D1F1C1D1F1E1E201A1B1D
1A1B1F15161A1C1D211D1E201A1E1F1C22222024272025281D25271F27291F222721242B
20242D232732424854383E4E3136493B4157393F574B526C646E89717D97707C96738299
77869D76859C78879E7C8BA07D8EA27D8EA27C8CA37E8EA57C8CA37D8DA47E8EA77E90A8
7D8EA87E8FAB8091AD7D90AE7E91B17F92B28093B47F92B28295B58196B57F94B38094B5
8093B37F92B28194B48194B48393B48393B48292B38393B58292B68193B78195B88296B9
8195B88498BD8294BA8193B77F93B68094B77F93B68092B87E90B67F91B97F90BC8091BD
7E90BE7F91BF8092C07D90BB7D90BB7E91BB7E91BB7D90B87C90B57E90B47A8CB0788AB0
7A8CB47B8EB8788BB6768BB8768DB9748BB77389B87389BA6F85B76E84B56F85B66C82B3
6D82B16B80AF6B7CAA697AA66778A466759E65739A637196616E91606D8F5E69895A6583
545F7F4F5A7A4E57784952734B56744752703F48673A43623841603A43623B4463393F5F
393F613A3E61393C5F3C3E643C3E653E406940426B44466F4B4D764D507B525582535585
545888565C8C5B63945A64955B67995D699B5D6A9E606DA1616EA26471A56472A36474A5
6272A56370A46370A46370A46370A46270A1636FA36470A2626FA35D6DA05F6FA25F6FA2
5F6FA060719F5D6E9C5B6C9A5B6B9C5B6B9E5B6B9E5B6B9E5E6EA15B6B9F59699D57689E
5B6AA159689F5867A055649D56659E55649D58649E56639A576499556296546195546195
53619253619255619155619156629255628F515B8C515C8A525D8A545F8C4F5A884E5987
505B894E5B884D59894E5A8A4C58884D5B8C4B588C4C598D475788485889445686425482
46578544558146558048578048578045547B45537A435176414F7442507743517844517B
434F79424D7A424D7A414C79424D7B414C7A3D47783D47783D497B3C487A3B45783C4677
3C49763A48753A47733A477338457137446E37436D38416C353E69363F6A383F6D383F6D
343C6A363E6C343C6B343C6B303B69313B6C2D396B2C3A6B28386929396A28386B263667
2636672735662634632835622A35632934612B345F262F5A2A315B2C345B262E55262E55
2B3058262B53292E56272F56272C542A2F57282D57282D57272B58252C562128521E264D
20284D1F294C1A27491926461A27471A294A18254715234619264918254819254B1B274D
1A264C19254B152149172049141D46161F48152147132043152245152245152244101D3F
132243101F3E101E3B131E3A141E37131E340F1629141B2D
1E231C1C2218141A101A20141C221822281E23261F20221D1A1C191A1C191C1D1F1B1C1E
13171A12171B191E221B2024181D211D252824292F1E252B1C2329181F251E212A21232F
2426322125312C3240323846363D4D373E4E404759656D806E798D6F7B91707C92768298
76859C77869D78889F7B8BA47A8CA4788CA4798BA37B8DA57B8DA57A8CA47C8EA67D8FA7
7D8EA87F90AA7E8FA9808FAC808FAE8392B38491B38392B38493B48593B68393B78393B7
8393B78393B78292B48292B48093B48393B48292B38392B38594B58393B48494B68393B5
8295B68294B88494B88292B68294B87F91B58092B88291BA8392BB8291BC8091BD7E90BE
7D92BF7D92BF7E93BE7C92BB7C92BB7E94BB7F95BC7C92B77B91B67E92B7798DB27B8EB6
7C8FB9788DB8768BBA778DBC758BBC7389BA7289BB7289BB7087BB7087BB6F86BA6E85B7
7187B87186B56E83B0687BA66D80AB697CA465799E65799C65779B6275966070925D6B8E
526182566385566083525C7F50587C4F577B4A5276495175474D7140466842486A43476A
3E42653C3F623B3E61393C5F37365E3B3A623A39613C3B633D3C6441436C484B76484B76
4A4E7B4D54804F57854C598652608D54628F5263915869975D6E9A606E9B62709D616F9C
62709D63719E6470A06571A16470A0636F9F6470A26470A06371A26371A2616FA05E6C9D
5C6C9D5C6C9D5E6C9B5F6D9C5E6C9B5C6A9B5B699A5B699A5A68995D6A9E5F6CA15A6A9E
5A679C5A679E59669D57649B55629954619855629956639A546498536397516195536397
526296526295526296506094536095525F93505D924F5C904C5C8F505E8F4E5C8D4E5C8B
4D5B8A4D5B8A4C5A8B4D5B8C49598A4858894B5B8E4A5A8D455787455787435583425482
44578246578245547F46557E46557E46557C45547B425178415077404F78404F78404F78
3D4E793D4E7A3F4D7A3C4A773C4A793E4C7B3C4A7B3B497A3D4A7E3B487C3A477B3A477B
37477839497A34467434477234477236477239487136456E34436C33416837406B363F68
323B64343D66353C6A353D6B313C69313C6A2B38652A3867293A68293A6829396A263765
25366225366226376229386125345B253358293659293658273252283353252E4F273051
252D51242C50262E53242E52252D54232B52232A56212854222957232A582229571F2853
1C25501B274F1A264C1826491826491828491827481829471A29481625441726471A294A
18274816244714224714224914214B15234A1322490E20440D1F431023440E21410C1F3F
0D203E0E1F3B10203A101E38131F35131E300F1628111828
161E11182013161C0E1C23131A231220261823261B1F22191B1E171C1D181C1C1A1E1E1E
17181A181C1F1C20231C21251B20241B202421262C262A33282C35292D36292B37292B37
2C2E3B2B2F3B2F3543373F4C3C445156606C616D7B75818F78859574819276839479889B
79889D7B8AA17989A0788AA2788CA4798DA6798DA6788CA57A8EA7788CA47C8DA77A8BA5
7D8EA87D8EA87E8DAA8290AD7E8BAB838DB0848CB0848EB18791B58491B4838FB7818FB6
8391B88291B88291B88291B88393B78090B48292B48191B38191B28090B18292B47F8FB1
8393B58292B68191B5808FB68291B88392B98392BD8190BB818FBC818FBC7B8CBA7A8CBA
7A8FBC788DBA798EB97A90B9778DB6778DB4788EB5778DB2778DB2768CB1758BB27389B0
748AB3758AB57489B8748AB97488BA758BBC7389BB7187B97087B97188BA7188BA7086B7
7187B87288B77188B46F86B27087B17087B06E85AE6D85AB6D83AA6C80A5697DA2687AA0
66769A68769B677399646D94626A915C648B575F86596186555A80494E74484E72444A6E
383C61373B5E33375A3135582E305631335A2D2F55282A502E2D552D2F582E315A31345F
393E683E45713E4674404B7846537F4655804A5885515F8C55639054638E5A67945B6895
5D6A975F6C995E6899606A9B606C9E5F6B9D5E6A9C5F6B9B5D6B9A5D6B9A5B69985B6998
5B69985A68975C6A995D69995D69995C68985D699B5B67995C66995C689A5C689C59669A
5B679B5B689C5A679C58659A536095546196566398536397556599526296526198526399
5061974E62975162984E5F974F60984E5F954B5C924D5E944A5B8F4D5F914C5C8D495A88
4A5B89495A88475584495786495A88475987475989465888455787445684435583435681
455882485A8244567E45547D47567D46587E47567D3F51793F517941527D3E4F7A3E4F7A
3F527D3D4F7D3C4D7B394A783B4C7A3D4E7C3D4B7C3A477B39467A3E4B7F3F4C80354578
37477A37477834467433467132457035487236487037466F36456C35446B323E66363F68
353E65343D64363D69353C6A3139673038662C37652C37652A36662937662B3968263765
25366226376226386024365C25355925355729365828355528335125304E262F50273051
242D4E252D51262E52232D51252E55232C55242D58242B59232A58222957272E5C1B2351
18204E1D295319254D18244A19274A19274A1928491C2B4A1A2948172645152443172645
1726451423421321441624491624490F1F430C1E420D1F430E21421023440D20400D203E
0F233E0F233C0B1B340C1B30121F32111D2D131A2A141C29
141C11161E11181E101920101B22121E25152024152022151D1F141B1B131C19141F1B18
1B1A161D1D1B2020202121231F20242122272929312B2B352A2C382B2D392A2C39282A37
313541343A46363E49444E5855626B6F7D866E7F896E7E8B71818E728492748694768797
768797798A9C7A8B9F7A8AA17A8CA27A8CA47889A3798AA47A8BA57E8FA97F8EAB7D8EAA
7E8FAB808FAC818EAE8590AE858EAF858EAF898FB3868CB0898EB4868EB3868DB78790B9
8591BB828FB9828FB98190B9808FB88190B98291B87E90B67E90B47D8FB37E90B47C8EB2
8092B67E90B67F91B77F91B98092BA8192BD7F90BE7F8FC07F8FC07D8DBE7E8EBF7C8CBD
7B8DBD798BB9798BB97A8DB87A8DB7778DB4768CB3758BB2768EB2768EB27389AE7389B0
7187B07388B37388B37388B57486B47186B3768BBA788DBC788DBC788DBA7489B6768DB9
758CB87189B57189B57189B5748CB87189B57088B46F87B36F88B17188B26C81AC6C7FA9
6C7EA66D7CA56E7AA4636F99606992626B945B628C555C86525983474F76464E73434B6F
373F63384162323D5D313C5C30385C2D35592F345A2C30562E30592D2F582D305B2B2E5B
303461363A67353C6A3C4272414978404B793F4A78444F7D4954824D58864F598A505A8B
5660915761925A61955A64975B679B5A669A5F6B9F606C9E5B699A5B699A5B6C9A5D6B9A
5A68975A67945A67945D68965E69975F6A985F699A5D67985F67985C6697596396586496
596396586496586496576596566495556598526295536396546497506195506197506197
4C60954A5F964B5E984B5E984A5D97485B93485B93495D92485C8F485C8E495B8B4B5C8A
4A5B87475884495784495784475884495A8648598748598546578342537F44558143547F
45577F45577D41537942547A45577F43567E44567E3F527C3E517B3D507B3E517C3D4F7D
3B4D7B394B7B3545763646773A48773D4B7A3D497B3B47793945773C487A3A4678384474
38447435437033416E32416C31406B33426B36436D36446B35426C323F6934406A353E69
343D66333C65353C68333A663138643239673135652E34642D35662B35682B3769263264
25316124325F25336023325D24335C24335A273359263356252F53263054272F56292E54
282D53262B51262B51242C53242C53252C56222955262A592327542125522428551D244E
1D244E2129501D254C1B23481C24491C24491D25491C26491B2548182547172446172444
162544152441132241132241152443122140101F400F1F401222430D1E3C0C1D3B0D1E3A
0E1F3B0E1E380E1E350F1E31142132131F2D131B26111924
191E17161B14151B11181E12191F13171D111C1F142021191C1D151B1A151D1A151F1B18
1E1A17201C19231F1E231F2029272A2D2B302A273028253033313E3D3D493234411E202D
282C38262C382C344157616D737F8B73818C6E7E8B70828E71838F748694758795758795
7688967889997A8B9D77889C7B8CA07C8CA37A8AA37A8AA47C8BA87D8CAB7F8EAD7E8DAC
7D8CAB808FAE808DAD828DAD858EAF848DAE898FB3878DB1858DB2878FB4858DB4858EB7
8591BB8692BC8691BE8390BC818EBA8190BB8392BD8192BD8193BB7F92BA7D90B87B8FB4
7D91B68397BC8093BB8093BB7D90B88295BF8597C57F91C17D8FBF8090C17E8EBF7A8CBC
7D8FBF798BB9798BB9798CB7798CB6798FB6748AB1758DB1748CB0738BAD728AAC748AAF
7086AB7086AD7386B07184AE7285AF6F82AC7285B07386B07184AE7086AD6F85AE7188B1
6F86AF6B84AD6B87AF6F8AB56C87B46A85B26B86B56C84B46C84B26E86B46B81B06E83B0
6D82AD6D80AB717FAC6D7AA76A77A36C77A46C77A4616C995E6A945D699159658D556187
515E814E5B7D4C597B475476404D6F3B45693842662F375E292E56272A53252853232852
2126501F244E262A57272B58303463313866333A683A416F3C4272424878444A7A484E7E
51598A535B8C51588C545E915662965460945763955967985B699A596A98576896586995
5A68955A69945865925764905A65935B66945B66945B65965B6596596595586494576393
5763935662925563925563945565965264945163955163955264964F6094526399516298
4C60954C5F974B5E984B5E984A5D95475A92495C94495D924F63964C60924B5D8D4B5D8B
4B5E89495A854C5D89495A85475A84485B85475A84475A8445588242557D41547C42557D
44587D42567B3F53783F537842557D42557F40537D40537E3D4F7D3C4E7C3D4F7F3B4D7D
3B4B7E37477A3646793848793947783C4A793D49793B47773C46773B48753A4573394672
38457139467035426C33406A2F3D6434426936426A36426A34406837436B38416C363F68
343D66353E67363F68353C66323963353966363A693135652D35662A3465293366263264
24306024315E25336024335E23325B23305A253159263258262F58252E57282F59282F59
252D54242C51242C53272F56252D54242B55242B55242B5522295321295020284F1E264D
1F274E20284D1F274C1D22481E234920254B22274D22284C1A2246182245192346172446
15224215244113204016244115234013213E142141132042121F410E1B3D0E1B3B0E1B3B
0E1B3B0E1C39121E38121E36121D31111D2D131D291A222D
191B1A181A191719161A1C19181D19181D19191D1C1B1C1E1B1C1E1C1C1E202022211F20
2622232723242A21242E25282E252A342A32302631413946524C5A4F4D5A4B4A58363847
333645393F4D606777727B8A737F8D6F7D8A6C7C8B70808F738392758594768695758594
7989967A8A977B8B9A7B8B9B7B8A9F7A89A07C88A27E89A77E8BAB7E8BAD7F8CAE818EB0
7D8AAC7F8EAF828FB1828FAF8491B1808DAD828CAF838DB0818BAE858FB3868FB6838FB7
838FB9838EBB828DBB838EBC828DBB828DBB818EBB8391BE8391BE8091BD7D90BA7D90B8
7A90B57D93B87B91B67A90B5798FB4798FB67A90B9788DB8768BB6788BB6788AB8788BB6
778AB5758AB57388B37288B17288AF7189AD7189AD6D87A86F8CAA6D8AA87089A8718AA9
718AA96F87A97086AB6E84A96E85A76F86A86E84A96E84A97087A97087A97288AD7088AE
7189AF748DB5718AB3738BB77088B66F87B57088B87087B96E86B66D85B56D85B56D85B5
6C84B26F85B46D83B26C81B06D7FAD6D7EAC6B7CAA697AA86576A26675A064739E57658C
5563885765885563864F5D8043517438466B3A466C384168353D642E365D272F56262B53
252A5022274D22264C2022492527502729522B2D5631335C3437623A3D683A3E6B414572
4B52804B53814A52814A5583515D8D4F5D8C4F5D8C4F608E526492546792566994596C97
596C96586B93576A94576A92576893586994566793546591556692566793526391516290
5264945062924F61914D5F914D61934D61934D61944E5F935364984F5F93506197506197
4C5D914D5E924A5B914B5C924C5D934B5C924D5E944A5B8F4B5C904E60924B5D8D4A5C8A
495B89475C87465B88475C87445B84435B81435B8141597F425C813F597C3E567A3E567A
41587A3F56783F557A3B51763F527A3F527C3F507E4050813D4D803E4E813B4B7F3A4980
3D4A813D4A813B487D3A477B3747783A48773A48773846733B487237466D37456C37456A
37456A37456A39456B374369344066313D63353E65363F66353E65353E65353E67313A61
313A61333C63333C632E375E2D365D2F375E3138622D34602B33612C37642C3765283562
24315E23325D26356025345D24315B222F59232F5925315927305B252E59252E59232C55
222B52232C53242E52233053233053222F52232D51222C501E284C202A4E202A4E1C264A
1C26491A24471E264A1D25491F244A1E234920244A1F244A1C21471921461C2449182246
192346172444172144172242182343152040172145172145161E43171F4411163E12173F
14194112173D131B3F151E3D111B360D182E0D15280D1627
1A1A1C18181A191A1C1C1D1F1C20211B1F201A1D221C1F241E1F241B1C211E1D221C1B20
241F232A242830272A32272B2E2329372C343C303A4D434E756D7C6E6A785D5A6B3B3D4C
474A5B585E6E6E7585737C8B6F7B8B6F7C8C6E7E8E718191728292728292758594758592
768693798A9479899878889879889B7B8AA1808AA57F8AA87E89A97D8AAC7D8AAD7F8CAF
7E8BAE7F8CAF7F8EAF808FB08291B07E8DAC818EB0818EB07C89AB808DB0818DB3818DB5
838EBB828DBA848CBB838BBA848CBB838EBC7F89BA7E8ABA818FBE7E8FBB7F90BC7B91B8
7A90B77A92B67D93B87C92B77991B5778FB3788FB8768DB67389B2758BB47689B4788BB6
758BB4748AB3748AB37389B07189AF6F87AB6E88A96B88A66D8AA86F8DA96E89A66E87A5
6F88A66C85A37188AA7087A96F86A67188A87289AB738AAA758EAD7089A8768DAF748CB0
728AB0748EB36F88B1718AB3728AB86E86B47086B86F85B76D84B66D84B66C83B56A81B3
6580AF647FAE677FAF657DAD677CAB697EAD697EAD687DAC687AA8687BA66C7AA76978A1
68779E657599606E93606E935262864A5A7E4A567E4A567E3F486F384168343C61262E53
1D234721274B1E2046191B411A1A401C1C421F1E4623224A24264F262851363964353A64
393D6A3F48733D45733D4A76424F7C495784485985485B8650638E4D628D4F628D546791
526891546A91556B9253699055689053668E546792536691516691546994536593506290
5166954E63924D61934B5F914A6092495F914B5F924B5F924D5D914F5F934D5E944D5E92
4A5A8E4B5B8E4B5B8F4B5B8F4C5C904D5D914A5A8E49598D495B8D495B8D485A8A475989
465B88465B88435A86465D87425B83415B803F597E3D577C3D5A7C3C597B3C56773D5778
3F57793E56783D55793B53773E517B3C4F7A3D4E7C39497A3B4B7F3F4F833F4B853B4781
404C863C49803B487F3A477B37477A3A4B793B49783948733B4A7139496D364668344466
354465334263374467374467384568323F62353E65363F66333C63353E65343D64313A61
303A5E2E385C2B385B2C395C303A5E313B5F2E355F2F38612E37622C38622936622A3763
25345F28376227365F25345D23305A25325C25315B232F59262F5A262F5A252E59252E57
212D551D294F212E51222F521E2D4E1F2E4F232D501C26491A27491B284A1D2A4D1D2A4C
1C294B1B28481D25491E264A1E23491F244A20234C1F224B1B20461A1F451B234A192146
162044182245151F421721441B2445151D41182045192148181D45171C44171A45151843
171A45171A4311163E12183C111A390E18330F172E10182D
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{320, 240},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000500000l2000`400?l00000o`00003ooooooom1
ooooo`00oooooom1ooooo`00oooooom1ooooo`00oooooom1ooooo`00oooooom1ooooo`00oooooom1
ooooo`00oooooom1ooooo`001oooool0900=1@8030L300/80@0:2P8020L300T81P0;10/0308:00d2
2P0@0PH04@<300`2000=1@8030@200X50P0;1P<020L500P62`091a@02`LN00`59`0>0bh0300`00d1
;`0<12d03@PX00/7800>2Ad04P/F01<:2`0C1`L03@@500/93P082@h01PX;00D920801@L600@020H9
00L520091@H02@D60P081PL0<P0;1@T02`D700d41`0;1@D01`H400T720071@P02`H=00d33P0?0`l0
4@@>01D53`0G20/06PP401H7000F1PH040H700h8300;2@`02PT700H50@0:1@803@H70107300=1Pd0
3PP:010;200>2@<04@X400h:1`081`l01`XC00X94@0920h02P@@00T33@081@`020H900X61@081`<0
20L200L91@0420T01`P<00L62`0;1`P030H600l61`0=1`L02PH30P0720<02P0620D010L<00D83@0:
2@l01PH800X52@091@@02`L600P70`0720<200H80`0=00P71@0920H020P600L71@081`<020L500/7
200;1P`020D<00L42`081PT01PH600P82P0200H72@0D00L82P051PP010P900<720061`T01@H:00H5
3@071Ph02@<=00X52`0:0`X02P@600T51P0:1PD01`H400P71@081PT01`D800X52@0;1PX200P61`03
00H610072@H01`T600801@L400d020T400L80`072@@01PP300@90`0320801@L200H80`061`801`P3
00H90P042@<010/400<01@`500`01@/700<<2@032`d010/E00885P021AH010DG00H64P071P`01`L7
00L80`061P@200H70P1<00P80`0720<01PL100<80P0420T00PTA00876P021bD01PDa00T5=`0=1CP0
40@b0142:`0?0B@03P4M00/3600<1Q802@T;00T91`0840L01Q<<00<@6@022R400PH[00P6;@0@1b80
40DE00h32`0=10L02PL>00P64`0;0a/03@8P00l18P0?01d03`4H00d2400710/01`L900H81`051`80
1@X400@=200230h000TH00468`010b`01`4]00l09`0@01X04P0>00d10`0;1P<01`P300H81`0420T0
20T>00L730081`d01P@?00P5400:11002`@<00d2200=1@<02PD200L60P071`L01PL;00H53@071Ph0
2P@>00T42P0;1`H020L300L60P801`P30P081`8030061P@01`L500P61`091`P030H600/51@0:1P<0
1`H200L71@062`D010T300<:0P800`T500<00`T700D:200420L00P0420L06@061`T01@H800D71P05
1`H01@H800H72@051PX01@H;00<63@031Pl01PH>00D53@0821@01@D?00P540071P/00`L800@81`03
2@T01PL;00H730081P/02@@:00/42`0=0`/02Oooool000Oooooo00d060h<01P@3@0H4`l061D@01TE
4P0I5A@06A<G01/A6@0P4aX08Q8F028D500P5A<081HD00808ALF01L08ATG024K6`0Q6al08A/U02LN
<@0]83`060P/01<3:00B12P040DU018:8P0D324050hL01HA5P0G3`d05P`:01491`0<2Pl02PT?00/;
3@0:2PX020P800L71`0200P61`0600X61`091@@030P700X61@0;1@L030H60P0=1@<07P0;1P<020@3
00T31@0>1@X03P<;01443@0B1@h05PX>01X>3P0L3`T06Pd501H;1`0C2@P03PP:00`82@0<20D030L3
00h60`0@1`D04PP901482@0C2`T05A4801HB1`0I4PX04`h:00`:3`09210030T@00`73@802`@<01d0
2PD;00d92P0:1PD02PH300X910092PH020X900L62`0:20d03`T;00l61`0@20H030L400`81@0:2@@0
2@X400P:1`0720X01PL;00P82P091`P02@P600T510081`<020P300L:0`062@801`T400H70P0200L7
1@0H00T91`0920H020L500/7200;1PX020D<00X73P091`X01`L900L82P061`/020L<00P72`061`T0
1`P:00@82@0720X01PL;00L630081`l02PD<00/6300:10P02PH70P0:1PD01@0920H020H700T72P08
1PT01`D800802`H:00<020H700L71@0820H00P0620D03@082PL020T400H80`0620<01@L200D:1003
20801`T400H80`0720<020T400H80`062P@00P052P@030062`D01@X400H;1`052`T01@X=00D:4005
2A@010HC00H54`081Q401`H<00L71`801`L505P02PT700T81P081`D02@P600P70`0820H01PP700D8
3@052AD01PPO00X9:`0?2S804PXc01D;<00G2B`050LU00h47@0?1Q/03`TE00l:400<2`L02@l600LB
30084AP01@`N00@88`071b<04@TN01085@0A20d03@L900T7300:21D03PTO01888`0E22H05@LQ01H7
700A1A<02`H<00T820082PL02P`700P=1P0940T0210B00L=6@072b@020P^00/4;P0E1b/05@DP01H4
4P0A1@T02`D500P71@082@/010P;00H7300820d01`H<00H53@071Ph02P@>00/4300>1@P03PH400/6
0P0920<020P600L82P071P`020D>00/63@0;10/030H800/7100920H020L500H70P081`<020T400P8
1P071`D020L500T81P0;1`H02`D50P0;1`@02@0820H020X500L<1P062`D01@X600D9200420T01@L9
00L82P0200H72@801PL;0P0720X0100720`01`P=00L83@071`l200@64P0?00P850061Q801PHB00H6
4P081Q401`L=00@82`021`X00`P;00<62`061Ph01`H<00P5300:0`/030D=00Wooooo0007ooooo`0a
02<H5P0S6AL09AXH02HL6`0[8b40;B@U02hS9`0`92P0<RHZ03DU9`0f9RL0>B/[03X/;00j:RX0>R`[
03T];@0k;bl0?c0e048c>P0^72P0=B0_03@M;@0c72h0<A`]02dK:@0[6bP0:AhV02LL800W8Ah09R4M
02DP6P0R7AX081/O01hI7`0S7R8091hP02HP800T81l08AdL02<O7P0T7Qh08ahK02<N6P0R7AT09B0L
02@O6`0T7AL09adI02LL6P0202PM6`0302XL700Y6Qd0:AdO0080:R0O02X0;2DO02/W7P0Y9AX0:2<M
02HQ7@0U81d09QhL02PO6P0W71H091XA02HI4@0W6Q809Q`B02HN4@0X8Q809B8A02@Q4P0Q7A807ALG
01`F6P0P5AT08ADI020D600Q5AT081DI01dD5@0O5QL06aHC01PC3`0D40`04`l>018<400;1@T040D9
01<9200E3@X03PT300d:0`0=3@D02``400`=1`0<30X200/;2@0600h=2@0>3@P03Pd800d>200>4@T0
3A<90P0<4PP0100=40T03Q0;00lA3P0A4@l2014@3P0D01DA4P0D41404a4D018@5@0;2Pl02``@00T:
3`0920h02PL>010=4`0G5aT05ALF01LH6P0E6AX051DI00l>4`0>3A804@`@014=3P0D4142014=3004
00h=2`0<2P/02`T<00`:3@803P`A00<03PX@00l:3P0@3Q400P0@4100200A4@l04A<@010B3@0A4`h0
418=00h@2`0<4@/03a4>0P0;3@X0<P0<3P/03@l<00h@2`0>3`X03Q0<00h@3@0<3P/03a4>00h@3@0@
4Pl04A<B00h?4@0<41<03PlD00l>500@3aD03P`A00/930092@T020P800`:2`0>2@d030L;00h93P0?
20l03`T=00l;300=2``030`<00h=4P0@3aL04Q0N01<>8P0F3R<0:R4f03`cB01BBEh0ACaA02`S=P0O
528091XR02<K6@0L6a<061XE010F5P0D6Ad05aXS01TI8`0N6b808A`P0P0M6a`0=`0M72407QdU024M
;P0V7C808aD^028C:P0K2Qd05`LD01872`0;1`D02P/600T:100:3@@030l800`>2`0C51T061LY01LD
<`0F3SD070ha01X:9@0K21/060PB01<:3`0=20`02PT>00L8300=3AD03PhE00h=4`0>3A803`hC00h=
4P0A3a807a/J01lJ5`0I5Q405QH>01HG4@0G61<05A<F01<A5P0P6B00<BL_034X:`0/8b@0;2HX02PT
9@0M6a`0820P01@F4`092`P01`T600T91`081`<00P091@806@0910402PH300`81@0920@020P600L9
20061`T01PL;00L830071``01PD;00@32@0510X01@@<00L63P061Ph01@D=00D84@072Q<01PPD00d?
700A4280518W01HG:@0K7B`00P0O7Rh02@0O7R`07R0/01dQ;00M8B`07B4Z01dO:`0O7b/08Al/024M
:`02028L:0Wooooo0007ooooo`0:02DI6@0R5QH09QXJ02LK6`0[7al0:b4P02dS900a9BL0;b<S03<U
9@80>2XY0140?2`/03/[:`0l;2`0?2h^03d_;`0n;S40?R/_03lZ<@12;C80@b`b04<^<`11;S00@C4b
044c<`0m<S00?3<^03Td:`0203Hb:@0A03Lb;P0j<C80>C0c03/`=00k<C80?cDf044g=P0n=S@0?CDc
03lg=@0l=340?SLa03/d;P0o>300@3L`03lf;@12=Rl00P12<bh0;`14=C00ASLd04Df<`14=S<0A3Te
04Dl=`15?SP0@c`d040l<`14?CL0@SXg040f=@12=cD0@C<`044b;@10<BX0>bdT03T[800h;1h0=bhM
03H_700b;AT0<bhK03@^800b:B80;b@R038T8`0c8b<0<B4Q038T900c9bL0<BDU030V9`0b:2L0;R@R
02TP7P0O5QL05Pd@01H;3`0E2``050X901L@2P0G4`X051@:01<C1`0D5P/05aT>00805aP@02P061P@
01XJ4P0M7AD06a`D01LJ4@0F6Q<05a`E01DK4@0D6A805a`E01TK5P0H6QL06QXJ01dK700R7B408AdN
028M8@0N6Al05aDJ00l>4`0>3A<030/A00T840091Pl0:2</044oA011@4D0>ca002DV:P0P8BD071/P
01TG6P0L6Qd06QPI01XI5`0K6QP05QDC01<B400B41404@l@0P0C4A@0600C4aD061DJ01dH7P0K6Ah0
6aTL01lO8@0P82808B4Q020P800L71`06adL01TK6P0G6aX06AXL01DF600D5AL05AHH01DG5P0E5a@0
5QLB01DD4@0H5aD06APF01/J60807A/L02H08AlR020P8P0G5Q/06QTN01/I7P0G5AX0518E010>4@0;
2`/03P`=018=4@0D3a<0614H024H800O5Ah07Q<I01`C5P0A2`/03@L701PB4P0I4a<05a4E01P>5P0V
72@0@3Ho05U?FP1PEF<0ET]K04DjB00e:CD0@CHl0598A`14?SX0=cHb03<c<@0b<S80;Rh^030^;`80
=S8c00h0=S8a03<a<P0d<SD0>CHm03/e@@0d:c`08AHW01D86@0D1QD05`XD01P=4@0E4Ph04A8<010A
2`803Pl703T03@h9014A4@0I5Ql08A`b028I=00U638070dT01/=7P0I2aP05@/D010;4P0=2Q403@`D
010>6@0I5b806QLP01/J800P7b@08B0U02<Q900P71d071PG01PD4@0F4`h04a8=01XI5@0U8B809R0T
02@K800W7280=BX`05Q=D`1KDUL0E4mD04A2A`0e=CL08B8T00T;2P02104010H300P81P071P@020L5
00T5100;1`H020L500T81P071`L01`L900H72`061``020L=00L530071A00108=00D53`081Q<00P05
1A402P0621@020XG018E900D5bH07B0a02@U>P0[;440=cQ<03PkCP0l?E4203`mC`0:03/nC@0o@U40
?D1?03XmC00j?4/0>ce<03lnCP11?dd0>cM603Hb@@Wooooo0007ooooo`0X02LM7P0T6Q/09adN02XN
800/8200;28Q02hT8P0_9B<0<2LR03@Y8`0f:bD0=b`V03X]9`0m;R/0?2dZ03`^;@0l;Rh0?2d`03//
<@0k;2l0?2d`03``<P0m<C40>Bl]03Tb;00i<RX0>SH[03Pf:@0g=2P0>S<Y03/d:P0k<R/0?34_03``
<00o<C40@C4b04<c=014=3D0ACDe04@f=@80@C<b00L0@C<`04<f<014=bl0@cH]04@h;014=R`0ASD]
0080AcH_00D0AS@`04Le<@16=c80ASLd04Tj=`0204Ti>@0_04Ph>019>c/0ASPh04@e>014=SH0@30`
03l`;@0m;RT0>2TQ03HX7@0i:ah0>RdM03L[6`0f:QX0=B`K03@[700h;200=2HM038S700e9Ql0=BHS
03@T900b92<0<B<R038T900d9RD0<R@S034R8P0J30`06@l@01T?3P0G3@`05@d:01<@2@0G5`d06QX>
01`N400I6`h061X<01dO4P0K7A006Q`?01XL4@0L7AD061TC01<F3`0H6QH00P0F61D201TK600801XJ
600K6a/071XM02DN9@0W82L091dU028K8`0I4A`2018<5P0@00l:4@0:1`h020D<00d74@0f<3/0AT=<
03hkA00e=3`07ahV01/J8P0M6R406QPM01/I700K6a/06QXH01/L5`<04Q<>01P0414<01<B400D4Q<0
4a<C01TG6`0M61h071XO02HU:`0];380;2/a02h[<P0[:3408AhW01hL9`0M7BD071`T01PK900F6B00
5APO018F6@0B4aD04A4?01HE4@0I518201hE5P0M02<J7@0T6b008AXQ02@M9@0P6b8071LN01TF7@0K
61l0514H00d<4@0<30h03@/<00`:2`0A3@h05Q0B01dD6@0W7BD09Q/S02<F7@0M4AD05@/<01<9200K
4A006`l?01L92@0M3`l0>Rh^04Di>`17?Ch00P18?D401`19?T@0AS/o04Xo@`1>A4D0A3/l03dg=`0h
<S@00P0e;c404@0g;Rl0?3<d03/b<`0l<cH0>38d03Tc=`0m=Sd0?SLo02dU<00C3AL040/B01L@600H
4AP0510A01`I5`0H5a804Q4<00803Pd800@03@`700h=2@0@30d05A0F0P0J4Qd0:`0K4A`06@hL01L<
6P0@21D03`LD00d75@0C3A/04`lN01XF9@0P72X081dX024N:@0S82/091hX01XE700C3Q805a4C01LA
4@0C3P/0618B01lF6@0U71l08QLK01lD6P0d:Bl0Aca404LmA@1DCUD0@3e403dl@P0Y:Rl01@T<0004
1@0420L01PX900P:2@0620L01@L600H81`0820X01`L900L82P061`/00P051P/050092Ph01`H>00L5
4P061A<010HC00H55@061aT01`PJ00P;700<3b807B8e01lT=`0R9cX0;Bm4038gB`0j?e80>CiA03`n
D`0k@5@0?45D0P0m@e<0100l@U80>T1@03XmCP0j?Dh203`mC`0303ThBP0d<d?ooooo00Sooooo0007
ooooo`0`02@K700P5aP08aTJ02LM700Y7Ad0:b4O02/R7@0^9al0<2TO03<[800d;240=BdR03D[8P0k
;RP0>bdZ03X/:@0l;Rd0>bd]03T];@0g:b/0>2h]03P^;00f;bT0=c0X03@`9@0g<bP0>3@X03Lc9`0g
<RH0>C8X03`c:P0m=2/0@3<]03h`;@11<Rl0A38`04Hb<`17<c@0AC<c04Le=@16=3@0AcDe04Pf=013
=2l0ACHa04Hg<014=Rd0@cD/0P15=bh0;`16>2l0ACL^04Li<016>2l0AcPa04Tj=@18>C@0BSPf04Tg
=@1:>3P0BCHh04De=P12<S<0@Bh`044_;`0l;BX0>BXU03LX8@0i:b80>bdR03T]8@0h;200=RXL03@X
6P0e:A/0<bLK038V6P0b9A`0=2LQ034S800b9240<28O034S800d9R<0<R@S02hP7`0L4@l0718@01P@
3@0E40`05A8;01DE2`0K7A807R0C01hP4P0F60X05aT;00<06Q`>02<06Q`?01XL4@0G61005aPB01HG
4`0G5aL06ATI01PH600J61T071XM01dK800U82L09alZ02LO;00S6bP07aLT01TC7`0C3AT04P`H01<=
5`0>21803@P?024K9@19@dl0CdUE03dg@`0N62807ALS020J900P6b807A/P01hL7`0N7Qh06a/I01XK
5P0201PI4`0I01HG3`0A4P`051<?01LF4P0D518071TK01/F700M6b00=3<i04M4B`1KF640HE]U048l
B00R7R`0;b/i02DS<00T93009RHb028T<00O92X05Q/O01HG6@0G5aD06aXF02<L6`0202HL7@0b02PN
7`0Y7R@0;24Y02HL9@0N5R407ADP01/E7`0J5b004a0I00H52`081``02PX<00/92P0D3a<071HJ02LQ
9@0^92X09a`R024E6@0J3Q005`/;01X?3@0I2`X05PP501/<2@0Y6QD0=bXT03DW900d:BD0@3Dc04<g
=`16?3/0Cd=504m3A`12=c/0@3Ll03`c>00j<C@0>2lb03P]<@0j<340@3@h03hb=P0n<cL0?S<i044f
?P10=Sh0>Blg02hW;P0V8BL201hL8@0_01TG6P0I6AT0:2TU01`M600@4@/02``600h?2@0=3PP03Pd9
00l>2P0>2PT04@d>01@?4`0C3Q@050`G018:5`0?1a@03@DD00d45@0I42407A@U01hG9`0M5RH07QPV
01`F900H52805A8M010=5P0@3A@05A0D018>3`0D3Q005Q0B01`C5P0P5aX08aPL01hC5`0Q5Q`0<2H^
03T_>00j<c`0?CY303/j@P0M7BD01`P=00<72P021PL00P072``00`0830d02@d>00T=3P0200P92`0A
00H72@051PX01@H:00L83@061``01PH>00D44P061AD020TK00L870082Ah04A8W01DG;00H6Rl08RLk
02T^@P0/<dH00P0i?U803`0k@U@0>T5C03XoD`0n@eL0?D9E03e4E@0mA5@0?49B03ToC`0j?E00>ciA
03/mDP0h>Tl0=cQ<03HgB`09ooooo`001oooool02`0V71/091XI02@H600W71X0:b8M02XQ6P0/8a`0
;bPN02dW6@0b:ah0<b/N0080=2hP00<0=BdR03P^9@0j;bT00P0h;BT0500g;2P0>BhZ03T^:00g;2H0
>2dW03L]900h;RD0>S0W03Xa:00k<RT0?3<[03Xa:P0j<BP0?3<Z040c:`11=2h0@S<^04Hd<017<c80
B3@c0P17<c803019=CH0BcTi04Tg=`18=SH0ASHf04Lh=@15=c@0A3La04Dh<P14>S40@SP^04<k;P80
A3d]01<0A3//04Dl;@17>bd0B3X_04Pj<@19>340AcDa04<a;`13<C40@Bh`03dZ;00k:BT0>bXZ03PX
:00f:2D0=b`X03D/9`0d:b@0<BPO0080;bLL00@0;RPJ030Z700_9a`0<RTP0P0^8ad0600/8A/0<2DO
02lV7`0/8ah09QlG018>1@0@3@H04Pl800l?1`0D50X05AL<01`O500P8aP0720B01TM3`0J7Pl06al@
01TM3P0H6P`07AlA020P500K6@d06AH=01XF4P8071HH00D07ALK020I8@0R6RD091`[02DN;P0202XS
<`0`02<O;P0L62L06QHT01LD7`0F4ah05Q<L010=5P0M6R<0@ce905A=FP1?Ae80>30k02XS:`0/92l0
91dU02<L900U82H08QdQ01`J6`0J6AL07QdI01/L5P0J6a<05aT>01HH3@0H6A406AXB01TH4`0L6QL0
6ADF02DP901KFEh0M6me085lP`1bKG@0BTA>04Q2CP0j=d80<2hi04e;EP14@Td0=cM102lb=`0P9BP0
828Q028T8@0W:2<0;bXW0P0a:BL02P0b:2T0<BH/02dR:P0Y7bL091dU028J9@0N62804a0I00/84@09
20h200X93P0>01@D5P0T8bP09B<V030[;`0a:bd0:b8S01T?3P0C2@L05P/701T>2P0B1`<050T301lB
2P0P4`/202<F3P0L034S800h;B/0>bl_0596B01UEU/0DdI=04<h?P13>400?S@l03Tc=`0g<CD0>c8g
03`a=@0m<3L0?S4h040c>P11=Sh0ACY203hd?@0h;SL0<BXb02XU:`0Z:2d0:2PZ02LW:@0W:BP0:R`X
01HH4`801@X403P020X500L9100:3`/020`;00X<2`0<30h03Ph@014?500A31<04`/F0149500@1Q40
40DC020E8`0W72X081PW01`F900K5B<05A4O010>6@0?3AP03`lG00/<4@0=3Q803a0B018B500I5aP0
6QHG01TE5P0K5AL05Q0B01LA5@0S7B409AhU02/V;@0^:c808QlX014@600>3A<02`X@00/<400<3A40
3@hB00d>400;3a002@d<00T;2P0<30`020X900D71P052@`00`H;00H730061Q001PDE00P76@802`TO
00T030`T01`L=P0O7cT09BDm02h`A`0a=T`0=3U?03LlDP0j?e<00P0k@U@01`0l@E@0@4EH03m4E`0n
A5@0?D=C03e0D`0k?U400P0l?E80100n@5L0>3YA03TiD@0f=Th9ooooo`001oooool05`0Y7ah091TG
02PM6`0Y7QX0;24K02XQ6P0Y7aH0;RHK02/U5`0`:A`0<RXM03<]7@0e;b40=S0R03L_900h<RH0=c0V
03L^9@0f;B@0=blT03T_9@0g;B<0>RdT0080>bhV02D0?C0X03`_9`0n<BT0?C8/03`c;P0o=2h0?S@[
03le;012=Bd0@cH^04@e<018=S80BSPd04Le<@17=C<0BSPf04/i>@17=CD0B3Hf04De=P15=CD0A3He
04Dg=014>C<0@SP_044i;P11>B`0@S/Y04M0;@16?b`0ACdZ04Hn:`17?2X0Ac/[04Pj;@11<bX0@S4Z
0080@Bl[00X0@Bl]03XX9P0l:RT0>b/[03T[:P0f:bT0=R`Z03D[:@0c:RD0;bPP0P0Z9Q/202`X701[
02hW7@0Z8aT08a`B02XS6@0]9Qh0:bLN02DQ600J5`h03@d300X:000<3P<03a4601DG300F6@h071lF
01dP5`0J7A@06ahC01XM4P0I71406Ad?01XN3`0N81808B8D020N4@0L60d07QPB01lG5@0P5aP07aHI
024G7`0R6RD09al^02XS<`0]9SH0;RXi02TU=00P7R`0928_02@R;@0P7RT07adX024N:@0h=D00DD]G
05eFH@1IDUX0ASm703lh?`0h<CT0;2D/02TR:@0T7R8071LK01PC5`0H51D06QTG01XI5@0H6A<05aPB
01@E3@0H6A406AXB01/J5@0O71P071PG01hJ6`1XI6D0RH>708N2QP1mMWd0HeiU05eEH01;ADl0C4U@
07QeO01PGF@0@d9804];C@0n@3l0=3@b03Tj=@0m?3P0?CXf03/b<`13>S/0>C0c03<Y<@0f;3D0>2hg
030X<`0S6bH07ADR01D?6@0?31D04@hG010?5@0B4AL08b8W02h]<P0Y9b`0;B/^02hZ:`0R71`06QDB
01`E3`0I40/00P0C2P<0;@0C2P405`h501X@1P0J40L07Q@;02XO6@0]8Qh0?S<a05M;B`1MCU<0CD55
04Dj@013>D00?cDm03T`=@0i<cL0@3Ll03he>P0f:c40=BXb03`a>@0n<S`0?c<m03`b>`0f;3D0<b`d
03D`=`0f=3T0<c4f02l_<@0[;B`0828P00d?300:3`/020d900L<20062`L020`;00T=30093@h030d?
00d=3`0>3Q0030X?00l:4002014:4P0:00l53P0F31L07Q@O024I9P0N62@05A8M014?6P0>3QH0410H
00hA608030lD03P041@G01HG6`0I6A/071XM01HD5`0I51P05A0D00/62P0D3aD061<I028M900L6B00
61<J01<@5`0B3A@03@XA00d<4P0<2a403`hD00l@500<3A4020`=00`=3`0:2`d02@X<00D92P0830l0
0`H;008530041a802@PH00/97P0>32804a4W01XH<00S8cd0:BU3034aB@0j>U80?CmF03XoE@0m@UP0
?dAJ0458F`0oAUT0@4MJ03m4E`0n@eH0@4EH03m4E`0o@UD0>ceB03hoE00m?ED0@D5I03dmE@80=SI>
2Oooool000Oooooo01809a`J02<H500W6Q@0:A`F02hQ6@0Z81L0;B0H02`R6@0]8aT0;RHJ03@/7`0b
;1h0=c4S03H`8P0h<R80=S<R03Db8@0g<B4203H`800503<]7@0f;R40>2hR03X]900l;bH00P0o<BP0
1P0o<2T0@38]03ld<014=c40@3D_03ld;P80@3D_00D0@C<`04Dg=016>3D0ASPe04Dg=00204Pi=P0A
04Hf=P17=cL0AcLg04Ti>@17=cL0ACLd04Lj=017>S80ACT]04Hj;015?2/0ACdZ04Dm:016?RT0AS/W
04Dm:016>bT00P13=bL0800o<B@0?BlR03la900l;R40>B/P03d/9@0k:BD0>BXU03T[:00g:BP0=BTY
03<Y9`0c:bP0;2LS02XW800[:1l0;2TP02HT600Q7a<071T@02<S6@0W9al0:2PP01lO5@0@40H020X0
00T<0@0@4`P04Q@901HH3@0K71@071dG0P0K7AP05@0L7QT06A`E01@I4P0F71806AlC01hR500S8aL0
824C024O4P0Q7A807QL?020I4`0Q6AH081XJ02HP8P0]9Rd0;RT`02hX<P0]:SD0:RLb02`Y=00203Le
@00?03Hd?`0n?4T0A41>04m<E`1IDel0GEMR061KHP1ED5H0EE1D04I1A`0e<3@0:bLX020L7@0M61`0
7APN008061HK04406QPM01XH6`0H61X05QHF01`K6@0N7A/07A`H024N6`0U81d06Q@D05YDE02;PXD0
MW1b07=ZK`1/IVX0HUQP05iGGP1`JVh0T8Z<07miN`1UGel0LFaY05]FDP14?c`0BTE204Y6@`16@T00
A3i004U3A`15?TH0?CE204DmC00n=TD0=Bdl02LO;P0N5RD07ADR01hH8P0O6B<07aXQ020K8P0c<3L0
=C8i038`=@0b<3<09bDX028N7`0R7Qd07APE01@?2@0@30<04``4018;0@0D3@<05`h501P?200L4``0
8aXE02PO6P0g;B/0AS`k04<g=`0o<cD0?c@h040e>P0203/b=@03040g>P10=c`0?SDj0080>Blg0140
?C<l03`b?@0l<Sd0>S8m03P`>`0f;ST0>C<m03Ld>`0g=CX09bDZ02@R9`0K6Qh03`lA014A4@0>3Ph0
20P:00P92`0300X;3@0500/<3P0:2PX02@T;00/9300<2Pd00P0A31801P0C31@05a8I01dH7`0P6b80
6aPO014@5P803@hC01/03PlD010A5P0@4AH03Q4F010C600G61d06APN01XG7P0E4aP050lF014<4`0<
1`h04PdC01PC6@0I51X05a8H01L@5`0D3aH050dE010;4P0B3A@03P/B00d:4`0B3aP03@dE00L:4@08
2a800P042@l04P052Q001@TB00H:4`021Pl01@TC00/=700>3b40414S01dK<00U8cT0;2Y0038`B00k
>E40?3aD03m1FP0n@5T0?T9K04=7H080@4IL00L0@dUO03m6F@10AeX0@DQK0417FP0n@eL0?T1G0080
@D5I00@0@d=K04=1E`0j>4h0>cU?2Oooool000Oooooo00`0;bDO02PN5`0Z7aL0;B8J02hT6P0/8aX0
:R4H02dR6`0`8Qh0<RHO03<X800e:R4203H]8`0703P`9@0h<RH0>3<V03@a8P0d<R<0=3@T03Dd9002
03Pd9`0803Ta9P0j<RL0?c<Z040d:`10<b`0?c4]044c<@10=34203lc<@03048e<`13>3D0@SLd0080
A3Tf00D0ASTh04Pj>018>CL0BCXh04Ph>00204Pi>@0804Tm>`1:>c/0BC/h04Tk=P1<?CH0BS/c04Xm
<`1:?C4204Xm;`0704Di:P15>2X0Ac//04<g:010<bD0?c8T040b8`0203d_801903d^800k;1h0?2/R
03XY8P0i:240>BXT03X[9`0h:RL0=RXW03@Z9`0a:RD0;BLR02XV800S81T06aP?01XJ3`0L7Q809RPL
02HX7`0Q8aX05AL=00T;0P0<40P03Q@;010F2`0D60h05AX@01XL500L7aL07AlH01/N600K71L06AXE
01HH4P0L7QL071lE01lQ5P0X:1`0;RhP02h]800T91D08QlA01lL400Q7A<0;2DM02dW8@0^9b@0;bPW
02hW:00]9BT0=Rlc04Q1A`1@Be80DTeF059>F01CCU/0FUER05]HH`1NFfH0HEaV06API`1SHFH0J6MY
05aHG00n>Sh0<Rl`02dZ:`0^:Rd08AlR01LE6@0H5Q`06QLM01/H7`0201XH7P1B01hK800Q7R<07adQ
02@R900X9BD0;R/Y05aIE@1_KFL0JFIP06MVG`1SHE`0KFYV08B1OP2JUI<0ViNC08f9Q@1fL6`0KfUU
06IOG015?CX0AShl04m:A`1EDU40IF5U06QUJP1WHV/0GeUT05E?G014?TX0<2Xf02/S<00`:3D0=Bdi
03@/>00a:SD0;2H`038^=`0i=cl0?ce403lm@P0k>Sl07ahQ02DS9P0S8B807AXH01<A3@0B40X04a4:
01<?200C3`X04Ph901D?2P0H4Pd07ALB02DM6P0Y7ad09adK02XN7P0g:RX0@C<e040b=`10<cP0@3@j
044g?@10=3`0?c@m044h@P11>D@0@3M303de@@0l=D40>cI103`e@P0o>DD0?CM1038/=P0R7RD05a<I
01D@5P0F4AL04a0E014;4@803P/A00H030T?00/83P0<2Ph03P`@00h;3`0=2@h200`83@0m00l;3`0E
4AD0514D01PD6@0N6Ql071TO01XG6`0C418040lC018A4P0@4A@03a0A018@500D4QH0518G01DB6@0H
5Ah07APS01hI9@0I52005A0M018=6P0>2QH040dH01<?600C3QH04`dD01<=5P0C31D05PlH01D>5`0B
31L04@/F018<600A31T03P/H00X95P0:2QL01`HE00H75@072QL020/H00D:5`052aH02@lK018E900L
7Rd082<b02`^@P0_<D@0?3aA03m1E@12@UP0@dAJ04E7G`13Aeh0ADQQ04I9HP15B640A4UQ04E:H@02
04E;HP80@DMN00P0@dQO0456G@10@e/0?d=I0414F010@eL0>ca?03hoC`Wooooo0007ooooo`0302TR
6P0X8AT0:b8K0080;B@K02<0;RLM02dT7@0_9200;R0M034R800d9B80=2HS03<U8P0d:BD0>2dY03H[
9`0h;bP0=RlW03<`9`0b<RP0<c<Y03De:`0g=2/0>3HZ03Te:P0m=R`0?C@]03db;010=2l0@S@c03ld
<P10=C<0A3Dh04<e=@17>CT0ACLf04Hh>017>CT0BC/k04Ti>P0204`j>P0304Ti>@16>3L0BC/j0080
Ac`j00h0BCdi04Tk>01:?CL0BSde04/n=P1:?CD0B3/c04Dh;`11=2/0@38Y044c:P15=2`0@C0X03l^
9P@0?B`R00@0?RdS03XZ8`0h:B80>2TR0P0i:R<03`0j;BD0>2/S038W8@0b:B@0;BHP02LR700L5a40
6QL@01PH400O8AH082<H01lR6@0J7A@03a8900P<1002010E3P0301@G400H6a805aX?00806QdB00D0
7b8I020Q6@0N7aL06Q`A01`L4P02020P5P0W01`L400T8QH0;R`O02h_7`0W:1P0824?024O400X9AH0
:R@F02`T6@0Z8QL0:b8I02hU7P0e:RH0@3Dc04Xn?P1AATX0F4eC05eCF`1PEUl0I5eU06IPJP1XHV`0
JFA]06YWKP1YJ6d0JFU[06ESIP1>C4l0C4a>0410@00k>CX0<30`024Q8`0O7R<071/P01hK8P0O72<0
81dV00808AhW01l092<[02XY<00V9BX0=SHf065PG01_KfL0LgEZ075cJ01^L6D0TI::0:2QV`2KVYD0
NGQd05UHE01?CT`0De9@05UEEP1GDED0DdeA05eHG01/J6`0[Zfb0;Rg_@2KV9l0MW=l05QCFP19A4/0
@Ca304Q1B@15?TH0?cM20080@3Y400/0>cQ103hmA@13A4T0A4E:04=7BP10A4D0<c@d03De=@0Q8Al0
4a@?014@300201DA3P05018>2`0C3`h04Ph=01@@3@0I5A800P0I5140@00I4@l060h<01lC4`0/7B00
>RX]04<b>@13=3/0@3<l044d?P1:?4T0BC]:04PmB`16?Td0ACY;048jB@11>dT0?CU703hkAP0l>D@0
;R/d01<@5`0>2A004@lD010>4@0@31004@`@010;4@0B3A<040/A00l:400B3A<04`hD014:4@0@2A00
4``C018;4P0@2a404`hD01PC5`0M61`081/Q01hL8@0J61d05A4E00l:3P0A3@h03`d>010>3`0C4A80
5a<D01/G600I4aL06A8I01XC6`0N5R407ADT01H@7P0E3ad03`/I00l;6P0C3ad04@dK00l<5P0<2A82
00d:4`07018<5P0C3AL04@/E010=5P0C3AT03@XE00`85P0200/75P0800X65`091QL030/M00/:700;
31h03Q4P01LJ:P0Y;3d202`_@00403`oDP17BEh0B4YO04M9GP80BTaS00<0BDiT04U=IP1<CVL00P1:
C6D03P1;CFH0ATYS04M;IP16BVD0@dQS0498HP13BF<0@DMQ0416GP0nAU/0?dMJ03a5E00h@4d0>d5?
2Oooool000Oooooo00@0;2DO02XS7@0_9R40;B@M0P0_9Ql02@0^9B00;bHQ02hS7`0b9280<bDT03HX
9`0d9RD0=BXX03@Y9`0203P^;00R03T_;@0i<R`0=S</03Ld;@0h=Bh0>CH_03/h;`0k=bh0?SL_03`e
;@0n=Bh0@CD_04Hi<`14=c40ASTc04<e=016>3L0ACLf04<c<`18>3P0BSXj04Xj>`1??3h0Cc/l050l
?@1=>cT0BCXg04`m>P1:?3T0Ac`h04Pm>@17?3P0B3lh04Hm=P80B3dg00H0A3Tc040f;@0n=2/0?c8Z
03d`9`0n<2L2040_9`0I040]9P0n:b@0@2dV03h[900l:b<0>RdT03T/900j;B@0>2hT03@Z8@0d:b80
=B`S02dT6`0Z8a/0:24K028M5`0J5@l06AHA01`K5P0N7aT07b8K01XM5P0B5a004A@=00lB2`0200hA
2P0E01PI4`0L7AD06Q`A01/M4P0P8QD08bDJ02DU6`0Q8AL07alC02<Q5@0S8A@0824C01hO4@0T8QD0
:2HG02PY6@0W:1H08B<>02DT4P0[:1L0;BLG0080;2DE00`0;bDI03LZ8@0h:b<0>B`V04Hh=@1A@d80
Fde=06AHFP1YGF40K65W06mUK@1bJ702079[LP0606mZL@1]Jg00K6Y_06ASJ01AD5D0>cXo0P11@4D0
=@0];3407QlT01hO900O7RH0924Z028O:P0T8B`09R<^02TX<00i=cl0=34j04a:C`1gLWH0RhN6081l
N@1oO7L0RHR30:JUX@2AT8h0Kfe^04Y8B`19AdX0D4mD05IEF`1EE5`0EE9M05UFH@1]JWD0X9fX0=7>
e`35`//0[jbe09:?UP1[J6l0BDA;04M2B01@Be80BdI=048lAP11?TL0@D1603m0A@15B4d0B4]@04E9
C01VK6`0KWA`05=HE00k?CP09BHQ00`;1P0L6A@06aHB00805a8?02005Q0@01PB4P0G4a806ADD01LC
4P0D40l04`h;018=2P0G3Pl09adN03/_<@11=CP0@SDl03`_>01BADl0I5=S05M9FP1;?U00Aca=04Lj
CP17>dl0ASe@03`eA@0f<3h0;BXe01HC70030PP03@/>00l?3`0B4Q004Q<?010A30804A4?02H04Q0A
010>3`0F51L0518G00h93`0@2a4050hB0109400D3A@06a@L028K8`0S7RD081/R02<N9@0J5ah03@T@
00h93`0?3A003`d>00/92P0G4a@06ADD01TC4`0M51D07A@G01hE6P0M4a/05`dF01P>6@0H41/04`dI
00l;6@0C3ad040hK00l>5`0>3AD03PdC010?5@804a0G02X04@lD010?500A3QD030/A00d<500<2QD0
3`/I00d9600=2Q/04@hQ010=800C4BH06aT^02LX?00b=4T0?3iC0415F@14BEd0B4eS04U=IP18C6D0
CDmX04i@J@1<D6T0BTiY04i?J`1<CFT0CDiZ04Y;I`18BFD0BDYX04Q9I`16BFH0ATYW04A:I011B680
@TYQ03m:G010C5`0?DUG03a6DP0mAe49ooooo`001oooool0400^9R<0:R<M02XQ700^9B00<2LR02dT
7`0/8ah0;R<O02dR7P0a8b40<R@S03<U900d9RD0=bTX03@Y9`0g;2X203P^;00<03L`:P0f<RT0=c@[
03/f<00m>C00>cL^03`h;`0o>300?SL_03lf;`12=S00A3L_0P15>300J@14=c40ASLb04Hg=016=380
AcDc04Xf=@1;=cP0CCTj054k?@1C?Sd0CSXi04/i=`1=>cT0BS/h04Pj=`19?SX0B3di04U0>`17@3X0
ASdh048i=011>340?C@]03X`9`0j<2H0>bhU03X]900l;RD0?RdU03d/900m;280?R/T03l]8`0l:b<0
?2hU03P^900i;bD0>2lV03D/8`0c;280=2dS02PT6@0M5Q006QD?01dH4P0K614071/F01`M5`0M7QP0
7b8K01XM5P0E61404aH=014D2`0D5P/05QH<01`L4P0L71006a/?01`M3`0Q8Q@0:2PL02LW6`0R8aD0
824C02<Q500S91@06Q/;01dN3P0V91D092DE02HW5`0T9A@08b@B02HW5@0[:QP0:bPG02dW5`0_:1P0
=RdN03T]8@0j;B@0=bXQ03lb:P19>SD0GU1=06UKFP1_I680LfMW06mUIP1fKG00OWEj07]dN`1gL7L0
MG1f079_MP1SH6L0CdaC048oAP17A4d0B4E>03Pg?`0E5Ad05aHN01`K8`0201hK900b02HS;00T8BX0
9b@[05YHGP1RGfH0KFQ_08j9S`2UWj<0W9JH09bFUP2LV9L0PWio05QCE`1BCE<0CdYA055>E`1GE5l0
FEMT05iLJP1UHW<0MgB509RDY@3;amH0emCO0<o9d`3:aL`0^KBk08N2R01@Be40CDI=05=<D`1;ATd0
Ad9904Q5C018Add0ATM<04M:C`16BDh0EEUL09:FU`2b^;@0OhAo03<e<00c=2h08b8M02DR7@0Q71P0
7QHD01lG5@0N5AH201TC4`0j01LC4P0H51D05Q8C01DA400B3Pd04`d?02XQ900l<cH0@3Hj03`a=`0h
;CD0F4YG06iPK`1GBEX0BSa=048eA`15>4`0ASU;044fA`0e;C`0:B4^02<M9`0E4QT020L<014A4`0M
7A/07R0M01XM5`0C5Pl051HA014C3P0A4@l04Q0A01DC500C4A@04@lB018=4@0C3Q8040/?01D>5@0S
72@09QlW02LO:P0V82X071HP01HC700=2Q802@H=00X83@0;2@`03@P<010<3@0@30/05Q0@01LA4@0M
51D071<F01H=40804`X?00<04``C014<4`0?31L00P0>31L0800=31@030`D00d>4`0?41D040lE00h=
4P0;2Pl030/@00h=4P0:2a002`/C00`<500=2aP03P`I00h=7@0B4B404a4V01LE:P0V9c`0<c=:03m1
F01;CF@0BTmU04I;H@19CV@0BdmX04Y>I`1?DFX0CU1Y04iBJ`1<D6T0CU1Y0`1<CVL03@16Af<0AdQT
04M8I018BFD0Ad]V04I<IP13Bf80@TYQ041;G`0oBU`0?TYJ03E1C`0g@dl02Oooool000Oooooo0100
:2<P02/S800/9240;bDS02lV8@0[8Qd0;24K030S7@0^8A/0<B8N03<S8`0d92@0<b<S03HV9P0g:BH0
=2TU0P0f;BH0100f;bD0=c<W03Le:00m>Bd203/g:`0R03hh;00n=bd0?C@]03ld;P11=Bh0ACH_04@e
;P17>C00ACH_04Pg<019>340BcPb04Xg<@1<=c80CSTf050k>01A?3T0DSdl04lk>P1??C/0CS`l04Xj
>P19>cX0BSdl04]0?P16?3X0@3Lb03lh<P10>C<0?SL_03`e;@0h;bH0>BlU03H/8P80>BdQ01@0?2hS
03X/8@0i:ah0?2/Q03X/7`0i:b00>BhR03T_9@0h<2D0=bhU03H]9P0c;2@0<blV02<P6@0H4`d06AH?
01`L500M7A<07b0H020Q6@807b4F02l07AlB01PJ3@0A4`H04aD801TJ2P0K6@X08Ql@024N3@0O7P`0
7Qd;02@S4@0Z:a/09bPH028U500P8a808B8B024R400J6`T07B0?02LX600W:1X0:BXL02<U5`0L7Q00
:RdL02`]7@0Z:1/0;RXN02XV6P0a:al0=RhS03H/8P0b:1h0=R`S040c:`1LCdT0JEaF071UG`1cJVD0
JF5N07A/J@2:Ph80R8:4085kO`20NH00MVmg065II00204i6D`0j05I>G@1HDV00BDEC010>6@0L6B@0
8AhW020J900P6b809R4X02/Y;P0f=3L0NWQi08:0P`25P8@0XIbP0:bVZP2TWZ80UXf@07]bM`1AAdl0
D4UA05YBG@1MEF@0H5MX065HJ`1YHW@0M6eo08MoU02ZYKT0dLWN0=kGj03Idml0g=CO0=K?e`31^/40
V9:F079/L01GCU<0D4M<04e4B@1?ADd0DdaD05E@E`1BCeH0DE1F06]ZL027QX/0_;bn0<72a026R8H0
=CHa0493?@0h=c80924L024N6@0V8Ad0:20N028I6P807A@E00<06A<C01`F600K5AT00P0G4a@07@0I
51P0=Blc040j?P10>Sl0>34h03dc?01GCEH0FdmK04/mBP18>TL0ACM404TkBP17>dT0?c<o03<Y<P0U
7BP07QTP01PF6`0B41<07AdM038b<00b=3409RPS01hO6P0G6AH05ALD010@400?3`l04A4A0080410@
00l04Q0A014?400?3A005A0D02DP9P0X8BP0:b@/02<M9`0I5Ql040dF00l<5@081`l020L=00d<4P0>
31400P0<2Pd04P0D41405Q8C01PD5@0F4Q404Ph=014;3@0@30d03PT=00l=400=31803`hD00h=4`0>
3AD02`XB00l>5P0@3aL03`hF00h=5@802``A00h020T>00P;400931<020/B00P:5P0=3a/03Q0O014C
8P0G6Rd08B@g02H[?P0i?E40AdUN04a>H`80BdeR01H0C4iS04]@I01;D6@0CE9X04aAI`1=DVP0C55W
04]@IP1>DfT0CU1U04a>H`18BEh0BDYO04]<H@17B5l0AdUR04E9HP13Af00@TIO0457G`11BEh0@TYO
0P0i@E@9ooooo`001oooool09@0W7ad0:R8P02dS8@0]91l0<2LR02dR7P0^8ad0<2<M02hQ6`0_8A`0
<B8O03<S8`0c9B@0=BHS03DX8P0d:B<0=R`S03P_9P0g<BD0=C8S03Pe9P0i=RL0?SPZ03dg:@0l=RP0
@3P]03he;00o=B`0@SL^04Dh<014=Rd0ASP_04Pg;`19>300BcXb04Xg<01;>3400`1>>S<05@1>>C@0
D3dg04hk=`1=>CP0CS`l04dk>`1;?3T0BC/i04Ll>P16>cT0@SLc03he<00o=Rl0>c@/03Xa:00j<2H0
>BlU03X`900i;b<0>RhR03T]8@0203T]7`0I03T[7P0j;1l0=b/O03P]8P0j<2L0>BhX03D/9`0d:RP0
<RXW03<^:P0R7AT061<@01/H4`0M7AD07AdC02@T6P0W9ad08B4E020Q4`0R8aD07b0@018C0`0G60L0
7ah:01lL2@0202@Q3P09020O2`0L6`L09RPC02`]6`0W:1H092LD01dP3@0M7P`07Ql=00807Ah<06T0
:2HG02h/7@0_<2808B8D02<T5P0X:AT0;2dO02/Y700W9AT0928F030/8@0^9ad0;BHL03@]8`0f;B@0
>C0W04Pm=`1JDDX0K6=L06mXH01`JF<0MVmY08R3P02<QXH0Qgj108ElP@1iKgP0JEmZ04m4DP1FBe/0
HEIW06=JJ`1?BeT0:BHa03Tf@@0`:S@0:B@[02XX;@0b;C<0?ce004Y8B@2?Shd0ViZH09VGV02ZYZL0
Y:2Q08^5Q`1cJVd0GEAI0516CP1GCEH0GU=Q05]@H01TFFX0L6Ah08]oT`2dZkh0a[gB0=38g@3Kd^D0
g=CT0=kFh`3DcMD0d/S@0<2j_02KUIL0LVUZ0599BP1GCDh0E4U=05E<D@1FC5@0F55I065LH`1lMgh0
/Zfc0<O2b03<al/0SH^>05UGE`0m?3P0C4U404=0>`0Y9R408AhI02dX900/9b@09AdK028J600P5aP0
6Q@D01XD5P0M6AX08QhO02HQ9@0X8bL0=c8h04@mA00o>T40?3I004DoB@18@4/0BT1904@j@`17>dD0
0P1;?dT04P16>T@0>Bhf030V;P0Z8bX09AhU020K7`0X9RL0;R`]038b<00e=c@0<c@a02@T8P0O8B00
6Q/M01@D5P0C4aD04a8G014A4`80410B03H04A4C01<A500J5AT08Q`P02HO9P0W82L08QdT01PC6P0G
4A/04PlH00d<500A3QL04PlF010=500?3A8040hC014?4P0C4A@04a4B018@4@0A40h03@`:00`;2@09
1`P0410@014A4`0A4QH04A0E010>500>3AD03`hF00l=600@3Q/03`lK00/;5@0:2Q@01`XC00X=5P09
3AP01`/F00`@700C5RD04QDV01LJ:`0R9CP0:2e0030eB@15BEd0CDmT04mAIP1=Cf@0CU1U04e?I01<
DFD204iCI`0804]@I01=E6L0Be9U04]BI@1<DfH0D5EX04aAI01;CV4204Y=H00304]=H@18BV40ADMP
0080ADMP00D0@dMP0498H012B600?TAL03i4FP09ooooo`001oooool04P0/8200;b<S03@V9@0a8b00
=2HS034V800^8ad0;B8L02`S6P0/8QT0<2<M03<V800c:280<bHP03<Y800f;2<0=B/Q03L]8`80>30S
00d0>cDW03`f9P0l=RH0?SPX03li:`10>2/0@3P]03lg;012>Bh0@cT_04<f;P15>2l0AcT`0080B3X_
00d0B3L]04Xi;`1@?S@0D3hd04lm<`1??3D0CCXc04dj=01;>S<0BcTe04hl>01=>cL0BCXf0080ACLd
00L0ACPb044d;P11=2h0?S4[03lb:P0n<BP0?C0W0080>blS00@0?30T03X^8P0i;b<0>2hR0P0j;R80
6@0h:b80>RdU03`a;@0i;R`0=RXZ03<W:@0c:2`0=BX^02LL800H3a00618B020K5`0O71D09R4K02PT
6`0P7Q807Q`?02@R4`0R8@l06QT701/J1P0Q7`X0924>02<P3@0U8Q400P0P7`d02P0W:1H0<34O02T/
6@0S9Q406ah901`N2@0M70P07Qd9024P300W91<202h[6P0A02DS4P0_;Q`0<C0N034`7P0^;1d07ad@
020N4@0X9QX0:BLK02XV7@0_:b80=C4X03<_9P0g<R`0Ad8l05eHDP1VHE/00P1cKVX0>`1jMg<0THf<
08EoO`1kMGL0Mfic07E[L`1SG6@0HEUT06QPK@1WGf`0FUMR04M4C@1ACUL0C4U@03Hc>P0i>3d0AD=8
04];C@16ATH0T96A0:JVYP2JVYP0Ti:@08j:R@1_JFT0EDm?0517B01CBTd0EdaB05aBF`1_IG00Qg^9
09Z=WP2gZ[`0g=7R0=W>gP3AbMP0f<gM0=W@gP3Fc]T0d/_B0<W3a@2SWY/0NWEa06YRG`1HD4d0ED]:
05]AD01GCTl0BD1306aSJ02ES940[JBY0;Vc]@2WXJ<0RXB606=JG@1HD4l0Bd=10080C4M30400>3<_
02/V8P0_:bP0:bLT02`W900Y9R40920M01dI5P0I5A807ATH02dY:00d<2l0>C<e040j?P12>400?3@n
04i8E01CCET0BD=?04DoB@11>T80AD17059;DP1ECUD0CdI;03/b=`0a:bd0:28T02/U9`0Z9RL0=C@b
03`k>@0l?3X0@dE20452@@0/;2h09bH[01lN900I62005QDM01DC7P0C4QX04@hG01<@5`0B3aH04a4F
01`E700T6R80:1lT02LM9@0S6B406Q0H01XC6`0H4aX04a0G01D@5`0D3aH04`hE014<4`0A3QD04Q0E
01<A5P0A4A<03Ph@0P0>3Ph06`0=3@d02PX800`<300G5aL061PJ01DF600B4QL04Q4I01<B6P0A4Ad0
3@`J00`;6`0;2QX02P`K00/<7P0<3Al03A0Q00hA8P0@4bH061T]020Q=P0Y:Sl0;Bi303XkD019BF40
C4aT04i>IP02059BJP0I059DJ`1@DVT0Be1V051EJ`1>DfT0Be5W04aDJ@1=EFX0BE5T04YBI@1=EFP0
BU9U04YAH`18Cf40Be1S04mAI@1:C640AdUP04Q:H@16B5l0AdUR04E7H014AUl0@D=L04=5GP09oooo
o`001oooool02`0c9B@0<bDR03HW900d9B00=RTQ03LZ8P0_8QX0;R@K02TP5`0/8aX0;R<M0080;b@N
00D0<2DO03@Z8@0e:b80>BlV03/a9`0203Ta9P0303de:P0l=2L0>S8U0080?SPZ0P0o=bX00`12>Rd0
@c/_04Dk<@0204<f;@0?04Pj<@17>Bh0B3X_04Pj;`19>c00Cchd04hm<`1@@3<0DD0f04dl<P1@?cD0
CC`d04`k<`1=?3@0CC`e0080B3L`00T0AS@`04Le<@14<Rh0@S4Z044b:`10<BX0?S0W03`_9P0m<2L0
0P0l<2@00`0n<RH0>2hR03X`9P0203X]900603/^9@0l;RP0?c4`03la<@0i;Bl0<RHZ0P0c9Rd0900_
8RT07A8F01L>3`0P61H08QXG02@L6@0S71H06AD:01lK3`0Y9QL09R<B01lL2@0O70P08Al:02@Q3P0X
9A809B@B020O3@0R8a40;RlM02ha7P0]<1d0:RdJ01XM200I6`H07A`801hK2P0P7@`09b4A038/700[
9AD09b<B02h[6P0e<Ql0<S4O02XW608071X=07<08b4E02PU700Z9ah0;2PO038_9P0e<R/0<c0[03`i
=01?BdP0DDa905aHE@1]JFH0MG5`07mkNP1kMgH0NWAd07MaL`1gLGD0L6Y^06mXK`1aJW80JfI]06AQ
J01SH6L0IVAY06QVJ`16ADX0ATI805MGF@1JFUX0B4Q808Z:RP2HV9H0Ti:@07UhMP1UHF00FUAD04e7
A`1DBd`0Fe9E06IMHP1_IFd0QWb509nEX033^<H0d/KD0=[?g@3Jd=/0eL_F0=O=f03FcMP0e/oG0<Bm
a02GTi@0NGEd06EQGP1PFeP0I5mL061HEP1IDe<0GUQH061JG029P8D0/:NZ0;>][`2JU9@0PWUj05]C
D@1SFEX0GeED04e3@P1@ATD0CdM504Lo?@0k=S<0>SDb034]:P0b;bX0>3D`03Lf<@0R8A`071/G01hJ
5`0V8Ql0>S@d03he>013>Sl0@SQ003P^>01GCe`0Ee5M04U3C`12?4H0@Se404@oA@1ED5H0FeEI055;
C`1<ATX0ACm102dT9`0V8280<2X/04I2@@1JEUD0EUEC05IFE01EE5D0;B/`02TX;P0Y:3007Q`W01XH
9@0I5b@0518O00805a@O00l05a@M01TD6`0K51`08aTQ02`R:P0_9R/07A<K01L=5@0H4AP06A@J01D@
5P0A3a804a4F018=4`0D3aH00P0@3A@2010?5@0M00l@500>3a<03a0D00h?4@0<3@l03@l>014B500D
5AL05QLI01PH7@0I61h05QHN01<C7`0>3Ad030/M00T:7P0;32403@dU00`>9@0>4bT03a@Z01@F;`0W
:D80:Ra502/]AP0k?EH0C4aV059BK01AD6X00P1BDVX205=EK00504iCJ@1<DVP0CeE[04iDJP1<E6T0
0P1;EVX01019E6H0BUEW04YEI`1:EFL204YBI@0;04]BI@1=D6H0C4iU04Q:H@17BF00Bd]S04Q8H01:
BV@0B4QR04=3F`16AUh02Oooool000Oooooo00X0>RdW03@W7`0g:240=2HM03LY800f:B00<2<J02lU
6`0]8aT0;R<L0P0`9B401P0c:RD0<RTT03D/9@0c:R<0>2lX03/b:`<0>C8Z00/0?C@[03he;00o=b`0
@SX]03hf:@0o=bX0@c`/04@k;@13>Bd0@cL[04Hi<00204Hi<@0@04Pk<`18>c80BC/b04/m=019>c00
CCld04/m<P1<>c40Cclb04dm<01<>S00BSP^04/h<@19=Bh0AS8[04@a:`<0AC8/00H0@S4Z03h`9`0n
;bP0?S0W03`_9P0k;RD203ha:00:03`_9P0k;RH0>R/T03X[900k;2D0@2lZ03l]:`0m;Bd0>bd]03PY
;080=BH[03P0=2DZ02<G6`0F2Ph07A<D028J600Q6AL071@A01DA200L60d0:bDI02/U5`0T8A0081d;
02DR4@0W9Q@09RDC02LU5P0T8Q<08R<C038c8`0_<R40:bhK02HY5P0M80d07Ql=01lP3P0N70d08Ql@
02LQ5@0`:Qh0:RLH02LS500`:Q`0<bdM034^7@0X8Q@07QX>02<O500Y9A`0:RHM02`W8@0[:240;R/T
034^:@0f=C00AD4n03hj>@0e<C80D4]?06]YK01`KW40KVa]079aK`1hM7<0NWIe07UeM080Kf]Z06`0
M71a071^K`1ZJ6/0IfMY06EUI`1XJ6X0GemQ05eMG@1ZJ6T0JfUZ05eKG027QX@0QHB007YfL`1OFUL0
DTa<05eDE@1RFEX0J5mR06UPI@1cJG40QWb40:^T[03Ab]80i]oW0>7Gh03DcM@0e/oG0=C=e@3Bbm<0
dL[C0;jka02>Ri80IfA[05=@E`1NFf80Hf5V06ITJ@1RH6D0G5YM07AbM@1nO7l0UI2D0::NW`2>RX/0
L6a[069MFP1MEE80J5iM05iCD`1AADL0Cd=504a2@`1<@DD0BD1104M1@@0f<Rl0<Rh[03`k=`0m?3L0
=C@_02h[9P0Z9b80;BPU040g>010=cX0@3Dk03ld?00m<C`0C49=04Y0B`16?4D0A3Y3044j@@15?TD0
Ee5E05M=E@1;@DT0BT1804i4C014>D40?C<k04Do@`1SGF40KFMY061LG@1YIFH0EU9E05IAE`1ACUD0
@Sm802h[=P0X9C0081h[01/I9P0M6BL071TT01hH8P0R6b<08QPQ02<I8@0Z82P0:24X01hH700J51P0
71LK01XF5`0F51D201@D500[01@B5@0G4QP040dD00h;4P0=31@03PdE00l?6@0B4QX04A@K010C600>
4AH03A0E00lB5`0@4AH06Q/O01`M8@0L7B8051@L00h>600>3A/03@`L00X;7`0<3RD03a4Z00h?:`0A
5C8061dj02DXA`0/;dh0<SIC0496H`1;Cf`0DE9`055BKP1BDfd0DeE/059GJ`1@EfX0DEQ[04mGJP1=
F6X0C5MY04]HJ@0204eJJ`0504UFI`19EVT0BeQ[04]HJ`1:EFT00P1:DVL02`1:D6H0Be1Y04Y>J@1;
CfX0B4YS04a<I01:BV80BT]P04]<H@18AU/0AdIH00Wooooo0007ooooo`0R02lR6P0`8aX0<2@H034U
6@0c9a/0=2PL034T6`0^8AP0;R@J02lS700`8Ql0<BHR03@Y9@0a9R@0=2TW03@Y9@0g;RT0>S4/03T`
:`0j<bd0>C8/03/b:`0m=2d0?cH]040h;@11>Bh0A3`a048j;@11>2`0@CL]04@g;P19?3<0BSde04Hi
<`80B3/c00@0BCXc04Xk=018>c80BCda0P1:?340201;?C00BSX]04Tg;@1:>2h0AcD[04Pd;@14<2T0
AC0[0P17<Rd00`15<R`0@c8[03h]9P0203`]9P0403ha:@0m<2L0?S4X03d`9`80>bhV0380>RdU03T/
900j:b@0?blY03d[:@0l;BX0>B/Z03LY:00e9bL0>2T/03HW:P0V5aX06@d?020F5`0S6aT07QHD01<>
2P0E40X07AT@02DQ5P0V8a@081d>01dK3@0S8A@0928C02LU5P0V91D09B<D02@U5@0Z:a/0:2/J02HY
600V:AH08RDB02HW5`0T9AD09B<D02DS5P0Y9AT0<2`P02hZ7P0[9a/0;RXN030]7P0c<240;2PL02TU
6@0Y9AX0:2@I02TU6P80:BDL0140;2TR038_:00l>C@0@cdm030Z;00i<ST0GeQP06QRK01[Ifl0LVec
07AbM@1kNGX0O7]i07IeL`1_KVX0L6m[075`KP0206m_K@0I06EUH`1SHf40IfMW06YXJ@1YIfP0Lfm`
07A`L@1`K6/0PGak079/K01WHF40HEQI065HF`1SFUd0IEaO075XK@20MGd0XiVQ0<Nma@3Me]d0gmGM
0>;KhP3Oe]/0dlgA0=;8d0020<[3bP0E0;F_]P1oNX40GeaU05aIHP1PGFH0IV=/061MIP1/JG80MgAm
07AaN02_[[<0ZJV[081nO`1[JVP0IV9O05mKF01QG5P0I5eG06IMF01IC4/0DD950080Ac/o0380Bci5
04TnA018?d80?cTi03hh>013?ch0@Shm03`h=@0i=340>SDb03/b<`10=CT0@SLm04<h?P13=Sl0AS]4
04/oB@14>D40AS]304Ll@P16>d40Bd1404i3A`16>d40AS]304i1BP1>@D/0EDQB065EG`1`IVl0Ng5i
07=ZK`1`JVh0M6i`06ANHP2?R8l0O7Mn04E2B`0P6R@0>3E003<`>`0T82h09B4_02TS<@0[8c00=2`g
02`R;@0T6R<07aPP01dF7@8071LM014071LK01PF600B4Q804Q8B01<C4`0E4aH05a8H014>5@0>2a80
3P/D010>6@0B41/0518M010@6P0C4ad04QDL014D6`02010@600G01TJ7`0M7R<06a/S00/;5@082QH0
3PdK00l@8P0=42<03a4X01@E<@0D63D06Qlm02<XAP0[<500>SmO04E:J01>Dg40Ce9a055ELP1AEG00
DeI^059GJ`1CFV`00P1AFV/00`1?FfT0CUYX04eKJ00204iKJ`0304eJJP1=FV/0C5MY0080C5M[00h0
BUEY04]CJ01:D6P0BU1X04eBK01<D6d0BdmZ04Y<I@1<CVD0BdaQ04Y;G`1;C5h0BDQH04A3D@Wooooo
0007ooooo`80;R@J00D0<2HJ038X700a9ad0<bTO030S6`0202`O5`07034S7P0d9B80<bDT03@V9@0c
9BD0=BLW03LY:00203L/:P0703/`;P0m=2l0>c8]03dd;`0l<b`0@CPa040g<002044j<P0703lh;P10
=bd0@CL^04Hi<@1;?3D0BCXe04Pk=@0204Pk<`0K04Tj<`18>C80AST`04Lj<@19?3<0BCda04Di;@17
>Bh0AcH/04Pe;P17=2d0A34[04<`:P13<2`0A34]04<`;014<Bd0A38^03l]:@0l;BP0?RlX03ha:@0k
<BP0>S0V03T_9@0i;bH0>S0W0080>2hU0280>bhV03`_9`0k;RP0>bhX03X]9`0i;2H0=BLT03P]:`0f
:bT08ADE01X@3`0M5A<08QdJ01PC400?30L05a@=01XG3P0R81@08B8D01dN400L70l06a/?02<S5`0Y
:Ad08R8F028S5@0Z:ad0:BXL02PY6@0V9aL09bXI02DX5`0Y;1T0:2/H0P0T9A<09P0[;1X0<34O02//
700Y9aT0;bdP030a8`0b<bD0<S0S02h/7`0]:ah0:BLH02/X6@0Z9aP0:BDI02lX7P0j<bd0@c/h03he
=P0m=3T0IEUS06]OK@1LDF40OGB307ifP`20NX@0RHJ=07ilO`1^KVh0IVIT06UZI@1]KVT0K6eX06e^
J@1XJF@0JfYV06a[J@1_JfX0M6i^0P1hKg80?P1cJVd0KVEY06=JG`1UG640HeQN06UNIP1_I6`0PgR0
09nDW02n/KX0gmCL0>?Hh03OeMd0hMKN0>?Jg`3Md]P0f]7F0=O<dP30]k`0XiZO07I]L`1`IVh0JV=[
05eFGP1NE5d0KF=^07M]N02KTI`0YYjY09jGW`2UX:H0Q7n3061LG@1FDTl0GEQD061KE@1UGUH0K6=L
06UPF@1BAT<0E4E804Df>`1:?T80C3m604XmAP1;@4P0BSm704i3B`1=@TX0B3i604@k@013>Sl0@STn
048g?@11=S`0ASU204Lj@`18?D<0BSm504Dj@012=SX0Ac/m0P1:?T007@1BATH0ASLj03X[<018=d40
Dcm:05M5D@1`GV`0PG5n08IhQ@1oLGh0Mf]e07=XL01cJVl0Q7j209^EV@1aJW40:2<Y024J8P0e;cT0
;bTc02PR;P0Y8c40:B4`02dU<P0b:SL0:b<`020H8`0L51l06a@L00807APO00/06QLN01PE6`0E51T0
51<H01@B5`0F4AL05a8I01<@5`0>2a803``E014>5`0201@A6P0V01<=5`0D4AX061HQ01HD7`0C4A`0
5aDP01PH8P0E5B004Q8N00X<6@0=41l04Q<U01@G:P0?52P04AH/01TM>00Q9D008bQ502`aC`0j?E`0
CU5`051CLP1AEG80D5Aa05AHL`1CEg00DUQ]051GJ@1BFf`0Ce]Y051LJP1?FfL0D5eV04iKI01>FVH0
D5aX055JJ@1@FFX204mGJP0?04iFJ@1<DfH0CEAW04aAI`1;D6H0C55X04eAJP1?DFX0C4iU04e?IP1<
CV<0C4eO04Q:F@16B5@0A4IB00Wooooo0007ooooo`0402PP5@0Z8QL0;B<I02lU6`80;bDL00D0<2<M
02hQ6`0/7aT0<B8O038S800203@T900603<S900f9RL0>RXZ03HX9`0h:2P0>R`[0P0k<2`04@0l<Bd0
?cHa03lf;`12>C80@3Tc03lh<011>S80@CL_04@g<@14=C00BCXe04Hg<017>340B3Tb04`m=P19>340
ASL`0080BC/b00L0BS`c04Lj<@15=bh0ACL^04Dd;@15<R`0AC<_0080A38^00<0@c4]048`;012<2h0
0P10;R`03P0o<2/0>b`W03d`:P0l;bL0>c4X03X`9P0h;R@0>B`S03X]900j;BD0>RdT03`_9`0j;bH0
>S0W0P0h;RD0E00i;2@0=R`S03L/9P0f;BP09Q`J01H>2`0J5A407AXE01`I500F5Ph05QH<01`L400O
7a<07R0B01hP4`0G6@d06Q`A01lQ5P0S9AX092HI02/]7`0Y:ad09BPG02P[6P0[;Qd0;2lL02LZ5`0Z
;AX0:RdH02DX4`0V:A@0;2hI030b7@0[;1X09BHF02d^800b<bD0<SDT02l`8P0/;Ad0:R/K02TZ600Y
:1@0:BHE02DR4`0a:al0>C0Y03dd;`13>CX0IeaR08EhPP1XFVT0F4]L09N;W01oMh@0RH>?092=U01m
OGl0Lg=c06IXI@1VJ6<0J6YU06MYI01/KFL0L75[075`K01bLFd0M71_07UcL`1aJ6/0KV=W06UNI01N
EE/0HUQP06MMI@1ZH6P0N6ig0967T02k/KT0dLK>0>KKh`3^hnT0iMcQ0=cCf080h=OJ02H0f<oB0=O>
d@32]k/0U8V=06iUJ01XGV80K65U06YOI@1JCeL0HUEN07]^M`2TV:@0a;S40;N[]`24NX<0E4eD05I@
E01IDeD0G5MD05aGD@1MFE00J65I07E/H`1]HeX0F4a805A6AP1>?d80DdA904`oAP1:?D@0CT5:05A7
D01@@dd0BCa604PlAP17?4@0ACY204LlA080A3U102<0B3]404/nA@1;@TL0@cXm03le=P15>c`0@cLg
04@h>018?3`0Bcdm02`L7`0d82T0CSY5061<F01eH6l0OFYm09B1U02GQYP0Nfen06=EI01WFfL0LfUb
07QaN01_J6l0C4I:01/D6`0L5A`08AXR02DN9P0T72L09AdZ02LO;00Y8Bh09al/020H9@0201P@7@06
01XB7`0J52006A<O01TC7`0E4Qd05a@M0P0D4AX01@0D3QP050lF01<@5`0B3aH04`hE00804@`C02L0
8A`S02@O9P0L5R005a@M01@A700D41h05aDR01HF8P0>3A/03`hN00`>7@0>4B80414U01@F:`0D6Bd0
724g02d_B00b=U40>3aI04M;J01@Dg80DEEb05AEL`1BEW<0E5Qc05IJM@1EFG80DeU^04iGJ01@G6`0
Ce]Y051LJP1?FfL0D5eV04mLI@1AFfL0DUUY05=JJP1AF6X00P1?EVT0101=E6L0C5=V04eBIP1:CfD4
04aAI`0704]=I01=CfH0C4iS04Y=GP18BeX0A4QC04=7D009ooooo`001oooool202TO5P0402lR6P0`
8a/0<2<M02lR7080;AlL00<0:adJ034R7`0d9B800P0f9280@00h9R@0>BLU03h/:P0h:BH0?2XX03//
:@0m;R/0?2h[03la;P10=C40?cHa044h<`10=c80@3L`03lf;`11>2l0@cH^04Df;`17>340BCP`04Xi
;`1<>c40BcXb04Pe;P1<>C80BcPb04Th<@1:>C80ASLb04Hd<015<bl0A30_04@`<@16=380@c@a04@e
<P12=340@38_048b<P0o<Bh0?2h[03d_;00l;bT0?C0Z03d`:00n<BT0?2lV03/_8`0l;R<0>bdR03`^
9@0k;B80?S0W03`_9@0l;bH0>BlV03T`9`0i;bH0>2hU03T_9P0l<b`0:24K01@?2@0J5@l201hK500c
01/K4@0H60`06ad?01hP4P0K7a005AT:018F200H70h07B0E02<V6`0W:ad0:blP02L^7P0Q:1H0:RhM
02ld800Z;aT09R/D02X_600_=1d092TB02HZ4`0];aT0;2hI02X/5`0W9aH0;2dM038c8`0c=280<34Q
02l`7P0Y;1T09bTD01lQ300U9180:RLH034[7`0h;bH0>c8[04e1@@1/H6@0N6Qb05a?F@1SEf<0QGZ7
07E^MP2JUI`0V9JI08>3P`1]Kf`0IVMR0080JfaW00<0JFYU06m`J`1fMg800P1cLW00>@1dL6l0LF][
05eDE`1OEU/0GeEM05]EG01UH6L0M6ee07mhP02TWjH0d<_B0>7LhP3NfMl0g]WM0=gIfP3Nf]T0f=CC
0=SBdP3KeMD0e]7>0;B_[02?QXL0He]I069JF01^I680Ie]K069FEP1JCU00Cd1505U:C`2HRi@0]jbd
0966SP1YGfL0FE9I05]EF@1KEeP0GEUF05aGD`1JETd0JfAL07edK@1hKFL0FDe905I8B01EAdL0ETM:
0593AP1@@DH0DdI=05E8C`1?@T/0C3m804/nA`1:?D@0CD1704`oAP0204XoA@0V04a1A`1=A4L0CDA7
04@n?P16?Ch0>S4b03@Z:`0n<S@0A3Dj044`=P0Y6200;a/W04D`?`1cGVl0QgB708QeR`2?O980TX2F
07UZO`1?@U@0DTMG05=;F01<Adl0>3<j02`W;@0K5Q`08AXQ020I800R6b8091dU02PN9`0/8Rd0:b4/
02TN;00L4B406@hO01/B8`0L4b@201XC9@80614S01<06A8R01H@7P0E3ad050hJ01<=5`0A3QD04a4F
014?4P0=2`h05A<F02`Z;@0Y9b`07a`S01TF7`0E4ah05aDR01<A7P0A41h03`dM008040lQ01<03a0T
01HD:@0F5b`09RLl034aB@0d=4h0>CUC04];I`1?D6`0E5Ec059CL@1EE7<0DeA`05QIM@1FFWD0F5ae
05ELL01BFVd0DUe_0080DUm_00H0CeeZ055MJ`1AFVT0DUU[05AIK@1BEf/3051EJ`0?04iDJP1?EF/0
CE9X04mCK01<DVX0CU=[04eAJP1<DFL0BTmU04aAI`19CV80B4eP04I<G012B5@0@DQB00Wooooo0007
ooooo`0H02lT7P0/8A/0<2<M02lQ7P0a8b00;b4N030P800b8R80;QhN034Q800f9280=B<Q03LU8`0j
:2@0>bTU03XX900j:bH0?bd[03d^:`0n;b`0?c4^044c<013=C80?S<_0P0n=C003@0m=2l0?cH_044f
<011=2h0A3D^04Hg<01:>Bl0B3H/04Xh;P1;>Bl0BSP^04Te;P16<b`00P17=2h09016=300AS<_04@`
;`14<340@bla04<`<P12<S80A3He04<e=010=C40@C<b04<e<P0k<2`0>c0Z03`_:@0k;RH0?S4Y040b
:@0n<2D0?BlT044`9P10;bD0@C0V03h]8`0l;R<0@38X03`_9P0g;RD0>S4Z03T`:@0h;bP0=RlU03hg
;`0a;2H0514:01@D2P806a/A01@071hA01XL3P0H70/06Ad>01LK300C6PX05A/<01/Q4`0N91P07bDG
028X6P0W<1l08b`K01hW500W;Q`0;SHQ02P`6@0T;1@0;SHN03@j80807b@=00H0:bdG02/]600[;AP0
9bPG02TZ6P0a<R8203<d901A038c8`0Z:aT08b@B01XK2@0S8Q00:bLK02dY7@0i<RX0@3Lb04]1@01P
E5H0G4mF04/nB01BAU00L6E^07YcNP2>R8`0QH6207YhN@1[JfT0J6MU06i]J@1^KF/0L6m[079aK`1e
M780Lg9`071^K`1^JV/0GEMI05M>D`1MDe/0G5EM061IH`1dKWP0SXRB0;:/]P3Hd]`0hn3W0=oLh`3K
fMh0emGJ0=GCeP3Mfm`0e]GC0=cKf@38alD0YJ6P07QdL@1ZI6@0I5mL06EMFP1_IF80IeaH065FDP0g
;2X0:Q`L03`]<01aIFT0Mfab061GG01QEel0G5EL05]EF@1KEEL0GUUF05YED@1OF580K6=N07=ZH`1T
FED0EdU705Q:BP1FB4P0ETM:05=4B@1DADX0ETU@05A7CP1>@DX0C3m80080Bci702T0DDA=0515C@1B
Adl0DDQ=04m6B`19@dD0Ad5304]6A@17@D40>38d03T`<`14>Cd0CD1703d]=`0Q4A/07@/G03h/>P1b
HG40TX6C09F4U`2AOiD0SWnD05I9G@0l<D80?SE603Pb@00f<3`0:B<]01dG8@0K5Qd08AXR01lH800K
51`07QHQ02HL9`0]8S00;24_01lG9P0F2a`05PdN01XA900201PA8`0G01L@8P0J4bD06a@V01TB900I
4R804PhL010=600>3AD03@`A00l?4@0?3`l03@d=014A4@0X9RL0928U01PF6`0H5al05aHN01LE8P0D
4Ql04a8P018@800C42<00P0E4bP05`0I5bd09bDk03DcB@0n?5@0@3eH04i>J01IFGD0FUYf05UHM`1G
Eg<0FEUe05QIM@1IFWH0FUii05QLM@1FGG<0E5aa059ML@1BGg80DUm`051MKP1@Ffd0DEa`0080E5Y`
0P1BF6h0101@EVh0DEM_055GK`1@EVh204iDK00604mEK@1=E6/0C59Z04aDJ@1:DVL0Be5Y0P17CF<0
0`16CF00@TUI0458F009ooooo`001oooool202dR7P0G034S800a8B40<B4Q038R8P0c8280<b4Q03@R
8P0c8B00=B<S03LU8`0f9280>bTW03/Y9@0h:B@0>RdU03d^:@0m<2X0?S4[03`_:@10<Rl0?c4^03db
;P11=S800`10=C<02@10=C80?S<_048e;`14=Bh0AcH^04Lf;014<bT0A3@W04<a9@0204@b:00<048`
9P12;bP0@c0Z04D`;@10;2/0@Rh_048^<011;S00@30a048d<`13=C@0@C<b0P0o=3001P0n<B/0>bhV
03`_9`0l;bH0?BlT040_9@80?blR01/0@BlS044_9@0n;280?bhV03h`9`0o<BT0>BhX03L^9`0h<B/0
=c0Z03@_:@0c<2L0=C8Y03De;@0P8AT05QT>01XN400M7a8071hA01hP4P0I7@h04aL801<J2P0B6@T0
6Al@01lU5`0P9QP00P0L91D0;00Q:AX07bLH01`W5P0N9aH09BhM02`e8P0[=1l0:C<K02lg7`0V;QL0
7b@>02DX4`0Z;AX0:2/H02LZ600Y:Q`0;BhP03@e9`0i=bX0=cDX02DS5P0P7Q407ad@02<O4`0[9ah0
;2PO03D`;010>3H0ASdn04a1A@16>d<0>2`f03hb?01SFF40NFmg07mfN`1jLG@0MW1b07A^L01_Jf`0
Lfm^07IbL`1fLW40N7Ae0P1jMWL0?@1RGF40GEMK05aEG01GCED0GE=L05YBG@1gKW/0T8FC0;6Y^03J
d^40j>3]0>CNjP3Je>00f]OP0=cIhP3FdmX0fMSN0=?Be`31`<D0W9bN071^L@1NG5l0GeeN06APH@1R
G5`0J61M069KE@1CC4H09QlI01dC4P0Z8240@cXk05]EE`1DCU80EDmC05IAE@1FD580EU1@05]CD@1Q
FEH0I5YH06UNG01WFEH0DTA304lo?`1B@TD0Dd=605A3B@1A@TT0Dd==05E8D@1CAe40CT9>04XnBP1;
?d/0CD5=0596DP1ICeX0HEMP05I?EP15@4@00P12?Sl05@15@T<0CDU:034/<00f<CD0B49604a5C00k
<CT06a4I01X?5`0X72H0DD=@07QZM`2:O8/0M6Ie05U=F`1;@4h0ACY:03lgAP0k=D<0<R`j01XD8P02
01XB8@0O01`D8`0O5bH07QHU020G:00U72d09aha02/R=@0Q6R`060lR01PA8`0I4R805PlO01PB800I
4b406aPS01hK9`0H5R<05Q@Q014A6`0<3aH02PdB00`@4`0=4A802a4?00`A3@0=3``05QHF01LG6@0F
5AX05aHN01DD700201@B7`0>018A7`0D4b<05QDW01TG;00J62d08Qhe02d[@`0f=4`0@41H05=CK@1G
Eg40FUYd05YLM@1NGg/205]LN00H05QLM@1IGGH0F5ae05UON@1GGWL0EEed05INM@1CGW@0EF1f05AO
M@1@G7@0Deef051JL`1DG7<0DUY_05=KL01AFG00D5Q_051HK@1?Ef`0CeM^04aGK@1>FFl0C5M]0`1:
EF/01P1:DF/0B4mY04Q?J@18CfT0@TYQ03i6F`Wooooo0007ooooo`0>030U8`0/8Al0<28Q02hN7P0b
8R80<B4Q038P800d8R80=B4P03@Q8@0i9bD0>2HT03XX9P0k:BL203//9`0B03X]9`0l;bT0?2lY03`a
:`0k<2X0?c4^03d_;00o<Bh0@C<b04@f=@14=SH0@cDe040d=00o=380@C<`044d;P11<R/0@38Y0P0j
;R805`0j:Al0?2`O03h]8`0n;280@2dV03hY9011;2T0@RdZ040[:P11:bd0@Rh`048_<@15<c<0@S8b
044b;`10<Rl0@C@^040c:`0o<RT0?S4X03hb9P0m;b80?blP0080?RhO00l0@2hP03l_8P0n;280?2/S
03h`9`0n<BX0>c0Z03Xa;00k=2h0=c8^03Ha;@0g=2d0<S8Z02l_9`0S91`00P0I7140600N81D07AlB
01dO4P0K7a005a/<01HJ2`0I7@`0720@02<W600O9QH07B@D01lU5`0P9QP07BDF01hV5`0P9QP08R/J
02df8`0^=b@0:C4L02hf8@0/=1l09b`H02HY6080:B`K01H0:2/K02X/7`0[:b40<C4W03Tf;@0e<RT0
9R<J01lL4`0P71<09B4H02`W8@0`:bL0=2l/03Xa<P0o=ST0BD15048f@00d:S<0CD=<06QNIP1jLGH0
N6ea0P1gKW40RP1hKg80Mg5c07I`LP1iLgD0NgEg07YfM`1fLGD0K6Y]05QFF@1IE5X0GEQN05aEG@1Q
FV80JfE_09N>VP2l/Kl0gMGT0>_SlP3Vg^/0g]KS0=oGhP3Ne^40hM_U0=kHhP3?bM<0ZZN^096>U@1h
MG`0I69W06ESJ01RH6<0HEmR06QRI01NF5L0DDa803Xe;`0M61807aLD02TQ7`0e<2d0B4A304]7B017
@d@0D4Y<055;C@1GCU40FU5B06UOH01[HF00JE]K05Q8B@13<c@0AcDh04/h?P1;>T00CCa40551B`1E
AE00DTE?0555D@1@A580CT9@04m3D@1<@Dl0FDiL07E]NP1[Hfh0CDQ?03lj@00j>3d0?C/n04I4B01I
Ee`0AD=803lm@P1ACUD0CdYA03@_=P0O6R007aPO028H800Y7bL0Cd==069FH01FBU@0ASY4048h@@0o
=D00>c<n03hf@`0`:3H050`K01P?800I42406A0S01lF:@0R6B`08AP[02@K<00Z8SL0>c=803PdA@0]
9SH05a<R01LC8@0F4ah06A<O01TF7`0K6R807A`T01XJ8P0F5R004aHM00lD600:4Q@01`lA00H?3P07
40d02a4=00`A3@0@4Q40414E018C600C4a/04A4I018B7P0D52005A@R01HE9@0Q83808b@h02LX?00e
<dT0>SQ>04A4G01>D6L0F5Ya05YLL`80F5ec00/0F5ae05]ON01IGgD0Eeec05QNM01HGWH0F61g05UP
NP1GGWP0F5mi05MNN00205QON@80E5ii00@0Deeh059LM@1BG7D0DEab0`1?Fg<0201@G7@0C5Q`04eI
L@1=G7<0BUU^04MFJ`18Ef`0BEE]0P17DF`01019D6`0AdiZ0499H`0lA5/9ooooo`001oooool04@0a
9bD0;24O02lQ7P0]7a`0<B<P03@U8P0b8b00<24N03DS7`0e9B40=bPU03PY9P0l;BP0?BhY03`]:00n
;bX0?BhY00<0?c8/00H0?c4^040`<011<C40@C4a04De=P15=CP204@d=`0N048c=P10<C@0?c@b03hc
;`0k<2`0?34[03L^9@0_9a`0;1lF02lS5`0d9Qd0=RPO03XY8P0n:bL0?bXW044/:@12:RX0A2`/04H]
<017<380B3<b04Hb<@15<Rh0A38^04<d;@12=2/0@C<X03lc9`0m<BD0?30P0P0k;Qd07@0l;ah0?2`L
03X]700l;1l0>bdR03h`9`12=Bh0A3Tc03dd;`0k=2h0>3<_03Pc<00h=C00<2lZ020O6P0K6QD05aPB
01/L500Q8AT071`B01TI3`0K7A006ad?01lR4@0Q91406ad;02DV5P0T9aH08RDD008092HH03T07b<E
02@X6P0X;1d0:2`M034e900/<b40:RhM02``7`0^<R40;c8Q02T[7@0X:A/09bTL02PZ7P0[;B80;2`T
034a:@0f<b`0=34Z02PX800M6Q<07aXD02DP700^:BD0=S4^03D]:`0d:b`0>C0c04@k@01@ATl0DTQA
06EKI01aJG40Mfic07A[KP1dJf`0NG1a07QbLP1jLG@0OGAg07afNP1kMGT0MG1d05eKH01KFUl0EeIK
05iMHP1PGf@0IVAY06i/L@27Q8/0`[g40>;Kh`3[i>`0knS`0>_QjP3SfN400P3RfMh0;@3HcMD0bl38
0;N/]022N800KF=[06mXK`1UGVD0HUeS061KH@1/If/0M71a05IBD012?cX0<2dV020K5@0Q6Q@09alL
02lZ9P0l=c@0@Sdj04<m?@1<@dH0DdY=05=:C`1LDeP0LVU^06]PIP1DAdh0C3e203LX;@0f9R/0=bH^
044`>01;>T@0EDE@05I6D@1A@e00Cd5>0514DP1AA5D0DDIF05A<F`1RFVL0O7B105YDGP0203Xd?P0`
04M1B`1?BU40DdmE05iKHP1JEf00DDiG05MDG`1@CEP0@Ci702`Y<00R7B@07aXP028K8P0^9BX0@cPn
03ld>P10<cX0?C0g03HY<P0f:S@0=b/g02`R;P0S62P0714R01T=8@0M52T081L/028J;`0P62d091`a
02hY?@1@C5d0FUQV04e9E`0R82/07QdU01dL8P0K61l07adR01LF6`0E5AX071dR01PK8P0@5AT03QHI
00XB50073a40214@0P063``0100;4@l041@E00dA500A51T2014D6`804A<O00T051HS01HG9`0S93H0
<3=403<fB@11A5L0ATUL04eBIP1DFFd00P1JHG@0101IHG@0F61c05EQL@1EHG4205UUM@0505QSM@1E
H780EV5e05YSNP1HH7L00P1IGgT205YOO00605IKN@1HGG/0EU]i05IMNP1BFgP0CeYf0P1>G7L03`1=
FgH0Ceej04aJM`19FG<0Beee04UJL016EVd0AEE/04IEK017Dfd0B59]04]BK016C6@0@TQP03m5F`09
ooooo`001oooool202/Q7`0302lT800`9B40<R@Q0080<B@N00H0=2LQ03LZ900g:B<0>BXU03X[9P0k
;2D203h_:00:03h_:P0n<B/0@C@/040c:`11=2`0?c8/040c;@0o<Bh0@S@a04@d=080A3@e00l0A3@g
04@e>011<c<0?S<a03`a;@0k<Rd0=bhW02dT7@0Y81L09A/B02<I400X6a<0<RDM03HW8P0l:RH00P10
;BT01`13:b/0A2`/04D];@1:<S80Ac8a04Lb;`18=C400P17=Rl0BP14=Rd0?BlT03la:00l<2@0?S8R
03`a7`0k;Qd0>RdL03`_7P0j;Ad0?BlR03/]8P0m<BD0ACP_04<i<010=c00>c@/03`e;`0i=2h0>SDa
02`W8@0M6QD071TB01dJ4`0P7AH08QlH028R600N7Q@0820D024R500Q8Q008b@B01XJ1`0U91809bPF
02d^700^;1l09bDH02@U5`0W:1X0;RlQ034b8P0f=bL0<S<S02PY6@0Y:QX0;RlQ030a8`0^;R809bLK
02PX700V:1`0:B/P02`^8`0`<2H0<30X02h^900Z:R007AdC020M5P0X8al0<B`X03D`;@0c:bT0<RPY
03@[;P12>Ch0ED]C06ENI@1]IVd0KFIZ079YK01fKFh0N71^0P1kLg40N@1jLG80Ng9c075[K@1YIFH0
If9V05UGFP1HEe`0F5UM069SI`1YJ6d0P7n509bIX030_L@0i>3W0>ORj@3]i^h0l>Wa0>OMi@3Wg^<0
imcP0=W?d02^XjL0VHjB09nBV@1aIV`0IeaR06aSJ01RG600GEQL06aWJ`1mNg`0Q8:3059ACP0d<bh0
9bLO01lL5@0Q71H08QdG02`W8`0m>3@0A3`j04Hn?01<@d@0CdI90556C01RF600P7Io079VL016>d<0
>2/d038U;00Y7200;QlV03X[<P1@@DP0E4E<04i1BP1?@T/0CD5;0514D01HC5P0ETaG05Q@F`1PF6<0
EdmJ040jA00c;CL0CTIA05iFH@1KDeh0FUAN06=MJ@1QGVT0I61^06eYM`1WIG80BdUD03Pg?`0Z9bh0
7Q`Q02HQ9`0/9RX0<2LZ03<X;00o<cL0<bH]02`O:00`9Bd0<2@^02PL:@0]834081DV01`@900P5b`0
8AP]01lH:P0T7Bl0:RHg03XfA@1ACE/0D4iI04U8D00j>Cl0<C0e02XY;P0M6b007adP01HF600C51L0
5QXM01PL7`0E6Qd0314D00P@4P0:4a8031DD00/D4@0=4a<03aDE010E600>4aL00P0B5ad0400A5Ah0
4ADP01@H900I7BT082Dd02X]?P0i?dl0>d9B04I<G01@EfT0EUe_05MNL01IH780GVMh05]WM`1HI7@2
05MTM00R05YWM`1IIWH0EV=d05QUMP1EHWD0FVEj05UQN01LHWX0GVAn05iRO@1KGgX0F5ag05QLN@1H
GGX0Eeaj05IMNP1AFWL0D5ii04mMNP1>GGX0CEai04aKN01:FW@0BE]c04MKL018FW00AUM[04IEJP16
DVP0B5=Y04U?I@19D6<0A4UM0456F@Wooooo0007ooooo`0:02/S800/8R00;B@O02hU7P0a9R00=2XQ
02`R6@0`9Qd0<RPO03H[8P80=BPO00@0=bXQ03/^9@0j;B@0?C0X0P0l<RP0600m<bL0?38V03hd:00l
<RH0?C<Y03le:`11=bh0A3L_048e;`10<Rl0@C<a048d<`0n<bl0?34]03P]:@0a:240:B0K02DL5`0V
6aL09a`F02@I4`0W71H0<R@Q03PZ9`80?2dX0P10;BT05`14;b`0AS4^04Ld<017=300BSPd04Hd<017
>340B3L`040b:@0l;BH0?S0W03da9@0j;R00>blQ03/_7`0j;R00?30R03``900i;B40?c<W04Hi;`16
>C00AC/_0080?S@Z09L0?3@Y03@[8P0Y8aL081T?028K4@0U7Q@09b0F02DQ600X9A`09B8I02DS5`0U
9QP08b@B020Q3`0N7PX09RDA030_7@0f=B<0<RhR030Z7P0_:al0;bdN030]7P0i=RL0?3TZ03Pb8P0a
:ad0<2XL030]7P0f<b@0>CDY02HT5`0T9AL09RPH02LZ6@0Z;A`0:bhM02h`8P0];R009RLI02DV600X
9QX0;BXQ030[9@0b;BT0<b/Y030W:00d:bh0?3<f05==C`1]IfL0Lfe]07=^KP1gLVl0Mfm/07ifL`25
OGX0OWIc075ZI01]IF80If9O061LF@1OFeX0GUaM065QH`1RHFH0IfI/09BCV@2i][l0cL[E0>7Nj@3Y
i?80jn?`0>WQkP3/i>l0jMoX0>;Hh038_l80]Jb]07ieMP1bJFX0RGmn07Q^K@1]Hf80Jf=Q05MBC`1>
BTL0LW5]09jOVP2OX9/0HV=N02d^:00W:2006Q/C01XJ4P0R7aP09R4K03Lb;01;@d00CD=205A:B`1A
ATX0BSe406aQI`2DRI40P7Em03hb?00T6B409Q/Q02<H700T6Q/0=B//04@j>@17?C`0CD=40515B@1A
ATX0ET]A05Q=D`1HCe@0F4iF05aBFP1DBU80?S@l03le?P1NDU`0JEeY06ILI`1XGFX0JV9a07E_O@1i
MH@0Og^:08B0SP1UHfh0CTeE02h[<P0K6Ah08R0U02PS9`0[9BT0;B@Y02`S:00W7BD08aTQ02LM9P0Y
7bX0:1dY02TL;@0T6BT081DV008081LX02L08Q`Z02LQ;`0d;SX0BTM@05ICG01>Be80@d56040n@@0e
=CL0;2`^01XH6`0F51L05ADG010A4P0=4A804aLF014E500>4Q<02Ph?00`@3`0A5aD04ALG01@H6@0A
5AP041DI014F700B6B4051/S01@K9@0B62@0620]01hV<`0]=4@0>3m?04A<F@17DEd0EUi[05iUM@1L
Hg<00P1MI7H04@1PIgX0H6Qk05aWN@1KJ7/0FVMj05MVN@1JIgX0FFEk05YUN`1GI7L0FfIi05]SN01M
IGX0GVIk05aRN01JHG@0F5mb0080FEme01@0FV1h05QPM`1CGGH0DE]f055LN01?GGP0D5ii04iNN01;
Fg@0BUab04YLK`18Ff`0AUUX04IHIP16Df<0Ae=Q04U@H01;Df00AdeI04E9E@Wooooo0007ooooo`0T
02h/9P0[:200;RTQ02lZ8@0`;240<2`P034[800c;R40=BlR03D]800k;b80>2`O03T/800l;b<0?C0T
03lb:010=BT0@3HZ03lg9`0m=RH0>S@U03Tc900l=RX0?SP[03li;@0o>Bh0?SL^040i<@10>3<0?cLc
03P`;00_9b<0;2<P024H5@0P5AL08QPI0P0R5QH03P0R5aH081DD02`O7P0m<Bl0?S0]03/^:@0m;bX0
@c8]04Df;P13=2X0ASL]04<g;012=RT0A3H/0P1;?S<0h014=bd0?c4Y03da:@0l<RP0>c8W03`c:00k
<RH0=RdR03P_8`0e;B<0<RXN03D^8@0/9AP0<2TL03dg9`0n>2L0?CLX03Lb8`0Y9AD07aX;024M3`0T
81<09B4E02TU6P0[:1l0:2HM02@S600U91P08b<F01hN3`0Q8Q4092@A02TX5@0^;1/0=c@S03Tc9`0g
<BD0=S0R038]7`0`:ah0>3<V03`g:P0g<RD0=BhQ03@_8P0b;B00<RlS03/i;@0_;b<08B<F01lQ500S
:1X0:2dM02L[6`0V:AX0:B`M02HW6P0U9QT0:2DK02hZ8@0c;BL0>C8_03T`;`0b:BL0<b/Z048i>P1N
EEH0K6ET07=/JP1hLVl0P7Qe07mgM01mMg80O7M`071[I@1PGUH0EUA=05EDC`1MFeL0HV9N071_K@1l
NWd0TXnC0;B`]`3>bM40jN;/0??[n03`j?H0k>;a0>WOkP3Vg^X0g=CN0<Joa`2[YJ/0PGan079_KP1Y
If<0KFaV06eXH`1]J600HV1G05UFC@11@3L0>CT`069QF`2@T8X0[JZV08Z9QP14@T805aDE01TG600K
5aT09AhQ02`U9P0f;2h0AS/n04a1@`1CATP0E4M904Di?01EBD`0OG9f06=IG00c:2d060lB01dD5P0Q
5aT09AXL02lS8P0c9bH0>bd]0512@`1JCTd0ETY;05Y<C`1KCe40GE1D05eBE@1BAdX0@CHk038W;01?
A4X0IUYR07ibN`1iKGH0MFUd07icO`1jLgh0PGZ508n9U02ETIX0R8B<05UEG@0b;CH09B4Y02TS:`0V
82P08QXT01dF800M5b0071HO01lI8P0T7RD09AdU024I8@0P620081PN01lG700P6B008AXP02@P900[
9RX0<Rha05QDE`1QGf80EeEH04U8BP0e=3P0:b/^01@C5`0B4AD05ADI01<D600@4A@02@/<010A4@0E
5QH04a<F01@D5`0G5aX05QTK01LI700D61`05APO01DI8P0D62805a`W01/Q;00M8bl07RHc02P_?P0/
=DD0?4IE04QBH@1BGFX0EV5^05aWM01NJGH0GVQf061XN01PJ7X0HFUk061ZO01OJW`0GFUm05eYOP1J
JG`0FFUl05aZOP1KJ7d0F6Ih05]ZN`1IIgT0F6Ih0P1GIGH03`1GIWH0F6Ad05QUM@1IIGD0F6Ae05IT
M01EHW@0E61c05=OM01CH7D0DUmg051MM@1?GG<0BeU^04YJKP0204UIJP0704UGIP18E6@0Ae=R04]B
HP1<Df40ATYF04A8DP09ooooo`001oooool0900`<2P0:b/Q02h[8P0]:R40;RhR02`]7`0^;1l0;bdN
034^7`0_:1P0=RdN03HZ700l;R40?BlT03/]8P0m;b@0@SHZ044g:`10>2/0>cDY03Da9@0h=2P0=S8V
03Le:00i=b/0>SP/03/h;`0l?380>cXa03dj<`0a;RT08A`H01lJ5`0O5aD08QLK020E6@8081@F0<X0
8ADG02@F5P0^8200?Bd^03`/;00l;BX0?2dX04@e;P19>c80A3PY040g9P10>2D0?SHS04i6<`1AB3L0
AC`]03/a9@0j<2H0>S4X03D_8`0g<BD0=c0V02l[800Y9AX09R8F02PT600X9QT0:2TI01lP3`0T9AD0
<c8P03<d8P0f=B<09bPF01DD0P0H6@L0824C028R5P0T91P09RHL020P5P0I6@l061P@01TI3`0G50/0
71X>01hO4@0T8aD0:BLH02dZ6`0e<R<0=C4U03`h;00]:Q/0:2DF02hZ7P0`;R40<RhR03<a8P0c<240
<S0S038`900d=2P0>3P^02`]9@0T9Ad071lH02<V7`0T9ah08bHM024Q6@0T91X09BDK02TV7@0_:b80
;bPP034Z900m=C80>c4_03L]:`0j<2l0CdM506aRH@1_IFH0MVa[07abL@22NWP0J6=P06MTG`1QH5/0
DU=;05MHD01JGEH0HVEN07MiM01nOgX0V9NC0:jZZ`33_l00jnGY0?O`m`3ikoL0lnWb0?;Vl03Xg>L0
f<cF0;^a^@2DSI@0NG=g071[K`1aKFh0I6=Q06QYI01]KVP0HfAL05AFB`0i>c00;BlR034c:014ACd0
H5mJ06eYIP2=RHH0NGAd030Z;P0<1@d06a@L024G800/8R/0=B`a03L/<P0h;C<0AS/o04a0@P1;?cl0
=2XY03H/:`1=@d80?3@b01882@0I3a008AHJ028G6`0Y7Al0<24T02dM800e9BP0Ccm00592@`1DA4D0
FTY;061@D@1VEUL0CClo03@V9P0`92H0@3@f06QNG`1VFel0LFIZ08YoP`1mM7P0PgYo08AnPP22Nh80
U8fD09bEW020Nh809b8Y02DM:00g;cX0<RXg030X=@0R6RT071@S01PB7P0E3a/05a4K01hI800M61`0
7QXJ01/G500L5a<06QL@01hI5@0R7aX081dH01lK600m>CP0QHB206]YJP19AdX07A`Q010?500J6Ah0
6aXP01LH7@0C4a/03PhF00l?5P0>3A<040lE0P0H5ad05`0G5Q`061LM01LH7@0G61d051LN01<G800B
5R405a/V01TM:@0S:CD0;SA203U0D018Cel0A4eN05EPK`1PKW/0HFek069^O01QKGd0Gf]i061/NP1R
KW`0HFem00<0Gf]k0P1MJGT02P1OK7d0F6Qh05ASMP1HIgX0EVIf05MXN@1EJ7T0DVEf055SM`1BI7P2
059WN00>051VM01CIW@0E6Qc059VL@1DIW80DF5^051NJ`1BGfl0DUm`04mJKP1>FW00C5Q^04YGK`18
Efh204QDJP0604MBIP15CF80BDmU04Q=H@14AeP0@dIE2Oooool000Oooooo00h0:RLR02DR6`0T8AX0
:BHM02h^900Y:Ad0:bTM02l[7`0^:1`0<2TK03D/7@0h;1h0>RhP03hb9P80>bhU00<0@3<Z03hd:P0k
<bP00P0i<RP203Lc:02j03Tg:`0j>2`0=cL[03Ph;00k>bl0>c/`03hn=00c<b/09R<L01hI4`0P6aD0
8ATG024G5P0Q5AD07a@B028D4`0U5AD0<R0P03/Y:@0m:bT0?bd[048_:`16<bd0BSTa04Hh:P12=bD0
?S<Q04@l:@1AB3L0CTDd048i:P0k<bH0?CDZ03/e:@0d;B<0<RhS03@`900W9AP08AlB01lM3P0V9A<0
9BHD02HX4`0W:QH092LD02`]6`0a=240<S<S020S4P0C50@07R0B024S5P0Q8aP092@J024Q6@0O71D0
6QL@01DB3@0H5@h05Q<<01`I4P0P7A@08QhD02LS600V91L0<c4T03@b9@0j>2/0;R`M02PV5`0]:a`0
:R/I02h]6`0_<1h0<2lM030a8@0`<B<0<c<Y03<c:`0Y:2<09bHR020O7@0R8Al09B@P02@S7`0W8Qh0
:bHP02`X7`0]:Ah0<b`R03@[8P0c:R<0>2lX03T^:P0g;RT0>S0^05I<BP1_IF@0LVQW07Y`L@1lLW<0
N6m`06=MG@1IEE80FUUE05QID`1QHU`0JVeV079cK@2>ShT0/:nZ0<O6`P3:a/<0h]kM0>oYj`3lloH0
no3d0?7VjP3]h^H0hMGK0:VMX@21MGT0J5eQ06MNG`1]IfL0LFe/06]ZIP1aL6/0KVmY05EFD00i>S@0
8B8L02d`:@0e>340@d@n051AC01SHUh0Lg9^06ESG`0Q7A`04`d=01/E5`0P6Q`0;bTY03D_;`0g;bd0
<b/Y03hf=015@3d0=C0]028J600P6aP0:28R02<M7@0E30l06A<E01TC5`0Q6Qh09a`R02dQ9@0Y7Al0
=2DX04/k?01>?Sh0C3dj05Q6A01TDU00I59B03HV9P0V5QH0=2HV04Hj>P1hKVd0JV1Q07YaLP2AR8T0
P7Yk08R2Q01oNg`0RhJ:09^DV`2HTIP0IF1W01XE700d;3L0=2`i0P0a:cT06`0Q6RX07ALU01TC7`0J
51h06QDL01`G6`0K6QP07QdI01PH400F4`X04a<901`I400L718051@<01HE4010?c/0IVES04U7B00Y
:B/04A0E01XI7`0H5ad06aXR01PF8@0D4Qd04@lJ01<A7002014@600B01TH800J6R806ATQ01HF7P0E
61l05aXO01PK800F6b405ATR01TM9P0K7bX0<CM304E;F@18Cel0C5=S05ENK`1RKWh0GFel0P1PKGd0
201OK7d0H6em061]O@1QKWh0Hfmo05iZNP1QJWT0HF]g0P1OJGD08P1SK7/0H6Uj05UTMP1KIWP0FfQk
05MUN@1HJ7l0EFMo055SN`1?Hg/0D6Ik059XO@1CJW`0CfAe051VL`1@IW40DFE^051RK01=GVP0Cf1Z
04iNK@1@GFh0CEU_04aHL01:F780AeE_04QDKP1:E6l0B4m[04I=I`1<D6T0AdUP04=4F@16Ae/9oooo
o`001oooool02`0W91l08AhI01XG4P0P7AH0:2DN02HS700Z9Qd0:bLN02lX7P0c;240>BlS0080>S0T
00T0?38X03/a9`0j<2H0>S0V03`b:@0h;bH0>34W03/d:P0h=2T00P0j=R/04@0k>Bd0>SP/03Tj;00l
>Rd0>c/]03dm<@0h>2`0;bdQ02<Q5@0R7QD07QTC01dF400P5a808aPD02HI4`0V5a80<b4M0080@2hZ
01d0A34]04Db;017=2h0BST_04Hh:@15>2P0@cLW048f9P14>b`0BT4b04@l;`0n=RT0?CL[03/g;00f
<RL0<S0T02LU600U9QP08R<C028U4P0W:1H09RTD02T]5P0]<A/09RTF02d`7@0`<b80=CLY02d_8P02
028T5`0701dO500N81D08R8H01hN500P7A@08AhE01`I400201lL4`0602<P5`0R7QD08QhD02@P5@0]
:Ah0=C<W0P0c<B@06@0`<B40;c0P03<d900/;A/0:BXH02`^6@0^;ad0;BhN02LX6P0[:al0;R/R02XW
800W9R40:RHT02@N7P0S7Q/0:bHS030X9@0`:B<0<2TQ03@]8`0e;2<0>S8W03P`9@0i<2L00P0k<R/0
4012>C@0HeaF07I^J`1aJFL0NG1a071YJ@1SGEd0HUiM05aKF@1PGed0J6MS07=dK`1kO7L0VYVE0<W8
a03Sgmh20>7Mg01S0??]k`3aj>/0ln[]0?3Uj@3^hnL0iM[N0;FZ[01XG5h0I5YK06]RH`1/I680JfIS
06aXI@1cKf`0Mg=`06i]J@1;BTH0:b`W034a;`0g=cD0?Shl0451?`16AD<0HV5O07A`K@1PGET071TB
01hI5@0T7a/09B0L03D`;00g<Rh0=S4]038]:@0i=S40<RlZ01PD4@0D40d071PG02@P8@0R7Ql05Q4E
01PC6@0I51X07QPO02<I8@0W7R<09a`P034U9`12=3@0AcTh044b;`1@@Ch0H4i:04Tg=@0_7A/0=2@T
04`l?01JC4/0KF9P07U_KP23NgT0Q7aj08f8QP25Ogl0O7Ih0:^UZ@2k];/0VI:I03hi@00I51/0;2@_
03@/>@0a:cL0:bDa02LQ;@0Q6bL071HP01hI800N6Al07A/L01dL600O7QP06AT?01@D2P0F5P`06QX@
01TI4@0F5Ph061LB02h]:`0h=cD09bDV01dK7P0L6Ql07AXQ01XG7P0L6B806QLR008061DP00L06QLR
01PF8@0G5B0061PR01TL9@0H6b8051PQ00806AhT00`061dS01LN900G7RH072<[02H]=`0j@4h0BU1N
04mEI@1MHg<0IFan06I_P@1RKGl2069_P00/06E`Q01RKGl0HFan06A`P01UKWl0I6el06A/N@1SJgP0
HFUd06=[MP1SJgP0HFQh061WN@1PJ7/0GfMl05]WO01JJ880EfN105EVP01DJ840DfV105=YP01DJWl0
DfYl059XMP1@IW<0DVI_055SK@1>H6X0D65[051PK@1=GFd0C5]^04aKLP1:F780AeE`04YEL@1;E740
BE9_04U@K01:CVT0ATQQ04I6GP19BUl9ooooo`001oooool0D00V8A/07QTE01TD400M61@08ahJ02LR
7P0Y9200:bHR02hY8`0f;bL0>C0W03P_9P0i<BH0>2lV03H]900f;R<0=blT03P`9@0e;b<0=S0T03@`
900g<BD0>3@X03Te:@0l>2`0?CT]03Xh:@0n>b`0?3X[03`j;@0n?2l0<BlR02PV6@0P7Q807Q`@024M
4P0O6a008Q/A02@L4@0[8AL0<bHM03`_9P0n<2L0ACL^04Lf;P17=R`0BCT/04Hh:`14=RT0A3P/048f
:P0o=B/0Bd4g04]2>@11>2l0?SL_03di<00d<2L0:BLK01dO4@0P8Q@08bHE02H[5`0]<1d0:c0J02L/
5P0_<ah0:B`I02`_7P0a<bD0<S@Y034c:00/;b@08bHK01`N4`0Q8aH09BLI024R500O7A008R0A0P0V
91D04`0V8a@09b<G02LQ5@0S7A40;BLK03@^8P0i=BT0=C<V03<a900`<B<0=STX03Pk:P0[;Q/0:B`I
02X]6P0N8A0071l>024T4`0T9QP00P0W9a/07`0V8aX0;2PR02LP6P0W81X0;2DO03H]9P0i<2T0=2dS
038/800c;B40>cDW03Xd900g<B<0?SP/03Xc:@14?CD0If9L07UdL01_JVH0KFUV069OG@1OGU`0GemO
06UYJ@1/JV/0M79c08R6Q`2TX:40blG90??]l@3hk_H00P3dj_802`3gkOD0m>[b0?;Xl03VgN80elkC
0<Fl`@1nMGT0IEaO06MQH@1/J6L0KVYY0080If=R02T0P7ak06]WIP1LF5L0GUYI04I2@@1>BT/0A411
04I2@`18A4<0BD=3065KF`1`JVX0CDU402<P5`0Z9ah0:bPO02`Y800e<RT0>3D^03Db;@0/:B@0;RdY
01HE4@081`D02`T:01`J7@0Q7b@071XO01XG7P0I5Qd06QLN01hH8@0P6B408Q/R02`S:00/8bH0=B//
03X^;P0h:RT0AcPe04Df<`0202lM6@0V03l]:`1HBDH0LF9O07]]JP27NGP0QGYh08MlNP26O7`0UHb=
09fDU`2k/[L0ZJ:Y07E^MP0/9bh06QDL02TT:`0e<3L0<R/c02/T:`0Y8bL0:2<W024L800N71l071XK
01dM6`0P8A`081lJ01`I4P0J5a006QLB01`I500M6AH07QXG01hJ6@0S7ah09b<T028N7`0L5a/201/F
700J020I800K51`071DM01`D7`0M5b407QPT01hK9P0N72T06ATS01PK900F6R<05A`R01DN8`0H8BH0
624X01XS:P0M9Rl0;CE003e3D@13BEL0DEAU05YML01UJ7/0IfUn06Y/PP1XKH<206I/PP0S06U_Q`1Y
KhD0IVf006Q_P@1XKH00IF]k06E[N@1RJ7@0HfUe069XM01SJGL0H6Mg069YN`1PJGX0HFUl05iYOP1I
IGd0FfN105QVP@1GIh40EVN105IXP01CJ7d0E6Ul05AWN01CIWD0DFAb055SK`1=Gf/0CV1/04mQK@1=
GVh0Bea^04]LL019FG000P17EFl01`1;Eg40BE9_04Q?J`18CVP0ADUR04M9H018BV402Oooool000Oo
oooo00h09QhK020H5@0K4a406Q8@020H5P0R6QP0:20N02hV900`:2D0>30[03/b;@0i<2T0=RlU03D^
9080<b`R00<0>34W03D^900e;R@00P0b;R<0D00g<2H0>34W03Xc:@0i=BX0>cDY03Te:@0k>2T0>cLZ
03/g:`0n?2l0=C<V02PV6@0R81<08AlB028P4`0R7Q8081`@02TS5@0_9aX0>2hR03/a9@0o<bL0@cL[
04Li<017=R`0ASP]04Hh;P14=Rd0A3D^048e;@0n<BT0BSli04a3?00n=bl0?3La03/h;`0b;bH08b<G
01DG2@0K7`h07b<B02L/600_=1h0;C8K02P]5P0/<1X0:B`I02/^7@0^<280;BlT030a:@0/;BD08RDL
01lQ5P0Q8aH08bDG02@W5P0Q8Q809B@B02d/600T8`l09R<B02LT4`0Y8a<09b0@03D]800i<bD0>C<W
03<_8`0c<B@0<S<U03Xl;P0o@C<0;S0R02`_7P0R9QD05AL901dO4@0S9AL092HH0P0W9a/0;`0Y9Qd0
;RXR02`U7`0/9Al0;BHN038[8`0d;B<0;BTN02`X700[9a/0<RlP03@a800e<R<0>CDY03Xf:`1DCdT0
KfaW06QUH01NGET0HF1L061OG@1NGU`0IFMV079dL`1mOGd0U9:C0;Rd]@3Tg^80k>;Z0?;Wk`3djO40
m^[d0?CZl`3YgnP0knS`0>SQj03Gd=L0ZJ:Y08n9S@1UH6@0HUiO06ETHP1[JVP0JFER05]GE01CCd`0
H5]H0080A3hn03h0K6IV071ZJP1VH680Dde?05A>D01>B4P0DDQ;06MNH@1TGV00>C@c020M600X9b80
;RdX03`k=P0h=c80<2l[02LV8P0T8b408b<S01LG5`0<30`030`>01/I7P0K61l050lF01D?6@0I4ad0
6aDO01lI8`0N62808AXR02<L8`0W8BD0<2LZ03<Y:P0f:RX0?c4`03DV8`0V5a@0:AXE048c<01XFEH0
PG9_08MiMP2KSHX0UHN4089gL`23NGL0WYBE0:6FVP2ES940N75h04Y5B`0S7RD091lU038]=00f<CL0
=C0d02hX:P0X8R80:BDT020L6`806aXH00<06a`G01dM6`0M7AX00P0L61D0?@0K5a@07ATJ01hL7@0O
6a`081`M020K7`0O6Qh06aHJ01PC5`0G4QP06A8I020F7P0N51`07A<L01hF8@0M5B007QPT024M:`0M
6bP06ATU01HH900E72H05AhW01DO:00H8R/072H`020Z=P0_>DD0>T5A04M>H01?E6L0Feia06AVN`1V
J7d0J6Yo06a/Q@1ZJX@0J6Z306Q/Q@1ZKXL0If^406M/PP1XKH40JVf006MZN`1XJg`0IVaj06=YM`1R
J7H0HfUi061WM`1SJW`0H6Uj065YO01PJWh0GVUo05iZPP1JIWh0F6J005ATO@1GIh000P1EIG`0301B
I7P0DFAe04iQL01=GVh0D69`04iPKP1=Gfd0BUe/04ULK@1;G700BEU`04MGL080AUA^00H0B5=_04I@
J`1:DF/0ATaT04=8GP17BF09ooooo`001oooool02P0Q5aH07Q@C01hD4`0K4A007Q@C024G5P0U6AT0
;20P03@Y9`0g;2T203`a;@0503H]9P0c;2@0=BhV038^9@0a;B@00P0e;RH05@0d;BD0=BhV03Tb:P0j
<b/0>C8Z03Xc:`0i<2/0>S<[03`e:`0j<bX0>SH]03`i<00g=2/0<2`Q02l[800[:Ad0:BLK02XX6`0[
9a/0;BLK03<[800203/a9`0E040c:P11=2/0A3D^04Df;`17=Rl0AS@`04<d<@12<c00?c4^04Dg=01=
@Sh0Bd8m03lh<P0j=bh0=SH/02h^8P0L7Q003a<401TM300L8@/08RL@0080<3HL02@09R`B02X^5`0/
;A/0:R/K02PY6`0W9ad0:B/P02PY8@0U9Qh08R<K02DW700T9QT09bTK02DV600R8a<09RLE028T3`0S
8Ph09bHB02HS400Y9A80=c8O03La8`0g<BD0<blS038`900e<bL0@T8f04M7>`0e=bX0;2hS02HX7@0S
8aT092@J02/[8@0Y:Al202XW800302HU800`;BP0;BPT0080;BPT06X0;b`W030`:00a;RL081dD02HS
6P0]:al0=38U03@b9P0j=bh0A44j05EBB`1ZJF@0Hf9P05]JF01OGU`0H61P06a/K01fMgT0SHn>0:2P
X03=c<X0iN7P0?;/k03djNd0n>ga0?O/lP3fkO80lnWa0>cUk03/ind0b/G909^FVP1aKg80IfEX06IT
IP1WIV@0J6QV06QWH`1EDTd0@Sdi03D`:P0h<B/0?CH`04<l=P1dK6T0Ng=`06iVI01YH640J5mP05aC
E01LDeH0JF=W05mJH00Y9B/07adR02HU:P0^;C80?Ca1034`=@0J6Ah04Q4F01PG700F5AX04a8G01HE
6P0B41D061HK01PC6P0C31@05`lJ01`D7`0J4Qd07QHQ01lG8P0Q72<081/Q02@O8`0_:B/0=S0`03L_
;@0h;2`0;R<Q02PM6@0U6QH0=bTV05E7A01^HE/0SH1j09b?R@2:OgT0IEYD075WI01gKF`0Mfia05mF
F`12?400>SDi03D`=P0`;S40<c4f03Tg>P0j>3T0;BTX02@P7`0U8B007a/J0`0I61H00`0M7Ad06aXJ
01LE5P0201HD5@0/01TG700L6b0081hS01lM8P0L6B0061DL01DB6@0B3aH050lF01<>5@0I4QX07aPP
01dE800O5b807QPT01`H9P0N6RT06ALU01PG9`0H6RT061/Z01TO;@0J8C406R4c02H]?`0c>dh0>d=H
04I<I01HGWH0I6Z206EYPP1VJX<0J6b506M[Q01ZK8L0JFZ606U[Q01[KHH0K6j706]]QP1[L8H0JFj4
06EZOP1VJgl206Q]P@0K06I[O`1SJWd0HfYl065XNP1RJG`0HFUl061YNP1QJWd0GFQl05]XN`1JIgX0
FfMm05]WO`1IIGd0EVEl05ETN`1BHWT0Df=j055RMP1?H7@0DF9d04mPLP1=GW00C5e_04YKK`18FVh0
BEYa0080AUI`00L0AUA_04MELP16DFd0ADmZ04E=I013B5h0ADYP00Wooooo0007ooooo`0N024I5`0M
4a40718@01/A3`0K40h081DC02HK6@0]7ah0=bTV03T[:00k;RP0>BhX03H]9P0a:240=2dU03Pa:@0d
<2L0=c0Z03L`:00f;bL0>34Y03`e;@0j<b/0>S4Z03T`:@0k<Rd0>C0[03T`:@0j<R`0>C8/0P0j=Rd0
gP0g<bP0=S8W038^8`0a;b80<RhR03<_8`0d<2@0=c4U03`d:@0k<bP0?S@Z044g;@14=bl0@cH^044b
;@12<bl0@c@a048c<00n<2d0@S@a04e2?01ABT@0@clf03dj<@0h>2`0:BXL01PK2P0>4@005AX601hS
3@0X;AH0;C<I02hd6P0/<QP0:RhH02ha7P0X:A/08R8F02<S6@0T91`0:R/S02PY8`0W:2809bPP02@U
7@0V:1d09bLK020Q4`0M7Ph071l<028S4@0V9aD09B@@02XX5@0`;A`0;R/L034]8@0b<2@0<BlS03Dc
9`10?S80C4U004e=A@14A3`0>c/c03<`:`0b;bP0=34Z038_:P0a;RT0;RXW02/Z9P0^;BX0;B`X02XV
8`0];2P0;2dW02d^:00b<b/08R<K02/[8`0b<RP0<C4W038b:00h>300AdI105IED01KG5L0FeYH05UI
F@1UIFD0JVYX07UiM`27RHP0ZZbY0=;Ac`3`kn/0kn_X0?3[i`3cjnT0mng/0?K]kP3ckNd0mNc_0>?M
g`3@c<d0Z:JW07ekO01aKg00JVYZ06MWI`1`L6h0LW9`06IUH@1<BD@0=C0Z030Y8`0g;RL0?C@]03`c
;P1OE500LVQV06eSHP1`IVD0KFES06YQHP1[HVD0KfU]065OI00_;3@09bH^02XZ=00_;cL0;Rhf02@T
;00G5al05QLL01PI7P0E5Q/05QDJ01`K800J61d061HK01@=500B2a8060hG020F7`0K51`07AHN01`E
7@0N6B0081/Q01dH700W8b@0?3Pi03La<@0d:b`0;bLU02`T8@0Z8Ql0:R0N03<Z9@10=C40JUmI08Ik
M@1dJF<0FDi805Y?C01CBDP0DTU:04I0@P0f<S<0=38e03lm@00k>C`0?3Xm0490@@17AT@0<S4_01LF
500M71X08AdL01PG5@0J6AL06QPI01XJ700J6A/05Q@G01@B5@0B41<04a4F01XI7`0T8BP08b0W01`I
8P0J5b005aHN01DD700C41T05Q0J01PB700K5Al071HP01hH900M6RD06aTW01`I:P0K6RX061T[01XM
;P0K7S406Ahb028W?@0T:T00=SaD04E<IP19D6X0DUMd05aQOP1WKHL0J6j806Q/Q`80Iff500H0Ifb5
06M[QP1YKHH0IVZ306U]QP1XKH<206Q^Q00;06I/PP1WKH<0J6j606M]Q@1UKH80IVj306A/P@1SJgh0
Hf^005mZO01PJgd00P1QK7h02P1LJGX0GFYk05]VNP1JIGT0FVIl05MSN@1EHGL0Df9g05=RN@1@H7L2
051QM@0?04mPM01=GW80CUmc04]KLP1:G780B5Ub04UIL`16EW00A5A^04ABK@16E6h0ADmX04M?I014
Beh0ADYN00Wooooo0007ooooo`0<01hI5@0M61807aPB01`E3`0K4P/07aH?02PM5`0`9Al0=BXT03P/
9P0i;2@0>2hU0P0e;2<303Pa9`0403T`:@0h;bH0>S4X03Xa:080?3<Z00T0>2hU03L]900h;BL0>BhX
03T_9P0j<2P0>S4Z03/b:@0j<BP00P0i<bL02@0j=2P0=c<W03La9@0g<bP0>CDZ03Xf:`0h=2T0?3D[
03hf:`0203lg;00503hf:`0o=B/0?c8Y03lb;00o<RX00P0n=2/0>@16?C@0Dda404]7?010?S40=SLW
02@U4`0E60D041<001XM200S9a00:BdF02da6P0^<A`0;34K02X^700X;1d09RPM028T6@0T9Ad092DO
02//9`0_<2/0:R`Y02PZ9@0S9B008bHO02DV7P0Q8aP08B<F020T5@0R91H092HH028U500W:QT0;2lN
02/]7`0^<280<S8V034a9@0h>2`0?S``04I3>P1FDd`0De1;04m<A`12?CX0?CPd03Td<00c;RX0=2l/
038^;@0`;bd0;bl^02h^;00[;BP0;S0[02d`:@0202ha:P0P02X]9P0b<bd0=3D]02h_9`0g>380?Chi
04Y;AP1MGUT0FE]H065QH@1QHf80J6YW075bK@2PXI`0_;fg0=[Ke@3al>/0n_O`0>g]i@3dlNX0l>_U
0>kYh`3bkNL0mO;]0<_6`P2c[j`0^KRd09nNW01_KV`0JVUW06a/JP1]KF`207moO@1e065PG011?CX0
=S4]02lX8P0f;BP0?34]03T^;01;?Cd0K61R07Q/KP1dJV/0KfIW071WJ01`JV`0FEAH04A2A@0`;c@0
:bX`038b>P0`<cP0;C0e01/N8`0D5a`06QhQ01PI7@0E5QP06ATI01XJ6P0L6Q/06ALJ01D?4`0G4AD0
6A0E01/B5`0G4AD071LL01`G7@0O6R408QdS01hL7`0R82<0:RP[02HT9`0X9RT09R@U02HU8`0U9280
9b<P02dX9@0b:RL0ASli06IKE`1MDTh0EDY60556@`1:@3h0BD4o03dh=@0f<S40>SPi0451@@13@d<0
ADE504U9B@0o?cd0820N00h>300H61H06QTG01LE5P0K6AX071XK01/I700J61/05Q@G01DC5P0D4QD0
4a4D01PF6`0N6Al07Q`Q01dJ8@0L6B006APN01<B600C4QX05Q<L01PE7P0N6bH071TT01hL9`0M6bH0
71dY01TK:P0I6R`061/^01/M<P0N83L07b<l02`bC00d>U@0ATaV04]@K@1FFgP0HVN506=XQ@1UJhD0
Iff706Q^QP1WKHD0Jg6906Q`Q@1ZLXL0Hfj206MbQP1XL8D0IVj10080IG2200@0IG2406A_P`1TKh<0
IG240P1RKH<04@1QK880HFb0069]P`1RKh80H6f0061]OP1NJg`0G6Ui05eZNP1JIgL0FVMh05UVM`1F
Hg@0E65b05ERL`1@Gg80DF1c0080D5mb00l0Cf1d04eNLP1=GG@0CEef04QJLP18FG80B5Uc04IGL@13
Dfd0@U1Z049AJ013CV80A4eN04=:FP13BEL02Oooool000Oooooo00l06a/C01TI3`0K5`h07QXA01`H
3@0K5``07aH=02/R6@0a:240=bdV03T_9P0h;bH0=bhU03P_9P0j<BP00P0g<2P0100i<2T0>S4X03/b
:@0k<RT203`c:P0U03Ta9P0k<BL0>2hU03P^9@0g;B@0>RlY03T`:@0l<RT0>C0W03Xc:@0k=BT0>C<W
03Xd:00i<RP0>34W03Te:P0g=BT0=S8W03Xf:`0l=RX0?SPZ03dg:@0n>2P0>c@T03Xb9@0k<bP0@CL[
048j;@0o=b`0@S/a04Y6>`1;Ac`0@3ha03Pf9`0c<B80824?01`O300202DX5@0H02X]6P0`<b00:RhM
02P/6`0W:ad09BPM02LZ8@0X:b80:R/U02LX8P0];RT0<S<^02l`:`0X:RD092DO02LX8P0V9al092HK
02@V6@0R9QP09BLJ02<W6@0V:1X09bTK0P0/;R009`0_<B@0<cDX03@d:P0g=bd0=34X03Lb;017@Sh0
CdY704@l>P0e;B/0>S8`03H^;00c:bT0>38b03di>P0m>c`0>S/j03Dg=P0b=c<0<CH`03<h<P0a=Rl0
;c@]03@g<00n@CX0>c`f03Pk=01;CDP0Ce1;05eMF`1KFeT0GV1M06ATHP1]KF/0NW]f0:FVX03Qh]X0
m?G]0?KfkP030?SekP0e0??`j@3ak^L0mO3Z0=kId`2]Z:80ShZ40:bYXP2_[:L0NGQc069OFP1WIV40
IVEQ07emN@2ZZZX0Shf>06MVI014@3l0:B<S01dE4`0`9R@0=B/Z044e=@1PE5P0Kf=W071SJP1`IFT0
MFa_069LGP0m>3`0<Rda03@b=@0[:Rh0@T5605IGF`1HFEd0BDY>02d^<P0O82@07AhR01PI6`0M7R00
92@T028R800P7ad06QTG01HB4@0I4a<06Q@D01/E5@0J5QD07ATI01hJ6`0O7B000P0P7R409`0S8B@0
9BDW02DT:@0V9RP08b@V02@U9`0S8bD09R@U03<_<00`;2/0>cHc04e5@`1:@3h0Acdl04<i>00n=S@0
?CPe03di=P0k>SP0@d=104U9B@18BTT0Cdm?03De<`0=3``01`L500d=2`0@40h061PH01`J6`0K6A`0
6ALJ01XH7@0K6Ah05aDJ01DC5P0F51L05aDH01TG6P02020N8@0701hL8@0H5Q/051<H01DD6P0F5A/0
5aHN01lN9P0202@R;@0G028P;@0O7b/071d[01/N;`0J7C007Ald01lQ>00U9d00<CE@03e3G@13B6D0
DUMd05eRO`1UJXL0JFj;06U_R@1YKhL0K7::06Y`R01YLHH0JW:706McQ`1VLhH00`1TLhH01`1SLh<0
I7B4065aP@1RLH@0I764069_PP1RKX@00P1QKH<01`1QKHD0H6b2065]P`1PK880H6n405a[OP1JJWX0
0P1IJGP01P1HJ7L0EfMf05IVM@1CHg80EF9b05MTM080D61_00D0D61`04iNKP1=GW00C5e_04]KLP02
04UIL00:04UILP15EFl0AEE_04ADK@12DFP0AE5W04AAHP12CUh0@4YF0418D`Wooooo0007ooooo`0I
01PK400E60d06AT?01TI3@0F5P`04a<901PD2`0Q7A@0:BHO03@^:00g<2X0>S<]03Tb;00f;bT0=bl/
03H^:`0i<Bh0>S<]03/d;P0k=2`0?3D[03hg;@0m=R`0>S<Y03T`9`0203Xa:00403L^9`0h;bT0=c0Z
03T`:`80>S<[02<0>34Y03Xc:@0k=2X0>S<Y03Pa9`0k=b`0>CDY03Lc9`0j=bP0?3TZ03Tf9@0h=B@0
>SLT03Td8@0g<Ql0?3LT048k:@14?Rh0BD<e04<m<@10?340?c/`044m<P0o?C40?3X^02LW6`0W:A/0
:bdO02T]7P0]<B<0<3@V02T_8@0U:ad08bPL02HY800202X[8`0Z02HU800U91l0<34[03Hg;`0e=Rh0
:bdR02LW7@0X:1h0:b/O02XZ7P0W:1X09RPJ02DV600W:A/0:BXL02LW6P0X:1`0:b/O034a9`0c<bT0
>SL`030]9P0/:B80;BPT030X9@0g;bd0=B/Z02lU9P0b:2T0<BPY03Xa=011>cd0Ad9605=AE01CE5H0
BTi=03m3@P0i?SX0>S`i03Pj=@0e=c80?Clj0P19BdH0?@1<CDP0EUMB05EFD@1NGeX0HF9M06QYI01^
KFT0OGag0:NVX@3Gell0kNgU0?;bjP3hmNh0mO;]0?Sck`3el>`0kn[V0?G]jP3Pf=D0]J^Y07Q^K01g
L6X0SHIn08AoN@1/JF80JVEO06ERF`1NFeH0R8F30<O5aP2^ZZ/0THb@06QSI`16@4@09b4S02DO8@0Y
8bD0CDA706EKH`1]HVX0NFif06aRJP1FC5@0>38f02LR9P0b;Rl0<2h_02DS901DDU<0L71`08B4Q022
PX@0J6M/03/j?`0D5AT092DY03Lh>P0d=3@0:BTW02DV8@0K6QH00P0I5Q406@0F4``06ATA01PH400J
6A@07A`H01dN6@0M7A/08B4O02@T900V9RP09bLY02@U:@0R8bL092DY02PW;00[:Rl0<2hc030^<@0e
<3@0?SPl03hh>P0n=CX0?3<h03Xd>00j=CT00P0m>c`0;`13@d<0CDe;04m?C@1ADDl07AdK00D50`0A
4@l04Q4?014?400H5QT06aTL01XE6`0K5Q`07APO01dI800J5ah05QDJ01LF6`0F5QP06a/M024Q8@0P
82007QhP01TI6`0F5QP06APM01PF6`0M6b009B@/02/Y=00]:cP0928`01`K:@0N7Rl07Ahb01hP=@0P
8ST092Ho03PjD`10A5l0BTiW05AHL`1SIh00J6j606AZPP1XKX@0Jg260080Jg:500P0J72306QcQ`1X
MHP0IGB:06=cRP1RM8P0H7F805mdQ`<0H7>401T0H76306=bQ@1RLHH0HFf3061/Q01RK8D0HVb7065[
Q01SKHH0Gf^305m^Q@1LJh00FFYl05UZNP1JJg/0EfYi05EXM`1FJ7H0DVAb05=SL01DIW80DF=_051R
KP1AHfl0Cf5]0080C5i/00d0BeY]04QGJP1<Fg00B5M_04MEK`19Eg40B5A^04MCJ`16DVP0A55T045>
G`0oBeT0@4aH00Wooooo0007ooooo`0;01HL400D5``05aT<01TK3P0E5``04Q8801DB2`0M6Q<0:RLP
030/9P0e<2X00P0f<B/04P0e<2`0=2l[03Ha;@0i=300?STe03lj=010?3<0@She040l<@0n=bd0?CH/
03/d:P0k<RT0>S4Z03`c;P0j<bh0=c8^03L_;080=c8^02d0=S4[03Pd:`0l=Bd0>c@/03Tb:00h=2P0
>CHW03Xg:00i=RD0>SLT03Db7`0c<A`0=S@O03Le800h=R40=S@O03`i9P15@Rl0E552059>@P0e<BH0
<BhU038^9@0h=B`0?S/d03Lg;@0c=BX0<SDZ030c:00e>2d0<SDZ02X`8P0T:Q`092PL02@W700Y:b00
;2hS02`/900];BD0;c0X03Pj;`0n@3<0<c<W02LW6`0[:al00P0_<280I@0[;1h0;BhP02d^800Y:Ad0
;BdQ02PW6`0[:1l0;b`S03<`:@0e<R/0<c0[02l/9`0S7QX08QdI02DM6P0Z81l0;B<R02/O8@0X7Ql0
;R<W040g>P17@DD0DdeA06EPI01WIV/0GUiP05YKG@1GFEP0CTi>04];B@18B4H0ATI4051@CP1DE580
F5UD05YKEP1KG5L0HV5L06i]J01[JVD0P7mj09fMU@2m^[<0k^gT0?CdjP3im^l0m?7Z0?;^j`3`k>T0
m_7^0>oZi`3Jd]00]Zj/09F;RP1`IV@0JfAN075ZHP1eLFP0LFeT06eYH01KEdh0DTm8075^JP2/Z:L0
][:c0:nZ[P2=R8`0KFQ/04e7B`0]9b/0<2/_04Y5B`1UGVH0J5iW07=YLP1FC5D0;2D]02@M9@0a:S40
?3Lk03di>P0S7ah0>SHe05MCDP2BSXd0Y:2Q08j<S@1WIFH0<30`02l_<@1<C4`0>SXh02h_:P0X:B<0
8R4L01`L500O71D04A4901@D300J6Q806QXE00807AhI00@08B<N02<S8@0T92809BDU0P0U9RP08@0X
:Bd0;2/`03He>P0d<cT0<2le03<a=P0a;c@0=C0f03Ha=`0f<CP0=c4i03Td>`0h=C`0?C]003lo@@11
@D40AdM704Y:B014A4@0>CTg02h^;00V9R@05aDF01/G600H5QT07Q`O01hI7`0O6R4081XT01hK8`0K
6R006AXN01`M8@0201dN800X01lO7`0P81h0820P01hN7P0J6ad07AdO020P8P0Y:2d0;B`b02h^=P0Y
:CD08b8`02<R<P0Q8S<07b8e024S>P0V:T<0;31903/oFP0m@EX0CE5Z05iRN`1TJ840IF^306I^P`1X
KX@0Jg6706]bQ@1[LhH0JGB806YeR`1ZMXh0IWJ>06AeS`1RMXh0H7J;069gS01PMHX0GW>8061bQP80
HG:600`0HW6806=_Q`1VL8/0IW2;06A^R@1RK8L0I6j7065]Q@1PKhH0Ff^205Y[O`1IJW`205MZN`08
05IYNP1EIWP0E6Eg059SL`1DIGD0DVEd051SL@1?HFl204iPKP0>04eNKP1=GFd0BUU/04UHK@18EFh0
Ae=]04QDKP1:EVh0BE=/04IAI`14DF@0AE9S041>F`0oCEP9ooooo`001oooool201PK400<01LI3P0H
60h05QH<018B200G50/08AhE02h[8P0e<BP0=c<Z03Ld:`0e<RT0=c@[0P0f<b`04@0n>c@0?c`e04A1
>014@CP0AD8i0490=00o>c00?SX^03Xf:`0k=2`0?CH`03lg=00o>SP0>SHe03Tc<`0h=340>SHc0080
=C8]02h0=c8/03`e;@0k=2X0>C<U03La8@0i=240>cHR03Xe7`0f<A/0<B`F03Ha6`0d<Q/0>SPR03Dd
8013@S00B4Hg051>@@1LFTh0AdDi038b:00[:240;BdU03Th<`10@CT0@4<j03m2>@0n@CP0@D@i03@h
:P0/<2409BTJ02HY6`0X:Q`0;2dO038c9@0^;R80;blS03@f:@0h?2h0?T8d03Xl;`0];B40<C4U03Hd
:00i=b/0=38V0P0`;R80P@0^:b80;b`S02dZ8@0]:280=2lY038]9`0b;BT0:bHS02HQ7P0N6AH06aHC
01TD4@0V7Q`0:b<Q02XP8@0T6Q/0;24U03hc=`12=cd0C45906EKH`1_Ifl0KFI^06UTJP1ZJ6/0JfIZ
06EPI01MFEX0FeMF05]JF01JFEL0H5mK06=RG@1QH5/0I6AL075aJ@1jNW80U96:0<G2^`3MgMD0moK]
0?SekP3dm>`0lo?[0>_ZiP3Yj>@0kn_Z0=WEe02ZYZD0Thn>07McL01_JfP0KFYU06i[I01_K6<0KFYQ
06]XG`1NFe80DDi705eIE@1lMg@0VYJC09nKVP2CSi00NWEi07A_L`1IE5P0BdI<05QCFP1WH6P0GUIQ
0598D`0j;cd09AXX02HK:@1BB5<0ETmG04@n@P0`:R`091hN03Tc<`1LEe@0SHR508N2O`1SGU/0B4E0
04M6@P1BDdd0?d0h03Lh<00_;bL09RHN01`K5P0M71L071PE01DD400J6AL06aTI01/K7@0O7al0828Q
02<S8@0R8R008bDT02HX9`0U9BD0;B/^03<a=00k>C`0>SPm038`=@0e<3H0<B`b02h[<P0a;SD0<c0i
03Ha>`0i=Sl0>3Dn03lnA013@TL0@T9404M7B@16ATH0@Cm20490@@11@D409bLW01/I6P0201`J6`04
028P8`0R82D07adR01lL8`807QdR01d0824S01hO8@0S92P08R<U01lQ800M7ah07b0R01hO8@0I7B00
7b<V02`]<@0c=3T0;Rld02/^=@0W:cH07R8]020R;`0P8c<08RLj02@Y?`0Y;dL0>3iF04A:HP1DFW@0
H6J006Y`RP1[LH/0JG2:06]bS00206edSP0F06eeS01[LhX0JG><06]eT01XLhl0IWFB06AeT`1UMY80
HWJA06IgT`1RLhl0HgB>069cS@1PL8X0Hg6<06=^RP1VLHd0J76>06M`S@1XLXd0Hff806=_Q`80Gfj5
00`0Ff^205UYP01HJ7l0F6Mn05QVP01FI7l0EF=n05ARO@1BH7/0D61i051RNP1BI7`2051PM`0?04aN
LP1;GG40C5ea04UJKP18F6l0B5M_04MEK`17EVd0BEE]04UCK017DVP0@e1S04EBH`12CU`0@DeK00Wo
oooo0007ooooo`0F01TK400J71405aL=01PH3P0E4PT03``301XG3P0Z9ah0<BdT03Lc:P0i=BX0=S@X
03Dc9`0f=2P0=C8Y03Lg;@0o?cD0@3dd048o=P16A3P0AD<g03Xh;080>cL/0380?CH/03hg<@10>3D0
@C`i04<m?P0l>3T0>cLf03Lc<P0i=C80>3D`03@a;00e<2X0=C4V03Pd:00f<200=c8O03Lb7P0j=Al0
>cHP03Da600c;QP0=C0J03Dc700i=b<0>CPV04A2=@1<CCl0D51405=CB@18B3h0=CD[03@d;00Z:B@0
:R/S059CB`1OHUT0DUE<051CBP1FFDh0BT`o02HX6P0U:AX0:RdN02PZ700[;1h0<34S02XZ7P0[:al0
;c4T03Di:`80?3ha00X0>SX^03dk;`13?c@0@cld03Lc:00^:Ql0;BTP02l[8P0`:bD0;BTS0P0`:bD0
9@0^:B<0;2LS028M6@0L5a<06A@A01dH5@0L5a@091lL02TQ7`0X81h08aTJ02`R8`0a9RX0=R/_04Tn
A01KD5H0LFI^07E[L`1aJW40L6]_06mYK@1^J6`0IV1R06=MG`1TH640IV9Q06eYIP1/JF@0JFIQ06UV
G`1gMfl0YZJL0=7>a`3YjN40moO_0?Gek@3cln/00P3em>l0C@3Xin<0e]GA0<2o^`2FUI40NGQd07Yi
M@1dLfl0K6UT06YWHP1[J6<0KV]T06]XG`1VHe`0JVMP069OF01MFE<0JVEQ07ejM@24P7d0NgMf07=_
KP1fLW<0KFQ/06UTJP1aJW40K6E]04i4C`0/82`091PV02/O;@0j;S`0IeaZ06MMJ017?DD0:b8V02DO
7`0[9R<0B4<o07=^JP1WHU`0CT]404m<@`1FETh0DE5703i0=@0m?C<0=cL]030]9P0V8a`08b0K02@O
700L5QH08A/M02HQ9@0Z9BT0:bT/02/[:`0V92D092<Q02@T8P0Y:BL0;bh/03Lc<P0k=cH0?SXk03Xe
>@0g<SH0;bX`02@O9@0T8BP0<2df02l/=@0e<S`0>cQ303/iA014@d/0B4M=0080AdI;00D0?3]003<a
=P0i=cX0=3@f01dM7@0201/I6P0U01lM7P0U8b@08AlR020N8@0J6Ah071/P01dM7`0W9R/0;bhc02TX
;@0W9R/092@V01hO8@0O82@07QlS01TL8@0O8RL0>Ca303Lj@@0W:S408bP^02HZ=@0R9S408BDa02HY
>00T:C`0:Rm303ToE@1<DVX0F61g06M]Q`1`MY00KgF?075gT@1]M8h0KWFA071gT`0206edT00:06mf
TP1]MY<0K7FD06UbT@1WLi@0IWFF06MfU@1VMiD0IWFD06AeT`80IGBA00D0I7:?06IaS`1VLHl0Ig2=
06QaSP0206MaS00<06EaR@1OKXD0GFb305a/P`1JJh40F6Qo05IVO`1GIGl0EVAo05YUP@1GHX00E5mm
0P1CHGh04`1?GW/0Cf1l04mON@1>GgT0CEmg04aNM01;GG<0BE]a04MIK`17F700AeI]04IEK016EFX0
Ae=Y04ICIP15DV<0AE5Q04A=G011BUT02Oooool000Oooooo05P05AD;01HF300H5@`05Q<:01PD2@0B
3P<06aL>02XV7@0`;2<0>CD[03Te:P0g=BT0=cDX03Hd9`0e<bL0>SX^044o<`0o>c00@cld04A0=012
?S80<blT03L`9P0l=B/0@CXb048k=@14?3T0BT90044h>00k=CD0>C<c03D_;`0g<Rl0=C0/03@_:@0c
;bH0<RhS03Dc900d<Ah0=cDP03Dc7P0g=Ah0>3HO03<a6P0b<1/0=C<N03Xe8P0i=RH0?3X]04A1>017
A3/0BDU104I6?P0m?c@0<cDZ03Df;P0/;BD0:R`Q05YLD@1aLfP0GV1E05mQEP1_LF@0IVQM02h`8`0]
<B<0;C0R02`^8@0];B40;2`P02/[8@0X:1h0:bdR03<e:P11@CL0AD8i04=0=`15@CP0BD8j044j<P0b
:b<0:R<K02hW8@0[9R00:BDL02`W7P0`:B40:2@K0P0W8aX01P0Q71H04Pl801LD3`0N6aH07a`G024N
6@809b8N02809B0M02HQ7P0Z9B80<bh[048m>P1>BDH0JV9S071ZJP1dL740L6a]06USI@1XGf80IeiQ
06eTI`1bJF`0OWQj08N1P`1oNGT0OGQe07ikMP2LW9@0hn?K0?Kel03al>/0mOC_0?7bk03_l>X0lO;]
0??dk`3Fem80UYNB07]jMP1bLF`0JfQS0P1_K6L0G@1/If<0JVEQ06QSG`1eL6`0OGQb08=nNP2DSh/0
UY>>06aYH`1HEDh0JFIO06aYHP1/If<0KfYV06iYIP1]IfL0M6i`07YaMP1WG6@0>Bhf01d@6P0C1A80
70hK04@f@`1XG6P0ED]F03T_=`0Y8bH0:BDT02XV8`0f<bh0BTU4051@B01@D4H0D51404mAAP1=Cd80
AdLk0492=P0l>2d0>3@[03L`:00]9R00;28Q02`R8`0T6Ad0@3Hk04U0A@11>cl0>S@f02lY:`0/9RH0
:bLV034]:P0j=S<0?CPe03hi=P0o>SL0=c4a02`X:@0P6al06aHL024L8`0]:S<0=S<l03Pf@@0j>4<0
@3i904M5D01:Ae80AT=<03Lf?P0T8bT07a`S02DR:@0N7R006a/K01`L700I6AL06a/I024Q7`0S8R00
6QPI01PF6@0N72008AlT03Db>@0e<S/0;2Tb02HS:P0U8RT081lU01/J8P0201`L900@02<V;`0f>4@0
:R`h02<V;`0Q9C008bLb028V<P0S9SD09bXi038hB010AEP0CUEX05aRN01VK8@0KgF?071fT0<0KWFA
0140KgJB06idU01_MID0KGJE06aeU01_MID0JgBE06efU`1YLiD0IgBF06]hV01WMYD0IWBA06IeTP1W
MI00IG>>06MbSP0206QaSP0;06YaS@1YL8`0IFn:06A`RP1QL8L0GFb305e^PP1JK800EFUl05MYO@1F
J7h00P1CHgX01`1EHgd0E69m05ARO@1DGg/0EF=n05=SO@1>GWP00P1;G7H0201=GWP0Bemg04]OM`16
FW80AE]`04IIK`17Efh0AEIZ0P16EFP01@14DF80@e1Q04A@H013C5/0@d]H00Wooooo0007ooooo`0B
01PE300F4`X06AD<01PD2`0N5`l0614901`E3@0`:B40=BhV03`h;`0m>Bh0>SP[03Pf:@0g=BP0=S@U
03`j:`11?c00@Ch_0P12?2h02@15?c40?3HZ03`e:`0o=Rd0@cXc04Ho>@1;A3h0CTI304Lo?00203hf
<`0903Td<00g<R`0;b/R02l[8P0a;B80<S0S03@b8`0b<Ad0=SDP00<0=cHQ0P0d<al01P0d<b40?c`[
03dk;@13@CD0BdLn044n=@80>CT_03L0=CLZ02/]800a<bH0=CLZ02`^800h>bX0MWQZ071bI01VJ5X0
NWa_07=eJ018Bd00@4<h038e:P0`<RD0:RXP02d]8`0/;280:2PN02`/8P0d=2X0@Slh04U6?`1:ASd0
BDDl04Y3>`0c;2@081TA01hJ4@0U7QH081`C01hK4P0S81D0:2@I01lK400K6@d08AlC01dK3`0F4`X0
6aP?028O600Q7QL0924J02TV7`0Z9Al09b@M02DR6`0X9Ah0:bPQ03Ld;@17@S`0FEA>06UTH01`K6T0
KfYW0080G5AB01H0KfEV07I[K`22Mgd0TXN=0:>HWP2MU9T0Thf?0;F_[`3Ccl`0lO3/0?_jn03gm_@0
m_Kd0?;bl03]kN/0lO;]0=?Dc`2CU8l0KFaW06e]I@1^KVH0JfQO0P1]JF00301_J600FU=;07edK`2>
QH00R7mj0::JU`2m]K80]k:^07]fLP1KF540I65J06YWH080KVUU02T0IF1L06mZIP1mMG<0JV5R0515
B@0U6Ad08A8I01`<5P0R4Qd0;B0Z03L[=@0h;SL0=Rlf038^<00/:bL0:bXU02PW8P0[;2@0BT]3069T
F@1GFDh0CU1504Q8?P1;Bd40AdLk03di;P14?C<0@S/c038Y8P0l<Bd0@38b03HZ;01CAd/0G55E05A:
B`15?3d0>2l`03D/;@0d;Rh0>SDb03hi=P0203hj=`1<03Hb<@0T81l09B4R024L800L6Qd081hS034^
=@0j>Cl0>cY103dlA015A4`0AdI>04Y7D00o?4<07A`R01HE6`0K61l06aTN01TI6`0I6AT06ATG01PH
5P0H6A@07QlJ028Q7`0U92806QPI028P900d<CP0@3e603Db?@0[9C408A/W020M:00O72L08R0[024O
;00R82d09RHb02LV=00P8Rl08R@a020R;P0T9S<09bTf02LZ>@0b=D@0@DME04eCH`1IH780Jg:506ee
RP1/M8/0KGF<06ieS`1_MY00L7NC06ieT@1_MID0L7JF06mhU`1/MI@0KgFE075gV@1`NIX0JgBE06Ud
U01ZMID0J7JC06QcT@1XMY40IgF@06IdS`1XLhl0J76>06QbS@80IW2;02<0IFn:069`RP1RL8X0GVf4
05e]Q01JK880F6f005U[O`1FJ7`0EFIj05IWN`1FIG`0EFAk05MVO@1FHWX0Ef=k05ARO01?GgP0C5af
04eNN01;GgP0BEef04YNM`17Fg@0AEUa04IIL@15EFh0A5A[04AEJ@15E6L0AU=V04MBI017D640@dYJ
0459EP09ooooo`001oooool201XF3@0Z01`E3@0O61008APA01`C3P0K4Pd0<RTT03/b;@11>S80@3`a
03/i;00i=bP0>3HW03@c8@0l>bL0?c`Y048m:P11?2T0@3dZ04E2;`15?c40@C/_048j;`15?3<0Bd8i
04m6?@1=AS`0CdLm04@k<P0m=2/0?SL]03dg:`0f<2@0<blS038_800c<B80=C@R02la700b=1l0=CLR
03@e8`0e=R@0=CHV0P0b<b<0B`0m@2l0@D<d04M7>`1=Bch0>CLZ02d^800[;1`0;2lL02X]600]<1/0
?3lZ03i2:`10A2d0I6UC06]`G01PIE40Kg=R07j2L`1iOFl0GV9D04A8>P0b=RL0;BlR030b9@0];B<0
:b/Q02h[8P0e<bL0A40g03hj<@0h<bd0>SD_03lj=00Q71H04`l6018?1P0H50T061H:01@D200L6`h0
7Q`?01HG2@0D5@L07b0B024R500G60P07Ql?02@U5`0S8A@09R@H02PT6@0Z9ah09b@K02@Q600T91X0
9R<J02/X7`18AC`0F5E<05iKE01VHE/0JFAN06ENF01VG5X0Ng5`08YoP`2AQ8d0VXfG0:2CW@2h[;H0
bl7:0=[Cf`3`jo40n_Gk0?OenP020?Gcn0170?GcmP3Rh>40/:n]09JET@1jNG@0JVYR06e]H`1ZJUh0
JFMJ06m/G@1cKEl0L6QK05Q@@`1hKV@0OG1X06aOF@2DRHD0/:FS0:>IV026OG/0M6m/07=^J`1]J6D0
Lfi[075/J@1FDDd0FEA@069KE@1HDD/0A3Xh02LK6`0`8B@0<24V02dP9`0b9B`0=2Ta03L]=@0e<3@0
;B`[02XY9@0[:RD0:2TQ024Q6@11@CT0FUYB05iNEP1CDd/0?Cde0410>014A3X0@Slf04<o=P17@3H0
AC`c04Tn>01;@3X0ACXf05U>C01SF5H0DdM704@j>@0m=C<0?C@e03dg=`12?Sl0?SXk03<a=00[:B`0
9bDX020N8@0R8R@00P0Q8B<0700T92H0<S8d03dm?`0n?Sl0?cm104I6B01;BD`0A495028P8`0@4180
6QXJ01`L700I6AT061PH01XJ6P0I6aP05aTF01DG500I6aP08B4Q02PX:00S8b<0:RT/03/h?`14@DX0
=C8m02PU<00U8Bl2028N;00>02LS<@0U8c409B<a02PV=00X9CH0;2Xh02XX=P0X9cD0:RTi02d/?00`
<T40>Si=05ALJ@1MIG8206efQ@0F06ahR01]N8X0L7^=06iiS@1aO980L7ZC071jU@1_NI@0LGZG07=j
U`1aN9D0LWRH071fUP1`MYP0KWBF06efU@1[M9<0JWFC06aeU01ZMI40JGNB06UgT@80IgF?0140IgF@
06EcSP1UL8`0GVb7069`R`1PL8X0GVj8061`RP1KKHD0FVb205UZOP1JJgl0FfYm05MVN@1IIWT0EfAg
05QUN00205IRN00C05ETN`1AHGP0CEef04iPN01:GWL0Bemh04eNNP1:FgL0BUUh04UHM`16Dg<0AE=`
04ECKP18E6h0BEE[04MBIP1:DVD0ATeM04A:FP09ooooo`001oooool07`0L5a405a<:01/B2`0R6A80
7QD@01D<1`0J3`/0:b0L03L^:@11>C40@Shc03`j:`0g=R@0>CPV03Pg8`0j>BD0?C/V03lm:014@Rd0
AD<^04M4<@12?bh0@S`^04<m<@16@3@0Aclb04Q2=01>B3X0CdTk04Do<@13?Bd00P11>b/04`0l>BX0
=S<T030^7`0c<B80;RlM02//6P0^<Ah0<C@S034e900d>2T0<CDV034c9@0c=BL0>S`^0411=012@3<0
@3ha02d[700^;A/00P0[;AP0;`0Y:aD0<S@N05MK@P1MHDP0BThe04I9=01MHTh0Gf=B06AXF@1jOW00
QXYl07UmK`1>DT@0<C<U03Tk;@0g>B/0<C4U030^8P0_:b00?CT^04<o=00n>S409B0J02@O6@0X8ad0
6QH=01@A200D4PH05A<701LH2P0F60X06A/<01TJ2P0G6PT061/:020S4P0T9aH08RDD020S4P0S9AL0
92DG02HT5`0W9AT0:BLK02LW6`0U9AT09RHJ0080;2XN00l0?3``05IFC01NFe@0GU]D06ERF`1eL6X0
NW9_08AkO02CR8`0WY6J0::EW`2GRIH0a;S40>WNk03_i?800P3hl?/0EP3dkoH0mO3g0?7/lP3Nf]`0
[j^Z08V6P@20OGH0L6eT06m]H@1/KEl0IfQH06YYE`1[J5D0KFQE06iYEP1UGT`0Hea<05mEB@1DBT40
OgA`09^@SP2@QXD0PGQi07ihN01jM7@0NgMf06USH`1MF5D0E4m;04M2?P0/9b40=2dU04e6?P0g<2X0
;B<Q034W9@12>3L0@SXh03lf=`0h<S80>3@c02LT8P0X9B009bHQ02HU800T8A`0=c@_05A@C@1IEE80
F5=@03ll=`0e<Rd0?CXc044n=@12?SD0Ad<h04e6?01BBD00D4Ln04Po>01GCTT0FDm=04To?@0n=S@0
?C@e040j>P16@T<0@ci202l]<P0U8bP071/P01TI6`0O7b409RHX02DU9`0R8R80:2PX03@c<@0n?S`0
@D4n0492@015A480@d52038`<@0H5QL05aLE0P0H61H04P0I6AL06ATI01dM7@0K6a/06A/J01PJ6@0K
71h09BDW02`/;P0];Bl0<Ble03`i@P10?DH0<c0k02LS<@0V8S009Ah^02<O;P809R8a00d09R<d02PU
=P0]:3`0;2Tl02XW>00/:c/0<2m102d^@00k?Td0CUES06A^NP1/MX80KWR40080L7b:0P1`OHd00`1a
O900LWfA071kT@02075kU0<0LgZF00@0LgZG075gU`1aMiL0LGNG0`1]MYD0101/MI@0JWFA06YhTP1Y
Mi4206MeS`0406EeSP1TM8d0IG>>065_RP80Gfj;00T0GVj805e]Q`1KJh@0Ff^205QYO@1KJWd0FFQk
05QWNP1IJ7/00P1FIWH01P1DHgH0Df9e05=TN01>GWD0Cemf04iPN080Beaf00d0Beah04aKNP1=FWX0
BEIg04MDM015DW80C5Mc04QDKP17DFX0Ae9V04Q@H`16Beh0AD]K00Wooooo0007ooooo`0B01XE4@0I
50h06a8=020G4P0P5@l05P/501X?2@0/8A/0=BXT044i;`13@340?S`]03Lf900j>BL0>3LS03Th900j
>BD0@D0/0P15A300?014@c40AD<d048o<012?c00Ad@e04U3<`18AC@0CDXi059??@0o?2T0?3XU040n
:@10?BX0@3l]03dk;00a<R80:R/K02P[6P0W:aX09RdM02X`8P0]<bD0;cDY030f:P0b=BX0=CLZ03Li
;00m?300?3P/038^8P0Y9QL0:BHE028Q3@0Q80`0<2lK0450;01SIE00G5i90412;@0d=BD0J6YL06Q/
GP1TIe`0KG1W06a_IP1YK6<0EUU=04i>@P16AcT0?Ch`03Xh:`0h=RT0>SHZ04<o<`0g=BT0:bTM01/G
3P0N6Q408b0G01dK3`805aD900P06aT=01TI3@0H6P`05aX:01LJ2@0I7@`08BDD024U5P8092PI02H0
9BTJ02<W6@0T9QT08bDH02TY7`0[:b40:RXP02HV6P0T91P0;RhR034a9@0n@3D0DE9:05mPFP1SI5l0
IfQS07mnNP23PX00R8B509B>TP2`Y:h0_k>o0:JJYP2h[;P0gM7O0??Wm@3ikOT0m>Sb0?O]m@3RfM`0
bL?30=3;aP2DT8L0NWI[06m[G`1/JEX0L6mM06e^G080J6YE0P1[JUD0:P1WIU40FUQ305AA?P1BCd00
CTPl06iWG`27Og`0Pgik07eiN01lN7L0OGUh06e/JP1>BTL0?SXg02/X8`0Q7QT0924J03Hc:P18AC`0
Ad@k034^9@0Y9Qd0FEI=05MDB`12?cH0>CH]03Ld;@0V8Qd0:RDQ02`T8@0Y8Al0;28S03P^;`18?Sl0
C49304m6A`1:@T00@c/h03hg<@16?cL0CDU0059>A@80E51700l0BTHm04U6?`1<BD<0@cll03di>00k
=cH0?3Pi04<o@012@4<0<c4d01LE6P0C4AH06ALL01dK7P0S8B@00P0W9BH02P0X9bD0<2`[03Xf<`12
@Cd0AdI104M6@P13@Sh0?3/i02HU8`0I61H201XJ6P0401TG600H5QL06QXJ01dM7@806aXO01h07QdS
02<R:P0/:c<0;bhf03@d?00c<c/0=C8k03H`>P0^:380;BLc02TS;`0Y8C00:28`02DQ<00T82l09B8c
02LV>00Z9c`0<2e2034_A00_<4@0=3M:03DjC@1=E6@0HV]j06]gQ@1^NXH0L7b8075mR`1bOX`2079n
SP80M7bA0P1dO9<01P1cNi80LgZD071gT@1bO9L0LGZG06mhU@80KGJC00L0K7NC06YeT`1YM980JgJB
06]iT`1YMi40IgN>0080IgJ=01@0IGF<06AdR`1RLX/0HG6:069`R`1NK8L0GVb605]ZP@1IJ7l0Ffb0
05UZO01KJWd0FFQk05YYO01GJ7X0EVMi055RM01@HWH0DF=g055SN@80Cf5g0100CEme04eOM`1:FgD0
BeYg04eKN01;FGH0BeMe04YEL@18Dfl0BUA_04UCK01:DVT0BE5T04U@HP12B5P0@dIG2Oooool000Oo
oooo01/06QH?01/G3P0N5`l071@;01TA200H3`D071<9020G300V7A80>cHW03ll:`0o?R`0>CPU03/j
9`0l>bP0>SXW03dn:P12@S40@d@c0493<@16AS@0BDLh04Y8>@16ASH0AdLe04A5<`18BC@00P1@DC`0
<@12@B`0@d8]04=2;`12@Bl0A48c03dn;`0X:1/0828E01dO4`0K7Q80724D02L[800Z<BD0:2lR02T_
8P0b=RT0>3/]03/n<010@C@0>c`]02`/700P8@l07Qh:01`L200N7PT0<S8L04=4;`0m?RT0:BTD02PX
501DDD40JfYL06ARE`1VIE`0If=M06IQG@1YIEl0HEaF05E?B@1DD4P0DDm604U7?@13@CL0Ad@i04e<
@@10?cD05Q@<00T7000I5Ph00P0M6Q80X@0I5Ph07a`E020M5`0J6A806ATB01/L4`0J71407b8F02P/
800V:Ad092LJ02HY700W:Qd09BLK02DV6`0V9a/0:2TL02h_8P0];2009bHJ02DT5`0];200>CT]04Y<
@@1?DDX0HfAO08>5PP1mOgd0MGEd0861PP2DTYD0XIbS0:^R[P2n//40bko<0<Fja`3Cb=@0jn3[0?K/
m@3bjNd0em3@09:=R029Q7`0/ZjS08=nLP1WHeL0JfMJ06e[G@1]Jel0J6UM06EVFP1VIeX0L79S079d
H`1SIE@0B4Xi059B@`1=C3l0@d8g06UWG`24PW/0NWUe07imN`1iN7T0?d0o02X[:P0b<c40=3@a02DT
8@0E5A00?3`g06e]IP1XJ600G5eE04]=@`0f=bd0@D8f03Xk;P0_;B00<S0S02`Y7`0X8a/0:B0M02@J
600V71/0;R<S03/`<00n=380Bd0m04e4?`1<@cd0CTHn04U3>@18@SP0DTm305=AA`1@DDP0CU1804A6
?`13Ad00>d0k03Tl>P0h>cX0>C/l0493A@16ADL0>cTk01dK7P0H51X07ALN01hH7P0R72409R0V02HS
9@0[9bX0<2`/03@`;`0k>CD0ADA004Q8@`0j?3H0=CDb034b<00Q8R006ATJ01`M7P0M7Ql06aXL01XI
7@0J6A`07A/P020K900Q72L0:B@`02/X=00Y9S80924]038`?P0g<d40=C8o04]8E@1GDUl0BTED02`X
=P0W8S80;BXj02HV=00U9SL0:b`n02X]@@0/;D80=3M<03TmDP0n@UP0CeEZ05UQM@1YLX@0L7V;071j
R`1dOXh0M7j?0080MGn@00l0MX2A07EoTP1fOY<0MgnE07EmU@1dO9@0MGbG07EmV01cOIT0LWbI075k
V01_NiP0KgVI06iiU`1_NYT00P1[MiL02@1[N9H0J7JB06UiTP1XN900IgJ=06EdR`1SM8P0HgB706=c
Q`02069aQP0I065`Q@1OK840GV^005e/P01LK7l0G6f005]ZOP1JJGl0F6Uo05AWO@1CIWd0DFAl051S
O01?HG`0C61k04iRN`1=H7X0CF1i04mPN01=GGH0CU]e04eJM@1=Eg<0CEQb04YBK@0204]CK@0604YB
J@18D6D0BE1S04M>H011AUT0ADUK2Oooool000Oooooo00X04a4501DC1`0H50T06aL;01dG2`0M5`T0
7aT;024I300S7@l0=S0P0P0m>RT203/h9`0W03Tf9@0i=RL0=c@U03/h:@0j>2T0>S/Y03Tj:00m>b`0
AdDf04E6=P14AcH0?d8a0495=018BcX0C4dn04E6>018AST0AD<f0490=00k>Bd0:BTM02HV700S8aT0
7AlD01`L4P0M7a@0:2XO02/_8@0Z;R00<CDV03Tm;P0j?Rl0@4@e04Q<>`0h?BT0:RlK024V4P0N8@`0
8RD@00809BTB01L0:B/E02X/5P0V:1808B0;03Xg901LETH0I5iB06QQE`1ZHEX0KFAM06aSG01PEe80
F4i<05M?C01DCd/0CTU304Q5?P1:Ad00B4Q0040o>P0M71L01`H101LF4@0201`I501k01`H5@0Q7AX0
81lM01`K6@0J6AL08B4L024R700T9Al0:BXR02d]9@0Y:Al09bLM02PX700V9QX092@H024Q5@0V9aT0
9bPJ02TZ700[:A`0;2XN02h/800c<bL0?3hc04I8@@1PHE`0QhV60;6c/P34a<H0_;bn0:2NX`2<RI80
UY2N0969V02`Z;D0bl?@0=C<e`3Qg><0iN3T0<:n_@1lNG@0LFiU0821L`23Pg@0KVYN06aXG01^JUl0
K6UP06]XH@1VIF00HV5M05]JEP1fMg80RX^506a]I`1BDTX0Hf=K061PF01;Bd<0IVEP07YiM@1nOGT0
MgMf04U;BP0V:2L0<cLf03i0?`12A440;Bl/01DG4P18BD@0S8f707YkM@1LGEL0Bda603m0>P0b<RX0
<C4W02h[8P0S81L08b0I02LQ700Z8Ql091`I01lG500R6aD0=BhV03`e;@15?S@0@C/_03dg:@17A3D0
AT<d03lm<015ACT0BD]004Q9@@14AT40@DI003m5@@0g@3`0=3dj03Dk>@0m@D00ADM604M7A`0e=380
920Q01`F600P6Qh08QTN02@N8P0]9b/0<Bd^02l[;00a<2h0=cHd03Th=011@Sd0@T<n038d;`0U9b@0
8bDT00807R8S01h08R<W020Q9@0L6b0081lU028O:00O72D08QlZ02HS;P0W8c40:RHd02DQ;`0P72X0
9b0`03L`@017@500JfMf07EbP`1GE6D09b@g02@S=@0/;Cl09bXm02P]@00Y<4<0;CA702leB`0oAE/0
AdmT05eUNP1^MX/206eeRP0507=kT01dO940MWjC07EmTP1gOi@00P1hP9D02P1gOi@0N82E07Z2U`1g
OiH0M7nE079lU`1dP9X0M7nK079mV`1]NiP206mlW00;071lW01aNih0JgRJ06ejW01_O9h0JWNG06Qg
U01XN980IWJ?06EeS01QLXH00P1SM8P2069aQ00505i]P01PKh80Gfj105e/P@1LK8400P1JJX401`1G
Ih00EfR205M[Q01BIX40DfJ405=SQ01CHhD00P1=H8004@1=GW`0CEij04eLN@1=FgH0CUYd04eIL`1>
F7<0CEMa04YDK@1;EFh0C5I_04MAJP1:DVT0BE5V04Q?HP13BUd0ADaN00Wooooo0007ooooo`0701@D
200E4`L05aD901TG2`0M6@d07QX>024K3`0202<M3`0>030Z700o>B/0?cT[03hh:P0l=RP0>S@V03La
9@0g<B<0>S@V03Tf9@0k>2L0>3LU03Tf9`13@C8204=1=00N044o<`14@CP0@d0i04Q5?`1;Ad@0C4]6
04=2?@0d<bh0:RXR02TV7@0T8AP08b0G01dM4@0O7A40820D02/[8@0d=2P0<c<W03do<@15B3L0@TDd
04Q<>`1;D3`0=CXV02@Y5@0T:A<08B@?02<V4@0V:A@08bHA0P0X:QD05P0V:1<071h9024P3P1:AcH0
IV=B06QRDP1ZHUD0K69F06MMD@1QEd`0G59905]AB01DBd80CD@m04U2>P1:ASd0@3dd02LT7@0I6A40
4Q8:01HE400I5Q42020L6@0;020O6`0P7ad08B0N01hM6`0P7a/08R4L02<R7@0Y9Ql0;RTS02TU700W
91/00P0X9A`0I00S8aT092@J02<U6P0R9AX09BTK02X/7`0/;R40;S0S034c9P0b=2T0@48k05MIE021
Ph00^;Zi0=gMg`3[j^l0fm[P0:NT[@2>RYP0T8ZH0:VS[`3Fd=`0fM?M0=3=e02j^;/0VYVG07=bK@1d
M6X0NWY^07moLP1^K600K6QM071/H@1[Ieh0JFAN06ISGP1SGe`0FEED06UXIP26QH<0MGAb05mKFP1Z
IVD0Kf]Z05iJF@1/J6T0MG=d07YhN@1]KFl0AdQ:034c<P0o@D00ATQ504i@C@0i>cP07b4L0452?01c
M6`0HV9J04m?A`19B4<0ATE003`k=P0a<2/0:BPS02<R7@0R8Ad09b<P02hY9P0V8Ad06aHB024L5P0f
<RT0?3P_03Te:P0f=2P0=cDX03`m;`0j>Rh0=cL]03do=015ASh0ADI00452?@0j?3T0>3di03Pm>P0e
>CP0=CLd03`n>`0n?cX0?chj03Hb;`0/9b@08QdJ01lJ5`0S7Q/0:RDR02lZ9`0a;RT2030_:P0B03He
<00e=2l0>S/e03Xk=P0b<S009BLV01dO7P0O82@08R<W024R9`0P8BH081lW020M9P0U8Rd0924/024O
;00^;3T0=C<n0P0`;ST04`0Z9c8091h/03liA`1ECUh0ETmO04Y6E`0o>Th0<Rm402/Y?P0];T80;Bm4
02hcA`0/<dH0=Se@03e3F@0oAE/0Eemb06eeR01aNHh00P1cNHl01@1fO980N7jD07InT`1hP9D0MWjA
0080N82C00D0MgnB07R0T`1hP9<0MX6C07B1TP0207B0UP0307=oU`1bP9X0L7jI0080L7jK00d0LGfM
075kWP1_O9h0KgjO06aiV`1[N9X0IWFF06MfU@1VMI80I7B>069dS01QLhT0H7:80080HG:600D0H765
065bQP1PLHD0Gfj505e/P`0205QZPP0C05MXPP1CIh00DfN205=XP`1BIh@0D6>3051SQ01@H880Cen1
051OP01=G7d0CU]m04eJNP1<FWL0AUAa04aGL`1<F7<0BeMa04YFL00304MCK@0404A>I`17CfH0ATiS
04A<G`Wooooo0007ooooo`<05aL=00/06QL>01/I3@0M6`h07a/?02DO4@0T7Q009b0C03P`8`0k<bH0
?3@W03P`8`0203Ta900U03Tc9@0l=RH0?S/Z03hk:P0o?2/0?3TZ044m<@14@SD0A48f04I1>`19A400
AD4n04A0?`1>BTT0DU5?04Q7@`0X9b<08B0K02DR6@0Q7QD07adA01hL400J60`08AlC038_9P0h=RX0
@40d04I7>@17BC/0B4/j04M;>P16BSP0:c0L024V4P0Q9Q007b8=024T3`0202HY5P0D02HW5@0U9QH0
8R<A024R400P7Pl0=cHT05mLB`1ZIeH0J69B06MPD01TGDd0GUM805aDB@1IDDH0DTU004]4>P18@CT0
>CD/02`Y800O71D2018?202W01LD3`0I5A8071PE01XI5@0N7AT09B@P02<R7P0O7QX08R<L02@T700U
9A/0:BHM02`X7`0[9a`09R<J02XW7P0Y9Qd08b<K028S6`0Q91/07R@H028X700V;200;30R02/_8@0_
<B@0<38W03Hg;P1OH5X0XZ>M0<S9a03HemD0h^3Q0>?Si@3Th^L0a<780;Zg_P32_lH0i^?Z0=KDf@2[
ZJ`0Shf>08V8Q01hMg80L71V079`I01iMf/0LViS06aXG@1^JV40KFQR06]VHP1WHUh0GEQE05MAD@1`
JV`0Q7j007MaL`1[HVD0LFQ[079/L01^J6`0Mg1g07]fO@1iM7/0KVac05YKH01<CE40CTmA059DD`1A
De00C4i;0453?P1;C4H0HfAL05IFCP19BD40B4M204A3?P0o?ST0?C`g02XY9@0U92009RDQ02TV8`0/
:B@0;R/V02HS700S81T0>3D/03dj<@0i=b/0<c4U03Lg;@0j>S00>3X_03`l=00k?3H0?chi04U:A@1<
BdT0>c/i038b<00i>SL0>3Pf03Lh<`0f=C40=C@_03Ld;`0j=c80:2DP024L600Q7QT08QdI02LT7`0]
:RD0=C8[02l_9`0/;BD0<30X03<c:`0`<BT0<34/02l`:`0];b`08R@Q024R900T9BT0824U028Q9`0U
8R/0:RLb02LT;`0T82h09B<`04Q8E01?CeT0?Si803Le@00d<Sd0<2`j03hjB01=BEP0AD5B03XfA`0i
=TT0<c56030aAP0`<TL0;C9602heB00/<TP0<c]@04Q>IP1DG7<0I6b1071hS@1bNY40M7bC07InU@1i
P9P0Nh6I07b4V`1iQ9P0MX6E07J1T`1gPY@00P1gPi<04@1fPY80MH:B07:2TP1bPI@0LH2E071oU01a
P9L0LGnI075oVP1cPI`0L7bK075kWP1^Nid0KgjO06ejW@1ZMiX0IgJG0080IWFD02L0IGBA06AdSP1T
M8d0HG6:061`Q`1QLHP0Gfn6065aR01MKH@0GFb305][P`1KKHD0F6V305EYPP1EIX00DVJ105=WPP1B
IH<0DFB4059RP`1?Gh00CUio055OPP1=G7d0CE]n04mNO`1?GWd0BEQg04QGM01:FW@0B5Qb04IFL013
Dfd0@E5[04=AK013CfL0@diT04A<H@12BUl02Oooool000Oooooo01<061TA01LH400I6Q8071`B01`L
400O7A00924B02DR4`0U7`l08ad=02XS4`0f;al0>34Q03Tb8P0h<B40?3LT03Pe8P0k>2D0?SdY0080
?ch/01h0?S`]03hl;`14@3D0BDDl04M2?01<Ad<0Ad=00490?P1ACD`0DE1>0491?@0Z9b007a`C01dJ
4@0K6@d07Q`@01/I3@0H60`0820D03Tg:`0l>Rh0ADDi04E7>P12A3L0@dDh04Y<?`0^<B407b8?01hQ
3P0Q914202@U4`0b02TZ6P0X:AT09RLI028S5@0S91H09B<F02@R5@0d<RD0F5I906aZF`1VHe@0Gea=
05eKC01IEdX0EeE905ECA`1;BCd0@d0g038_:00R7aP07AXC018?2P0=20@03`X601D@300F4@h061@A
01XI5@0R8ah09RLR02DV800R8a/08bHJ024U5`0U9aT09bPJ02X[7@0Y9aX092@H02TY7@0X:1h092HK
020Q6@0S9Qd082HL02H/800X;R00:C0P02hb8`0]<B8203Li:`0E05EEB@2c/JD0clc30>3Ld`3Wi=d0
iNCO0>WXi03Pg=T0iN7N0=gIeP2k]k@0YJ6N08J2O`1lNG@0OGYc07QeKP1_K6<0KVYO075]H`1cK6@0
KFIN0080LFYT04L0KfMT06=KF@1FCDh0FU5B07ieMP2=Ph@0O75e07AYK@1hKG<0NVmg07ibOP1nLh40
OW>307afQ01fLh40MgF0071`N01TIFT0Fe]M05aLG01LG5X0GUiL05YKEP1IFUD0EeQC04A5?`0i>SD0
>3Td03/l=P11@S`0<C0[02TX8`0/:bH0;B/T02`Y8P0`:bD0<BdT030/8`0k=bh0?CXa03`i<00e<RT0
=c@]04]8@@15A3l0@3dh040o>`15@Ch0DE1<059>C@0i>3H0;bhZ03Ph<`0e=2l0<c8]02h]:00_:bP0
<Rh[03<`:`0V9B00924L02@S7P0V8ah0924L02XW8P0b;bX0;RhV02`/900[;2@0;2dU02d^9P0202l`
:00902h_9`0Y:R@09BHQ028R800S8b<09BDW02/Y;P0^:C00;BXc00809B8]00P0CD]F051>F`12@4d0
>3I30490C@15@e40=cE303PfA080;bhn0P0_<4806P0]<4<0<39703@iC@0g?E<0>41G03a7G@1LHgd0
K7J?06egTP1_NI@0LG^F07N1W01fOi`0NH>O07V3WP1fPYX0Mh>K07F1U`1fPiH0MXFH07B4U01cPi80
LX:A0762TP1_P900L86C0P1bPiL01P1aPIP0LX:I07:2V`1bP9/0LWjL079mW@80KGZL0P1/NI`01`1X
MIL0J7FE06UfUP1WMI80I7:=06=aS01RL8/00P1RL8X2061^R00805i/QP1LK8D0Ff^505UYP`1IJH80
EVR005EUOP1FIh4205AUP@08059SP@1AH7l0DV6004mNO@1@Gh00Ceim04iMOP1=GW`204]LNP0;04IJ
M@17FgH0AEUd04EIM014F7<0@U=_049CK@13DVT0A51V045<H010B5d02Oooool000Oooooo0<D06QdF
01HI400I6a0071hA01hP4P0P8A408b8@02@S4@0T8@h08Ad:02DP3@0`:aP0=S4N03H`800h<R80>SLT
03/h9@0e=200>CPV03Xi9`0k>BX0>CLZ03Le:@0k=bh0A3li04]6@P18AD00@T4m04I3@01;BTH0CTe8
038b:P0S81L08AlC020N4P0N70l08R0C01dN400N7a409bPJ03Xh:`0f=bT0=cL[03Pj;@0o@C@0>3X]
02X/7`0M7a0082<B02<V4`0V:AH0:BXJ02DV5P0T9AD09bPH02DV600T91P09BDI024Q5@0Q7a<0>c/_
06ARE@1]KV00Hf5D05]KC`1HF4`0EeM<05=CB@1?CdD0A4@j02`/900B4PX0410801HF3P0?2PH02PD1
00l:1P0C3PX050l;01D@300Q7QT092<N028Q700R8a/08R@I02@X6P0Q9AH08bLF02LZ6@0Y:Q`0:2TK
02@U5`0S8aL09bTN02HX7@0V:B009bXQ02X]900]<bL0:S0R02T_8@0]<B80;2hP03`n<01?D480Cde1
096=PP3<b;l0g=G=0>7Je03Kf=40fMK?0=cGd@3Ie<h0][>/09:?R01mN780N7=]07IcJP1hMF`0NGE/
07EaJ01_Jf80LFYR079[I@1_IV40LVUT07E[J@1eJfX0H5IE05A:B@1^I6<0OgEd07ibLP1kKfl0PWIj
089eO022MGh0PgJ007]]O01lKh00S86B09N?X02ETIl0TXnJ08V8SP1cLGH0JfUZ07IdM@1cLW00H5mM
05]JEP1AD4`0@3lk03Dd<00b<B`0=cHa03dm=@0d=2`0;blW034^9`0_;2<0<RhS02l[8P0d<2D0>SH[
04<o=015@ST0@3dd040k=@0h<bd0EE1<05eJE@1>BTL0DDe:05A?C01BCT/0C4I603Xf=@0g<c80<c8^
038a;00_;RT0;2/W02`X9@0_:bP0:RTU02PW8`0S8Qh09RDQ02HU8`0S8R00:RHW02/W:00Y9B@0:bLT
02LV8P0202TX900U02X[9@0];RP0;BhX02X[9@0X:B@09RLR02@T8P0X:2P0;R`_034_=00_;3<0:bPa
02LT;@0n?4L0AdEB04I4D@11?dd0De9P04a;F@0[:SX0;S0o02d_?P0Z;Ch0;c9302dbA@0[<4<0<SM;
03Y0EP0oAeh0BeE^05]UOP1[MI00MGnJ079mV@1fPId0Mh2M07R1WP0207V4XP0407F3WP1jR:<0MhFO
07B3VP80MHJJ0100LhBF07B5U@1dQID0LhBF0721T`1aPYH0LhBH07>3VP1aPIP0MHBK07F3W@1cPI`0
LgnL07F0WP1_O9`0KW^M0P1]NY`02`1ZMiT0J7FE06UgU01XMY<0Ig:>06=aS01TKh/0Hg6<069`R`1Q
KhX0Gfn90080GFf700<0Ffb605YZQ01IJH<00P1HJ8403`1FIWl0EFEo05EUO`1DHh00DV5n05=QOP1@
Ggh0DEin04mNO@1AH7l0CUel04QIM`17F7H0AEQf04IIM`0204=FM00704=GLP15EW80@E5[049AJ014
D6H0@d]P03m7G009ooooo`001oooool01@0G7A<05adA01PL3P0L80l07b@@008082<>00/08R@?028Q
300Q80/08Al:02HT3`0c<1d0=C8Q03<`7`0h=B@0>STW03He8`0203Pf9`0503Tg:P0l>2d0>SH]03/g
;P11?3H00P16@ch0@016AD00CDe6059BBP1>CT@0<38U02<S5`0L7@l07Ql?020Q4@0P8@l07Ql=02<U
400a<ah0=3DS038c8@0i>RX0?d0`03`n<00b=2H06al@01hR4P0U:1L09bXG02P[600Z;AX08bHC02HY
5P0U:1L092DE02@U5`0X:A/07b4C020Q4`1:C3h0JFUM065SEP1KFdl0EeU>05EGC01GF4l0Bda403dn
>00d=Bl06aXE00d<1`0D50`05aL=01@?2@0>2@<040T301PA2@0J4`/07aP@02LR700X8ad09B8K02<S
6@0S9AP08BDF020T4`0R9QD092PG02`^800X:Q`202<U601302LY7P0Z:b<0:b`T02`]9@0`<BT0;S4X
02/^8`0Y;240;BhV03Lh<017Acl0If=M05iIE@1hL6d0]Zj/0<o5a03SfmT0imoM0=7<b02h/jl0Yj:N
08F2N`22OgP0MgA]075^I`1bKfH0M75X07E`JP1hLF/0M6eW07=[IP1hKV`0LfQV07Q]J`1mLG40QWYj
06QLG01NE580NFm]081fM01mM6l0P7Mb08YnOP29OGl0SGj308]lP`2:NXD0U8BA0:bN[@2h[;`0^K6n
0;B/]`2h/KT0[ZV_092<S@1jM7H0L6YZ069MFP1DCd/0B4E003`i=00i=S40>cPc03`i<P0j=bh0>3D/
03Dc9`02038^8`14030/800d<2D0>cL/04<o=018A3/0C4Po04]7?P1<ACd0AT8i05MBC01LEe<0FEAA
05iIEP1KDe00@C`i03P_<00l=SH0>cDe034];00_:bP0;B`X02`[:@0];2X0;2/Y02PX9P0X:2P09R@U
02HT9`0X8bT09B0W02HN:@0W7bX0:b4Z02hT;@0[92`0;2D]02XU:`0Y9b/0<2ha02d];@0U9BD0:2PX
02XZ:P0Y:bX0;Bd]030`<00c<cD0<C4c02TX;@0^;CD0>cY204=1C01?Ce/0E5=Q05=BH011@500:b`n
02lb@`0^<D80;35402hcAP0]=4L0<cY=0418F`15CF80EF1f06I`R@1aNiH207=nVP0@07AoV`1hPil0
Mh:P07V4XP1jQJ40MX>P07N5XP1hQZ40MXJO07J6W@1fQi/0MHJJ07:4V01gR9`0MXNK0720U`<0Lh:I
00P0MH>M07N5W`1ePI/0MH2L07J1W@1dOi/0M7nM06mmVP<0KGZJ00`0JWVH06QgU01WMY<0IWJ@06Id
S`1RLX`0Hg6>06=bT@1RLI00H6n>05a]R`1JKH/205Q[R@0L05MXQ01IJX@0F6V305IVO`1CHg`0EF=m
05MUO`1CHG`0E69m05EPOP1AGg`0DUek055OO01AGWh0D5em04eHN019EWH0AeIe04QFN017E7H0A5=d
04IEM015DW80@e5^04A@JP13CFH0AD]Q0417FPWooooo0007ooooo`0701HL400F70h05a/<01dQ400Q
9Q807b@>020S3P0201lR3@07024S3P0R8@d07ah:02HU4@0`;A`0<RlN03<`8@0203@a8P0>03Lc9`0h
=2T0=c<X03lh<013?3H0@CXd040h=@10>cL0A3lk04Q5@01?CTL0DE5705MGB`0m?S0202`]7`0>02LX
600S91808B@?028U400V:180<C<M03@c7`0^;AT0<C0N03He8`0i>R`0=CHX02T[7@0W:A/202T/6`0_
02LZ6@0V:AP0:RdJ02/^7@0W:QT09BHF02@U5@0W:A/09RPJ02h`8`19Bch0FUaA05]MDP1IFU80EeQ@
05QID`1EEU00?Slj02l`:`0Y:RD06aXF01HE400I6@l061P>01/G3P0E4@P04``401L@1P0M5P`08AX@
02PQ6@0[9ah09b@K02@T600T9QP08RDF01/O3P0N8Q408BDD02<U5`0U9aT09BDI02<U600/;280;BhV
02l`:00];RH00P0[;B80>`0/;R<0:bdR038d:@0j>S80De1909J?S02ESH/0MVe^0:>JV`3>aLP0f]7D
0=C;c02e/:d0WiZG07]fL`1cL6/0NgQa07QeKP1aKVL0LVmX07=`J@1dKf/0LfiZ07M_K01jLFl0O79a
07idM@26O7d0Rgn10965Q`28OWl0KfET07adLP1nMW<0Q7eg08V2O02;PGl0SXB209^AT02JSY00UXN<
09^<T`2l[;H0b[g70<o3c@3>`/`0cL?;0<Bk`02VWJ00Mfi_06EMF`1UGEX0Ee9>04M2?00`:bD0=C0Z
03Pe;P0i=Rd0>3HZ0080=C<W00P0;RXO02l[800g<bP0@Shc04<o=015@CP0FeM>061LD`<0GEU@03`0
GUUC065LEP1TG5X0He]I04Y2?`0j=C80>38b03`f=P0l=SP0<Rh^038a;`0c<S00<S0a02`/;00[:bd0
:BT[02XZ;00X9b`09B8Y02DR:`0S7BT08A/Y02<K:P0X82d0<BHd02lT<P0Z8Rl09R0Z02LS:`0/:C00
;B/`02XZ;00[:Rl0:b/]03Lh>P11@T@0@41203Ph>P0_;S<0:BP]030_=@11@4P0?Ce704I6D019BED0
>C]802PZ>@0[;Sl0:c1302`aA00^<dH0<CQ;02lfB@0g?e80CEEX05mWO01bNY40MWfG07ElV01fP9/2
07V2W`0607^4X@1iPZ40NHBP07f6X`1iQ:40MXBQ0P1hQZ40601iQj40NHRO07J6W@1cPiX0MXFL07J4
WP1ePid0MXBO07V4X01gPYh0MhFP07J4W`1dOi/0LgjJ07F0W01`OYT0KWbG06ekUP1[NI@0JWRC06Ug
TP1XMi@0IgNA06QhTP80Hg>=02D0HG6;065`S@1QL8l0H6n>05m^S@1KK8X0FV^905U/S01HJXP0EfR4
05YZQ01GIh40EfN005ESO@1CHG/0E69l05IRO01EH7`0EF1n059MN`1DGgd0DUek055LO01@Fg/0CeQi
04aGM`1:E7L0C5Ii04QBMP16D7<0BE=f04QCL`15D6h0ADi[04I=I`13BEl0@DQK00Wooooo0007oooo
o`0601HN3`0G7a006AlA01/R4P0Q:1H08bXH0P0Q9A@01`0O8a808RDD02@U5@0Q8Q807ad>02DR4`0[
:1T00P0c;B401@0f<2@0>S4X03Xa:P0m<Rh0@38a0080AS/i01l0@SPg040f=@1<@T40CdM404m;AP1?
C4D0DTm604i>@P16ASX0?3h`03Xk:`0_<1h0:2XE02`^600a<ad0=3<N02`Y5P0[:1D0;2TH034^7@0`
;200<blS034_8P0_;B00:RPK02@U5`0Q8Q@09RLI03@e9@0m?c40=CLY0080;2dO08P0:R`N030b9@10
@3H0DE5905UJE01HFE<0EUQC05EGE01GFEP0E5ID03Dg=00Q8ah08R<M01`K5P0E5@d061P>01/K3`0N
6Pl071P=01HB1`0K5``07QX?024M4P0Q7a<0:2PL02DU6@0P8QD08B<E020T4`0I7@`0720?024T4`0V
9aT092DG02DS5`0T91P0;2TP02h^900c<bT0;RhT02LW6`0];R00<C8R02d^7P0`<B40=cDX04A1>02O
V9@0d<S60;F/[@2TVi`0^kFg0<W3a@2i/kD0UY2@07ihN01gLVl0Lg1[075`J`1dLF`0LFiY06m/I`1`
K6T0LFe/07=_KP1hLW@0PWan08V0Q@2:P8P0VY2I0:jT[@2XWZH0ThbC08=nPP25Oh40R8B308N3P02=
S8P0VYNB09RET02RWiX0XijJ09B<R@26O7/0THF50;f_/`3DaLX0^jba0:nSY`2aYJT0S8:307=ZJ`1k
MW<0M6m[04U6?`0n>c80=S<Z03Tg:`0f=2P0>3HY03Xk;@0e=BT0=3@X02h/800/:B00>3D/04a9@01A
CTD0D4a305mJE01dKfT0L6]U06]VH01XHed0If9L06EPFP1ZHV00F51>048m>P0k=c@0?CTh03`h=`0k
=cH0<2l]030`;P0b<S80<C4a02h^<00Z:Bh0:2T]02LX;@0R8bP08R4Y024O:P0P72X08Qh/0P0T82h0
6@0Z9300;2Hb02LQ:`0V82X0:B@^02`Y<00[:2l0:RP]02l/<`0k>T00CDiC04U:C`11@TL0?Ci3030a
=P0_<3D0?cm70492BP0l?4@0=SI002`^>P0Y:cP0:2`h02/a@00Z<D400P0/<dD08`0g?U40?dII04E<
G`1LHgH0J6f307IjT`1iOIH0NGfH07YoW01nPj00OHBP07n6XP1nQJ80OXNT07j5XP1lQJ40O8NS07V4
X01jQJ40NHBP07Z6X01iQIl0N8BN07N3W@1hPil0MXBO07B2W`1fPIl0N8>Q07J4X@1dPYl0Lh6N07:2
W01`P9X0L82I0080KG^E00P0JgVC06QfT01YMi40JgVD06MeS`1XMY00IWB>06=cS080HG6;00D0HG2=
061^R`1PKX/0GF^805YXQ@0205]XR00405QVP`1LJXD0FFN105ITOP80EF=m00/0Df=l059PN`1@GWT0
D5ik055OO01@GGd0Ceal051MO@1<FGT0CUQk04]EN00304]CN00804M?L`18D7@0Ae1a04I?KP16Cf`0
A4iW04E=HP12BUd9ooooo`001oooool0100L8QP07R@J01`R600U:b4202/a9@0;02/^8`0Y;24092LL
02@W700S9AX09BDI02@T600R7Q<09AlC034Y7P0g;b@00P0j<2L0R@0o<R`0@34^04Df<`17>3D0ACLf
04<e<P0o=380AS/g04U0>`1@BT@0D4]504]7?P1<B3l0C4Xn04Q8?014ACL0@D8b03He8`0_<1h0<2lM
034`7P0X9A@091h>02/U5@0]9aT0;RPJ03@^800c<240<BhP02`X700U8aH08R<E02<T5P13A3H0EUQ;
05AFB@12@SH0?clc03`n<@0j?340DU9:05YIE01IF5@0E5AB05IFEP1CE5H0E5EG05MIF00g>CH09RPS
02P[900O7aL05aL=01PH300O7a<07adA01lM400K6@d07A/?024O4`0S8AD07QhB02<U600T9QT07b4D
01TM3P0N8Q406Ad<01HJ2@0Q91<08b@D02<Q500T8QD0:BLK02XX700a;b<0;RhT02l_8`0/;Al0:b`L
034b800/;A/0@T4]04m>?00e<BD0Ui270<k5`03Db/P0a;bj0:JPXP2YXjD0TXb>07]eM`1kMGD0Lfm^
06a[I`1`KfX0M75/079_JP1aKVT0LFeZ07EaKP1gLg80PGen09B?TP2SW:<0XYZU0;F]^P3Jd]l0f];M
0:ZT[P28QHh0T8fD09FCV02CTiD0UIFC0;>b[P34`kh0cLg50;Re[P1hM6/0I5eE08Z1NP2UV9H0YiVI
0::DU02CQhL0S82007abL@1iLFl0NGA`06UVG`1CD4T08b<I02LW6`12@3@0@D8d0080>S/]04T0>SX^
03@d:00`<2H0=C8Z03Tf;`1DD4L0G5Q?05YEC`1^JF<0N7=]071/H`1XIEh0IF9I06AOF@1UH5X0HeiJ
055<B@0i=C80>cLd03`k>@0d<c40;Rd[02h];P0];Bd0;Rh^02LW:@0X:2X0;Rdb02TZ;P0X:Bh07QlT
01hM9@0P7bL07A/V028P:`0Q7bX09B<^02LV;P0[:340:bH]020M900Z9Rd0<B`c030]=00Y9Rd0=S<j
051=E01ZJG40EUEM03Le@00e=Cl0?3a604E5C`1BDU`0BDUC03Ph@P0^<CX0:R`h02L[=`0W;CT0:S50
02heA@0a>4X0<cY<03m6F@1=E6L0Ff9e071gRP1eNY00OX2G07]mUP1kOiP0OX:M00<0OhBQ00H0P8NT
08:9YP20Qj@0OXJS07b5XP1mQZD307b5Y00I07^4X`1lQJ80NH:Q07^4X`1iQ:80MXBQ07N2XP1hPj<0
MX>S07:1X01bPIh0M8BN06n0VP1^OiL0KWjE06elT`1]NiD0JgVC06QfT@1YMi80IWJ@06IdS`1WMi40
IGF?06=cS@02065`S@04065_RP1OKHP0H6^905eXQP80G6N500/0FfJ405]VPP1KIh40FFEo05ESO@1E
Hgh0E6An05ITO`1@GW/0Ceim04iMO00204mNO`80C5Uk00H0CEMk04]EN@1;DgP0CE9h04aAM`18D7@2
04M@L@0504E>J`19D6`0AdmV04=;GP11BU/02Oooool000Oooooo00@07R0M028T8@0S9B80:bdZ0P0`
=3<0@P0_<c80<3@c02P]:@0V:BD092HQ020Q6`0R8QX0920G02DN500[8aP0=2XP03`_9P0o<BP0@S@[
04@c:`15=2`0ASD]04Lf;`13=B`0@SD]044g;@14>S00B3lf04i5?P1;@S/0CTDn04i7?`1:ASd0CDU0
04=0=`0h=2/0;b`S02XV6`0X91T08alC028N4P0W8AD0:R@F02hX6P0_:AT0<B/K038/700Z9aH0:2HG
02h/7@0Y9aX0?3``05mQEP1XJUl0Gf1H05]LE01GF500DE9:05mNF@1MG5P0GUeK05EDDP1BD5<0DU9D
05ADEP1KFeX0=CHa02DX8@0[;RL09RHN024Q5`808b<G01<092@H01hN4P0K6a406QX@020R5`0R91T0
82<H024T6@0P91H07B4C01TM3P0J7Ph05aX901TL2@0R9A809bPF02@U5@0V9aL0:BXJ0080;2dO01@0
:RXN02`]7`0Z;A`0;c8Q03<f8`0`<ah0=CLQ06YZDP1_JU@0S8Ec0<>i[`3Fc<<0b;fi0967QP23NGX0
PGQk07egN@1jM7@0LFe/06]ZIP80KfiY0P1^KVH0C@1dLFX0MgA]079]J@22OGX0]k2a0<:h`032^<<0
d<GC0=kCh@3?amH0XI^Y085mR`2ZY[@0/k6l0;nna02f]kT0aLG30=gNf@3Og]T0];6X075]HP1_J5h0
U8f309^AR028OGL0OW=]07ieKP20Mg80NgA^07]fL01hLfd0D4e6044n=`0Y:B409bPP03hn=P1ADDL0
B4Pn03do<P0m?C<0>c/a03@a:010>c@0B4<m05=<AP1HDD/0HeaD07YcJ`1gLfX0LViS06IRF@1MFDh0
HUmF06ERF@1LFE80<c0[034]:P0m>CH0@Cdl03<_;P0X9RL0;2X]02d[;P0[:bd09BDW02HT9`0Z:R`0
:b`^02LX;00Q82D07adR028P9@0Q7b@08b4V02DS:00R8BH09B@Y0080:bT^02009R@Y030]<P0i=3/0
=S4h038]=00j=3h0GeUS07]eP@1JEf80<Rhl03Dc@@1:B5H0G5YX06MVMP1IF6P0>ce:02LY=P0X:ST0
:Rdl02X`?P0[<T80<cY<03HnD@0oAeX0DUQ^06AZP01eNi40OH>I0865WP1oPi`0OX:K07b2VP80OhFO
01H0P8JP08:9X`1oQZ<0PXRX07f6Y@1nQjH0NhBS07f8Z01lQjL0NhBU07b5YP1hPj<0NhJT07f6Y`1l
QJ@0NhJT07f8YP1jQJ<0N8>Q07B2W`1cPYl0LX6N0P1_P9X07@1]OiL0KX2H06inU`1/O9H0JWVF06Uh
U`1XMiH0IWJG06EdU@1WMiP0I7BE061`T@1RLi40HW6@069`S@1PKXT0HVf905eXQ01LIH80GFN405]V
PP1HI7h0FVJ005]VPP1FI7l0Df5n05=RO`1DHh80DV620080CEeo0P1<G8003`1<FX40BeV004iJP01=
EWd0Be=h04]AM`1:DWH0BDma04U@K@18Cf`0AdiZ04Q>J018CV@0@dYL04=:FP09ooooo`001oooool0
;@0T92@0:2XY02h`;`0d=SD0=SLi03Di>P0c=cP0=CTj03<g>00W:RP08B<N020Q6`0S8aT09B4F02PR
5P0/91L0<bTM03X^8P0o<B@0A3@W04De:018=RX0ASHY04Lg:P17>Bh0ACL/04<g:`14>2`0@SP^04Y0
=`1>@cd0CD@m04]4?018@CT0Ad8l03Hc;00Z9Al0:2DN02<O5P0P7140920E028N4P0T8A80:B<E02/U
5@0202`W500S034/6@0b;a`0;RdK03He8`0l>Rd0?cda05EEB`1[K6@0JFYT06Y[IP1YJVD0J6UT06ET
HP1RHEl0GUeK05QFE`1BD5<0DE5C05EEE@1JFUL09RTR01LJ4@0S9Qd09RPM02@V6@0X:1`09RPK02DW
6P0P8QL06Q`A01TK400L7a@07R4F01/Q5@0P9QX00P0N8Q@02`0I7a406al@01HJ2@0M80d08RDB02LZ
5@0Z;1L0:bdH030a7`0a<R80;c0P0080:b`L08/0;2lL034d8@0e>2D0=CPS034c7@1QHDT0UI=l09J@
O02_Z9P0^JnU0:6GSP1oM700OgEc07idL`1lM780Mg9_07AaK01aKVT0LG5Y079bJ01aLFL0Lg=W079b
IP1eLfL0RHEl09:=Q`3>alD0h]WN0;R^]P2bZ;<0]:Ze0;2U/`2ITJ00T8ZH0;nia`3;b=<0b<G>0<[9
cP34`/<0][Fc0;Je/02?S8D0JfMN08R1M`2>Qgd0PGU_07]bJ@1dJf80N6mX07igK`23O7@0NWE_05eJ
D`13@3T0@T8j03hm>00d=Bl0=3@/04Y:@P1HFTl0AdTn0410=P12?cH0=S<Z04E1>01:ASd0C4Dm05A@
A`1IDTX0JfML06YVF`1VI5L0HemD05mMD01WIET0JfUM06UYG`0X:20081dH03Pd<@0l>3L0=S8c02d[
;P0_;C40;Bd_02LW:@0S8bD09B<V02/[:`0/;2h0:RXZ02HT9@0W9BH09R@U02DS900X92D0:2<W02DS
9P0V92L0:bT/02d[;P0_;C80=S4g03df?P0i<SX0?cM2048jA`1FCU/0IEm[05iHIP17@e@0@cm@059?
H01XIgL0LG2206]/OP1<CEl0;S52030cA00_=DD0;3=3038iBP0d>dd0>D5D04mGJP1YKhD0MgfC07Z0
UP1kPIT0P8BM08:6X@21Qj40OXBN0826X021Qj40OhJP0827X`21QjL0OhFW0080OXNX00L0OhRY07j9
Z@1mR:P0OHJW07b7Y`1jQJ<0OHRV00<0NhJT00H0N8JQ07^6Y01jR:D0MHBQ07B5X@1`PId206enVP80
KGjH01<0KgjK06akVP1ZNIX0JGNJ06IdV@1TM9P0HW6H06=cU`1RLYH0Gg:C05m_T@1QLI80H6n>065_
S01OKHX0GF^605]VPP1LJ8@0FfV40080EVAo00H0EfF205MTQ01EI8<0EFB305=RP`1BH8<204mOP`0A
04aKPP1;FX40C5V304]IP01>FX80BUIl04eGN`1;DgP0Be=g04QAL018Cf`0AdiZ04M=I`16C6@0ATeP
04A;G@13BUX02Oooool000Oooooo01d0<C0^03@d<P0e=C<0>SXh03/k>@0i>cP0>cdl03do?00o@Ch0
<C@^01dP5`0Q8aH08b@F02DS500X8Q80:B8@02hV4`0e:QP0?34O044d8`12=B@0BSX[04Ph:@19>BX0
BC/^04/m<P15>Bd0@cH]048h;P0204@k=00]048k<`0n>S40?S/b034^9@0P81H08b0G024Q5@0R81<0
8b4B02DS500T8a409bHB02TV4`0/:AH0:RPC02LU400]:aH0>3HQ03/j9P0n?B/0BDLj04Q6>P1>CT@0
G5]F06QWH`1[JVP0J6QV06IVIP1WIFP0IVAW061NG`1JFUX0DE5A04i>C01@DD`0E5M?02@W700I7@l0
8bLI02@X6@0S9aP09BLI02@X6@0P91H06Ad?008051L<00l06ahC01XM4P0L7a@07R4F024T6@0N91H0
6R8C01lW5P0D6`T08RLC02P]5`0]<AX0<3@M02``6@0]<1/00P0`<Qd0400Z;1H0;BlI02h`6`0g>B@0
=cPV03Df900i>RP0HfAB07QgI@2FTX40Y9j>09nGRP2>QW/0PGQ_07acJP1jLFX207UbJP0X07McJP1f
LfX0M79V075bI01cM6H0MGIV07=dHP1[JEX0UiF60<[8^`3LfM00dLc909VCT`2ITiD0XYRP0:JLY@2R
V:40Zj6/0<Bja@38`</0/Z^c0:RQZ02KUYX0SHV:08b8Q@1oNWH0OWMa08^4OP23O7@0MfmW07Q_J01e
K6D0Mg1Z089kM@25OWP0If9L03Db:`0i=Rl0Bd]304Y:@P80?Shf04l0@T8j04i>A013@cT0=cDY03/i
;@0i=b/0BTPl04e;?`1:AS/0DDm205A@A01HETT0G5Y=05aMC@1RH5<0IVMG06m`HP1XJE/0C4U002l/
9@0c<2/0@Cdj03hj>@0n>S/0=C<f034a=00b<S@09RHX02<U900V9RH0:b/Y02`/;00];2X0:bXX02XY
9`0X9bD09bHT02/W9P0Z9RL0:bLX02dX;00b;C<0<bhd03Lb>@0j<c/0@3I103hc@@19?Th0GeAU06ML
K@1AB5T0DdaL069KK@1MF6`0EeAW06=RM01]Jh00HF9f04U>H@0c>T`0;3=5030iBP0a>T/0=d1A03a5
EP18DF80J76207MnT@1kPIL0OHFJ07^3VP21Qj40PXNT0866X`22Qj@0PHJS0866Y021R:D0OhFU00<0
P8JX00T0PHNX07j7YP1nRJL0OhZX07b7Y@1iQ:00NhNQ07Z8XP1gQJ000P1iQj80201fQYl0N8JQ07J6
X01bQYl0LXJQ07:3W`1^Oid0KGfN0P1]O9d206ikWP0K06YfW01YMId0J7BN06IcW@1WM9h0I7>L065`
V@1QL9L0H72D065aT`1PL940GVf>05a[RP1MK8T0Ffb805YZQ`1IJ8D0F6N405ETP@1FIH@0EFB505IU
QP1BHX<0E6:505=QQ01AGh@0CUb30080CE^200l0CEV104aHP01;FH00BEMl04QFN@1:EgT0B5=c04MB
L016DFd0A4iY04I>I@14C640ADeP049;G011BU/02Oooool000Oooooo00L0=cHb03Dd;`0e=S40>S/e
03`m=`0k?3H0@44l0080A4E001l0>chf02X]8P0Z;1h0:b`L02XY5`0Z9a@0:RDA02dW4@0a:aD0>C4L
03hc7`15>RP0B3/Z04Tl;01:?Bd0BS`_04Pj;`14=Rd0ACP_04@k<P12>c<0?cP^03Pf:P0a<BD09BLJ
020R5@0N81<08bDG02DW6@0T9aH0:BXH0080:B/F00<0:BPD02PW4`0Z:AD00P0T8`h05@0g>280?chZ
03hm:@15AS@0CT`o04]9?@1>Bd80EUI>069NF`1RHEl0IVES06ARH`1RH6<0IF=V069RHP1IFEL0DE5?
04i?BP1>DDX0DeI<03<f:`0201lS5@06028V5`0T:1T08RHG01`P4P0M81D05aXA0P0D5`h07`0J6a<0
7AhF020Q6@0R9AX09BLL01lR5`0P9QP092`L01`S4@0V:aL09b`F038f7`0`=1/09b/D02T]5P0b=1h0
<cDO02h`600^<1X0;c4K03Tk9P0j>bT0=cPX04M8>P1aKf<0Lg5U07ikK`2;Qg/0/:ZN0:>MT@20N6d0
0P1gKf80A`1jLVD0O7AW07adI`1jM6H0M75P07EbH@1dLel0Lg9N06i]F@1iMVD0^;FT0>OSe`3_jn80
XIbI08AkO02UW9l0Z9nT0:FKX`2[X:P0e/[D0;V]]`2YWZH0UX^A08b3R02>QHP0RX6208^3P02:P7h0
O7=^07edK`21N740Qgih07acKP1gKVT0NW=]08R1N`1/IEl0B4<m03Tf;`16@c`0B4Q004A4>P11@CL0
ATHn0410=P11?SD0>CL[03Dc9`0n?300>CDZ051=@@1?CD00BdTl04e;?P1;BC`0DE9405YKC@1GFD/0
I6EG06m`HP1dMFL0EeM;03Xg;P0c<2T0@Cdj04I2?`13?ch0?C/l03<a=00c<cH0=SHh00809RHV00<0
:2PV02/[:@0];2X00P0Y:2@0<`0/:bL0:BPT02TX900Z9R<0;2PW02hZ:`0a;300=c8h03Lb>@0h<cX0
>c8l03T_>P14>DL0KV=c07=VN01MDV<0@SU:065JJP1_J7X0HEa`05aIK01UI7H0HV=g04=6F@0_=4P0
;SI903]3EP13Beh0=d=C03Y4E@1HHG80KWJ908>;WP22R9h0PXRP08>9X`21R:80PhRU08B9Y`25RZP0
PhRV08:7Y@22QjL0PHNW07n5Y`21QjT0P8JX0867Z@23RJX0P8JV086:Y`0207j9Y@0n07^7X@1jRJ00
NHRO07Z9X01jRZ40NHVR07J6W`1gQj00LhBN0765WP1bQZ40LHBR06moX01^OYl0K7^M06ajW@1]NYd0
KGVO06efW`1XM9`0JGFO06QdWP1WM9h0IG:L06IdV`1PKiH0H72D05e]S`1NKY00G6n?05e]SP1LKhd0
FVf;05QZR01GJ8H0EFJ405=TPP1DHh@0EVF605=SQ@1AHH<0E6:505=QQ01?GH80DV2504iLP@1?GH80
CE^004eKOP1;FG`0BEUk04IFM`18F7H0AUEb04=CK@15EFh0AE5[049>IP11C600A4mQ0418F`0oB5T9
ooooo`001oooool0=00j>cD0=cP`03Pg<P0j>S80?Shd03hn=P12@C`0B4M204Q8@011@SP0@D<f03Hh
:P0`<b80;BhL02DW4P0U9a40:2LB02/Y500_:QH0=BhK03lg9016>RX0ASP[04Pj;`17>C00BC/b04Tj
<`18>c<0AS`c044j<00c<B@0;c0R02/]7`0T:1T08bLF024U500U:QH0:BhJ02T^600[<1X0:bhI02LZ
5@0S9A008b@B02DV500P8a009bXG0413;P0o@Rd0@dHa04Q;>01>Ccl2051>@@0505AAB01IE500Ge]H
069NF`1SHV000P1RHEl0<`1KG5L0DeA>055BC01ADTX0CDi605AFB`0a=2T07b8G020R5`0T9Ad08R<K
024R6P0J6aD06A/F01@F4`0E5A<061PF01dL600V9B408b8M02PY8@0U9Ad08bDJ02P/7P0S9aP07b<B
02P[600[;QT0;c<L02T[5@0Q8`/0:B/C030d6`0_<aX0;S0J030b700_<A`0>CXX040n<@11?c<0@Che
07MbK029Q840LV]X09VBS02aZZ80Thb2079ZG@1eKUh0Ng9Q07]cH00207ebH00a07YbG`1hLU`0NG=M
07YdGP1dKUP0K6EB0:>JR@3Db[h0d<Nn0>CJf02>QHX0YibT0;:X/@2`YZl0_;:k0>SLiP3UfN<0SX:<
09:7S@2HSI40S82008n4PP2:Og/0UHR207Q[H`1REDd0QgYb0:RKT`2HRXH0MV]W07mdL026OGP0LfUW
05E=BP16@C/0A44j04E2>@14@CP0@d4e04E3=`19ASd0@d0g03`h;`0g<bP0?CT^03hj;P10>Rh0BdHj
04Y6>P02051>@P0A04];?`1<CT40FUa?06MZG`1[KF80Kg1X06YZHP16AD00>cLd04I2?`1>BT/0C4Q9
04M5B00o?D00>cTl03Le>00c<C@00P0Y9bP202`[:@0;02d/:00W9R809B@P02PW8P0W:280:R/U02/Z
9@0^;BT0=SDc03Le>00l=cd00P0k=Sd07P0h<C`0A3Y5069GI@1[H6h0EDQI05mDI01QFFP0IEe/06EL
K`1WGg@0IF9e05iLL@18BEh0:be202T`@`11BE`0E5a_04MBI00jAEL0CUQZ07R0T`1nQ9X0OhFM07n3
WP20QJ80PHJT08>8YP27S:X0QX^[08>9Z@<0Q8ZZ00`0PXRX08B:ZP23R:P0Q8R[08F9[024RJX0P8NT
08:<Y`1oRJ80OHVQ07^7W@1iR9d207V:WP0;07Z;W`1iRJ00MXRN07F6X01cQ:00LH:P06n2X01`Pj<0
L82Q06inW`1^OId00P1]O9d0501ZNIX0J7FH06MdU`1XMIP0IG>F06McV@1VM9T0I7:E069`T`1QLI<0
GFf>05iaT@1KL8l0Ffj>05]`S`1GK8/0Ef^;05IYR@1EJ8P0DfJ60P1DI8H00`1BHX@0Df>505EUQP02
051PP@0B04mOP01@Ggh0CUel04iMO01:FgT0B5Ug04IIM`16FWD0@eMb04=GL012EVh0@EE]04=CK010
D6L0@4mT041=H00nBE/0@DUL2Oooool000Oooooo0?<0@D0k03/k<`0l>C@0?c`e04=0>@14@CX0Ad@o
04i;AP1=BT<0AD<k04e?@P18BSd0@4@e02P[6P0O8a809RTF02LZ5@0U9a80:2LC02`Y5P0d;a`0?SLW
04Dk;`14>2`0ACP_04Lj<P1<?cL0BT0g03H^900a;B80;B/N034b8P0V:AP08RHE02@X5`0R:AL092`G
02`d7`0Y<AX0;34K02db700N8@`08RDB02T/6@0X:aP092LD03<h9013Ac<0ADPc04U<=`1:CCP0CTlm
05=A@P1FDd@0Ee=705IBB@1KEU00GU]D065NF@1PGeX0HF1K05QID`1CE4h0DU==04m@BP1@DDT0Ce59
02X]900A50d061TC024R700N7aX061TD01DF4@0D5180410>014A3`0M71X092<O02TU8P0T8ah0;RhV
02XZ8P0W9ad0:2PL02<U5`0P8a80:B`K02`]6`0`<Al0:B/F02<U400/;QT0;S0K02lb7@0^<Ah0<SDR
02l`800e=RP0?clc04M4>`18@cd0OgYf085lN@1`J6H0RX=m08IoM`1hLVH0MFiN07aeH`1lM640Ng=N
07ibG01oLed0OG9L07icG`1oM600OWIQ07YbG`1TFdX0Wi>70;:UW@2_XIh0`[Jk08j2S02dZ;@0_kG0
0=kFh@3aj_80nNoh0;fb^P1gK780QGYn08n3P`2<PGd0TXEo07mbJP1lKfH0CT4h05I8?`2?PWT0XYF=
081bK@1jKf/0R7ei081fM01?AD@0Aclm04Y7@P19ASl0@d0i040m=013@CD0AT@h04A1>012?SD0@Cdb
040l<@13?C40?SP/03li;@11>bl0BDDj05=AA@1CD4L0CTi6055BBP1ZJf<0Kg9Y079cKP1iNWD0HF1N
03dl>P15@D00Cd]<059=D@13?T80?CPn044oA00n>Cd0>3Hi034_<P0/:Rd0;R`]02l];P0Z:RP0:BTW
028S7P0Q8Qd09RLQ02TZ900^;bT0<C8]038a;`0h=ST0@Cm404<nA@0h<S`0<R`h03lhA01HD5d0EdaJ
04m4DP1KCed0LVMe06aTL@1WGfh0KVEf06mXNP1BCf80>CM<03PiCP0`<TL0>3mB05INL@1OJWh0@DaP
04IAI@1]N8d0Ph^R0827X@23RZH0PXNU08B9Y`23RJT0QH^[08N<[026S:`0Q8ZZ08F;Z`26S:`0Q8^X
08>9Z@25Rj/0Q8VY08F:ZP26Rj/0Q8ZZ0829YP21RjH0Oh^U07n;X`1lRj800P1jRil0901iRJ00NXZQ
07J8WP1eQil0MHJP07F6Y01aPZ00LH6R07:2X`1_P9h0L7nN06imW01[NYT0K7^J06YiV01YN9L0IgJE
06EdU@1VMIH0IgJG06EdU@1TLi@0HW:C065aTP1PLi<0GW6A05Q]S01IKHh0FVj?05Q/S@1HJh`0DfJ7
05AWR01CIXL0E6B605=SQ080DV:300H0DV>1055RP01AHWh0Cf1l04mNN`1=GGL204YKM@0=04QLM@15
FG80A5Yb049HL011Efl0@5I]041DK00oDFT0@59Z03m?IP0oCV<0@DaP03m:G009ooooo`001oooool0
:`15@3d0?CPd040h=P19?ch0BT9004]3@@1>ADH0CDM704a8A@1:B4<0H65I06IYH01GGE40@D@i02X`
8P0U:AX09b/L02HZ6@0X:aX0:b`J030_7@0e<R<0?S//040j;00n>2X0ACdb04]3>00m=BX09QlD02TR
600[9a/0;R`O02PV6@0i>R`0:R`N02<W600Y;Ah0:RhO02da800V:aL08bPD01dR3P0[<1X00P0`=Al0
;`0]<Q`0=CPS04=6<@1;CST0D5@m04e?>@1AD3`0DU4o05ED@P1GET@0FEI705eIC@1LFTh0FUM>05iN
E01OGeL0EeQ@05MHDP1BDdh0D55<05AED01:BdL061XG00T;200B51406QXH01TJ5@0H6QD04a@?010A
300>3@T05A@?01hM600U91l09RHN02TY8@0_;bL0<BhW02@T700Q8AL09BDI02XZ7P0];B40;bdP03Dc
9P0^;1l0;B/N0080<30T0100<C<X03@f:@0d>2X0=3HY03Dg:P0i>c00@T8h05UFC@1eL6X0Mg1Z07E/
IP1gKVD0N71U07Q`H`1mM6<0OWIS0P1kLeh00`1nLEh0O6mL07Y]FP0207U^G01W07ibHP1iKEl0H5=:
09N8P`2JS8/0ThB70:>GX02ISI/0akc<0>3Hi@3`j?<0ooWo0>[Tj02CRXd0MFe[08Z2O`24NgH0PWU`
07AZH01CBCl0DTPl0557>`1EB3l0H5I<069HC`1YGeP0Rh9m08EmNP1bKFX0C4M404U5@P1<B4D0AD@o
04I5@01<CDD0CDm404I8?@16AS`0AT<j04M5>@14@SD0?CT]03Te:@0j=R/0>cL/04m;@P1QGUL0HUmH
05YIE01VIF00NWUe06i_JP1dLW<0QXB5075_L016@T<0@cdo04e7B`17@TH0=c8f03D`=P0k=S`0>C<g
03Pd>@0]:c009RDZ02XY;P0[:Rl0:BX/02@V9@0N81d0828O02T[:00_<Bh0=3He03<d=P0e=3T0>CPn
040oA`11?TT0;b/i02/W=P19A5<0FE=Q04i6E@1DC5T0IUaW06eSKP1dK7T0NG5n06YTLP1ACE`0@Ci?
03/jC00k?500<SM;0417FP1KHgP0FVEk04IAI`1VLXX0PHfX08>>ZP02086<Z080Q8f/00X0PhbY08B=
ZP27SZ/0Qhj[08>:Y`22RjP0QHbY08F<Z023S:T0Q8fZ0P23RZL01`24RjP0Phb[08:;ZP20RjL0OhfX
07j<Y`1mSJL00P1lS:H01@1jRJH0N8NT07J7X@1dQIl0Lh:O0080LX6P0P1aP9l0101_OY/0LH2M06em
V@1[O9P206YkU`0706]lV01VMi<0I7FC06EfU01VMiD0GW6?065dTP02061cT`0305mbT`1LKi00F6^<
00<0F6Z>00<0F6V=05QXRP1DIhP00P1CIXH01@1AI880DVJ104iRO@1BHgd0DF9l0080Cf1j0140CUmi
04]MM@1:G7@0BUad04IJLP16FW<0A5Qa04=GL011EFh0@5A_045EL011DV`0@E=[041@J@12DFP0?DaQ
03i;GP09ooooo`001oooool01@1CBT/0?SHd03le=01?AD@0DdU:0080D4M80200CTQ804]7A01?CTX0
LG9]07EhL@1SJEl0EEYC03Pn=00R:1`08bLI02P/7P0/;R00;c0R02h_7`0^;1d0>3HW044n;@0l>BP0
?cT[044k;@0^:1X05A4401LC1`0Q7Pl0=C<T040n<@0n?2l09bTK02HX6`0X;1h0:BdN02@X6@80720?
00/09BTH03Hk9`0i?RX0>C`W03`o:P15AS@0BDXh04i@>`1>D3X0D4lj059A?@0205=B?P0P05MF@P1L
FDP0G5]905aJB`1KFD`0FUY>05YJD01HFE40E5E?059CCP1BDU00FUYH04Q8A`0=3`h0418A01TK6P0J
71T06a`G01/M600E61403a0:00d>1P0B50T06Q`A028T6@0S9AX0:2XO02la9P0`<2P07QhF01dM4`0U
9Qd202`/8P0I034^9@0b;bH0<RlV03<`9`0]:R<0<S4/03@c;P0h>C40>3/b03Xm<P0j?340=SP]04Q8
?01RH5@0LfmT07M`IP1eKF<0MViS07]cIP1jLf<0OGIS07]eG`1hLU`0NG5L07Y_F`0207EZEP0/07AY
E`1cJ5H0MVeL07U]H@1gJV80VH^809f?SP2MSY40Rgj809nDXP35_L`0gmOT0>7Ki@3ZiN/0al7308b6
QP28P7d0MFiX05=:@`1AB3l0AS`c03/a9`12>2h0AS`b04<i<014>S40Bd0j06aSG@24NWP0Mfm/06mW
I01KEU<0DTe9055>B@1>CDP0EEA?04i?A`0o@CH0@T@i04I6?019BCl0Cde10490=00/:1d203Hb9`1?
03di<01NFE<0KFYU06QUH01YIF80L6m[07EaL01]Jf`0Ui:F0:6LX01gLWH0>3<g040k?`19A4P0>C@h
02d[;P0[9R`0<2/a03Lb=P0c<SH0:bX`02PY;P0Y:Rh0:2`_02<W:00O8b807B<Q020V900_<c80=SXk
03Pi>`0h>Ch0>SY203Ph@P0m>dP0=39002/Y=`0j=TL0BDEF05aEI@1IDf40GUQT06aTK`1cJgH0O7J0
071ZMP1GE5l0CD]H03PgA@0g>DP0>Ca?03HkCP0nAUT0AE1R05AOM@1XM8`0OXZR07j:Y@1nS:T0P8jY
086?ZP22T:/0QI6[08>?Z@24T:X0QY2[08NA[025SjX0Q8jY08>=Z024SZT0Qi6/08B@ZP25SZ/0PHZW
08:=Z`24Sjh0PXf]07n<[00307f<Z`80NhZY00T0NXVX07R7YP1fQjD0M8FS07J5Y01dPj80LH2O0721
W`1aPYh00`1^Oi/02@1YOIP0JGfF06UmUP1XO9D0IWZC06EiU01SMi80HGF@061cT@02061eTP05069e
U@1OLY<0Ffj?05Y]SP1KKXl00P1GJX/00`1GJ8X0F6R:05AWQ`02059UP`06059VP@1AIX40CF=k04eQ
NP1?Hg/0CF5i0P1<H7P04017Fg<0AEUb04EIL@17Fg@0AUYc04AHL@13EG40@eA`04AEL`11DW00@U5^
045@K@0oCFP0?TaV03a8H00mBEl9ooooo`001oooool01@1VH680@cXk04Lo?@1ECD/0F51>0080D4]8
02`0DTi;04m>BP1QHUd0M7E`075cKP1_LV/0IfUT05AGD00n@CP0;c4V030b9`0c<bL0<C8T038`8`0Y
9QL0;b`K03Lf8P0e=200=C<N02/Y500N6`P07A/801hM2`0b<Al0@44_03Xk:`0b=B@09BPG02DY6P0P
91D07R8C01XN3`0K7a40:blQ03Hj;010@S@0ADLi04M8>01<BS/0DDm2055?@@1CDT00CTdi055>>`80
E54n0240DU4m05ED@01FED<0FEQ605]IBP1EETP0F5Q<05]KD@1HF500DE1;055@C01DDe40FUQI059@
DP0J6Q`06A/J028T8`0M7a`06adH01/N5`0G6Q4041<800lC1@0D60T05a/<01hR500T:1X09b/M02da
8`0[;R<082<H028U700Y:b@00P0];RP0<@0_;bL0<2lZ03@c;P0b<B`0;RdX02`[9P0_;RT0=CH^03Pi
<@0l?S<0?Shd03/i;@1EDdH0JfMK07IbIP1eKf40MW1Q07UbHP1iM640N7=O07]fH01jMUd0Mg=J07Ib
F@1dKUH0L6QA06iXD01/ITh0L6YD07A]FP1jLF80OG=Y09F:Q02GSXT0UXb;08AkP02aZ[80b<3;0>3J
i03JeM`0al;80;Rc]`2GTi80M6m/04m7A00g;B/0=B`W03DZ9P0e:R@00P0j;BL0E00l;bT0>BhX04<h
=01[H5h0M6UW075WI@1[HUd0I5YH06AKEP1NEdl0GUYA061LD`1:Ach0@3dd04=3=`17Acd0DE5704];
@@0g=bd0<2dT03Xg;P0e<RT0CDY306ISGP1dKf/0Lfi[06iYIP1/J6D0KFMW08=oP02UWj<0RHB:05A?
D`0b;C40A3m304M5B00];Bl06a/M020P8P0X:2X0;Bh`02h`<`0Y;C00:2d`02L];@0V;2`08BXW020Y
9P0R:bP09c0_03Lm?@0j?T40=cXo03Lg@@0m?DT0?3a803@c@@0[:SP0>3M705IDHP1OGF/0IV9`065N
J@1^Jg@0RXN@07EbN`1IF600ATE=04=3B`13ATl0?41;03e3C`0lA540>T=B045=G@1SL840NXNJ07b;
X01nSJ80PHnX086AZP22TZT0PI:V08:CY`80Q9>X00D0R9FX08NDY`26TZP0QY:X08JBZP0208B@ZP0K
086?Z@22T:X0P8jY07j<Z@1mS:/0P8na07n=/P1nS:l0OH^^07^9[01lRZd0OXf^07^:Z`1kR:X0NHJX
07J5YP1gQjP0MXFV07>2X@1cQ:80Kh>N06f1W01ZOYT0JgnH06YnU`1VO9@0IgfD0080IWbC00/0I7ZA
06=iT@1QMhl0HWNB05mdS`1PMI80GgBA065dU01NLI40GG2@05]^SP0205YZR`0305UZR01HJHL0EfR6
0080DfJ400L0DFJ3051UP01=IGl0BV9j04]UO01:I7/0B69i0080Aemg00L0B5if04IKMP15Fg<0AUYe
04EIM015EW80AEEd0080AUEf00L0@e1b04A>L@14CW40@DY[0419J011B6@0@TQR00Wooooo0007oooo
o`0c08F2PP1@CD/0?CXe05]IDP1[JV40H61G05UHC`1NGEH0JfYS07QiLP1iNW<0MWUc079gKP1^LF/0
J6eT06=WG@1DEdX0ATTm03Pi;00a<bD0;blO02`/700Z:AL0:bXG02XY5@0_;1P0:2HB02<R3P0Y:AL0
<c<R03Pi:@0i>RX0<C<T028V5P0K7`l0720B020S5@0R9AL092LI02T/7P0g>Bd0@44d04I7>`1:Bcd0
CTi0051?@@1CD440De9204m@?01ADS`0DU<k0080DE4k0240De<m059E?`1GEdD0F5Y805QIBP1GF4X0
FUY>05QGC@1HE4l0Ee5>05YBE01LE5P0GeML069JH014?D80=S@d02PW9@0L7A/07b4K01/N5`0I71<0
5AX>01@J3@0F70d05al?01/S4`0S:Q`09RdO02P_8P0]=2H0:S4S02`a8`0^<BD00`0_<2D01P0c<BT0
<c<Z038b:@0_;bH0<30V03<c:@80>S``0140>CT]04a<?`1GETT0JVYL07IfI`1eM6@0M7=S07YfI`1j
MF<0NWAS07YeH`1jM680NgER07A^F`1aJeP0KFMD06aVD`0206iXE@2>079[FP1lMF@0QGi_08^3N02E
S8<0S89k0925PP2`YZH0eLgB0=K@eP3Le]d0d<_B0=?>e03Kf=`0_[^m08n<S@13?Sl08Q/J02dT8P0d
:bP0=R`X03H[9`0f:2@0>B/X03TZ9`0f:2@0GU1=061BD01gJ6D0O71/07IZIP1bIf<0JV1I06YRF@1a
JF00GUU>05MBA`1HEDT0EE9605UFBP14@CD0>cL]04A0=`1;Ad40Ad0l061IE`1QFUX0P7Yl08J0PP1]
IfT0N79d07mjN`1kMWL0O7Mi06iYJ@1]JVP0GeaJ055?C@0c<C009RHW01hO800L7Al08BDV02T];P0Z
;c009b`^02/a<P0]<S@0;34b02X_<00W;2`0;C0a03Li?@0f=c`0=cHl03@c>P0f=3h0=cDo03Hc?P0j
=d80@T1;04i;E@1NG6H0MWAm06e/M029R8l0V9NN07inQ01JG680A4I;03m2B00n@DT0@4A?03i1CP11
AeL0CeEW05]RMP1dOY80PHfQ082;X`22SJH0PHnV08BBZP25U:/0Q9BY08BDY`24UJP0QIJX08BEY`26
UjP0QIJW08>DY`25UJT0QIFZ08BAZ`22T:X0PY2[08:AZ`21Sj`0P8j]082>[P20S[00PXnc07n=/01m
Rjd0OHZ]07^9Z`1mRjd0O8V[07Z7ZP1iQjX0N8JY07N6Z@1dQ:D0Lh>T06n2X01_Pil0KH6M06]oW01Y
OI/0J7bJ06MkV@<0IWZG0P1TNID0:@1TMY@0HG>A065cTP1OLi80Gg>C061aTP1NL940FVf=05]^S01I
JhT0FVb805QZQP1FJ8<0EVN205=WP@1BIX40D6F204iSP01=IGl0C6Io04eWP@19I7d0B6Am04MSO017
HG/0Af1k04ALN@13FgH0AEUd04=GLP16EgD0AUEe04QEM`16DgH0AE9d04E=L@13Bfl0AD]]04=8J012
AF@0@dIS00Wooooo0007ooooo`0<06ATHP1cM6l0G5eG03i0=@1eMfX0N7Y]06YZH01dLFP0NWM`07Uh
L`1cM6h0Kg9[0P1/LFX0B`1ZKfP0JW1V06AZGP1JH580EUa>04I:>`0c=RD0<C@S02h_7@0Y:QP0;B`J
03Hc8P0f=B<0<34O02h_800b<bD0=SHZ03Li;00Z;2406adB01XL3`0S9AP0:2XM02LY700_<B@0=CLY
0493=@18BC/0AdPh04U:>P1<CC/0Bddh04Y<=P1<CSP0Bddg04iB=`1@E3T0D5@k055E?01CEch0EEU2
05ULB@1HFdX0F5Y<05YJCP1OG5<0F5==05MBC`1JDE80GU=G069GG@1SF600HUMO06IMHP1LF5T0>3Le
01dN6@0R8ad08B@K01hQ5P0J7A80728F01dS5`0J8QD08b/N02L_8P0X<bD0:C@V02`d9@0Y<R409B`L
02`a800Y;1/08B8B038`8@0203Hd9`0:03De:@0a<BD0<C8T03Tj;00l?Bl0@48d04I7>@1JFdd0HfEG
06e_H@80MGIX01T0MWQZ07moK`1iMVL0OGMY07miJ`1kLfP0NW9W07I^H`1_Ie`0JV9E06eUF01`J5/0
LFUL07eeJ02>QWT0UXj108V1MP24NW00UH^20;:WX@3KdLl0i=WM0>7Hg@3Qf^40h=WQ0080i=oV03d0
bLK=07ilP@0X9RT081XL02hX:00d;2X0<RPV030U8@0b9240=bTV03X[:00h:B@0B3Te05I7A01bHf00
M6IS071RG`1bIf<0L6EO079WH@1lLf`0N6mV07=]H@1]Ie/0GeU=06=MD@1LED/0ETm505eFCP1WGUT0
JEmM06aQI01WG680Q7^009ZDV02ESYD0ViFI0:2LV`1aKFX0DTi;06ERG@1gM6d0IF9K040o>P0H5a<0
9bLW02`];`0O8b@0:2`]02T_;`0S:BT09RX[02P/;`0^;c<0;Rdc02DT:P0[:2l0>3Dl03dh?`0g<3P0
;bXa00<0<Rdd0240>34i04U2B@1CCU@0D4]A055?E01^K740KFaa09JEV`27Qhl0FEaS04E9DP19CEH0
@dMB0413DP13AUL0BDiR05AIK`1gN9@0OH6L08B9YP24RjL0QHZX08ZA[P29TZl0RYB_08VE[`29UJd0
QYF/08RG[024UJT0QYNY08FHZ@24UZX00P23UJT00`24UJT0Pi:Y08BB[00208>A[080QI2^00D0Q8n]
08F@[`24Sjl0Q8n]082;Z@0207f:ZP0D07b9Z@1kR:P0NHRY07N6Y`1hQjP0MXJW07F5YP1bQJD0LHBR
06n2X01/Oil0JgjN06]nW`1YO9h0JG^O06QjX01VN9h0IgVM06UiW@1WMi/306AbU@0>06AdUP1SLiD0
H72D05e]S`1NKXl0Ffj>05a]R`1IKHP0F6b505UZQ01GJ880EFJ005=WP01AIH0304mTO`0=04YROP1;
HX40Af1n04MQO017GWd0B61l04EMN@17G7T0AUYe04AHL`17F7@0AeMe04QEM@0204ICL`0604E@L012
BfX0ADaY04E:I`13Af@0@TIQ2Oooool000Oooooo04X0DE9F07MhNP28R8P0EEEC05IED@1QGUT0H5]H
071ZJP22O7`0MW9c06iZJ`1WIfL0IfUX06U]K01ZL6`0IfiW06E/I01QJEh0H6QK05]QD`14Bc/0=3PY
02lb8@0b<b<0<c@T03Xh:@0e<b@0;BhN02d_8@0^;b40<C<U03@f:@0^<2D09bLM02PX7P0Y:Al0:b/Q
02XZ800d=2P0?Sla04U:?01=CSh0BD`i04Y=>019CCH0Ad/b04E9;P16BS00B4`c04eA>01BESd0E5Po
05AH@@1DET00EUQ305YKB@1IFT`0FUY>05]KD@1JEe00Ee9?05MAD@1IDeD0GUQJ061JG01OFEd0GeYK
061LF`1QH5`0CTm902h_9`0X:b0082<H01`P4P808BDG01L08bLI020V600S:ah0:c<V02/f:00X=2H0
:3<S02@_7P0U;Qd0:S0M02DX5@0Q8Q00;2dM038`8`0g=BP0>SP/03Tg:`0j>2`0?3``03lo<`19BCd0
GUiB06][G`02075aI@08079bIP1dMFL0O7e_0820LP1lN6`0NgM[081lL01mMV`207M`IP0T07A]H`1`
JUh0LfeO07A^H01bK5`0P7YZ092:NP2CS7`0QWm_08IlL02j/:H0dLS10>CIe`3Wg>00i=WO0>?Ih@3T
f^D0l^[g0>;Lj02m]l40EE9I01XH7@0Q6al08adO02dT9`0b:2T0;b<S034S8`0c9BD0>B/Z03/]:P0n
<2d0F4Y7065DCP1MDT`0K65K0P1aIV00A@1fKFH0PGQc07mfL@1gL6P0LV]Q06MNE@1TFe80Jf9K06]R
G@1]HUh0KV=Q06mSH`1_HfH0KfAX09fDU`2c[Jl0Yj6U09jJV`2PVYX0LFaY04@o?01RGEX0JfMT059>
C@0k>CX071XM02@S:00/;C40:Bd`02/`<`0[<C4092TZ02TZ;P0/:c40<Bhe034[=@0^:380>38l03/e
?`0m=D00<BTd02/T;00c;3@0>c@k03Xc>P0o>3l0BdA;04i7CP1BCE<0BdQ?05iLI@1VI6l0Hf=_04e?
F`19BeP0@dIE04A7F013B5/0@TMK04E:H01LH7T0N7bG08R9Z028R:X0RHb]08V>[P2:SJh0RXn_08Z?
[@0208fD/00N08ZD[@2:UZ`0RIR]08RG[027UZ/0QIJZ08NHZP26UjT0Q9FY08FFZP25U:/0QYF/08BB
[023TJ/0QI2/08JA[@24Sj/0PhjY08B@ZP23SjT0PHfW07f;Y@1lRZD0O8bV07Z9YP1hQjH0MHBS07F6
Y01aQ:@0M8NW0P1aQ:@0301`Pj<0Kh>T06j2X`1^P:@0JgjR06UmXP1YNj40IgVO06UhW`1/NYl0I7:G
06IbV080IW>F01H0I76C06=bT`1QKi80HFnB05m^S`1LK8d0GVf<05a]R@1JJhD0FVZ405QXPP1FIWl0
DfAn05AUO`1BHgl0DfB004mSOP1?HX00DFB204iSP01;H7/0C65n0P19GWT00`18G7L0AUYc04QIL`02
04MHLP0904IFL013Df`0@U1Z04=AJ`13CfT0@deV04A<H`0oAEd0@DMO00Wooooo0007ooooo`1:06AU
JP27R8`0R8N<06IVJ01<BT/0F5AE05I@DP1[IFL0VI>G071[K`1YI6P0I6AT06EWIP1XK6/0JFm]06Q^
JP1TKVH0IFmV06I`I@1XL6<0HVYK04U?@@0`=2H0<S@V03Pj;00k?2h0=SLY02h`8P0];b40;S0R02la
8`0a<bD0;BdQ02`/800^;200;2TP02h^900a<BL0>CT]04E6>019BSX0Bdhk04U<=`19CCH0A4P_0496
:`15BBh0@dL/04Q<<`1>DST0DUHo05AH@@1GFD<0EEM205MHAP1JF4T0G5Y=05aJCP1KF540FEA@05IA
CP1GDe@0F5AE05]GF01LF5T0GUYK05eKG01KFeT0HF9M05ULE@11A3/0<3<X024T6@0O8QL2028T5`0I
02HY7P0Y;2409bdS02Ta9P0Y<bP09S4S028]7`0R;Ad08b`K02D]700W:aX0:B`K02`]7@0_<280>3HY
03Xh;00n?300?CT^04=1=@1<BSh0DU14061PE01cLfL0N7Q/07MgJ`0207AdJ00S07QhK020OG40Og]`
07ahK@1kMf`0OgQ`07YcJ`1iMF`0M71U07A]H`1fLVH0NGIW07ejJ@26Pg80T8Yj08N2K`1mN6D0S8Ee
0<c4]`3Pf<d0i=[E0>KJfP3Sem/0jMkT0>gQj`3Ne=l0ZJ6^08=kQP0i=3/0=2le024K7`0T6ah0;24U
03<Y:P0f:R`00P0`92@08`0b9bD0=R/W03L]:019@3/0B3lh05A;A01WGUL0K6=N06mVH@1jLF`0OWAb
07abL01iLV`0M6eW06eTG`1`If80LVUT071WHP1aIV@0KV=Q075VI01YGEh0HEEG09jDU@2RVIX0RhF5
092:RP2VXIh0Mg9_04<n>`1FDTl0CTY902h/;@0`;S40:2PZ0080;2da03T0:blb02``<@0Y;Bh092LY
02`[<00_;C80<bhe03@]=@0j<Sd0@CU403`d?`0c:cH0:b<^02LP:00c;S@0DTeC04]6BP13?T80Ad96
04a7C@1?BU40B4E>04i;E`19AeD0AdIF04E6F014AET0@TAI04I8H@13Af80ATYW05UMNP1lOih0RHb]
08V9[@2>S[80SI2c08b?/P2=T;40S8n`08^@[P2>Tk00SiF_08fE[02:UJ/0RiN]08NF[@29UJd0Qi>[
08ZF[P27UZd0QIB[08>BZ@23TJ/0Q9:/08JD[`24TZd00P26TJd02@25T:`0PhnY08>?Y`22SZP0PHfW
07f;Y@1gQIl0N8RR07V9X`0207R7Y00G07B5X`1aQ:80LhJV0764Y01_PZ80Kh:S06j1XP1]Oj<0JgfQ
06]mXP1YNj40IgVO06YiX01XMih0JGNN06MeVP1XM9X0IgBG06=`T`1RKi40I76C06=`TP1QKY000P1N
KHh01P1OKXl0FfZ905a[R01IJ8D0EfJ305ASP080EFB10P1DHh805P1?Gh00Ceio04mOP01>GWl0CF1n
04mPOP19G7X0CEij04IGL`14EG40AEI`04AEK`15EW00@E=[049BJ`10D6T0?deW049AJ011C680?dYP
03m5F`0nA5X9ooooo`001oooool0801cM7P0Oh2406a]L@1VIVP0EUIH05UGFP1QGf80MW5e0:2LW@1[
JFX0FUYH06=TG`1VJ6<0J6eW06M/IP1YKVP0J6mW06]eK01/MVd0JG=Z06mfKP1SJV80EU]D055GC@1;
CT<0@4@f034e9`0_<bD0;30R02lc900`=2D0<C<U0P0/;Al04`0b<2<0<2hR038b9P0e=BT0>S`_04Q:
?019C3/0B4di04E:=015BS<0@4H/0457;@15BC00A4L_04i@>P1?Dc`0EUU405UKAP1KFTH00P1KFTP0
301MFT/0GEU=065JD01MEU00Ee9>05MBC`1HE5D0EE=D05YHF@1MFe`0H5iQ05iNGP80GEmL04<0Ff1J
055FD00k@3T092TR01dS6@0K7QL07b8K02@W800Y;2D0:2dW02P_:00V;BD08RTQ01/R6P0L91T082/M
028Y700X;R00:BdN02hb8`0d=RP0=CHX03/i;00o>bl0@3X^04Y4>01JE4P0GEU=06UWFP1gMFP0O7Y]
07ekKP1jN6`0NGM[07YhK020OG80P7ac07eiL01kMfh0OWM]07efK01iMFX0MW9W07A`I@1kMf/0Oga]
08N5MP28QWL0S8Uh07ejI`1eLUl0Thik0<S2/P3Gcl80h]W?0=oAcP3KcLd0el_=0<Zma02HSI<0L6E]
05Q=E@0f;C80=Rd`02hU9P0W7Ah0:b4R0080=R`[0380;B<R02`T8P0_9b@0=2lY034]9P0n>C<0@3/e
04m8@P1WH5X0KVIS07UaKP1lM740Ng=a07Q`KP1gKf`0MFeZ07A/J@1eKFX0LfaV079YI01fK6X0J5eK
061ED`1KD4h0ET]907AZJ01_If@0O7Aa08b7P`2>RHD0JfQS05QDD@1HEe<0?C`j028R800X:2P0<30`
034c<P0`<S40:R`Y02PZ9`0[:b/0:RT[034/<00f<CD0=Bhe03@]=@0o>400@CY2034Z<P80;RT`00@0
:bH/038`=@1HEU/0EE=F0P13@dD03@15@dP0@d170491B@13@Dd0@Sm@048nE@12@5P0@d1M04E2H@13
@V@0ATIZ069RR01kNj400P2:S;803P2?Sk<0T92d08nB/`2@UKD0SY>a08nD/@2?UJl0T9J`09:H/02A
VK00SYV_08jH/@2;Uk40SIJc0P2<UK80302;U;<0RIBb08NB/026TK40Qi:b08NB/028Tk40QYBa08BB
[`25Tk00Phn/08:>Z080PHbX00/0OXbY07^9YP1iQj@0NXRU07N6Y@1iR:L0M8BU07>3Y01dQ:H0LX:T
06n2X`0206eoX`0>06moX`1^OZ80K7bP06alX01ZNJ00IgJM06IeW01WMYd0IGBK06IdV@1ULiH0I7:E
065`T@1RLI82065^T00>05eZS01OK8h0FVN905]XRP1KJX/0EfJ605QWR01DHh@0EF>605MUR01CH8<0
Den5051NQ@1AGHD204mMPP0:04iNPP1=Fgh0Be]m04eLO@18EgP0AUEd04MFL`15EW80A5Ea04=DKP80
@U9/00@0@DmZ049@JP11BfH0?dUR0P10AUh9ooooo`001oooool04P1bLgP0K6md06EYK01@E5D0DUIG
06a^K@22Q840QhN508R9Q01TIEl0DeA>05=FC@1DEdh0HFAK06Y]I01TIeh0I6YP075fK`80MGad07T0
MWef079gL@1^Lfd0LWQ^06M]H@12B3`0<cT[03Tm;`0e>BX0<SHW03<g9P0c=RD0<34Q034b8P0d=BD0
<S<U03Hf:P0g=b/0>S`^04M9>`1;Cch0BDhj04E:=014BC80@TL`04E9<017Bc80BD`e051B?01ADch0
EeU405eLB01NFdP0GEY905mLC@1MFT/0GEU=06=LDP1KE4`0EE1:05QED01CDTh0EUEC05]JF01MG5X0
HV9R06ATI01RI6<0Gf5P05eRGP1IGUX0Be1<03Tn>P0/<B/09BLT02HX9@0V:2<0:R`W02L/:00X;BL0
9bhW01hU7@0L8a/07bHN02@/8@0Q:1d09B/O028X6P0]<B<0<S@V03<e9`0j>bd0>cTZ04Q2=P1CCCl0
GUQ<06MQE@1bKV80PGea08B0M023Og<0Pgmd07ilL01lN6l0P7ac089nM@1nNW40O7Q_07mhKP1nMfd0
N7AY07IbI`1jMV/0Q81e08N5N@27QGP0PX1d07ilL020OW40OG]/09bHS02h]:P0_;JZ0=kEb`3Eb/H0
`K>b0:BHV01nLW@0FDiB05=7B`19?T80?38c03T_<00f;2/0;R@S030V9@0e:bX0=Bd[02dU8`0^9R@0
;RTU0080;R/T00P0>3D^03lj=01ABT@0JV5L07E[J@1lLW00OWIc07idL`80NG5_01D0N71]07I^K01e
KFX0Mg1Z06YSG@1RFeD0E4e704@k=P1<@cd0Achg04U0>`15?3L0LfaV0929P`25P7`0KFYU05mKF01:
BDD0;B`Z024Q7`0Z:RP00P0a<Bl0:P0Y:bP09BDS02XZ:00`;Rl0<2d_038]<@0g<SH0?3Lm03Xc>`0c
;SD0=Rlf02hY;`0T7bD0:bT^038`=@0o?T<0C4]@0451@`0k?3h0?d1203m0A@0n?TH0?Ca4044oC@11
?U<0?SYC04E0GP16@680AT9U04e;L01[JI00PH2X08n>]P2ATkT0SI2c08nB]@2AU;D0T9Fe092E/`2A
U[<0TYRb092G/@80T9J`00H0T9Na09:I/`2?U[80SYNd08bE]02<UKH208jD]P0>08^D]@2:U;L0RI6e
08R@]027TK@0QY2c08FB]024TK<0Pi:c086?/022T:d0P8^Y07b9Z@1nRj/307b9Z@0407R7YP1gQZL0
M8BU07>3Y@80MXBW00/0L82T06inXP1`P:@0KGfQ06inXP1/Nj00JgVN06ajW`1YNId0IWJJ06MgV`02
06AdV00506AdUP1RLY@0H72A061_T01RLI800P1NKHh205aYS00O05YWRP1JJ8/0EfF805MURP1DI8P0
EFF9059PQ@1AGh@0DEn604iLP`1?GH@0CUb104mMPP1>G7l0C5Ym04eKOP1<Fg`0B5Mh04MFM@19F7L0
AeIc04EFL`11DW00@e9a045@K`11Cf`0@4i[045<J00oBF@0@DQR0457G`09ooooo`001oooool07P1T
Ifh0HVM]06adM`1FH5l0EV5K07V3NP2DWY<0SYJ906M]G`1MHU@0F5a>04U;?@1BE4L0JfeP06]]HP1W
JEh0HfEJ06i_I`1lOGD0P8=j07f0N@1lOgP0Ngie07b2N01gOG40GV5F0496>00o@c@0>ch]03Lj:@80
=3LT00d0<S<Q030a7`0b<b40<c@T03Tj;00k>bl0?Cla04E7>@1:CC`0BD`i04Q;>018BcH0BD`g0080
Bddg00@0Cdlj05=B?P1DDcl0EeA10P1IETD0>@1MFT/0Gea=05mLC@1OG4d0HEeA05YHB`1HETX0F5Q>
05UIC`1MGED0I6AL06ASGP1UIF<0JFUY06MWI`1QHF40H65S05IGF@1DEEL0DU=E04Q9B`0e=cH09RPW
02<X900Y;RP0:RlY02H[9@0X;BH08BLM01`R600Q9ad09BXS02<W7P0V:Ah08bLI02da8`0c=BL0>S`^
03ho;`0k>RP0Ad@e05MA@@1XHU@0KfUK07egJ@2;QGL0SXQj08^5N@2:PgT0O7Q]07aeJ`21NW40OgQ`
07ijK`1lN6d0P7U_08=lLP0207]gK00B08B0M`2<Qh40RhJ008V4OP21O7P0MG1]07YfL`2=RXD0YJ2M
0:NRWP2DSh/0/JRT0:bRX02ERHT0PgUj05eCE00o=SL0>c4`0P0i;bh04`0l<S40=B/Y02lU8`0a9bH0
=2XY03H/:P0`9RD0=2XY03H^;00f;bT0<B`U03Pa:`0i<2T0CdHo06EJE01fJfL0OW=_07]bK@1kL6h0
0P1fK6X0701gKVT0M6aY07E^J01aKF@0EE5804I2>@17@cX0>cL^044l<P11>S00@c`d03Tb:P15?SH0
OGI`08V1OP1XHel0B4=003D_;`0_:b`0:RPY02/Y:P0`<300=3@d02DU9@0Q7b80;2X]02h^<00a<3@2
03Pf>`0I03dk@00i=3/0:BH]02lZ<00b<3D0:bP_030]=00g=S/0?ci304E4B@10?d@0>CXn03Pl?`0j
?D80>ci503`lAP11@E00@T1E04<oF019A680BDIU04m;KP1[JX`0RhZ/09:B]P0208nB/`0J08jA/02@
Tk80TIJd096F]02BUk@0SiJc092G/`2=Uk80T9Ve08jE/P2AV;D0T9Nd092F]P2>U;H0SiFg08fC]`2<
T[H0SiFi08fE^@2;TkL0R92e08VA]P29TkL0Phfa08:>]022S[H2086?]005086?/P1oS:l0O8Z]07V7
ZP1hQjP00P1kRZ/03@1gQZL0N8JY07N5Z01cPJ@0MX>V07>1Y01bP:<0L7jQ07:0X`1/NYd0JWRK06]i
W01YMiX00P1ZN9/0101UMIL0I7BF069eUP1RMIH3061cU00=05mbT`1PL980GVj@05a/SP1LK900FfV>
05UWS01HIX/0FFN<05ITR`1DHhX0EFB;055PQ`0204mOP`80CEeo0P1<G7d04P1<GG/0C5]j04YIMP1:
FGH0B5Md04QFL`17EW<0AUEd04IEM@15DgH0A55c041=K`0mC6d0?da^049=K@11BVT0@DQT0417H@Wo
oooo0007ooooo`0D06IYLP1UJW00IVia07EoOP1oRX@0Oh^107n;O`1GHU@0DEU:06=ZF`1RIUP0FE]>
05eODP2;Rh40L71V05aLDP1WIed0LVmX08F2O@26QH02081oNP0G0821N@1oPWT0NWeb079eJP1MHE<0
B4`m03@h9`0e>2D0>3/V030c7P0a<ad0<S@N038e800e>2D0>CXZ03ho;`11@S80@T<c04M8>01ADT00
DU4o05ED@P1AD3h00P1AD3`0101CDCh0De0o05EB@@1JE4@205]EA`0J05aIBP1LFT/0FEM805iLC@1O
GDh0EUM705QIB@1KG4h0HF9D06ATF01VIUX0IVIN06QWH`1`KF`0KVY[06MUJ01QGf80EUAI05ABE`1G
EU/0EEIH04=4AP0R92<0828M02DZ8`0Z;bP202@Z800B02@Z7P0S9Q/09BPM02P[8P0[;R@0:bhS02L[
7@0a=BH0>C/]0495=016BCH0@d@b04Q7=@1CD3l0KFMG07MaH@1lMFD0SHIf0P2<Q7L0;P28P7D0O7=Z
07YcJ@1oN6l0Pgad085mM01mNFh0OWM_08N0N024OGD0QH5h08n:Q02BSHT0R81n089lO01iLgD0KVQ/
08J0Q02WXj@0ViFG09NAT`2RWIX0THZ708f5PP1oMg@0K6AQ059:B00l=c<0=S4]03dh<P11>S@0?cPb
03P`;@0]9B809alL02XR7`0j<2h0>30]03L];00h<2d0=RlY03</9@0e;RP0>c8[0556@01REe4207I[
I@0I07I]IP1kLFl0MVaZ07=/IP1dKFL0LVeW06]VH01JEdh0<S0T02l/8`0m>S40=c@[03Tf;@0j=Rd0
?3P_03Te;00]:280EU5=07=^J`1DCd`0@3Xj03D_<@0e<C80<S0c034_<P0203<c=@0^02LW:@0X9b`0
;B`a02h]<P0f=CX0>3Ll03Th?@0h=c`0<S4g02/X;`0^;340=S@i03Tf?@0g=S`0=cPm03Xk@00n?TH0
>CU103Hi?P0f>cl0>3]403TmAP0l@4`0@49C04=4F@17A5l0BDUU05YIN01]K8`0PX>R092A/02=TJh0
SY:_08nC[P2?UJl0TYRb092F/02AUk40T9Nc092G]02=U[<0S9Nc08nI]`2=U[D0T9Jf09:H^0<0SiFg
00`0RiBe08bB]02;U;D0RY>d08VC]P27TKD0R9:f08JC]P23T;<0PHnd07n=]020SkH207j=]080Nh^_
01L0NHV]07N7Z`1hR:`0MXJZ07N5ZP1iQj`0MXBY07B2Y`1cPJH0LX2U075oXP1_OJ00LGnR06mmX01^
O9l0KG^M06aiV`1ZNIX0JGRI06MfU`1VMYL0HWFF065dU@0205mcU004065eUP1NLY<0GG2A05e`T@80
F6Z>00T0F6N>05YXS`1HIX/0F6J;05=RR@1DHhX0EFF9055QQ@1?Gh400P1;GWh0201>Ggd0BU]i04eN
NP1;G7P0BUUf04aKN019F7D0AeIc0P17E7@02`15DW@0A55e04EAM`14D7H0?T]^03e;KP0nBfh0?T]]
03m:J00kA640?4=O00Wooooo0007ooooo`0]06a/M01ZJg00If]^08B:RP2=UY40Lgee06=/I`1<Dd`0
EEaE06AZH`1VJfD0Gf9K05iOFP2?SXX0JFQT05AAC01QGUT0KfYW081kN026PGh0PGai08B0O@1oNgP0
OWei07n0NP22QGh0N7]b05YND00c=bL0=3LT03Dh8`0e>B80<cLN03Di800d=Qh0=cTQ03ln:@11@2/0
@3lZ048o;015@Rl0CTPh055>?@1EDT<0F5940080Dddm07H0E4do05=;?P1DC440EU1405]DBP1IEDX0
FUQ<05aMC`1BDdD0DUE405MJB@1HFdP0G5m<05eNCP1TIED0IVAG06MUF@1UHUT0IV=N07A_K@1[IFD0
IV1R06EOH`1QFel0EU5E05ECEP1LG5h0Fe]K03Xl>@0^<BX0;S4X02lb9`0[;b40:2hP02D/700T:1T0
:2XL02`^800a=BH0;SDU03Di:P0j?Rl0?T8c04A8=`15BSH0CE0m04m>?01KF4L0JfIC07IaGP1iLV00
Q7]Z08=jJ`22NFX0PgU_07meJ`1iL6L0OGE]08=lMP1nNG<0O7Q_07mhLP2;Q7h0QWmi08^3P02ARHL0
S8>408IkO`20Mg`0MF]c07]dO02NUih0WINK08b6RP2ESi40YZ:O08Z6P@2<R7l0MW9Y05iJC`1FDTT0
A44h04=0=`14@CP0?SXa04I2>@0n>C<0:2<M02LR700Z9Al0>S<]03Pc;@0f;R/0=S4[03Lc:P0`;280
=RlW040i<@1<@c`0HUUB07A[I01aJ640L6UQ07A/J@1bKFT0KfaU071]IP1aLFT0IFEM0494>@0M7a@0
8b@L034a:@0`<2P0=3<^03Dd<00d<bl0>3Lc0P0j=SD05P1;AdP0@cm003dh?00`:bl0=C0d03Dc>00`
;S<0;bhd02h]<`0[;340;c0e038c>00h>Ch0=3Ll038e>P0c=3T0<34f02l`=00Z:Bh0;bhd03Xi?`0j
>D4203Hf?P0@03Hi@00h>d@0>Ce603Hj@`0e?4@0>3a803LmB@0k@E40?T=G0497G@15BF80DeMb07Ah
T`25RjD0RY2Z08jD[080SI>[01D0SiF[092H[@2AVJh0TYZ_09:J/@2BVK<0T9Nc092I]P2>VKD0SiZg
08ZE]@2?V;T0T9Vj08nG^`2?V;T0S9Ff08^F]02<UK@0SIRf08VD/P26U;400P25U;<01@23U;80PI6b
07nB/`1lT;40Oi:c0080Nhfa0P1hRZh0101gRJd0MXR^07B6[01eQjd207F4Z`80Lh:Y00@0LX6X0760
Y`1^OZ80KgnS0P1]OIl04`1_OYl0K7^J06elV`1XMiH0JGRG06MfU@1UM9<0I7BE065dU01QM9D0H7>D
05a`T`1MLI@0FFf@05Y/T01JK980EFN=05QWSP1GIXd00P1FIXX02`1DI8H0Df>504mRPP1AI8@0C5mm
04eQO01;GgX0C61k04YNN@1:GG/0Beil0080B5Ug00<0AUIg04QGN018EGP00P17E7L02P17DGP0ADie
049>M010C780?4Q^03e:K@0oC6h0?DQV03Y3H00i@eh9ooooo`001oooool04`1]K780LG1e075bMP20
Q8D0PHF405ILFP1PI6<0IVaZ06EYJ01ZKVd0KG5`071bK`1YJfP0KFe]06QWI@1SHV00FeMD05QCD01m
MG<00P28P7h0A023OW/0P7]h085nN@20OgX0QHJ008R;PP1hNg00=CT[03/o;P0o@Rl0?D0[03/o:00j
?RL0=SPR03Dg8@0n?BP0?chY044o:P13@B`0A3l/04M2;`16@300Dddm05A=?@1?B3P0D4Ti04i5>@1?
AC/0E4]205]DC01METh0G5Q?05]HC`1HF4`0DUA7059DAP1JGTd0GV9A065TD`1OHU40H65C06=QE@1S
H5L0IF9K06QUH01dKVd0JF=S06MNH@1TGV00HE]O05eGF`1JF5/0Fe]M05]KF`1CEE80@D@m03<f;@0a
=2T0<SHX02`c8`0Y<200;2hP030c8P0];b40>Cd]03e1<P10A3D0ATXk0P18C3/0@`1;CS/0E5M405aM
B`1SHTh0KVUF07E`G@1kLV40P7MV08AhJ023MfT0Og=W07idJP1nM6/0OGA/085jM01nMg40OGI`085i
MP2=QH80THV608n7Q@2:P840QW]o08=hOP1mLWP0P7Em08Z0R02GSY<0THR;09J=T02[XZ<0[ZVU08J1
NP2;RGd0MWAX06ESE`1LFTh0Bd/o04e=@`1ADDL0=cL_038b:P0l>C80=34Z02`Y8P0a;RL0>3D`03dh
<P0g<R`0=S8Y03@a:00b;R<0>34W03lh<01<AC/0GeI?07I]IP1jLFX0MVmY07A_J`1cL6/0LG1[06AU
G`1JFeD0C4e7034d;@0U:2400P0^;bT0<@0^;BT0<C0]034_<00a<C40<c<c03Pf=`0m>c`0=cDh03<a
=00h<cT0=2le03<a=P0^;340:RT_02/Z<00Z:c00;2db03Df>`0i?440>Se203<f>`0`<cP0;S4f02hb
=@0_<3@0;2da030_=@0h=cd0>CU103Ph@P0k>dD0=cU503XlB00m@D`0>cm;03HlB00i?dd0?TAD03m6
F014Bel0AdmV05QON@1^MHl0OXRQ08RBZ`2:UJ/0SYJ]09:J/@2@V:d00P2CVk001@2BVZl0U9ba09FM
/P2CVk80TYVe0080TIZg00D0T9^h08jI]`2>VKL0SiZh08nJ^P0208fH]P0708^I]02=V;@0RINb08NE
/025UJl0Q9Fa08>D/002086D/P1607fB/@1kT:l0O92a07j@/`1jS;00N8Z^07N9[@1gRJl0NH^a07J8
[P1dQZ`0MHB[07B4Z01cPZT0M8>Z07:1Z01`PZH0KX2T06]nW`1/Oj00KWjO06ioW@1[O9X0JW^G06Mh
U01UMY80IWFD06EfU01QM9@0H7>C061cU01NLI80Gg6E05eaU01LKY80FffA05]]T`1IJi40EfJ=05ET
R`1FIXX0EFF805ATQP1CHh@0D6>105=TPP1AIH00CV9m04aPN`1<Ggd0BEaj04QKN@19G7X0AeMh04QH
N@16EWP0AeEh04UFN@1:E7P0AeAg04UCM`15Cg<0@dea045>L@0nBfh0?DY/03e:JP0mB6H0>TEQ03]5
H0Wooooo0007ooooo`0C06IUJP1cLgD0MWIh07UjO01aLW@0Ce=D06IWJ@1oPh@0LW=e079dM01dMWD0
M7Ic06i`K@1ZJVP0LG5_07]kN@1]K6P0GeYF07UdL00208^6P01/08R3O@25P7X0QH9i08>3N@27Qgl0
SXn708jAR014Acd0?D0e0494=`11@cD0@48d03m1<`0g>RT0=3DS03Th9P0o?R`0@D0/03`i9P15@Rl0
B4Db03ll:@10?BX0AT4^04<n:`13?2X0@3PZ03L]8`0o=Rd0ETm705eFD01JEe00EUI>05AEC@1FEdl0
GV1E061TEP1SIeT0HF=H05QJC`1KG5@0GUiF06UVH@1[If@0Kf]Z079^KP1WHf@0HeeM06APH@1RGF40
GeeP05eKGP1LG5h0EeMI05AFE@1?DDh0?D8l03]0>@0k@CL0=C/_034g:@0b=2L0=cT[03Tk;P10@S@0
BT`n04a>@01EEdT0F5Y<059EA01GF4H0HV=A06YYE@1]K5P0LfiK07A_F`1jLF00O7=R089iJ020MfP0
O79V07idJP1nM6/0OgI^08EnN022NgD0PWYg085iM`29PGl0UXj<08f7Q`23NW/0P7Mh08AiO@1mLg@0
P7Ig09N=S02RV9L0XYRF0:RMV`2[X9h0XYVD08b5OP2:QGl0OW]d07EbJ`1/K6@0GUiF0P1CETd0;P12
@cd0=SLa03dl=`0o?ST0>3Lb03Th<`0j>CD0?CXe03`i<P0i=Rd0<2`S038]8P0k<bP0@ST`04U1=P1T
FU40Ng9Y07YaJP1gL6X0LfiZ07QdL@1^KFT0DE9=04I6A00d=S<0:B/X02`^;@0];Bd0;R`]02h]:`0a
;c40<Blb030^<@0d<SD0>SPk03/i?00d<SD0;2X]02hY;@0`:bl0;bd`02h/;`0^;C80;bhc02l`=00`
<CD203Xn@@0303Hj?@0`=3L0;S8e0080;C4d02L0;Bhb02h_<`0d=CX0=SHn03Tg@P0j>T@0?Ce903hm
B`10?dd0@49?03`oCP0j?D`0?3m@04A9G013BUd0CeI]06I`R@1eOiP0PHfW08RF/029Uk40S9R`08bF
[`2AVk@0TYZa09FM]02FW[D0U9bc09JN]@2GWKD0VIni09NL^@2DVkL0TIZg09:K^02@VKH0Si^e096M
]`2>W;H00P2=VkD02@2;Vk@0RYRb08FE[P26U[00Q9F_08FF/P24UK<0Q9Be086A/P0207nB/`0407jA
/P20T;<0OHfa07f=/@80NXZ^0P1iRJd04P1hR:X0N8JY07J4Y`1cPj@0MHFV07>6YP1`Pj<0Kh:R06Yo
WP1[P9l0JGjK06MlV@1WNiP0IGRF06MjV01UN9H0HgRG065fU@80HGBE01L0HG6C061`TP1PL9@0Gg6E
05e/T`1JK980FffE05QZTP1JJI00EfF<05ESR01FI8T0Df64059QPP1AHH80DV62055RP01?HX00CF1n
04mOP01=GGh0C5am04UINP0204YHN`0?04MEN018EGP0B5Eh04QEM`18Dg40Ae9`04E@KP14Cfd0@di/
045<K00mB6P0?dYX03e8IP0jAF40>DEO00Wooooo0007ooooo`0o06MUJ01cLgD0M7Af07MgN@1kNgd0
KVma06UZK01]Kfh0KW1_07MiM`1]Kf`0IfUV06U[IP1[KFX0LG=^07eoO01hNG@0JfYU07mlM@2NVi80
UI>708N5N@2:R7`0R8Ij08J4N027Qgd0RHUo08n@R01ZKF@0DEA;04U<@@17BSl0BDa10455=`0i>bh0
=CLY03Hg:@0g>2P0>3TW03dn;016AC<0A4<_03Lf8P0a;aX0<RlL02l/6@0g<Ql0:b@F02DM4P0S7180
?CH^05A?B@1CD4T0DU9:05MHD01MGUH0HV=K061SFP1RIE`0GUmG05UJE01LGEL0IfQS0080Lg9`00<0
LG5a079`L@1QGEh00P1VHV<04@1QGf80H5iQ061NH@1KFed0EEEG059DD`1CEE80Ada604I;A@19CTL0
AdXo0496>013ACP0ADHh04M8>P19BC/0FeU<0080HV=C02l0HV1A059@@@1KFDX0KVeK071]G01fLf80
NG=S07YdI01kLfH0NW9U07igI`1oMfX0OWIY085gK@20MV`0PWQ_08ImMP25O7L0PgYe08=iM`29Ogd0
U8Z908=iM`1iKfd0O79`081eL`21MW@0SX=o09fBSP2TUi40W8n90::ES`2OTX`0TXN108f4OP2=QX00
QH1l07=`J`1bKfX0MGA_06=TG`1OHE`0H65L05QIE01?CTX0?Slj03/j=P0203Pg<`0/03Lf<P0m>SD0
>cPa030]900f<BH0?CH/044k;`13?C40IeiE081iK`1kM6h0M6m[075]JP1gMW80L71^03Tk>00^<2l0
;c4`02X[;@0/;Bl0;Rh`030^<@0_;C00<S0c034_=00c<CH0>3Hi03hl?`0n?3d0<c4b02TW:00_:b`0
;2X[02d[;00b<340<C4c03<c=@0e=SX0>S/o03Xn@@0h?3l0<SLj02hb=@0];S8202da=00H02l`=00a
<SL0=CDm03Hf?P0k>D@0?Sa90491C`12A5<0@D1@0411D`0n@E80@4IF0453F015BUh0ATaT061YPP2<
U[40T9^g08fH]02=VkH0SYbg09>N^P2CWKP0U9ji0P2GW[P00`2EW;H0UYfg09RO^@0209JM]`0509NL
^@2DVkL0Tifh096J]`2?VK@00P2>V[8308bK/P0708VI/027Uk00R9Ra08RH/P26UK@0QIBe08BC]002
08>A]00L08>A]P21Sk@0P8jc082>]020S;@0OXZb07f9[`1kQjd0NhV^07^9[01iQjX0N8NX07J5YP1e
QJH0M8FS0723X@1]P9h0KhBQ06b1WP1WO9/0JWnN06UnW@1WNi/0I7RI06AgU`1RMiH0H7BE05mcU080
Gg6E00d0H72D05i^TP1QLID0GVjB05][S`1JK900FF^?05MYS@1HJ8`0EVJ805MUR01DHhH0E6:500<0
DV6200<0D62104ePP@1<Gh000P1<G7h00`1<G7d0BUYk04UINP0204UHN@0>04EDM@16Dg<0AU=c04ME
L016DVh0@U1[045<JP12CF/0@di/03m:J00nBFL0?dYX03U4H00g@ed9ooooo`001oooool0E`1WHVH0
L6ia07=aM01gMgT0OGem07UiM`1aLFl0HV=N06UZI@1hNG<0HfAN06=VG`1_LV/0LWA_075fK`1eNW@0
LGI_07UnM`25R7l0][Z/0;^o/02>T880PhEg08Z;O@2<SGl0SXao08>3M`25Qg`0Q8Ik07]nL`1`LfP0
J6iR05eSE@1:D480>cla03Tk;P0j?2l0=SPZ03<e9`0l?bh0@D8b03Pi9`0Z:aT0:2LC02LV500T8a40
:BHE02HR4@0`:QX09B8C02hZ7P13?c@0D4e405EEB`1NGU@0HF9J06=TG01QI5/0HVEL05iQFP1IFeH0
HfEP075cL01kOGX0Q8J508N9R01/KFd0G5YK06aXJ@1/If/0If9V065OI01MFf00FEQM05IFF01CEE@0
EUQE05=ED01CETl0EEQ?05AFB@1>D480EUM905IDA@1@CSl0FEI606ISDP02075[F`0:05iHB01:A3H0
Ee5306USE@1eKf<0S8Ij08n8OP20NFl0NW=[07igK`80PGY`0180P7U_08=kL020N6d0PWQ^08]nMP2:
OGD0QgYb08UjL`2:Ng@0Sh1k08=dK@20LFX0PgA]08=fKP24Mfl0THAl09^>QP2FQh0209>4O@0S08n2
O02@Pgd0THJ108f3P@1mMG<0JfIS07QcL025PGh0S8^908>2P01kNWP0GeiL04i:B@1;BTP0B4A303`h
=`0e<C00=30_03Pd<@0e<Bh0<c0[03Tf;`0n>S40@cld04U5>P1aKVD0OW]d07EbJ`1]K6L0QXN208F6
P@1NH5/09R/W02lc<P0d>3T00P0_<380;00c<SL0<C4c038b=00`<380<C4c03<c=@0k>c/0@3ho0450
?P0i>SD0=CHa03Dd<00c<S00<S4_03Hf=00f=SH0=CDe03Tj?00m?T80>Si103@g?00_<SL0;2ld02T/
<@0_<3D0=SLl03Dd>P0c<SX0=SDm03Xh@`0l>TL0?Se;04=5DP15B5L0ADIJ03m2E@0l@ED0@4MJ0496
G`15Bf<0GfB10869YP2@VKP0TIZi0P2CW;/01`2DWK`0UIjm09RN_P2FWKX0UYfi09RM^P2HW[P00P2H
WkT0202GW[P0UInh09NN^P2CWKP0TYbg09:N^02@W;H0Si^c0P2?Vk4208fL/`0=08ZH/P29Uk80RiVf
08RE]@26TkH0QY:h08>?]`25TKT0Q92h08J?^P22RkH0P8Vb086:]0020829]00908:;]01nQjh0NhN]
07^8Z`1hQJP0MXBW07B3Y01bPZ<0Lh>T00<0Kh:R00X0KH2P06YmWP1ZOIh0JWfN06UkWP1WNId0IgJM
069dVP1RM9`0Gg6I0P1QL9T01@1MKiD0GW2D05maU@1KKI40FFb=0080EVV900P0EVV705=VQ01DJ8<0
FFZ6055SP@1>GWl0DF62059RP`80DV:400P0CV2404YNO`18Fg`0BEam04YMO@18FgT0B5ag04QIM@80
AeQb00d0AeIc04EDL@16EG80AUAa041?K00oC6`0@Di^041=K@0mBVX0?deZ041;J@0h@el0>D9O00Wo
oooo0007ooooo`1[06UUIP1[JFX0Lg5b07MeMP1jNWP0PX=n07ioN@1[K6@0LG=X07UkL01HFE40IFQO
07EhL@1cN740MGYc06ieK@1iP7P0W:>K09jVV`3=eLH0f=k@09RNT01UJE/0MgU[0862M01lO700LW9V
07=cJ@22Q7T0RHb108Z=PP22R7`0NX1d065WF@1<D480@4@f03Pj;@0i>bh0<cLX03@h:@0f>BP0<C@S
02T/6`0Z:aT0:BXH01hO3@0J6`T0:RTF03`i9P0m>RT0=34R03@`901>BSh0GUa?061QD`1PH5H0HV9H
05mPF01NGeL0HfAN06AUH01YJfP0K6i]07]mO02EVIX0UYZK06a/KP1nOX00R8J907QcN@1VHFL0I5mU
05iIG`1LEed0FEMJ05UGF01IFUD0F5UC05UID@1HF4h0Fea>05YKB`1THU<0I65@061MC01[IU@0KFID
07A]F`1/IED0E4dm04e5>01>AST0F51507=ZH@2;Q7`0VI:<08j6P`1lM740PGah08AoN@24P7L0Qh1h
08MnM@21NFh0PgQ^08]nM@2:O7<00`29Ng802P2;OG@0S7ie08IhK@21LfP0QgU^08IjKP2?PWT0UHQo
0964N`2=P7L208aoM`0P08f2O02BR8<0S8B107E]J`1ZIF80Pgik09nKV02KUi@0Q81m075]K01SGeh0
H5aI06aXI@1JEU<0>CDb034/:@0h<c00>SDb03Pd<@0g<c00?S`g04A4?015ACd0D51807MhL01gN780
MGMb07UkMP2;SHX0LWAa03Pj=`0Y:bP2034b=00i02d^<00a<3D0<S4f038a=P0a<C<0<S8d03De=@0f
=SH0?3`l03ln?011@Cl0?Chi03Tj=@0f=S@0<S8`03@d<P0f>3D0>C/j03Pj>@0e>CX0=c/n03Hi?P0d
=c`0<3<h02lb>00a=3/0=SHn03dmA@0i>400=cHn03dlA00j>T@0>3I403`kB`11@e80@dIG0453F010
AE/0@4IN04]AJ@1;DF/0GV>008:9YP2=U;D0SIJg096J^`2CW;d0UYbn09NM_`2FWl00U9fn09FN_@2F
WKX0V9nk09NN^P2FX;/0UZ2i00<0U:2j01H0Tini09:N^02AWKL0T9bf092L]02?Vk<0T9bd08fI/`2;
VK@0RYRc08ZH]@29V;L0QYBg08JD^@26T[X0QI6i08B@^P25TK/0QHji08B;]`22RKD0PHVd0P1oR;<0
101nQk00OHJ]07R4ZP1jQjX207J4Y`0307F5Y`1dQ:H0LhJW0080LHBU00L0Kh:S06UkW`1]OjD0JWbR
06UkX@1XNIl0JGRO0080I7>L00D0Hg:K065`V@1SLYd0GW2H05i`UP0205eaU00605Y^S`1IKXd0DfR7
05EZQ`1DJH@0EFZ50P1DJ8<07@1BIH80CV61055QP`1AHH<0DV:605=SQ`1>H8@0BUb004ULO@1:GGd0
C5ek04QLM`19FW@0Ae]c04EIL@17FG40AEI`04EEK`15E740@e9`049AL00lBf`0?di_03e:K00lBF/0
?4UY03]9IP0h@f40>T=P00Wooooo0007ooooo`0V06e/JP1/JfT0Lg9^07MhL`1mOWP0OWmg08:4N@20
PWD0QHIh07anL01UIeX0Gf9G06e`I`1gO7D0MGYc08:9PP2=U8d0Vj:K0;g4_03Kh]X0a<_308N<Q@11
ASl0FEaC06AWGP1LG5@0D518065QF@1nOWH0PX9j08b=Q@2AU8/0SY6807n2M`1_LfD0FEe?04A8>P0f
>R`3038f9`0702da800Y;A`0<3<R02ha800K7Pd05QT8038c800204A3;`0P03Th900g=2<0D4dl065N
B`1RGd`0HUm@06MSE`1WHeP0If=J06aWH`1cKfh0JFMX06QVJ@1mO840Rhb@0862Q`22PXL0X9nT09JD
V@20OH@0K6M^06IQJ01PFF40HEYQ05eGF@1OFET0GUUE05iID`1RFe40IEmC069OD01WI5<206aVEP0H
071ZFP1hLEl0JF1?06MNC`1MDdL0ETi1059:?`1;ACT0DDY006URFP1nMW<0XYZG09ZETP23OW/0THb8
09jIT`2FTXT0THZ208V0M`1nM6X0OW5X08]lM@2=P7L0Rgie0P2:OG@06`2;Og<0T8Ah08MkK`1oMFT0
PgY[08EkK`2?QG/0TXQn08Z2M`24O740QWme08f6O02?R7h0SXR109fJT`2<RH@0NgYe06UXH`1fMG00
QhJ108F4O`1bKfX0MgA_07mjM01hLfd0DDa603dh<P02048k=@0@048j=`10>3D0?cXg04U6@`1KG5L0
EeUD05]MF01hOGL0PXN109>IU@2:T8`0Kg=b03/m?00^<2l0=CDg03Hf>080=cHk01/0=S@i03Dc>00e
=3T0=3@f038d<`0j?3T0>3Xg03do?00o?cl0?Shn03Xj>P0e=cH0<S<e03<g>P0h?3d0=c/l038h>00f
?3`0=CXm03<h>`0d>Cd0<SLk034f?00c>3l0>cm804E8D@16BE800P16AU004`1;BeD0?3i:03dlBP0n
@4l0@dII04A6F`12AUl0A4QS04E:I`1=E700HVV607Z0X02<T[80TINj09:H_02EVkd0TiVk09NM_`2C
W;d00P2EX<002P2DWkd0UJ2l09>O^@2DX;X0Tj6k096Q^P2@W[T0Tj6l09:P^`2DWk/209:M^@09092K
]`2BWKT0TIbh092K^@2?V[P0RiRh08^J^@2;V[/0QiNi0080QiNk00X0QYBk08FC^024T;P0QY:j08>?
]`23S;D0PXVc0869/P1nQjh0OHJ]0P1jQZ`02`1iQj`0NHNZ07J6Z01gQj/0MHN[07:6Z@1dR:/0M8JZ
06n1Y`1aPjT0JgfU0080KWfX0100JgfU06EhX01UMil0HgFK069dVP1SMI/0H7:H065cV`1OLiP0GG6F
05U`TP1HKi40Efj>05M^S@1DJhX0DFR70P1CJXT0101DJHP0DfR5059UQP1BHXH2059QR00905=RR@1@
GhH0C5j204ULO@1<G7d0C5ek04eLN@1:FgD0BUYd0080B5Yb00h0AeU_04AFKP13E6h0A5Ea04AEM012
DW<0?Ti`03m=L00oC6l0?dU]03e:K@0iAVP0=d9P03Q3H@Wooooo0007ooooo`0W06m^JP1[JVH0LG9/
07QiL`20PGT0P89g08B6N@27RG/0QHMi08>6MP1oPg@0If]M06AZGP1`MV`0OhEk08bCR`2Y/:P0cMC<
0=?JdP2X/ZT0SYF>061UG`1EFU@0EeaE055DC@1EE4l0CT]606ERG@1gLfd0N7E^08>3N`2?T8P0TiB<
09:DR@2=T8D0Ngma05eQD`12ASP0>3`^0080<cLX0300:2`M02X^7`0a=2<0;c4S01XK2`0R8a<0=CDT
03hm:@12@Bd0@D0/04=0;@19AS<0EE<n06=QC01[IU<0KfUI06mYF`1aJV00MFiV079ZI`1/IVH0NWIg
07ajO@1_KG80QHB90:b[/02AT9D0QhF:07ilP@1gLWP0KfY`06ANHP1SFUd0HUUJ069JE`1RFeD0IUmE
06eUFP1]IEP0IV1@06MQD@1_J5P0MFiN08=lK01mMVH0Dd`l05Q@@`1LE4T205MAA@0n05UCA`1HDDL0
FeA>07]cL02SViT0XIVG09VAS`2g[j`0`KZd0;>/Y02NUHh0MfeT07=VG@1lKfL0Rgif08n2N@29OgD0
R7id08InL`27OG40S89f08IlL022NFX0Pga/08EnKP28P7<0QWia08EmL025Og<0RH=g08f6O02:PgT0
Y:2F0<:o^02RXYX0LW=[051@B01gMfl0VYZ@09BDRP1iMVd0TXn6096>Q@1lN6l0G5Q?03lk<P0l=c40
?CPb048j=`15?CX0AD0m04e:BP1iNGT0KFm^05mQH01jOWd0Yj^/09ZNW`1[Kg00Ce1B03@e=`0f=SP2
03Xh>`80>CLl0100=cDh034_<P0c<c<0=SHd03Dg<`0o@C`0?T0k03m1?00o?cd0>SXj03Li>00e=SP0
<c@h03Pk@010A4L0>d130P0c>3`00`0d>Cd0<cPl03Dh?`02034d>`0Q03XmAP1CEUl0F5]R051CFP1@
D5P0EUUR051CG00m?d/0?T1=0495EP15B5/0AT]Q04I:H`1>Dg00DeYg06Q_S024RZX0Ri6a09:H^P2C
VK`0UYc009RN`P2IWl40V9k209FM`@2FX<<0UZ7109>N_P2BX;d0TZ2k09>S_@2@XK/0Sj2l0080TZ6n
00/0T9fm096N_P2DWkd0U9nm096L^P2@Vk/0TYfm092J_@2>Vkd0RYVj08NE^00208NG^@0408BF^P23
UKT0Q9Bh08FE]`80Pi6d01`0Pi6f07f9[`1nR[00OhZ_07b9[01kR:/0N8J[07V7[01iRJd0MhN[07F5
Z@1fQJ`0MXR^07B8[@1cQj`0M8J^0760Z@1aP:/0KWbY06]hY@1/NJH0JGNT06IgX`1WN:<0IGNO065c
V`1SMId0Gg:J0P1NLIT205]aUP0T05Q`TP1DK8h0Eg2?05A]S01CK8/0DFZ9059YR`1AJ8X0E6R9059U
RP1DHh`0DF2;059QS01BHHX0Cej704iMQ01=GH40CUen04]JN@1=G7T0Be]e04]IM017Eg40BEUb045C
J`13E6h0A5Ea04=DLP12DW@0?Ti`03a<L00mBg00?TY`0419L00nB6`0?4IY0P0j@f89ooooo`001ooo
ool01`1aL6/0K6]V07QgLP1oOWT0PH9j08:4N@26R7/00P27RG/09`24R7L0RXim07MnKP1MI5@0N7i`
092FR02_]jX0dMW<0=WQeP2QZIh0LGU^06U`J01GG5D0Gf9K069UGP1EETh0HV9J06QUGP1]J680LVaU
07A`I`1gM6/0Q8Aj08b>P`2FV8d0UYV>09:HS01nQ7P0F5i@0498>P0_=BL0;30R02da8`0Y:ah0:B/M
02HT600N70l0;bdP03Tf:002040m;P0h044n;@0o?R`0@3l[04a;=P1VIE00KF]F075^F`1iM640Mg5Q
079/GP1XHUH0L6UQ0:FPVP2/Yj@0ViNF09ZIU`2_[Z`0NGQf06m_K`1kNGX0Og]j07YfM@1[IV<0J6=O
06]VH01ZIUd0KFUN071]GP1hLV80LFaI055<>@1:AC80Hea:07QaH@1mMFP0KVQJ04m9?@1GDdL0EUA8
05MEB@1EDdL0FEM;069NE@1^If40RX1n09N<RP2KT8h0/jRV0=K;a`3Aa/00/JNN08f0N01gJV40O6mV
089eK023NG0208QoMP0f08=jL@22O700QGe`08^3MP26Ofl0PW][08AmK@23O6X0Qgi_08^2L`2>QGH0
SXIi08V1MP1oMf`0Rh9i0;NbZ02o_;<0QhMm06MWG@1bLVH0T92408f?P@27RG/0RHUm0:>SU`2VYYX0
RXMn06UVG@1>Bd@0BTU40491?013?c`0C4Q7055=CP1GDeH0RHN<07YhO@1/JG00O7V008^8S`1RGfH0
AT=:03`i@00h=S/0>cHj03dh?00k=SX0?CTj03dk?00h=cD0<S<^03@e;`0i>S@0>S`d0P11A3/01`11
A3d0?T0k03Pj=`0i>CT0>CXl03Pi?@0h?3l00P0n@DH0100k>d<0>SY203dlA00l>d<203/iA00F03/k
A@14A4h0IfM_06EVJ`1>Ce<0A4M<051CFP19C5D0@4A?04E9E@13BET0BTmR04Q>I018CVH0EEYg071g
U023S:/0SYBf08fC]@2DV;/0Ui^n09VM`P80VIo300P0VIk409RM``2FW/<0UIo209BN`@2AW[h0TZ6n
092Q_@80T:6o0P2AX<4209:Q`P0/09:O`P2BW/40TYc0092M`02?W;l0SY[008bH_P29Uk`0RiVn08NG
^`25UKL0QIRi08:E]@24U;D0Pi>d07nB/01nTJl0PI6b082@/@1lS:d0O8^]07^;[@1fQZP0N8R/07N6
[@1iR;40N8N`07J5[P1gQ[40MXF`07R7/P1gQ[40MH:_07>0[@1_NZP0KWRY06egZP1/MZT0K7RZ06Ue
YP1VM:<0I7FQ069cW`1QM9l2061cWP0M05aaW01JKiX0FW2I05E]T`1FKY@0E6jA05E_TP1EKI40D6R<
051VR`1BIX/0DVF=05=USP1?H8`0CUn;04eKR01@GhX0CUf604eLP`1=GH40CUao04aKO01<FGT0CE]h
04eHMP1:F7D0BEMd04IEM015E7D00P15DgH02P11Cg<0?Taa03i<L`0oBg40@DYa041:KP10B6`0?TMX
03e3H`0j@Eh9ooooo`001oooool0K01QH5/0N7Mb08:1O020PGT0OGmd0822M`25Qg`0QXQk08F9NP2:
SWl0R8am079iJ@1ZLF40RXj00:Z^X03;dLD0d=K:0;2f[01oQG/0G65J05UNE`1IFeH0GF1I06QYH`1T
IEl0IVEP06]XH@1FDdX0GUYA05]GC01THUH0NWY^07n1M027Rgd0U9R:09NMS`27SGl0K79T069XFP18
Ccl0;C4R030d9@0Z;1l05aL;020N4P0[9a`0<blS03dh;014?S80@C/]040m;P0n>bX0?ch/04]:=P1V
IE00MWAO07QfH@1hLel0MG1L06iYEP1VH500HeeA09F>Q034_KL0fMC@0:n/Y`2>SHT0QhR305]LE`1T
IF00M7=_07elM`1kN740MG9Y07MdJ`1kNFd0PGmb06m/G@1SH4l0Gea;048o;00W8Pl0DD/k07MaH`1^
J5`0F5A905EAB01GEdd0F5Q@05MGC`1EEDd0H61H07IcKP23OWX0Rh>108j3P@2BQhD0XiFD0;b^Z`2j
[JL0UhZ208IiL@1nLFP0O6mV07meK01nMF`0PGY`08N0MP80Q7ec03@0QGmc08R2MP26P780Q7i`08J0
L026Ofl0Rh9c0927N02@R7/0RH5d08V1MP1gKf@0P7Q]0:^TV@2GThP0PWib08N5MP2JUhP0U9:307=b
H01ZJ5T0RHMh0;VgZP2m_K40UYJ<075aJ@1]K6L0JfaV065PG01OFeX0GUYI061LG@1/IVX0ShR?08R1
R@1iLWX0EdmJ05I>F@0o>400?3Dl04DnA@0o>Cd0>38d03Xd=P0l=SP0A40o0491?@0n?CP0>cXe03`m
=@0m?SH0?Slg0P14Ach08`10@c`0?3hi03`n>`10@400@d=503ln@`0j>cl0>ca104Q9CP17Adl0@3m7
04E4C013@4T0=c@m03dj@`18Adl0HV5X07EdNP1]KW80BDaA03Pk@P12ATl0@dUE04=9E`14Be/0ATeP
04M=H`1<DVX0Ff5k07=hU@22RJH0T9Jf096G^@2AUKP0UYZm0080Vio200`0VZ3409ZOa@2IW/H0VJ78
09VQaP2FX<@0UZ3309>P`P2BXL00T:6o096P`@2BXL8209>Qa00A096O`P2AW/40TYo2096L`P2DWL@0
T9c208nK`@2=VKl0RiNm08^I_P2:V;d0R9Rl08JF^023U[H0PYFe08BE/`20Tk400P1oT[001P20TJl0
OXj_07j>[`1lS:h0NHV[07V9[@80N8N^01D0NXVb07V8/`1iR;<0NHJc07R5/P1fPk00M86^07Ao[@1b
OJ/0LGVZ079jZ`1^N:/0K7JY06egZ01ZMZL0IWBU06=dXP1QLZ00Gg6O05i`WP1OLIl00P1LLIh06`1J
KiX0F6jG05Q_V01GKiD0EFfC05I^U01CJhl0DVR=051VR`1?HXX0DVF?04ePR`1?H8`0CUn;04iMR01?
GXL0C5^204eLP`1=Fh00Cef004eJO01<EWT0CEMj04YDM`19EWP0B5Eh04IDN@0204IDN`0:049@N010
CGL0@4af03m;M@10BG80@4Q_0459KP11AfT0?T=S03TnG0Wooooo0007ooooo`2E05iOF@1_L6X0MWM_
07=eJP1_LFH0MgY_08B7O027RWl0R8^008Z=PP2CUX/0OX1e07UkL02[[:@0`lBl0<C5_`2QXY`0M7M`
06Q[I01/KVT0G5iI05MGE@1OGed0I6IS06maK01]KVT0K6eW05mPF01@DDD0E5E705IGB@1gN6X0NWa^
07f1LP22QWL0RXio08N;O01aMF@0IFUH05eQD010AcD0<cLV030b900A4`D07AdA040n<P0n>Rh0?3L[
044k;`12?2h0Ad@e04Y7>014@C00E55006]XE@1`KEX0LFiK06]YE01UHdh0L6]H06YTE01OFdl0JVIK
08j:P@2_[:D0WIbG075aJ`1fMg40H65K05AGCP1JFe<0J6YO07MiKP1iNfh0O7a`07moL`1nOg40J6II
05IDA`1:B3/0AD<d03@b8`15@cH0HV1D05UFC@1FDdd0EeIB05QGD`1GEeD0EEEC065QG`1fMW@0PH1n
08F1P02:QXD0ShN508^3P023NGL0R7ei09:7P@26O7<0PWQ_08=iL01kLFL0OWI[07aeJ`22Ng40QWmg
08=lM024OGD0PWic08J2M`27PgP0PGeb08F1M@29QGT0SXMm09><PP2;QGT0PWa`08EoL`25OG80P7Q[
08j6N@2<Q7L0RX=c09ZCP@2WWXd0W9F205eFA01FDCh0Mg5S0:VUV@3;bKd0X9fD07AdK01fMG00N7Mb
06i]J024P7d0PG]k07I]KP1nM7T0S86708b1R@1kL7P0?c@l03`a>@17?T<00P11>3/01`12>CX0?STf
03hi=P0o>cP0AD4n04E4@011@3/00P12@C`00`10?cX0@D8m04E6@@020451?`0T04=3@`13@dD0AdE8
04I4B@17ADX0?Ca103<d>01<CE40FeaP04i?D`15ATP0AdM703lm?P0n?C/0FUYJ08n?T01]K740EeQM
04a?F011AE40A4YJ04I=H013Bf00A4aS04aCK@1=E700GFB007MlVP29SZ`0SiBd09BI^@2FVk/0Vijo
09ZM`02KWl<0Vio40P2KX<H209VQb00809VQaP2GXLD0U9k209FO``2BWl40TJ3109:O`@2CX<8309:O
`@0?096N`02@WKl0TIg0096K_`2>V;`0SiVm09>M`@2>Vkh0RiVl08ZH^`29UkX0QiNi08:E]@23U[H0
P9>c0080PIBb03L0OXn]07n?/01nS:l0Ohf`07n</01kQjd0O8R`07V7[P1jR:l0NHN^07b9/`1kR;80
NhJc07V4/@1gPZl0MH2]07In[01aNJL0LGVX06ifY@1]N:H0JgJT06YgY01ZMZD0IgFT06AeX@1SMZ40
HW>Q05i`WP1OLIl0GW2N05e`V`1NLI`0FVfG05I/U@1GKI@0E6bB05E]T@1BJX`0DFV;04mWR@1=I8H0
CfJ:04eSRP1?HXX0C5n704QKP`1:G8@0BE^104]MP`1=G8<0CUb104]IOP19EWT0BEEk0080B5Aj00h0
Ae=k04AAN`15DW`0A5=n045?NP11CWX0?dah03a7M00mAG<0?dIb0418K`0mAFT0?49T03]0H0Wooooo
0007ooooo`0Z06aaJ024R7l0KFmW05iQE`1NH5L0KFmW08B4OP26QX40R8R408V:Q@2KW9P0[:fW0;:d
[P37al80Z:RR0820NP1mOGL0M7E^065RF`1JFeD0HF9L069SG`1UIF80IFMS06a^J@1YKFL0If]U06]_
I`1OI5T0H6=G05QJCP1PHUH0LWAW071aI01cLVL0NWU^07QhK01`Kf@0IVMI059DA@0n@380<cDV0P0Z
:ah0UP0e=2P0?S``03Xh:`0l>2/0?ST]048n;`1>Bc`0EeE405aJB01SHDl0K6YI06YWE`1YIUH0I5m?
065LC01WHE<0K6II06IOE01SFe80KVMO07mhL01oN740G5U@05MFB@1SHe@0KFiM079bH@1fMf<0LgIQ
07QjIP1oPG00QHIf06a^G`1JG4h0Fea@04e=@`15ACd0AdU104U9A@1>CT/0D51?05=BE01IEed0F5QM
069QJ@1_KGD0O7^108N5S02;RHh0RXN<08AoP`1oNg/0K6QV06ANF`1nMg@0Pgeg08=nM@20NW80Pgic
08N3MP22OW40O7M[085lL@29PgX0RH9i08R1N@25OgP0R89m08n9Q02:QX40U92:09:>Q`23OgP0N7A/
06YYG`1cLVH0Shb0092<O01lMfH0NgAP09ZCOP2VWHP0Zj:<0::IQ021NF@0CTHc04]4<@1RFdX0JVAD
08AoL@29QWX0Q81h07YfL@1nNWH0S8R30:bWY02NUYD0P7Mi08UnP`29OH<0NFec0596C00^8RL0@CHj
04Lm?P16?Cd0B3lm04M1?011?3L0@3`g04I3?@18AD00AdE004A3?P13@Sh0@3ll0450?`11@D80@453
03dm@P0n@4@0ATI;04U:C`1;C540BDY?04m@E018BTh0=CPj04M<C@1LGf40Ee]M04mBDP1<Cdh0CDm?
04M9B@1ZKFd0OGn405AGG`14Ae<0Ad]K04A9G@16C6@0A4YV04M@K01?EG80HVZ807=iU`24RZT0Uibl
09ZN_P80VYfm0180VYjn09bP`02JW[h0WJ7309bR``2KXL<0VJ;309^SaP2IX/H0VZC809NQa@2IXlL0
Uj;609FQaP2FX/P0UJ7709BPaP2CX<D209:Pa@0J092Na02AWlD0T9k408fK`02>WL80Ri^n08bL_`29
VKd0R9Rl08RG^P28UkT0QYJh08>F]`23U[H0PYBe086B]022T[H0Ohnd07n=]@1oS;D0O8Za07f7/@1n
Q[<0OhVe07f8/@1mQk4207n9/`0D07b8/@1jQZh0NHF]07B1Y`1aOZD0L7jR06mlX@1aO:80KWbP06]i
W@1ZNId0JGRL06IfV`1UMIX0I7FM069eW@1RLY`0H76M05m`W@1MKi`205]]VP0A05QZU`1GJI@0EVRC
05AXT@1DJHl0D6N;059XR`1?IhP0D6F904iUQ`1:H8@0Bf:504UPQ019GH@0BUj304ULO`1:GGl00P1;
Fh004`1=Fh00BeMm04UDO018DW`0BU9l04MBO014CW/0@Tij041>NP11CWT0?def03i<MP0mBg<0?4Ma
03e8K`0nBFd0?4IX03PoGP0d?ET02Oooool000Oooooo0=40I6aO061VFP1IG5<0FU]C05eNEP1KFUD0
MW9_08j:R@2=S8X0U9>B0<70_P3Kg=L0blc709:CS@1UIUh0D59705iPE@1QHEL0G5iC05UJDP1OH5P0
IFIP06IWH@1VJF80IfUT06I[I`1ZKf/0Jg1/07AiM01ZKfT0Gf5L05EHD@1GF580G5]F05aIE01UHUd0
JFIO06ISG00o?3<0<RlV03Tf;@15@ST0?Cda03hn<P17ACT0?C/^03Pf:@0j>2X0@Cl`04]<?01UIUH0
J6UG07=dHP1^KE/0HV5?06=QDP1TH5@0H5a@069NDP1RFe40HeaB06QOEP1PETd0G4m906MJE01[H5X0
G599044k;@1?BSL0EU4m04]6<01VHTT0L6iE079bF01iN6<0NWUW061NC`1EEDT0EeM?05=BC@18B4H0
BTY:04a;D01@Ce@0E5=I05EDG01QGfX0MG=n08F3SP27QXh0SHbD092=U02DTIP0THbB06=NHP19ADH0
D4Y:06USH`2DSh`0Y:2M09FBS@28Qh80YJJN0:j`Y@2?TH@0NW]]08:3M@29QgX0RHMk08V5O022OGL0
S8N309VDT@2NVIH0V9>@07]gM01?BdP0?C`g04U:@P1dMV/0ZZZN07EfIP1NGDT0VYN109NAN`2^Z980
^K>M09RAOP1[I580?CHT048k:@1AB3L0FE0o07M_HP27Og@0Rh9k08b3OP2RVYL0[:BR0:BKW02;PXD0
PWan08j6R@1lLgH0E4]>024H6`0W7Ql0=S0`03dh=@15@3`0BDHo04Q5?013@3L0@d<i04U6?@17A3/0
B4Dn04A1>P10?cX0@d8n04E3A010@4<0?d1503loA`15ADd0CTiF04m?E`1BEEX0K6md07EiO01IGF00
?d=4055EEP1[L7<0GV=V03Pm@01RIfX0OhB806I^L@1MIFP0ADaD04A:F017CUh0AdiQ04M=I@1:D6X0
CE9_05eRP01fNi/0T9Fe09NK_P2FV[d0W9o209^N_`2LWl00X:?209fR`P2KX;h0W:7109bR`@2JXl80
VjC309ZU``2KY/H0VZC709^Ub02LY/X0V:G809JRb00209RTc080UJ7;00<0U:7;09:Qc02BWl/00P2?
W/T02P2<WLP0QiW108RJ`P26V;h0QiW108NI_`26V;h0R9Rl08JF^P25UKT208BD^00j08BC^P22TKX0
P8nj082>^`22S[h0Oh^k07j;^01nR[L0OhNf07n7]@1nQ[@0P8Vd07j7/01lQJh0N8BZ07V6Z@1ePZD0
LX6R0760X@1_OYd0KGbK06mnW@1/OI/0JgbJ06MjV01UN9H0IGJF06=cU01PLi@0HWBH069aV01OKYL0
GVnJ05e^VP1HJIL0EVNE05QYU`1GJYD0EFJB05EXTP1AI8`0DFF:059VR@1CIhX0DFF804aQQ019H880
BF6304QPPP19Gh@0Ben204YNO`19G7d0BUYl04QHO01<FWl0BeMm04QANP80BU5k00<0ADig04A=N013
CgT00P0oCG@02@0lC700?De_03e=K`0kBV/0>TUZ03]8J00jAF<0=d1M03M1G009ooooo`001oooool0
1`1@ETP0F5i@05iQEP1QHeP0I6AL065NF@1cKf`00P2BSX/08P2ZYZ@0e=??0<70^`2FUXh0Jf]Q06=S
F@1JFTh0FEU=05MDB`1DE4X0FUYB069RFP1PGeX0HfAO06MYI01SIF80JV]]075bM01_LgH0NGf006M[
KP1UJFX0JFY/05UKFP1PH5h0I6AR06YYI@1QH5/0E5A<038b:00`<2H0@Che04m=@@1=CD4204U:?02C
0452<P0l?Bd0?Sl^04]<?01HFdX0JfiM06Y]G01VJEH0HV=A05eNC01OH500Hf5D061NC`1RH540H5a@
061IC`1SFU40IeaF05U<AP1CAT00IEQB06YPG012>C80HEU>06UQE01HDD40FeA2079[F@1jLf40M6eM
06aTF@1PFDl0ETm90518A@1<ATH0C4Q904i9C@1ED5H0FUEL05MDG@1OGVH0L6mg07elPP23PXL0Rh^=
08j>SP2AT8h0VIRF09jJU`1kMW<0Ad8o04m7A@26OGh0WYFF0:RRY02FU9D0SXj>0;^m^P3=e<d0/KV^
075gJ@1lPg<0RHen08b>P@29RGd0PX9h08N4O@2FThh0V9BA08Z6Q@1`K6/0BdM603Pg<`16Ad40MGI^
0822M`1GEd/0LW1S09jKS02GTH<0UY220:BNT02HTX@0NG=U051:?018@3<0DDLk05U?@`1gKF@0PWMa
0;6SX02YVi/0U8R:09J;S`2IT9D0SXR<08Z5R@23Oh00HemN03`k>@0M71P0<S4/03Tj=00n?cL0@48g
04E5>@11@CD0@T<e0453=@15ASP0AdPj04A5=`15ACT0B4Hj04Y7?P19AT40?chl04A2A@14@TL0BDQ=
04m<D`1GE5/0KFad09RGW@2EUYX0J6U]03dn@P1MGV80Oh:7079gN`19CU80IVia08:9S`1MIV/0AE1D
04==E@17DEd0ATmN04M?HP1;DfP0CeM^06=ZQP1oQZ<0TiRh09ZN`@2KWL<0VYc20080W:3500/0WJ74
09jS``2NX/D0WZ?309fSa@2KY<@0VZ?409RQ`P2IXlH0VZC709NTa`0209RUb00H09NSb@2GXl/0UZ;:
09JRc02GX/l0V:?@09BOc02BWl`0U9o=096Nb`2@W//0SYg808ZIa029V<<0RYW208ZIa027U[l0QYFn
08ND_P29UKl0QY:l08>@^P23T;`0Q96n0P20SKX04P21SKd0P8bl082<_01mR[L0OHVg07n:^023S[/0
PHbi07n;]@1hQ:`0MX:Z07R4ZP1fPjH0M8:U07:1XP1_OYl0KWfN06]jV`80JWZK00/0K7bN06MjV`1T
MiP0HWJF061cU01QLI<0Hg>G05m^U@1NKIH0GVfH05e[V00205UZUP0V05AWTP1EJi@0EFR@05AZS`1A
J8X0D6B5055VQ@1BIHD0D6B504iRP`1;HX80BV6104QOP@1;Gh@0C62304aOP01:GGh0BUYl04UIN`1;
FG`0BEIi04QBMP1:E7P0BE=g04MAM@16CgH0@Dec049@M@10Cg<0>d]_03a<KP0kBfd0>DQY03]8JP0l
AfL0?4MS03M1G00h?eT9ooooo`001oooool05`1DG4l0Ff5E06Q[H01bM6T0LW9X06YWH01mNWD0UI:=
09nLU`3@blP0d<_709BARP1VHe`0GU]B05aID01KF4l0GU]D05ICC01FEE00GEaG065PG01NGU`0I6AR
0080IVQW01h0IVM[075bM`1eN7d0M7Mn06]^L`1/Kg@0Jfmb06MXJP1]Kfh0JfaW05mPFP10@3P0<30V
03Lg;@0n?S80Cde105]LCP1JFdd0Ce9104Q9>@13ASD0A4Dc04Q9=`1LGD/0LGAS071cHP1RIE@0HFAC
069SD`1NGdl205eMD@2<05iOD@1PHE<0H5iB05iJC`1QFU80IUeF065FD010<bd0C3hk07]`K@1?A400
Jf1J06eSFP1CBD00Fe5707ecJ@1dJV00JEaD06IID`1LDDd0B3hl04To?P1;@T<0CTQ:055;C`1GD5L0
FE9I05]FG@1fLgX0PX6608N7R@2=SH/0TI6?096BS@2@ShX0UYJ>0:FRV`2ASXL0F5=?04<n>`1fKFh0
SHN90:bW[@2QWj@0WijS0;Nk_02j`;h0eMgG079jK`1hP7<0S9:408fAP`2;SH80Ph=i08Z:PP2BShX0
T8b907eiN01JEUD0C4Q704i=B@1FEE00KVeX061OFP1MFU<0UY><09ZFS@2ASH@0S8Qo08^7O02>RWl0
OWY_04U2>01BC400E4a104Pn=@1eJ680XYBC0;:TY02IRXl0TXF<09J;T`2DRY80TXb@08b:S@1aLG00
>SXh02`]:00`<b`0>3/d03Hl<P0i?cD0?3ld03/o<@0j?S00>cl`0414=@16B3X0A4Hh04=4=P15ASP0
BDLj04U7>`1:Ach0BTE1055;B`1<ATP0Dde?06YTJ01dKG@0RX>:09NBV029Qh`0M79e065OI01hMg`0
RHZ?07j1QP1/LGL0LWUo06I_MP0mB4h0ADmH049>F@18E680B5AT04IBHP1BFVl0K7B;08fD/02BVKH0
V9bo09^Oa02KWlD0WJ7709nSb@2OY<X0X:C90:6Wb@2PY<L20:2Vb00509jVb@2LY<P0W:C909^Ub@2M
Yl/00P2KY</0202HY<X0V:C<09RTcP2GXld0Tik;09FPc@2FXLl0Tik<0P2CWLh209:NcP0h08nMbP2=
VlP0SI[608bIa@2;V<@0R9G108JC_`27U;h0Qi>m08FA^`22Sk/0Pi2m086>^`1oRk/0PHfm082<_01n
R[X0Ohbi07f:]`1mRKL0OHRe07n:]`1lR;80NXJ^07R4[01hQ:X0MX:X07B2Y`1bP:<0Lh6T071nX@1]
Nih0JWRM06UgW01[Nil0J7NN06EgW@1SMIT0HgJI061bUP1QM9D0HG6C05m_T`1OKYD0GfjG05a[UP1I
JYD0EfRC05MZTP1EJi80EF^@05A[S@1>IHD0C6>204mTP@1AI88204mTP`0=04]PO`1:Ggh0Ben004YN
P@1:G800Beio04ULO@19FG/0BUYl04]JN`1=G7d0AeAf04QBM@0204ICMP0=04EBM@0oCG80@4ic041>
M00lC700?Dea03];K`0jAfX0>dEY03Y4I`0lAF@0=ciK03HmF@09ooooo`001oooool0UP1EGeL0G6=L
06ecJ@1cMFX0KfmU079_IP28QG`0X9^E0;bg/@3CblP0UHf:07eeLP1bJVL0LFUW05UDD@1DD4d0GEUF
05mMGP1LFU/0GUaM05mOH@1PHF<0HV=W065UIP1SIfX0JFe`07=fN`1^LGH0Jfic06Y^L@1]KW00L79a
075cL01fN7<0LW=[05aND`10@SL0=CLZ0494=`1:C3l0EEE9065RE01QHeD0EEU804iA@01=DSh0C4ll
055C@01aLV00Kg1N06QYF@1SI5@0I6EG06QVFP1THUH0H5eF065NE`1NGUH0F5Q@07MdK@21O7H0LFYT
061GDP1LDdh0B3di03hc;`1fJfP0D4910594@@1[GEX0H55>05E5A@1QDe80FTa;05a<C@1RE5@0DDE5
048h=`17?Ch0CDA504e7A`1DCU00EDmA05eGF`1_Jf`0PX2108V8QP2<SHP0TI:<092AR`2@THT0Si66
09:DR@2GUhd0PX9j05iMF01RHEd0N7Ac08f9RP2KVIh0WibS0:NV[02i^[l0cM7D0>;Vi@2FViD0M7Ub
08nBR@2MX9L0V9VA08N7O`25QGd0S8V4096>R@1gM6l0BdQ304m<A`1SGUX0IV5M06=NFP1ECD/0O7Ab
09bDTP2;Ph40S8B108V4OP26PgX0S8Qo08J2M`1TH5D0I5eC06=JD@1ICTP0LFIT08IjO02=P8L0RWn7
08f3R`2<QH`0RhJ<08^9S028R8X0Gf5O04iCC`0m@S`0=C`d03Po=`0h@3D0>D4f03]1=`<0>Clc02`0
?T@h04I:?017BC`0ADDi04=3=`19Ac/0BdTm04Y6>`1?Ad40G55=05Q=B`1MDE40Nfm_08j4Q@2<PX<0
QGam07]bM@1eKg40NgEi085lPP2>Ri80UiNO08f@V@1VKGL0AdmJ041:EP16D5`0@e1M04YHI@19EVH0
Ce][06]cR025SJ@0Uifg09VN_02KWl80Wj?809bPaP2OY<X0X:G;09jVb`2OYLT0WjO;0:6Wb`80X:K:
02/0WjG:09fRb02OY<`0WjC<0:2Uc@2NYLl0W:??09^Tc`2IX/d0WJGC09RSd02EX<h0UZ7?09JPd@2C
Wll0U:3B09BPe02CWm<0TioA096Mc`2=VLT0SI_808VH``2;V<@0RIK008RG`026UKh0QI>j08>B^@23
T[/0Q9>n082>^`1nS;T0OH^h07j<^@1oSKX0OXbi082>^`22S[X0OXZd07b8/01jR:l0MhFZ0080MXBY
01L0MH>X07B0YP1cOjD0LX2U071nX`1aOJD0JWNQ06ejY01XMJ40JgRT06MfX@1TMYh0IGNM061bV01O
LID0G6n@05e_T`1LKY80GfjE05e/T`1HJY00FF^A05M[T00205Q/S`0H05AXR@1@IhL0CfJ5059WQ01A
IX<0D6>1055TPP1=H7h0Beil04YMO@19G7`0B5]k04YMO@19G7`0BUYk04UINP1:FW`0BUQk04QEN017
E7L0A59g04ECN014DWT0@4ie0P0oC7H02@0mBW@0?4Uc03e9L@0mAW40?DA^03]3JP0lA6P0>3aO03Hk
F`09ooooo`001oooool09P1KIV00G6IN06U_I@1/KV<0L71T08J4N02LV8l0`;^e0>OPfP2^YZ<0MVi/
08n6Q`21N7T0MFm_069LGP1GDe@0GE]N05eKH01EE5X0F5MM05]LH@1OHVL0HFAY05mRI`1QIVX0J6]`
06U^LP1XK6l0If]^06U]KP1/L6l0LgEb07AfL@1dMg00Kg9W06EWFP1>D4<0BT`o0P1DETT0K01KG4h0
H65C05]NC@1JGTd0EEY6055F@P1HGDT0FE]906EWDP1RHe40HfAB06QVE`1XIUT0JfUL06MWF`1THEP0
EUI<04m?A@1_KfD0Xj>I0;FbZ@2?Rh80H5aC04m8@01ABT80ASdf069HE00n<c40B3Xj07U[J`1GAdX0
=bLZ04<d>@1>@TH0ETM>05I9D01;?d<0BCi204a2@`1?ATL0DdY=059<CP1FCE00Lfe_08N1P`2<QhH0
SXZ7096@R`2DThh0TI6908n?Q@2>SX@0SHf308f=Q@1`LFT0HV=M079cKP1eLg@0OG]n09NEVP2l^L00
a/G;0>?Rj03Xin`0gMcN0;2_[@1oOW`0ZZVU0;bi]02OW9L0RHIo08F2O@2=RXD0Sh^807QeL00n>cH0
HeiK07E`K@1aJFL0HeYK075VJP2:Oh<0Rh2408IlO@29PGl0QX5m08N2O02<R7l0RhMl07YfJ`1_Jf00
IeiE06MNE`1_IF<0PGQi08V0Q@29PXT0RHB:08Z5R@28QXT0R8R807MiN01LGed0G65M0497@@0f?CD0
?4<k03e4?080?T@j02L0>d4g03a2>010AS`0@DLk04A:?P14B3X0@D<e04Q9>`1>Cd40D4i104M3=`1C
BT40Fe1:05e?C01WFEH0QWQg09:6QP29OGd0NFm`07M/L01fKG80L6U`07iiP02MVZ<0XInZ07=ePP1;
CUd0Be5Q04U@HP18DF80Ae=S051KK@19E6H0GVUm08jF[@2FW;H0VIjk09jS`@2PY<L00P2NX/L00`2R
Yld0Y:W?0:2Xc00309nWb`040:2Xc02RZ<`0X:K<0:2Uc@<0X:G?01h0WZG?09jUd@2LYM00W:G@09^W
d@2IY=40Uj;?09NRd02FXLl0UZ;B09>Od@2CWm<0TYkB09BNd`2AW=00Si_=08fIb@2;V<D0RYO308ZG
`@28UKl0QIBm08JD^`25U;/0Q9>l08>B_@22T;d0Ohfj07j<^@1oSKX207j<^@0;086?_01oRkL0O8Rb
07Z8[`1gQJ`0MH>Z07N5[01fQ:/0Lh6X07=oY`1cPJP00P1_OJ@06`1^NZ@0KGVS06aiY@1YMZ80IgBP
06EdW`1SMId0HgFL05mcV01MLI@0G72C05eaU01KKI40G6jB05U[S`1GJHd0FVb@05M[SP1FJXd0Ef^<
05EYRP1AJ8L0D6N605AYQP1@IH80DFF0055SP002055RP0<0CEil00H0C5am04]NOP1;Fg`0BEUk04QH
NP17EgT204IDN@07049AN015E7/0A55k03i;M@10CGT0@4ah03i9MP0203i7LP0603i5L`0mA700?4=]
03e2J00k?f@0>SeP2Oooool000Oooooo01H0F6AH05MRE01SJE/0JVaO0861M@2=RX40ZjJP0=oJeP36
`Kh0Pgen08^5Q`22OWl0LFe^07EcM01XIVT0H5mT05mPI01CE5T0EUUP05iQJ01MH6L0HfQ^0P1UJW00
4P1TK6l0IFY^05iVJ01UJf/0IFe/06U_K@1`MW80M7Uc079gL01_MF/0I6YL06M[G01SIEL0EUQ:05UK
C@1KGDl0Fe]?05]LCP80FUe<05L0F5]:05QKB01WJUL0HfE@055@>`1CDSh0H5m;06]ZEP1ZJEL0IVME
06=VD`1OH4h0CU4n04I9>01dMfH0ZJbI0;g0[@2i^ZX0RX]k0493=@1;BC`0EE5605==A@14>SP0A3Xk
04]0A00m<3L0>2/d04<g@@1=@D/0BCm:04ToB01;@DT0CT=904a1A@1DBDd0EDY@061GG01iKW@0Qgj3
08^2Q@2AR8T0U8b:09VDT02GTXh0Thj:09>>R02CT8T0QH9k07QeL01eM700M7=_07]jN01lO7`0KVi`
08R7S02g][/0dLoB0>;Ph`3Sgn00iMgO0<:h^@2TV9X0cL730<2f]@2HSXd0SHF208=kN027PH40RhF5
07QdL`1OFeX0OGMi07YdN01YH6D0KFAY08=hP02:OhL0R7f308QnP02:P7l0Rh>008R1N@2:PgT0T8Yn
08R4N01oNfl00P1aKF40>020OG@0QX=l08Z6P`2:RHL0S8b:08V9Q`25Qh@0TYBA0866PP1RIf<0E5UE
0456@012A3l0ATU204A5?`0o@ST0@TDl04A7?P12AC`0ATTn0457>`12B3X0@4Lg0455=01>Dcl0F5]8
055B@012@c<0CTXl05Q?AP1EBT@0LfQV0924Q02BQXP0QGUm07Y_M@1gK7@0LfUb079ZM@20NXH0Pgn=
06ITLP1EE680E5IU05EHJ`1=DVH0CE9X04iDJ`1HGgT0JW2:08R>Z02DVKH0V9fj09bQ_`2MX/80WjC4
0P2RY/T0<P2SYl`0XjW=0:6Wb`2QZLd0XZ_<0:2YbP2PZ<`0XZS<0::Wc@2RYll0X:G=09jVc@2OYlh0
W:G<09fVc`2JY/h0VjO?09VWcP2HYLl0UZ?=09FQb`2GXld0U9o<09BOc@2EWm00UIoB09BKc`2BVlh0
SYS;08nIbP2=V<H0S9C208fE``28U;h0QI:l08JB_026Tkd0QI:l08BA_@24TKh0Ohbi086?_020S[/0
PHfm086>^`22Sk`0Ohbi07V6/P1hQK40MXF^0P1fPjd0=P1bPJX0L7nX079oZ@1bOjT0KWbS06ajX@1^
NZ@0K7RR06YgX@1XMj00Hg:K06AcVP1SMI/0HGBI05ieU`1LLYL0Fg6F05Q^T`1JKY<0G72E05Y^T`1H
K940Ef^@05M[SP1FJXd0EVZ;05EYRP1CJ8L0E6V805=VQP1CIX@0D6Ao055SO`1@HGd0D5ml051OOP1>
GG`0C5am04eMO`1:FW`0BEUk04QHNP15F7T0A5Af049BMP13DWT0@e9k049ANP12Cg/0@Dai045<NP11
BGP0@TYh0417L`80?dIb00D0@DI`03m4K00o@fP0?3mR03/nG`09ooooo`001oooool0:01@G4P0DU]8
06Y^G@1fN6X0OWa`0::OUP39a/40eM7>08F1P01fLgD0P7j105YJG01HFE/0IFIX06m`LP1XK6l0DUII
05AIG01QIVX0GfAX05iSJ@1XKG<0Jg1f06E/LP1WKg80HFU[061YJ01TKF`0I6eY06aeL01[MFd0KWE]
06YbI`1ZL6@0JG1P06M^G01LH4l0FEa;05mRD@1PHE<205aMC`0;05iOD@1MGU00H65C06EVF01/KEd0
KVeK05YIA@1EE400EEM2061OB`1PHTd00P1QI4l08P1OHd`0CE8k034f801?E3h0Qhae0;RmYP30`jh0
VIb904A7=P1?D400DU1304]8?@1>BDD0Bd=103<Z;@0h;c@0ASa404ToB01<@T/0Acm:04DnAP1=@d/0
DTU>0556C01DBDl0HUMO07aaN@27O8@0S86909>8SP2ISY80Uhf>0:JLV`2QUiD209>9Q`1O08V1OP1h
L6d0N71^07YeLP1hLW80NWIg08N5R01dLWD0OWb10;Ne^03/j^/0j>CS0>cViP3ainH0cKno0:RJVP2[
WId0U8J608f2P02<PX00PWYg08InO024OWh0PWal07eiN01lMWP0LF]_06iUJP29P8D0XYNO09nDVP2>
PhL0RX2108b2P@2>QH00RX5j08f4N`2<QG/0UI650:VUV@2<RWd0Lg=W07alLP24QGd0S8f708f?RP2?
TH`0P8Eo07f2OP2<THd0KgA`05iSG`1LGU/0BD]604Q9A017AT40AD@o0491?012@c/0ADDm0411>@10
@SL0?d8g04I:?013BSP0?DD`04iC?@1aM5l0KG1K05UJB019ASL0E4e305U@B`1lLW00SXB50966RP2>
PhT0Q7Z307U_NP1/I740IEm]069NK01LFVP0CdiN051?G`1BDfD0DeEZ051EJ`1=DFX0Ff5l07YoW@2?
U;80Vj2n09jS`@2OY<@00P2PYLD0102RYlL0XjO:0:6Ub02TZ</20:BZcP0?0::ZcP2T[=00Y:c@0:6Y
c@2TZLl0XZO>0::Wc`2OYlh0X:S?09fVc@2KY</0VZK<09^Wc@2HY/d0UjG<0080V:K=01L0UZC;09>P
bP2DWl`0U9o=09FOd02EWm80U9_?09>Jd02?VLh0SiW<08bFb@2=ULH0SIG408RC`@29U<80Qi;008FB
_`23T;d0Q96n08>?_`1nS;/0PHnn082>_@02086?_P07082<_01mR[T0MhFb07J4/@1eQ:l0Lh6^07B3
[P020760Z`0I07:1[01aP:/0KGbU06YiXP1^NjD0JgRR06MfW@1XMih0IGBK06=eV`1TMYX0H7BG05mc
V01LLYL0FW2G05U_UP1KLIP0F6jE05U_UP1GJY80FFbD05IZS`1EJHh0E6R;05=WR002055UQP80DfJ6
00T0DFB2055SO`1?H7`0D5ml04mNN`1>GGh0CE]n04eKP01:FWh00P19FGd04`16F7`0@eEi04=BN@14
Dg`0@e9k049AO012Cg/0@Dai045<NP10B7L0@DUg03i7LP0mAW40?DA^03m7KP11AV`0?d=V03]0H00k
?Ud02Oooool000Oooooo0580EUm405IKA020PVd0R8Ig07ekK`2ZYj00^kNd09BCT@1^KVh0LG9d071a
L`1:CTd0Be5?06AZJ01ZLg00HV]X059KEP1LIF00IFi[06A]K01VKW00K7Ag06Q`L`1SJfh0IFe_06=]
KP1UKfh0IW1_06=^I`1YMF/0HfmS069]G`1SKUh0IVmN06]dH`1XKed0H6AC069UDP1WJ5H0I69C05iL
C`1LFTd0HV1D06UWF`1/JF00LVmV06i/H01/JUh0JVQK05aMC@1@Dd00D54o05MJA`1IG4L0G65;05AI
@`1=ECh0>T8Z03a1:P1dNF<0YjZE0:V/U`28RgP0Ce10051>@@1=Bch0AD<h04]8@@1>BDD0AT4n04Q2
@P1;ADD0BD=5055;C@1ABdl0BdE905=:C`1GC580G4mF06ePI`1nLg/0S82:0P2@Phd0I`2HSID0Vi2F
09Z?T`2ZWZ00[:2P08UkN`1YFe/0OW1`09F7Q`29NWd0N6a^07Y_L`1fKG00MW1d09NBUP2d[k<0_[Vm
0=??d03Gdm80i=oL0>CKf030]K<0Rh1l07Y_J`29P7T0T8N008j7O`27P7P0PW]e085lMP25P7X0Qh9l
071[J01cKV/0ThZ;09jEUP2aYjP0[j>U09J:RP2>Ph40SH9n08j3O`2@QGl0THJ008n6O`2LUHd0/:bS
0:6NU`2?ShL0QXN108B7P02;SHP0TYNC092FTP1oQH40Mg]j06a`K`1DEUD0JVaZ05iNG01;C4L0BDY5
04U8A01:Ad80@d0k03dl=`13@3/0?Cde03Ti;`0k?C80@dDh04I:>`17BcX0B4di071cGP1iO6L0F5U7
04I6=P1ACD80G5MA07I^K01mM7L0Pgb309N@V02LUZ80QGn=061LJP1MFFL0E59O051?G@1<CUd0D55U
055CJ01BE6d0DUIa059GM01aN9D0Tibk09RQ`02HXl40VZ?209bUaP2NYlP00P2SZL/02@2TZ/h0XZS<
0:>Yc@2UZ]00Y:W?0:2Xc@2RZ]40YJ[B0:>XdP020:>Xd00:0::Wc`2KX/`0W:?=09fTcP2LYLh0VjO?
09ZVcP2FXld0UjC>09NVc`80U:?<00L0U:?>09:Ob`2BWl`0U:3B09:NdP2BVm80T9WA0080SIK?00X0
RiC=08ZCbP29T/T0R97808JBaP25TLD0Q93408FAa@22Sl<0PY310P20S[l02P1mSKh0O8bm07f=_P1l
R[/0N8Rg07B5/`1eQ[@0LX>_07:3/@1bPjl206enZP0^06n0[01`PJ`0JW^V06anYP1/Nj@0IgVQ06Ih
WP1UMid0HgFM06EgW@1RM9P0H7>G05e_U`1LKiL0FfjH05e`V`1IK9L0FVfH05U/U`1IJiT0EfZE05=Y
TP1CIY00DVF=05=UR`1AHhT0Cf6505=VQ`1BIHD0DV>1051QO@1>Gg/0CUih04eLN@1>Fgd0CE]n04aJ
O`19Eg`0AeMk04QHO013EGT0A5Il04ACNP12DGX0@e9k045>N080@4ei00/0?dah03i9MP0lB780>dMa
03Y6KP0g@fT0>DIY03Y4I`0mAVD0?45O03TnF`09ooooo`001oooool0O@1XKU80K71G08F7LP27QGH0
Q89f08j>QP2;RXH0IfMU06=UI01QIFH0JVi_05QNG01JHf00HfaY065/J01QK6H0IG1X06IaJ`1UL6X0
HfiX06MbKP1[M7<0Jg=e06QaL01UKVd0IVm^06QbL@1WLVh0Ig5Z06A^I@1TKV<0HfiP06E]GP1WL5l0
JG1N06U]G01VJEH0JfaJ06e/FP1XIE@0IEmA06EOD`1]IU`0L6UQ06mXH01_Jf80KFUP06i[HP1ZJV00
K6iQ061RE01ADdD0Bdm005IJB@1CF4@0BU8m04UA?014C3L0@TXc06Q]F@24RGD0QhYg079eHP1MGTh0
AdPj04A5=`19BCh0CDe3059?BP1GEU40G5QE05MCDP1EDE00E51?05A@D@1ECe40Dde?06ELG`1]HVP0
O75g08AjPP2;PHT0TXJ@09>8T02ISY@0Vi2D09bBT`2HS8`0XI>C07Y/J`1GBDP0PG=b08n1P02BQ8@0
QWYj07idM@2:PH80PG]k0;B^[P31_K`0/:b[0<Bo_03Ed<`0e/k;0=S@b`2XWIT0O75[08EjM02AQX00
U8^20968O`2<PgX0QWef08MnM`26OgD0QGid07I_J@1hLF/0XYRF0=?9a`2n/k40XYBA08n1OP2@PWd0
ThAo0080Sh1m03L0UHN40:NLV02XWiX0XYfI09bIU02ZZJD0UiRC08J8P`25Qh@0Qhb808bBSP1bN7@0
J6eY06AXI`1IFeX0HfES04mACP14AT40ATM204U:A@1;BTH0@T4l03hm>012@C`0@D4i03hn=P0o@CH0
@T@g04=5>01;Cch0CE5005IIAP1GFTL0CE0o04i?@01DDTH0JVMR07QcL021Ngd0S8N=09bFX026Phh0
GUYX05ABG`1IEf@0DU5O04i@G`1>DF80CU5T055FJP1DF740HfV307EjU`2CVKP0X:W:00@0X:_;00L0
Y:g>0::[c02T[=00YJgA0:F[c`2SZll0YZc@0080Xj_@0180Y:cC0::Yd`2RZM<0XZ[A0:2Xc`2NY/d0
WZG?09jWd02JXl`0VjC?09VUc`2HY<h0UZ??09JSc@2GY<h0U:?<096NbP2CX/d209>Pc@09092LcP2A
WM40TIcB096KdP2?V]80SYWA08bGc`2:ULd0QI380080QY?:00L0Q97808BAaP23T<D0PXo308>@a01n
S;d0OXjo0080O8bm00P0Nhbj07R8^@1fQ[L0MHFf07N8]P1fQkD0M8:a0762/0<0KWn[00H0JW^V06Yi
Y01YNZD0K7^T06UkX`1VN:02069dW00706=eW@1QMIX0Gg:I05]/U`1KKYP0FfjI05QZV00205Y/VP06
05Y/W01HJYX0EVRH05AYUP1BII00DV>>0P1BI8`01@1BI8X0DVB805ATQP1BHX<0D65o00<0CUel00<0
CU]n04eKP01<FX400P17EWd01`14EW`0@eEk04EGO`11Dg/0@E1i041?N00oC7H00`0nBgD02P0lBG<0
>TQ_03a:L@0hAV/0>DMZ03M4IP0jAF<0>D9O03U0G00i?eT9ooooo`001oooool0601fOVL0NGiZ07Mj
J@1nP7<0QHIn08N8PP25QX40I6AR05]MG01KGUh0HVIW05mSHP1PIV@0HfUY065ZI`1RJfP0IFiY06I_
K01ZLfh0JWE_06]fL01WL6/0K7E`06mhM@<0JgAa02`0JW=^06YbK01UK6@0JG1X06Q_I`1YKf<0K71R
06U[G@1ZJe/0K6]I06eZE`1^JEH0JfIC06=LBP1KE4@0N71S08=kL01dJf80KVMO06eYH01`KFD0L71X
06]]HP1WJUl0I6MN05]QE@1BF4`0A4Xl03i4=P0oASH0@T/j04=:>P1IH500IVeM06AXE`1KGdh0D5A5
03m1<`15AcX0BTa004Y<@@1FEE00IFIQ06MVI080GE]L06l0EUAE05ECE01BD540FeUJ079`L@1nNW/0
PWio08Z4R02=Qh/0TXV>09J=T02IT940VI6?09>9Q`23NWD0Q7Uc085fL01NDdd0IEaE06YQFP1nMg40
T8V309>>R02VXi`0VIJ?0;Vf[`2j]Jl0YJ2J0;2YX@38`KT0d/W20;Z^Z02UV980LFAN08=dK`2DQH00
UhR309B7P@2AQ7h0SX1m08j1N`2=P7P0QgYb081cJ`1oLVX0]JRP0=kAb@2TUHh0TX=l09B3O02GQGh0
UX=o08mkNP2KQhH0^JNU0<o1_P31][@0YYbK0:BLVP2^Z:P0VIFD08N6Q027QhD0Oh5n07f2O01iOWP0
KG9/069WH`1PIF40Ff1L03i3?`0d>CD0>Chj03m4@013B480@TDn0454?@16Ad40AdQ00493>`11@cP0
@dDj0494=`16BS`0D5A505QLC@1EFDX0BTho05IHB`1PH5H0K6aT081mN02BSXd0UI6B08J1Q`1UHVT0
AdE@04m?F`1BE600CU9N04a?GP1:D600CE9U05]PM01UJH80Nh6K09>H]@2PY<H0X:K:0:BZcP2SZll0
0P2T[Lh01`2U/=00Y[7A0:F`d02U/=00YZo@0:F`d02U[/l00`2U[m801@2S[M40XJ_?0:6[c`2OZLh0
W:S@00<0W:SB00d0VZGB09VTd@2KY]<0VZGC09RSd02JYM80UjC@09FPc@2DXLd0Uj;?09BOc@2BW<d0
TI_>0080Si_=00P0SY[<08nKc`29U/X0QiC908JCb022T/H0PY?708>Ca`80PY;600T0PI7407j>`@1o
Sl00OHfn07j?_@1mRkX0NXRe07V7]P1gQKD00P1gQKH04P1dP[<0M82b07=o[`1bOj`0LGj[071mZ@1]
O:L0KW^W06akY01[N:80JgZS06MfW`1UMZ40HgBO06AeX01PLi/0GW6K05e`V`80FVnL02`0EV^J05U[
V`1JK9`0FVbN05QZW01FJ9X0EfVI05EWU@1BHi40DF:>05ASS01DHhX0DV6805ARQ`1DHXD0Df64055N
P@1@GH00DEf304iLP`1;FH00BeR204MFO`15Egl0@eIn04AGO`12EGd0@EAl041BNP0mCgL0?dig03e<
M@0mC7<0?4]b03e<L`0mBg00?de`03]:J`0iAVP0?4MW03]6HP0i@eh0>3mI03HlEPWooooo0007oooo
o`1R075eI01eNFP0LG=U07EgK021PWX0PhAn08B5P01jNgH0KFe[06]]J`1YKF`0I6QW061TH`1OIF<0
H6IT065ZI`1QJVD0IVm/06aeL01[M6l0KGM_06YdK01[LV/0KgI_06idL01aMW80LgQd06idL01]Lfh0
JfeX06i`J`1^LFX0KG1W06maIP1_L680LFmP06aYF01YIUD0JVAD06]UE@1PFTX0CdLj06EMDP2BRH00
NW=Y06=OEP1UHUT0JFUP06m_I`1_L6P0IFQO069UG01TIeh0EeY?03e0=@0l?c@0?D4c03e3=@0k@C<0
B4`n05EIBP1<D440?40a03Pl;@0n@S<0Ce53055CAP1<CT<0G5eE06EVH@1/K6X0L79a07AfM@1ZJfd0
FeaN05iOH@1ZJfd0NGYl0862Q027RHP0RHV908N7Q@2<RhT0Shj:09BAS02?Rh@0NGE/06iWG`1fKfL0
Mg1X05eID01EDDP0C4U006=PE`2;Rh40XjFJ0:naYP2DU8X209JFS00^09>AQ@2YYIX0ZZ>I0:fTV`2@
QWh0MfYT07]^J029NWD0TX>009J7Q02BPgh0TH9m08n1OP2@Pgd0Sh9j08]nMP23MVd0OG1W0:6DR`2a
Y9/0UHMn09>5O02KRX<0UhEo08ahM`2FPX<0[IVJ0=;0`03Lc<d0b;bl0:JLW@2VWIh0[:JV09RDT`2=
RHP0R8N507MhL`1bM6l0MW]d07MlMP1`MFl0JFiX05aRF`18CdP0=C/g03To>`80@TQ402L0@TM10415
?`13ASl0B4]40495?00i?340?T0e0494>@15AcX0CU1305YLD@1UIe`0J6YO06EVG@1`L6P0NgYe09BC
SP2CTY00LW1a06ITJ@1GEU`0CTiH055CG`1CEf<0D5IV04mFJ01AF6/0E5]^06Y`QP24RZ80Vj2m0::W
a@2SZ<X0YJW>0:R^dP2UZll0Y:c@0:F^c`2V/M400P2T[ll0202U/=00Xjk>0:F`d02V/M40Y[3C0:>]
d02V/=<0YJoC0P2S[M404@2PZm00W:S@09ZVcP2KYm40VZK@09RSd02JYM80VZGC09VTdP2HXm40V:?@
09NRc`2EX<d0UZ7>09BOc02CX<d0Tik<0080T9c<00<0SIW908bJb@2;VLP00P27ULH00`24U<L0PYC6
07fAa002082Aa@0^082Ba01oTL<0O8bm07j>_`1kRk`0O8fk07Z8]`1kRKH0N8Jc07N5]01fQ;D0MH>d
07B2/`1cOk40Lgn_075nZ`1`OJX0L7fY06mnZ@1^NjL0K7^T06]jY@1YN:<0J7NR06MhX`1SM9l0I7FP
065dWP1OLY`0GW6L05U^V`1JKi`0EV^H05QZV01GJIT0F6ZJ05QZW01FJ9P0E6JF05EWU@1CI980EFJB
05ETS@1CHXT0DV2705=QQP80DEn400<0DEf304iJPP1AGHD00P1>FhD01@1<FHD0B5N204EFP@15EX40
AUN20080@UAl0100@E=k03e?M`0nD7H0?die03e<L`0lC700?Da`03a:K`0lBVd0?4]/03U6J00kBFH0
?4MS03M1FP0f?EL0=ceE2Oooool000Oooooo00H0MgU[07QiJ`1eMFT0KfmU0820N021PGT208F5O@0<
07]kL`1gN7<0Kg5/06]]J01SJ6@0G69N05YPG01OIF40HVUR069[IP1ZM6`0JgE]0P1/Lf`0E01[L6T0
K75Z06Y_J@1`LVd0N7Ye07MiMP1dMG<0KVmZ071aK01_L6/0L75[075aJ@1bLVP0KFeQ06]YG01]Jeh0
KVmQ05=CA`1:BSh0AT<j04A1>P23P7T0SX^405mLE@1EEDd0Hf=J06MWG@1^KV@0JFUO061PEP1GEd/0
Ce530412=011@S@0?d0b03dn<00n?c40@Clb04A2=@1:Bcd0?Ch^02HW5`0/;ah0BT/k05=DA@1DE4P0
I6EM06i_JP1jO7/0Q8R90:>YZ@2SZ:/0MWj006UaM01dO7l0P8R;08F=S`2;U9<0MGii065[H`1mQ7`0
SYB:092CR01jNg00GEeC06][H@1gMfl0JFQS04U:A015ASh0EeYA07AgKP2;SXD0XZRN0:jdZP27RX40
Q8Ml08:5NP20PgP0Z:RL0:ZZWP2DTXH0If5G06QOEP80O79Y02@0QGIa08]lM`2@PG`0U8N108j3O@2?
Q7h0SHAk08V0M`26O7<0Ng5X089hK`2JT8L0UhZ209>6OP2GR8<0UhN5089bL`2<O7d0[9bO0;f^/@34
^;`0a[Zn0:ZPX@2ZXJ80ZjFU09>?S028Q840OWei07IgL@1^LFX0KG1W07EjL`1eNg40KG=Y061VG@1B
FE420417@00904E:AP1=DTh0DeQD0497@`0n@3/0@D@m04A5?@0i>S80>c/a0080ATHl01d0BdPo05IC
C01[IV00NGI_07EaK@1fLVl0PX5m09ZIU`2;Rh/0E5EG04e>DP1?DUT0CDmK04mCG`1AF6P0CUIY05=K
L01NIWd0J6n90827X`2GW[/0WZG20:2VaP2UZ/d0YJW?0:BZcP2UZll0YZkB0:F]d@020:J`d`0<0:F_
dP2T[]40Xjg@0::/c`2V/=<0YJoC0::/d02T[]80XZ[A0:F]e02W[mH0XZ[C0P2PZM8209fVc`0709^T
c`2MY]40W:CB09^Sd@2JX]00V:?@09NRc`0209FRc`0?09BQcP2AWl`0T9g:08nMbP2@W//0SI_808VJ
aP28VLD0QiS608JGa@25ULH0PYC407nA``21TL@0P9330080Oi7300H0OHg007b<_`1jS;h0NH^k07Z:
^`1hRKL207J7]@80LhBb01P0LX>a07>1/01bP:l0LGn/071nZ`1^O:T0JW^W06ilZ@1/OJP0JGZV06Mh
Y01XNJD0IWVT06=fX@1PLih0HGBN061bW@1PLid0FFbF05Y]U`1IK9L0FFZF05MXU01IJYH205MXU007
05IWT`1CI8l0DfB?055SR`1CIH/0D6:6059RQP03051PQ00L04iLP`1=FX@0CU^504mKQ@1>FhD0C5V3
04QEO`17E7h0AU=m04UFP016E7/0@e9i04EDN`11D7L0@4mf03m=M00nC7<0?4a`03];L00lC700>DU[
03Q8J@0hAfP0>DQW03Q6H00hA5`0=3mE03HnD`Wooooo0007ooooo`0O06]/GP1aLV@0MgEX07AbIP24
PWH0Ph5e08Z8O02;RGd0QXAh08J5NP1lOGD0MWM_06iaJP1UJV<0GfAM069YH@1VKFD0HfeT06E_IP1Y
L6P0J6mW06I[I01SJ640HVMP06Q[I01]KfX0KVmZ075bK@1eMG80NGQd07IeL@0207AcKP0J07=cJ`1_
KfD0K6aP06]]G`1]Kf40LgEX05iQEP14ACd0@d@n04=4?`1PHE`0OWmj07YkMP1ZJfD0HF9L069RFP1W
Ied0HV9H05MEB@1;BC`0ATLi03ho;`14@S<0@d4d0490<`0n?2l203lk;`0c04I4=@1:B3T0>3TY03`m
:`19BSP0C4dn05EEB@1]KVH0MWUb08b>R`2WZjX0dmWI0<WAd`23Rhd0M7j007^4R@1mQX/0PXb>082:
R@1_NW@0BUE=06=]I02:TXL0N81e05iRE`1UJ5l0M7M^06EXG`1AETl0ADY304=9?`1^M6X0WZBJ0:2V
W02<TXP0RHn508Z=QP2<ShP0O7mh06iaJP2RXid0VIVA06i^IP1]JF80L6US07mhL01oMVl0NVm[08j3
O`2DRHD0T8N20080SHJ000L0RhJ008F1N025OWP0QGif07]dK02DRh@0UXf80080ThR403X0V8Z;09J7
S02ISI40_K6e0;Z_]@2aZ:d0/JR[0:^UY`2WXj80Wi^H09bHU@2GUY40L6mZ06IWG`1^LFP0K6mV06ab
J01_MFT0K79V05QND`1=E4`0Be1:04aAB`1?E500GV1M06IXI`1MGe`0ATQ50411>`13A3h0?Chf03hn
=01:BT00C4a204U6?`1ED4`0IV5M06m/I`1gLg40SXZ908>2P01eMGD0JFY/04mCEP1?DUL0E5UO055E
H@1AEfD0DEY[04aGJ`1KIW`0JG><08B>Z@2FWk`0WjS50:2Yb02TZ/X0YZ_?0P2W[M403@2X[]80YjoD
0:J^d`2U[m80YJoC0:J`e02U[m<0Y:kB0:>]d@2S[=<0XZ_B0:>/d`2S[=D00P2SZ]@03`2TZmL0Xj[F
0:>ZeP2RZM<0WjK@09jWdP2MY]40WJGC09^Vd`2IY=80Uj;@09JQc`2EX/l0Tj3=096Oc002092Nb`05
096Oc02<V/L0Sig:08bKb02:VlL00P28VLD02028VLL0PiC208FEaP23Tl@0P93307n?`P20T<<0Oho2
0P1kRkh0201jR[d0N8Zl07V9_01gRK/0M8Jf07F7]`1bQ;@0LX:c0P1bPk40201_P:h0KWn]06f0Z`1/
OJT0K7nZ06YkY`1/OjX0J7^V0P1UMjD0201WNJL0HWBR065dW`1QM9l0H7:M05m`V`1LKiL0GG2H0P1L
KYH01`1JK9@0FF^C05QZTP1HJY80EfVA05=US@1DIXh00P1BI8X3051RR00804eOP`1<GXD0C5^404eL
Q`1<FHD0BeR404eJQP1<FHD204UFP00704QDOP1:EWh0AUAk04ECNP15E7/0AeMk041@M00203e<L`04
03i>LP0kC740>Ta`03M:J`80=DQX00D0=TMU03E7G`0eA5/0=d9H03@oD`09ooooo`001oooool01`1X
JET0KF]L071]GP1gM6D0QhAe08>0K`2:Q7@00P2<QWH02@2@Rgh0RhUl08Z8N`1fMVX0LWAY06iaIP1[
LFL0JG5V06E_I00206=]HP0S065[HP1RJF40GVEM05iVF`1QIUl0IFMR06]/I`1]KVP0Lg5]07QdL@1k
NWH0NWUd075cJ01/KV40JVaN06U/F`1UJUH0MGUX07j2L`1dNV`0CU560415?P15BT@0BDi:06e_KP20
PX40PhF4075cL01MGUT0DU==04a=A@16AS`0?Sla04=4=P13A3@00P14@S<0M`13@340?CX[03Pf:@0o
?C00AD<f04A2=@12@3<0AT@e04I7=`1=CSl0DU9607anL`24Qgh0PhIo0;Zo^@3>e=00[kFc0866R@1c
Ngh0PHV<08::S@1lPHD0KG9e06Y`KP1DFUH0GfEQ08N>Q`1IH5T0ADa406=[H01MIe`0AU53045<?P1F
HE<0JWEU0:N_X02_]JL0UI^?08N8P02BThd0WijL096?T01iMgX0L6ia08b7R`2:R8/0E59C07]hN02;
QHD0RhJ307UdL@1dKf/0ShZ609jIU@2ETHh0Sh^:08b;R@2=RHP0Q81m07mkNP20O7T0R8>008n:Q`2A
R8T0U8Z;09Z@T@2SUY`0/:>/0;FZ/P3:`<P0]Znf0:ZUZ@2[YjP0[J^/0:6QW`2XZJ@0_Kji0;6b[01Y
JV80FeiC05iQEP1GFTl0HFAI06Y]HP1VJEh0Ce9804M<A@1CEE00EUQE05EGEP1eMGD0Shn?08B4PP1A
DDl0>3Tc03dn>00o@3P0AdQ004e>AP1>CdL0C4a405=BC@1NGET0KVeY07elN@2<S8`0N7Yi05iRH`1?
E5L0CU=G051EF`1DF640E5MV051FIP1CG6d0FF5f07R0U`2?U[00Xj[40080YZg900<0Z:o<0:Z_c@2Z
/=000P2Y[m40202W/=40ZK7E0:ZbeP2W/MD0YK;E0:B`eP2U/MT0Y;3H0P2S[mL00`2R[]H0XjcE0:>/
e`020:>ZeP0;0::Ye`2SZMP0Y:[J0::Ye`2OYmD0WJSF09VSe02JY=L0VZKH09RTe02FY=<00`2DX]40
3P2BX<l0Sig:08jOb`2BX<l0SYc;08nMc02<V/T0RiW808NHaP28VLL0QiG408JD``25Tl80Q9;10P22
T<42086>`P0E07j;`01mSL40Nh^o07V9_@1gR;h0MHJl07F6^P1cQkX0LHFh0763]@1bQ;@0L8:b0763
/`1/OZh0JWn/06YlZP1XOJX0JGbW06UnZ@1YOZ/0HgRW0080HgFU00X0HWBT06EgY`1RM:@0Gg6O05e`
V`1ML9X0GG2H05]_U01JKY40FVb@0`1HJh`0201FJX/0DVJ905=UR@1@HXP0DFB<051SR`1AI8`0Cf::
0P1=H8X00`1;G8P0B5V504QIQ@0304]IQP0304YIQ015E7d0AeAn00<0AUAk0P14DgX203i@MP0<03a>
M00lCW80>Te`03Q<K`0hC6d0=T]Z03=8I`0eBF@0<dAN03=3FP0d@5H0<SmB2Oooool000Oooooo01H0
FeU:05=B@01GE4<0IV5>07iiIP1oNVH0P7]W08N2KP2@RGH0T8aj092?O@2@SWl0QHIf08:4M`20Q7H0
OX5f07UoL`1aNF`0JG=X06I^H`1MIEX0GVEM0P1NIU/0VP1NI5X0GV5H06EXG`1ZJV00K6YR075aJ@1g
Mfl0NGYb07IhK@1WJE`0IFMI06M[FP1IH4h0Eei<08J<OP2QYi/0HVQN034h<@12B4@0@dU7061VIP1m
Ph<0PhN808B8R01hNWL0CU1;034b:P0i>c00@44c04=4=01HFDT0EEA204A3<@17ACH0@3h_03Le:00l
?Bl0@d@f0411<`0o@380ADHh04M8>01=D400E5I908N9OP2_/ZL0VIbE0:2UWP2JWiT0OhF108F;R@28
SXh0Q8b>07=kO@1ZKg80IVa/06U_K@1[LFd0LW]h071iM017DTX0AE1705QTF01;Ed/0?DTk069_GP1j
QGD0Yk2O0::XVP1kOW<0V9VA0::QW02XY:<0[jZ^09bGW@1kMWd0MW5h07]fO029Q8X0JFAX07mkO02O
Vi`0VI>C085mO01oNgX0SHV809VHUP2FU9D0SXj@092@TP2?Si40PX:207UiN@21PH40SXb=09:>S@2D
SY00XifO0:nVZ`2bYk00c<3:0<NmaP2h/kT0ZJBZ0:JTY`2YYjP0[Zj/0:^/Y`31`[`0fmcF0;6bZP1I
G540B4]0051CB01=D4D0DUE:061SF01IG540D59905EFD01NGeX0HV9P069QG`1`Kfd0V9NE09bKV@1X
I640;B`W03Xj<P12A3T0ATHl05=EBP1LGU<0EeQ@05mPFP1RHed0N7Ud08B6Q01RIVL0EUYM05MLH01>
DeT0BU5K051FHP1BF6H0D5EX05ELK`1VKX<0NX:I09FL]P2PYl40Y:_70:J]b@2U[<P20:V`c@0;0:V`
cP2[/M<0ZK;C0:J^dP2Y/MH0Z;;F0:Vbf@2U/ML0Y;3J0::^f02V/Mh00P2U/=d0502T[m`0XJcI0:>[
f@2SZmT0Y:cJ0:2XeP2PYmH0XJWH0:2Xe`2MZ=H0VjOG09VUe`2KYmT0UjGF09JTe@2CY=80TZ;C092Q
c`2?X<h0SYo=0P2=W/`02P2<WL/0SIk<08bJb@2:VLT0R9S908VIbP27V<H0QiG408JD``25Tl8208>A
`P0B08:@`@20SL40Ohc007n<`@1mR[l0NXZn07R8_01hRKl0MXNm07:6^`1dR;`0LHFh0724]P1^P[@0
L8:b06j0/01YOZd0J7f/0P1WO:T0101VNjP0J7fZ06IkZP1WNJT206AfZ00B069dYP1TMZP0HG>S05i`
X01LKY`0GG2K05e`V01IKI80Ef^>05IZR`1GJXX0EVV905MZRP1FJhX0DfN805AVRP1BI8X0Cf::0`1@
Hhd01@1;GXP0Ben:04ULQ`17FXD0AUV40080AeR400<0AUN304IGPP14EWh00P14DgX04P14E7P0A59i
04=CM`11D7L0>dea041?MP0mCg<0>Ta`03Y=L00fBVd0=d]/03E:J@0cB6L0<TES03=4GP0c@e`0<T5F
038oDPWooooo0007ooooo`0E03Db8@0]:QL0<RdI05UD?P1QGdP0J6I?07AbF@1fM5/0PgiX08N5K`2<
RgL0SXek092AP@2AThH0Si>508f@Q@2:SH80PHMm07ImM@1XKFH0HVMP0080GF=I02L0HFMK069VF01O
HeD0HfMI06MXFP1UIUP0IFEI06U[GP1[Kf40L7=X06U/H@1JGU00Ff5C05YPDP0mACP0KWI[09JMU@1U
K6D0A4Y804U?C`14CD`0GfMY07R0PP22R8P0PhV608B;Q01JH5H0;S4V03Pj;@19Bcd0DU=307AeI@1k
NFX0JFMH04m=?P0k?2`0=3DU03Xm;011@cD00P17BC/0LP19CCh0Bdm004]?@@1=DD<0PHAi0:f`Y@2U
Z:40UibE0825OP22Qh40R8f908B:QP1bNgH0HFYU05eVH@1cO7L0OhZ406A_I`1MJV<0EfAK04eMD`1B
HUL0G6aO04]KCP1<FT/0QY6309bRUP2RYIX0R8V107AcK`2`[Zl0`;^o0<>na02h/kT0THnD081nP`20
OX40MG=d08R4P`2;Qh@0QH1m09VDT@2QV9T0U8j>08^5Q`25PH80S8Z=09RFV`2CTYP0TY6G092AU@25
QXP0PX>508b>S@2?TI00W9bL09jLW`2c[[80a;g40;je_@37_LH0gMKM0<6l`P2YY:X0[jf`0;6`[P2g
][80bl[50<W:`P2VYil0P89g04Y<@@1IFe00D5=804a?AP1ADTX0EEM<05IICP1HFE00LVmZ06eXI01O
FUL0N7=`07iiMP1dKf/0KV]V05iIE@0l>C80AT@h04U9?@1;BCd0GUiB06U[GP1SIEP0KFmT07EfKP25
Qh80K71_04]@D`1:CUL0Ce=N059EI01AEVT0E5U]059HL01DFW@0Ifj:07j5XP2AV[L0W:G40::[bP2S
[</0XZ_:0:J_cP80Yk3?00l0Z;7A0:Vbd`2Y/MH0Z;3E0:Vbf@2X/MX0Yk3K0:Vbg@2W[mh0YZkM0:R`
h@2T[]l0XZcM0:6[g02Q[=X00P2Q[=T00`2OZ]L0Wj[H09jZf00209fZeP0909VVd`2KZ=D0V:CD09NU
e02EY]@0UZOE09BUd@2CY=80T:;@00<0SZ3>00D0S9k<08^Mc@2:W<`0RIW:08RIbP0208JHb00508BF
aP24U<D0PY;308>A`P21S/800P22S/8207j;_`0<07b9_@1mR[h0MhNj07R8^`1gRK/0MhRl07:6^@1b
QKP0LH>e0722]01^P;00Kh6a0P1/OZh01`1YNj/0JWb/06UkZ`1SMJD0IWRX06AfZ01VMZT00P1UMJP2
069bY@0805maX@1LKYd0GFnM05]^V@1GJY80EVbA05A[S@1BJHT205EYRP80DfN800/0DVJ7059TR01C
IHT0DF>9059TS01?H8/0CUn:04]NR01;GHP0BU^604IIP`0204MJQ00H04AGP@16FH40A5Mo04AHO@12
E7X0@UAh04EEM`12D7D0@e5d03i<L@0lC6h0?deb03m?L`0lCW80>T]`03Y:KP0iBFd0=4MX03=6I`0d
A6D0<dAP03A4GP0d@5P0<SeC2Oooool000Oooooo0:`06QT701PG0`0H5P40>3HO03hl9@14@R/0AD<Z
04]9<01VI4d0Lg9L08J5L`29RWX0TI:4096CQP2BU8L0V9R<09FER`2@THT0QhZ1079eKP1TIeh0GV5H
05iQEP1PI5H0HFEF061TE@1QIE@0HFAC061SD@1NH580H6AE069XFP1YK640IF]O05AJD01PIU`0IFYS
055FD01IH5T0MWah06Q^K01CFEL0BU1@04eFE@1ZLg80NH9o07n5P@1hOgP0OHEj05QNDP0d>2X0Ad/l
05=EA`1QHeD0Si:109jOT@2>Sgl0EeY902/^7@0c=bH0?d<b04I:>@1=DD00DEE6059FA@1>EDD0B4lo
03m5=`24R7X0Si:70821N@2:RhD0R8Z508F7PP1kOGX0LWAa06M/J01PIV80O89n08><Q`1UL6X0GVUQ
05MTF`1HIE`0F6QM069bI`1MKF00EfEF06ijK02FWY40RXf208Z<P@2LWID0Xj:N0<C2``34_l<0/:^_
0<W7bP2d/[D0TY:B08F5Q@1kNWP0OGUf08b7P`2=QH40W9BB09nEUP2>QHH0PgYo08J0Q02?RY00X9jS
09JCVP2@SiD0T96E08b@T@2>Si40SHn>09JHU`2e]KD0`;k10<G0a030^l40^;>j0=[Ef`3_j>l0cLS<
0:f[[P2l^[/0`Kfj0;^h/`2c/j/0Xj>K06a^H`1FF4d0De=905EGC01@DDT0DU=;04i?A`1ADTX0FU]C
06MVG`1cKVX0LFUV075YI`2;Ph40U8n<06QSH015@3`0CTU504]8@`1;B3l0AdLk05=CB@1UIET0HVAG
075dJ@27RX40MWUb07IkM@1IGEh0D5EK04eDGP1>E680EEQ[05IHK`1FFWD0Eeai06Y_S`26S:`0WJ?5
0P2RZl`05P2U[/l0Y:g>0:J_d02X/M00ZK;A0:ZcdP2Y/]80Z;3D0:Zbe`2Y/MP0Z[?L0:Rag02Y/=h0
Z[3P0:Z`hP2Y[n40ZJoS0:F/h02V[N40XZcM0:2[f@2Q[=X20:2[f00=09jYe`2LZMH0Vj[E09NVd@2H
Ym80VZOD09JTd@2GYM80U:GA09FVdP2BXll0TJC?08nQc`0208jPd00608fOc@2<W/h0RI_=08VKc@26
V<P0QYS90P24U/H00`23ULD0Q9C508:B``0208:@`@06082<_P20S<00P8c007n;_`1nR[h0O8Vm0P1i
QkP307J6^@0407>4]P1aPK@0LH6d0722/P80KGn_00@0JWb/06UkZ`1XN:T0IgNX0P1UMjL00`1UMJH0
Hg>T065aXP03069bX`0F069cX@1OL9h0FVbJ05Y[U`1GJY@0FFbD05M[T01CIhX0E6R;05M[SP1DIXX0
DfF9055SQ`1FIXX0EFF9055PQ`1DHhX0DUn9055NR01>GH@0C5^204YIP080AeUo00X0AeZ204IIP@16
FWl0@eMl04AHO@12EW/0A5Il049BMP13DGH0@U1e0P0nC7403@0oCG80?Tib03e=L@0iB6l0>TU`03Q8
K00fAVX0=4AV03E5IP0cA680<T9L038nEP0c?U@02Oooool000Oooooo03@05AH601@E1@0F5@<06aX6
01dL200T8`h092<?02PW4`0d<al0E5I307enKP2=Rgh0UYB709FCQ`2@SX80VYJ;09^GS02JUXd0W9V@
08N4O@1RGeH0FUY@05]KD@1LG500GEmA05iPDP1MHE00FUi=05]OC`1KHU80GF=E05eUF01UJel0H6IL
04U>A`1KH5X0LG=`05eOGP1CEeH0MWYi07]oP01OHf80F5iL05YPG01YL6T0Mgif07b2N01eNfh0LGQX
04iB@`0o@c@0CE500P1@E4D0N@1bMVL0NGe_07YnK`1IH4h0?4<a0419=P17D3d0DU]805MOBP1MI580
GVIA05]RD01>E480@4@e07AfJ@2:S840PX9j08R4P@24Ph40OWam07=aM01WIFP0K6a^06]/KP1nOh40
PHF606M]J`1GGET0HV]V075kL`1]NFl0M81d06UeI`1JIUP0LWe_08fCQ`1mP7D0QHQm0;^n/`39bl00
_l2h0;Nh/P2QXY`0cLc80?Cck`30_k/0S8^706]WI01iMG80T8^709bCT@2GSH`0T8B608MmOP1lLGL0
O7=h08j8S02RWJ40UI2F08b:S@2<SHl0Rhf<0::RXP2ZZ:T0`l720>3Ng`3Ie=P0/:^a0:FPYP35`<H0
iN?X0=KAe@38a/L0_[bm0<G4`P36aL40Y:>N085nM`1ZJV80D597051@AP1IETl0DDi704U9?`1BDTP0
GemG065QF@1VIF00KFUU06MRG`1TGe`0QX20096;R`2?Rh`0LVi_051<C@1EDE80DE1>04a=B014ACl0
EEMB06mbJ`1[L6T0I6UR07j3O@1[L6X0E5YF05IKG@1AEU`0EEUT05YMK01JG740EeUb05iRO`1eNYP0
RHj^09NM_`2TZ/`0YZc>0:R^d02Y[m400P2Y[ll0;P2Z/=00ZK;A0:Rcc`2Y]=<0Z[CG0:Zdf02Z/mX0
ZK3J0:^bgP2Z/Ml0ZJoO0:b_hP2[[^<0[:oT0:J/h02W[Ml0YZcN0:F[f`2SZmX0XZ[H0:6Ye`2PZ=H0
W:SE09fZeP2IZ=<0V:OB09ZWe02EXm00UjGB09BUd@2DYM<0TjCB092Qc`2@X=40Sio@08jNc`2=WLh0
Ri_<08VKc@27VL/0QiO:08RHbP27UlP0QIG608BE``25Tl8208:@_`04086?_P20S;`0OhVl07j8^`80
P8Zm00T0OhVl07b6^@1kQkT0NXBi07N3]`1fP[H0Mh>h079o/`1aO[800P1_Ok802@1^OZl0K7b]06]l
ZP1YNjT0IgVW06EfY01SM:80I7FQ061aW@0206=bW@0=069`W@1SLIh0HVnK069_W01MKYX0G6ZG05UZ
UP1KK9L0FV^F05QZTP1GJHl0EVR>05MVS@0205ITR`0A05UUS@1HI8`0EV:805IRR01DGH@0Def1059L
P01@FWh0C5Ul04YHN`19EgX0BUQm04YIP018Egh0AEMm04=EO@11Dg/00P12Dgh01`10CgP0?dig03i=
MP0jBG80?dii03i=MP0lBg@00P0iB6l0200eAFT0=DM[03E5I`0eAFH0=dIU0390F`0_>eD0<3aD2Ooo
ool000Oooooo00d03aD601@I2P0G6PX06ad>01dN3P0K70`06AL901hL3P0W91L0Cd/n08J2MP2CSH80
UY240080Ui2406d0VY>609bEQ`2JThD0VI:5092=O`1/JE/0Hf5B05eLC01LGD/0GV1=05MJA@1HFTH0
FEe905ePC`1RIeP0Gf=H05UNDP1GG580I6QQ07EiLP1nP7/0O7ej06ASHP11@T40KFe^092?T01gMgL0
JFaY07=fL@1kOgP0MWY`07=gJ`1cMfL0JfiM059FA@17BSX0ATXl03i1=00e>bl0;C@Z02/d:@12C400
H6eN06=_G`1CHDl0AeE2059PBP1`OFL0M81Y079lIP1[MV00HfeH05=LB@1KI5@0Nh=d08>7O@1oPGX0
Kg1Z069SG`1UHf40JfMW071/K01^JVX0Lg1`089mO01nNgX0L6m/06UXI@20PWd0SI2708Z=PP21Q7H0
MgY[07aoL02>Sh80Rh]m09fNSP2c]J@0YJJE09jOSP2_[ih0_K^^0=oJd@3dknT0f]KA0:6LVP1kMWH0
R8B509nIW02i/[@0R823089jN`2>QHP0ShF808MnP025O7h0Th^=09ZBTP2DSHd0THb:0:jZZ03;aL<0
l>WX0=gFe@3>alH0^K>a07=^K029Q840]k>_0080/:bW04L0`;jh0;nm^02]ZjL0T92907YjL`1VIEd0
G5aC05IFB`1JFTl0HUmE05eJD01DDDL0G5]A06e/I01aKfP0KFYW065OG01@CTd0C4]:05eOG@1fMgP0
MGIg07=dM@1RHV<0EEEF05IGEP1:Bd`0@4=304]?D01XK6d0HfQY05ILGP1HGF40EU]P04mDG01DF6D0
EeY/05IIK`1LGgT0GV9n06mcTP28S:/0VYno0:J[b`2W[<h0Z[3?0:^bd02]/]<0[kCF0:fce@2]/mH0
[[?G0:ndf02//mP0[KCK0:Zcg02]]N00[KGQ0:bdh@2[/n40Zk;R0:Z`hP2]/NH0ZjkS0:^^hP2/[n40
ZjgO0:V[g@2WZ]X0YjcL0:J[fP020:BZf@0l09nXe`2LZML0VjSF09bYe`2JYmD0V:CC09RUd`2FY]@0
UZ?D09JUeP2DXM<0Tj3B09FRe02BWm80Sik?092Od02<Vlh0SI_?08^Jc027U/P0QIG608JEaP24TL80
QI;208BA_`22T<00PHno086=_`1mR[d0OHVl07f:_@1oR[l0O8Rk07^8_01jQ[/0NXBj07R3^01hPkL0
Mh:f07=o/`1aOK40LGf`075n/@1aO[00KW^[06elZP1ZNZL0JWVV06MfX`1WMj<0IGJQ06=dW`1SMYh0
HWFM065bV`1QLIX0HW2I069aV`1NK9T0GFbH0P1LJYH05`1MK9L0F6VD05QYT`1IJI@0EfNA05MUS`1G
IHd0F6B=05USS01FH8L0EF6405EPP`1CGX40Deeo051LOP1>FW`0BeQk04UHN`1;F7h0BER004QGO`18
Eh40A5En0080@e=n00X0AE9o04=AO@11Cg/0@4ih03m=N00oCGT0@4mj03Y:M@0jBG80>TU`0P0eAf/0
1P0dA6H0=DAU03Q5I@0e@f00<3aG038mE`Wooooo0007ooooo`2o010H2`0E7@h06alA024S5P0P81@0
8AlC020L4@0K5``07aP>05]CB02ESH00THUl09N@P02NUhL0W9J609ZEPP2NVHH0T8]g07ilI`1/JeH0
GEm705mQB`1PHT`0G61704mC>P0i>b<0D58l05eOBP1KG4`0Hf=G05mOE@1KG5@0GUmI059CCP1^KfX0
TiB?08^<Q`1ZJfH0>S/f065QG`1oOW`0JFQV05ACD@24Q880V9VD07n2N`1gNW40LWEW05iPDP12AC@0
;c4S03Li;00a=2T0:2hT02H]9@0K9Ad0;CP`05aZG@1`OVl0M89c06MfH`1OKUT0P8ig09>OQ`2<V800
PHeg07V2KP1_N6D0HfiM06QcH`1aO6h0LWY_06ifJ`1/LVP0KVmY059AC01JEU<0LVmZ08N2O`22NWL0
MFeZ07A_J`1jMG40QH9k08Z7OP2?S7h0SHYi08n9N@2ET7d0^K>S0;VbXP2RVhT0VY>108N0K@24OFX0
/JVF0<k5]P3=`kX0_[>_0;V][@2DRHd0ThR@0;N]]P2j/[d0]:ng09JAU`2ZYJT0];2a09bFUP29P840
SHF309B:R@2GSH/0V8j<0;>YY`3Icld0g=;@0=WBc02/YIl0Qh1h08Z3N@1oNFd0TH]o0:^SV@2AR7l0
Zj:K0;RaZ@2[YZ00Ph1i06UVG`1HF500EE9;05UIC`1SHED0L6iQ07QfJP1XIUX0HV1D06YWGP1]JV<0
JVUT06Y[IP1;CD/0B4a;04=9A`10BDH0EEiK06A]JP1OIF<0CE=A04Q<B`1;Cdh0CE5D04M;CP1?DUL0
DEAK04mCG01AEF00DUIR05=FI`1ADfP0EUMc05UJN@1JGH00HfJ907]oXP2RZ<X0Zk3@0:^ad@2Z/=00
[[GB0:fdd@2//m00[KCA0;2feP2^]=H0[[CH0;6ef`2a]=d0[[7L0:jbh02^/^80[K?W0:Zai@2Z/^<0
Zk?T0:NahP2Y/N80Z[7U0:V_h@2Z/>000P2Z[]h00`2YZm`0YjWI0:NYf@020:FYf@040:BZfP2RZ=/0
W:KI09fWg080VjOK0P2GXmD01@2HY=H0UZ;F09RTf02EXMD0U:3D00<0TYkB00P0Sig>08jJcP2=VLd0
RiW:08NFb025T/H0QI?408:>`080Q93200D0PHo0086>`P1nS/80O8c007V9_@0307R8_00O07R5^P1f
PkP0MH:g07J3^01fPKL0MX:g07B0]01eOk@0LWb_071j[@1aOJl0Kg^[06aiYP1[MjL0JgRU06MeXP1V
M:40IGJR061aW@1QM9h0I7NQ065bW@1PLI`0H7:J065aV`1LJYL0G6^F05]ZU@1IJ9<0EfRD05IWT`02
05EVTP0@05EVT@1GJ9<0DVB<05=RR`1DHXT0DEn4051NP@1BGh40Cean04iMO01=G7`0C5an04MGN`17
EWd0AUEn04MFO`80AUF001D0AEAo04IEP016Dgl0@e1l041;N012CWP0?daf041=M`10CgP0?dii03Q9
M00fAW00>DQ_03E7K@0gAf/0=dEX03=2H`0d@F40<d1P03<lF`0a>UL02Oooool000Oooooo03@051X@
01/N4`0O7aD08AhE01lM4@0M6@h08Q`@024I3P0N5P/0FE5308Z3L@2BSGX0ViV409RFP@2CTWd0U9Al
092BNP1mOfL0JViC065WB`1NI4P0IF]A061VC014BRh0<cTO03Pl8`1?DSd0EEI405EEB01CDdT0FUUD
06AUH01UIF<0EEMD065SH01/LF/0IfaV05mTGP1;D4X0FUmI06e_JP1_Kfd0Hf9P07]jN01oOW`0LgA_
07f0N@1eMfh0EEM:03dn<00O8A<09RPJ0P0[;b40M00U:al07R@J02L_901GHEH0MX5c08B<O`23Rg`0
MGi]0869M02PZ940YjbF09bQS@2>TGh0PHEd07MnKP1cNF/0LWQ^06edK01_MVh0LgQb07MlMP1DEU40
EeME075bK@1dLg40L6m[07EdK`1nOGP0OWif08Z7OP2@SX40Shek08^6LP2FSg`0/:RE0=35/`33]ZD0
]jZI0:^NS@2>OVl0RGUZ0:FCQ@2lZZ00]jBN0;6OW`2kZ:`0WXZC09j<V03Mc=`0^:^l0:jW]@2l^L80
/k6f0:FPY02=QhT0R8:208f8Q@2>QX<0XIVG0;:ZZ033^kT0al:n0;bg/`2YY9h0Pgmd06IREP1nN6`0
Ng=X07E[H@2MT8T0SX1m09N9R02<PGl0OGEb06aWH`1LEe40EE9;05A@A`1HED`0IF5F071/H@1dL6D0
J6AI06=OEP1XHed0JFAN06ISGP1QHUd0B4]904Q>C010BdD0?TU3059ME`1JIF40DeaI04UBC`1=De40
Be5?04mDE`1DEe`0EUUP05EEG`1DE600EeIT05MFJ01IFVl0EUIb05YINP1NG840IVJ<08:4ZP2MWlD0
Z:cA0:N]c`2X/M00ZK;?0P2/]M820:ffd`0l0:ffe@2_^=T0[[KJ0;2ef`2a]]h0/;GO0:nch@2[[ml0
[;;V0:^biP2Z/ND0Z;;U0:JbhP2U/N40Yk7R0:R`h@2X/=l0Z;3N0:R_g@2Z[]d0Yj_H0:FYeP2TZ=L0
Y:SH0::Xf02RZ=/0WjKL09fTf`2LYM`0VjKL09NRf02EX]L0Tj3E09FRe`2DXMH0TYoD096Nd`2@WM80
TYkB096Md@2>V/h0S9S<08^Gb`28U/L0QiG508FCa024TLD0PHk208FA``22S/00P8g107n<`020SL80
OHZo07f:`@1lRL00NhRo07f:`@1jQKd0N8>k0P1gP[X08P1dPKP0M82g079m/`1dOK@0LWba06mk[`1_
Njd0KWZ/06]gY`1[MjT0JgNW06EcXP1YMjH0IWJW069bX`1PLZ00Gg:M05m`WP1NKid0GW6L061_W01N
K9T0FFZF05]/V01JJiL0EFJB05IWT`1EJ980E6NA05EXTP1CIY00DF>;051RR01AHHD204iNP080Ceio
00D0CUio04]KO01<G7h0AeMk04AFO00204IEOP0504EDO`14Dgh0A55m04ICO`15DW`00P12CgT2041>
M@80?ded00`0?Tef03Y<M00gB700>4M^03M6K@0eAFT0=TAY03I4I`0c@680=D9R03@mG00a>UT9oooo
o`001oooool03`0K7QL071lF02DU6`0S8AD07Q`?01hJ3P0S7@l08a`<01dF1P1MEd@0OWaW08J6KP2D
UWh0Si=j07QlH`0207AjGP2K06M]D`1OID/0GfQ;05iWC01TKE80@4P`02X_600j?bP0Bdhi04mB?`1C
E4H0CTe1040m=01PH5P0PX5l07=dK`1UIf@0IVQU06EZI01XKfP0H6MP05QOF01OIUl0JVmY07EgM01k
NgT0NGUg06MVI01WJ6<0LW=^05UJD`1>CT@0@Clc02XX6`0X9QT0:b`N02`/800U9aX08B<H02ha9P1>
DDH0LgI[08b?Q02EVH/0SI6208:5M02DUh@0YZNE0:Z[V`2VY9D0RHYl08J6NP22Q7T0O7eg079eKP1X
JVD0LWA_07j0O@1ZK6T0EeME06EUH`1/JfT0NgYh08>2OP27QX40Ph1i09NDR`2]ZId0ViN509B=NP2_
Yi@0eLZh0=G8]`2n/J00`[FU0:^KS028N6T0V8Ij0:BBQP2aWiD0`ZnY0;VUY02iYJL0]:6W0;JR[@3V
e>00/ZBa0<2g`@2l]kd0WiZN09VEU02<Qh@0SXV508V4P02;QX00X9^G0<g:a@3?c<L0ZjRS09^HT@2Q
WYD0U9:606iZGP1hLVH0JV9G05aBB@27NWH0M6IU07AVIP1`I6@0J5iM069JF01IDDh0EU5;051;A@1B
CTD0If=J071/H@1dKFD0I61G05IAB`1HEDh0GU]F05IED@1?Cdd0@dU604A=BP15D4`0?dY6055LF01K
I640E5iM04iGEP1?EED0D5EH04iCEP1IG640KW5j06ATL01GEV@0FeY/05UGK01LG7@0FEQg05mNP@1_
KI80Q8BX09fP``2/[]@0[;3E0:bbdP2[]=<0[KKC0:bedP2]]]<00P2^]m@0;P2^]mH0[KKG0:ffe`2^
]]X0[[KK0:nggP2^]N00[;?Q0:bdh`2[/n@0Z[CU0:Vci02W/n<0Y[?P0:JbhP2W]>40Yk;O0:JagP2W
[md0YJkI0:J]f@2U[=P0XZWG0::Zf@2QZMX0X:OL09bUg02LYMh0VjKN09^Vg02GY=T0U:?J09>Rf@2A
X=L0T:3D096Qe@2@X=<0SioC092Md@2=V/h0RiS<08bIc@2<V//0RIO608NEa025Tl@208BAa@0<08B@
`P21Sl00PY31082=`@1oS<00OX^o07Z7_01lRKh0OXVo07f8_P1kQ[`0N8>i0P1gP[P207>0]`1207=n
]01dOK@0L7^a06ik[`1_O;00K7Z[06ek[01]NJ/0JgVZ06IdY@1VMZT0I7BW069bY@1RM:@0Gg6Q05m_
X01OLJ40GFnO05i`WP1LKIT0FFbG05Q[UP1IK9L0EFRC05MZU01FJI<0EFRB05AWT@1BIHl0Cf::051R
RP1CIH/0Cf6704]MP`1?Gh<0CUj204aNPP18FWh0BE]o04QJP016F7h0AeIm04IEO014Dg`0AEAm04=@
NP15DW`0A59i03i=M010CWD0?die03m?L`0mCG40?D]b03a;LP0jBG00>DQ`03Q7KP0gAf/0=4AX03I4
J@0gAFP0=D9T03M2H00d?E`0;SMD2Oooool000Oooooo09H06QlI01lR6`0P8aP0828D01lP400P7`d0
8b0=028P2`0M70L0C4`c07MjG`1nPVL0UI]o09bUR01UKU40DE]005iXC@1NITh0G6A<05mWD01@F440
AT/g02/_7P0a<bD0AdTk05EGB@1HFTd0D59505=DB012@SH0KVaP09:?QP1iNG40IfIQ05YMEP1KH5X0
IfiW06Q^JP1TKFP0IVmZ06]dK`1_MG40LgQd07IhL`1aLVd0KFiY065PF`0j>340Ee=:03lh;P0a:al0
=BlS02hX700[9a/0:RHK02hZ7`0[:Ad0?cda075aI@1nOW@0Vi^A0::RUP2JVhd0UiR:0:2NT@2MVHd0
ZJFJ0:BPU`2HThd0S8V408N4O`21OGX0Lfm/07A`K@1jMWD0MW9a07MaL@1kMGD0Ng9e09F<S`2IT940
T8R60928Q@2[Y9h0`kbb0;B]X@32^j/0f]?10=_B`@31^:L0/:NF0;N^W`2YX940THQi09N;O`2BQWX0
XiN;0<>f[@2`Xi/0ZYfG0;V[Z035]kH0gLo?0;nc/`2i/:l0Xi^H08f8PP2>RH<0Qh1h08b8O`1iMF`0
RXMn0:n/X`38b;h0_[jd09bLTP1iNFl0TY:60:>PU`1aKVD0GEU@06MPF01UGUP0J5mM06=IF01QEeP0
H5MH05iFE01LE580F51>05=;B01>AT<0CDI0061KE@1^JV40JfIP05YEC`1:Ad00BDQ304a;A`1<CDP0
ADM404=8A@1:D500BeAC04aEE01AEeL0G65T05INH@1?EeX205EHG`0C05AGGP1VJG80Oh6>06e_OP1C
EVL0EUU/05]MLP1OHGP0G5ei06e^S02ATK<0YJS90:^^c`2]/M@0[;7A0:fcd`2]]=40/[SH0:nhe`02
0;2ieP090;2kf@2_^]X0[k[J0:njfP2_^M`0[[SK0:jhg02/]]/0[;GN0080Z[KP00L0[KGS0:Rch02W
]>00Y[?O0:Jch02V]N00Y;7M00<0Xk3J00/0XZoI0:6^f02NZmP0WjgL09f[g02KZ=`0V:GJ09VVg@2G
Y]d0UjOK09>Tf00209:Se`0509>Tf02@X]@0Sj7C08nQd@2=Wm400P2<W<d308ZJb`0908RIa`26UlD0
PiC208:B``21TL@0PY31086?_P20S[d0O8bm0080OH^l00<0O8Zk07j<_@1lR[T00P1kRKX02P1gQ;P0
MX>g07F2]P1fPkP0MH:g075n/`1bOk@0KW^_06em/01/O:l206Yj[@0>06]h[01VMZT0I7BW06AdZ01S
LjL0HG6U069cY`1NKj<0HG:V05maX`1MKil0G6nM05Y]V01IK9L305Q[U@0B05AWT@1DIhl0EVNB05IW
TP1BIHl0Cf:=04mPS01AHY00CEn=04]MR`1:FhL0Beb804YMQ`18FhD0B5^304EIOP17Fh00AEMk0`12
E7P05@13DgL0@U9f04=CM`0oDGD0?dmc03e?L`0oDGD0?Dmc03e<L`0lBg80>TU`03Y9KP0iAf`0>4I[
03I4J@0gA6L0=T=V03DoHP0d?ed0=CmJ034hDP09ooooo`001oooool0I@0S:2808bPQ01hT600Q9AL0
8B@C020S400R90l07R0;028T3P0o@B/0L7AM08V>M`25SGD0QXif06miH@1FH4P0GVQ@069ZE@1DG4L0
E5Q703/o;P0c=BL0=CDY03hn=01ADTX0FeaD05MICP1>D4D0JF]N05MIB`1PHE<0RHYl07QhK01QHeP0
BTe405IKE01[L6X0K79^06]dL@1]MW<0LWQh07EkN@1dNGD0MW]g07]mNP1gN7<0De9>03<_:P0i=B`0
;bPP03H]900d:b80:b<H02`V6P0a:al0=S0T02dV700l>2d0LFmS07ejL`2KVi<0^[Zb0;Be[@2][JD0
ZZZR09^HT@2GU8h0^[Fa0;Ja[@2PViL0RHB008N2OP24Og/0Mg9^071[I`1iLFh0THV609fCTP2FS8d0
W92B09jBTP2NTi40YIZH0:jSW`3=`[`0`kV`0<g3^@3Jd/L0bL6f0;J^X`2/YYX0ZZBH0:NSU`2UWY@0
YInC09:<P02>R7`0ViF90:ROUP2aZ9l0_;>Z0080h=G?04T0aKZd0:>ITP2BRH80RhAl08V2NP20NFl0
NWI[07AaJ01hN6h0UIF;0:NYWP29Rh00OGmd07=eJP1hNVl0RHV106YZHP1IETl0FeQC05]FDP1KEE80
GEEC05aFEP1IE540FUEB05Q@CP1ECD/0C4M404U4@@18AD00EeA?065PF`1RHE`0EUE@04Q9A016B4<0
AdU404M<B015BdL0ATe<04YCDP1CGEh0FV9T05QMH01KH6@0EeaR05EIHP1MGf/0J6Yg06=ULP1XJWT0
K6n0065TM`1IGW80G65e05aQM`1OHg`0HVJ107n5X02TYlH0Z:_:0:f`c`2^/m<0[K;B0:fdd@2_]]<0
/[SH0:nee@2b^MH0/K[I0;2kf@2_^]X0[kgJ0080[kcL00X0/;gO0:nlgP2/^=`0[;SN0:bhh02Y]Ml0
[;GP0:Vdh@2W]>40YK;O0P2T/]l0202S/]d0X[?N0:6bg@2P/M`0WZoJ09j_f`2L[M/0Vj_L0P2JZ]d0
102IZMd0UZOK09>Ue`2EYmT209:TeP0A092Ue02BY=@0T:;B08fRd@2<XM00S9k>08jPd02;WLd0RI_;
08VIc028V</0RIW:08FFaP21Tl<0PY;508>CaP20T<400P1mS[`01P1lS;d0NXZk07V9^P1lR[/0NXRi
07Z8]`80MHFf00L0M8Bg07>3]P1bP[D0LX:e0761]@1]O[80KX2b0080Jgf_0P1YNjd01`1UMZX0IWN[
06Mh[01RLjT0HG:X06AcZP1QL:L00P1OL:H06P1OL:@0GFnQ05]_X@1IKY`0F6fH05U/U`1GJY@0EVbE
05=YTP1BIHl0EFRB059US`1EJ9<0D6>>04ePR`1?H8h0D62A04mQT@1<GXh0B5Z:04UKR`1;GH/0BEb7
04IIQ015F800AEUn0P14EWX00`13EGT0A5Af04ADN00204=CM@03049BM00nCW80?U1d0080?Dmc00d0
?4]b03i<L`0kBG00>TM^03U5J`0g@f/0=T9X03Q1J00g@FD0<C]N03DnG@0c>U@0=3aC00Wooooo0007
ooooo`0702L^9P0X;bL09RhS02T_8`0X;R0092XL02P/7P0202HX6`2103m1=01VJ5/0MWY/05AJC01J
H580JW1R06=YF`1NI5H0GfIF05=GB012A3H0?Shb03ll<`19ASl0De1;05YIE01ADT`0BDY405MJD`1^
LVH0H6AE05ELC01TJe/0If]L065UE`1GGE<0HFIO06aaJ`1`MG40LWIe075eMP1hNGd0Ngb007QiN`1i
NW`0P82207EeM@1=Bd`0>SHd028M6@0T7a/0=BhX03@]9@0]9Q`0;bTM03Hc900n>2X0>C<W03di;P1_
K6<0RXN20:RWX`35alH0b<[90;Jj^`2VZZ/0Z:b]09ZMW02OWid0/[>^0;6`Z`2NWYH0TXn608Z7OP25
PGH0NgM/07E^I01oMVd0VY2709nBS02LShT0XiB=0:VJT`2ZViH0^:VT0=;3`035]k40XiJ@0;2UX@2X
WiX0YYjK0:NOW02QWYT0WibE0:JSWP38aKh0ZJVO08Z:P01jNW00S8Yn0:jZW`2[Yi`0a;fe0<Nn]`2c
ZZD0Uhj908j5P01jLfd0Mg9/06aWH@1NFE<0K6UR07YjLP25Q7l0Q8Eo07AeK`1XJf@0GV1K06]]J01n
OgT0JfaV05EDC`1?CTT0DTm:05IBCP1FDDd0Edm=05E@C@1FDDh0E51=04e9AP15A400@d8n0493?P1;
CDP0DEI@04iCC`19Cd/0@dU70080@4U600l0AE1<04E?CP18De@0B5AD04eKG01iQ8H0R92C071eN`1M
HF`0G61/06a_P02HVjh0Wj6f06maR01DF7400P1IGgL02P1LHWX0GF=k06M^R01mQ9h0WZG00:R]bP2Y
[//0[K;@0:jcd`2_]=@20;:ge@040;Bif@2c^MT0]K_K0;:kfP80/KcJ0140[kgH0;2nf@2^^m/0[kkM
0:jmgP2]^mh0ZkWP0:^gh@2X/n00Z;?Q0:Vci02V/^@0YK7S0:Fci02P/>40X;7O09nag`020:2bhP03
09j`h02L[]h0W:kN0080VjgO02D0UjWK09NYf@2GYmP0UJKD09BUd`2BYM00TjKA09:Ud02?X/d0SZ3>
08jSd02<XM00RIg?08^Od@29WLl0Qi_=08VJcP28VLd0QiS>08BFc020U<T0P977086BaP1oTL<0OHno
07^=_@1kSKl0NH^m07R:_01iRK`0N8Rk07N7^`1eQKT0MXJj07>4^01bPkL0L86e0080Kh6c00T0JGf_
06Yn/01YOJl0IWZ]06Ql[`1WNjh0I7R]06Eh/01RMJd00P1QM:h05`1RLj/0HG:X069cZ@1QLZP0GFjR
05maX`1JKZ00F6^J05]^V@1GK9L0EF^D05AYU01EJYD0DVNB055VT@1?I940D6FB04YORP1;H8/0CV2>
04eOS@1>H8h0BUb<0080BUZ;00l0BU^904UJR015EX80AUN304MHP`15E7d0B5N004IEO017EGX0AeEl
04IDN@13DGH0@U1e045?LP10CW400P0mBfh03@0mBg00?TYb03i:LP0mAW00>dA]03i7LP0c?6D0=CaV
03DmI00e?F40<cUI03<jEP0d>U@02Oooool000Oooooo02D0<STa049:?`15Bd40>Cle02H/8P0/;bH0
<c@^038c;@0Z:bH0ATM206a]J01UIF<0Ce5>05]MF01UJV@0HFIO05eSF@1JGU00FE]>04];?`14A3P0
E558065NE`1FDdh0C4]605YKE@1;C4H0Kg9Y06ecJ01IHE80E5e<05YSDP1TK5d0GFEH061XG@1WK6D0
KW=_0080LWAc03D0M7Eg07UhO@1jNGh0NgYo08J7R@27QhT0J6QZ0451@@0d=3808b8N02@S7P0h>300
>cP_03Tg:`0b<2<0<S0Q03dk;013@C@0?3X^051=AP2<RhL0/k6b0<G6bP37b/l0b/gD0;Rk`P2]/[P0
ZJja09ZKW@2UYj@0/kB^0;Bd[02^[Z@0YJ>F092>O`24PG80QX1`089lK020NFT0RGmc09>7N@2LT880
XiF:0:RJT@2hZJ@0`;6^0:fOW@2GRHP0UH^:09N>S`2KTY<0Thf=09ZFT`020:ZYY@140<c;a`31`[`0
VibD08B4O021PGL0UY>:09^GSP2MV980XIZD0:NPVP2ARX@0PW]e05aGD`1KF5<0Ge]H05EACP1RHEd0
LgA_07IhL`1bM6l0Kg5/06MYI01EEe80FUaG07f0N@1YK6D0GEiH059BBP1?CdL0E55:055<AP1CCTP0
DTm805EBC@1BDD`0CTm903Pk=00j?cT0@TM304A:AP14CDP0?dQ503i9A@0oBDP0?TQ703m9B016DU00
CUYJ05UTIP1EGf40BUEG096KW@36cM<0YJVb061TK`1bM8<0PX>E0;>ebP30`]/0U9Rc04iCL01AF7@0
GVF105iXP`1XLXd0NXBO08nK/`2W///20:^ed0030:fdd02_]]<0/KSE0080/k[F02X0];_H0;BjfP2b
^mX0];gL0;Bog@2c_]`0/;kI0:jle`2]^]X0[KcM0:jmgP2]^ml0ZkWP0:^hi02Z]n@0ZKGU0:^gj@2W
]>P0YK;V0:Fej02Q/N@0XK?U0:2bi02O/nD0W[;T09b`hP2J[^00VJgO09N[g@2IZmd0V:[J09NYe`2D
YM40UJKB09:ScP2CY<l0T:?=08nRc02?X/d0SZ3>08jSd02<XM0208VMd00?08NKcP26V/d0R9W?08FH
d023U/h0PiO>086Fc@1oT/X0O97607jBa@1mTL<0Nho107N;_P1fR[d0N8bo0080MHVn01h0MXNm07F6
_01bQ[/0LHFh07F6^P1`PKD0Jgna06b1/@1YOJl0JX2a06Qn[`1UNj`0IG^]06Il[P1SN:d0IGV^06Ii
/@1QM:`0GW6Y05m`Z01OL:H0HG:X069cY`1OL:@0GFnQ05Y_WP1HK9X0FF^I05Q[UP1GJYD205AVU008
05=UT`1@II@0D6BF051UU01<HHh0CV>@04mQS`1=Ghd204]NR@0?04]MR`1:FhL0BU^704UJQP17F8@0
AUN204MHP`17EX40AEAm04IDN`14DWT0AE=j04MENP13DGH0@Dmd0080@Dia00l0?de`03e;KP0mBFl0
?4Q^03m8L@0kA6l0>T=^03i5L@0g?VP0>D5X03U1IP0g@640=SeJ03<jEP0e?E@02Oooool000Oooooo
06<0B4]206=VG@1XJF40C4]603hm>019B4@0@cln04U5AP0j>3d0?S]205YIG`1VIF/0GeiS06EUI`1O
HF00E5IA04iAB01=Cd80CU1204i?@@1DEDL0N7U[08:2MP1JFU00=cL]05QJC`1DET/0HfIK06edI`1C
GU00E5mA05=ND01QJf00HVaQ06A^I@1XKfL0KgA`075eM01eMgH0MgQj07alOP1nOX00QHJ80824P`1R
I6<0C55=02ld<00Y;RP07R<L01TN5`0i?cD0A4Xn03e3=@0g?Rh0?40_0412=016B3/0BDTo04M6@@2F
TY40`Ko20<O4b`38a]40d<kK0=7Ag@3>c]H0^;Rm0:ZY[P2b/[80Z:NS0:FTW`2^Zj80/;6S0:BUU@2D
Th40RHQd08b;MP25Pfh0OG]V08=nJP2<Qg<0TX]h0:6GR`2YWiH0YibF09^?SP2LTY<0SXB508QoPP2C
RXd0SXR809^GU02f/Zl0^[Vg0<2o^`2o_[T0ZjZU09:?RP2DTH`00P2ET8`0302AS8P0T8^709F@RP21
O7L0JVMR05EACP1GEU80I6=Q06e]J`1ZK6/0IVYY06Q^K080KWA`0180JVmY05UNE`1EF4l0Gf9G05=E
B01?Cd<0DE94059CA@1@DD<0CTm104e=@@1@DTD0DeE:05EHC`16C400<SX_03I0=`0i@c/203m:A00P
03a7@`0nB4L0?dU803m9B019De80C5AF04]CEP1bMWd0K6mf07=fN`2UZ:d0eMGM0<[:e02;RYP0X9n_
0=;Ag`3Ngo40`<;I09^O_01KH7h0?dIS05MPO@1UL8`0Q8n]09NU`02L[<D0Xk?=0:RhdP2Y^M80ZkWC
0:bje@2]^mH20;6me`80/[gI01@0/KcH0;:mf@2`_]/0//3M0;6ofP2__MX0[K[L0:nlg`2__N80ZkWP
0:ZihP2[^^D0YkGR0:Ffi02U]NH0Y;CW0:>ci`2S]>P0X[?W09n`i0<0WZoS0180W[3R09b^h02G[=/0
UjcK09J[fP2HZmT0V:_F09JYe02CY]40TJC?09:Ud02@Xlh0T:;@08nQd@2=Wll0Rj3?08bPdP2:W]42
08VMdP80QIS@00T0PIC>082EcP20U/l0OI?<07bAb01jTLL0NXo407^A``1hS/000`1fRl001`1bQkh0
LhRm07:7_01bQk`0L8Jh06j4]@1`Q;H00P1^Pk801`1[P:h0J7f/06Mm[01VOZ`0IG^Z06AjZ`1RN:T0
0P1QMjP0601RN:T0H7JW05meY`1NLZD0GW:T05mcY@1NLZ@0G6jP05i`X01MKil0FVbJ05UZV01GJ9H0
F6RI05IVV@1EIIP0DV:F059SU`1>GiD0DF:F055SU@1@HY80CfBA04eRS@80BEn80200BEn604YMQ@17
FX80AUV004=FOP13Eg`0AUYo04EGO@15E7/0AUAk04ECNP14D7H0AU9h049>M014DG@0@Dmd03i<L@0n
C6l0?D]^03e9K`0nBW00>dM]03U5K@0g@f/0>D9[03DnI@0e?f<0>4=S03Q3H@0e?eX0<3YC038mD@Wo
oooo0007ooooo`1M069RF01lO7@0QH9m05EACP1SGeh0KFUZ05=>E01JEE`0DDiI03Pf@@18B580JVYd
06ATK01UIVX0EeQJ0453@00c=Rl0>C/`059DA`1NGe40KfmS08b<P02ATHL0GUiD0492>014AS/0?d4f
04mBB@1_MF`0FF=J04]EC01?Fe40FfEM05mYH@1UKfL0Jg9[075fLP1cN7@0N7Yi07QjM`1nP7l0PH>0
08N<R01/LF/0<cPb02Xa:P0]=2`0:2lV01hX7@0@6Pl0>4<e05MRE01<EdL0@4Th049;>P1;DD<0DeI;
06IWG`1fMG00ZZVW0=[Fe`3Dd]L0d<gD0=;Af@3Cd]X0eMCJ0=?AeP2g/k@0`[jm0:JSWP25P7X0Ti27
09fKSP2/ZY/0][BU0:2OS@2:RGD0RH]f08V8M01jNFD0N7MR08J3L02DTH80VY>909N@R02WWi/0Th^9
0928QP27PWl0O7If08J1OP2YY:00bLK100<0_[^f04T0^[Nb0:BQW02GU8l0RhN408n;R02ASH`0RhZ6
08b;Q`1WJ6<0Ce1;04mAC01BE540LG=b08Z>S@2?UID0Lgai055JE`1mQX40PHN306mfK`1HGEH0DUE:
05=GB@1<CT00ADHf04Q9>@1;C3X0BT/k04U;?@17BC/0D5A6051CB01=DdL0A4Xn03<k;P0g@CH0>D<j
03]6?P10BdD0?dY603i9A@14CD`0ATm>04mEE@1CEeX0D5AG08B4R@2RXJL0V9NL0;6`]@3=b]40fMSP
0<[:eP3Ge^@0nOWo0>7Pl02o`MP0JVj9055FM01EFg/0JG:A07b7Y@2DWkl0Xk3@0::bc02T]<h0ZKWC
0:Zje02/_=D0[;cF0:Zje02]^mD0[kgG0080/;kI0180[[kH0:nof@2`_]/0/;kK0:nnf`2^_MX0[[_M
0:jjh02/^^40Zk[R0:Nhh`2Y^^H0YKKT0::dhP2R]>@0Y;KX0::diP2Q/^H209n`i080WJkR0180W:gQ
09b^h02K[Ml0V:cN09R]g02FZmX0V:cK09JXf02GZMT0TjSG09:Te02@YM@0Sj?E092TeP2?X=@0S9gA
08^OdP2:W]4208VLe00608JId@24Ull0Q9OA08:Ec`1nT/d0OiC=0P1lTLP01`1lTLH0NXo407N>`P1h
SL80MHc007F<`P1cR/000P1bRKl03`1aR;`0KHBf06f4]P1]Pk@0KX>b06n4/@1`P[00KGn]06Yo[01Y
OZ/0IWb[06Un[@1WO:/0I7RZ069fZ00306=gZ@0T05mcY@1NLZ@0G72R05a`XP1LLJ00GW2P05a^WP1J
K9X0FF^I05QYU`1FIYL0EfNH05QUV@1FHiP0E66F059QV01AH9L0CUfD04mOT`1>H980CEn?04]PS@1;
HHX0B62604MMPP14FWl0AEUl04EIO@13Eg`0@UUk04=GNP13EG/0AEAk04MEO014DWT0@e5f0`12CW@0
4@11Cg@0?deb041>L`0lBVl0>dU^03a:K`0jB6d0>DM]03=1J00e@fP0=45T038oH@0e@V80>DAR03I2
G00a?580<SeA00Wooooo0007ooooo`0o051;A@1JEE40DDa904U3A@1nNGd0MWAi05mLI@1YIg80Fe]W
03LhA01FFV<0Ifab061XJ`1LHV80BU1>02H[9@0V:B80?Chf05mPF01kO7@0TY>;092AR`1^KfX0Bda7
04e>B@11@Sd0<c@_04Q:A`1PIF40F5iL04]AC`1DGEX0HFMU06AZJ01VK6P0K79^075fLP1fN7<0Ngej
07MiM027RX<0U9Z@08R>PP1RJUd06B4F01dU6P0Y<B@092lQ01dY6`0H91H0@4`n069^H01MJE/0FVEG
05iVF@1SJf00I6YP07MjL@2TYIl0_[fi0=?Bd03?c/`0d]7?0080e=;C03L0eMCB0=_He@3Ie=00fMC>
0;jj/@1nMfl0NW=Y0929O`2GThP0/jnT0;B`Y@2CSh@0Ph5d08J6NP1iNFd0M7EW08J7N@27Qgd0QHEk
09nOU`33`[X0QX=l08>0N@2;Qgh0L6]U07eiL02ZYY/0[j^P0:jZW`2g/jX0_;V`0<:o^02^ZjH0Ti:>
08n?S@2=Sh`0SY2?08b@S`24RXP0GfIT05AMFP1HHEh0BU=@06A]JP2U[Z/0W:FR086:Q`0kA440HfUU
08bAS@1nPg`0JFaS051CB015BC/0BDdn0080ADPg00`0AdXi04I8>@14AST0A4Hi04e@A@1?DTL0Ce99
04A7?P0i?cD0?T<l03Xo>011AT0304E:AP0L04U;BP1=Cdh0EeMG05aLG01KFe/0UIBD0;Rf]`2VY:D0
YjFV0;^f^P3He]/0knkd0?CdoP3Ogn/0[:jm07j0U`1IGGP0HfR606]aT@25SZd0W:G60:N_d`2V/M40
Yk;B0:NedP2Z^=<0ZkWD0:jle`80[kgH00H0[[kG0:ble@2]_ML0[KgG0:o0g02^_m/20:nnf`090:jo
f`2/_M/0[KcM0:blh02[^^40ZK[T0:Nhh`2W^>@0Y[SV0080Y;KT0P2R]>@00`2R]>80XK?Q09nag`02
09b^gP0<09^]g`2J[=`0VJ_M09RZg02HZMd0UJWL09FYg`2AY=`0TJCN096Vg`2@Xm/0SjCK0P2<XMX0
902=X=X0RikH08fNeP2<WMD0R9_F08FHd`25V=80PYG?086Ac023Tlh0PIC>082Bb`1oT<H0O93507b@
``1jS/40Mhc107R<`@1eR/40MH[307>8`@1cR/00LHRn0766^`1`Q[P0KXBf06b0/P1/PK00KGn]0721
[`1]OZX0JgbX06YkY`1XNJL0JgVZ06YhZ@80J7FY0100IGFY06=cY`1SM:P0H76U05m`Y01NL:80FF^M
05]]W@1LK9d0GFjL05a^W01IJiT0F6VG05QVU@1HIYL0FFFG0P1EHID03@1EHYL0Df2E059OU01@GI@0
CUjB04iNS`1<GX`0BUn:04UOR016G8<0A5Yo04=IOP12FG`00P10EgT03@12EWT0@eEi049DN015EGT0
@e=g041?MP13DGP0@4ie03m=M00nC7<0?ded03a;LP0iB6l00P0hAfh02`0gAVd0=TE/03=2J@0c@fL0
=49U034oHP0b?f40=T5O03A0FP0`>U<0<c]B00Wooooo0007ooooo`1h02`T8P0f<Bh0:R4T02`U;01J
EE`0H5eV06UWLP1LG6P0D59N04eAF`1KHfH0Ff=U04mHE@16CdX0;cH_02`a:P10@cX0EeQ@06QYH@1n
OgT0RHZ408f>R@1UIF<0Bd]904M7A@0m?Cd0>3Ph04U;BP1@DU40D5AC05QLF`1SIfH0IFUX06I[I`1[
L6`0KW=]07=fK`1dMfh0NGac07aoM02:T880VJ2>0868MP1ZLf006B8A02lh9`0e?Rd0:C@T02Xe9`0[
=b/0AE5505mYH01PJV80IFaU08N>Q`2CVID0S96;0:6SWP38b/D0bLW70<k=b`3@cl/0dm;>0=;Ac@3E
e=00f=OC0=[Hd`3Jem00h=cC0<k:_`23O7@0GUM?07mhL024P7L0UI2:09VDSP29QG`0NgQ_07]kL`1h
NVl0O7ic06maIP20PWL0Y:JK0;:cZ`2e]j`0SXj207emL@21Og<0P7aa07eiKP2<QWX0UY240;2WWP2i
/ZX0_KRb0;Ja[@2XY:<0VINH09BEU`2?Ti@0Qh^>08bAU022RX`0H6UZ05iXI`1MJ6@0FFAN07b5P02d
_KP0Yk6Y08:<Q00f?CD0C55:08J;Q02;SXD0LGAY04a>@@1:C3l0Ce530P17BC/03@15AcT0A4Hi04I8
?@13AS/0C4m6051CBP1AE4/0B4]404I9@P1:CDH0ATM204E6@@17AdD00P1;BdT0<01;BDX0C4Y;055?
D01SHF80OWam0:n][P2k^KX0ZJNZ0:^Y[02h][/0g=_Q0?CdoP3Ff>D0[:jm075dQ`1[KhP0HfR506eb
T025Rj/0WJ?30:B]cP2V[m00Z;7B0:beeP2Z]=<0[;OC0:fhe02_^]H0/[gI0:nmf02``=T0[koH0:no
f@2^_mT0[L7L0:^ofP2]_]`0[[oM0:fmgP2Z_Md0Zk_O0:ZlhP2X^^80Z[_V0:Rii02W^^D0Y[WT0:Bf
i080X[GP00H0X;?N09nbg@2O/]d0Wk;M09f`f`2K[M/209Z_gP0@09R]g02GZmd0UJWL09FYgP2EZ>40
TJKO092Tg`2?Xmh0SJ7L08jRg@2:X=`0RIoK08^Og02<WmX0RYgH08bOfP80RIcG01T0QYWC08BGd@23
Tlh0Pi?>08:Bc@20T<P0O8_207f>`P1lSL40Nhc007b=``1jRl<0NH[207B7`@1cQ/00LXO007:7_P1^
PkX0LXJk06j2]@1]PK<0KH:a06j0[P1^Ojd0KWn/0080JW^Y02@0JGNV06YhZ@1XMJT0IW>W06QeZP1V
LjX0Hg:Y065bZ01QLZH0GVnS05e_X@1JK9h0FffM05]/VP1JJiT0FfbJ05MXUP1HJIL0FfVH05ESTP1D
HY40E6:C05IRU01EHi@0EF6E05=PU@1AGY<0C5b@04iNS`1;GH/0BUn:04QNQ`17GH@0AUb104AJO`11
F7/203iEM`0=049FN@0oDgH0@UAh04ADN013DgL0@E1g049AN011CgH0?D]b03i<L`0mC7<0>dYa03Q7
KP0203I8KP0;03E7K@0cAF/0<D=W0395IP0aA6D0<T9S03A3HP0e@eh0=D5I038mD`0`>dl02Oooool0
00Oooooo03h07QPL02TT:00Z8bX071LN02<P:@18ADh0HV1[04I6CP14Adh0G65U05eVH`1CGE@0=Cld
02lg:P0g?C40>Cla05UMC`1fN6d0LW9X06AUG@1SI5h0Ogij07AcK`1@Cdd0@D0n03dl>P0m?C/0?Cll
055BD01LG5X0Hf=Q06MYI01ZK6L0K6mX075dJ`1bMFX0MGQ]07=gJ01aMF@0QHYd09nTS@2HWX@0G698
061YCP1;Dc/0AThg03Dm:00c>R`0<SP^03@i<P15BTH0I6QW07IjN`2;S900^[^o0<K7b`2m_/80`/?7
0<k?d@3?cm40dM7C0=?Cd`80e=CD0300e]KD0=WIe`3IfM@0g]kF0=[Gd02_[:<0LfiX04I3?01LFE80
IF9K06][H`1gMfl0OW]d07MdK@1dLFP0Ng]a07MiKP1UIeX0UIN:0;^m/02f^Jh0YZZK0:FWV@1mOW00
MG=V07ahK@1kMf`0PW]c08n6P@2QUY@0/JFU0<_0a02[XZL0WYNO09^FW@2DTi/0TI6K08>3S@1iO8D0
PXF<0866RP1aMgL0GF=O07j5OP2^]Jd0bm?80<?9_@2AUhT2059FB00[06IZG01gNF`0KfmS04e=@@1;
Bcl0CU1504I8?@17BCh0A4Ll04A7?P15B440AdY304a?B01?DT/0DeI?04m@B`1=CTT0Ce1;051?C@16
AD<0BTI504i:B`1>B4X0CDM;055;C`1IDeL0O7Mk0:BRY@31`<@0]KBj0:f/]02c/kd0_kk<0=?DiP3H
f^l0W:6g06AXP@1GGGL0HfZ707AjVP2AUkL0Z:k>0:^ad@020:fcd`030:^bc`2`]m@0/[[G0080/K_F
00/0/;cF0;6lf02__MP0/L7J0;30f@2``M/0/<7M0:k1g`2/_md0[;oO0:fmg`020:fmh@050:^mi@2]
_nL0ZK[U0:Nji02T]n400P2U^>804P2S]^40XkKP0:>dg`2R/mh0Wk3K09jaf`2M/=/0Vk3K09Z_g02H
[m/0V:kM09Z`g`2H[]d0UjgN09F[g02DZMd0TjSM092Ug080T:GN00<0SZ?L08^Qf`2;XM/00`28W=L0
0`27VmH0QIWD08BIdP0208>Hd@0g08FHdP22ULl0PiC<086Bb@1nSl<0OHg107b<`01kR/40NXW007Z9
`P1lRl@0N8O207F4_`1eQL00LX>k0721^@1aP[P0KWnc06eo/@1]Ojl0Kh6_06an[01/OZd0J7ZZ06Yl
[01XN:/0IgNZ06Qh[01SLjL0IGB[06=bZ@1RLJP0H76W061aY@1QLJ@0G6bM05][W01LKI/0GF^J05i/
V@1JJ9D0EVND05IWU@1GJ9@0EFJB05=TT01DII<0E6:A059ST@1BH940CUj?04iNT@1<G8l0C5b=04UK
R@0204UNR@0504MMQP15Fh80@UQm049HNP15FG`00`12EWT01@15Eg/0@U5h049AN011CgH0@U1g0080
@4eg0P0mC7D03`0jBG00=DM]03A6KP0dAVh0<TI[0396JP0aAFP0;TEU02e4H`0`AF80<DEN0394FP0b
@eD0<3e=02hlB@09ooooo`001oooool07P0O6R009b8X02PS:P0Q72<03``C03@a>01QH6H0BT]?055E
EP1OHf00FEmE04]A@`0c>RX0<CDT04E9>01JGD`0RHYl09fMT@2ATHD0C4a4038b:P1PGeX0Ogij05IE
D@0d<bl0=C@`03dl>00i>SD0FUYF06IUH@80JFQS01L0L75Y075cJ01cMFX0M7IY07MiK01kOg00KgAP
07j3K@28T7P0K7EJ05AM@P1hP6P0LGUQ05EMAP16CST0?44d03Pk<P0l?cP0Bde:07IhM`2MWIl0]kJk
0<W8cP020<S7c@050<o>e03>cM<0c/gB0=7@e@3DdmP00P3EeML0303Hf=P0emOE0=SHe@3Qh]`0eMK>
09bLU01OGeL0=c@]0492>01;Bd40EEE;06=SF@80M75X04l0LFeR07ajKP1cLfL0Ng]_0:j^XP2WYi/0
Y:JI0:RZW02RY9H0TiB607QfJP1aKF80MFiV08QoNP2LTHl0Rgem09R9SP31/[T0YIRQ09R:U`2ISY`0
VI6N08R0S`1hLX00R8:@09nLY`2a[[D0RHV;07moO@2f]k80blc60=?Fc@30`[D0P89d05MIB`1SIUD0
FE]=059DAP1DE4P0AdLk04U9?`18BSl0BT]304e>AP18BD40B4Y204U<A@17BT<0CE19051CC01CETl0
DU==055BC01CDTh0CTY704Y6@`1=AdL0EDa?05=:C@1BBD`0H5ML07meO@2h/KP0^[Nn0:j[/`2k^L@0
_;[70<C3d`3<cN80^;[C09>G/P1PI840G66106idU01lPZ@0VJ;30:Vbd`2Z/m80Z[?@0080[[GB00h0
[kKC0;>je`2d^mP0];_G0;:le`2b^mP0/KcJ0;2nf`2b`=d0/L3M0;31g`2a`N80/<?S0:g0h@80[;kT
00/0[;kV0:^mi@2]_^T0ZkcW0:Zmj02Y_>H0Y[WQ0:Nih@2U]ml0X[CL0:BfgP020:>eg@090:2ag02Q
/]d0WK3K09Z_g02I[mh0UjgL09F]f`2F[]`0UJgM0080TZ[J00X0TZWJ092Vf02>YMT0T:OM08nTf`2=
X]T0SJ;K08bRf`2:WmP0RIkG0P27WMH02`23VM80PIO@08:Hd@21U/l0PYO@07nDc@21U<h0OY7907f>
a01lSL<0Nh[10080NXW201`0O8S207Z6`P1iQL40NHG107F4_`1eQ;d0M8>l07:1^01_Ok<0KWja06em
[P1_Ok00Jgf[06YlZ`1XNZX0JWb^06Qj[01WNJ/0I7R[06=dZ01QLZP0HW>Y06=bZ@1OL:@0GfnR05i^
X@1LK9d0GffN0`1MJiX01@1IIiH0FFVG05IWU@1FIi<0EFJB0080E6FA0P1AHXh03@1?H8h0CUn=04iN
S`1<G8d0Bef;04QJR01:G8X0AU^604MLQ`14FX<0@EMn04AIOP12EW/00P12E7X06@11EGX0@UAj04=B
N@14DgX0@Tmi045>N010CGL0?daf03e:M00kBW<0>DQa03M9L@0gB7<0=TMb03=5K@0dAVd0<dM/02i5
I@0]A6<0;4AP02e3F`0_@EL0<D9D034nCP0]>dP02Oooool000Oooooo01d0:2HY02<Q900[9RX09b8V
01@B5@0_;Bh0I6=Q05aMF01NGeT0FeaC05UIC@1CE4@0=CHT03Tj:01IF4H0RHIe0;FbX`2@S800MgEY
04I3?00k>c<0Cdi905aKEP1CE4h0@D0k040o>P0o?3D0?Shf06YWGP0206i[HP0J06m/H`1cL6L0MG9Y
07=cJ@1jO740QhUn07QlKP14B3X0CeI605iVE`1/MF@0O8Mf07=nK@1VLF00IVmN06=[G012BC`0A4Xn
04M:@@1CETd0SHj80;:c[P35a<80bLG60<c7b`3?b<l20=;=d`1P0=?>e@3EdmP0dm7F0=CBe@3GeMP0
e]CE0=GEd`3Jf]L0fM[D0;fn]P25QWh0ADDk02l_9@14A3P0CDe104i<?`1ACd80NWMX07mlK@1[IET0
KfUM081lL@2HU8T0/ZnV0:FRV@2TXIP0X9nE09fMT`2VYY`0SX^2079[H`1cJVD0SXF009jCT@28NWX0
SWf30;6MYP2UTI`0XHfI09j9V02@OX`0O6Yj0:2>WP2n[;X0_Zji0=G6d03Aa/`0Zj2T0<[1`P3Hdm00
`Kji08n?Q@1VIUX0Cdm3061RE01LGU40Ad/m04M9?01:C440BT]304]<A01<CDL0BDY404I7?`19BD<0
Ce1:04]<AP1ADTX0EUM?05QID@1CDdT0DE5705EBB`1>Bd@0BTE104Y2?`1CBdT0FDm@065GF02:Oh<0
YIZP0;ne_P2[Xjh0YIn/0<c8e`3Rh>h0eMCV0<W6h@24Pj80HfB305ULO@1^LYL0PHN[09^Qa@2T[Lh0
Z[GC0P2[]]806@2^^=<0/;[E0;6je`2b^mP0]KgK0;Fkf`2c_=/0/kcM0;:lg`2a_^00]<7T0;;0i@2a
_n@0/L3W0;73j`2^_nX0[;oY0:Zmj02/_nT0ZkkX0:^nj@2Z_NP0Z;WT0:Vji02Y^n400P2X]mh03P2X
]]/0YK?H0:>af02R/MX0X[7L0:6bgP2M[md0VZoN09^ahP2G[ml0UZkN09Vah@2DZmd0TJSJ0P2BZM/0
3`2?Y]P0SZGG08jUf@2=Y=P0S:?G08nTf`2<XMP0RZ7G08VPeP29W]D0QYcE08FKe023W=@0OiS@082F
c`02082Fd00307jDcP1nTlh0O8o:0080Nhk80140NX[607R8a01jR<D0N8O207F4_`1fQL00MHBo07>2
^`1fP[`0Lh2e079o/`1bP;40L7j_06il[@1/OJ/0JgbZ06YlZP0206UkZ`0D06EjZ@1UNj`0HGFW061d
Y`1QLZH0HG>U06=cYP1QLJ@0Hg2T065^XP1QKJ40Gf^O05eYW@1NJYh0FVNK05]YW@1GIiP0E6JD05EW
U@1BI982059UT00704mRS01>HH`0C5n:04aMR`1>Ghd0CEj<04]MR`0204YLRP0P04QJR012Eh@0@eR3
04AHP`13EX00@eIn045DO010DWX0@E=k04ACO012DGX0@Tmk049?N@12DGX0?ded041<M00nBW@0?4]d
03Q7L00hAg80>TQe03M5LP0eA740=4E`0396J`0aAFP0;d=T02m2H00`?e`0<D1G038mD@0]>DT9oooo
o`001oooool07P0c<CH0<c4d038`<`0e<c@0=C@b04E4@01KFUD0FUYB061PEP1KFD`0E59305]HA`1I
ET<0GU]:051=?01]IeT0Ui65079^H`1MF580Ddi8048o>P11@3/0De9>05EDD01<BdH0De1;04I3?01J
Edh0OW]b07MeJ@80M79V01T0MG9Y07AdJP1hN6h0PH=h07UjLP1;CTD05APA0415?P1IH5T0K7I]06eg
KP1RK6<0I6iS06Q`I@1YKfD0G65G05IICP1RI5T0LG=X0:>UVP36a[h0c/_60<c8a@3@b/X0fM3C0080
eLoC00<0e/oF0=OBf03Gd]P00P3FdML0<P3FdMD0eM?D0=gJfP3@cld0WYnJ06=TGP0o?ST0@T8j04i>
A01ADDD0D4i105ABA@1`KUl0MG9S06USE@1TGU80Pgmc0:6MTP2ZYYd0VIJ=09jKU02WYIl0[:bT09ZJ
TP28QGh0KfYT07=[J024NWP0THJ409N9R@2KRhh0Y96E0:RCVP2GPX/0UX2<09=kR02VT9`0b;:n0<6[
]`38];l0mNG/0=oBf@2HS900YIZN0;2ZZP2@S8T0L6mZ05AEC@18BD40D5970`1:CD8204Q;@P0704U<
@`1=CTP0AdQ204Q8@019BD40E5A<05UJDP02061RE`0N05IHB`1=CD40C4a004m=@@1ACd<0Cd]204a5
?`1DC4T0IUiK07Q`KP2XWj00^K2c0:^QZ@2LUId0]Znm0=;>g`3HeNH0]K?808b<Z01QHX40J6^<06a`
T`23RJd0WJ?70:Vae@2V/M40ZKCB0:Zed@2/]m<0/;cF0P2b_]P00`2d_m/0/kgK0;BmgP020;Bnh@0;
0;2mh02a_N<0//3U0;70i`2b_nT0/L3Y0:o0j`2``N`0[/7/0:^nj@2/_nT00P2[_^P0?02Z_NL0Z;_S
0:Rkh02W^Md0Y[SL0:Rhg02W]MX0YK?H0:>bf@2R/MX0X[7L0:6bgP2N/>00VjoQ09V_h@2G[^00UjgO
09N^h02CZ]h0TJSL092Wf`2AYmT0SZGG092Vf02>YML0RZ7C08VPdP2:Wm@0Rj3E08VNd`2:Wm@0RIkC
08JKdP23V]00P9W?082Fc`1nUll0O9G>07ZCc01kU<d0O9?=07^Ab`1iSlT0N8c707R;aP1gR/D0MHS3
07N7`P1fQkl0MXFn07B3^P1dQ;P0M7ne07F1]@1cOk40M82b075m[`1_OJ`0KWb[06]lZP80J7ZX0300
I7VV06=jYP1RN:L0HGNV05meYP1MLJ<0H7:R05maX@1PL:40HFnP061^W`1QKZ80Gf^O05iZWP1NJIl0
G6VN05QXV`1FJ9X0EVRH05=XU@1@II80CfBA04mTS`1>Hhh0CfB?04aQS01;GXT0Cf:=04UKR@18FXP0
BUb<04UKR`18FXX0AEN504AIQP14F8@0AUN304AEP013E7l0@e9m045@N`12DG`0@Tmk045>NP14DG/0
@U5h03i=M00oBg<203]9L00303Q7L00jBG@0>dYe0080=dEb00T0=D=`03=5K@0_@fP0<D=W0392I00_
?Ul0<ciJ038lE@0_=d`02Oooool000Oooooo07H0BTU?04I5BP14A4H0@T9204E6@@1ADT`0EUI<05AD
B01IEdX0F5I805ICA01YHeD0MW1P07E_H@18@S@0=BlS06mXH01mMG80J6=P04e8A@0k=c@0ADA205]J
F01MFEP0GUYG069NF`1ACDX0L6mZ08b=Q@1eN6d0LWIX07AhJP1gNVl0Ngic07UlL`1[KVD0BTe602DW
900N81l0?T91059FE`1OIFD0HVQX06=YI`1WK6P0JFiX06U[IP1ZJVD0OGYc09^KT`2XZ9h0^;R^0<O4
^`3;b;l0c<W20=?>bP3Ed<d0em7A0=K@d03GdM<0f=;D0=[Df03Id]T0e/oF0=C=e03Ebm<0g=?K0;ni
_@1lMg/0FEEF04]7B01=BDP0CTe9055AB@1CDdT0EUI:05mPDP1TIEL0IVAG05UGBP1cLF@0VIV=09BD
RP2ATHL0ZZ^S0<C5_`2Z[:L0NWag06]/IP1mO7L0Q85l08AoN`2@R8D0UXb:09>8QP2[WI`0^JVZ095n
P02UTY@0^ZJX0;>PXP2eXZH0^j^^0=72a`3Xg>80elkC07MbMP1FE5L0PGn0071`L01RI6<0CE5@04A9
A@13B480@TM004M:@`1<CdP0CTm90P1;C4H02`1<BdH0B4M204U9@@14A3/0Fe]?06MYG01ZK5h0G5i@
04a>@01;CCl0CTm10080DDm201H0Ddm404i:?`1?Bd80N7A[08n<Q@2NViH0Wi^H09ZFU`2[ZJ`0clgF
0;nnc02CU:H0MWR=06U]R01VJhT0L7JF08J?/02OZ/X0Yk;B0:Vde02W]M80ZkWF0P2[^M@02@2__MP0
[[cF0:jleP2b`=/0/L3M0;70g`2b`N80]<;U0;6oi0020;30i00M0:foh`2a`>L0[;kT0:foi`2[_^H0
[L3X0:boi`2Z`>D0ZKoT0:Rni@2Y_n@0YkkP0:>jfP2R^MT0Y;SI0:Bhf`2T]]X0Y;KL0:6cf`2P/M`0
WJkJ09f_g@2M[ml0VZkP09Z^h@2FZn00UJWN09FZg`2DZN000P2BYm`01`2BY]/0SZ?H08jRe@2>X]D0
T:CI08bPe@2;Wm@00P2:W]<03029WM80R9cA08FJc`21U//0PIS<082Ec01oU/`0OIC:07fCc01kU<`0
Mi3807J?a`80MHk601X0Mhg607B;`@1bQkh0LhRm07>7^P1cQ;P0LXBf07:2/`1bO[00M7j_07J0/@1c
OJh0KWZZ06ilZ`1]NjP0JWbX06IiY01UNZD0HgRS061gX@1RNJD0H7JU05meY01PMJ@0GgBQ05aaWP80
GW2N01@0GVnM05e]WP1KJi`0G6VM05eZWP1JJYh0EFJJ05=WV@1BIYP0D6JE04mUU01>II40CFB@04iU
T@1:HXh0Aen;04IMR@18GHX0AU^:04IHR080BUb:0P18FHL00`17F8H0AUF204IDP@0204AAO@0704A?
O@15D7h0@Tej03i;M`10CGT0@e1j03m>M@0303a<L00403Q8K00jBG00>DQ_03U8L@80=DA_00T0=4=^
02m0J`0_@6/0<3mX0350I`0_?F00<CaL02dfD`0Z=4l02Oooool000Oooooo03D0FeaQ05EFF`1ADUH0
BTa;04M9A01@DD/0EUQ=05EEB@1CE4H0E554059>@P1ZI5P0NWAX069KD@1?B3h0AChh061HE@1gKVl0
JVAT03hh>00m>CP0Cde>05eKG01RGUd0I61O06QTH`1NGET0HfAN08F:P01ZLVD0K7AU06UbH@1mQGH0
VZ:C08jFR@1OIET0:c0Y028T8@0X:RT0>c`n05IGF`1OHfH0IVMY06Y/J`1^KV`0KfiZ06eYIP1hLVd0
XYVD0<:k/`36_kL0b/>i0<g6_0020<c8_@120=;;``3Cc<H0eLg:0=O?c@3Gc/l0fm;C0=gDf@3LdmP0
elgF0<o5cP34^/<0^k6j0:FNYP1_J6l0@ci204Y5B@1?CDh0DE1<05=BC@1DE4`0FeeB06=UF01TIUP0
HF=F05mQE01cMFL0SY220824M@29SGl0^Kf_0>W_hP31akd0NX1f065TF`2=T8L0XJ:J09VIT@2FUXh0
VYF?07YfK@2/YId0bL2i0:jSW@2_XIh0aKRb0:ZMU`2ERXH0/ZNU0=S@cP2n^KT0Xj6R06i^KP1<CTd0
I6IU05]OGP1GGE/0BU1>03]1?@0m@cl0?dHo03m4?@1=D4T0DeI=05=FC`1?D4P0CDi80P1:BT808`1<
C480GV1C06QZG@1QHeH0Fee?04Q:?01;CCl0BT`n051>@@1BD4<0Ee=8055=A01?Bd80NgI`0:NTW`2E
U900NgUj09^KW@37a//0b<SB08:4T`1PHgH0EEY`06meS`20Qj<0Tibi0:2Yb02^^ML0ZKOD0:Zhe@2]
^mP0[[cI0:nmfP2__MP0/;kI0080//;L00@0[koI0;71gP2ca>80//;S0P2c`nD0102a`N<0/<?T0;33
i02aa>D20:k1hP0H0:g0h@2^`N80ZkoP0:Zng`2Y`>00YkoQ0:S1h02U_]d0XkcJ0:6jf@2S_=/0XKSJ
09nefP2P/m/0XKCN09nbg@2O/Ml0VjgK09R]g02J[^00V:cO09JZg`2EZMh0UZ[O0P2BYm`2096UfP80
SZ;G00/0S:3E08bOe`2;W]H0RikF08VNe@29W=@0R9gD08NKd024VLh0PIK=082Ec002086Fc@0507jC
bP1mU<X0OIC:07VAb01eS/H00P1eS/@0701fSL<0M8^o0768_01cRK/0LHNi07>7^@1bQkH0MHNe07:0
[`1bOj`0Lh2]075nZ`1`O:`0KWb[06]lZ01/OJX0IWRV06AiYP1SN:D0HGJS065fY@1RMjH0HGJU069d
Y01MKid0GW6L05mbW@1MKid205U[V@0605a]V`1IJIX0F6RK05MYV`1DJ9/0DVRI0P1@IYL0901=II<0
CVJD04YRT01:HY00B62>04MOS@16G8/0Aef<04MKS@14FHP0BE^;04MIQ`15EX@0B5V704MHQ017EH80
@e1m04MDP015D7d0AU5o04A?O@0nBGH0?DYf03i;M`11CWX0@4ie03a<L00kBW40>d]_03Y9L00iB6l0
>4M^03M6K@0eA6/0=DA]0391JP80<D1[00H0;ciW0390I`0^>eh0;3UI02`gE@0Z=E49ooooo`001ooo
ool0N@1mP8L0L7=h06ibM@1cMgH0KgA`06IYHP1HFE40FUaA05AFB01GETT0FeQ?05QDB`1DCdT0B40m
05A<BP1XHV80IV1R05mIG@1:ADT0=S@g051>C`1IEeP0HV1Q06=RH01SHUh0IFAP06EVH01VJF00KgIY
06ehI`1ZMV80K7QR08VEO`2U/I/0Q91l04iIB00X;R80:BlU02/`:P0i>cP0EEMF065QH@1XIfD0KFUV
079ZI`1fKFP0MV]W07e_J02WUXl0`:nX0<>d[@36^:l0d<>j0=36_03Bb;l0d/W20<k5`03>a<80dLW7
0=K=cP3Gc/l0eLoC0<:l`02d[KD0Yj2X09bDW`24OhL0K6Y_05eKGP19AdP0Cdi:05EDC`1ADDT0EUM?
061RE`1OHEH0IVQK06MYG01FFT`0Ce=408V@OP2EWHP0IViI07j8L033cKD0hngD0<K>]`2NYY40ZJfL
0;:fY`2c]jP0Yj^L09^OT02FVX/0PXIe09BHQ`2a]:<0[JjP0<O5^02k^Jd0ViV=08n;PP2WY9/0^;F^
09JFT@28R8H0MGMb06MYI01LHE/0FF1I051JDP0lASd0>48i03e7?P0oBD00?4@i04A<@@1@ETX0E5Y@
05=FB`1BED`00P1<CT<00`1DET/0G5iC05iPE@0205EHC@0G04U<@@1:C440C4i304e:@@1CD4L0Ee9<
05aDD@1SFU/0MVe`0:VSY`20Nh40IFA/08j>V02d]<00XjJd05]QL@1JGg<0IF^107n7WP2EW;H0[;K?
0;2je@2a^]L00P2_^]H00`2a_=P0/;kK0;;0g@020;6ofP0=0;71f`2`_m`0/lCP0;?4h02ea^@0/LCR
0;74i02c`n@0]<CU0;?4hP2ca>00//?O0;72g0020;72gP0D0;31g@2^`Ml0[<7N0:W1g@2W`=h0Y[oM
0:Bog02S_]`0XKcJ0:6kg02P^=`0X;KK09neg02N]=d0Vk3K09bagP2J[m`0VjgM09V]g`2GZmd209BZ
f`0?09>YfP2CYmX0TjOJ092UfP2@YM/0SZ?J08fPfP2<WmT0S9oJ08VMf02;X=T0QigF08NLe@25Vm@0
QI[C0080PiSA00L0PIK?086DcP21U<h0PYG?07jCbP1lTLP0O9770080N8g400@0Mhc307J;`01cR;d0
M8Vn0P1bR;X01`1`Q[L0LXRg0766]@1_PK40Kh2^06io[@1]OZ`00P1^OZl03@1/OJ/0JG^/06MiZ`1T
MJT0IGJZ06=dZ01RLjL0HgBX069dYP1RLZD0H72Q05m`WP1OL9`00P1PLId02`1KK9P0F6VE05Y[U`1I
JYP0FF^K05AXV@1CJIX0DVRI04mWU`1=IID0C6BD00<0BV:B00h0BEn@04MMSP18GXl0AUb>04AJS016
FX`0AU^:04UKR@16F8H0B5^604IFPP17E800AU=o04AAO@80@e1m00X0@4ej03m=NP0oCGX0@Tmk041=
M`0oCG@0>dQb03]9L00oC7H0>dU`0`0iAfh02P0gAF`0<T1W03=1J00a?fH0<3iU0390I@0`?El0;SaI
02`jE00Y>4l9ooooo`001oooool0X@1iOX40PHN808^AS`29T8X0P8El05]QE@1<CD<0D59605QIC@1U
I5T0FeQA04<o>014?ST0?SHd05iDE02GSXl0O7Ee05E>D00i<SD0BTI605mLG01NGE`0I6=P06=TG@1S
IE`0IFML06MZG@1]LF40L7QT06]fG`1hPf/0N8=Z07F0J01;ESl0?TTd03Dn;00[<B@0;S8X03Hk=01:
C4P0FUYI06=QH@1ZIVD0KfQV06eSH`1^I640LVER07Y[IP27MW40U85l0:2>R@2PShX0[ijI0;RXX`3=
_kT0cl6n0<Vl^P38_;`0b;jn0<Jm_`39`lD0clW;0;^f^02DT9D0P7f107QfN@1MGEl0DeAC055BC`1@
DTX0Ce1605]LD01LGe00HFAD07EfI`1aLf80K6aK06YZF@1`LF00KVmM07UkI`2RYi00UiV3092DO@36
b[<0bLjg0<33[P3@dKl0d];10;BdY@2/[9l0/K>U0:6SU01iOF`0U9V50:Z_V@2d^:80^[fZ0=OIa`3D
eLH0_/2a0:BUUP2IVH`0TiF908j@Q`2AU8/0PHAj05MJD01?DdT0CeI<04A<@P0nAcd0?dLn049:@@12
Bd<0>D8i03Y1>01:DDP0DUY@05AKD01CFDh0CU=804eAA`1FF540DeE>04i@BP1>DD/0CE5;04Y>B@18
C4L0Bde904e>B`1GEE@0I65S065NHP1RGVH0IF1Z06]XL`1RHG00GUm^06M[N`1cMhT0K76406edR@1k
PYX0SYJ]0:V`c02_^=<0[kSE0;2je`2`^]P0/[gK0;>og@2`_m/0//3N0;;1gP2a`=d0/l;O0;?1g`2c
`^00/l;R0080]<CS00L0//;Q0;G5h`2da>80]<CR0;C4h@2ca=h0]<CN0080//?L02T0/L?L0;31g02_
`=d0[/3M0:^og@2Y_md0Y[cM0:>jg02S^]l0XKWP0:2hh@2P]n<0WkGQ09jdhP2M/^80W;7S09^^h@2K
[N40WJkR09f^h@2HZ]d0UZWL09R/g02FZMT0UJSI09FXfP2CY]P0SjCH08fRf02<X=T0S:3J08^Of`28
W]T0RZ3K08BKeP23V]D0PISC08:IeP21V=<0P9OD082Ed00207fCc080OI7:01T0OY7907f?a`1iR/@0
N8W307N8`P1fQl40M8O107>6_`1aQKd0LXJn07:7_P1^Q;P0KH>g06b0]@1[Ok@0JWnc06Yn/P1/O[80
K7ba06el/@1ZN:d0JWR_06Me[01VLjX0Ig:Y0080IG2V0P1RKZ800`1RKj40GfbL061]V`0205m]VP0@
05a]V01KK9L0FfbH05Y[U`1EJ9@0EFRG059XUP1BJ9P0D6FG051TU@1>HI@0CF2B04aOT@1=Gi80CV2C
04aNTP80BUb?02<0B5Z=04IIRP18G8/0BE^904AGPP14FH<0@EIn04AGO010EGX0@5Ah03mBN@0nDGP0
?Dmg03]>MP0kCGH0?Tih03i=M@0lBg<0>T]c03Q9L@0iBG<0>TQb03U7L@0hAfl0=TE]03E3J@0b?f@0
<d5V034oH`0_?600<CiQ034mG00`?EP0<3]C02/fCP09ooooo`001oooool0?01oQHD0NGmm07j5OP1X
KV@0@DLi04=7>01CEDL0FE]=05mOD`1OGU<0Cda505]FD01QG5H0>c@^040i<`2NUi40LFUV04U1?P0m
=C80DDa906IRG`1WIV80JFQS06YZHP1WJEh0J6YM06]]G`1`LV@0O81_065UE01VJUT0OX9a07IjJ@15
BCP0=c//02X^800Q91T0<SD/0454?@1FF5<0I6=Q06ESI01YIFH0JFET06=MG@1KEU<0FU9?06=IEP1`
IF40M6IS085cL01oL6d0NVYZ08UiN@2gYjL0]JFV0:BFUP2YWIl0ZInP0:jUYP80]K2]02<0XIfJ092?
R`2CU8l0WYnJ07]mMP1XJf@0JF]P06Y/G`1VIeT0Kg1P07UjJ01fN6<0MWEQ07IeH01hMV40MWAO07Yg
I01mNVL0M75N07aiIP2CT7d0];6P0;bfZ02c/:<0clg00<k:_`3:a[/0ZZJM08f:P@2OW9D0ZJJM0:NU
V@2`[Z40c<Zk0<k=^`020:f[W00J0>7OdP3akn80`Knb08^;O`28RWl0VYbA096DR@1VJEh0B4]003e0
=`16BD00@4<l03a1>`0oA3h0@TM104=8A00h?SX0;S@`0498A01JI5`0FF=J05IME@1AETl0CeA=04a@
BP15Ad@204e?C00G04Y<B`15BDX0@dM:04U>DP1;CU<0CU5H05QKI01CEUl0F5YW05iRKP1GGF/0F5i^
05]RM01RJG`0I6Z006mfS`2@Uk<0Yjk;0;2ge02_^=L0/[_L0;2kf`2c_N000P2e_n80102d`N40/l;Q
0;C1h@2b`N020;C1h@050;G2hP2e`>00]<7S0;K2i02h`^D00P2g`^801P2d`N40]L;R0;G4h@2d`n00
/lCP0;;3g`80[/;M0140[[oM0:jng`2/_=h0[[kP0:ZjgP2Z_>80YkWQ0:BghP2O]>40WkCS09fah`2N
/^D0Wk?V09b`i@2L[N<0WZoW09f^i00209VZh00409RYg`2IZ]h0VJ_M09JXfP80TjOI00`0Sj?E092T
e`2>XmP0R9gD08RMeP29WMP0QigG08JLf024VMP0PIKE07fEe@1oUmL207fEe@0707ZBd01iT//0Ni7;
07Z?b01kT<T0Nhk607^=a@0207R9`@0307R8``1eQL40Lh>o00<0L8;000`0KX:m06n4_@1/P[/0JX2i
06Mm]P1YOKP0JWji06Mj]01WMk80JgZc06Ud[`1WLJ`206IaZ@0706M`Y`1VKJ@0IFbR06=]XP1RK9l0
HVjP05m[W@0205e[VP0305Y[V@1JJiL0EFRC0080F6^F00L0F6ZH05EWU@1CIID0DfFE055SU@1AHI@0
D62D0080DUnC01`0D5fA04iKS`1?Fhl0C5V=04eIR`1;FHX0AEF604UJR01:FhT0@UF0049EO`0nE7X0
?UIh045HN00oEWH0?5=c03]BLP0kDW@0>E1b03U=LP0kCg@0=TY_03Q<L@0gBW80=DQ`03M9L@0gB7<0
=dIa0P0eA6d00`0eA6`0=D=Z03I4J@0202lmH00502llGP0`?U/0;cYF02hhD`0/<dd02Oooool000Oo
oooo01D0JW=`06M]J@1VJfD0FUeD0453>018BSd0De=705]KC`1HF4`0AdLl071`IP1jNW00J6QN04i>
A015AC/0J6QN04i>AP0m>S<0@d0i055@B`1[JVD00P1YJ6<0O@1[JVD0KFaW06a[IP1]K6L0L6eX07il
M`1=C4L0C4e7071aJ@1dMFd0H65I05eOE00i>c00828G03Hh;@1=Cd@0GUiF06ETH01XI6<0L6YZ05eH
E@17@Sl0BTE104e8A01DCTT0HeaD06QQF@1aJ640LFIP06iSG`1cIF80/jFR09N<RP25NWP0S8:008R1
N`2GT8X0Y:2G09fIT020O7<0LFmS07UgJ`2HUXX0TY:807UiK`1iMVd0OWY_06e[G`1UHeL0O7Y]08B2
L`1eLV<0JVMF06]ZF01iN6@0QXEc08^:N02:R7T0OWa]085oLP2LVXh0ZZNN0;>aZP2n_[H0f=G>0<k;
a02MVYD0MgIb09>BS@2RXI`0[Z^T0;BaZ032`;@0alFi0;bh[@3Gd<H0l^_Q0=[Cb`2GThX0PGaf08j;
QP2PWiX0PX=m03/l=012@c/0@T<m04A6@@10@Sd0A4I304=5@P11AT80?d=203Y0?P0a=cD0@DY505eW
G`1JI5`0F5mH05IMEP1=DT`0B4a704E5A@1<C4h0C4e?04e>DP17BTl0ADUB04I=E`1=E5h0C59N04YB
G@1;Deh0EUe]05mXM`1FGg00E5a_05eSN@1QIgl0JW6;08:9Y`2b^=X0/kWK0;2ff02^]]X0/[cO0080
]KgQ00H0];kQ0;FohP2e_n80]/?U0;S2i@2f`n<20;S3h`040;W2h`2i`^40^KoQ0;_0hP80_<;T00T0
^<7R0;O2hP2d`N40]LCS0;C3hP2b`^<0[koP0:g0h02]`>400P2__n<00`2[_N40[;_R0:Rgh0020:Vh
h`080:Nhi@2R]>80XK?S0:2bhP2P/^@0Wk7S09f^hP2L[N4209f_h@0B09VZgP2FZ]d0UJWN09J[h02B
Z=X0TjWK092Vf02?YML0SZGG08fTf02<XMP0Rj3I08VNe`28W=L0QY[G08RLf`25V=X0PYGG0P23U]X2
07nDe`0807fBd`1jSlh0NY3<07^?bP1jSlP0NHc407Z=a@1fR[l207N8_P0<07J7_`1dQKd0LHBn06n4
_@1^Pk`0KhBm06b1^P1ZOkP0JWji06Um^01ZOKP0J7^f0P1XN;@00`1XMk80IgF`06Ib[00206MbZP0@
06E^Y@1RJj80HVbQ06=]XP1TKZ<0HfnS065^XP1NKZ40FFVL05UYVP1FJ9P0DVNF05I[VP1DJIP0DfRG
05=WUP<0DF>E02`0CenB051MT@1CGi40DenA059NT01@G8h0CUR;04]GR@1=EhP0CEV904]GQ`1:EXH0
AeF404IDP@14EH00@UEn045GOP11EGX0?e=f03eAM00kCg80>E1b03Q?L@0iCG80>Tab03U;L`0hBW80
=TQ`03M9L@0kBW<0>DQa03A6KP0cAFd0=dUa03=5J`0eA6/0=4AX0310I00_?f<0<T1S030mG`0_>UX0
;3EB02/eD0Wooooo0007ooooo`0n06=/J@1XKVX0GfAN051CBP1=Cd@0De=7055BA01EETP0CTm103Lg
:P1mOG40O7ia05eODP17BC`0Ce5605=EBP1;CD80AdLo04m?A`1LGED0JFYR06YYI01]K6L0LVi[07=_
KP1bKVl0LFe^071ZKP1hLgT0C4Y?05ABE@1`L700MgMe06i_JP1LGeH0B4]003do=015AcX0FUa?05eO
E01QH5/0IFAP06EQGP19AD80@3`i04Y7@P17AT40Cde705]HD@1NFe80HEeD06ENEP1VGeT0JV5L0967
Q@1aJFH0L6QU07IaJ`1fLVT0OGU`081lL@1jN6`2079`I00/07EcI`21Og<0RHIn07aiM01iM6h0OGQb
06QSG@1XIE`0Og]`08J2MP1bKf00EE9305eLBP1kNVP0V9N509JDQ@29QgP0QhEh08f9P02:Qh00WibG
0;bj]`3=c<X0moKd0;nm_P20OX40RhV<0:^YZP2][:X0[jjZ0;Rg/P31`KT0gM[A0?Gaj03jm^d0e/o7
0:RQV@1/If40M75/08J5P01hN780CDi803Dh<@16BD8204A7@0030494?`19BdH0AdU60080@DI204l0
>Clk0416@P1CG5L0G6IN05iUGP1WKVL0J6eW04M<AP17B4H0ADE704M6B`1=C580BTYB04Q;E018C5P0
ATaH04iFH`1;Df00C5IR055JJ@1EHG40F6=e05AOL@1GGg@0GfEo06I[R01oQ:80XZK80;>gg02b^=`0
/kWM0;6ig@2d_>00]KgR0;Fmh@2g`N@0]KoR0;K0h`2g`N@0^L?V0;O1i02h`n<0]l;R0;[3i02l`^@0
^/3R0;^oh`2m`NH0^l7U0;S0i02g`N@0]<7S0;6ohP2a`N<0/L7U0:jnhP2^`>H0[KoU0:jmiP2]_>D0
Zk[S0:bki02X]N40Z;GR0:NehP2X]^@0Y[OU0:>dhP2Q/^00XK7R09n_h02O[n80VjgO09b^gP2IZmd0
UJWL09N[h02CZ=d0U:WN0080T:OK0P2=Y=P02`2:Y=L0RZ?G08ZQe`2;X=L0RIkG08ZMe`28VmH0R9[H
08JHf022U=H0PiGG0080PI;G00l0P97F07jAd`1kSlh0O93?07b@c@1iSLP0NXg707V<a01gRl00N8Vo
07F6_01fQkd0MHJl0765^P1aQ;`00P1_P[X0101/OkL0KH2h06in^@1YNK@206Qh/`0A06Ui]01YN;<0
J7N`06Me[P1TL:X0IW>Z06MdZ`1UL:H0HVfS06=^Y01QK:80HFjS05m/X@1PKJ80GVjR05a/X01JJYd0
0`1HJY`05`1FJ9X0EFNG059TU01CIID0D6:B051PT@1BH940DEn@059NSP1@G8`0DE^<059LS@1@FX/0
CeV:04iHR`1<F8P0C5J904]GQ`19EHL0B5B404IDP@14EH40@5=m0080@5=k01T0?U9g03eAMP0jCW40
>Tia03]=L`0iBg40>4Y`03Q:LP0fB700=dUa03]:L@0gAVd0=dI_03I8L00cAFd0=4I]03=5J`0bA6X0
<d9Y030oIP0`?V<0<CiQ02hkG@0]=UD0:C9?00Wooooo0007ooooo`1/069[IP1OIUl0DeQA04mBA`1B
ETP0Ce5304e@?`1CETD0ATTf03Dh9P1MH4l0IVQJ04A6>00k?c00CU9405AGC01HFe00FeaD05mPF01R
He/0JFYR06i]J01cL6/0NgIc07miN`1gLGD0B45904i8DP20NhP0BDMB06MWK`1iO840Jfm`06M]J@1N
IU/0F61C05EKC@1GGDl0Gf=E05mRE`1PHeX0EUUB04]=B010@Sl0@d=104E6@@14AD00D51;05YIE01L
G5@0Fe]C05mLE`1SH5/0GeaG069NF`1OFeP0Hf1K06IUH01SHe/0HF5I06MWG@1]KF<0K6aT06m_I`26
QH00KfiZ05mNG@1^K6l0LVi_075`KP1]K6P0KfiY07AaJ01dLVH0KVYN051=?01IF4@0LG1L085nJ`24
PFh0PWm`08f9O@2TWID0[JFR0;>^Z`3Ed=@0i^7X0<g:d@2_[;D0THnJ0:NU/02d/k/0Z:N/0:^[Z`3?
d</0fM[B0>SZg@3Rh]H0g=[>0:VYW@1hN6h0HF5G071aJ@1WJV40CE=904U?A@14BT00B4i40P15Bd40
1`1;DDL0D5I<04M<A@13B440Adi60499@@1=E4`00P1AF5003P1gOWH0Nh1j06icK@11AT80A4E404A2
A`13@TL0C4]A04a<E01;BeD0AdUF04U<F`1;DEl0CEER0P1JHg802P1IHW<0FV9e05QPM@1NIWd0KWB>
07j3X02LXKl0/;?E0;Bfg02c]mX20;Bjg0080;Fng`2e_N40^<7R0;O2hP2e_n80]/?U0;S5j02h`^D2
0;O1i0040;FohP2g_n<0][kR0;Noh`80^L7V00/0]l3W0;C0iP2d`>P0//3W0:jmi02]_nD0[/3X0:fo
i`2`_nX0[kkY0:jkj0020:fji`060:^hi@2X]>@0Z;CT0:JbhP2V/^40YK?P0P2Q/]h0302Q[mh0X:kM
09n_h02M[Mh0VjgO09RZg02FZ]l0UZWQ09BWg`2DZN00TJSN08nVg080SZGK01`0SJCJ08ZQf029X=H0
RYoF08VNe@2:WMD0Qi[D08FHd`25UM40QYCC08FCdP24T]<0PY7D086@d`1nT=80OHo?07b>cP1mSll0
Nhg;07R<a`1gRlD0MXW107R9`@1gQ[d0MHBk07F5^@1dQ;P0Lh:i0P1bOkH02`1_O[D0KWfd06mn]@1/
Nk80J7N^06Mf[@1YN:l0JGV]06Qh[01WMZ`0Hg:Y0080HW>W00T0HG:X05m`YP1MK:<0GFbS05m^Y@1N
KJ@0H6fT061]XP1NJj000P1JIi/03P1IIiP0FfVJ05UUU`1HI9@0EF>B05=TTP1BHhl0D66=05ARS`1B
H8d0Df2=051MRP1?Fh/0CUZ:0P1=FH/04@1<F8`0BUR904YFRP1<F8X0BUJ:04UEQ`15Dh@0A5:1049C
O`0oD7`0@55m03m@N`0nD7P0?Dme03]=L`0kBW40?4]b00D0>TU`00D0=DA[03I5K00gAVl0=DA]03I5
K`0203=2K@07034oK00`>fP0;c]U02diH@0^>eh0:C9C02PaD009ooooo`001oooool0901ZKf/0EU]E
04Y=A01:C440BD/m04M:>@1<Cc`0CU4l04I9=017BSD0Ce8o04iA?P10@c80?40a04U=?P1HG4h0Gf9G
065SF01VIel0J6UQ06Y[H`1/JfH0LG1[08N3P02BSXd0L6]_038`=@0m>T<0KF]f069RK025R8d0NWn2
055GE@1NJ600GVQM05]VF080G6AG00H0HVQL065WG@1>Dd`0@dQ20415@@11AD@204=5A01X04I8A@1>
Cdd0EUID05QIE01GF5<0FEQF05mNG01JFEL0EEAB05YIE`1LG5X0FU]F05UJE@1FEe40FEYD06QYH`1c
M6h0MGIa06e]J`1MGE/0GUeO06]YKP1cLG@0LG5a06i_JP1`LF/0L71X07AdJ01gMFP0GUe;061RC01b
M5`0OgmW08F3KP2:Qg@0Y9j>0;J^X`2`ZJ40c<C20>oVj`3<aLd0Z:2]0:jX]02f//00[JVg0::OZP2^
[K<0aLC90=cLfP3]k^P0g^3E0;Zj/037akd0`l>i07EgK01JG540IVUN04U?@`14C3l0B51304M?@P14
C3l0BE5404aDA`1AFD`0EE]?05=IC`1@F4d0DUY?04eGC01<Dd/0BE5604iFB`2FWID0UibF075fL00l
@Cd0A4E404Y:C01:BDh0CDiC04e=E@1;BeD0BD]H04e?G01=D5l0CUAT05IMK@1HHG80Eemb05iVN`1N
IWd0J6n908R=ZP2QY/@0[[7B0;FffP2f]]`0]KSK0;Jjg@2h_=l0][cN0;Joh02h`>@20;O1i0040;O1
i@2e`^D0]L;U0;S5j080]/?U00D0]/?V0;G2i@2a_^40]<7U0;C2i`020;?1j00O0;C2j@2b`NP0[/3X
0:bniP2]_nL0[KkY0:jmj02/^^L0[kcY0:fij@2[]nL0ZkWX0:NeiP2V]>D0YK?R0:Bbh@2Q/]h0X;7M
0:6bgP2O/=`0WJkL09j_g@2L[]h0VjgO09R/g`2EZMh0U:WP09>Xh@2BYmh0T:OM08jWg@0208ZSf`05
08VRf02:XMP0RJ3F08NLd`26Vm000P25V=004P26Ull0PY;=08>Bc@22T<d0Pi7>086Ac`20Sm00OXg>
07f=b`1kSL/0NXc:07V;b@1gRlH0MHW207B7_`1hRL40MHBk07B4^080MH:f03d0M86e071m/@1`OK40
KGZ^06ik[`1_O;00K7V]06Ui[@1WMj/0JGJZ06YgZ`1XMJT0IWJY06=cY`1PLJD0GW:U05mcZ01LL:D0
GFjT05a]X`1MKZH0G6fU05i]Y01QKZD0GFZO05]WV`1IIIL0FVJH05aVV@1KIIH0Ef:@05IST01DHhh0
DF2;04mPR`1?GXT0DV6<051ORP1>GHP0BeR504YHQ`1>FX`0C5Z;04]IRP1:Eh/0BEJ:04YGR`17DhL0
AUB504ECQ013DH40@4im03i<N`0jBgL0?dii03m>M`10CgP0?4]b03Q7KP0gAVd0>4M^00<0>DQ_00@0
>4M`03I5K00eA6d0<d9[0P0c@Vd02@0`?V/0;ceZ02lmJP0`>fT0;cYW02hjI00^>V00:SAG02/dE@09
ooooo`001oooool08P1UI600FUUD05MDB`1:B3`0@T<c04E6=01?DC`0D58l059D?P1GFD<0CU0k04a?
?01:CC`0C511059FA`1IH500G69D05aPDP1WJUl0K6mT06U/H`1]KVP0N7Uc08V:Q@2?T8/0MgUf04M9
AP0l?Sd0GF5P07]oOP1jP7`0HfYS04mFCP1OIe`205aVF`0=061WG`1RIf00HF=N059DD@0n@3d0?T0o
04A5A`16Ad/0ATE:04A3B018Ad`0CdiB05=AE00205ABE@0505QCE`1FE5L0EUAE051@D01ADE400P1D
E5@02`1BE5<0DU9@05EED`1XJVD0OGmj07YlN@1HF5H0De=A06ARH`1YIfP0L71^0080L75/02<0LGA[
07AgK01fNV/0LgMV06M/EP1cNEl0N7aQ0823J02CTgT0ZjV@0;>aVP2e/9d0`[b^0>WRfP3Ic/l0]:V_
0;:V/02g[KH0]jfh0:FMZ02[Xjh0e<gE0>SSj@3VhND0l>c[0=_Ge039aL80em?@0;Rg/`1JFeD0ATU0
04eCA`0mACH0@D/j049=?00204=>?P0Y04UDA01=F4P0DEa<05IND@1HH5D0EemD05YQF@1HGeL0C5=<
04]BBP1@Edl0NX5i07MnM`1IGUP0?T<m04Y=BP1>D4l0Ce1B051AD`1>Ce<0DE9G04mBF`1ADel0Ce9Q
059HJ01CFV`0EUe`05EKL@1LHWX0J6f:08:7Y@2OY<80[K;B0;:eeP2c]MP0^KWO0;ZjgP2h^mh0^kgS
0;Znh`2h_^800P2h`>D20;O1i@070;K3iP2fa>T0]LGY0;C7j02eb>T0]<KZ0;73i`020:o3i0050;34
i@2^`^D0[l7U0:o1i@2``^H00P2]_nD0302^_N@0[[gV0:Zli02]_>L0[kcX0:fji`2Z^>D0YkSV0:Fe
iP2T]>D0X[CT09nchP80WK;O01l0W;7N09Z_g02I[]/0VZoL09N/f`2H[=h0UZ[M09FZg`2BZMd0TZWO
092Yg`2=Z=d0S:OL08ZUg027X]T0Qj;G08JOe@25W]@0QikD08BKd@27W=<0PYO>08>FcP24Ull0Q9G=
08:Cb`21T/X0Oi;:07f@bP1kS/P0NXg70080Mhc500P0N8g607N<``1dRKd0LhNj07F9_01cQ;P0M8Be
07:2/`80LH6b101^Ojd01@1/NZ/0JgVZ06]h[01YMZX0JWF[0080JGJ[00H0IgFZ06AdZ01RLjL0H76U
05mcYP1PM:L205Y^X`0S05Y]Y@1KKZH0FFZP05a]X`1LK:00FFJJ05YXV@1HIYL0FFFE05QUTP1EHXl0
EV>?05ERS01AGXP0D5n804iPR01=GhL0CUn:04aMR01>GHP0BEZ604aJQ`1=FhX0BeV804UGR017EHH0
AUB504ECQ014DX40AE>2049@O`13DH00?Tai03e<M`0oC7P00P0oC7H00`10CGL0?4]d03Y9LP0203Y9
LP0403M9L@0fB700=dQc03I8L080<T=^00/0<D9]0393KP0`@Fd0;Sm[02lmJP0/>VL0;S]U02hlH`0[
>5/0:39E02TdE009ooooo`001oooool03`1PFeL0E4m904<o=P0l>Rd0@D0^0491;@1@CcX0F5M205MF
@@1ADSd0AdPf04]<?01=D3l0DUI705eQDP0205eTE00O05mSE01VJU/0If]M06]_H@1hNg00NWed07ao
N027S8D0TiRA07ElM017CTH0FfAL07ImMP1TJf<0HFQP05eUFP1PIel0GfIN065XH@1VJfL0HVIU055C
DP16AdT0ADI:04I7B`16Ad`0B4U>04U8CP18Add0BdY@04m=E002055?E01J059@E@1ED5H0DU1C059B
E01?Ce40CTi@051@D01BE5<0DE=B04M9B01FF5D0OX=o07EjMP1KGEX0DeEB05]KF@1YJFL0Jf]Y075b
K@1eMW40LWE^07MjL@1fO700KG=U06mfIP22RGL0PXYc07f2J`23Qg00/K>M0<S7/P37a[40h=g<0?ci
jP3^iml0_[Bc0;nc]`2n/KP0]JZ`09V>UP2OU9`0b[o70>[QiP3`in`0ln[]0?;Yk03=alL0[JNW0;2/
Z@1kNWH0?d0k03/n=@0k@CD0>Cla04=<>P10BCH0@d`k04M@?`1=EDH0De]<05INC`1KHeH0GF=I05eR
F`1MHU`0HFIR05YOF`19CTX0CU=?05AIE@1@EE40C55=04I;A`1;D4`0C55=04eAD01@E5<0Ce=D055D
F@1FFf40EEUT055DH`1CF6/0EEa_05UOM`1KHG/0KgBA09>H]P2QYlL0[K;B0P2c^=P0202d]m`0^[cR
0;^nh@2k_^40^[kS0;Voh`2g_n@0^<3U0P2i`NP01`2h`NP0]l?Y0;G4j`2a`nT0/lGY0;;6j@2`a>T0
0P2^aNL02P2]a>H0[<?U0:c3i@2^`^D0[/3T0:foh`2_`ND0[KoS0:noh`2^_^820:ZlhP070:bki02_
_^L0Z;WT0:Rii@2U]nD0YKOW0::giP0209jdh`0309bbh@2K/]h0UjkJ0080V:oK01<0V:kM09V_h02E
Zm`0UJ_M09>ZgP2BZMl0SZOM08bWg02:YMX0RJCK08RSfP27X=P0R:3H08RNe`27W=D0QY_D08BIdP25
V=00PYG=0080PIC<0P21ULX00`1oU<T0Oi?807bAaP0307V>``0307N<`@1hSL80MX^m0080M8Rj00L0
Kh>e07>5]@1aPK80LH>c06n1/@1]Ojd0Jgf[0080K7j/01T0Jg^/06ajZ`1[N:`0JgR]06UfZ`1ZMj`0
JGJ]06IfZP1SLjL0HG:V05i_X`1OLjH0GW:W05a`Y@1KKZH0FVfU05Q[X`1HK:40FVjQ05a^X01IJI`0
EfFF05ITU@1EHi80EfFB0080EVBA00T0DV6<055PR`1@GhX0CUn:04]NR01>GhX0CEj904]LQ`1=GXT0
0P1:FhL01@19FXH0AUN504AEP`14EH<0@eB20080@U=o0100A5B0045@N`0lBgH0?4]d041=M`0oC7H0
?T]e03m<MP0lBGD0>dQd03U6LP0iAg@0=dEb03Q6L`0fAg<0=DIb0`0bAG002P0`@Vl0<49`02m0K00/
?FT0:S]W02`kI00^?6<0;3YM01l/C00S;T`9ooooo`001oooool0A015@S/0>CH]03@b9P0a;b00>CPT
044o:P12@2/0C4Xe04e:=`14@S40@d4d04E5>@1<CT40DUI705MNCP1MHE00Gf=B06=WEP1ZKUd0JFiJ
07QlJ`21QGH0LWIX07QnLP2MXiL0]Kfb0:B^X`1nR7d0I6mV06egK`1[LV/0JG1Y06EZIP1WK6P0I6QW
06EYJP1XK6d0EUYM04A8B`11ADP0ADQ=04=6B`18Be00BT]@04]:DP1<Be<0CdaE04e:D`1?C5<0CT]B
04i<D@1@CU<0De5D059BE01>CTh0CDe=04m?C@1ADe00CU1=04A9A@1QIV80LWQd05iUGP1HGEL0GV=M
069TG`1YK6L0L7E_0P1hNg@0=@1iO7D0Oh9k06abJ01/LVP0S8n609>FR`28Rh00Rhj30:Z/X@3GfLh0
h^CI0>SXh03no_H0jNWQ0;fl]`30^[P0ak^k0;R/[P2HS8h0Sh>50:FIV@2gZj/0e<[90>KLf`3klO00
knGT0:ZRX01mN7D0NgQc059AC00o@3P0@dHm03i4>00nA3H0A4/j04E<>P14BcT0CeI605QLCP1JGU00
Gf9G065TF`1SI5l0H61N05QJF@1WJ6X0LG5c05]JG`16Ad/0@D9404U:C01<CDl0A4Y80080BDm=00l0
BU1<04aBD017D4l0CeMJ05YQJ@1EGFP0CeIV05AKKP1KHgX0HVV507AkV029Sjl0YZc<0:Vbd`2]/mD0
0P2_^=T0102c_=h0]KgQ0;Blh02f_^820;Noh`80]l7U00P0^<3W0;[1j`2ka>d0^<C^0;S5k`2d`n`0
]LO_0;?6kP<0/LC/00@0/<CY0:k2i@2^`^D0[l7U0P2a`N<03@2``>80[koQ0;30hP2^_^00Z[cP0:Vk
g`2W^Md0Z;[P0:Nih@2U^>80XkGS0::giP2R^>T00P2N]^H0102K/n<0VK7O09R`gP2H/=h209F]f`80
UJ_L01d0U:[L09>Xg@2AY]d0SjKL08jTg@2?YMl0SJ7N08bPg@29WMX0RYkI08VLe`26V=H0QIOE08JI
e024Um80PIC?07jCc01oU<d0OY?:07jCb01lTlL0OI;707bCa@1iT<80N8o107N>`01fS[h0Mhfn07B:
^P0207>8]`0:0766]@1fR;P0LH>e07>5]`1aPkD0KGn_06j0/01[Ok40KGna06em/080JWZ^0P1YN:l0
101VMJ`0IWF^06EdZ`1QLZP205i_Y@0:05eaYP1LKjL0FVfU05Y]Y`1LK:L0FV^S05Q/W`1IKIl0FffO
05U[W@80EFFF01D0DF6B059RT`1AHI80Df>D051PT@1>GXl0Cen@04mPSP1=GX`0CUb904mMRP1<GHT0
Beb804YKQP1<GHP0AeR304IIQ013EX40AER204IIP`13EX000P11E7`01@10CgH0?Dac03i>LP0oCG80
?4Ya0080?DUa00<0?4Qb03Y5LP0jAG<00P0hA7@0400iAGD0>4Ig03A4M@0bA7H0;d=e0314MP0]@G<0
;45`02/mJ`0[?VT0;3eY02`kIP0^?640:SUJ02LeDP0V=4l9ooooo`001oooool09P0`<2H0;BdS034_
8`0b<240=C8Q03Db7`0i=R<0?c`[03ll;@0l>2d0?CT`04E2>@19BCl0BT`o04Y>?`1MGe40H6=B06EX
E`1ZKEX0L7=P07UlJ@1cMVD0OH1_09jRT`2]/J<0/;JX0:R`X`2GWi80MWid07QoN01gOGT0L7Ea06Y/
J`1ZJfd0L75e07=fN`1XJg80Ce9I0P16BE001017Be@0BDeF04U>E019C5<204Q8D00>04U8D01;BU80
C4]A04Y9C`1:BDh0CDaA055AD`1=CDd0C4a<04e=C@1?Cdl0C4i;051BC`1>Ddl2065VHP0<05YOF@1L
HE/0J6eW06Q]IP1[L6P0LWQ^07MjL@1oPWT0O7mf07=fK@1cMV/0QHQm0P2NXIP0@`2][ZH0`/>m0=[K
eP3UiN<0m?Cb0?_kn@3Jf]P0]KFc0:j^[P2k^;H0c/K40:BLVP1oMgD0XYRG0:RNW02MU8l0/:NP0;N^
Y`31^[80/Z^S08B0M`1^JV40Hf1G04E7?013ACP0A4Pj03m3=@14Bc/0BU1004Y>?`19CCh0EUY;05mQ
E01QHeP0HV=K06=TGP1QHUd0GemM055AD@1^KW00R8N<05ACF011@TL0A4E904U:CP1;C4h0ATa<04UA
CP1;DDl0B4i<04UBD@19De@0BU=H04mHH@1AFfL0E5e^05mWO01TJhD0M7^G09:H^02TZ/`0Z[?D0:Vb
d`2[/mL0[kOK0:njfP2`^m`00`2e_n802P2g`N@0]<7S0;K3iP2e`^D0][oV0;S1jP2ha>`0]l?]0;O4
kP2e`^`20;C3k0060;?5k@2a`n/0/L?[0:o1j@2_`NL0[KoU0P2__n<03`2a`N<0[koQ0:boh02]`>40
ZkkO0:^mh@2W^mh0YKWN0:Jjg`2T]ml0X[OR0:>eh`2O]><0WkGV09bci@0209^ah`0G09V_h@2H[]l0
UZkN09J^gP2D[=`0TjWK09JZg@2DZ]`0TZOL08jSf02?Y=/0SZ?J08fRf`2=X=/0RYcJ08VLe`29VmP0
R9[H08JEeP25UM<0QYKD086Dc`22UM000P1nTl`207bAb00O07fBa`1lTLH0Ni7307Z@`P1dS;`0MXfo
07J>_P1eRk`0LhRj07:6^01cQkT0LXJh07B5^@1`PKD0LH:f06f1]01]O[80Jgnb06Yn/@1YOK00JGZ^
06Qi[@1WN:h0IWN]06Qi[`1VMjd0I7F[06=dZ01OL:@0GVnS05]_XP0205Y^X`0J05a`Y@1KKZH0FfbT
05UZXP1HJId0FFZN05QYW@1GJ9`0E6BG05=SUP1BI9H0DV>G051QU@1BHiL0D66E04eMT@1>GY80CenB
04aMR`1=FhX0CUb904eKR01:FhH0C5^604QIQ016Eh8304EHPP0P04EHP013EWh0?UAk03iCN00oDGL0
>dea03Y<L00lC700>TU`03a:L@0nC7<0>dMa03Q3L00kAW@0?4Ig03Q2L`0g@gD0=T9f03A1M@0`@7@0
<T9f0311M@0^?g<0;3i`02`nKP0/?V`0;CiZ02dlI`0[>Eh0:3MH02HdD@0W=E09ooooo`001oooool0
2`0];b@0<C4W03<a9@0f=2L0=C<T03Le9P0e<bH0>3@Y03/g;P0j=2h0?cXd0080AT<l0300@d<k03hn
=019Ac/0EUA706]YG01THUD0Hf5B07IdI@22P740XIn@0:BRT`2QXY80[:fO0:j`X`2XZYl0VY^D09JH
T`2ATi00S8j=07UiN`1fMGX0RhZB09JFWP29S9D0BdeI0455D01;Ce/0B4iJ04]BG018CeL0B4aE04I:
D`17BU<0AdYA04Y=D`18Be00BT]@04E6BP18BDd0DU9D04i>CP1;Bd/0Bd]=04m?D@1<C4h0CTi@059C
E@1WJFP206U[J00d06IXI@1UIf80JfiW079eJ`1eNF/0NWi`07UkKP1aLfD0MgU[096DP`2FVHP0ZJ^N
0;bn/`3Fe/`0emO?0>OVhP3jn_P0k>c/0=gNh02m_Kl0]KFg0;Ng^@2g]KL0dlo@09VEUP23PX00Z:BQ
0:ZWXP2>Rh80NgU/06i/G`1THU<0KfeN065RDP1HFDT0DEA304E8=@18CCT0ADTh04Y>?@1AEDH0Ce93
04i@@`1EFD/0FeiC05mRF@1SIUl0H6=L05aNF@1KGEX0GEmL05=EE080IVMY01@0@T=50496B@18C4d0
C51A04]?D017CDd0BU9A04UAD`1<E5H0C5IH04eFF`1AFf@0DE]U05EQK`1NJG/0J7>707R0U`2EW;H0
YZg:0:bbdP80[KKE00D0[KKG0:nhf@2a^]/0/[cM0;>ngP020;:og`080;G2i02ea>D0]/GV0;C2i@2d
`N@0]/;X0;G3j02d`^L30;K4j@030;C2i`2f`^X0]l?[0080/l3Z0140/KkX0;2mi`2__^L0/;oX0;2o
iP2]_nD0ZKgP0:^oi02Y_N80ZKcT0:Fki02S^^@0X;OQ0:2gh`2N]><0XKGW09neiP0209jdiP80WK7V
00D0VjoT09Z^h`2H[>40VJgR09FYgP0209JWg@0>09BXg@2BY]/0T:GJ08bRe02=Y=H0SJCH08bQf02:
WmH0RIkG08NKe@25VM@0Q9KD08:DdP22UM02082Cc@0307b?b@1mT<X0OY790080O8o700X0Nhk607Z>
``1iSL80Mhfo07B9_P1eR[l0Mh_007F8_P1eQ[h0LhJn0P1aQ;`02@1]P;X0KX6i06Un]@1YO;@0JWnf
06Un]@1ZO[<0J7ba06Ij[`0206Ei[00>06EiZ`1SMjT0HGJU061dX`1OLJ40GW>R05ebW`1FJiX0F6jM
05U^W@1IKIl0G6fS05]ZX@1IJ9l205QYW`0A05EVW01EIYh0DfBL059SV`1@HIT0D6>K04mRU`1?H9H0
CUnE04iNTP1=GI00CUb;04eKRP1=FhP0BeZ504aKQP1=FXH00P19F8401015Egl0AeV104AGO`12EGl2
03iDO@0M03iDN`0kDGP0>U1e03Q>L`0iCG80>Tad03]:L`0lBg@0>dQd03Q5L@0jAG80>4=a03Q2L`0k
AGP0=d5f03@nL`0f?gH0=Cig03@oM`0a?W<0<3ea02loL00_?F`0;3YW02hkI`0X=Ud0:CMJ02LeDP0Y
=5002Oooool000Oooooo0940;2lV034c:00a<BL0<c4U03Dc9P0d<RD0=S@X03Dc9`0i=B`0=30W03Xg
;P16@cX0?Shd03`j;P0o?C40?S`_04I4=@1RGe00FEI704i;>P1lNFP0T8Yj0::LS02MUhL0Ui610:2M
SP2TX9@0Yj>H0:n/X`2_[:D0YjBO0:NSX02JUYD0U92A0:>NXP2ZZ:d0Xj2W07imQ@1fM7l0OGf706i`
O01UJG80HfI]069UK01JGF@0DEAK04iCE`1DFE`0CE9E04=7B011ADH0@dM804a=C`1;Bd/0Cdm?051@
DP1>CE80BTU>04M7B@1MGEl0LW9b07MiMP1fN7<0KFiY06a]I`1bMF`0N7a^07UmK01iO6/0M7MV07Ig
I@2<SG/0Y:FC0:^/VP39bkd0f]cA0=[Jd03/k>@0o?_g0>OUiP32`/@0b/W>0<G3b02XYZ/0[:V`0<C2
a`3UhnH0Zj^[09>CT@36al80b<W108nAQ01WJUT0A4Ld0454<@15B3<0BD`g04U<>@17BSL0@dHa04U<
=`1=D3d0E5M605iRD`1FFDd0EUM?05ULD`1MH5T0HVEN061UG`1NHed0FEiH059GD@1FFeD0CU=?05AI
E@1AEE@0@DE404=7AP15BDX0BDe>04a@D`1:CU40CE9G04aCF@1?EUh0DeaU05EOJ@1GHFd0E61`05IQ
L`1VLHD0NXFK09:M/`2Y/<X0[;??0:bcd02^]m@0[[OF0;:kfP2a^]/0]K_M0;Fmh02f`><0]KoR0080
]L;U00T0]/CW0;O5j02e`nH0/l7T0;G3iP2fa>L0//;T0;?3i@2eaNH00P2d`n@20;G2i@050;?1iP2c
`>T0/KkX0;2ojP2^_NP00P2/_^H02`2/_nL0Z;kU0:Jli@2V_>D0Y;_U0:>jiP2R^^P0XKWW09jfi02L
]>80W;;S0080WK?U00D0W[?V09faiP2M[^H0WJkV09^/i00209VZhP0709FVgP2HZ><0U:CO09:Ug@2A
Y]d0SjCI08bSe`0208fTeP0=08VPe028Wm<0RJ3F08FLe028W=L0Q9SC082Dc`21U/l0P9G>082Cc@1n
TLT0Oi;:07jBa`0207b?a`0B07R;``1iSL80N8c107R=`P1fRl00MHZo07B9_P1eR<00LhK00764_P1`
QKh0KX:m06f1_01ZOkP0JGjg06Qm]P1WO;D0J7ff0P1XOK@0501UNZl0HgR]069hZP1SMjT0HWNV061e
XP1PM:80G6jN05]`W@1KL9/0FFjK05Y_W01IKY/0FVbL05UZWP1IJId0FVZN05QXW01FIid0E6FK0P1E
IYh0401BHYd0CEfH051QV@1@HIL0Cf2D04]LT01=GI40CEf>04eKRP1>G8T0CEb704YIQ01;FXD0BUV2
04QGP016EGh204IHP00Q04AEP014Eh40@UF003iAO00oDWd0?E1j03Y@N@0iCgP0>Teg03Y;MP0iBWD0
>DQc03Y9M00iAW80>TEb03a4LP0j@W40>d=d03Y0LP0i?g<0>Cie03HkLP0c?7<0<Sia02lkK@0`?Vd0
:cUV02djI`0Z=f40:CML02/hFP0Z=E<0:CE?00Wooooo0007ooooo`0802P]9P0a=bd0<C<X02d]8@0^
;b40;RlO034b8P0^;al202d[700?038c8`0n?bd0=3LT034c7P0j?2L0>C/U04Y<=P1PGdX0BTTd04=1
:P1iM600QGi[081iI`2=QW@0T8Ui0080UXj100L0Ui650:6KS`2VX9@0Y9jB0:VQUP2ZXIP0ZJ2I0080
ZZ6L07D0ZZ2N0:NOW@2TVi`0XI^M09jHW02IU9P0Ti6F092?U029R8h0P86507QlO@26RXX0LWIe05=I
E@1AEe<0EE]I04A8A`18BTL0Jf][06UWJ01ACe80ATI804U9B`1NGUh0MWId07QjM@1cMVl0LgEZ07Ih
J`1iNfd0OX5_07IiI01`MEh0N7eV08N:M@2SYY40_l:_0<;5]03Kfll0k^kT0?Cdk03mo?L0j^KU0=GA
dP38`lL0c/W?0<_4c02FSiL0PGV40<Bma03Tgn<0`;jo0:JVY02i_;D0Z:^P06Y^G`1JGTd0@TLc0497
<@0n@bd0@dHa04I9=P1<CCd0CDhl04m@@01GF4X0G5a@061RE`1LGEH0Gf1K05iPG@1KH5`0GV=O05mT
GP1NHed0F5mH059ID@1=E4`0@dY204M>AP16BdD0?D8n0494@@15AdH0AdQ<04a=DP1CEUl0DeEQ05EF
J01FFF`0GV=g06]aQ`1VKX<0HFb006EbQ@1lR9h0WJW10:2/a02X///0[KC>0:nfdP2a^=@0/[WE0;Nm
g@2g_Ml0^;cO0;NmhP2g_>@0^;gW0;NnjP2f_NT0^<7/0;S4k02ha^d0]L?X0;K4i`2da>D00P2danD0
3P2can80//KQ0;;6g`2daN40/lCR0;;2h`2``N@0/<;X0:g0j02/_nL0[;oY0:Voj02W_>L0Y[gW0P2V
_NT01`2U_N/0WkOU09fhi`2L]nH0W;OT09^fh`2L]>800P2K/n<0102L/n@0Vk3U09^^iP2IZ^8309RX
h`0409NWhP2HZ>@0UZKT092SgP80SjCM00<0SJ?L08NNe028XML00P26X=<06@25W]@0PY[B08:HdP21
Um40OiG>07jDc@20U/l0P9G<07fBa`1nT/L0Oi?607fAaP1lT<D0NXo407N<`@1fS;h0MHbn07B;_`1c
R[h0L8Nk07>8_P1aR;h0KhFn06f3_01[PK/00P1YOkT02P1XO[P0IWbe06Il]@1VO;D0I7Zc06El/P1U
NZl0HgR]065gZ@1PM:H2061eY00:061bXP1MKil0GG:O05aaWP1JKi`0G6jL05e_W`1JK9`0FF^M05QZ
W080EfVK01L0EVRJ05=UU`1CI9P0EFJJ05ASVP1@GiH0DV:F055QU@1AHI@0Be^>04YJR`1=GHh0CEj<
04aMR01;GHD0BE^304YLQ014Egl0@UEm04AGO`16F800A5F004=DP00204=DPP03045BP00oD7l0?dn0
0080?4am01T0?Tam03a:N@0mBgX0>dQe03Y7M00nBGL0>d=a03e4LP0l@g40>T5_03/oKP0l@700>Si^
03@jJP0e?Fh0<Se[02hkJ00/>fH0:cYS02TfH00Y=eh0:cQK02XgE`0/=E80:C=<00Wooooo0007oooo
o`0602hc;@0i?SP0;c0Z02HX7@0Z:Qh0:2TK0P0[;1`0JP0[;1X09RTF02LZ5@0Y;1L09b`E02/`6@0_
=A/0;30G04M;<01XJU80JFUA05aLA01eLeh0LfiK075ZF01nMfL0L6UI07I^H`2<Q7T0RXAh08N1M@2B
S7h0UXj109^DQ02DRg`0RX1d08QnLP29Og<0ShEk08n5O02BQh40UHZ609^AT02VW9d0/ZV/0;>]/@2D
SiD0N7Ik07UiN`2CUIH0Oh>206AXI`1OIF<0HVQV05YNG@1NH5l0NWak06YZJP1@D500Bd];05EED`1U
IF<0MGIa071aJ`1]Kf@0N7Q/07QiJ`1nOfl0NGYY07MiI023QW40V9^60:R[UP32aK80dMC30=GGbP3[
jn40no[e0?[im@3If=H0`ko00=?=d@3@bM00akg50<c2b`2aYJl0PgN10;ne_@3=al/0c<[;0;6b[@2A
TX`0FeiC0457>@19D3h0Adlj03i6<@0nARl0A4Te04U<>@1BDd<0EUM705IGB@1UIET0IfMM05mPF01M
GUX0GEmL05YNG@1HG5/0FUiM05MMF@1FG5P0EUeF04eDC017CTH20458@00@0458@@10ACl0@TM30496
A@18BDd0CTiF05IHI01JFV/0G5Y`06=SN`1iNi@0TIF`07f4WP1aN980OhVR09JP^`80Z[C?01P0ZkG@
0:fgdP2`]m<0/[WE0;>jeP2g_=X0];WI0;NkgP2i_><0^KcW0;Vlj@2j_^d0^Kg/0;Rok@2h`N`0]l?]
0;O3j`2fa>T0]LGV0;74hP2baN<0[lCO0;77g`2`a]h20:o3gP0@0:o2h02^`N<0[L7V0:[0i`2Z`>T0
ZKoX0:Vnj@2X_NX0Y[_Z0:Jjk02U^n`0XkW[0:2gj@2O]^P0W[GW09jfiP80W;CT0180V[;R09Vah@2I
/>80V:gR09N[h02GZ^80VJ[R09RWhP2GYn80UZKQ09JVi02DY>80Sj;M08jRg@2=XM`0S:;L08VRfP28
XMT208BMd`0=08:MdP21V=40PIOA07nEcP1nU<d0OI?<07jDc@1nUL/0OI;707nCaP1nT/D0OI7407^?
`P0207R>`00?07J<_@1gSKh0M8Zl07B9_P1bR;X0LXNm07:7_P1]Pk`0K8:k06b0^`1]PK`0JWji06Um
^01WNkH0J7ff0080IW^d00X0I7V`06=h[`1UNJh0HGFZ069fZ@1RLjL0HG>U05maY01KKIl0Fg2O0P1M
Kil02@1LKYh0FF^K05U[V`1JK9`0EfVI05EWU@1FJ9H0EFNE05AVU00205EWU`80DF6D00d0E6BE05=S
U01?Gi00Cef>04eKS01=GX`0CUn=04aOR@19G8H0B5^504ILQ@14FX<0@EMn0080AER200`0@eB0045B
P014DX<0A5:304IDQ@13D880@Tj203m;O`0nBW`0?dUn03m9O00nB7T203a7M@0D03a4LP0l@g40?TEa
03m3L00l@6d0>ci[03`oJP0k?f`0>3m[03@kI`0c?VP0;3US02/jH`0/>f80:cUP02XhG@0Z=eT0:cID
02/eD00[<T`9ooooo`001oooool0300/;Bl0?Cdm02/[:@0W9R40:2TQ02@V6`0V:1/09BLJ02@V600T
:1P08RXE02@/5@809RhG0280<3PP03e2:`19CcD0LGEN09:DOP1jO6L0KVeK079`H@1`KV40JFMJ05mM
D01XIE`0NGI]079^H`1`K640NWI[07ejJ`1eLV40Mg5Q06mZE`1^JEH0L6]H07E^G01fKel0NFmU07id
J`29OWX0UHZ80;2VY`2_Y:P0RX6603lj@01;BDh0MGEj0P1oPXL0E@1hO7l0K75d07=hN`1jOWl0HVIW
04i@C`1BE540G5aJ061QF`1SHUd0LFiW079_IP1gLfP0Og]_07ijKP20NVh0Qh9e09ZHR@2WZ9X0][RZ
0<[<_P3@d/D0fM[B0>KWh@3ko?L0lo?a0=CBd`2o^[h0a[o60=S>eP39_lP0b[o70?7Tj`3PdmX0YYZN
0<^o``3>aLH0^;Ba07mnN@1FEe40D5=:04E;?`16CSl0ADhm03i7=014CCP0C5@o05=HA01LGd`0Gf9A
061RE01TIUT0HfEJ05eNEP1MGeX0Gf5N05aRGP1AEeD0CUAB055GE@1?F5D0D5UD04mHD`18DD`0@Ta4
041:@P0nB400@TU204=9A@17CD/0Ce=F04iAF01=D5T0K6el07mmT`20P9P0TY:/09FF/P28S:T0SY:_
0:2U`P2[//l0/;OD0:nfd`2/]M800P2_^=D0302b^mP0];_H0;Jkf`2g_=`0]k_N0;VlhP2j_>D0^[_W
0;Vlj@2j_>`0^Kg/0;Roj`80]l3[01l0]<3X0;?3i`2b`^@0//;T0:k1h@2]`]l0[/?P0:c1gP2]`^40
Zl3O0:^oh@2Z_^<0ZkkV0:VliP2X^^P0Z;[Z0:Rjk02X^Nd0Zkcb0:FfkP2T]Nd0XkC/0:6dk02P/n/0
W[?X09^`i@2L/^@0V[3R09N^h02H[^<0UZ_P0080UZ[O00X0UJKL09FVgP2GY]l0UZGP09:Rg@2AXMd0
SJ3K08fQg02<X=/0RZ3J0P27X=T03`25W]H0PicD082Id@21VM80P9K@07jDcP1lT/`0OI7<07fBb`1l
TLP0OI7607b@``1oT<@0OHo107b>`00207Z;_`0907R<_P1fR[`0MHVl07J:_@1dR;d0LXFl07:5_`1a
Q;h0KH2j0080Jgji01P0Jg^i06]k]`1YNKD0Jg^f06Yj]@1WN;00IGJ^06Uj/P1VMjl0H76Y05m`Z01R
Lj/0H76W05m`YP1MKZ@0G6fQ061aY@1NKZ40FVZM05U[V`1JK9`0FVbJ05AVU01EJ9<205=VT00f05=V
SP1CIY00DVF?059UT01BHhl0DF:>059PSP1>G8/0C5f;04YKR@1:FX/0CEn=04YOS017G8L0AU^604AK
Q@13FX@0@UV2049GPP13F8<0@eJ104=DPP13DH80@U2104A@P013CWl0@4Ym03m9O00oBGX0?dIj0459
NP0oAgH0?4Ab03i6M00l@fl0?DA`03]2K00n@fd0?45Y03i3J`0l@FT0>SmY03DlIP0a>680<C]T02`j
H@0/>f80;CaS02/iH00[>Eh0;3UK02hiF@0]=U<0;3=?2Oooool000Oooooo02409bH[02/[;@0U9BD0
9B@P02@U7`0S91h09BHN02@U7@0T9ah092PL02<Y6`0T;A`0:C8O030g9@11B3H0GfMB06adG@1dNFD0
PXEb07]nK@1hNV`0M7IX06i`H`1XJ5`0JVYN06YZH01]KF<0L71V06m_H`1aLFD0M7EU06YYE`1]K5X0
0P1/JeL0T`1ZJED0KV]H079_GP1fL680N79V08f6OP2/Xih0/:JT09R>S@2=Q8L0DD]?04e8C01]K740
Ogj408^<T@2:Ri00PXJ908Z>T@29SHh0IFUZ04a>C@1HFUL0HV=N06MVH@1YIUl0KVYQ07E^I01iLVP0
QGid08b4N@2?QWd0YijD0;nh[P37`kX0c<W20=CDc03Ad</0jNST0?Kfm03YinP0dLo@0;^i_036`LL0
b/?:0<_1b@3@a/h0f/oE0?W^lP3fj^`0akfl0<Vo_P2HTi00NgQc05]KD`1<CDD0D5=:04Q>@P0lA3L0
?dLh03U2<@18DCh0FV=@05mVE01QJ5H0IFUH06=WF01SIeT0HfIK065TF`1LGeT0DUMA059IDP1?EE40
C59@04mED`1=EU<0C5EB04]DD@13C4T0@T]804=<A`10BD@0@da704YCCP1?EE<0CeAG04]@E01HGF<0
NWb90;jod@2i^/l0WYjf08Z:YP2EU[@0Yj[90:Z_c`2]/]80[[CF0;:hfP2^]mP0/;WJ0;6jf`2a^]T0
/kcK0;Fkf`2h_^00][cN0;_0h`2k_nD0^[gV0;Vli@2j_NX0^;cY0;NnjP2h_n/0][oZ0;K2k02d`^T0
]<CX0;?3i`2``^H0[/;S0:g1hP2/`n<0ZL3P0:NngP2X_n80Y[cQ0:Nmi02Z_NL0Z;[X0:RjjP2V^>X0
Y[O[0:Nfk`2V]O00YKC_0:>bk@2R/^d0X;3[09f`jP2L[nL0VZgU09b`i@2H[N80UjgQ09N]g`0209FY
g00:09>WfP2BY]/0TjCJ09BUg@2BXm/0SZ7K08fPf`2:W]T0RioL08ZNf`80R9kJ00d0QYcH08BJeP22
V=@0P9K@08:HdP21Um40Ni7;07jCc01mT//0OI3807b@a@1nSlD0O8g10080O8k00P1hR;`01`1hR;/0
MhNk07N7^`1gQ[d0MHBk07B3_@1bPK`00P1`OkX04`1_O[T0JgVf06aj]`1ZN;D0JGRc06Yi]01[N[<0
J7N`06Ie[P1VMJ`0IWF^065`Z@1SLZ/0H6nX065bZP1OL:P0FfbT05a]X`1OKZD00P1MJYl02P1KJih0
EfVI05QXV@1HJYP0E6FA059SSP1DIXh0DfF;055SR`1CIXh205=TS`0Q051QS01CHXh0Cf2>04aMR`1<
G8d0BUZ;04]MS@18GH`0AE^:04AJR@15FhX0@eV8045HQ010EH80@EJ3049DPP10DX00@e60049@O`13
Cgl0@Tel0418N@12BWT0@DUh0416MP0oAGD0?dMe03a5L00l@fl0?DA`03a3K@0j@F/0?TE_0080>D5X
00h0?4A[03U1J00e?F@0=3eT034kH`0]>F40;3YO02XhG@0Z=U`0:SMJ02dgFP0_>5L0;CA@02/bC0Wo
oooo0007ooooo`0;02LX:P0T9RD0820N024Q7`0T9B008B8M020P7P0Q8Al09BLT02DW8P0Y;RP00P0^
=Bd02`0f?S<0Be=606ifI`1iP700NX1b07f1LP1lP780Ngm`07QlK@1aMFH0KW1S0080L79U01h0Kg5T
071bI01aLfD0LGAS07=fI@1_L5h0KFiL06a]F`1XJeP0JFaI06a_GP1]L5l0K6eO08b=O`2n_[80j^ON
0;fi/02RWIL0/:RU08=kN@1NFEH0MW5b07EaLP1lNWd0T92B092BT@2>T8l0PhF406][J@1KFUP206AS
G`0D06YWHP1bKfP0M71W07A]I@22NG80WYF>0;6WWP2bYj40_kF]0=C;a03EcLX0e/k;0=cGe03Qg=T0
mO7`0>3Ng`3@c<d0_k^l0<O3a03:a/L20<O1``0P0<c6aP3Hd]80gm[G0>;Mf@3Ie/l0YjNO06EVGP1F
FDh0D5=804e@A@15Bcl0?dLj03]3=P0e?C00?dLh055LC01PJeX0I6eL06=/F@1SJUP0HfYJ06=YF`1Q
IeT0HfUM05ILD@0nA3X0@TM004]@B@1=DT`0CE9>04]AC@19Cd/203m5@`0P04=9A`16C4X0A4Y804M=
B`1CFEL0CeEE04eCD`1@EEP0H6EY09:FWP2j_<T0`<7C0:6S^02IVk@0Zjc:0:b_cP2]/]80[k?H0;:h
g02e^^00/[[O0;6igP2c_N40/[cO0;>mh02d_^40/kkN0;Joh02g_^00^/3T0;_1i@2m`nL20;Zoi`06
0;Jni@2g`>T0]KkY0;K2k02d`N/0/L3Y0P2``^X03`2^`^L0[/GW0:[2i02Y`n@0Yl7R0:S2i02W`N@0
YkoU0:Fki02V^N@0Y[SV0:Fgi`2U]nT0Y[G/0:Bck0020::ak0090::bkP2Q/Nd0WK3Z09b_j@2K[^P0
VZgU09N/h@2G[N00UjgN0080TjWJ00`0U:[K092Vf02>Y=H0SjCI08jSfP2=X]/0S:3K08^Og028W=/0
RIcN08RKg`27V]h208>Ff00508>GeP21UM80P9CA082Dc`1lTLX00P1lSlL00`1mS/@0Oi3607j=a002
07b<`00>07^;_`1mR[l0NHJk07Z7_01hQKX0N8Fl07V5_`1gPkd0N8>n07Eo_01bO[X0Kg^g071l^01`
O;H206ah/P0806]h[`1/NK00IgB[06Qe[01YMZd0JGJ[06AcZP1SLZT2061aY`03065bZ01PL:L0GFbU
0080GFbS02<0GV^R05]XW@1NJil0FVZK05YXV@1IJYP0EfFB05ETS`1GIXl0EVF>05ASS01CIHd0E6><
051RRP1CI8l0D66<051QS@1=GX`0C5j>04YLSP18FHd0Ae^>04IJS@16FXl0A5R;04IJS@12EXP0@eF5
049DPP13EH<0A5N204ABO`11Cg`0?dah045=N003041<MP040418MP0mAW40?TMb03a5L0<0>dA_0180
=d1Y03a5KP0j@f`0=d1Y03U2J`0h@FX0<caU034mH`0_>f40;SYP02/hF`0/>E`0;CMK02`dF00^=eH0
;cIC02/bC00Y;dL9ooooo`001oooool01P0P92<08B<P01dM6`0M7A/08B4O01hN70807AdK00h0828O
02@V8`0W:BH09R/U04A9@`1VJfD0JFiW06meJ@1bN6`0NWi`07b0LP1lP740OH5`08:5M080QXUh00`0
QHQg08>4M023QWD0QHQg08B7MP21Q7<0P8=b07f0K`1lOFd0LGAS06]_H01]LF8206IZG00c08B8NP3;
cl40fM_@0>?UfP3;bkl0_kfa0;RdZ`26OgL0M6eW07YbKP1^JFH0NgEe0:BPW`2PX9h0Ph>105iNG01N
GeX0I6=O06MVHP1UI600L6eX07AaJP1cKfH0KFUP08^4O02k/Z/0bL2i0;fb[03:`KX0g]G>0=C=a`3<
a<40h=SF0?K`l03Zi^D0][:a09nKVP2d/:l0`;^h0<o:a`3?blP0e];?0<_7a02n^kH0^[Nb0:n_Y`2Q
XYX0H69I04e@A@1JH580@DLi0080@dTk00@0=cd_03Hn;`0d>R`0BE520P1SJe`01@1QJEX0GfQG05iW
EP1PJ5T0HFMK0080FF5D00@0DEU<03i6>`14BT00B4e60P1:C4L06@17C4P0ADY60494@`16AdT0CDi@
04m@E01@DED0CTmD05AEFP1EEU/0Ce9G059GG@1`Mgd0WZ>]0:2S/P2UZ;T0XJJj0:^_b02]/Lh0[K;B
0:jdf02_]=X0[kON0;6hhP2c^^@00P2c_>D20;:ni00[0;?0h`2c_N40];kR0;Joh`2i`ND0^<3T0;W1
i@2h`>D0^L7V0;O0i`2e_^D0][oX0;C0jP2c`>X0/;oX0;70j`2_`>/0[L3X0:g3jP2X`>H0YKoT0:O1
i02U_n<0Y[kT0:Fli@2S^><0YK[U0:Fgi@2U]nL0XkGW0:FfjP2R/nT0XK;Z09f^iP2P/>/0VjkX09b_
j@2K/>L0VJkW09R]i02G[><0UJ[O09>Yf`02096Wf@0:096XfP2>YML0S:?G08fTfP2<XMX0Rj7K08ZP
g028WM`0Qi[L08RKg`80QYWM00l0PiCI08>Ee`21Tm<0OY3>07nAc`1mT</0O8o907^>b01lSLD0Nhc4
07V:`P1jRl<0NH[207^:`@1iR;l00P1hQkh0301iQ[d0MX>j07R2_@1hP[d0MGnj07En^`1cNkT0LG^h
06mi]P1`O;P0Kg^e06ah/P80JgR_00D0IgB[06Ib[01ULJ/0IgB[06IcZP02065`Y`0705i]Y01OL:H0
H6nV05m^Y@1MK:<0G6VP05eZW`0205]XW@0705]XW01JJYd0F6RI05IWU@1DII40EFJA05ETS`02059S
SP09055RS@1@HH`0CUn:04mRS@1=Gh/0CEj<04YLS01:G8h0B5Z<0080AeR<01L0B5V=04IGS@12DhT0
@U>704=EQ`13Dh@0AEJ404AEP@13E800A59o041?NP0lBg@0?Tac03e;L00lBVl0>dU`03e9L@0kAfl0
?4E^03]4K@0j@f`0>TI^03M3K@0303I2K00?038nJ00e@F/0=41Z034mI`0a?FD0;CUP02diG`0Z=eX0
<3YM02`fF@0[=UH0;3ED02`fD@0/=4/0:31500Wooooo0007ooooo`808B<P00@08b<Q024R7@0R8ah0
7b0K0P0O8A`0<00P8A`08R<M02T/9@0M81T0Ce9;08V<Q@1oPWT0LGAY07AhJP1lOW00OH1]07f0J`1n
PV/0RH]e092BO02BTG`0U9=n09BDO02GUX40V9N309RIR02DUhH0TiF709BHR@2@TXD0N7Y]07=gJ@1d
Mf`0LGA[08V<P`36bL80iNSQ0>;Sf`3PhMT0j^cQ0=SHc02UXiL0NW=Y089kL@1^IEd0KVMQ08F0O02H
UI00S8^707IgLP1FEe80G5mH069UGP80JVeV04/0LW=]07MfL@1bLVX0MGE[09FER`34`KP0`[nf0;nk
/03AcL80d]340<_8_`3Ge<d0jnSS0?7^j@33`;/0Ti:=0:2MUP33`;T0d<g40<c9`03@c<<0emC=0<k;
a02][:L0QXF006YYI01ZJfD0?D0h03Pk<00m@C<0?40a04A8>@10A3<0?40_03]2<00l@340FV1B06Y`
HP1VK5h0H6IH05eSE`1MIEP0GVIK05mVGP1AF500DEU>04]EBP14CTD0BE1804YABP15BT@0ATQ504I8
A`19BDT0C4Y=04i<C`1JEE/0FUEL05iHI01JE680FUIT05]GIP1GE6D0DeAV069UMP27S9l0U9V]0:Z_
a@2[/LT0[;7>0:^bc`2_]ML0[[KK0;2gh@2_^><00P2a^^D01@2a^NL0/k_Y0;Fnj@2c_>L0][oZ0080
/kcU01L0];gT0;S2iP2g`ND0]l7U0;K0i02d`>H0]/;X0;:ni02b_^H0/KgU0;:niP2b_nT0/l3/0;2m
j@2__^T0[KkY0:joj`2[_^T0Yk[T0:VliP2X^nH0Y[_X0:Fjj@020:>hi`030::giP2P]N@0X[KX0080
Wk?V00T0W;;T09Z_i02I[^<0VJkS09R_h`2G[^@0UZgS09N^i02DZ^<0102@Y]l0502?YMh0RZ?L08RQ
fP28W]X0RIoK08NLf`27W=d0RIcN08JIf`25UmT0QIOG08FDe@24U=80Pi?A08:BcP1mSLT0Ohg:07f;
b01oSLX0OHg90P1lS<P0201iRLD0MXW407V9a01fRL<0MXW107R9`@1gQ[l0LH2k0P1ePKd01@1dO[/0
MGjl07=k^P1bN[T0KGNd0080KWZf0100K7Rd06]g/`1YMK40Ig>_06Ea[@1WLjl0HW2]05m]ZP1QL:/0
GfjY05e/Y@1OKZD0GfbS061]XP1MJYh0GFVM0`1KJ9`01`1HJ9/0EFNI05QZVP1DIY@0DFB?059UT01?
I8l00P1>Hhh01`1;HX`0C66>04]PS@1:HHd0Ben>04]MS`1=GI000`19FH`01016EXT0BUN;04QERP16
DXH204A@PP05045=O@14DGh0A59o04ACOP13DWd00P0mC7D01`0nCG80?De_03Y=KP0hBVh0>DU]03Y8
K@0kAfd00P0jAV`0500gAFX0=dE/038oJ@0d@6X0=D1]034nJP0b?f/0<SeZ034lJ@0`?FT0;C]S02/i
GP0/>Ul0;3UL02TfF00Z>5D0:CMB02`hD00/=d/0:3=52Oooool000Oooooo01H0:2LY02TX:@0X9RL0
:2HT02PU8`0X9B809bHR02LW8`0Y:B@0>CXb061QEP1VJ5/0MWM[08b;O`21P7D0OGa_07imK`20Og00
PH5_08:2K@29R780Ti9l0P2HU7d209VFO@1?09^HP02MVXH0Wif<09NFR@2FUh/0Vib?08J7O@1[K6<0
L75Z08N9P@2^/:X0e]SA0>;Tg`3Ti^80hN?O0>KZi03Riml0];V^0823M`1kOG00PH=e05iPD`1IG4h0
FemD05aPEP1JGUL0G65J06Y_J01]Lf`0M7]c08N>Q`27RX@0QXR207ioNP1JFU@0IFEO0:>SW03:b<80
bLFo0<g9`@2k]jh0c/Vo0>;Me@3TgmP0e<k80=[DcP2d[jP0ShZ00<2k/@2j]j/0^[NZ0<O4^039a[X0
c/_20<o?a`2UYIl0A4=003`n>P1RI680?d8n03/o>@0l@3P0@4Di04Q=@01<DD80B4hm04I>?@16C3`0
JViO06]^G`1UJ5X0HfII065TF@1MHEP0GF5J05aPFP17CDL0BU1:05=ID`0204mEC`0L05EJE018BTD0
B4M4059@C@1BCTl0FE5B06IMH@1WG6<0HeUQ05mDH`1YH700KfQj06IQMP1SH7P0HF1i06Q[Q02EV[@0
Z:o90:bcc@2Z//d0[[KB0:^ed`2^]mT0[k[M0:njh02`^n<0/K_T0:nli080/K_V01`0]KkW0;Bni@2g
_^L0][kV0;NoiP2f_nD0]/3U0;>oi02c`>@0/l3W0;;0iP2a`>@0/;oT0;2oi@2`_n@0/;kU0;2oiP2`
_^X0[kcX0:jki`2^_>T0[[_Z0:fjj@2/^NP0ZkSV0:fjj02W^>H0Y;SU0P2R]^@02P2R]nD0XKKT0:2g
i02N]>80Vk;R09^dh`2J/n80V;7Q09R`hP2G/><209F]h`0:09>Zh`2DZ^@0TZOR09>XhP2CZN80TJGN
08jSf`2;X=X0RIoH08ROf080QikG00H0QigF08FJeP24VM<0Q9SB08>Gd021Tll2086CcP0408BBc`20
S//0P8g;082<b`80OH_900@0Nh_807V9a01iRLH0N8W40`1fQl807@1dQL00MHG107B4_`1cP;d0M86n
07>1_01cP;`0LWnk06mm]`1^O;H0K7Zd06Ui/`1YNK@0J7Rc06Mc/@1UM;40IG6`06=b/P1SLK40H6n^
061_[01OKZT0H6jW065_YP1OKZ80GffO05m[W01NJYX0GVVH0080G6RH0P1GIIH0201GIYH0EFFD05AT
TP1BI900DF>B055TT`1>Hi40C6:?0P1=HY<0<@1=Hi80CF2@04eNS`1;Fhd0B5V804]HR`1;F8P0BUN8
04]FQ`1;E8H0BU>404aCP`19Dh00Adml04E?N`14D7/0A55j04=@N@0mC7<0?4ac03Y<L`0jCG40>Dab
03Q:L00hBVl0>daa03U9K`0fAV`0=DE]03M6K`0f@fl0=49^03E1KP0d@6d0<Sm/038oJ`0b?VX0<CeX
030mI`0]>V80;3UM02TgF`0Y=eX09cMH02LgEP0W=e80:3QB02HcB`0T<TL02Oooool000Oooooo00d0
7adR02DS9P0Y92P0:28T02/R8`0[9R<0;2LS02dZ8`0_;2D0HV1E08N5N027QGH0PGm`0080PX1a00H0
P7i_07mmKP21Og00P7i_08J5L`2?SW`209REPP0^09ZEP@2MV8@0WYN409nHQP2SWHd0XIb?09bHS02O
WI00TI6506aZGP1iMVd0UIF=0=?Bc@3[j^D0inKQ0>?RgP3Ti>80iNOT0>gbkP2e_;D0MX1g082:P@1n
R7d0NHEi07R4M`1ULFD0Gf]O065]H`1SKfD0GVQO06miL@2:THT0^;ng0=CIdP2o`[/0[JjX08F4O`1V
IUh0Ph1i09jKU039a;h0b/Fo0<Bo^@1jM6h0]:fW0<c5_`80c/No04P0dlc40<S1]`3Je<P0em7508J2
MP2JUXX0YjFI09VGR`2a/JL0Z:VS06i_JP0l?S/0>C/j03Li>00e>CP0?D500456@P12Ad00AD]1065W
F`1]MFP0JG5R06=YF`1ZLF40IVYK069VE`1RIUP0H6=H05iQF01DEe00DE=@04mAD01<D4l0DUAD05AD
E01CDe40EUID05MFDP1GDe00G5MD06QOH01aIfP0LFIZ06mTJP1^I6`0LVMe08V2TP28PiL0L6j406i^
R01jNiL0UY^h0:N]c02X/M00ZkCC0:bge@2/]mL0[;WI0:jkg@2]^mh0[kcO0:fkh02__N00/;kQ0:fk
gP2a_n80/l3R0;Bog`2f`><0][oP0;S0i02g`><20;?0h`0;0;2nh`2`_nH0[kkU0;2oiP2a`>L0[kkU
0:jmi02a`>T0[[gV0;2ojP2/^^L00P2/^NH01`2]^^L0Z[OT0:^hi@2Z]n@0ZKKS0:Vhh`2U]^800P2S
]>802P2R]>80W[?P09jch02L/ml0Vk?O09Nbg@2G/]l0U:oN09B^g`2C[N0209B[h@0509:Xh@2@YMl0
TJGP09:Vh@2AY]l00P2?X]X00`2<XMP0RIkE08VPe00208NNdP0308>JcP22VLd0PIS:0080PYS:00/0
PYG=07jAb@1nTLT0Oi3;07j>bP1mSLT0Nh_707f;b01lRlH0NX[507R7`P0407N6`@0407F3`01dP[l0
Lh>o07B4`080L82l00`0KH2j06]o^@1ZOkH0Igba06Qm/P1UNZl0IGV^06Ii/@1VM[40IGFa06Ad/01S
Lk42065a[`0D05m_[@1PKZ/0GfjY05i]YP1NKJ@0G6bO05e/W@1KJIP0FfRE05]VT`1LIi@0FVFB05UT
TP1IIY<0F6FB05MST`1@GXd0DV2?05ITU@1BHY<204iPT00504eOS`1<GXh0C5j>04]LS@1<GH/00P18
FHL04019EhH0BeN704UEQ@1:EH<0BU:104UAO`19DWd0BU=n04M@N@16CgP0@Tif049@M`13CgL0?ded
03i=MP0kC7H203Q9M080=TMb01P0=dQc03E6L@0b@fl0=D=b0390K`0d@Vl0=D9_03A1K@0a?VX0<3eY
030mI`0_?F@0;SaS02diG`0/>E`0:CMJ02LeF00X=UT09SIH02@dE@0W>5H0:3MD02@bC@0Q;dT9oooo
o`001oooool0<00R82<0:RP[02hZ:`0_:bX0=c8^03Lb;00d<2L0<blT04Q4>@21OW00R8Ig081oK@1n
Ofd0Oh1^07ioK@1mP6d0PHAc07n2L@1nP780Q8Ee08f>OP2>S7d0Ti6209REQP2JUhP0VI>709^ER@2P
VXh0WiZ>09jJSP2TXYD0M79U05MCA`2XYYX0a<6h0=gJd@3RgmX0gMcG0=[Ie@3Shn40l_Ca0>7Ui029
Sh/0HVQT07f6P@27T8/0UIjI07=nM`<0JGA^0500Lgag06egK`2?UXh0];Z`0=?Fb`3Uim`0g=c@0:bZ
W@1fLVH0NWIZ09B@Q02a[J40a[ne0;J_Y@2<R7d0JfMN0:NSVP3>bl80f=K:0=OGb`3Acl80c<Zk0=[G
b02_[9d0JfUL08Z8O020OG@0EU=<06IUH01TIF00@40n04=3@`0o@D00=SPg03do?P17BDH0ADM204eB
B`1FG580IVaR06]cJ01UKF00Hf]N061XF@1KHe@0G6AG05mUF`1MHU/0GfAN055FDP1>DU40D5AE05=D
F01GEe/0EUAI05=AE01LF5T0If5S06IPHP1VGF00KFAU07U`L@1iL7<0N75h085lP`27PHl0RhRI08J4
V@1hN900OWnK09BI]`2SZ<P0Z:kC0:Vaf02Z/mX0ZkOO0:ZfgP2[^N00[K_R0:flh`80[kgT00h0/KoT
0;6ohP2]_=d0[kkM0;70g`2b`=d0/KkN0;Bog@2d_ml0]L7Q0;:og`2b_n80//3U0;2oiP80[[gT00h0
[KcU0:ZihP2]_>D0Zk[U0:jkj02]^^L0Z[SW0:bjj@2[^NH0ZKOT0:Vhh`2X]n80YkKQ0:Jeh080Y[CQ
0200YkGT0::ch@2T]N<0Wk7Q09^`g`2K/N00VK7O09N_g@2E/=l0TjkM09B/g02CZ]`0Tj[P09:Xh@2A
YN00TJGQ08nSh02>X]d0RioJ08fRf`2<XMX0RYoH08^Pe`28WM80RYoD08JMc`24Vld0PiW;082Fa`21
ULL0PIG8082Fb080O97600@0NXo607Z?b01hRlD0NHc60P1iRL@00`1iR<<0N8O207V4`P0207R3`@04
07J4`@1fQ<<0LGnn0720_080KX6l00`0Jgnj06Z0^@1XOkD0J7ne06Mn/P1VOK40HGR/06Ai[P1SN:l0
HGB/06Ee/01TM:l2069b[P0;069`[@1PKZ/0H6bX061/Z01OJjL0GVZT05]XW@1OK:00FFNH05QVU@1I
IY<00P1IIY804@1HII40EfJA05MVT@1EHi00DF:>051QS@1CI980DV>A04aNS01=Ghd0C5f;04YLRP1=
Ghd0BUb:04UJQP17FXD0AUN30080B5J50140AeF204QEP@15DWh0@e1j04ICO@16E7/0AE5k049?N@11
CgH0?Dac041>M@0kBW<0?4if03];MP0jBG@0>DQc03Y9M00203Q6L`0=03M4L@0d@700>4Ad03I2LP0f
@g00=D9^038oJ@0a?fH0<3aT02lkH@0_?F00;SaO02`jG@0202XhF`0802TgG00V=UX09C=H02DcF00U
<eH08c9C02DcD00T;d/9ooooo`001oooool0D`0`;Rl0>3Le03Hb;`0j=c80?c/b03`h;@0k=2X0BTHj
06m[G`21OVl0OWa]07amK@1lOf`0NGa[07YoJ`1lP6l0OX9a07n3LP24QWP0SHj008n@PP2@SX40TY23
09RDR02KU8X0W9><09jESP2PUi00WiN=09nKS`2MVHd0JfMK069NDP2[Yi`0b/Rl0>7Ne@3Og=L0emKB
0=GDd03Ng]`0g>3O0:F[Z@1cNGL0MG]i08ZCT02BViP0W::P06meL@1SK6L0Jg5]06meL@1bN7@0LWMa
0;k3_03>dLP0fmgB0>OWf`3Bd<<0QX=d06YTEP2>R7X0[jVK0;B^XP33_;80_;F[07ahK`1hM6`0_kZd
0=_Hc`3Bd/P0e=C80=[Kc@2o_Jh0ViV:092>P@2DTXD0UYB805ADBP0V9Qh0@D8l04=4?`0m?c`0?3hk
0080=CLd03P0?3lk04]=B01CEE00GF1I06=XH@1WKF<0HFUN05UQEP1GHEH0F69G05EOE01GHEH0FF1H
05MNE`1JGeT0EeaH05UKFP1IFE/0GeeP06ISJ01PFF00GEAI06eTJ@20MG/0OG9h07Q_M01mM7T0RX66
08Z3RP26PHP0QH:=08V7U@27QYP0PH:G08f?Z02OY<40ZJk<0:J/cP2Z[m@0Z[;I0:^dg@2/^>00ZkOO
0:bjh@2]^n80Zk[Q0:nni@2``>@0[kgP0;70h@2__]d0/;oN0;;1gP2`_m`0/L3M0;?1gP80/KoL00/0
/l3P0;2mg`2`_^40/KoT0:nmi02`_NL0[;WS0:Zii02/^nH0Zk[U0:^iiP020:Zhi@0U0:Nhi02X^ND0
Z;WT0:>dg`2V^>00Y;KN0:>dg`2Q/]d0X[?O0:6bgP2Q/^00X[;S09f_g`2K/=l0VZkP09R^g`2E[Md0
U:_M09F/gP2DZmd0U:_O092Wg@2@Y]l0T:KP092Tg`2?Xmh0S:3K08ZNf@2;WmX0QicE08RMeP26Vm80
QI[?08NLd@25Vld0Q9[<086Gb002082DaP0@07jBa01mTlD0O9;407fCa@1lTLD0NHk307J;`P1eR<00
NH[007J7_@1hQl00O8S207R2_`1gPKh0MH6m07N2`080Lh6n00P0Kgnk06j1_01ZOKP0JGjg06V0]P1U
O[@0Igjd06Ak[`80HgZ^00@0I7V^069g[P1OLZX0HgB/0P1SLZ/05P1RLJX0HfnY069^Z01RKZP0H6bV
061ZY@1OJZ80FVNK05aZV`1HIYD0F6JC05YXU@1FII00F6N@05MVT@1DIXh0EVR@05=VSP1AI8h0Cf:<
051SSP1?HXd204aNS00H04YLRP1;GH/0C5j<04QJQ`19G8L0B5^604AGPP16Eh<0A5F104IGPP13EGd0
?U1h045CN@15Egd0@UAj049AN011D7L0?U1f03a>M00lCWH0>dee03U:M@0kBgH0>dYe0P0hAg806@0f
A740>DIc03A1KP0f@g00<d1]03E2KP0e@V`0<d1Z034oIP0a?f@0<3iQ02lmH00_?Ul0;3aM02hmGP0Z
>U`09cMI02TiG@0X>5`08c=G028bEP0S<e@08c9A02<aCP0T;d/02Oooool000Oooooo08L0?chi0410
>00n>c@0@3`c044j<015?c<0C4Pl05UEB@1/J5`0M79U07EfJ01jO6h0Mg]Z07MkK01kOfh0P8Ae07j2
L@23QWD0RHak092AP@2ETh@0UI6509RBQP2JTXL0W9:909b?R@2QTXd0XIB>09R=Q02BRWl0SHMk075]
H@1gLfP0[ZZQ0<k;`P3Nfm80eMC?0=7Bc@32a<40[k>b09jRX@1eNg/0P8J6092IUP28THh0[;:^0;6f
/P1cMG00KFmZ07MhL`1mOWP0Oh1j0:FVX03Mg]H0c/o70>g_i03clnL0[:ZM06ESE01gM6D0W9R<0:FQ
UP2GT8P0f=7;0=[Bc`2RWIX0P7]h0:^VX`3:aL40d<g80=SEcP3Jelh0[:ZN0::PU02`/:@0V9R<06UY
G`0S8aT07b0H03<f;`0g>S<0=3Tc02ld;P0/<b`0=chf03i4?013BCl0GfEK06U_I@1OI5d0FUmH05MN
EP1CFU<0EEaE05UPF@1FH5L0F69I05ELE@1>Ddd0DeE@06YYI@1[IfH0KFMW07ieMP21MWX0D4A806QI
GP22LgP0RGZ108UlP`29OXH0R7j708V1S02:Q900QXBA08B3T@22Q9<0PXFH08jCZ@2SZL<0Z:g:0:N^
b`2X[l`0Zk7B0;2ff02]]]L0[KSH0:jhf`2`^]d0[kcN0:flg@2__]l0[kkM0;2ogP2__]d00`2_`=`0
302^_m/0/L3M0;70g@2b`=d0/koM0;>ng02d_ml0/KkP0;6mh`2__N80[[cS0:fkhP80Zk[S00@0ZKSQ
0:Rii02Y^^D0Yk[T0P2V^N<08P2U^>80XKOP0:6ggP2R]m`0XKCL09jdf`2N]=d0X;?M0:2eh02M/]l0
W;7P09V]g`2H[=l0Vk7S09J/gP2EZ]l0UZ_P09B[g`2DZn40T:KO096Wh@2AYn00SZCM08bRg029WmT0
RZ3J08RNe`28WmD0R9oC08RMdP28W]00Qi_>08BHb`23UlX208:Fb@08082Da`1nT/D0OY;407fA``1n
Tl80O97107Z>`@1iSKl207V;_@0F07R8^`1jQk/0NXNl07V4_01gP[X0MX:l07J2_P1dPkh0L7nj07:2
_@1^PK/0K7ni06Yo^01ZPKL0JH2d06Qm/P1VNk00HgR]06Ai[P1RMZ/0I7F[06AcZP<0IW>X0100I76V
06=`Y@1SKZ@0HFjS05m/X@1OK:00G6ZK05]YV01JJYH0EVNB05IXT01EIhl0E6J>05EYSP1DIhl0DFN<
0P1BJ8d05`1?IH`0CF>:04eSS01=Hh`0BEj904UNR`17G8T0B5f<04QMRP17G8P0AUV304MJQ015F880
@eJ0049EO@11Egh0?eEj041DN@11EGX0@5Ik03eDMP0oDgH0?U9g0080?E5f00l0?4mg03Y<M00jBgH0
>TYe03Q7LP0gAVl0=dUa03E6L@0hAg00=DA]03A3JP0`@VP0<dEY0394J00_@FD00P0^@F803`0[?Uh0
;3mO02/nG`0Y?5d0:SYL02PjG@0V>5`09cYK02DhF@0S=UL08SEE02@hD`0T=Th08S5801l^@`09oooo
o`001oooool0S00e<RT0AD<g04Y8?014@3@0CDTm05MDA@1DDD80C4Xk05MEAP1RHeD0LG9T07AfJ01f
NVT0N7a]07b0L@20PW@0PX=e08N8N02<RW/0Shen09FAQ@2FSX<0V8j409R;PP2IS8@0V8V409R6PP2F
Q800Rgee07idJ`20MV`0PGQ_089iLP2^Yil0d/k50=;=a`2l^;D0ZjZX09nOW`2CUI@0RX^=08>7R02A
UIH0Si>D0;Nk^P3SiN80W9fH06aZI@1lNG@0Ogag07ikM02IUXl0_KZc0=GEc@3Gf=00ko7V0<[<`@20
PW@0O7e_08f>P027Qg/0Ti>90:FRV`32_KT0_;Nc0:jYYP1iM7<0XYbL0;nj]`3Ed<d0i^;O0=cIe036
`kh0/;2X07YkL`1KG5@0?Slg02<T700O8QT0:RdT02P^900S:Al08RLP02`d:@10B3d0@4Ll03To=@1K
HEL0FEmE04aABP1AETl0EEYD059GD@1JGe/0GF9L05QME`1KH5X0F5YE05=DC`1IF5@0OgYg08=kN@26
O7X0S82008QhN`1[FV00Q75g08YiP@2=OHP0Sh6>08f2TP2<Pi@0RX>E08V6V@25PiP0Oh:E0822U`2F
Vk40Y:[20:N]a`2V[LT0Z:o;0:bcc@2`]]40/[OD0;2gd`2b^MD0/;OD0;:kf02c_]X0/KoJ0;2nf@2a
`M/0/<3J0;2og02_`=`0/<7M0:o3gP2]`M`0/<7O0P2a`=l05@2d`>00/kkN0;:og`2`_Ml0[kgP0:nm
hP2`_^D0[KcS0:bki02X^^80ZK_S0:Rkh`2Y_>H0YkgV0:FkhP2U^n@0X[WR0:6hh@2O^>00X;WP09nf
g`0209^dg00809fdgP2M]>00Vk7P09Z`h@2J[^40VJgR09V^h`2H[N@209NZhP0:09FZh@2CZN80TJOP
09BZh`2@ZN40SJKN08^Tg029X]X0Qj3H08FNe080QikB00H0QYg?08RNd027Vlh0Q9S;08:Fb@23U<X2
086Bb00307nCb01nT/L0O9330080OI7300l0Nho207V=`01jS;h0NXbn07J8^01gQkP0N8Rk07Z7^`1i
Q[/0MX>j07:1^01cP[/0LX>k0762^P1^PKT00P1/OkL206Qm/P0C06Ql/@1UNJh0I7R]06Ef[01WN:h0
I7>Z06AaYP1VLJL0Ig>W06MdZ01TLJD0HVnS06=`Y01PKJ40GffN05i/V`1LJYT0GF^H05YZU@0205QY
U00905IYT`1EIY40E6NA05AWT@1AIi00D6J?055WT01@IXl0CVB=0080CV6<0P1<GhX06@1;GH/0BE^9
04YORP17GHL0@eV004MJPP15F800@UEm03mEO00mEG/0@5Qn03mEO00nE7/0?UIj03eEN@0mDgP0?59g
03Y@M`0hCWD0?E1h03U<MP0jBgH0>DYe03E7K`0gBG400P0gBFl0600fB6h0=TQ/0396I`0bAVL0=4QY
0396I`0_@f@0<dIW02m2H`0Y?Eh0:SiO02`nHP0[?F40:3YN02LiG@0T=UX09SUJ02DhF00T=eL08SEC
02LhDP0V=Td08Ri402<`@`Wooooo0007ooooo`0F03Te:P16A3P0A48f04E3=P1KFDX0F5U704I8<`19
C3L0DEA105UKB@1[K5`0Kg1P079cH@1dMFD0MWMW07ajJ`1oO6d0Qh5e08R0M@26OW<0RX1g08UlM080
S7ef06@0PG9[085`J@23LV/0OVeV07a[I01lKFH0MfQQ07EXH02=P7X0X9FA0:^RW@2OUI<0TXZ809J@
T02QVid0ViJJ092;T@2BT9D0YZBY0;bj_@3RgN40cLW:07QbLP29PGh0S8:008Z1O01kLV/0ZJ2I0=39
`@3Nf]40dM770<S9`@2EV8d0PXQl07j4MP1bN6X0P8Ij09nUV@2^]:P0VIbC07IgK`2>SHP0Xj6M0<>o
_03Abl/0in7Q0>GOh@3Cclh0^;Bc08J5P`0l?CP0<c@_038e;P0Y;2<092LN02/^9@0W:R408B@I02T/
8`13BCl0G69H04I<@P0`=R`0F5]B055DC@1?DT/0DeE@05IHE@1HF5H0Gf1K05eLF01GEU80Hf9M06=O
G01LEe@0KfMT08R0O@2:P7h0SX=o0922P@2;Ngh0RWV108ilR02?OHd0T86D0922V@2>Q9l0SXFR08Z5
X`28QJ@0NGfJ0825XP2HWK/0Zk3>0:V`c02X[l/0[;;<0:^ab@2`]/`0/KO=0P2c^<h04P2d^]00];[B
0;Bld`2c_MH0/koG0;6of@2b`=X0//;K0;;2g02``Md0[l?N0;33h@2_`^00/L7R0:noh02__n40/L3S
0;6ohP80[koQ00D0[[kP0:^ng`2[_N40[;kR0:bni0020:Rlh@090:Rni@2X_^L0YK_T0:Bjh`2U_>D0
XKWU09jii02J]n40W;WT0080V[OS00T0V;GQ09Zei02J/^80V;3P09V_h@2H[>40V:_S09Z]i@2I[>H0
0P2GZ^@209BYhP0Q092Vg`2AYn00SJKN08ZUf`29Y=/0R:?J08JQeP25X=D0QZ3C08BNd@26WM40QicA
08>Hc@25VLh0PIG:08BEc@21T/X0PiC<082@b`1nS/T0Oho:07j>b@1lS/P0NHc607N:`P1hS<40MXZm
07F9^`1gRK/0MXRj07N7^P1fQ[T0MHFi0080LX>g00P0LhBh06f1]01]PK@0K82e06Mk/01/P;<0JWjb
06Yk/@80IWN[0P1WMj/04P1VLjX0I76V06IaY`1XM:P0IG>T06AbX`1RL:40HG6R05m_X01MKY`0GVnM
05a]V`1LKIT0FV^H05MWV01EIIH0EVJG05UVVP80EVJI00/0DV:E059RUP1CI9P0DF>E051RTP1=GHh0
CEj<04mPR`1=GXT0C5f804]LQ`0204ULQ00;04IIP@14FX40A5Z1045GP011F840?UEn03mFO`0nEGh0
?eIo03eDO@0kDW/00P0mE7h203U?N00603]>N00iC7H0>Teg03Q;L`0eB700=DU^0P0eBF`02`0gBf`0
=TY[03=:JP0cBVX0<4MY0396J@0dB6d0<DEZ02`oI`0[?VH0:3]S0080:ceS00/0;3]R02dlHP0X>5`0
9cMI02HeEP0U=5<09C=@02TeC`0W<DX0:31702L]@`09ooooo`001oooool0UP17ACT0BDLj04a:?@1>
Ccl0DeA205AF@@1DET00Fee705]NB@1OGd`0JVQI06UXEP1/JeT0JFQF071]GP1gLF<0MW1T07Q`I@1d
Jf80M6YQ079XG`1cIUh0L6=K075TG01_HUT0KF1G075SFP1bI5/0MfUQ07IYH@1HBd<0FTe508=eLP29
NgP0N6e[06]QG`2>Q8<0W9:C09N>T@2LTiH0Ui6E0:VSY`3;a/X0h]cN0=K@dP2NUY@0PWYg08b2O@2;
P7X0RGad0:VLU03<`[T0b/2g0;B]X`2/Z9l0X:2H08J7O`28SX@0U9Z@06E[H@1cNFl0_<:f0;Bj[P1k
OW<0JF]P0;Vi/@30_[P0blK30;bf]P2o^KT0aKo10:6LX01bL740Fe]K03<c<@0X:RD09b`U02T^9`0]
<2L0;S4X02P[800Z;B80?3ld05ULD`1TIeh0CE170495?P1FEe40DE9<05=BCP1GEU80FUUE05aHE@1N
FEH0G5MD05aGD`1_If@0KVIT05iDD`1hKV`0V8j<09R=R`2HSHT0Vhf:08emP02CPhd0T82=08eoT02>
P9L0Rh6J08n6Y@2:Q:H0Q82S07emW`1nPj<0XJO70:Z`d02X[/h0Z[7>0:^bcP2^]<h0[K?;0;2fc02b
^<`0/kS<0;>hcP2b^<h0]kgC0;FmdP2c_]@0]L3F0;G1f@2b`=X0/KoI0;71f`2``Md0[l3L0;72h02b
`n40/L7S0:jnh02/_^80[KkR0:foh`2[_N40[/7R0:foh`2Z_>00Z[kQ0:Rlg`80ZKgR00X0Y[cQ0:Fk
h02U^n80Y[gV0:>jh`2R^n@0W[WT09fjiP2I^>H0V[[W0P2F]n@01`2E]>80UK7Q09NahP2G/N80V:oQ
09R]hP2DZN000P2I[>@02`2DYml0TjSO09:Wh02AYn00T:KO08jWg`2<YM/0RZGK08NRf@27X]L0Q9oD
0080QYoE00H0QIcB08>Jd023V<l0PYG=082Cb`22Tl/208:Ac00;086Ac01oSlX0Oho;07b<b01mRlX0
OHg;07V<a`1gRlH0MX_407J;`P1eR[l00P1dR[`05`1dR;X0LXJh06j2]01`Q;H0LH>e06n3]@1]PK<0
Jgna06en/P1ZNjl0Jgb`06Yl/01XNJd0IGJZ06EgZ@1VMZT0IGFX06AdZ01SLjH0Hg2T06AbX`1TM:D0
GfnP0080GW2P01H0GW2N05a^W01JK9X0F6ZH05U[V@1KK9/0F6RK05IVV@1EIIP0F6FJ05IUW01IIYd0
DV6H059QVP1BHIP0CejE04iNTP1?G900Cef>04mMRP1<FhH0CUf80P1;GHD05@18G840A5Qm04EHP014
FX40A5Z304=JP`0oEWl0@5N003mFO`0mE7d0?UAm03eCO00lDG`0?E9m03U>N@0mD7X0>dih03U<MP0j
CGD0=TU`03I:K`0203I:K@<0=DUZ01H0<dMX0355J00]@F@0<TAZ03E7K`0^?fX0;CiY02XkI`0X>F@0
;3]T02dlI@0/>f@0;S]T02TgG00Z>5/09cIE02LdE00W<Th0:C=>02XbB@0W;DD09ba22Oooool000Oo
oooo00/0CU1204a>@01?DT40DeA205aMB`1SIE00J6MB06MVD@1ZJ5<0K6QF071ZFP0206eWE`1C06eW
F@1aJed0Mg5U075ZH01_J5h0L6UO079[H@1aJV00KfQN06=MD@1PFTh0JVAH069LD01JE4P0HE]?06aV
F`1/IE/0AChd04Y1>01bJF@0M6]V06QOFP1UGUP0OgMd0969QP2CRhT0Uhn=0:JPX02j][D0`l:n0;Nf
/@2NVi@0Q81g085jL02<QGP0Yj2@0:FLS@2/Xi@0]j^M0::HS028OW@0RX5h08EnN027PWh0THf:09FD
T01cLVh0LG1[0>7Qf@3>c/H0QXIl0:RUW03Fd/T0c<G10;6YYP2`ZjP0[ZRX08J2P`1DDU<0?Shn03Pj
>@0^<2d0;S<]02hc;00X<2D0;38X02hd:P0Z;B@0<cH]04i?A`1JFeD0GEiH05EFD01@DD`0FUUE05YF
D`1JEE40GEQD05mGE01NEU@0GeED069HE`1TF5P00P1REUH04@1gKF`0ThV80:BJV@2MTI40UHN609R=
R`2LSY40Wi:K09^?W@2@QIH0R7nD08Z5W029QJ00Q86N08F4X`2BTk80XZO50080ZJk<00T0ZZo=0:jc
d@2]//l0[kK@0:jfc@2_]lh0/KS?0;>ic`2b^=000P2e_M@01@2g_mH0/[gC0;>meP2b_]P0/KoJ0080
/l7N00P0/;oN0;70g`2`_mh0/<7O0;71h`2^_^00[;kR0:bnh`80ZkgS0140ZkoR0:bni02Z_>00ZK_O
0:Nig@2X^]h0Yk_N0:FlgP2S^]`0Xk_O0:2hgP2N^^40W;WQ09bih`2I^>@0V;OU09Jgi00209Fgi009
09Ffh`2E]>80U[;Q09Fah02E[n00U:_M09F/h02G[>40U:WN0080TZOL01D0T:GL08nVg02?YMh0RjCL
08ZSf@29X]P0QYoE08JOe`25W]H0Q9[C08JLe@26Vm@0QISB08BGdP25UM40Pi?>086Ac020SlX0PI3;
082?b020SlX00P1nSLP03@1mR<H0O8_707N:a@1hS<L0M8S307:8`P1dR/<0LXVo0768_01aR;X0KhJh
06f3]@1_QKL00P1^P[@206j3/P0806eo/@1ZO:h0JWb^06an/01XNZX0IgVY06IhZ01TMZ@206=eX`05
065cX@1NL9h0H7:R05mdX`1LLZ400`1JLId02P1IL9`0EfbI05EZU`1FJiX0EfRI05MWVP1FIYT0EFNI
05ATU`1CI9P205=SU`0<055QU@1BHYH0CenC051PU01=GI40C5b?04]KS01=GX`0CEj:04aMR01:G8@0
BE^31014Egl00`12F7l0?eEl041FO@0203mEO00;041CN`0oDWX0?U5k03iAN`0mD7X0?e5i03Y<M00i
Bg<0>Tab03Y;L00iBFd00P0fBFX06@0eB6T0=4MX03=6I`0cAFT0<T9V0350I`0_?VL0<d9[030mJ@0b
?f`0;ceZ02`iIP0b?FX0;cYW02dhI@0]>F80;3QN02`iG00[>5P0:SEE02TdD00X<Td0:S9902L]A@0U
:d402Oooool000Oooooo07d0Bdm0055EAP1EFDP0FEa9061QC`1RI4l0IfAA06UVD`1/Ie@0KVQH075Y
G01_IeX0L6YL071ZGP1cKF40Mg1V06aXG`1iMVd0R8El089oMP1cLFD0Lg=W061QD`1ADT@0Fea>05MH
BP14ACL0Bd/o06YZGP1^KV80Cda304U6?@1WHeX0JVEO06MRG01XI5/0Q81g09NCRP2IU8h0ShZ409JA
S@2_ZZH0YjNO096AQ`2>SX@0S8Yn08Z6NP24PG40Wib;0:BQSP2OVXL0O7MT07I_G`1iLF@0NWAX07Qa
J@23NgP0T8R609NBS`2PVYX0[jZW0>GPg03ZiMl0`kjh0=kId`3`jN<0gmKB0;>[Z@2XXj00U92?04A2
@`0`<300=cLg02X/:@0T:BD0;c@^02lf;P0V;R<0:c4W038h;P0d=bh0>che059CC@1LGEL0GEiH05eM
E`1IF5<0G5]F05mLE`1PFeD0GeYD061ID`1NEE00GU=A069GE@1SEE@0GU1?07=UI@2_XJ40XIFE09fA
T@2OT9<0U8F809F6R@2PU9T0ZIfW0:ZR/@2:QYD0M6n308>1U`25QId0QXRQ09>D/02TZ<D0ZJk;0:ba
c`2[/<h0[K;B0:jcd@2_]=80[kKB0;:ie@2a^=80/[WC0;2jd`020;6ke0<0];kG0100]<3J0;:mf@2a
_=X0/[oO0;6ngP2b_ml0/KkN0;?2h@2`_mh0[[oM0:fmgP2/_n00[;kQ0:bnhP2X^]h0Z[cP0P2[_N<3
0:Vkg`0B0:Fig02T^md0Xk[L0:6ig@2O^Mh0Wk_R09^hh02L^N<0W;WU09^hi02E]N<0TkCQ09Bch@2C
/^00Uk?R09Jbh@2C[]d0U:kO0P2E[=h209BYgP0609>Xg@2AY]d0T:GL08jUf`2=Xm`0SZCM0P2;X]P0
1`28WmD0QYcE08NLe@26Vm@0QISB08JId`23U]000P24U=001P25UM00PY;=08:Ac022TLX0P8o807j=
aP80OX[402P0O8S207Z9``1fRL<0M8W207>8`@1cRL<0LXS10729_`1]QkX0LHRj0727^@1_Q[P0KH>e
06]o/P1_P;@0Kh6c06j0/P1^O[80Jg^^06Yj[@1ZNZ`0IgVY06IhZ01UMjD0I7JT06=fX@1RMj80H7FP
05mdX@1MLZ40GG>R05idX`1LLZ40Fg6P05UaW`1IKih0F6jM05M/V`1EJYT0EfRI0P1FIYL04P1GJ9H0
Df>D05=SU01BHY<0DF6B05ART`1CHI80DUnC051PT`1?Gi<0CUjB04aLS`1;Fh`0BU^904YKQ`19FXD0
B5V404EGO`80@eIn00T0@UEm04AGO`11E7`0@5=k049DO010DWP0@E=i03mAM`11D7T00P0oCWL02@0m
CgD0?die03Y<L00kCG40?4]_03U8J@0hB6T0=TUY03Q8J@0303I6J0080390I@0d@VT0<d5X038oJ@0b
?FX0<ci[038mJP0`>fP203<kJ@0;02hiIP0/>6<0:CEM02PeF00Z=eT0:3EE02DcD00X=4h09c=;024/
@P0Q:Ch02Oooool000Oooooo00/0HFMI06Q_G`1aMF@0K6mL06]/FP1XJEL0JfQG06]XF@1YIUL0KFQL
079/H00207A]H`1I07E^IP1eLFP0L6aS06AQFP20P7P0_Kjf0;6dZ@24Qg`0LgI[06a`HP1<DT@0DUQ:
05MMC`18CT00BU1406=WG01/Kf@0IVUP05EGC01MGE<0IfMM06QXGP1[Jel0QhEi09jLT02RX9<0V9B9
09ZFS@2PW9<0VYR<08n?P`2EUH/0Shn508>3M`1mP780OH5b08F9N01fNVT0HVEB06MXEP1]KU`0MG=T
06YXF`1dL6L0RX=m0;Zb[`3OemD0lNWW0>_Sh@3ajNL0lnk[0?Wdl@3ilNh0cLG20;2XYP2?Rh`0I69S
03/i>P0g=cL0=SHd02d_;00W;2P0;3</02he;@0/=2T0<SX]03e5>011Acd0C59805MJD@1OHUT0IfQP
05iOE`1DE4`0FEUA05]KD@1LG500FeU=05eIC@1NEdd0HeYC06UNF015=c@0@S<`09J4Q02kZ:X0UhN8
08IfN@2CPXP00P2HRI00302SUj<0/Zbj0:VU]01gMXH0HEmd07YlT@2:SjD0VYjg0:BX``2Z[l`0YZ_9
0:^`d080[[;E0P2_]ML01P2`]]H0/KSE0;2feP2c^]X0/[gK0;6lf080/[gI00@0];oK0;>ng02a_m`0
]<7Q0P2b_ml01@2__=`0/KoL0;;0g@2b`Mh0[[kH0080[KkH00L0[l3L0:jogP2/_=d0[KgO0:ZmgP2Z
_>00ZK_O0080Y[[O00<0Yk_P0:Bjg`2S^Mh00P2O]m/01`2N]]`0X;WQ09jgg`2M]]l0W;CP09jfhP2K
/n800`2H/>001P2H[n40UZgO09>Zg02I[^<0UZ_P09BYgP80U:OO00<0U:OQ096TgP2@Xmd00`2>Xm`0
102=X]T0RYoG08VNe`26Vm8208NJdP80QiS@00D0Q9C?08>CcP23Tlh0Oi;<07jAb`02082Ab@0307n>
a`20SlH0Ohk50080O8_200h0NH_207F:_`1dRKh0LXVk07:9_@1`Qk/0KhVj0728^01aQkT0KhFg06n4
^@1`Q;T0L7nf0760]`80KWfd01X0KW^b06ai/01YMZd0JWN/06MgZ01XN:T0IWNU06=eX`1RM:80H7FP
061eXP1RM:@0GW:T05a`XP1MLJ@0FFfP05a`X`1JL:80F6jP05Y^X`1HJId0EVRH05MXUP1EIY80EfRC
05MVS`80E6>>00l0EF:>05ERS`1FHi00EF6A059NT01@GXl0CenB04eOT@1<GY00BUb>04MIR@18FXP0
BE^904MJQ@16FH<00P15EX401P16Eh80@eAo04IEP013DW/0A5=l049ANP80@4mf0P10CGL01`0nBgD0
?Dac03m=LP0mCFl0>TY/03];K00jBFP00`0gB6H00`0gAfP0>4MX03I5IP0203=1I00C03A0IP0a?FD0
<caU038nJ00`?6H0<3]X038jJ00`>6L0;3MT02XgH`0W=5h09cEL02HfFP0U=EL09CID02@eC`0T=4d0
8C1501l^@`09ooooo`001oooool0:P1`LfP0LWIX07eoL@1fMfL0L6iO06]ZF01]JUT0KFMI06QTF01Z
IET0KfUM07I_I@1cKf@0MW9Y06]XH@1^Jf@0QHEm0::SW@3;c/L0eM[C0;>i[`27Sh@0IFeR04M?@P1?
EdX0EUiA04iFB@1>E4P0IVYP07MhL01dMFd0LgA/06a/I01fMVh0OWif07MgK`2:RX80PH5g096AQ`2O
W9<0PGie08>0M`80QXIl01d0O7ee06UZHP1SIUd0L7A[08VAQ02AW8h0NXEe05]TD`1WKUh0LgMV07Ul
J`1bLfD0O7Y^0:6MU03@bL<0j^3N0>cRh03^i^<0l>SU0?ojm`3flNh0hmkK0;Ze/P2LUYH0Kfe^04Y8
B@0g=CH0=SHd038d<@0202X_:@0l02lf;P0_=b`0<3P[03Lo<P10B3/0AD/o05EKC`1MH5L0HFAI05mQ
EP1KG580EUM?05UKD01JG540FEU=05YKC@1HFD/0HV1C06IOE@1VGE@0HUMA061BC`2<O7`0RgQj089_
L`1kJW00RGR209N7TP2LS9T0V8fO0:NR]P2CT:<0HV=g06UYP@23Qj00Ui^d0:F[a@2X[LX0ZJk<0:N/
bP2Y[ll0[[;E0:fce`2_]MT0[[KJ0;6gf@2a^]/0/;SL0;>lg`2__=h0/;gO0;6ngP2b_Md0[kcL0;6n
gP2`_Md0/KkP0;:oh@2`_Md0/KkN0P2`_]/03@2__]/0[KgG0:fnf02[_=H0[;gG0:fnf`2[_=X0Z[[K
0:Rkg02W^Md0Yk_P0:Jjg`2U^>000P2S^N001@2S^n40X[[P0:2hgP2N]]`0W;CJ0080WKCM0140W[CM
09bag02M/]l0Vk3O09V^g@2H[M`0Uj_M09J/g@2FZ]d0V:cQ09JZg`2CY]h0U:OO09>VgP2DYn40TJCO
08nRg00208jQf`0=08fPf02;X=L0RIgE08RKd`27V]80Qi_@08NHd025U/h0QYO?08:Cb`23Tlh0Oi;<
082Cc@0207jAb@0307j?a@1lSL<0O8g10080Nhc000<0MXZm07J;_P1dR[`00P1cRk/02P1`R;P0KXJf
06f8]@1]QK<0L8Je0724]P1_PkH0L8Bg071o]P1_O[L206el]@0H06mk]@1]NK<0K7Rb06Uf[01VMZX0
IgNZ06EgY`1TMZH0I7JT061eXP1NLj00HG>S05i`XP1KKj40GVnS05]/X01LKJ<0FfnT05Y^X`1JJj40
FFZN05QZVP1FJ9<0DfB?0P1EI8/02@1DHXT0EF>:05=OQ`1EHH/0EV6>05MRT01BGH/0D5b<04iNS`03
04aLS`0704MGR017FHT0B5Z:04MIQ`16FH@0AeR404=DP002049CO`0404EDO`15DW`0A55k04ABN@80
@Dmf00<0@Dee041<M00mBg000P0nC6l0100lBf`0>DUZ03Y:J@0hBFL203M8IP80=TIW01L0=TEV03A3
I00b@F80<CmR030mH00b?V@0=3eT038kHP0`?680;CUQ02dfH@0^=f80;3QR02XgH@0U=5/09SAI02Hf
FP0W=eT09cMH028cC`0V>5008C5801`]@@09ooooo`001oooool0>`1aKVL0NGI]081lL`1^JUl0K6IH
06MQD@1VGdl0If1@06EOC`1VGe40JF=E07=`H@1_KF00JfUM06aYH028QGh0^[Vd0=?Dc`3CeM80g>7M
0=KLf02b^kH0QXn:04aFCP1JI5T0JW9W06meJ@1XJf00O7ac08j9Q@25P7`0SXJ408MoO@22NGX0QGn1
09^GV02UXJ80OWek06EUH`1fMW@0De=A05UKEP1NHEX0GF1I05IHD`1=CdX0E5IA065TH02KXId0/kbg
09bVWP1IH5P0I6YP08J<P027Rgd0Q8Ii07inLP2j^:`0fmO<0080i=gE03@0kn[T0?7/iP3Yi>00gm[F
0=?>bP2PWIT0JfYV04i=B`0d=380=cLe03<e<00`<Rd0;S</02`a:P0a=bd0=cd_03Ln;P0oASH0CeI6
055GB@1FG4h0HfIK06AXFP1FFT`0FEa?05]MDP1JG540F5]@05MICP1KGE00EUQ;05eMD@1_KF40MG5V
07mhL02GSXT0OW=a07MYJ@2:Nh00Sgn908UiQP2>P940U8FH08EiT@26OIP0RhNR079bSP1gMYD0TYJc
0:N[b02Z[l`0Z:o<0P2Z/Lh04P2X/M00[kGE0:beeP2]]MT0[[SL0;2hg@2`^]h0[kSO0:nkhP2^_>40
[kgR0:fkh02__=l0/;gP0;2mg`2__]l0/KkQ0;2mg`80[kcL00l0/KkN0;2nf`2^_MX0[kkK0:bmf@2/
_ML0Z[kG0:Vmf@2X_M`0Yk_L0:Jjf`2W^mh0YK_P0:Bjh@2T^^<00P2P]]l01@2R^>40XKON0::hg`2N
]=/0WK?J0080W;;I01T0Wk;J09^^f02M/=X0VjkI09Z]f02HZ]P0UjWI09N/f`2GZM/0V:[L09RYg@2F
Ymd0TjOL096Tg02>Xm`0SZ;M08bQfP2=X]T0S:7H08^Pe`2;W]H0RYgB08ZKd@29V]00QYO;0080QYO=
00D0PYK;082Db@21U<`0PIC<07nDb`0207jCbP0I07Z?a01hS/00NHo107R>`01gSKl0MXbm07F<_01d
S;`0LHVi0728]P1_R[D0KHRc06b8/01ZQZh0KXN`0727/`1]Pk80KH6c06io/`1[O;80KGjd06am]@1Z
NK80JGRa06Qg/00206Ef[P0C06Ef[01QMJP0H7BW05ibY01PM:H0GgBS061bXP1LKYh0FffM05a^X01I
JId0FVZN05a/X01KJih0F6RK05UYVP1EJ9<0F6ZD05ASS00205ESR0<0E62600L0E62805ENR@1CGX/0
DEb:055MS@1@G8h0CE^<0080BeV:00<0BEJ:04QHR`19FH`00P17EhP02P16EXL0A5F3049CP@11DX00
A5=n04ACO015DgX0AE=h041@LP0oCg42041>L@0R03m<KP12Cfl0?Te/03]:J@0lBfX0>TYX03M7J00f
AVL0=TUZ03E7J`0eAFT0=D=V0390H`0a?V40<SmR03<mH@0c?F00=3iQ038lG`0a?5`0;SUI02hhF`0]
=e/0:3EH02/hF`0W=EP09S=E02LfE`0V=EH09cIG02DdD@0R<T`082i801/Z@@Wooooo0007ooooo`2@
07A]I`1iLVX0Pgad06iUGP1SFe00GeM:065JBP1RFd/0GUQ805I@@01MEdL0JVMH06QVE`1[JEd0R8El
0;Vi/@3If=<0gMgK0=?Ee03AeMH0g>;R0<O?d@2@VYT0MH1l08RAS02:THX0UIZC096DS@23PWd0OGMg
07Q_L01lLg@0K65U04Y0B01ZHf/0ZjF_096;U@1]JW40?Ci304mCEP15BD`0C51A04Y>C@18CDT0ATY9
04]?CP1FF5D0HfES0;6e]02h_[X0WZFN0413?01[KVD0TiJ;09nQU028R7`0NWY^0:j/W`3?bkl0f]?9
0=cEb`3[j=l0hMkE0<_8`@2j]k00WYfH075aK01BDdh0BDU703Xl>@0f>3<0;S<]038g<00k@3T0=cdc
03@j;P10ASP0@TTi04Q??`1BFDL0DeY:065XF01_Lf@0H6AE05EIBP1HFdd0G5iA05UKCP1GFD`0EeM;
05aLD01HF4`0IF=G07ijK`2?Rh80Q7eg07Q`K@1UFeX0Ng1d09V<U@2MTId0V8fM08]oT`1lLXX0N76:
07YfT@23P9d0QXNU09ZK^P2QY<<0YZ_90:^`cP2X[l`0Z[7>0:Vbc`2[]=40[[OF0:^feP2/]]T0[KOK
0:jhg02^]mh0[;SN0:jjhP2]^n80[[[R0:nkh`2`_>80[[[P0:nlg`2]^]d0[[_N0:nlg`2__=h0[kkO
0;2mg`2__]l0[kkM0:fng02Z^mT0Z[gK0:^ng02W_=X0YkkN0P2S^]`03P2S^Mh0XkWP0::hh@2R^>40
XKKQ0:2eh02Q]^40XKOP09fcg02N]=/0WK?J09bbf@2M/MH0W;3E0P2K[]H05P2J[MD0VJcF09NZe@2I
[=L0UjWG09J[fP2DZMP0TjOI09FYg02CYm`0T:?K08bQfP2;X=T0Rj3G08ZOeP28WM@0Rj3G08RMe027
W=40QY[?08FIcP21ULP2086EbP0408:Fb`1oTlP0PIC<07nDb`80OIC:00X0OI;707^@a@1iT<80N8o1
07N>`01fSKl0MXjn07F=_@1bR[P0LHVg0P1`R;@04@1]RK40KXZb06^7[`1]QZl0JhB]06f4/01]Pk80
K82c06]o/P1[Ok@0JWjc06Qk/`1XN;<0IWN_06Ef/@1QM:h0HgJ^0080H7BY00<0Gg>V05ibY@1NLZ@0
0P1MKil01@1KKId0GFnO05a/W`1MJYh0FFVJ0080EfRF0100EVVD05MZU01FJI00EVJ:05EUQ`1DI8H0
Df6405ARQ`1AGh@0Df66059NQP1@G8H0CU^7055NR`1?GH`0CE^:0P1;FHX0<`1:F8T0AeN804aJR`17
EhP0AEN704IGQ@14EX@0@E:0045BOP12Dgh0@UAj04=BN@12DWH0?U5b03a?K`0oCg00?Tm]03i=K00n
CFX0?DaY03]:J@0lBfX0>DQX03U9J`0fAVP0=DEY0394JP0c@VT0<T5X03=1IP0b?V@0<SmR030mH00_
?5h0<3YM02hkF`0c?U`0;SaI02ljFP0[>5P0:CIF02XgF00W=5H0:3EE02LdE00V<e<09cAD02HdC`0U
<D/08B]401hY?`09ooooo`001oooool0K`1gKVL0OGA]07Q_J01@Ad00A3/d04m6?@1>AS/0BdDi04U3
=@16@C<0G5I806QTF01TH5@0S8Qo0<C1_03If=@0e=?A0=OGf@3Ee]X0cM3E0=3Ef@2j_lD0Yjjd0:fe
^02^][T0/;Rj0;>h^`24RXX0FeeO05MEF01GDUH0Ee9H03L`>014?TX0LVil07ekR@1GEF<0DE1N04U;
E`12ATl0?d=<04I;D@13B4/0A4U<04E9BP17Bd`0FUaK07inN`3?d//0[[6X08:5NP1RHUP0S8V00:BR
UP38a;P0WYZ>096=P@2i]JT0f]K:0<_7_02c/JD0`/:f0:f_XP2>T8D0QHIn071cK01;CTL0AT]403a1
>`0i?SP0>d0j02L/9P0h?CH0Be9:03m7?00h@3<0Adm004aEA01<Dd<0D5M505MKBP1SIeH0HFED05QL
B`1FFTT0E5Q705YKB`1FEdT0FEM:05mKC`1KEd/0JVAH081jKP2<PgX0OgIa06ILFP1`IVL0QGZ008n5
SP2GSi`0]Jjn0;nkc02OWK80MWN<06i`R01kOIH0RhnZ09ZP^P2TZLH0Z:g:0:R_b`020:Zac@0:0:bc
c`2Y/lh0ZkCA0:bge@2[]]H0[[SK0:^hfP2^^md0ZkSK0:jkgP80[[[P00D0];gT0;:khP2c_>D0/[_T
0;>lh`020:nkh@0E0:fig`2]^n00[KgO0:jlg`2/_=h0Z[gN0:VmgP2X_=d0YKcL0:NngP2S^mh0X[[N
0:6ig@2R^^00Y;[Q0:6gh02R^>40XKKQ0:6fh`2P]N00YKSS0080XKCO0P2P/md0102N/M/0WK3H09f`
f02L/]L209R^d`0W09F[dP2EZm@0UjcG09FZe@2AZ=@0TJOF09>YfP2BZ=X0TZOL08nTf`2>Xm`0SJ;K
08^NeP2:WMD0RYoH08ZOeP26WM<0QIgC086Jd022Vm40PIS<082Gc@1oU<T0P9G:07fBa`1oU</0OI;9
07bCb@1kT/P0O97807V>``1hSl<0MY3107F?`01aRk`0L8^j07><^P1dS;X0LHVe0080KhNc0P1^Q[80
6`1]QK40KhJb06j4/`1YPK40Jh:d06Z0/P1XOK80JGjc06Ik/01UN[40IgZb06=f/01RMK00HGB_069b
[P1QLJ`0H76Y05m`YP1MKZ80GW2R05i`X01LKYh0G6jL05e_W@1KK9X0FV^I05U/U`0205MZU00705AZ
T@1CJHh0DfV:059UQP1BIHD0DFB405=SQ@02055QP`0C055QQ@1AH8L0D5n804eNR@1?H8`0C5f904UJ
QP19FhT0B5Z804MIQ`17FXD0BU^704EHPP12Eh80A5N103mEOP0oDW`0@5=m041CN`0203iBM`0<03iB
M@0jDG40>U5`03]@K`0iCV/0>4]Y03U<JP0mC6/0>dY[03Y:J`0hB6X0=dM[0P0e@fP0100b@FP0<3mV
030oIP0`?fH20390I`07030nI@0^?640<3aR02hlG`0/>E/0;3]L02djG00202ThF@0:02PgF00W=UL0
:3EE02LeDP0X<e40:35>02PbB`0X<4L09B]1024X>`Wooooo0007ooooo`0507igK@1dKF<0IeiG04a3
?019@3T00P14>c803`15?C80?CL[04e7?01QFU00FU=9089nM@2n^K<0e=7<0=C@c@3>cL/0d=3B0<k=
dP38bLh0^Kc30;:e_0020;2d_@0i0;Fi`P2f^l40SYFK07^2R01^LWT0EUIN05aMHP1GEU`0CdeH075_
O01gMH80Gei/055@GP1BDUh0BTaH05IJH`1CEf00AdaB04=6B`17Bdh0A4Q904U;BP1OGed0UYNA0<32
]`2CThL0RHYl08V7NP2@S840`knd0=OCb02b[Z<0^kN/0>?Qe@3>c/80Vi^A08>5N02<SX40K71R059F
B01AE4T0Ce9704Q<@`15BT<0@4Dn03i3?@0g?3H0;c@^04aABP1?Ed`0BE5404YBA@1=EDH0C5E404eD
A01AF4H0EU]70080FEi:01X0E5Q7055EA01CEDD0EUA7055?@P1YIET0Mg5U069JC`1`Ieh0Uhf408f2
OP1eJVP0M6QZ08IkP@2UVj@0Y9bY0:BP[`2/Zkd0TiBX075fRP1PIW`0LWZ?092H[`2LY;/0XZ[10:F]
a080Yjo600`0Z[7;0:bcc@2//ll0[;KA0:fgdP2]^=H0ZkKD0:Zge`2/^MT0[K[J0:fjg02^^md20:jk
gP0/0;2lhP2a_N<0];gV0;>li@2a_ND0/;cR0:jlh@2/^]l0[;cN0:ZmgP2X^]h0ZK_O0:Rlg`2U_=h0
Y[cQ0:Fmh@2T_>80XK_Q0::kh`2S^^<0X[WR0::hh@2Q]^40X;GP09jeg`2O]>40WK;O09fbg@2L/M`0
WK;M09bag02K[M/0VZoJ09bag02L/]/0V[3I09N^e`2F[MH0Tj[C09J]e`2E[=P0TZWE08nWe@2=Z=D2
08bSe@0408jUf@29W]D0S:7J08ZOf080R9gF00D0R9kG08NMeP24WM<0PIcA07bJcP0207jIcP0?07jG
c@1mU/`0NYC707fDb01mU<X0Ni;807bCb@1kT/P0NHk507R=`P1fSL40M8jo07>:_01aS;/0Lh^i0080
LXZh00<0LHVe06j6/P1`Q[D00P1^Q[@05`1[Pjl0Jh>a06Z2/01XP;00Ign_06Im[`1XOk40Igj`06El
[P1UNZl0I7V^06=f[P1SM[00H7>^06=c[`1PL:/0G6bW05e^YP1LKJ<0Gg2T05i`XP1MKil0G6jN0080
FF^I0100FFbG05M]UP1DK980Df^A05=[S`1@J8X0DFV904iUQ@1BIXL0DFF6051TQ`1=HHH0D6B904eQ
QP1=H8P0Bej80P1<GhX02`19G8L0Aeb704IKQP16FhH0AEZ504ILQ@19G8@0@UQo041FO@11Egh0?UAk
0080?eEl00@0?UAi03aBM`0kDGH0>U1e0P0iDG<02`0hCfl0>4m^03Q=K00hCF`0?dma03Y:K00iBFd0
>4Q/03E5J@0gAFX0=D=Z0080<T5X00D0<3mV02lnI@0_?F@0<T1W03E3JP0202lmHP<0;3YM00d0:cUL
02XhF`0[>U/0:3MH02PgEP0V=E@09SAA02/fDP0Y<dh0:C5802TaA00X;d408RTk00Wooooo0007oooo
o`0F08:3M@1^Kf40DDm303/g:`12>Rl0>S8W03/a9`0n=2X0Acdd05Q>AP1GCTL0Qh1h0;>/YP36`Kd0
dm3;0=_Ge03Ddm40dm?C0<g=c`33`lD0^kc00;6b]`80/[:j05L0][W00:NZ/`2=TIX0YZfe09JKY@1K
GfX0L7Am075fO01`MG/0LGAk05mRJ@1DEEX0EeQM05IGF`1aLWH0PX>806]/L@12@DH0@T1304M7A`1C
De40FeaG05MHDP2DU8T0Wj2B09BBP`2KVHX0L6iO07ekKP2g]:/0c<W20<S8`03Qh]`0gn;K0:jc[02<
U8T0P8Qk06E[G@10AcL0ATdm04U=?P1<D440C4m104M:?`16BD00?D0i03Pj=@0m@S`0CU=<04mEB`1=
DdL0BU1404Q@@@1:Dd80Be9005AIA@1HFdP0DeI305=FA@1HFdX0E5I8055?A@1>BD<0Dda607acKP2;
PWd0LFIR07U^K02ISX`0Qg]k081dN02@QHd0W92L0<:jb@2k]<@0Ti2S06]/P01UJ7/0GfIi05YRM`20
Ril0X:^m0:6/_P2PZkd0Xj_00:F]`P2X/<D00P2[/lX01`2]]<h0[KO@0:fgdP2[]m40[[WE0:^ieP2/
^]L00P2^_=T02@2^^m/0[kcO0:nmh02^_>40[kgR0:jlh@2`_^<0[koS0:fmg`020:Rkf`0>0:Vng@2X
_M`0Y[[K0:FlgP2W_^00X[[N0:6ig`2Q^^80X[_T09nki02O^^D0XKWU09jfhP2O]^8209nfh00309^d
g@2M]=h0W;?M0080W;?M0P2L/ml0402J[mh0V[3O09V_gP2G[M`0VJoN09J^gP2CZm/0TJWI092[fP2@
Z]/0SjWJ08bXf02;YmL0RjCJ08VRf02:Xm/208VOf@0B08RNf025W]L0QYoH08FNe`23W]D0P9_@07jL
d01kVlh0OI_?07ZHc01kVLd0NiK;07^Gb@1jU/P0NYC707^BaP1iT<@0N8o30`1gS<401@1bRK/0M8Zl
07>;^`1bR;L0LHNf0080L8Je00D0KhFd06b4/P1[Pk40K8Bb06N2[`0206R3/00A06F0[@1TOj`0I7n/
06=nZ`1TOj`0IWj/06AjZ`1RN:X0HGFZ069eZ`1RLj/0HW6Z065`Z`1PKjX0GVfV05e^Y01NKjD00P1L
L:<0501KKj40FFnN05I]V@1DJiD0DV^C04mYSP1AJi00CfV<04eWRP1>IhX0CFF904iTR@1=HhX0CF:=
04aQS01=HXl0BUn<04]PS@19GXd0B5f<0P19GXd01`15FXL0Aeb704QOR017GXL0A5b204AJO`0oEgT0
0P0nEWP00`0lE7P0?UIj03iFNP0203eCNP0503Y@M`0iCgH0>E5g03Q@MP0hCWD00P0eBg002P0gBg00
=dU_03M9K`0hBW00=TQ^03=5J`0hAfh0=TE/0353J@0^@6H202m1I@0402hnHP0_?f40;cmQ02hnG`@0
:c]L00d0:3QJ02TiF`0X>5T09SME02LhEP0V=eD093EA02<cC@0U<dd08bm502@a@P0Q;Cd07bPg00Wo
oooo0007ooooo`1^07UjK01NGe40BDDi03Xd:00l=2T0>2hT03DX7`15>300FDa405=8@P1JDDX0Y9fE
0;bh[`2i]:h0b/O00=GDc`3@clX0clk<0;bl^P2b/[80];Bd0:n_/@2a/;D0[:^a0:Z[/02n_l@0a<O>
0<W>e02;SiL0H6A]06mfO01[LgH0JG5c06=YJ@1AEeL0C51?05IHE@1>D4d0SY2=08V9Q`1dM7@0BTU7
04=2?P1>CDT0FeaF061QF@1HF4h0Q8=e09VHQP2NWH/0RhYh06QVE`2<RWd0ZJVO0=gMe@3NgmT0d=;=
0;_0^P2NYIh0MX1g05IPE@19Cd40@4Lg04E9>P1;Cch0E5M605=EA`1=Cd80Bde204A7?P14Ad00B4]4
04iAB01AEd/0D5I804U?@@1:DD40CEA205EIB01FFdL0G5m<04I9>015B3L0D55304m?@`1;Ad00GUIC
06ILFP1XGU`0N6a/0924Q02BQ8@0QWYl07]_L`2>PhT0[:2Z0:fR/02bZk/0YZ>f071^P`1>D6D0GFAg
06Q`Q@1kQY`0UZ>f09j[_P2S[/00Y:o10:B_``2V/LD20:Zeb`060:^ecP2/]/l0[KOB0:fid`2]^=@0
[;[E0P2^_=L06P2__MP0[[cG0:jmfP2`_ml0[[kO0:jnh02[_]l0ZKcM0:boh02[_n00ZKkM0:Jmg02W
_m/0Y;kI0:>mf02T_M/0XkcK0:Fmg`2Q^Md0WkWN0:2ih@2Q^^<0XKWU0:2hiP2O]nD0WkGT0P2N]N40
102M]=h0W;GN09begP2K]=d209Vbf`0409^cg`2H/=`0V;3N09N_g`<0U:kO00T0U:gR09:[h@2@ZMl0
SZOM08nXgP2=ZM/0RZKH08VUe`2:XmT00P29X]X03027X=P0RIoI08FNeP25W]H0PikE08BOeP23W]D0
PYgB07jLd01jV/d0O9c?07VGb`80N9K:00X0MYC807NEa`1hTlP0Mi7407^BaP1hSl<0N8g207F:_`1g
S<40MHZo0P1dR[`00`1cRKX0L8Jg0726]`020726]`0k06b3]@1ZPK<0J8>b06R3/P1VP[40IH6`06B1
[@1QOZX0HGbY06=nZ`1ROJX0H7^X069jZP1QMjT0HGFX061cY`1RLjT0HW6Z061_Z01QL:/0GfjY05e^
YP1MKZ@0FfnT05Y^X`1KKj80FFnP05I/V`1BJYH0DFZC051YT@1?J900CFN<04iXS@1=IX`0C6B:04iU
SP1>IHl0CV>@04eRT@1;Gi40BEn@04]QTP19Gi00AUZ<04QLSP17G8/0A5V604MNR017GXL0AEb5049J
P011FGd0?eMi03eEM`0nEWP0?UIj03iFO00nE7/00P0mDg`0200jD7T0>4ig03Y?NP0iCWT0=T]f0398
L@0gBW@0=TUa0P0gBG404P0fB700=4I^0353J@0a@fT0<dE[0394JP0^@6H0<49V02i0I00/?V80:ceQ
02`oH00X>e`09SUI02PkF`0Y>EX0:3QI02LgF@809SIG00X09SME02HgD`0T=E<08S=?02<cC@0T=4/0
93=602HcA00R;S`06bLc2Oooool000Oooooo07L0G5I:04Y4>00l=2T0=R`R03P^900c9Qh0@3<[05=6
?P1AAch0BD4g04Q4>@2DT8D0ZJNK0<C2]P3>c/80bLVo0;fm/`2h]k80[ZfX0:FTW`2[ZZH0YZFS09nO
W`2LW9`0Y:JU0<O9b037b<X0XZJW06Y^K`1MHF80HFET065WI@1KHEd0GVAP069YH@1KHEL0F5]B055D
B@1ZK640OGmd08F7O01CEDX0?T0c04mAA01@DTD0F5Y<06EVEP27QgH0ViR50:RUTP2ASWd0S8Yk0:>Q
U02_[jD0hn?K0>GVh037b<80Wj:K07YoN01DFE80AD]10416>P0i?Bl0ADLi04e?@@1EETP0EeQ:05=E
A`1CEDP0CU1304=5>01?DdD0E5Q9055EAP1@E4D0Ce=404iB@@1DF4L0FEe<05YMC01LGdh0ATTh04E6
>016ASX0BDLk055=A@1TGEL0HUQF06=IE`25NGT0VHf=09:6QP28O7h0Rgj50::GW`2bZ[D0[jVg0::N
[`25Q9H0H65f05]PMP1[LHT0Q8bS09:L]@2JY[h0W:_00::^a02W/lT0Z;C<0:RdcP2W//h0ZKC@0:Ze
d`2Z^=D0Z[OG0:bif@2]^]X0[;_H0:jmfP020:fme`030:jnf02/_ML0[<3K0080Zl3M01<0ZKkK0:Jm
g02V_M`0Y[oM0:>nf`2T_m`0XkkK0:6le`2R_MP0YL3M0::mf`2T_md0WkWJ0::jgP2R^^00X[WR0:2g
hP2O]^80X;OS0080X;GR00<0W[GQ09fdgP2K/]`00P2K/]`209Vag@0809Ncf`2F/M`0U;7M096]g02A
[Md0TZkP096]g`2C[><2096ZhP0508nXh02>Yml0RjCJ08fWfP2:Y=L00`2<XmL01P2:XMD0R:;E08NQ
e024W]40Q9k?08>Md080P9c>00d0OYc>07ZHbP1kVLd0NIO;07RFbP1gULT0MI?707BBaP1fTLP0N9?8
07ZCb@1gT<H0Mhg60080MXc500H0M8_107>8_`1bQkh0LXNl07:6^`1`Pk/206n4^@0306j5^@1[P[H0
Ih6d0080IX2c00<0I7ja06F1/`1TP;800P1PNZ/2065k[00;05mfZ01QN:`0HWN/065eZP1RMZ/0I7F]
065a[01OKJX0H6nZ05i^Z@1MKZH00P1LKJ<0201KK:00FVjP05I[VP1CJ9D0EFZE05=ZT`1AJ940D6N@
0P1AJ9404`1=I8d0CfJ@04eTSP1>Hi00CV>B04]OT@1:GY00BenB04YNT@15Fh`0Aef>04QNS@16GHT0
AEb604AKQ013G8@0@Ub1045KP010FGd00P0mEGT07`10EWd0@EAn045DO`0oDWd0?U5l03]@N`0iCWT0
>e1m03e?O@0iBgT0>4Yh03]<N00gB7<0=DIa03U8L`0hAg00=dI^03A3JP0cAF/0<TAX0353J@0^@6H0
<4AY02/oI00Z?V<0:CeR02/oI00Y?F80:CeP02LkGP0X>e`00P0U>5T0300S=UH093AE02LgE@0V=U00
9SEB02@dCP0S<dX08cA802DeA@0Y=TH082`h01`V<0Wooooo0007ooooo`1^03Ta:@0i<BP0=B/T03H/
9@0h;RP0ASXe04a0>`1<@3X0AS`e03/b:`0a:R80JfAK09>>P`2ZYY`0[ZZN0::OT`2NVhh0W9Z<09:?
P`26PgL0S8]o09RDS@2^[:L0bl[40<g=b02TY:40Q8F107AcL@1^KF`0J6MV06MWI@1VIf80JFQT06a/
IP1aLFT0JV]Q069TE`1WJ5`0KVmQ06i`H@1VJET0E5Q604U<>@1GFdH0HFA@06a^FP1oPFd0PX=^08F6
L@2VYi<0^;VU09NJR021Q7<0SY:10;Vn[P2d^:X0PHIj0413=`0j?S80?T4f04A7?01<CT80CTm304m>
@P1CDTD0E5A905MHC01HFT`0F5]=04eB@P1=D400E5Y705MMBP1CFDL0EEU905QLC@1GFdh0F5a@05UK
D@1HFE00E5E<04i@AP1=CDH0DDi7059>A`1KDdl0G59>0598A@1PEE80ZYnN0;Z_[P2QV9H0XYZJ0;>Z
[`30^/40^;?007]iR@1XIg/0I6En06Y^RP1iOi`0T9Rg09^U``2NZLL0WJ_60:6ab@2T]</0Y[G<0:Jd
cP2X]]420:Vge080ZKOE01D0Z[WI0:ZjfP2/_=/0[KgK0:fmfP2Z_ML0[[kI0:bof@2/_m`0ZkoK0:Zo
g@2X_md0YkoM0:Nog`2U_]h0Y/3P0:Bng`2U_]l0XkgO0:Bnh02S_Ml00P2S_Mh0:@2U_>00X[WL0::i
g@2S^]h0Y;WO0:>gg`2R]^00X;GO0:2fh02Q]N40WkCP09^`g02J/=`0W;;M09Z`g@2I/=d0V:oL09J`
g@2G/=h0UJoN09>]g@2C[Ml0TjcO09:Zh02@Y^00TZOQ096Ug`2@Y=h0TJCM092Sf@2AXmL0T:;D08nQ
d`2>X]80S:3@08^Qd@2<XM40RIo@08RNc`26WLl0QYc?0080Q9cA00T0P9W=07jFc@1nULd0OIG<07fE
cP1jTl/0NI?;07RBbP1iTLX00P1hSlT03`1fS/P0Mhg907F;a`1eR/L0M8[507>7``1cR<<0M8O307>6
`01bQKl0Kh>m06f2^P1^PkX0Jh6h06b2^00206Z0]`80JGnf01`0J7je06Mk/01XO;40Ig^_06Ei[@1T
Mj/0HgFZ06Eh[01TMZX0HW>X065bZ01PL:H0GfnW05e]Y@1NKjD0GFjT05e`Y01IJj00EfVM05Q[W@1G
JY/0EFZI05IZVP1EJYL0DfRD055WT@1BIi40DFNA0P1>I8h00`1>Hhh0D6:@051RT@0304ePT@80Bej?
00l0Aef=04IJRP15FXX0AUb904EKR012F8@0@e^7049IQ@12Eh<0@5B0041BOP13Dh00A5>304=@P013
D7h00P10Cg/03`0nCgX0?Tmi03e=N00kBgH0>d]e03];M00jBW<0>4Q`03U9L@0hB700=DI/03=4JP0b
A6T0<D=X0351J0020312J00F02i1IP0/?fL0;3mW02/mI00Z?F@0;3mU02/nI00[?640:CYM02XlGP0V
>5T09cMH02HfE00W=U809cIA02HeC`0X=e008c98028aA00U<T@08Bdm01hX=PWooooo0007ooooo`06
03Pc;@0o>S@0?3La04@o>`17?c`0BD4n0P14>SP0?00n=c40<b/V04e4?`0c;2@0JV=K08=lM023O780
LfeQ07AaHP1^Je`0K6YK06MUEP1THU<0QH=f0;NeZ@2m_K<0[JfS07]kL`1PGeX0Lg9^07YgMP1iMGH0
JVIU06YTI01]J6D0LFaX07A_J@1dL6L0L6eT06aZGP1PHE<0FEa;05AGAP1EF4D0GV5<06Y^E`1eNF80
LWAN06maG01aM600V9^80<K;]`2h_:/0IfiL04iE@`27SW`0[;>Q09^TT@10AcD092PI030d9@0i>bh0
CU1305EEB@1DE4P0EE9905AAB01DET/0EEM<059FB080DUU90380DeY8059IA`1DFdT0F5m=05AHBP1F
FDh0F5]B05AEC`1>CdX0DU5?05EDDP1FEE<0FE=C05QBDP1FCT`0E4U705mDDP1UFUP0KV=Q08n5P`2W
Wid0][2`0;B_/`3:alh0^kW409fL[01LGg80G5ig06U^R`28SZh0VJ;309nYc02NZ</0Xjg@0:>ac`2T
//d0Z;K@0:Nec`2X]<h0ZkOA0:Zed@2/]m<0[KSD0:Vge02Z^MH0ZKSE0:VjeP2Z^mL0ZKgH0:NkeP80
Z;_I00L0Z[gK0:Vng02Z_mh0Z;oO0:FlgP2V_Ml0YkgR0080Y[cQ0P2W^^805`2U^>80Yk[T0:Fhh02T
]ml0YKSP0:FigP2T^=d0XkOL0:>gfP2R]]X0X[KK0:2df@2N]=/0X[GO0::eh02N/mh0W;7N09j`h02H
[M`0VJkM09R^g`2H[^00V:gR00<0UZ_P01P0UJ[Q09BWg`2AY=h0T:3K096Qg02BXm/0T:7G09:ReP2C
XmH0TJ7B08jNc`2=Wll0SZ3@08VKc@2;WLl0Ric@08^LdP26VM40PiK>08BGd@23U]40PIC?086Ac@1n
TL`207^>b@0B07b?bP1kT<T0O97:07^>b@1jSLP0N8[807J:a`1eRLP0M8S707F9aP1bQ/<0M8S707>7
aP1cQLD0LH?006n4_@1/PKX0K86h0P1[P;L206^0]@0406Yn/`1[Ok@0JGZ`06Uj/080K7b`00h0J7R[
06IfZ@1WM:P0I76U06EeYP1SLZ@0HW:U069bX`1QLJ80Gg6Q05a^WP1KKIl0G6jP05Y^X080F6bO00<0
EVZM05AXV`1DJ9/00P1DJ9X0201EIiL0EVRF05=UT`1AII00CV>>04iQS01AI8l0CV6<0P1>H8h01`1=
Ghd0Bef;04YLS01:G8`0Bef=04MIR`16F8X00`17FH/04P15EhT0@UJ904=DQP15Dh@0A5:304=?O`12
CWh0AU5o04=>N`11CGL0@Dee045?MP0nC740?dmc03e=L@0jBVh0>4Q/03Q:KP80=TQ/00<0=DM[0353
J00`@VP00P0bA6X0100d@fX0<D1W0312J00^@6H202hmIP0502hlH`0/>V40;S]U02XiH00Z>5l00P0[
>Eh0300Y=eX09SAG02HeEP0U<U809SAA02@bC`0T<Td09C=>02HbC00U<DT09Be4020X?@Wooooo0007
ooooo`0e04=5>P18BSl0ATHn04M4?@14?cT0?CPb030[9`0]:2@0<c0Y030]9012?SD0>cL^065MDP1h
M6T0L6aQ061LD@1IEd/0DDm305YJCP1LGDl0A4Dg061QD`2QXY@0RH]m07eoL@1_L680JFUM06m/H`1e
LF`0NgIc069LG01UG5d0JV5R071XIP1bJVP0LFaX06QUH01UHU/0GemE05eODP1IG4/0F5e907=hHP1k
P6X0Oh=/05AG@P19C3T0NWe]0;2bY@3<d<80`lVm06Y]HP1NHEH00P2IWi<01P1UJel0;cDY02/^8`0S
9Q/0>CXb055BBP80D59704T0DU9:05EFCP1FEdl0D5=:051FC01DFTh0De]>05=KC01?EdP0CeQ705=J
BP1FFDh0E5M>05EFCP1DEDl0D4a9051<B`1HDU@0GeUK06EJGP1SFEX0FDm@0555A@1QEED0M6QX07Y^
KP1mLg@0PgYm09JAU`2PWJH0[J^h08F7UP1/Kh80J6j407^1V`29T:d0W:G40:2[b`2S[M00XJ_>0:J`
d`2Z/m<0Z[?@0:^bc`2//m00[[?A0:ndd@2//Lh0/KKC0;2gd`2]]]<0[;OC0:fkeP2Z^]@0Z[_G0:Zn
f@2X_=L0YkcI0:Fje`2X_M`0Z;cL0:VmgP2V^]d0Z;cO0:Jjg@2Y^ml0YkWM0:Vig@2[^^40Z[WP0:Fg
g`2V^>00Y[SN0080Y;KL0140Y[SN0:Fgg@2T]]`0Y;KL0:>ef`2Q]MX0Wk?H0:2df@2O/mP0XKCL09nb
g@2L[]`0Vk3O09V^g@2J[^00V:cN09N[h00209JYh@0B09FXh02FZN40Uj[R09JWg`2EY]h0TZ?I08nP
eP2@XML0Sj3F08bPe@2<X=<0RYkA08bPd`2;Wm@0SJ7F08NJdP26VM<0Ri_F0P27Um<02@26U]80QIGA
08>Cd@23T]40Pi7@08:@c@20S//0PI3;07n>b@0207j=aP0807n>a`1mS<D0OHc507^:``1hQl80MXK1
07N7``1cQ/4207B6a0040765`P1`Q;l0KXBm06^2]P80JH2d00<0JGjc06b2]01ZO[400P1YOJl0201Z
O:`0JG^[06Yj[@1XN:T0JGZX06QiY`1WMJ@0IG>R0P1TMJ<01@1PLIl0HG:P061bX01PLIl0G6fK00<0
FffM0P1KKIl04@1IJid0EVNK05IWV`1FJ9X0EFNI05MWVP1GIiP0E6FC05=UTP1AI8l0DV>>055RS@1@
HH`0DF:>04mPS01@HHd0CEj:0080BU^902D0CEj<04YJR`18F8/0AeN:04MGR`19EX/0AeB904ACRP14
DhL0A52404A@P014DGh0AE9l04ECNP14DWL0@U1e045?LP12DG80?di_03i=KP0mCFl0>d]]03M:J`0i
Bfl0>4Y^03A8K@0fBVl0<dM/0355JP0cAf`0<DEZ03A6K00cAF/0<3mV0391J00`?FL0;caV0080<CeU
0140;CUQ02XhG`0Y=E/0:SMJ02/hF`0Z=eX0:CII02LdE`0Y<eH09S1C02D`D00T;U4092m?02H_CP0W
<4d09Ba802D[A@09ooooo`001oooool06@10AcL0@dLi04M9?P13@cT0=cL]02LW7@0P81P08b<K02h`
9@0];R<0>c/_03De:@18B3`0GUiB05eMD@1IEd/0BDTm04M7?@1ADdP0EEM<04A6>`1VJ5/0SHn1079d
IP1/Keh00P1XJE/01@1[J5l0LFeW071[I`1ZHV00KVEV0080L6MX01X0JVER06UTH@1YIF80HF1K05aM
E@1RI5T0I6QJ06Y^G`24R7T0LGET055D@`0c=RD0DE=509VKT@2n_kL0`lJo0<O:``26RH80OH1i092C
S01ZKFH0<cH_038e;P0Z;BH04A@=03Xk=P80CTm900H0Bda6051AB`1EEe80DE=>04e@B`1AETl2059I
D@04055ICP1@F4d0D5Q;059JC@80DeI=01T0DeA>05=BCP1CCDd0D4Y:05M>D@1QEUX0JUmU06aOIP1H
C500DdQ<06IKG`1nLgL0OgIi085jP@1lMX00O7R607YgR01jNhl0JF^2065UOP1iP9X0U9fj09^T``2P
Zl/0XZg=0080Y:kA01X0ZK;C0:Vad@2[/M40[kCD0:jcd@2_/]<0/KCC0;2dd@2_]=40[kCB0:fdd@2]
]]<0[[WE0:^ieP2Z^MH0Z[_G0:Rkf@2X_MX0Y[_H0:Nlf`2W^m/0Z;cM0:JifP2W^]/0Y[WJ0:Vif`80
Z;KI00P0ZkWL0:Vgg02V]]X0YKCK0:Nfg@2U]=/0XK?I0:Bfg080XkGM01L0Y;KN0::dg02P/]X0Wk7G
09jbe`2P/m/0X;?M09jag02M[md0W:kN09V]g`2H[=h0UZ[M09JYh@2DYml0UJSP09JWg`2EY]h0U:GM
09FTg@2EY=/0Tj;I096Pe`0208jOe@80RYgE0180RIkE08ZOf028WMH0RYkI08JJe@27VML0QiWI08JE
eP26U]@0Q9?D08>Cd@23T]<0PY7@08B?c`21S<X0Pho;08>?b@1oRlD207j;`P0>07n:`P20Rl<0OX_2
07f:`@1iQKl0NXK207N6`@1cPkl0LX;00722`01aQ;l0Kh>m06^1^P1YP;@206Qo/`0G06Un/`1[Ok80
Ig^]06Ql[P1XOJ`0JWb/06QjZP1XN:T0IWJW06QiY`1UMZ@0HgBR06AeX`1SM:80HW>Q065bX01PLZ00
GFnM05m_X01PL:40GVjO05a/W@1MKIh00P1KJih05P1HJ9/0EfNJ05MWVP1CHiH0EVJG05ATU@1EIIH0
E6FC05=TT@1@HHd0Cf2;04iPR01?H8/0D66<04eNR@1?H8/0Beb804YKQ`19FXP0C5f;04aJR`19EhP2
04UFRP0?04YER`17DXP0AE:704ICQ`15DH<0AE9o04=@O013DGP0@U1g049@M@10CW<0?Ta_03m=L00n
C6l0?4Y]0080>d]_00@0>4Q/03Q:L00gBG40<TA/0P0dAfl01@0dAV`0<TA/0394K00`@VX0=4=/0080
<T5Z00@0<3eW02llIP0_>fD0<CYS0P0]>F40100Z=U`09cAG02TcE`0/=UX202TcE`809S1D00L0:31E
02D]DP0S:dl09Bi?02D^C@0V;DT08RQ200Wooooo0007ooooo`180458=P18Ccd0ADTj03<g:00J7Q00
4AD701hQ5P0X;1h0:BlQ02`a8`0e>B/0=CTZ04U=?P1LGU40FE]>05MGC@1=Cd@0FeaD06=TG01WJ600
I6MN06]^I@1^LFH0IFML06AVF@1UIET0IFEK06ISFP1[If80MW5]079]JP1fLFh0KVUV05QCD01LF5D0
GEaH061OF`1UI600HfAO06IXH`1_LV/0MWUb07]nM`1VIf40Bda606e/I`2IV9@0^[Vf0<O7a@2f][H0
[:bZ0:JVY01iNWD0ADI103<d;`0a<Rd0<34/02LX8`0E5Q40<S8`04Y:B01@DTl0CDm:04I8@`18BTL0
BD]804I:AP1?E500CeEA04]EC@1@Ee00CeI?0P1AF500601BEDh0DEA=051AC01=C4P0DTa<05A;CP1B
Add0J5eS08=hP01/HFT0DTI@05E=E@1RFf<0Mg9i08N1R`2CSid0RhJJ06EQN01RGgX0JFR706MZR`1b
MiL0SYBd0:6Zb`80WZW900T0Wj[:0::[c02V[m00[;;D0:fbe02_/mH0[[;E0;2ee@2a]MP00P2_]=@0
302_]MD0[[CD0;2feP2^]mH0[KSF0:VfeP2Y^=L0Z[_I0:NjfP2W_=/0Z;gL0:Nlf`80Z;_K01<0ZK[H
0:Zkf@2Y^]P0Zk[I0:Vhe`2Y]]H0ZKSI0:Nef02V]]P0Y;KJ0:Fgg@2T]]h0XK?K0::dg02R/mh0XkCO
0:Beh@2R/]h0WZoK0080WZoJ01/0X;7M09f^g02N[]l0WZkQ09b/g`2IZ]h0VJ[P09RYh@2GZ>00UjOR
09FUh02FYN00UJCO09FTg@2HY=h0UJ7K09:QfP2AX=T0T9oH08nNe`2=WMP0Ri_G08VLe`27VML0QYSH
08RLf`24V=L00P24UmT02@23UML0P9;B082Be022TM80PY;@086@c@21T</0Q93:086>a@0208:?a080
Ohc100`0OHRn07n:`01mR/40NhO107Z6`P1iQ<80N8?107N5a01dP/40LH6o0723_P1_P[d206Yo^007
06b1^01[P;L0JWjc06Yn/`1ZO[40J7b_06Ij[00206Qj[00806MiZ`1TMZP0IgV[06EgZ@1SM:P0I7FY
069cY`1PLZD2061bY00=05e_X@1OKj<0GfnS05m/X01NJil0GfbP05i[W`1MJYh0FfVJ05YXV@1HIYD0
EVNE05=TTP0205ITT`0305EVTP1BHi00D66=0080CF2:0P1<GhT02P1;GXP0C5n904eNR@19FXH0BE^9
04aMR`19EhH0BUR704YHR@19EhP204QDQ00H04IBPP15DWl0A55n04EBOP14DG/0@Dih049?N@11D7T0
>dYc03e<M@0nCGH0>dYe03a;MP0lBGD0?DYf03]8M00jB7D0>DMd03E3L00fAG00>4Mb03I5KP0e@Vh0
=45]0P0a?VX203A1K@0402djIP0^>fD0;SYT02`hHP<0;SMP00L0:cAK02XcFP0Z<eX09c1G02HaEP0R
;e808c1C008092iB00D08Ra?02@_C@0T;TT09Be4028X?P09ooooo`001oooool05`1BEd<0E5Q703a0
;`0P91D061l?01<I2`0R:1`0;C<W02`d9@0d>b`0=cd_03i2<`1>DT<0J6YM061PEP1DE4X0EeM?075a
J@1iN7<0Oh1j07YkM@1SI5h0GUmI0080HF5I0500Hf=K065QF@1THEX0KV]V065NF@1OG5L0J6EP05AA
C00X9b80@d@o05mPF`1VIf80HfAO06]/I`1aLfh0OGmj07]lM`1[K6L0Gf1K08N6PP3:bLD0fMSD0;Vh
]02SXYh0S8^906YZJ01]K6X0GEaH0452?@0e=S40>c`g038b<00/;2X09bTX034a<@16ATH0Ce5@04M9
AP19BdP0CU1=051BD@1:CD`0BTm;04Y@C01;DDd0CE9<04iCC@1AF540DUM@051ECP1?DT/0BDY404Y9
A@1AC4T0D4Y:06YQI01mM7L0JF1U05Q>EP1JD5T0CdUB07ihPP1WI6l0P7b;09B?X`1`K8D0E4m]065M
OP1WIHX0OGfS09>E^`2MXlL0WjO;09jWb02PZLX0Xjc;0:F[c@2Z/=00[;;D0:fbe0<0[[;E00d0[k?F
0:jdeP2^]=P0Zk?G0:jffP2]]MT0[[SK0:bif`2[^=X0ZKSI0:VifP2W]mP0Z;_K0080Y[WI0200ZK[K
0:Rie`2X^MD0Z;WE0:Zke@2X^=80YkOA0:JedP2V]M@0YkOH0:Bgf02U]m/0Y[SN0:2ag02Q/]d0X[?O
0:2bh02O/Ml0X;;R09n`h02O[n00WJoM09b^g02N[]l0Vj_L0:2`h`2L[=l0W:cP09^[g`2HYmh0UjSN
09JWg`<0U:GM00@0Tj;K09:QfP2CX]/0SikH0P2?W]T04`2=W=L0S9_F08bLf029VMD0RIWG08NIf@26
V=X0PiKH08:Ee`23U]X0P9?E086Ce@20T]@0Oi7C07nAd@1oTLl0P93<07j>b@1oS/L00P1oS/D207f=
`@0707b<`01lRL00NXNn07V8`@1hQl80MhG207V4a00207V4`P0607N2`P1aOk`0LH6l06mo^P1/O;L0
JGbf0P1ZOKD01@1WN[80Ig^`06Um/P1WNk00IWZ]0080IGV/00T0IGJZ069fZ@1TMJT0HGFX065bYP1N
LZL0Gg>X05iaY@1MKZ800P1NKj<01`1OKj<0GV^P05]VW01KIi/0GFVM05aXW01JIYP00P1JJ9L03P1G
II80EFJB05=TT01HIY<0EfRD05=TT01BHi00D6:@055TS`1@Hhh0BUf804aORP19G8L0B5^60P1:FhL0
3@1:FhT0AUN504QFQ@19EhH0B5J504QEPP19EX<0B5F104QCP016DW`0@Tih04IBO012CWP00P12CGX0
1012Cg/0?T]g03i;N00nBWX203]7M`0<03a6M`0kAGH0?4Ig03Y4M@0kAGH0=d5b03U4LP0h@g40=T5^
03@oK00g@Vl0<Sm[0P0c@6`05P0a@6T0;CYV02hkI@0[>680:cMO02`hH00Y=Ed0;3EN02L`E`0X<EP0
:C9I02L`E`0V;eH0931F02L`E`0V;eH08beA028/C`0T;dd092i902L_AP0S:Sd9ooooo`001oooool0
JP1DEdH0C4ln03/o<00U:A/07B<E024W6`0]<bT0:S0V02lg:P11B3X0C51205IHB`1SHeL0MG9Y06i[
I01^JF<0NGA`08j9Q@2ET8d0THb906AOG00n>CH0C4M405UFD@1OG5L0FeMD05YFD`1SHUh0Hf9M03Th
<`13A3`0DeA<03Tj<P020`0082<L05iQFP1]L6T0KFiX075bJP1oP7P0QHMl075aI`1lO780UYJ<0;nl
/`3]j^40i>;F06i[H@1XJ5h0G5aD04I6?P1GEU40FEQC04A5@00m?cX0>cdj03<e=00^<S40<cLh03/l
?P11@d80AdM704I6AP1@D500DU9B05=CD`1>DTl0B4e904aAC@1;D4X0CE1904mBB`1>Dd`0D5I<04]A
A`12B3h0@TDl04Q;@P1CDd/0GeaE07E`K01WHUl0DD];05eGF@1]If/0DTaC08=mQ`1^J7@0PW^;07ad
R`1MEg<0IV61079^S`29Qj`0W9Zo0:>Sa`2TYlX0YJW<0:>Yb`2UZl/0YZg:0:V^cP2Y[/`0[;7A0:jb
e02]/M@20:fce`070:jdf02`]]X0[KGJ0:fgf`2^^=`0Z[OJ0:fjg@020:bjg@0M0:Rff@2X^=T0YkOH
0:VifP2V^MT0YKSI0:Jif02U^M@0Y;SC0:Jjd`2V^]80Z;[B0:Vkd`2T]Ll0Y;GC0:Bde@2S]]L0XkGI
0:>fgP2O/]`0XK?Q09nah@2K[n40WK7S09bbi02M/^H0W;3S09Z^h02G[=/00P2J[=h0102KZmh0W:cO
09^Xg02JZ]d209NWfP0<09NXg02DYMT0T:CG08nSeP2?XmP0SZ;G092Sf`2;W]H0S9oG08fPfP2;VmH0
RY[F0P28V=@04P29VmT0QIOG08BFeP24U]H0PiGE08>Ee`24U]P0P9;D07nAd@22U=H0PI?E07nAd@1n
T=00O8k<07b?bP1lSlT0O8c707Z:a@80MXW30P1fQ/8207B4`00Y07B4`P1ePl00Mh>o07J2_01ePK/0
LWjh07>0]`1bOkH0KWfd06Yk/@1[O;@0JGZb06Qi/@1WN[80I7N_06Mj/P1TN:d0IGV^06Ej[`1QMJP0
HWRZ065eY`1NM:D0GW:T05idYP1LLZ@0GFnS05m`Y01MKj40G6jP05m_XP1JIi/0FVJJ05]WV@1LIYT0
FfNG05UVT`1IIY80EfJA05ETS`1BHhh00P1DII006@1CI8l0DFB?051RS`1=Ghd0Cf6?04]PS@17G8T0
AU^804MLR@18FXP0BEZ804YKR@18FHL0AeF404MEPP18EH80BEJ304UDPP19E840BEEo04YCOP16D7T0
ADig04QANP14CGP00P12BWP03P13BgX0?dMf03m7N011BGX0?dIj03i5N@0k@WH0>T5e03e3M`0j@7@0
>T1b03ToL@0h@740=cm^0P0e?F/06P0f@V`0<CiX030mI`0_?VL0:3YP02/jH`0/>f80:SUP02PhG00V
=5T09cEJ02PdFP0X=EP0:39F02/eF@0Y<UT09BiE02H_F00V;EL09RiE02D]E00U;E809Rm@02D^B`0U
;4H08bTo2Oooool000Oooooo01@0GEi@055AA@14AST0;c8W01/Q5`0S:Al0:c0Y02T^9`0h?S@0Bdm5
069TF@1WIed0KFeU07MbKP1iM700OgMd085iM`2>QX@0N79b05UCD`80BD=302L0DD];05YEDP1JEE80
@C/k040l>`1?CT`0?chi02LW7`0`<BT0<cDZ03Hg;`0Z:b<0C4a405mOE`1UIEd0Jf]Q07UiK`1lO700
OG]_07ilK`2[ZI`0b/Ri0<k<_@2c/J80QH=d05aJB`1KG4h0EeM;055AA@1GEdd0FEYB04e@B@19BdH0
@48o02la;P0]<C00<SHe03`n?@14ATD00P1;Bd/09@1@D500DE5A055?D01?D4l0Bde:04i@C@1:C4L0
AdQ204]>A`1@EDh0DUM@04]AA`0h?S@0A4Y004aBB01HFe@0I6EO061OFP1>CDP0CTY705UEE01aKFh0
GUYP085nQ`1[IgD0If=d06MRN@1PG7L0Hf1o08>2XP2MWKl0Wio10:>Sa@2TYlH0YZW80:J[b@2VZlP0
0`2Z[l`01@2//Lh0[;;A0:fce@2Z/]H0[KGI0080[KGJ03H0ZkGI0:^hf`2[]md0ZKOL0:Zhf`2X]]T0
ZkWL0:Zhf`2X^=T0Z[_I0:Vjf02W^=H0YKSH0:Jie`2T^=<0YKWB0:Bhd@2S]ll0YKWA0:Nkd`2U^M80
YKKD0:FeeP2T]=H0YKGI0:>eg@2R/ml0X[?Q09j`h02M/N<0W;;T09^`i@2K/ND0WK?U09N]gP2F[=/0
V:cN09V[f`2GZM/0VJ_M09VYg02GYmP0UjWI09FWe`2EZM/0TZKH092Ve`2?Y]P0SZGG08jUf@2<XmT0
S:7I08^Pf@2:WmP208VLeP0408RKe@27V]@0QYWC08JIe080Q9KD0P23UM<04023UMD0P9;@07nAd@1n
T]40OI7@07f@dP1kT<l0N8g<07Z@c01jS//0NHg807R<a`1gRlH0MX[507J8aP1dQ/@207:4`P0:07F5
``1cPkl0Lh:k07J3^P1cP;L0M86f07=n]01`O;00Kgba06Yj[P80JWV`00X0K7^d06Qi/@1SMZh0IWVa
069fZ`1TNJh0I7Z/061fZ01PMZL0GG>T0P1MMJ<03`1OMjD0Fg>Q05aaXP1MLJ<0GFnO05a^WP1NKYl0
G6bM05i/W@1IIiH0FFFE05]XU@1LJiH0FfZE05ETS@02051RRP06055SR`1AHXd0DV>>04mRS01>HXd0
BUn:0P1<HH`204UNR`0O04QMRP16FhP0Beb:04YKR@18EXD0BEN404UFP`19EX80B5F204UDP@16DW`0
B5An04MCN`16DWT0@dme04A=MP14CGP0ADek03i6M@10B7L0@4Qi03e5MP0nAGT0@4Mk03i5N@0k@WH0
?DEf03]1L`0j@780?49d03Y0L00203Q0K`0C03Q0KP0e?VT0=41X030nI@0`?fH0:ceS02XlHP0Y>f40
9SQN02PjGP0W>Ed0:3QL02LeFP0W=EP09C=F02LdE`0Y<eL0:C9I02H_EP0302H^E@0602L_E00U;E40
:35B02H_C00S:T@07RHk2Oooool000Oooooo00d0GEeE05UID@1?D4P0<SD/01<H4@0M8Q/08R@O038d
;`1GFU<0HVAN06m`J`1dLfl0Lg9`0080N79b01@0OgUi07afMP1nN7P0IV9S05aHF@1FDU<0?CTh03Da
<01;Ad@0@3`i02XV8`0/:2L0<Rh]034^:P0^:b@0;2LQ03@`9`1<B3l0Ddm606ENEP80JV=K01X0KfQP
07=/HP1bK600OGU]0:>PT@37a;D0V9N506i]F`1@Ccd0?Sd[04]<>`1?D400EUM905AFB@1FF4d0F5]B
05EHC`1?E4d0BDa504E8@@0j?cP0>d0i04=5@01<CDP0DE1<04m>C080Cde>0340DDe>051>C`1:BTX0
CDe;04I6A013AD00BD]604]@BP19D4T0CE=?04U?B`1?EE40DUQD04mCDP1@EE40CU=?04Y?B`18BTL0
BD]:06EUI@1^KG<0KVag061OK@1QGg@0J6R006m_R`29RZH0Wj?00:2U`P2SZ<D0XZS20:F[``2X[/H0
Yjg50:VaaP2Z//L0Zk?:0:Rcb@2Y/l`0ZkG@0:bge@2]^=P0ZkGH0:ZgfP2X]MP0Z[OJ0:Zhf`2Y]mX0
Z[SK0080ZKWJ00H0YkSF0:Jge@2W^=H0Y[OC0:VjeP2X^MD20:Fie00H0:Bie02S]m80YKWD0:Jjd`2U
^M80YkSB0:Jgd`2X]mP0Y[CG0:Fcf02U/mX0YK;N0:>`g@2S/N00XK7R09f]h02L[N40V:kP09V`hP2H
/>00UZkL09F/f02EZmX0U:_G0P2DZ]T05`2DZMP0TjSG09:Xe`2AYmH0T:SH092Wf@2=YmP0RjGF08ZT
e`2:XmT0R:7I08ZPfP29WmP0R9kG08RMeP25V]40QicC08FJc`24VLh0QIS@08>FcP23U<`0Q9G=0080
PIC>0P1nT/d207^Ac@0A07V>c@1iSlh0MHg;07F=b@1fSlP0MXc607N;aP1gRlP0MHW607J9a01dQl80
LhK107:5`01cPkl0Lh>n07:3^`1_O[D00P1_Ok<0901aOk00Kgf^06ai[@1/NJd0JGV]06Yj[P1YN:l0
IgJ]06Ef[01SMj`0H7BY065fZ`1RN:X0GGBV05ifYP1OMjD0G7NR05ahX01KMil0FWJN05YbW01IL9X0
FVnJ05]`V`1IKY/0FVbJ05Y[V@1FIi<0EFJB05MXT`1FIi80EVR@059TS01AI8`0DFB>04ePRP80Cf2;
00/0Cf:<04eQR`1:H8T0BV2704UQQ`16GHH0B5n804MMQP16G8D0BU^704MHQ00204QFP`0404UFP`17
E840AeB004ICO`80AE9l0140A5=j04ACN@12D7D0@e5h045>N00oBWP0?TQi03m9NP10BWd0?TQk03e7
NP0lAWT0?4Ig03a7M@0jAG<0=D1^03U4LP0203M2K`80=T9/00L0=D5[03E1I`0a?f@0;SiR02i0I00/
?V80:CeP00809c]N01<0:3YN02@fFP0T=UX09cMK02LeFP0U<eP08bmE02DaE`0U<UD09S9E02@^DP0U
;e809S1C02@_C`0U<4h09c9>02DaB@0Q;4006RDg00Wooooo0007ooooo`0R06QXH01SHe/0H61H02//
900F6A80;C0Y02/^9`15AT00FEYD06a]J01hN7H0MWAe07AbM@1hLgL0Q7n307]fNP1=Bdh0KVa_08:0
P`1PH680A4A602HV9P0a<Bl0?Sdk03Lf<P0X9240:BDR02`X9`0X8b0081/G02PQ6`1[I5h0J5mJ06AK
EP80JV5J00l0Jf1L06QOFP1LDd`0HEY@08b5N`2ESX@0OGU]05UEB@1ACd00>cTZ034b8P1CE4D0DE=5
05EGB@1EEdX00P1GFTl0501FFE00E5M>051CBP1:CD@0@TDl04=6?@19BT@0EEA?059AC@1=BDH0CDU8
04e7B@1@C4d0Cd]<04]9BP1<BdT0@D8m0411?019BdH0BDi80P1?E500<@1:D4h0CUAD04iDE01:D500
BDm?04M<C`18CE00BTmB04E:C@1PHfP0IFQ`05EII@1HFf`0FUmb07YoU@2CUk00Vj6k09nW_P2QZL00
X:_10:6/`02S[/00Z;330:Vaa02W//@0ZKC60:Nda`2Z]lX0ZKG;0:Vgd02W]M00ZKKF0:Zgf@2Y]]P0
Z[WJ0:^hf`2Y^=T0ZkSK0:ZifP2Z^mT0YkSD0:^je`2Y^=D0Z;OD0:Nfd`2Z^MH0Z[_G0:FfdP2T^MD0
0P2R]m@00`2S^=D0X[OD0::ge0020::ee@050:>ce`2U]=/0YK?J0:>`fP2S/=d00P2Q[mh02P2P/>40
WZkQ09^/h02J[^40V:oP09R`h02G[md0UZkJ09R^g@2E[MT2092XeP<0SjOE01l0Sj[G08jYf02<Y]L0
RJGE08VUe`27X]L0QZ7F08JOe`26W]H0RIoH08RNe`24Vm40Q9W>08JLcP22V<X0QI_=08FIc020U<L0
PY?707n@a020U<T0PYK;086Fc@1mT//0Ni7;07VBb`1gSl/0NXo=07J>bP1gSl/0MHk700<0M8[600P0
MHW607N;aP1eRL@0LHG007>6`@1cQ/00LHBn0721^@80KGjd01`0KWnc06an/01]OK00Jg^^06Ui[@1X
N:`0JGR_06Mf[@1YN:l0IWF/06AeZ`1PM:T0HGFZ061fZ01OMJL0GWJV05ifY01KLil0FGFM05YfWP1J
Li/0FW:J05U`V@1KL9/0FVnJ05I[UP1DJI@0EVVD0P1EJ9<03@1FJI<0E6NA05=VT01AI8h0DVF?05=V
T01?HX`0D66<055SR`1@Hh/0CF6604YPQ@1;HX@00P19Gh@02@19GhH0BEb404ULQP1:FhL0BU^904UG
QP1:F8L0BUJ604ABP@0204ABO`0K04EDO`11DWd0@UAl045CNP0nD7H0@E1i045@N`0oC7T0?d]k03e;
NP0lBWT0?TYj03]7M`0kBGP0>TQe03Q7LP0gAW40=TE`03E4K@0d@f`0=4=Z03A2J@0b@6H0=D=X03=1
IP0a?f80;cmQ0080;cmS0P0Y>el0500X>Uh09cMK02@dF00S<eL093AH02HdF@0U<eP09C5G02HbF00R
;U@09C9E028_D@0U<U@08c1@024_C00S<D`08S1:024`A@0L:C`06bPi2Oooool000Oooooo00L0GemC
05ADB01DDTH0=38V03<c9`0e=bX0<C<V0080@40f05<0JFQR07QgM@1cLG@0MWAi08F2R@22PHT0GEeU
03`oAP1RIF`0JVeb059EFP19CE00>CXn03@e=`0d=380<30^02`[9`0^:RL0:RHS02XS800U7AX0A3Xh
06iTHP1[Gel0JEeM05I:BP17>c/0DTQ90598A`0n=S@0CDE205mGE01NEU<0G5MC04Q5@012?cP0<2dV
02XZ801DEDX0F5Y?05IHB`1EFD/0EeU>05QKDP1FFE00D5=:04m@B01;C4@0ADI00452?019BD40FEIA
05A@C@1;AT<0CdI704Po@01:A4@0BdE5051<B`1BCdX0BdQ304=0>`17AT40D55;05EFD@1BE540D59?
059DD`1>DU<0Ada?04A9C@10Add0ATeE04M>EP18CeL0CeIP05=JI`1BFFT0HFYk07Z3U02GWk@0W:Bi
09bW_@0209nZ_P0309j[_02S/<40Xk300080YK;20280Y;C30:Bfa02V]/H0YkS:0:Nhc02X^=00Z;SB
0:Zhe@2[^=P0[;WI0:Zge`2[]MP0ZKKF0:VceP2Z]mL0ZKKF0:Vhe@2Z^=D0Z[SC0:Rfd@2Z^=D0Z;KC
0:Vhe`2W^=H0YKSI0::if@2P^=X0W[KH09fee`2O]mT0WKGI09bdf02M/m`0X;GP0P2P/mh0102O/Ml0
WJoO09^]g@2J[mh209R/gP0809N]gP2H[]l0UjgN09J^gP2G[md0U:cL09:Zf02?YmL208fXe`0308ZV
e@2=ZMP0RjOF0080RJGE0P29XmH07027X=H0QYoE08FPe@24W]@0PicB08JMd`23V/h0Q9W>08BJc023
VLX0QYc=08>Gb@20U<H0PYK807nCa@1nT/@0P9C707fBa`1lTLH0Ni;807Z@b@1hS/P0NXk:07R<b@1g
SLT0MH_707B9b01aQl<207>9a@0407>9``1aQl00L8Jo06n5_P80L8Fn00`0Kh:l06j1^`1/OkT0K7ni
06Qk/`1ZNk<0Jgbd06Qi[`1WN:h0IgR`06Ef[P1XMk0206Mf[`80HG:Z00D0H7>[069fZ`1QMJP0GW:U
05ecY00205aaX00505U^V`1LLI`0FVnJ05a^W01KKI/00P1HJYP01P1DJIH0DfRE05=XU@1CJ9D0EVRF
05EXT`80EFJB00H0E6NA051SS@1@Hh/0Cf>804iRQ@1=HH<204aPP@0F04YMOP19Fh40CUf604]MQ@1<
GHP0CUb;04aJR`1;F8`0BEJ:04QERP13D8@0AE>404ADQ@13Dh@0@eB2049CO`0oDW`0?E1h03i?NP0m
CWT0>dah03a=N@80>DYf0100>dah03Y;M`0hBgH0=DQb03Q;M@0gBG40=DM]03E7J`0cAFT0<DAU03A4
IP0c@V@0=49U038oHP0c@6<0;ceR0P0`?6@202lkH`0D02hjHP0V=5/09SAK02LeG00X=Ud09SAK02Pd
G00T<UT0939G020^D`0S<EH08c5D02<bD`0S<U407Re:01l_B@0N;TD07Re001`/?00L;3/9ooooo`00
1oooool04@1@D4@0CTi204E3=`0e<bL0?S`_03Hd9`0/:Qd0=S@X03@a:01]JV@0KFUX06UUIP20OX<0
THjE081oQ`1FFF80CE1I0080EEQO01h0F5]P04iBE@0k?d80<C8d02XZ:P0V9R@0:2LS02XV8`0U8Ah0
9AlK038Z9`1LE540NW1^06iTH`1:@3l0:1hM02TO7P0c:BX0<BPY02`W900e<2d0?STf040k>011?CX0
=C4^03<_;00a<2`0:RTT059CC@1IFU8205MJD@0V05UJDP1IFU@0EEQA04m@BP1:BdD0BTU404I7@@13
A3h0ATE004m<A`1<B4D0BdI304Q2@P11>c/0@3`i04E1?`1AC4T0EE1<055<B013@3/0D4e805QGDP1K
G5L0GEeK05iPG`1DEUD0BDe>04A9C@13B4h0?TE?04I<F016CU/0ADeJ04U@H01RJG/0I6ao07^3UP2E
X;@209^S^P0A09bW_@2MZ;h0XJc00:6^_`2S/<40Y;C40::b`P2T]LD0X[?30:Fha`2V]lT0YkS:0:Fg
b`2X^M00YkOA0:Zhe@2[^MH00P2/]mL20:^feP050:Zee@2X]MD0Z;GE0:Zge`2Y]m@00P2X]]<05`2X
]MD0YkCF0:Rgf02V]]P0Y;SK0:2hg02L]=P0W[SM09bff`2M]m`0VkGJ09^dg02K/]`0Vk;N09bagP2J
[m`0VZoN09V^g@2J[mh0Uj_M09J/g@2G[Ml0UJ_M0080UJ_L0P2E[Md209:ZfP0508nZf@2=Z=L0RjGF
08^We`2<Z=P00P28Y=@01028X]D0Qj7D08JPd`27X=H208FNe080Q9kA01l0PYc?08:Ic@22VL/0PIS:
07nGa`20V<P0P9K707nEaP21UlP0O9;307jDaP1lT/@0NY3207Z?a01iT<H0N8k707V>a`1jSLT0MHO5
07J:a`1eRlL0LhO40767``1aQl40KhS106n5_P1`Qkd0KXBm06b3^@1_Q;d0KX>l0080Jh2i00X0JGfh
06]n^01XNkD0IgZd06Eh/P1TMjl0HWF]06Ig[`1TMJd0IWF^0P1VMJ`02`1SLZT0Hg:[06Ac[01SLZT0
GVnU05i_X`1OL:@0GW2R05e_X@1MKil0G6jN0080FF^K00L0FVbL05IXV01GJIT0EVRF05=XU@1DIYH0
DfFE0080E6JD02@0E6FC05=VT@1CIY00DFB<059US@1?HhH0CF6404ePP@1=H800C5mo04aLOP1=Fh00
CUb304]JP`1=G8L0C5Z704]GQ`17DhD0C5R<04UDRP16DHL0A56504=@Q014DHD0@E62045BP00nCg/0
?Tmj03e@NP0lCgT0>Teg03U<MP0hBgD0=dYd03U:M@0iC7H203I<M@0903Q;L`0fBVl0=DU/03=7J00c
AFT0;d9S0354I@0a@V@0<CmR0080;c]Q01T0;CUQ02hgH00`>F@0<CQT030iHP0_>640;3EL02/gG@0Y
=E/09c=I02DaE`0V<UP09c=I02@bE`0Q<ED08S9F024aD`0R<U<07Rm=01d/B`0L;4H07Ri501l`@P0J
:SX06RXi00Wooooo0007ooooo`0I04U:@P1>CTH0Ad@m040m=015@cL0>3@Y02LS600Z9Qd0>CD/06aW
HP1ZIF80OGMg092<S@2@Rhl0PX25071_M@1[K740FeaQ04m@E01<CE40?3do02//;P0T92H092@T02HU
8`0202PT8@0@02<P6`0Y9B00F5==06YUG`1ECTP0:20M01L?300L5@l08Q/E020I4`0N6A<0:2<M034^
9`0f<bh0=SD`03@c;P80;bhY00P0<S4/03Hg<@1?D4X0G5eH05mPF`1KG5L0EeQC04m@B`80CTm:0P16
Ad8204U:A@0^04Y;AP1;BTH0BDQ604Q7A@14@d40?3/i03/l=`0n?SX0C4Q5055=BP1DD4d0C4Q505MC
D01ZJFD0L71^07MgM@1kOG`0HF9T03Pl?`0n@dT0@4M?0457D`1:D5h0Be1S04A9G@16Bf40Qh^S08F9
XP2FV[D0Wj?009fQ_P2PY<40X:G30::Wa02SZ/@0Y:o50:F`aP2U//D0Xk;50::ca@2S]<H0YKS90::d
b02T]/`0YkW?0:NgdP80Z;KC00T0ZKOD0:Zee@2[/mL0Z[CG0:bff@2Y]]P0YkCF0:Ree`2V]MH00P2W
]]L06`2V]=L0YK?F0:Jdf@2V]]X0Y;?J0::dg02N]Mh0WKCM09Zcf`2L]Md0VkCL09Zcf`2L]Mh0W;?O
09Z_g02J/Md0VK3L09R]g02I[Ml0V:cN09N[gP2CYm`0UZ[O09FYgP2DZM`0UJ_M09:XfP0209>Yf`06
09:Yf`2>Z=T0S:KG08bVf@29XmH0RjGH0P27XM@02028Wm<0QYgA08BKc`27W]80Q9_?08FLd025W<h0
PI_<0P20V//01020V/d0OYS;07nIbP1lU/L207jEb@0E07bFb@1kULP0O9?907bCb@1hSlD0NI3607V>
a@1iS/L0NHc607N:aP1fR<H0M8O207F9a01eR<80LXO007>8`@1_Q[`0KhBk0725^P1_Q;/0KH:g0080
KH:i01D0Igbc06Qm]01XNkD0JWfg06Mj/P1XN[80JGZb06Mh/01UMZh0Hg:[06Uh[`1WMZd0IGFY06Md
Z@1ULZL0I76V06IcZ01ULZL0H6fR065^X`1QLJD00P1PL:@02`1LKJ40FfbP05UZWP1GJid0F6ZL05MY
V`1IJI`0EfNH05EWU`1GIiP0EFNG0080DVBB0P1AI8l01P1AI8h0CF>:04iQR@1?HhH0C62304]OO`80
CUio01<0C5am04eKOP1<FWl0BUQo04YGP@19EX00BUF204QCP@19Dh@0BE>604MAQP19DhH0ADn204=?
P@11CGl0@U1o041?N`0nCGP0?4if0080>dee0P0iBg<01@0jC7@0>dYc03I8L00gBG40=TUa0080>4Yb
0280<dM/0396J@0bAV/0<4AY03=5J`0a@FP0;C]R02lkI@0^>V@0<3UR034jH`0_>6<0;cQQ02hfG@0_
=e`0;SIJ02dgFP0/=UT0:SAG02PbEP0U<UD09S=F02DcEP0T=5H08C9E01lbD`0Q=5@08C9@01h]C00L
:dP07Re401l^@@0O;3d082dm2Oooool000Oooooo02/0@T@o04Y<A`18BD<0@T8j04M7?@0n>c80:bPO
02DR6`0h<bd0HEaH07YdM02=RHP0SHV:08=nPP1gMGP0M7=h06i]LP1IF5d0DU9D0410@P0[:bd08R8T
02DU9@0U928092<O02LS800[:2<08QlJ03lj=01VHE/0BdI002HQ6`0Q71H05a8<01`G4@0O71<07AXC
020M500U8QT09bLM03<c:`0k?3@0>S/c0080<S<[00@0<c@/03Hi<01?DTX0FeaF0P1HFE@09`1EEU40
BT]604Y;AP1;CDP0ATI404I8A@19BdP0Bde:04U;B016B4D0B4Y704Q:A@15Ad80>S`g03Tl=@10@S/0
BDQ304m>B@1BDDd0D4a;05mNG01hN7H0Oh6008nAT02?Ti@0OX:503Pm@@0j@DL0A4]C04=9E@1:D5h0
BTmR04E:GP15BV00Si6[08j=[02IV;P0XJ300:>R`P020:>Sa@0A0::Ua02UZ/L0Y:_50:N^b02V/LL0
YK770:Ncb@2T/lP0Y;G90:Bdb`2V]/d0YKG>0:Ned@2W]=@0Z[GC0:^feP2[]MP00P2Y/mH0102Y]]P0
Z[OJ0:Rff@2W]MP20:Fee`0:0:Jff02R]=P0X[CH0:>ef`2T]]`0Y;KN0:6dg@2O]Mh0WKCM09jegP80
W;?L00@0Vk;K09bcg@2K/=/0VJkK0P2H[m/0402I[Ml0VZkP09N[gP2H[>40TjSO09J[hP2DZN80U:WO
09>ZgP2AZ=`0U:_M092Wf@2AZ=X0SjWJ08fWf02=Y=P208bSe`0C08VPe02:XMD0RJ3F08NLd@23V/h0
QI[?08BKc`26Vm00Qic@08BKc`22W<l0P9[=082Ic`1nUld0OiS>07bGc01mU/`0O9G;07bEc@0207ZC
b`80O9;;02P0NY7707V>a`1jSLL0N8_507R:aP1fR<H0MHS307J9``1eR<00LHBl07F8`01bQKd0LHBl
07:6^`1`Pk/0Kh>h0764_01^PKT0Jgjf06Ym]@1ZN[D0K7fe06Qi[`1WNJl0JGZ`06Mh[P1XNJl0IgJ]
06MgZ`1VMZX0I7BW06QeZ@1WMJH0IG>T06AbX`1TL:@0HfnS069_X`1SL:@0H72S0P1NKZ803@1KJil0
F6VM05QYW@1IJYh0F6RL05MWVP1HJ9T0EfNH05ATU@1EIIH0EFJD055RT01AHXh00P1BII002@1>HH/0
CV6904mSR01;Gh80CEj104eMO`1?Gh40CEeo04]IOP0204YHO`0B04aIP`1;F880BUN104UDP@19E880
Be>404UAPP1;Dh@0B52104I>O`14CWl0@Tml045>NP11CWP0@4mh041?MP0nCGH0>dYc0P0lBg@01`0j
BG@0=TMb03M8L`0fAg80=4Ma03E8L00bAFd00P0aAFX07`0]@FH0<49Z02m0J00]>V@0;cYW02lkI@0`
>F@0<3UR034jI@0`>F80;cMN030hG@0_=e/0;3EF02hgF00Y=5@09c5D02PbE@0V<eH08c5D02DcEP0R
<UH07S5B020`D@0M;T`07Re<01d[B00M;4<08Bi101h[?00L:3P02Oooool000Oooooo03/0@4I204A:
AP19CTP0A4U204Q>A00m@3L0:RdT01XM5P0n?cT0Kfm/08R8R022PX80N7Qj07=cM@1aLG<0JVY/05IG
F@15ATP0?d1202d^<00U9bH09BDU02PX9P0T8al081lJ02DR7@0/9b40;bXT04Y3?@0b:bD09b8N01XE
4@0N6aH07a`G01dJ5@0K6a<07A`G01hN5P0P81P08R<K03Lh<019BT80BD]003e0=@0k?S<0>Clc0498
>P1CEd/0EUU>05EHC`1DEdh0CU5:04Y<A`19BdH0ADY404M9AP18CDT0C55;04Q=A`0204A9@`0L04Q=
A`15BT<0?d@m03To=@0k@CD0@DHk04M8@01>CdL0BT]5055@C01aLFl0PX:208j?T@2CU9P0RXjA075f
NP0]=CP0?TE;04M>EP16CeH0D5UR05=II`1LHW80K6j309fL]@2OW;/0Y9k00:VSa`80Z:C700P0Z:O9
0:RXbP2YZ/T0Yj_80:V]b02Z/<X0Yjk80:V`bP80Z;;;00d0ZK?>0:Zdc`2Z/m00Z[?A0:Zed`2[]=D0
ZKCD0:VceP2Z]=P0Y[?E0:Nfe`2Y]mX0Y[KH0080Y;OH0P2R]]L01P2Q]MP0X;CG0:6ef02O/mH0XKGJ
0:2cf`80Wk;L01<0W;7L09jag02N/M/0Vk7J09R^e`2J/=T0V:gH09N^fP2E[=P0UZcM09F[g02F[=h0
UZ_P09F[i02BZ>40U:[T096Wh02?Z>00SjSN0080SJOJ00@0S:KI08^UeP29Xm@0RZ7C0P2<X]@04P29
Wm40RYoD08RMdP26VM40QY_B08BGc`22Ulh0QIS@08BHcP24Ull0PYO>086Fc@21U/l0OiG>07fFcP1l
ULd0OYC=07bEc@80NY?<00`0Ni7;07Z?b01kT<T0Ni3907^>b@1jSLP0NHW507N6a01hR<H0MhO307J6
`@1fQkl207B5_@0607:3^`1cQ;`0LX>k06mo^P1`PKT0LH6l0P1^OkL01@1]O[H0K7^d06Yk/`1YN[00
J7R^00<0J7R/01l0IgN[06EeZ01UMJP0IGFV06QfY`1WMJ@0HW>Q06=aX01SKil0Gf^K05m]W01NKid0
G6bM05a/W`1NKZ40G6^N05YZW@1IJI`0F6RK05QUV@1IIYX0EVJG05MWV01IIiH0EF>B05MUU01DHY40
Df6@059SS`1AHXh0D66<0080Cf6904@0CV2804iOQP1<G800Cef404iLP`1=G8D0BUV404MFP@19F8<0
BUV404UHP`18EH80AE9o04IAOP17DWl0B5An04UBO@19DGl0Admm049;MP11CGL0@Tih04=?N@12CWP0
@4ei03i;M`0nBgP0>TQe03U7MP0fAgD0>T]g03A7LP0dBG@0<dUb0316K`0_AF`0;TAY02]1IP0`A6T0
;d1V034oIP0^>fD0<CeW034jI@0_>6<0;CIO02lhH@0^=eh0;CMK02liG00/=UT0:SAG02LaE00Y<eH0
9C9D02DbE@0Q;e@08S1E024aE@0R<U@08S5B01h]C00Q;Th07bY601l[@`0Q;4808RXo01dU>0Wooooo
0007ooooo`0[0498A015C4D0B4e604Q>A01BF4h0AD]102/`:@0I7QP0>Sli08F8QP1nOh40MWMi075b
M01YJF/0IFEW05AEE`14ADL0>CXl03Hh=`0[;B`07b4N02<S8@0X:B@09bHQ028Q700b;bP0CdY403hj
<@0a;2@07APB01dH500O71L07Q/F01/J5@0L6aH061TC01XK5@0P8AT09BHN02<T700b<b/0BTa104i@
A@0204Y>@00[04Q<?P1=E4@0E5U:04mCA@1@DTD0Ce9704Y;@`17BT<0B4Y504I;A@16BdL0BDm;04M>
A`12BD80@4M004=:@P17CTH0@DTn03a4>@0f?300=S`^04A8?01CET/0EeQ@04Y;@`18BD@0LG5_09NI
V02TZ:T0T9BG06=XK014C4l0=cm204M>E017D5L0BU=J051IHP1GGfX0KgF308V<W`2OWKL0Y:6n0:RR
a0020:RRaP090:^Wc02ZZL/0Zj[<0:b/cP2][/d0Zjc:0:^_c02[/<d0ZJo90080Z[7;00h0Z[7=0:^b
cP2//m00ZkCB0:Rcd@2Z]MD0ZkKF0:VceP2W]=L0Y[CG0:FceP2X^=`0ZKWM0:BffP80XkOJ01l0X;KK
0:6efP2N]=T0X;CI09ncf02P/m/0X;;J0:2ag02L[mT0WK3K09j_f`2N/M/0W;;I09V_eP2G[MH0VJkI
09F/f02F[=/0UZcM09F[g@2EZ]l0U:_Q09>YhP2BZn@0TZSR096Wh@2>Yml0SZOM08nXgP2?Y]X0SJCH
0080S:?E00H0Rj7C08VOd@2<X]@0R9k@08ZNd`28W=4208JId@0A08JId`23U]00PYG?08BFd025UM00
P9?=086Dc`20Tlh0Oi?>07jDd01lT/`0OI?=07jDcP1kTL/0O9;;07^@b@1jSlP00P1iS/D03P1jSLL0
Nhk807R8``1gQl<0MXK207R8a01hR<<0MXK107J7_`1eQL00L82k07B3_P1bPK`0L7nj0P1_O[T0301^
OKH0Kgjg06mn]@1/Nk80JgZa06Yk[`1XN:`0IGFX06MgZP1TM:L0IgNZ06EeZ080I7BW00h0IW>W06=c
Y01RLZ<0HW:S069`X@1QKj00GFfN05a/W@1JJY/0Ff^N05eZWP1NJil0G6VM05UVVP80FVJJ00L0FFJJ
05QVU`1KJIX0FFFE05QTU01IIID0EF6A0080Den?00d0EF6A055OS01?GXT0Cej904iMR01@H8X0BUV2
04aIP`1=FX@0CEb704]JQ@19Eh@0B5J30080AeR402<0AE>004=BO@14DG/0AeEl04IDN`16DWX0B55j
04YCOP13CgL0@4ad049>MP11CGL0@4]h03i9M`0kB7D0>dMg03Y6MP0gAGH0=dMh03M9N@0fB7H0<dQe
0399L`0]A6h0;4=/02a2J@0[@FH0<4AY0311I@0^?640<T1W030nI@0b>f@0<3UR02`eGP0202/dF`0D
02`eG00Y=UT0:CII02LaE@0Y<eL0:3EH02DaE`0W<eT08c5H024_EP0Q;eD08S1C024`D@0L:DT07bY:
01dXA00P:T<092a3028X?P0O9C/9ooooo`001oooool0;P16C480BU16051CBP1FFE00GV5H065TG@1:
C4L0ADM406mdL01mP800Kg1d07AeN@1ZJfl0HF5S059BE010@400<30`02d];@0e=CD0<38_01`N6@0L
7AL0:bXU03@d;00c<b/0@d0i04i;A00_;2<07QXC01`I4P0P7AH07QhF01TH4`0F5a406AXB01LJ4@0J
7A@082<J02LX800O8AH0:RXP04I6?01?DDH0DUA7051BA@1ADdD2051BA00C04Q:?01:Bcd0B4Xm04Q8
@019BT@0Bde804M<AP18CDT0BDm;04I<B010BT80@D]303m9@010Acl0?DDj03i4>P0g>Rl0@4@f04M:
?@0206IXG@0D05mPF01PHE`0LG5_09>EU02VZZ/0Mg]n04U>DP0mADP0?TM<04A=E01>Eeh0I6ef06=]
M`1kQI40RI2P09FL[P2MXKP0XjC00:>R`@2WY/H20:VXbP0O0:VWc02/Z/l0[:[?0:f]c`2[Zld0Zjk=
0:fbd02[/<d0Z:o;0:^bcP2X/Lh0YZo<0:Zdc`2X]<l0YkG@0:Jdd@2W]=@0Y[?E0:FceP2V]=L0Y;CH
0:Bbf@2U]=d0XkCO0::cgP2T]N00XKCO0::cg`2P/mh0X[?O0:2ag@020:2ag00509n`f`2M[]T0W:gH
09^^f02M/=X00P2I[mH02@2H[]L0UjcG09FZe`2EZ]T0UJWK09:XfP2CZ=d0TZWO09BZh`0209>YhP80
T:KO0140T:OM08nVg02>XmP0S:7F08bRe02=XM@0RYkA08^Oe028W=40RIgB08bMe@25V=00QYWA08JK
dP25V=80PYG?08JFdP0308>Cc`0B08:DdP1oTLl0OY3>07b@c`1lT<d0OI7<07b@b`1lTLX0NXo607Z>
``1kSl@0N8bo07N;_P1gRl00N8c107F9_P1fRL00M8O1101bQKl0101cPkl0L82l07:0_@1_OKX206mn
^@0806mk]@1^N[@0KGbc06al/01[Njl0Jg^^06YjZ`1YNJX206MgZ00:06AdY@1VMZT0IGFX06AaZ01U
LZT0HW6X065`Y`1RLJP0HG:X065`Y`80Gg2V00`0FfbP05a]X@1LKJ40Ff^O05eZW`1LIid0FfJL05aU
W01JHiX0FfFJ05YTU`1IIIL205MQTP0305QST@1GHY00Def>0080Def>00/0DEf=04mKR`1?GH`0Cef<
055NR`1<FHD0C5V304]HPP1:Eh40C5V304UHP`0204MFP@0;04IEP012Dgh0@59j04IEOP15E7/0AUEl
04ABN@12D7L0AE=j049AN00nC7D00P0oC7H07P0oC7P0?T]h03a8N00kAgL0>DEe03Q6M`0fAWT0=DMi
03E7M`0aAWD0<4Ed02a3K@0^AFh0;49Y02a2I`0_@fH0;d5R02dmGP0^?Eh0;ceP02hhG00]=Ud0;cQO
02/dF`0[=5d0;3EN02/dG`0W<5/09RmJ02LcG@80935K00d09C9L02<`FP0P;UD08RmF024^D@0O;4h0
82e=024/C00Q:TL09Ba6024Y@00O9C/082Dk00Wooooo0007ooooo`0M0495?01:CD@0EUM?05aME@1O
H5P0HV=M06i^K01cMG@0N7Uk079bMP1dLgP0KFaa05mOH@1JF5/0@3ho038a;`0[:RP0;B`Z03@c;`0f
=c80414;014A2@0e=Bd0@40h04A4?01;B440;BXS01LG3`0P81P00P0O7aL0600K71@05aPB01PI4`0G
6Q<061/D01lR6`0S9Qd08R<K01lP600b<RX0C4a204mAAP1EEdX0DU96055AA@1@D4@0@d<g04Q8?01:
BSh0AdLk04M7?`1<CDL0CE1904Y?B@80ADa502H0A4i6045;@`10Acl0@TXo0457?@0j@3@0>C`a0453
=P1:BSh0De=707]kL@20P7H0MWM_07=dKP23Q7l0UYRE08>7QP1DFUX0C5AF04mIF`1=EU/0>T=:05]T
K@2:TYd0NH>?08RAX02CW:d0UYf`09^Q^02QYL00XjO40:BWaP2VY/P0Z:S<0:^[c`2/[=80Zj_A0:b/
dP80ZjkA00@0ZZo?0:R_c02W/<d0Z[?@0P2W//h04@2V]<l0Y[C@0:Bcd02T/m80YKCC0:JeeP2U/mH0
YKGI0:>ce`2T/m`0Xk;K0:6bg@2R/mh0X[?O0:2ag@2R/ml0Wk3L00<0X;7M00@0WJkJ09f^f@2M[mL0
VjkF0P2J[ML08@2I[=@0V:kE09R^e`2G[=L0U:WF09FZf@2H[=h0U:[L09FZg`2CZ]h0Tj[P09>YhP2A
Yn00SZCM08nUgP2>Y=d0SjCK08fRf@2>X]L0S:3E08ZNd`2<WMD0SIkF08ZMe@25V=80RY[E08VIe025
V=00QISB08JFd@24U=00QIGC08JEd`0208BDdP0:08>Cd@22TM80OY3@07nAc`1nT<h0Oi;=07^>b01k
S/H0NXo407Z>`@80Mhfn02@0MH^l07J<_@1eRK`0MHVl07B9_@1aQ[d0LHBn0723_P1bQL00LXC20761
_`1^O[`0L82n06mm_01^O;T0L7jk075m^@1^N[@0Kgbc06al/01XN:/0K7b]06UjZ01XNJL0IgNX06If
Y`1UMJH0IGFX06AdZ01RLJP0HW6Z061_ZP1NKJP0GfnZ061`Z`1OKjX205m`Z00605a]X`1JJj40FVZN
05YZWP1LJ9h0FVFK0P1KI9/03P1JHiX0F6:G05UUU`1GHi<0EV2A05IQS`1FHi00E66>05=NS01AG8X0
DE^<051LS01@G8h0DUj@0P1?Fh/01P1?G8T0CER504YGP`19E840BeR204YGP`80AeJ100D0B5N204AE
P00oDGT0@UAl045CN`02041BNP09045CN`0oDGT0@59j03e=MP0lBg@0>dYc03e<M`0kBGH0>dUh0080
>TIf00<0>4Ig03Q5N@0fAWT00P0cAGL01`0^@g80;T=`0315L00/@V/0:T1W02a0H`0Z?Eh00P0/?5d0
6P0`@640;3YM02XgFP0/>E`0:SMJ02TeG@0Y=El0:SIP02HaGP0Y=640:3=P02DbG`0S<Eh09C9O02<`
G00S<5X08RmH020/DP0O;4l07R]=01lZBP0P:DP08B]401lW?P0I7cD06R0f2Oooool000Oooooo01d0
BD]605=ED01MH5T0GF1I06IWH@1cM6l0O7al07inP01_KW<0Kf]a06QSI`1MF5`0CDU:04]7B00n>ST0
;BTV02PU800/:B80:bPQ028O600?30D0514803@a:P11?SL0?3Td02l_9`0I6A405aP@01dO600201TJ
500I01XK5@0G61<06Q/F01XL5`0K7AP08bDP02PY900V:2<092LP038c;@1;C4@0D59705=EBP1CDdT0
Cdm504I6?00g=bd0ATHl04I8?@13A3`0ATLo04Q;A016Bd@0ADa404=:@P020458@00[03m7?00oAC/0
@4Hj0413>00m?c80?Cda04=1=018A3P0Ee9608V5NP2LVI00S8b407imN01mOWT0NG]h06AXI`15Bd/0
Be=E05=MG`1BFf80?dQA06Q`O@2MY;@0Ri:T08^CYP2DW;40V:2g09bS_@2RYl@0XZO50:FZbP2UZ</0
YZS>0:V[d@2YZm80ZJcE0:Z]eP2W[=80ZZoE0:N_d`2T[ll0Xk7>0:Fdd@030:Bcd0030:Bcd@2R/m40
X[;C0080Y;CF00/0Xk?G0:Bdf02T]=P0X[;F0:2beP2R]=P0Wk7E0:2_eP2R/MP0X[CJ0:2bf0020:2b
fP0709f`f02L[mP0W:oG09^^eP2G[M@0UZcE09R[e@0209R[d`80UZcE00T0UJcF09>ZeP2DZ=X0TjWK
09:Wg02AZ=`0SjSN08jWg@2=Y]h00P2=Y]l00`2;Y=d0SJ?L08ZPf@0208bQf00=08RMe02;W]P0R9_E
08NJe026VM@0RY[F08RFd`26U]40QIG@08NEdP28U]D0QI?B08JCd`0208BBd`0>08>Bd`21TLl0P93>
07f@b`1kS/P0OI3807^?a01kTL<0N93007N=_P1fS[`0MHfi07N?^`1eSK/207:8^@0g07:7^`1_Q;d0
Kh:m07>3`@1`P/80LXC606j0`P1]O/<0KX3206el_`1^Nkl0KWbm06mj^P1_N[P0KWZd06ik/P1YNJd0
IgNX06UjZ01VMjD0IGJT06AdY@1UMJH0IWJY069bYP1QLZP0Gg2X061_ZP1PKZ/0H72/061`Z`1MK:L0
H6nX05a[XP1LK:00FVZM05aYW@1JIi/0G6VM05aVV`1JIYX0FfNK05MTV01EHYH0EFFF05EVU01CI900
DV>>05=TS`1?H8/0DF2;05=PS01@GHX0DEj;059NSP0204eIR@0604iHRP1?FH`0D5R904YEP`1>EXD0
BUF20P19EX<01@16E840AUF004EFP@11DWd0@EAn0080@5=n00L0?U5l03mBO@0lCgT0?4mi03a>N@0l
CGP0>dYe0080?4]f02/0>TQe03Q6L`0hAWD0>DEe03Q6M`0fA7D0=DEf03A4M`0a@G@0<T9c02m1K`0^
@F`0;3mY02ToIP0X?6009SYM02PlG@0Z?Ul0:CaM02PkG00[>e`09SIH02DcF00W=E`0:3IM02HcG@0V
<el09cAP02@bG`0R<5l0931P02<`G@0R;e`082eI020]E`0M:e807BU?01h[CP0N:DT07RY401dX?P0I
8CH07BDj00Wooooo0007ooooo`1P059EE@1DEEH0IFMV07AeM022PX80Ogn007=aM@1dL7H0LF]c05eE
G@1@ATd0B3i403H_<@0]9RH0:bHS02TT800L61806QL>01XF3@0E4PP061L<020L4`0U91X08b4L01TI
4`0I6A@061XD01XM5`0K7AP061`E01DI4P0E61007QlH020P6@0P8A`08B<M02HU8P0X:2D0;BdY02//
:@0l?CT0C4e904]<A@19BT<0Bda504a>AP12A3`0?Clh0412>`15Ad00@D@l03Xm=P0l?cP0>Slh03e3
?011Ach0@dXo0417?00l@SH0?D0e03m2=@0n@C<0?Cl`0411<P1:B3P0CTPi055:?P1kMFT0R8Ak07Ic
K01THel0GEeK05AGEP1AEeL0C5IF04aGF`1BGF<0IG1i07R0SP2AVJX0W:Bf09^S]`2JX[T0WJBm09nV
`@2QZ<@0Xj_80:B/b@2W/<h0Yk3@0:F]c@2W[/l0Z;7A0:Zbd`2W/]80YK3A0P2U/M40302U/]80YK?B
0:FedP2U/m80YKGD0:Fcd`2T/]@0YKCF0:Bce@2T]=D0Xk?D0:Bde@80Xk;E0140X[7D0:6be02S/]@0
X[7C0:>beP2R/]H0XK7F0::bf@2O/MT0Wk7K09j`g02N/Md0WK7M09Z_f`2I[]X0VZkL09V/f@0209RY
e`0K09RZeP2FZMH0UZ[F09FYe@2DZ=H0TjSH09:Xe`2@YmL0TJOJ08jVf02>Y]T0SZKK08bTfP2;XmT0
RZ;H08bSf02;X]L0RZ3E08ZPe`29WmH0R9kE08JJdP24V<l0QiWA08NGd027U/l0R9O@0080R9??03P0
Qi;>08NAc`25T<l0QI3?08>@cP22Sl`0OXk907n>b01mSlL0Oho807b>a@1iS/40MXfo07N<_P1fSK`0
MXjl07>=^P1dRk/0LXVj07>9^`1cQkd0LHBm07:2_@1cPkl0Kh7006n1`P1_Ol80KGg006in`01]O;h0
KWfo06ek_01]N[T0K7Vf06ej]P1/Nk<0JWZ_06Qi[01WN:T0IgVX06AeY01UMZH0I7FV06MgZ`1QLZH0
HW>Y065bZ@1QL:X0HW6[05m`Z@1NKZL0G6^S05i/XP1LK:00G6bN05a/V`80Ff^H00D0FVVG05QWU@1H
IiD0EfNE05EVU002055UT@0=059WT@1CIXl0E6N?055TS01AHhX0DV69059QR01@GXD0Den7055NQ`1>
Fh@0CUV304mJQP0204mIQP0V04aHQ017E7l0AeAo04MFPP16Eh00AeJ204IGP@13E7h0A5N1049EP00o
Dgh0?e>003iBO`0oDGl0?Dml03i?OP0nCgd0?Tml03a:N00lBWH0?4Uh03a9MP0iAG<0>TMd03Y6MP0h
A7@0=dEd03I4M00e@g<0=49a0351KP0_?f/0<41Z02doI`0[?VD0;3iS02/lH00Y>ed202XlG@80:3]K
01H09SUH02PhF@0V=UP09SQJ02DgF@0S=5L08cAH028bF00Q<5P0935I028`E`0R<5P07biF01l]E00M
;58072]?01h]D00K:DX06RU401XX?`0I93X06R<h2Oooool000Oooooo03/0JFe`06=WJP1RHfL0Kfic
07=bM`1ZJFh0HEmT05eHGP1BBe80@3Lo03H/=00c:Rl08aXM01hH600N6AH06AHA01DE3@0D50`04A47
018B1P0F5PX07alE01hN5P0K71H05AH@00lA300A4`h04aD@01/N600H7Q@06ahE01`O500O7aD08B4G
024Q6@0U91l0:bXU02TX900_;RX0?3/i04=2@015AD<0A4A204=3@@13AD80A4I304=8A00oA3h0>3lh
03Tn>00i?SL0>3df03]0>@0h?CH0=cdc03Pn=00j@3@0>Clc03a2=P0203i2=00V03e1<P0n@C00>3TY
04a:>`1QGTl0Ddi1069ND`1ZIUd0EeA=05IED@1ADe80CU9C051HF`1EGVD0IW1i07>0R@27Til0Uj>c
09NR]02IY[T0VZJl09fW`02LY[l0WZS30:2Ya`2PZlT0XJc80:6_bP2T//d0XK7;0:>cc02T]<d0YKG<
0:Jfc@2T]<d0Y;C>0:>bc`2U/m020:Jcd`040:NdeP2X]ML0Y[?F0:Fbe@80YK?F01L0Y;CF0:Jde`2U
]ML0X[;D0:6ad`2P/=@0XK7E0:>aeP2Q[m@0XJoF0::`e`2S/]/0WZgH09f^fP2K[=X0VZcL09^]gP2I
[Ml0V:cO09N[gP2IZ]h0UjSL09RXg00209NWfP0409NWf02DY]H0UJOE09FWe@80TjGC01X0T:GB08jS
d02>Xm80SZ?B08jRe02=XmD0RYoD08VNd`28Wm<0S:?G08VPeP26WM<0QikD08NNdP24Vll0Q9_=08FK
c@23UlX0PiC808JFbP25ULT0QI;908JCbP26T<X0Q8k908:>bP<0Pho900P0P8o807f<a@1mS<D0OXg6
07^<a01fR[l0MHVn07F9_080MH^m00T0M8Vn07>8_@1bQk`0M8Rm07>4^P1eQ[`0LX>k0761_01_Ok/0
0P1^O[X02@1cPKh0Kgji06ak]P1/NkH0JgZe06]j/`1[N[40KGbc06Uh[`0206IgZ`0606MiZ`1UMjL0
I7JV061bXP1RM:H0HG>U0P1PLZ@0401OKj<0H72S065aY@1NKZ80GV^P069_X`1NK9d0Ff^L05]/VP1K
K9P0FFbF05Q[U@1FJI<0EVVA05AWS`1BJ942055WT00A05EXTP1CIY00DF:=059QRP1AH8T0DV2705=O
Q@1AGH<0DUb0055KOP1BG7l0D5f004eJOP1<F7h0BeV004]JP@17FH400P13EWh01@14Egl0@UEm04=F
P013EX00AER20080@EAo01H0?U1n045BP010DGl0@4im03m=OP10CWl0?del03]9N00mBGT0?TQi03]6
M00iA780?DQe03Y7M00hAG80=D=`03A3KP0eA6l0=4=^0391JP0b@FP0<3mV0P0_?f<0100a@6@0;C]P
02dkGP0/>Ud202XjF`0802PhF@0X>EL0:CUJ02LhEP0V=eD09cQF02@eD`0Q<U0202<bD`0301l^C@0Q
<4l08C1A00807be@00P0831D01l_D`0M:dh07bi=01l]BP0K9d406bDn01`T>`Wooooo0007ooooo`05
06Q^KP1^M7@0KFib05eNHP1DEET00P1EE5T0201BD5<0AdE8030^<@0[:BX08B0N01`K6@0K6QH06APD
0P0F5a40A@0H6A<05AH>01<D300H6A407QlG01dN600E5Q00414;00h?2@0?40X05QLA01XK4`0N8AH0
828G028T5`0R8QH08b<I028R600R8a/0:b`T02d^:00a<R`0>cXf0450?013@T00@D5103i0?`0m?ch0
?d5003i2@@0j@3`0=Clg03Dl=@0d>c@0=Sde03Po=`0i@CH0=Shc03Lm<`0d>Rh0<3HZ03Hl;P0l@SH0
?d<e03i2=013AcT0>S`_03hn<P1SI5H0FEQ<04e=@`1IFDl0Gf1H05iPF`1@EE40B4i>04eEF01XLGP0
Mh6;08JBX02>VZX0TIja09FQ]`2GY[/0V:Nn09NV_@2KZL<0X:_709n[b00309j]bP0<0::bc02N[lT0
Wk790:6cb`2S]L/0Y;K<0:>eb`2R]<`0XkC>0:Fdd@2Q/<l0Y;?D0P2U/]D05P2Y]]T0Y[?G0:Jeg02U
]=/0X;;H0:>bf@2P/]P0X;;F0:6cf@2O/MT0XK?K0:2_f02R/MX0X:oJ09j]f02O[]T0WJ_H09b/g@2K
[Md0VjgO09V[gP2GZ=`209VZh00;09VXg`2GY]d0UjSN09FVg02FY]X0UjOJ09JXfP2DY]H0UjOH09BU
d`2BY=800P2AXm404`2>X=00Sj7A08fNd`2=W]H0SIgH08RKe@28W=L0R9kH08FNe`27X=T0Q9gE086J
dP24Vm40Pi[>08BJc023UlT0P9C608:DaP23U<P00P22T/H01P25TLP0QI3808B>b@22S/P0Pho907j=
aP80Ohk500P0OHc507b;a01jRl40Nhc207V:`01hRKl0Mh_007>7_080LXJk00D0LHFh07B5^@1cPkL0
M8Bh07:1^0020760^@0;0760]`1^OK@0L7fd06ml/@1/NJh0KW^`06]h[@1/NJd0JgR/06Yj[@1VMZX0
0P1VMj/03P1SMjT0HGFW065fY@1PMJ@0Gg6O061bX01SMJ<0HGBO05m`WP1OKIX0HFnN061^W@1PK:00
HFjR0P1MJi`0201IJIX0EfVI05I[V01DJIH0DVND055VT`1BIi@0DfFC0P1BI9802@1CI980D66?05=Q
T01BGh`0Dej<059JR01DFhL0E5b305=KP002059JOP0G051JO@1?FWd0BeUn04]JP@18FX00AeV104MJ
Q012EGl0@5Io049HP@13EX40@5=n049EP012Dh40@55o045BP011Cgh0?del049?O00oBg/0@4]l03m9
NP0mAgP00P0mB7H01@0jAG80>DI`03Q5K`0iAW80>4E_0080=4=/00H0<d9Y0391J00c@FH0=49U030n
H@0^?5l202dmG`0802`lGP0]>eh0;3YM02TgFP0Z>5/0:CMJ02ThF@0Y=eX202TfF00:02XgF@0X<UD0
9c5D028_D@0Q;U008Bi>01l/C00P;Dd08Bi@01dZC@8082aB00H07RQ<028ZCP0S:D/082M401`Q?P0M
8C`9ooooo`001oooool04P1`M7L0IFU/06=TJ01PGf@0DE1E04E4B@0n?T00=SHh03Lg>@0^;Rh0:R`[
01/M6P0C5A0051HA01LI500H6QD05APA01TL5@806AXD04L06Q/E01dN600K71H05AHA00h?2P0=3PT0
4Q<=01DF400K71D07QlG01lQ5P0T9Q/09BDK02<S6@0N7aL0:BXR02h_9`0b<bd0>c`f03m0>P12@Cd0
ADA20451@@0m?T00>c`n03Xk?@0i?C`0=cdk03Dk=`0d>SH0<STb03<j<`0e?3@0>3lg03@l<@0`=R`0
<cT_03@j;P0c>Bd0>3hd03Y0=P0oAC/0A4Ln04=6?`16BD80EeYC04]=A`15AT40HfEP07n4P026RXT0
Bdm@055FFP1[KgP0OhFA092GY`2DW:l0Tijb09BN]`2GXkd0U::l09NU_`2IYl40VjW309jZa02O[<L0
Vj_509b/aP2L[LL0X;7;09nab@0209fab@0?09jbbP2Q]Ld0XKG=0:2dc02Q//h0YKKD0:Bce02T/]D0
Xk7D0:Bbe`2V/]P0Y;;H0:6cf`2S]Md0Wk;J0080W[7I00/0W;3E09^af02J[ML0W:oI09jaf`2N[mX0
WZoK09f[f02P[]/0VjcJ09ZZf`0209RZg00?09NXf`2HZ=`0UZOM09JWg@2HYmh0UZKJ09BUf`2CY=P0
U:CG09>SeP2BY=@0TjGE09BTe@2?Wm00TJ?A0080SZ3>01H0SIo?08fOd@2=W]<0SIkF08^KeP28VmD0
Qi_F08FKe@23VM<0PicE086Jd`22V=40PYW?08:Gc022V<T0PiS707fB`@1nTl80PYC6086Ca@1oTL<0
PY750P22Sl@01@21S/D0OXg4082?aP1oS/D0Nh[10080NXW20140N8Vo07Z;`@1gR;h0MXNm07R9_`1g
R;h0LhJn07F6_01bPkL0Lh>f0761]01bP[D0LX:f079o]01cP;D0LGjc06em/00206ml/00306ek[01Z
N:T0JGNX0080JWRY00L0IgNZ06MgZ`1TMJT0IGV/069gZP1SMjT0GgBS0080GW>P00<0GW>N05mbW01P
Lid00P1NKiX0:01NKIP0GfjI05m[V`1OJid0FfVJ05aZV`1JIi/0F6RK05QZVP1CJ9L0CV>B051RTP1C
IID0E6JH05=SUP1AHI80DEn@05ART`1BGY00E5jA05EMSP1DFXX0DeZ805AKQ@1CFh80DUYo04mIO@1=
Eg/0CU]o04YJOP17FGl0AeZ204EHP014Eh40@EN003mEOP10EH00@EJ104=FP@12E882041AO`0804=A
OP10CW/0?dah045>NP10BgP0@4Ug0418MP0mB7D203i:M00303Y8K`0gAF`0=dEZ0080=TA[0P0d@VT0
0`0c@FH0<T1U038oHP02034nH@0502hlG`0/>Ud0;3YM02/iG00]>Ud00P0[>5/02P0X=UT0:SMJ02Xg
FP0X=EP0:cEI02XdF00Y<eL0:C5F02/cF00X<UH2024[CP0302<^CP0P:d/08B]=00808B]?00L082Q=
024VC00N94P08BE8020SA00K73X07Ahl00Wooooo0007ooooo`0o07=`M`1PGV<0H5]Q06=NHP1DDUL0
?ce203Hd>@0b<3D0<C0e02LW:@0L81l05A/G00`B3P0<4@d04QLA01LL5P0E6Q@05a`F01PK500G6Q<0
6a`F01`M600L6aL05aLE00d=2`0<30X03Ph<01PG5@0I6A@07AhI01dP6@0Q8Q`08R<K02@U7@0N7aT0
9bPR03`m=`0j>cH0?Clj0452?@0n?S`0@d=104E5A@12@T80A4A60452A00l@440>S`n03Pj>@0e>CP0
<cLf034e=00f>cL0<cTe038i<P0^<bd0;S</03<j<P0f?CH0=S`h03]1?@14BTH0Bdm>0080B4a=0140
Ad]<04A7B`13AT/0EeYO08Z?U@2HWJ<0Oh><04e?F`1lOhh0U9NZ09RM/`2HW;L0VIjl09^P`02KXL40
W:G409bW``0209^W`@0509jZ`P2R[lP0Wjo609f]a02L[<<00P2O/LL06P2L/LH0W[;:09j_b@2P/L/0
W[;;0:2dc`2N/Ll0XK7B0:Bbe@2U/mP0Y;;G0:>bf@2T/]T0X[7J0:6bg@2N/M/0W;;K09^af02K/mT0
V[;H09Vae`2I[mP0V:kG09Z`f@2I[mP0W:oJ0P2M[]X03`2L[M/0V:SI09NWf02HZ=T0V:SJ09JVf@2F
Z=P0UjWI09NWf02FYmD0UZKG09RYe`2EY]@0U:GC09BVe00209:TdP0D092Rd02?XLl0S:7>08^Pc`2<
XM00RioA08VMd028W=40RIcD08NLd`26Vm80PiS?08JKe023V]00PIS>08:Ic@21UlT0PYK808>Ea`21
Tl<2082B`P09082Ea01mT/40OI;107nA`@1mSkl0OHo107j?``1kS<00NX^o0080Nhc000D0NX_107V:
`01gR<00MXNo07N8`00207B5_@0607F6_P1dQKd0LhBj07B4^01dPKH0LWnc0P1cP;@01`1cOk<0LGjb
079o/`1`OK40KGf`06YjZ`1/O:d00`1XN:T0<@1XN:/0IgR/06IgZ`1SMj`0I7V^065gZP1PMZL0H7JU
05edX01LLil0G7>M05abV`1LLYT0Fg6H05Y]U@1LKYH0GW2H05i]V01LJYL0FfNG05YVUP1LJ9X0FVRI
05IVU`1FIYP0DF>E051PT`1EIIP0Df>G05=PU@1BGi<0DenC059NTP1@G900DE^>05=KS01BFX/0DEV8
055LR@1>FX@0CE^204aJP@19Eg`0BEYo04IHOP15F800AE^2049HO`11Egh00P10EWd2049EO`0G03eC
O011E7l0@U=o03m@O011D7/0@4mh045?MP0nC7<0?D]b03m<L`0kAfd0>TI/03Y7JP0oCG00>TQ[03M5
J00fAVP0=49W03=1IP0d@VL0<SiT02lkH@0a?F<00`0c?6<02P0c?F40<C]O02`iG00[>5/0;CMJ02hh
F`0/=UT0:SMJ02/eF@0Z<eX202PaF080:C9I00X09BiE02H`E00Y<eL09BmC02H^D`0U;E408Ra?01lX
C00P:4d08RY?0P0S:Dd01@0T:4/08bI5028V@`0O83h07Adi00Wooooo0007ooooo`1S06IQI@1KEUX0
G5QI05iJF`1CCe00=C0d038]<@0_;C00:bT/020P8P0D61T05Q`J01@J600:3Pd0314=01HK5`0E6QH0
5aTF01LI500F61<06Q/F01/K6@0M71X06QXH01PH5P0D51804A0>01LF500I6AL07AlJ020R7@0O91d0
8B@M028U700Y;2D0=3L`0452?00n@CX0?3lh03i0>`10@C`0@40n0451?`13@d<0@T9203/m?00o@D00
?3hn03Pi>`0e>CX0=3Pi034e=P0d>3T0<cTi030f=00a=C@0<3@c034e=00d>SX0<CDh04E:CP1GFUl0
DEAI04Y=E018Be@0AdYC04M:EP15BED0AdUH07IhQ`2XZ[T0V9V[069SM@24QIT0W9bf09fN_02JWK`0
VYfn09^O`P2KXL<0VjC309fV``2OZlD0WJW109jZ`02O[/@0Wk340:2aa@2R/lL0Wk770:2bb02N/lP0
W[;:0:2ac@2Q//h0W[7?0:6ddP2P/m<0WjoA0080Xk?G00D0Xk;I0::af02R/MX0X;;J09^^eP0209bb
f@0?09Zbf02L]=P0VK?H09Vcf02H/=H0UZkD09ZafP2G[]L0V:kG09V/e`2K[=P0VJ[F09VZf02GYmP0
VJWJ0080UjOH0P2EYmD04P2FYm<0V:WE09NXe02FYm<0UJKB09BUd@2EZ=<0T:?>092Rd02>Xm00SJ;?
08ZQc@2;XM00Rj?A08VOd029X=00Qig?08RNd080Qig?0P24V/`01@26W<h0Q9S;08>Gb@20UL@0PI?3
0080PiC200T0PI;0082B`021Tl40OY?007fB_`1lTKh0OY?207^?`@1lT<800P1hS;l04P1iR[h0NH[0
07R9_`1hRKl0NX_107J7_@1hRKl0MHJl07B5^`1cQ;X0LX>i07B3^P1bP[H0Lh6e07:2]@1cPK80L7j_
075o/080L7fa01H0Jg^^06em/01ZNZ/0JWZ]06QhZ@1YNJ`0J7R[06IfZ@1VMj/0I7F[06Ah[@1RMj`0
H7FZ05ecY@1OMJH0GWBS05acW`1LLid0FW6J05]bV`1JL9T0FFnF0P1LKiL0101LKYH0GFbG05YXU@1K
JIH205]WU`0]05QVU@1GII@0E6FC05=SU01EHi@0EV>G05AQU@1BGY00E62B059NTP1?Fhl0Ce^=04aH
R01?Fh/0CU^804aKQP1:FH80BeZ304eLP`1;FX40B5Yo04EIOP16FWl0Ae^004IJO`14F7d0@UIk045D
O012E7`0@eAo03mBO011E7h0@U=n045@N`10CgP0?Ted041>L`0oCG80?D]`03i<L00nBfh0?4U/03Y9
JP0mC6d0>DUZ0080=TIX00d0=dMY03A2I`0gAFX0=D=X038nI00`?680<CYQ038kHP0e?F@0=SiU038k
HP0`>Uh0;CMK0080<CUN00L0;SQL02dgF`0/=E`0:C9I02L^F00Y<5X0:35J00809c1I01009BiE02H_
EP0V;eH09bmF02D]E00R;50082U>024YCP0R:Tl092Y>02<WC00U:TX09RU8024U@P0P8Cd0828k2Ooo
ool000Oooooo00/0DeA>05AEC`1GEU40A44l03/h<`0_:bP0:bLV02l[;00Z:2T05QDH01@C6002018C
5@0K00d>400;30h04A8D01HG6@0D51@04A4A01HF5P0K6aT06QXH01XK5P0M71X06aXH01@C4@0B4@d0
51<?01TJ5@0O8Q/07bHN01dU6P0L8QH09B/O02`b900f?300?T4f03e0=`0f>C00>C`e0080?3hi02T0
>cdh03do?00l?S/0>C/h03`n>`0m?cd0>CXl03Di?00c=S/0;S<g02hc>@0_=3X0;c@h03Dh?@0a=3T0
;S4h02d`=`0f=T00FeeY069QK`1GEV@0C4]K04U8F018AeL0BTUM04a=H@19Aed0G5Y`09fK/`2LV[80
ShfU09ZG/P2NW[X0VIZi09jQ`P2MX<40WJ;209nUa@2LYL80WJW309f/``0209f/`@0A09f^`@2N[l<0
Wk340:2baP2P//P0Wk790::dc02R/ld0XK;>0::cd@2M/=00Wk;C0:6ae@2P[mH0X[7H09j`eP2O/MT0
0P2P/]X06`2M/=P0V[3E09bbe`2K/mL0V;3D09Vad`2F/=<0V;;E09N_d`2H[]<0UjoE09J^e02G[M@0
V:_E09VZe@2IZ]H0VJOD09VWeP2GZ=H0UZOF09FUeP2GZML0TZOD09BVe02EZ=<0TjKA09BWd@0209BU
d@0:09FXd`2@Xlh0SZ?@08fRd@2<X]40RZ;@08ZRdP29Y=<0Qio?08NQd080QYk>00D0QYc=08JLb`25
V/T0PiS708FGa@0208BE``0308>D`022Tkh0PiBo0080PY>n0100OI2k07nB_@1oT[d0OI:m07^A_01j
T;l0Ni7207Z@`P1hS<40Mh_007V=`P1fR[l0NH[007N8_P1hQkh0MhNk0P1fQ[X0201dQ[P0LhFg07B4
]`1eQKP0M8Bg0762]01`P[@0LH6d0P1^O[408@1]OK40K7b`06]l/01[O;00JWb^06Uj[P1YNjd0J7R/
06]k[P1UMJP0I7BW06AdZ01SM:P0HW>W069cZ@1PLJD0GW:T05icXP1MLZ40Fg2M05YaW@1IL9X0FW6K
05YaVP1JL9T0GG2H05Q[T`1IJi<0FFZE05Y[UP1JJI@0F6NB05UVT00205IUSP0J05IUT01FHhl0EF:?
05ERS`1BGh`0Den?055OT01@GXl0C5f;04aMR@1;G8L0AeZ204QKP`19GH80B5Yn04ULO@18Fg`0BUao
04IINP15F7T0AUUi04UIN`17EgT0A5Ah04=BN@14DgX204=BN`0F049ANP13DW/0@4eg041=M`11CgH0
?Tib03m?L`0oCG00?dea03e;KP0kBF`0>4QZ03U9J`0hB6X0=TIZ03=5J@0dAVX0>4Q/03I6JP0eAFT0
=49Y030nI@80<3aT00@0=CiW03HoJ00a>V40<3UP0`0_>5l0100[=5/0;CIM02heG`0]=5h202XaF`06
02T`G00X;e/09biJ02P_F@0V;eP092eF0P0T;EP02`0Q:U<082UB020YDP0R:e808BU>024WB`0T:4/0
9BY8028V@@0M8CX07b@j00Wooooo0007ooooo`0:059EC01?DTT0B4U103@d;00Z:R809B8M028N6`0R
7Qd07Q`M01HE5P804a<E00d051@F00l?4@0B4Q@04a<E01DE5`0B4Q@03@d=014A4@0K6aT06adH01XL
5`0I6QD061TD00804a8>010061TD01PK5@0J7aP07bHN01dW700H81D08b/N038h;00j@3@0>T0f03/n
=`0b=Bh0>C/f0412?@0m?c`0=cTd0P0f>3<07`0e=c80>3Xe03/m>`0i>S`0<cLj030c>00[;SD0;S<i
030e>`0`=CT0=CPo02ha>00b<SX0=cLo02h^>01ZJW@0JVUg05]JJ01IF6P0D4mQ04]:G01>C680CD]Q
04e;H`1cLHT0W9Rc09RD[`2FTZd0WIZg09jM_02LWK`00P2LWkh01@2MX/80WJC109bV`@2JZ<80W:_2
0080WJk201d0W:g109f_``2N/<@0W[3609b^a02M[lL0Wk3:0:6bc02O/<`0XK;@09jad@2N/M80WJoE
09^]d`2O/ML0W[3F09naf@2M[mL0VjgE09b_eP2J/=D0VK3B09R`dP2I/M<0UZk@09R`dP2G[m40V[3E
09R^d`0209N]dP0?09J/d`2GZ]80V:[B09^Zd`2KZ]D0V:OB09RVd`2EY]80U:GA09>Vd@2AY<h0Sj;=
08nRc02@Xld0SZ790080Sj3;00H0Sj;<08bObP2:Wl`0S:7>08ZPc`29XLl208RPd00?08FMc@25W/`0
Pi_908>Kb@25VlX0RYo<08BIaP23V<<0Q9O208FF`P23U<00PY>n07nB^P21T[d0P96l0080Oi:l00P0
OI2j07V?^01iSkP0NY2k07V?_P1jT<40Mhfo07J:_`80N8c100T0MXZo07N8_P1eQ[X0MhNk07F5^01b
P[D0LXBd0763/`1aPk400`1`P[001@1_PK40KGn_06an/01]Ok40JWb^0080Jgb`00L0JW^_06]l/01X
NJd0J7V]06Mh[01XN:`0J7R[0080IgBX00H0IW>W069bY@1SLjL0HG6V069bYP1MKZ8205i`XP0705Q]
W01KL9l0FVnN05I[V01EJYL0EfbG05Q]V00205IYT`80EfZD01d0EfVA05EWS`1GIXd0EfJ=05ASRP1E
I8/0DV6805=RR`1EI8d0DUn;051ORP1?GH`0C5f;04aORP1;GXP0B5j504ILP`15Fh00AUb104AHN`18
Fg`0AEUj04YKO@16EWP0AEEf04IFM`17EGP0AE=f04ECN00204=AN00Y049@M`11CWP0@Tmi045>N00o
C7H0?T]e03i<L`10CgH0?4]b03e;L00lBVl0>TQ]03];K`0iBF/0>TY^03I6JP0eAFT0<dEY03=5J`0d
AV`0=4IZ02m1I@0a@6L0<3mV034oIP0]>f80<3aV03<oI`0]>F40;3QN02/gG@0Z=U`0:cMM02PdG00Z
<e`0:35J02T`FP0Z<E/0:C1J02P_F`0V;ET00`0U;5P03P0S:UH092eH02</E`0P:E@08BYC024ZD@0P
:E0082Y=020VBP0P9TH082M301hT?00M8cT07B@g2Oooool000Oooooo0540DEI?03e2>`0a=2d0:R/U
02<T7P0J6A@05A@@01@E400C4a404A8@01@F5@0F61L061XI01XL6`0K7A`06A/J01LI600A4a804A4?
01HF500I6aP06b0J01TN600E6Q<04QL@014D3@0C5Pl051TB01DJ4`0G7QL061lH01/R6`0O91h09R/U
03Li=00f>3D0>C/j03`l?00k>c/0?clo03hn?P0j>SX0=cLe03De<`0e=c@0=SPe03Pj=@0i>cT0=SLi
030a<`0a<SH0;c0d02lc=P0_<c@0;c<b038c=@0`<S40<cLf03Xn?@11ADH0HFEV06MXK@1QHFT0FeUT
04Q6D`1:BEL0DDmP06MTN@1iMhd0RhVQ09RD[@2IUK00ViRc09ZJ]02NW[X0WYnm09jR_`2LXKh0W:6o
09^R_P2MYl800P2JZ<806P2JZ/40W:k409f_a@2I[/<0Vk3509fba`2K/<D0W;7609nab@2N[lT0WJk:
0:2ac`2P/=40Wk;C09f_d`2K[M<0W:kD09f_e@2M[mL0W:gH09^]e@2J[M@0VZkC09JZc`2F[=40V:kC
0P2E[M40402F[]80VJoF09N]e02H[]<0V:cA09RZd02JZM00UZG<09NUc02GY<h0UJC=09BSbP2CX/T0
TZ7808nQa`2<W/8208ZL`P0=08NK`026V[l0PiJn08NJ`P23U[h0PYFm08BG`@21U/40PiS5082G``21
UlH0Q9[908:Ha`02082G``07086Ha022Ul@0PIK3082E`P22Ul80P9G0086F`@0207nD_`0307jD_@1m
T[d0OI>l0080O9:k00L0OI:m07Z?^P1iS[T0N8fk07N<^`1hS;h0MXZl0080MXZm00<0N8Vm07J7^`1h
RKd00P1gRK/0101dQ[H0LH>c06j3/01_Q;4306j3[P0>06YoZP1[P:d0JWn/06Yo[P1XOJ`0Jgf_06an
/01[O;00IgR/06Ui[@1WMj/0IGNY06AfZ01VMZT206IfY`0306MeYP1TLZ<0Hg6R0080I76U00@0I76V
065^X`1NKZ40H72S0P1MKJ005@1LKZ00F6ZL05QZW01FJ9X0EfVI05IXUP1EIiD0DVNB05=XT`1FJI<0
DVF=05=WS01BIXT0DVB8051RQP1AHhL0D6:6059TRP1AH8T0Cf2;04ePR`0204]NR@0504YMQ`18GXD0
B5j504ILP`15Fh000P16FWd02015Eg/0AUMk04EEN@14DWD0AE=f04QDNP14D7P0A59i0P13D7X03012
CgT0@Dih03m<MP12CWP0@Deg03e:M00nBgL0?DYf03a9M@0kBW<0>dUc03U7KP80>DM/00@0>dU`03Q6
K@0e@fX0=DA[0`0c@VT02`0`?fH0;ciU02lnI@0^?V80;cmS02dkHP0^?6<0;C]R02PfG@0V=5/09C=J
00809SAK01409c=K02TbF@0W;UP0:c1J02T]FP0W:eP09RYG02P/F@0W:eP09RYG028VD`0S:UH08bYD
024XDP0Q:Tl08B]>01h[C@0201dXAP0501dW@P0L9cd07bLj01`U=P0K93<02Oooool000Oooooo01<0
=3Xf02ld;P0Y;RP0828M01XM5P0A50/03a8;00hA2P0>40/04A<>01DG4P0J71T06A/H01XL5`0L7QT0
6adH01PJ5@0D5Q404Q@?00806Q`G00l06B0I01dT700H7aL05QdE010G3`0C6Q805A`D01LN5`0H7QX0
6R0L01/Q7@0Q9B@0:Rh]03Li>00k?C`00P0m?Cl0?@0j>S`0=cLi03@d=00f=SH0=SHd03De<`0e=c@0
>3Xg03Pj=@0h>SL0=CLf030b<@0d=SD0=cLg03<e=00/;R/0:2XW03Ph>00g=cD0=SPe06=UHP1XJVT0
IFIX06]/L01fMg`0?Ce7030`?00n?D/0D4mQ071^Q02<RZ00ShnW09JC[P2HV;80VIVc09^M]P2LX;/0
Wj>n09^P_@2MY<00W:>o09fT`02MYl80W:S209ZX`P2KZl@0WJg609f^a`2J[<80WJo709^_a`2L/<P0
Vjo709f^b02O/<X0Wk3>09j^c`2M[Ll0WK3A09j`e02J[]<00P2L[]H01@2L[MP0VjcH09Z[eP2J[=L0
VZgG0080V:_C01L0VJoF09N]e02G[M@0UZcE09:Xd@2DYm40UJS@09JXd02HYm00UZC;09NSb`2FX/X0
UJ7909>Oa`2@W/D0SYc208^I_P29Uk`0RYRm08JE_023UK/0PYBj07fA]P0207f@^00707b@]@1hRk<0
NHbd07Z=]`1kS[P0Nhji07b=^`0207^>^@0907jA_020Tkh0Oi6o07nA_`20T/00OY?007nD_`1nUKl0
OIBn0080OYFo00l0O9>m07jE_`1mU;h0NY6k07V@^P1lTkd0N8nk07V>^`1gS;X0NHjm07J;^P1cR;L0
M8Rj07F9^`1dQ[P00P1fR;X207F7]`0G07B6]P1`QK80L8Fb06n4/@1`QK00KX>^06n4[`1]PZd0KH:_
06b1/01ZOjh0JGj]06Yl[P1[O;00JW^a06Mf[@1[N:l0JgR]06IfZP1RM:H0I7BW06AdY@1TMJ<00P1V
M:<07@1ULj80I7:S06=aX`1SL:D0H6fQ065^XP1PKJ40GV^O05m/X01KJih0FFVM05QXV`1GIi/0FFVL
05EWU`1DIYH0EfVG05I[UP1EJ980DVR?051VR`1AIhT0DFF8055SQ`1@HXH0DF>9059TS01>GhX0Cf2;
0080Bej900D0BEb704YMQ`19G8H0AUb504IIP`0204IIP@0404AHO@14EW`0AEMm04IEO080A5=j00<0
AE=j04ABN@12DGP00P12DGP00`13DWT0@U1g041>M@02045>N00703i;M`0mBWL0?T]h03a:M`0kBGH0
>4Qd03E4K@0203Q7KP80=TE/0P0eA6/02@0b@FP0<3mV0391J00a@6L0;SeT02`kHP0/?600;CeQ02/j
H@0202XiH00M02PgG`0U=5d093=J02<bF@0T<UT09c=K02HbF00V;eH0:RmI02/_G00Z;eT0:2eG02T]
FP0X;5T09RUF024UDP0R9U<08RUC02D/EP0R:e0082];01l]BP0K:D@05bDo01PT?00K:3/06RLg01TU
<`0I9C402Oooool000Oooooo00/0;30_02/`;00S:2@06AhH018H3P0>50P02a4500dC1`0<4PP041@=
01LJ4`0201XP5P0O01DH4@0I71<06AlE01PK400F6A004aH=01PN500G7a@061lG01TS6P0D7QD04adE
010J4P0B71@05AlG01XS7@0J8ah082TT02H]9P0[<2`0<CHb03Dg=00g>CH0=cLg03De=@0f=S@0=3@b
02h^;00_;bd0<S@_03Hh<`0203Tk=P0503Pj=@0g>3<0=CHa038b<00d=3800P0j>CL08`0f=C<0?S`m
04E0A011?400@Cm206QXJP1_KW<0GEiS05mOI`1^LGX0DeER04i@G`1EEVX0LG6808j@Z@2DUZl0UIN`
09BH/`2HW;L0VYji09^Q^`2JXK/0WjK009ZT_@2KYKh0WZS309^U`02KYl40W:S209^V`P2LYl<0Wj[6
09f[aP2MZlD0W:c600<0WJk800/0Vjo:09^^c02I[<d0W[7B09b^dP2K[M<0WJoG09Z[eP2JZmL0VJ[F
09VZf00209Z[f@0=09Z[fP2HZ=T0UjWG09NZe@2FZ=H0VJ_I09NYe`2EYmL0UjOH09>TdP2BXll0U:;?
09FPc@0209FNb@0?09BKa`2AV<@0SiK208fF`@2<U<00R8nm08N?_@23S[/0Ohbi082>^`1lR[L0NX^g
07N:]@1gR[@0N8Zb0080MHN_00@0M8>Z07F4Z`1gQJ`0NHF_0P1gPjd00`1hQJl0NXNc07V6/`0207V7
]P0907^<^P1iS[T0N8fh07V@^P1jTK/0NY>l07ZA^`1iT;`0N8fj0080NXnl00@0Ni2m07Z?_01hR[P0
NXbi0P1hR[P207F7]@0307B6]01bQ;80LhFc00<0LhFc00h0LXBb06j3/P1`QK80KHB`06Z1[@1/Pjl0
KHB`06b3[`1ZPJh0JGf_06Mk[@1ZNjl0JWV`06Qg[P80IgJ_00H0J7B^06]g/@1UM:/0Hg>W06AaY@1T
LZ<206EcXP0906AbX@1RLil0GVnM061aX01QLJ80H72Q05i^W`1NK9d0FfVJ0080G6ZK01T0FfRL05e[
W01GI9P0EVBE05IVU`1GIiP0EfRF05IYU01GJ9<0E6N?04mURP1BIHX0DF>905ETR`1BHHX0DV6<059P
S@1?GH`0Beb:04eNS01<GH/0BU^904UJR018FHL0AUR60080AUN300@0AEJ2049CO`11E7l0@5=n0P11
E7h2041CN`0@041DN@0oDgP0?e=f03mAM@10DWH0?dmc03a<L010CgH0@4mh03a:M`0iAgH0>dUh03Y8
N@0eAgL0=DMf03=4L080=DIa01T0=4E`0353J`0`@VX0<49Z02i0J00/?VH0;T1V0312J00]?fD0:3YP
02/kG`0/?600:c]O02ThG`0Z>5l0:3IN02LeG00T<UT08c5H02DaF@0S;eL08bmE02PaF00W<5T09BaF
00809BeD00<09baF02L[F00U:EP00P0Q9E80300T:E<08RUC028[D@0N:DT07BQ601LU@00G9Sd062Ll
01PX>00D93<04b4^01HT;`Wooooo0007ooooo`0I02DY:P0[;c008bTW014G4`0?5Ph04AT>00hD2P0<
4PP03A<9014E300H6a806AlC01XP500G6Pl06QdB01LK3@0H70h06Q`A01PK400I7aD06b<H01@K500E
6aL04QPD010F500201DK6@0G01LM6`0I7a`07R@R028X900W;RL0<SLc03Pj=`0g>CH0=cTd03@f<@0b
=2l0=SPc034d;@0_<R/0;c4/030b;@0c=C00>S`g03Xl>@0f>3D0=CHb03<d;`0f=C<00P0k>SP08@0i
>3H0?3Xk04Q4A@1CCU@0BTE<040mA01JFF40FEMR05]KI`1LGV/0GF1_05MJK@1JG740Gf5j0824X02A
UK80TYNd09FJ]`2DVkL0UYfi09RO^`2FX;T0Uj>m09NS^`2FY;h0V:K009VW`@2MZ<@0W:O309^V`P2L
YL@0WJK509fXaP0209nZb00G09j/b@2N[LX0WZg<09n`cP2K[/h0W:o?09Z/d02L[]80W:kD09Z/e02J
ZmH0V:WE09Z[e`2JZmT0V:SI09ZZf`2LZ]/0VZWK09RXf`2GYmP0UjSF09NWf02HZ=T00P2EYMH01@2F
Y=D0Tj7B096OcP2AW//0TIc90080S9C20240S9?108b@_`28S;/0Q8^i08F:^`26RK`0PHNk07n6^P1n
R;/0O8Rj07Z8^@1iQkH0MHJd07>4/01dQK00LhF]07R7/01eQ:/0MH>Z07J2ZP1iPZ/0Mh2Y07EnY@1e
OZP0Mgn]07=n[01dOZl0Lgn_07J4/`1bQ;80KX>^0725/P1aR;800P1aR;@07P1bQk@0MXRf07J8]P1g
RKT0N8Zj07N9^@1gRKL0N8Zh07J8]P1cQK<0LhJa07F8/`1dQk80LhJa07>5/`1bQ;80LH>c07:4]01a
Pk<0KX:d06b0/P1ZP:l0J7j]06^1/01ZP:l0J82^06Qo[P1YOJl0Jgb`06Uj/080JWVb0P1WM[4206Qd
/00>06Qg/01TLjX0Hg>W065aY01SLJ80HG:P061aW@1QLYh0H76M061bW@1KKYT0GFjJ05a]V@1KK9P2
05]YV00505e[VP1KJIP0G6RH05UUU@1JIYH00P1HIYD03`1FI940EFB?05MVS`1BI8`0DFF:055TS01C
HX/0EFB?05ASSP1@GX/0DEn>04iLS@1=Fh`0CEf>04]KS00204]LRP0304YKR@14EH<0A5F30080A5F3
0P13E8800`13EX40@5=n041CO@0203eCNP80?UAi01@0?UEg03]BM00mDG@0?Dmc03]=L@0mC7<0?dii
03e;N00lBWT0>dUj03E5MP0cAGL0<dEe0393L@0a@g40<DA_0395L00`@fd0;d1[0353J`80<49Z00X0
;3mW02a0I@0Z?680:C]Q02/jH@0Z>F00:cYQ02ThG`0/>F<09cEM0P0U<eX00`0T<UL0939I02<aEP02
02@`EP0C02DaE`0U;UD092iB02L_E00W;eH09BaF024XE00O9U8082MA028YD`0N9e0082Y?01dXB00M
:4H06bI201TX?`0I:Sh06BPk01DU=00201@R;`Wooooo0007ooooo`0>01XO9@0N8bL06AhQ01LM7@0G
6aX061dI01/M6P0L7QT05ALB01PK4`0L7a@0720B01hR500N81<201/M400P01`N4@0M7a@07b0H01/N
5`0P9Al05a/J00lC500F6Qd05aXO01dP9@0K7b806QhQ020R900W:BP0:bdZ034c<00g>C@0>C/f03Pj
=@0d=c00<SD^02le:`0a=bd0<SP^02le:`0_=2d0;S<]02ld;P0e>SH0>3Xi03<e=00c<c@2038b=00R
03/k?@10@400@T9204Q8BP1?CE80CT]B048oB00n?4L0@d5>044nC`1FEFL0GEic05MIL01EEW80JVj;
07n2X@2;T;00T9Jf08nH]`2DWKX0U9nk09:P^`2CXK`0TZ:k09BT_P2DY[h0TJ:l09BU_`2GY/<0VJO4
09ZWa`2KZ<P0W:K909fWbP80WjW<01@0XZc?09n/cP2NZld0WZ_>09f[cP2M[Ll0VjgA09Z/d02K[M<0
VZkC09^^eP2K[=L0VZ_F09f/e`2LZ]L0VjWH09^YfP2NZ]h0VjSJ09VWf080VZSI01/0VJOF09RVe@2G
YM@0Tj7@09BRd@2@W//0S9[708RG`P2:Ul<0QiBn086>^021SKL0P8Rf0868]P20Q[H0OH:e0823^P1n
Pk/0Nh2h07V0]P1iPkP0M82d07F3]01ePk80LGn^075o[01cPZd00P1`OjP05@1cP:X0M8:Y07=oY`1b
OZH0LGfU079mYP1cNjT0LGbZ071kZ@1/NJH0KWb[06io[@1[OJ/0JWb/06Yo[01ZOjh0KX2`06em[P1^
OZl0Kgn`06in[`020720/`090761]01cQKD0LXNd0725/P1]PZl0LXNd0766/`1bQ;80LXBd0080Lh>f
00d0L8:d06n0]01aP[P0KH6f06^0]@1ZOk@0JGjc06Z0/P1WO[00Igj_06Mk[P1YN[00IgR^0080IgJ_
00D0JWJb06Ib[P1XLk40JWJb06Qd[P0206EdZ`09069cY`1SLj@0HG>Q061cWP1QM9l0GW6K05ebV`1J
L9T0FVfG0080FfjH00X0FFZF05]/V01LKIT0FV^G05aZU`1LJID0FfRD05YWT`1LJID0FVNC0P1HIHl0
101FIHh0E6><055RS01BHhh2055RSP0^04iOS@1@HHl0CEf>04eMSP1;Fhh0Be^<04YKR@19FXP0BEN6
04QFP`17EH80B5J304ABO`12Dgl0AEJ204AEP010Dg/0?e9j045ENP0nE7T0?E=h03iDN@0oEGX0>U1e
03M=LP0iCg@0?4mg03a=N00kC7P0?Tak03e;NP0kBg`0>DUj03E5MP0gAWL0=D=b03A5L`0b@fl0<4=^
02m2K00^?fX0<45/02m0J`0`@VX0;d9Z02/nIP80:CaT0280;3iV02PjHP0Y>640:SUR02`kI00W=Ul0
:CMN02PfF`0W=EP09C=H02<cE@0T<UD082iA02@bE@0U<eH0935C02@^D@0U;e<09S1D028/D00N:dh0
8BeC01d[D00O:e407BQ;01hWB00M:4H07BQ401lZAP0L:d806bLm01/X>`0F8c@05R8b2Oooool000Oo
oooo034061`U01HK8@0I7R80720S01PL7@0J7Qd07R0O01/M6P0K7AP06ahF01dP5@0N8Q@07B4B01lQ
4`0L7Q406Q`?01TK400M7QH07B0I01`N6@0K7AX071dO01TJ7P0M7R<08B8W020Q9P0R8bP07QlT02DU
:@0];Bl0<S8b03@d<P0j>SP0>S`g03`n>@0]<R/0:RlX02Xb9`0/=2T0<3P]02lg;00]=2`0;cH_038h
=00e>CP0=SXk03<d>00a<SH0<c@i0080;Rdc03<0CdiD05]JH01EE5X0A4=903Dd?00i=d80>cU403dk
B@13@U80BTQM04U:G`19Bf@0J6V507b0W@28SJ/0SiBd096G]`2?V;D0TYfi096O^P2BX[`0TJ6j09:T
_02DY[h0TJFm08nS^`2CY;h0UZO309NV``2JZLP0VJK609RUa`2GY<H0VZO909fZc02P[Ll0WJ[<09f[
cP2NZ]00VjW>09b/d02HZ/h0VjgA09RZcP2I[M00V:cA09V[d`2K[MD0W:_D09^Ze@2KYmL00P2LZ=X0
5@2KYmP0V:CD09NUeP2HY]L0V:CD09NUe02EXm00UZCA096Oc02<WLP0RY_608NI`@25Ukl0Q9Jl086C
^@20SkH0Ohbf07j:]021RKL0OH>e07f2^@0207^0^00B07Qo]P1hP[L0M82d07N3]@1dP;00Lgn_071m
ZP1bP:d0LH2[07:1[01cP:`0LWn[079oZ@1aOZP0LWnY06mlYP1`O:H0KGZV0P1/NJD00`1[NZD0JgVX
06QiY`0206QhZ@0<06IfY`1YNJX0JGNX06]iZP1YMjP0JgVZ06UgZ01WMjP0JWZ[06]mZ`1YOZ/0K86^
0P1ZOj`03`1/PJh0KhBc0763/`1aP[H0Kh2d0721]@1bPkT0Kh2h06]n]P1YO[D0Igbc06]n]P1XO;40
IWb^06Qm/00206Mh[00C06IgZ`1WMZd0I7>/06Mc[@1ULJd0J7B`06Ib[P1ULJ/0IGB[06AcZP1QLZH0
HgFW065cX`1OLIl0GW6L05a_VP1KLIX0FVfE05Q[T`0205U/U00905Q[T`1HJY80FF^C05Y[UP1JJI80
FfZA05YXS`1KIhl0G6R>0080FVJ>01<0FVR?05MUS01EI8/0DF6;051QS@1AHXh0Cf2>04iPSP1;GHd0
C5b=04eMSP1:FXd0Be^<04UJR018FHL0BEN404QGPP19EX80B5F10080AUEn01P0@U=n04=DO`12E7`0
@5=k045DO00nDWL0?e=h049EO@0nE7/0>e5h03Q>M@0gCGH0>U1i03i?N`0kC7P0?Tai03a:N@0mBgX0
>DYh03E3LP0f@g80=d=c03M5M00a@W020352KP80<45/00D0<D9]02hoJP0^@FT0;T5Y02/nIP0202Tl
I00802HhH00V=f80:SUR02PgH00U=5d08c9I02PfF`0U<eH202@bE@06028`D`0Q;e808c5D02<aE00S
<5<0935D0P0S<5<2024_DP0=01`/CP0K:dd062Q:01/WBP0L9TT07BQ801`WA@0M:4H07bY601hZ@P0G
8SP05R4g01LR=P09ooooo`001oooool0100?4QT03a8G01TM800I7A`201/P700b01dO700P8Qd0824K
01lQ600N8AH05a/=01DI2`0I6`h06Q`A01/N4`0I71405aXA01LJ4`0N81/07b@P01lQ800O82807QlQ
028S9`0N7b<08R<W01lS9P0/;S80=3Di03@e=`0c=3H0=CLf03Li=P0e>S@0;C@/02Xa:@0[<RX0;3<[
02/e;00/=Rd0;SP`034j=`0c?3/0<SLj02`a=@0Z;C@0;2lh034d?@0Y:CD0<30l05iNJP1eMGl0De5L
02XY<@0X9S4203Tg@P0T03XhA@17AE<0CDYK051?H@1SHGL0PH6I08J8X@2<TZX0TINa09>J]02AVk@0
Tine09BP^02BXKP0Tj:g09FV^P2FY[d0TjFk09FW_@2FZ;h0UJNo09NY`@2GZ<80VJW309NW`@2HZ<80
V:O409^Zb02LZlX0WJc;09b/c@2LZ/d0VZ[>09^[c@2J[Lh0V:_<0P2H[<d07@2FZ//0V:[>09V[d@2I
Z<l0VZWB09^Xe02KZ=D0VjGF09ZTe@2HY=@0UZCE09FSe02EXm80UZCC09JTd@2BXll0SYo:08fPbP2;
XLP0Qig208JL`@26WKl0PYZl086H^P21TkT0P8nf07n=]01oRKD0OXJg0080O8>g00D0NH2d07Mn/P1c
OK00LWb]07An[`02075nZ`80KgbY00P0KW^X06ekZ01^O:T0JgVX06ajY`1/OJT0IgVR06QjXP80IWRP
00P0JGRO06IeW01XMj80IWBQ06IdX`1ULj80I7:Q06EcXP80IG6Q00H0IgBQ06EbW`1TLIh0HFnL06=b
W@1QLYd2061cW@05069eX01RMj80HgRU06IkZP1WO:/00P1ZO[408P1^P[L0KH2h06Ym]`1ZOKL0K86j
06Yo]P1WN[80J7ba06Ij[@1XNZd0J7R[06IfZ@1WMjX0IgBY06QeZP1UM:/0Hg:[06Ac[01RLJP0Hg:Y
06AdZ01QLJD0HW:V065bYP1PLZ@0GfnP061aW`1ML9/0GG2J05]]U@1LJi80G6b@05][S`1GJHd205]Z
T@0605YZSP1GIh/0FVZ<05IVR01EI8D0F6N60P1GIXL02@1FI8L0EfF805ATR01BHX/0CEj:051SSP1=
Ghd0Bef=04YLSP0204]MS`0504]KS01:FX/0BeV804QFQ@18EX<00P18Eh801@19F840AeIm04MFO@14
Dg`0A5Ao0080@U=n0140?e1k03i?N`11DWh0@U=o03mBO@0mCgd0>Taj03I;MP0jCgX0?Tmk03a=N00m
C7L0?DYg03]8M@0hAW<0>DIc03I3L00203E2K`0303A2K`0a?fh0<D9^00<0<45/00P0:ciX02PnI@0Y
?fH0:T1U02a2I`0W?F809CUN02HiH@8093IN01d09CIL02@dF00V=5T09cEH02LaE00X<UD08c1B02<`
D`0R;e808BeC02@]EP0S;eL08bmI024^F00N;E@07BaC01T[D@0G:Dd05RU:01PWB@0H9DL06RM701`W
A@0K9T@07RM401dV@`0K8Sh05Qdi014H=009ooooo`001oooool09@0D61/04QHG01XL6`0M7a`07R<M
01PM5P0N81/082<L02@W800E60l05A/A010F2P0?5@T051L>01LJ4@0I71<051X@01@G3P0G71D07B8K
02<X8@0U9b807R0K01lQ7P0S9B808R@S02<U900Q8b80;c4`038c=@0a<S@0;S8a02d_;P0]<Rh0;S@`
02`c;00[<R/00P0]=2d07@0a>c<0=3Xf03@m>00i@T40<CTk03<h?00Z;cD09RXc02/^=`0Z;3P0;c4m
04U;F01SHW00CDaJ03LfA00f=T80?3Y703dmB@10?dd0ATEC05=BHP1PGg40NGN<08B5VP2?T:D0SI:X
08nEZ`2AVJl0TIV`0080U9nc00T0Tj2c09BQ]02FXkH0U:>f09BS^02FYKX0V:Vm09VZ_P2HZ;l00P2H
Z<40102GYl00VJW309ZZa02HZL<209RYa@0809RYa`2J[Ld0VJW;09RZcP2I[<d0V:_<09N[c02H[<d2
09JZb`0P09BVbP2GZLl0UjK=09RWd02GY]40VJSC09NTd@2FX]80UJ7A09BRd`2CXm@0Tj7@09:Sd@2>
Wl/0TJC?08jQb`2<X//0Rj?908RPa02:X/H0Qio108JN`027Wl40RIg208NI_`27U[d0R9Bo08:=^`20
R[/0PHVj07j6]`1lQ;D207N2/00507R3/@1dOj`0LGj[06mlZ@1_Nj/00P1/NZT03`1ZNjT0JWZ[06Qj
ZP1VN:H0IWVS06IiX@1UNIh0HgNJ06AfVP1UMIT0I7BH06=aV01ULI/0HfjK069]VP0306=^V`0A06A`
VP1RKYP0HfnI05m/UP1NK9<0G6^C05m^U`1KK9L0GFjJ05a_VP1OLIl0GW>R065eY`1RMZT0HWJ[06Ii
/@1XNk<00P1XNkD0201XOKH0IGZa06Ij[`1WNjh0IGJZ06MiZP1TMZH0IgRV0P1XN:T09@1UMJP0IGFY
069cY`1SLjL0H76U065aY@1RLZH0HG6U06=dZ01PLJD0Gg6S061`X`1OKj00GFnM05e_VP1JK9@0GFbC
05e]T@1KJhl0EVR<05][S`1JJXh0F6R:05MWR@1IJH/0E6B505MVQ@1HIhH0EFB3059SP@1CHX<0E6B6
055QQ@1CHXX0DF:=04iORP1>Gh/00P1<GH/01@1;G8X0BU^904YKR@17F8@0BEZ60080BEZ501P0@eEm
04EGO`15Egd0AUQn04AFO013EG/0@E=l04=DO`0oD7`0@E9n03i?N`0mCWX0@55m03a=N@0lCG/0>daj
03U<M`0jCGP0>4Ud03Y<M00jBG@0?DYd03Y7L`0hAFl203A1K@0_03=0K00d@Fd0<d9]0390K@0b@F`0
;SmZ0312JP0^@6P0:ceU02LkH00W?F80:CeP02HjG@0U>E`09SYO02@hG@0W>Ed08cEI02DeE`0S<e@0
8c9C02LdE00W<U009S5?02D`D00R;Dd09BmC02D^E@0Q:U<08R]F01hYEP0L:EH06bYE01`[EP0K:U<0
5RQ@01PWCP0G9T/05B=601TVB00I9TH05b9201PQ@00N9D807BA001DL>00A63@02Oooool000Oooooo
01T05AXF01HK5@0J7AH07B0I01lR6@0M81L08B@M02DX8@0R9Ah061dF01PO5`0F7AD051/C01LN5P0D
6a<061lG01XR5`0L8QP07B<G02@Z7P0Y;240:B/N02LY700W:ad09RXL0080:R`Q00T0;RlW038c;00]
;bX0;c4/02d_:P0Z;b/0;C8^02le<@0]<bl00P0_=300900a=S80<CLc03Di>00h?Sh0>T1003Xo@P0k
?T<0=cXo030e>`0_=3X0?41904Y=EP1BE600DE1N04E4E011@580?SmA03lnD015AUP0ADIJ04Q9GP1I
Fg00NG^B08R=X`2;SjP0SY:[08nE[@2BV[40U9^d09:M/`2EX;@0U:6d09JS]P2GY;D0U:6b09RS]@80
VjJj00H0WJVo09^W_`2LZ<80W:O309^Ya02JZ<<209^YaP0709VXa@2GZ<H0V:_909JYa`2G[</0VJc=
09JZb`0209N[c00609JZc@2H[=40V:cA09N[d02HZ]00V:[B0P2FZ=0209JWdP0<09FVdP2FYM<0TjCB
09>TdP2BY=80TZ?A096Sd@2=X</0SZ?>08fSc02;XLX0RZ;80P2;XlL05029XLD0R:3608RNa@2<WlT0
RIc608ZKa`2:VLT0RIO808JBa027TL@0QI2n07n:]`1lR;80NhNa07R4[P1fPZ`0MH2]079oZ`1aOZ/0
KWb[0P1XNZX0201WNJ/0HgRW069gY01QMj00GWBI05U`TP1PMI@0HGBD0P1SLi@0101SL980IW2D06A/
T@1UKYD306I_UP07069[TP1TKI@0I6fD069[TP1UKYD0Gf^D05iYUP0205eZU`0N05i/V`1RL:40H72S
065aY@1OKj<0GFjT061aZ@1VMjl0IgR`06Ul]01XOK@0IGZ_06Mk[P1WNjd0I7VX06IkY`1UNZD0IWVT
06EjY@1WO:T0IGZY065fY@1OLjD0HgFW061dYP1QLjD0H7:T05m`Y01RLjL0H7:T0P1OLJ<06@1NL:00
FVbJ05Y]V01KKYP0GVnJ05a^UP1KKID0FVjC05a^TP1JK900EVR<05MZR`1EJ8T0EVJ805MUR01IIhX0
E6B6055TQ@1DI8P0DfF9055SR@1BHHP0D5n605=RR@1>GH@00P1?GXL01@1@GhP0CUf604aKQ01:G8@0
BEb40080AUYo00P0A5Qm04QLP@15FGh0@eMl049FN`13Eg`0@5=k045DO080?e9l00L0?U5k03a?N@0m
CWT0?4eh03i=MP0lCWH0>Tad0080>D]c00D0=dU_03U;L`0iB6l0=TE^03I5K00303E4K@0303A3K00b
@FX0<D1Y0080<T5X0100<D5U02loH`0X>5`09cYK02XmG@0Y>EX0:3QI02LjF`0V>EX09cYK02LgF00V
=eD09cIC02DeC`0T=4d09CE>0P0V=D`05`0T<T`08S1;02@_C`0S;E4092aC024ZE@0P:5H07BQF01`V
E`0J9UH06bMG01/YEP0K:5@06RMA01HTB`0H9TT06BI801XUA@0H8d406R@o01`S?@0G7CD05Q`d00Wo
oooo0007ooooo`0n01TL5@0M81T07b8I02<V7@0U:1d082<J02<V7@0U:R<092TS01hT7P0M91d06R4J
01TS6`0G8AT061lH01LN5`0H7aL072@I028X700Y;b40:RhP02``8@0/<1l0:RhM02/_800_<B<0<cDX
03Hh:`0e=bd0;S4Z030c;00^<2/0;34]034f<P0f>cL0<SLc03<h=00a=C@0<cLf034e=P0h?3l0@dM:
0495BP0e>3d0<cHm03Dh?`0^<cT0<cPo059EGP1KGFT0DUAP04U8F018BE/0BTeN03`oDP0m@5<0?45E
03i3F@12B600JW2808jF[@2<Tjd208jE[`0K092G/@2CVk80U9jf09BO]@2FXkH0V:Fh09NT]`2FXkH0
V:>g09ZU^`2IY;X0VZBm09bV_`2MYl80W:G209jYa`2HY/<0VjW609VWa02KZLH0V:W709JYa`2FZlP0
UJ[709N/b@2FZ//0Ujk>0080UJc<00H0VJoD09R^d`2G[M@0UJ_B09V/e02J[MD209R[d`0c09NZe02E
Zm@0UJ[E09R[f02DZMH0TZOD092UdP2AY]<0SjC?092Ud02?YLh0S:;;08nUc02>Y/`0Rj?708RPa029
XLL0R9o808RNa`27W<L0RI_908RJbP29V//0RY[=08^IbP2:V<L0RYO408ZG`@23TKP0PY2g082=]`1o
S;H0OHZd07f:]P1lR[L0MHJd06n1/@1/PK00Jgf_06EjZ@1TNJH0HWNQ05Y`U@1IL980Ffn@05a_S`1M
L900HW>A061_SP1SKI00HVb?0080HVb@00@0I6jB069/T01QJY40HFZA0`1RJi80501PK9D0GfZG05eX
UP1KIiL0Gf^K05e[W01NJil0G6bO05QXW01KJil0G6fQ065bYP1SM:P0IGJZ065eZ01TN:X0Igb[06Ik
ZP1TNJH0IW^V0P1UNj@0601UO:H0I7^W06=jYP1QMjH0GWBS065gYP1MLj80GgBS05icXP1OLjD0G72R
05ebX@1LLJ00Fg2O05Y_WP1IKY/0F6fJ05Q]V01IKYT0EffF05U_V01GKIH0F6jE05Q^T`80EFV>00l0
EVZ=05=WRP1EIhd0EFN=05=UR`1BIX/0DVB:05=UR`1BI8X0DF:8059PQ@1CHHH0DEn2055OQ01@H8@0
0P1?Gh<0301<G800B5Yn04QLO`13FW`0A5Qk04=JO016FWd0A5]m045EN011Eg`0@UQm041DN`80?e9j
0100@5=k03iDN`0jCW<0?4if03e?M@0nCG@0>dec03U;L@0iBg<0>4Yb03E8L00hBg<0=dYb03I9L@0d
Afl0=TQ`0P0bA6`02P0bAV/0;d=V02m1I@0b@VH0<T9T0310H@0^?Ul0;3]L02`kFP0_?Ud202`kFP0R
02/jF`0Y>EX0:S]I02LhEP0Y>5D09cM@02DeCP0U=D`093E902<dB00U=D`09cI=028`BP0P;T/082e?
02<]D@0R:e@082aF01lZE`0N:EL072UF020]FP0K:5D06BIB01XWD@0I9dh05bE801PWAP0J:4D06bM1
01TU>`0O:Sh06B4d01PO<@Wooooo0007ooooo`03028S7@0S91h08b@L0080:B`S01808bTO028X7P0V
;2809BXS024W800Q:2407bHO01/R6`0G7AT06AhH01LL5P0G71D08bPQ02H/8P0W;B40:c4S02dc9@0_
<b@202da8P0:038d9`0h>Rl0>3/`03@h<00W;2H0:RlY02`a:`0/;R/0=3Hc03Dg=P80<cDd02L0<S<e
038c=`0Z;S40:Bhb04mDF01FFf40C55G04iAFP1=D5T0A4M@03doBP1ADel0IfUf04i@G`14AUD0AdYK
04Q>GP14Bed0Ae1Q03e8FP1:EV`0LgnG08JBZP2:UZh0RIF]08^G[`2>V;40Tiff09>N]02DWk@0UJ2f
09NT]`2CX[D0Uj>k09JR^P2HY;h0VJFo09ZU`@2KY/@00P2JYL<03`2HXl40V:G509bYb@2HYLD0VJS5
09Z[a`2GZ<H0UJS609BYaP2FZlP0UJg909B[b`2C[</0TZ_:09B]c00309F]d@0809J^dP2DZ]40UjgD
09J/e@2E[=D0U:_D09>Zd`2BZm@2096Zd`80SZO@02L0SJK?08fTc@2;X//0RZ;808RPaP2;XlT0Rj76
08RPa026X<<0Q9k308JOa`24Vl@0QI[508:Ga022UlH0QIS808>Ea@26UlD0R9W508NH``27VL40Q9Jl
08:D^025U;/0QIBm08>B^`23T[d0P8jk07j<^`1kS;X0NXbj07N7^01dQ[H0LH>a07:5[`1[OZH0JgnT
06YnX`1XNYh00P1UMi/04@1SMIT0I7BH06AbU`1TLYL0Hg6F06=_U@1ULIT0HFfG069^V01OJi<0GVZB
065]U@1QKYT0GVfH05e[V01GJ9H0F6VG0080FFZH0140FFVJ05]/VP1IJYP0F6ZH05Y/VP1MKY`0GW2N
061bX01RMJ00I7NR06MjY@1UNj@0I7^T06MnZ01TNjD0HgbU061hY002061hYP0905eeX`1OMjD0GGFQ
05ieX@1MM:00Fg:N05acW`1IL9`0F6nK0080FG2L00D0FG2J05I^VP1DK9P0EFfI05I^VP0205=^V@08
05A]UP1EKYH0DVVB04iVS01>IHh0DFRA055WT01@IXl204mUS00o051SR`1AI8`0D6>;051PR01AHHD0
Cen304iNP01?Gh40CUj004ePP@1;GWl0BEam04MJN`15F7T0AUYk04EHN@13EgP0@eIg04=GN013EGT0
@eMj03mENP0oDgX0@UEm03iBM`0lD7D0?U9g03a@L`0mCgD0?Ted03Q:L00jC780>D]c03U<MP0gBWD0
=4Uf0399M@0aB7@0<TUc02m8L@0`Ag00;dM]02m7J`0_AfT0;TEU02a0H@0^@F40;SiO02hoG@0_?U/0
<3iK02lmFP0^?5T0;CYJ02`iF@0[>UT0:CQG02PgEP0W=UD093EA02HgD00R=4`08C=900808SA:01P0
8SA<02@dC@0P<D/0835=020aC`0O;Tl07Ra?01d[D00O;E807B]B01l]E00K:E0062I=01PTC00I9D/0
6BI801PWA00H:48062Po01LV>@0K:cX06RPc01<P:@0B7bL9ooooo`001oooool0>P0V9R407b4K02PZ
8@0]<2L0:2hT028X7P0P9Q/08RPM02<Z7`0U:al09BXO01/O5@0H71<0824K028T7@0Q8a`08R@M02h`
:P0`<b/0<C@Z038g;00a=B`0;S<Y02X]900`<RX0=CL`03Hj<`0e>c@0;S<]02H[9P0V:bD0;2hY02l`
:`0a<Bh0<Bl/02l]:`0c<300<Rd_02lZ;00k=SX0=C4f03Xi?@1cL7L0QXN=07alQ019Be80?d9:05II
HP1DEf00B4]F03@iA@0h>dP0BDeM04A;F`17D640Ef9d06UfR@1oS:8208FBZP0F08VE[P2=Uk40SYNa
08fH/`2?V[<0SYZa09:O]@2DX[L0Tj>f09BT]`2FXkX0UZ>l09FS^`2FXkh0UZ?009RT``2IYLD0UjC4
09RUaP2GY<D0V:K709JUa@80V:S80100UZS709JWaP2CYlD0UZ[809JZa`2EZLT0UJ[:09J[b`2EZl/0
TjW:09F[c`2EZlh0U:_?09:Yc`2BZM00T:O?0P2AZ=007@2AYll0TJSA09:YdP2AZ=80T:OB08nVd@2=
Y<l0SJG?08^Sc@2:X//0RJ3:08VPb029WlH0Qik508FMa@25W/H0Q9g708>La`23V/P0Pi[908:Ib021
UlP0P9G5086GaP21U<@0PYK408:E``21UL<0P9?00080Oi?101P0Oi;107f@`01oSl80OXo107j?`01m
S/00OHjo07^<_01jS;X0N8^g07B7/P1bQJl0LHB]06eoZ01]P:T0JgjW06QkY01YNZ@0IgNP06EeWP1T
M9`0Hg>I061`U`1NKYH205m_U`0605a/TP1LK940G6bB05a[TP1KJYD0EfNB0P1JJYD06@1IJI@0FVZE
05UYU@1GJI80F6ZC05Y/U@1KJiH0FFVD05a/U`1PL9/0HW:N06=bWP1SMJ40HgFR06=fYP1QMZD0HGNX
05meZ01NMJL0GWBW05abY@1LLj<0FW6P05]bWP1ILI`00P1IL9/0301IL9X0F6nI05Q_V01GKYP0E6bE
05A]U`1CK9P0DVbG055ZU@1AJY@0D6VD04mXT`80D6RA01@0DFN?051VS@1@Ihh0DFR=055VR`1?I8T0
CfB804mRQP1>HHD0CF6404ePP`1:GH40C5f104aMP01;G7l0BEan04ULO@17FW/0BEal04MJN`80B5Uj
00d0A5Ig04IGN@14EgP0@UEf04=ENP12E7/0?U9h041DN`0oDWT0?U9f03a@LP0mD780?Dia0080?De`
02H0>d]^03U:K`0iBW00>T]d03Q9L`0dAg<0<TEa0397L`0bAg80<TQb02e4KP0_AFh0;T=Z02a1I@0[
@680;CmQ02hmG`0]?Eh0;SaM02llF`0a?E`0<3]J02ljF00^>eP0:cQG02PgEP0Y>5L0:3QH02DfEP0V
=UH093ED024aD00R<E0093=B02<cD@0R<E408C5@028aD08082m?01<08Bm@01d]C@0M:d`07Re=01`Z
B@0K:TT06RQ801/ZB@0K:4P06BI401TW@`0F93h05RDl01PV?00K:C`07B/j01DT;`0?7BH04AlW00Wo
oooo0007ooooo`0i02<T7`0O81/0:R/U034d;@0X:b@05A/A01/N5@0J81@07B<G02L/7P0`=2D08R@F
024S5@0[:al0=3@X03De:`0W:200;BhV02lb:`0b=Bh0=3Tc03<e<00]<Rh0<38_02db;P0/<Bd0:c4]
02`e<00[=2l09B`U02L/9P0Y:bH0;2dW02h]:00^:bH0<2/W030X9P0b:2L0>Bl`040f=`0n<cL0E4U=
08f7R`1iM7X0H5mT03Tj?`0Z;C80<SLl034h?P0a>T40<ca504=;EP1BFVL0GfQg07IoT021RI`0PhjR
0080Qi:X00X0Ri:/08jE/@2BUkD0T9Nd09:I]P2BW;L0TIfe092N]02?X;@0TZ>g0P2CY;P0@@2CXkX0
TZ:i09>U_@2CX[l0UJC309NVa@2EY<D0UJ?609RVb@2KZL`0V:K909RXc02GYl/0UZK809JVa`2CY<80
Tj;109JUa02EY<D0UZG609BTa@2AY<@0TjK709BXb@2AYLP0TjO<08jTb`2?YL`0SZC;08bRa`2AY<`0
Sj;:08jQb@2@X//0TjC?09JWd`2CY]40TJ?A092UdP2>Xm00SJ;=08ZOc029X<X0R9o808FLa@24VlD0
QIg908:Mb021W<T0PYg<07fHa`20VlX0OYS7082Hb021UlP0OI?507jBa@1oTlP0OY?807fBa`1kT<D0
O97607^@a@1jT<80NXk30080Nho200<0Nho107R<_P1hSK`00P1hSKX03P1iS[T0MHZe07F:]@1dRK@0
MHRc07>6/@1aQ:l0L86]06n0[01_P:/0KGjY06QkX`1SMi`0HWJI0P1NLYD01`1MLI@0Ffj?05]]SP1K
Jhl0FVR?05QVS@1HIHl00P1HIi004P1FIHh0EFB=05ETS@1EIhl0E6J>05ETS`1CHXd0EVF@05IWTP1K
JYD0FFZF05e[VP1PKj00GfnR05m`Y01NKj<0Gg>X05ibY`80GG6T0200GW:U05a`XP1KL9d0FVnL05U^
V`1HKIP0EfbG05Y_VP1GKIH0F6jG05M]UP1DJi@0DfZD05EZU@1CJ9<0DVNB059XT@1AIi00DFN>055T
S01AIHX0DFF8055UQP1?HX<0D6>4051SP`1?HX80D6>304aOO`1=H800Ben004YNP@80BEf00180BE^1
04IHO016F7`0AUUj04QKO018F7T0B5Mh04MFM`19FG/0AeMi04ADMP10DWH0@e9i041BNP0mCgL0?U5i
03e?M@0kCG4203]>K`0803Q;K00lC6h0>4QZ03U9J`0kBfd0>TY/03Y:KP0hB6`203Q7KP0d03M9L@0d
AG00=4E`0313K@0`@6/0<3mX0350I`0]?6<0;SaS030nH`0^?5l0;CYL02llG`0a>eh0<3YM02XgE`0]
>UX0;3UI02`kFP0[>UT09CAE02DeEP0U=EL08S5E024]D`0S;eD09C5G028^E00Q;E<09RmF02H`E00S
;E4092iA02<`DP0N:d/07BY:01d/B@0L;4H062Q201LW@@0I:D806RQ201TX?`0H9ch06bLo01XV?P0G
8c/072Pn01dZ?@0F8c@041`/014M:`Wooooo0007ooooo`0m02LV8P0T8al0;2/W03<b;P0`<B`08R@O
02DV800V:B009bXO02``8P0d>2L0<C@S02lb8@0`<b80<cHU03@f:00[;b40;2lV02lb:`0_=2d0;cH_
02ld<00]<c40:bl^02L]:`0V;2X08b`Y02Ha:`0V<2T092/T02T`:@0Z;bP0;2dX02d/:00_;RT0<c0[
03<^:`16?Ch0C4=604i5B01OEU/0IEaQ06eVK@1GEEX0@D9703Tl@`0i?T@0=cm503i9C`0jAdl0>dQA
04UCG@1TKWX0N86@08B=WP29TJ@0SiF[092F[P2>U:`0TINa09FK]@0209:I]@0R09>J]P2BW;D0Ting
09>P]`2@WkH0TZ:i09>S^P2CYK/0TZJn092T_@2AYL00UJK209BWa@2EZ<P0TjK709JVb02IYl`0W:[?
09VWc02HY/d0UZC909RVb`2EXlH0Tj;309RUa`2HYlP0UZG609BTa@2AY<@0TjS7096UaP2DZ</0TJG:
092Vb`80SjG<02H0SJ?808bSa@2?XlP0SZ;508jPa02=W/<0T9o609:QbP2>WLH0SYg808bMb02;W<L0
RIc608ZMb026VlH0QYg608:K``21V/<0Pio7086NaP1nVlD0P9g707jKa@1nVlL0OiS608>Kb@20V<H0
Pi_;086Gb@1oULL0P9C907jBa`1oTlP0PIG:07nCaP20U<H0OI7407b@`P80O97001@0NHnn07R?^`1h
T;`0NI:k07J?]`1fSKH0MHbf07J=]`1dRKH0LhRe07R:^01eQ[80LhB`07B5/01_PZ`0L8>[06]oY01X
Oj40I7^M06EiW080HGFH00<0Gg:E05a^U01MK9<00P1HIi001`1IJ940EfJA059SSP1DHh`0Df:;05=U
S@1AHh/00P1@HXX03P1?HHT0DFB<05=US@1EJ980EfRC05Y/V@1OLJ40GFnO05icXP1LLJ00GG:Q05eb
W`1NLj00GW2P0P1NL9h06@1OLYd0GG2K05a_V@1JKIL0FfjH05MZU01JKIL0F6ZB05MYTP1GJ9<0EVVC
05EXTP1CIY00E6NA05EXT01DJ8d0DVB805=VQ`1CIXH0DFB4059RQ01@Hh@0Cf:2051UQ01@I8D00P1<
H8401@19H8<0Aef204EKP019Gh@0BUf50080AEUn0P15Eg/05@18F7X0BUUj04MFM`16E7L0AE=f04ID
N@12DGP0AE9l049ANP0oDGT0?e1g03a>M00mCg<0>Ta`03U<K@0hC6d0>Da/03M:JP0hBf/0>Da/03E8
J00203I9JP0f03A7J00fBFX0=TQ/03E7K@0dAV`0<49X0351J@0`?fP0<D1W02lnI@0`?VD0<T1W034o
I00`?V40<CeS030mH00]>U`0;3UK02djG00]>UX0;S]K02/hF00W=5@0:CQG02LfE`0T<U@092iA02H`
E00X<UH09c5E02D_D`0V;U<09bmD02D]DP0Q:dl08RmB020]C`0P;dh072e901h_B@0I:T@06B]301PZ
@00I:Sh05RLk01TX?@0J9Sh06BDm01PR>`0K9Ch06RDk01PS=`0B6Rd04a`]2Oooool000Oooooo01<0
9b@O02/X8`0b;bX0=S<^034`;00^;BP0;2`T02/]8P0/;R40<3@T034f8P0`=B40<SLS038e8P0c>2@0
<SHU02D[7@0Y;240;cD[0080;C@]00<0;C<a030f=00Y;bd00P0S:BL08`0Q:RL09BhY02L_:@0Z<BX0
:c0Y02/^9`0[;2L0:RTU034`:`12?cX0>38b04a6AP1/IVP0KVQ/08ImPP1UGVD0<Rdc03Ld>`0j>T80
=CQ1034e@00a>D80A4iH045=F@1:F6<0HVil07N3T@1lR9P0QhnR08^CZ02<U:T0SiF]08jD[02?Ujh0
TYVc0080SiVb01D0TYbe096K]02CWkD0TJ2g092P^@2BX[/0TZBl096U_P2@Y;d0SjBo096T`P2CY/H0
TZG509BWb02CYLT0V:S<09FUb@2JZ<l0V:K=09VWcP2GYLX00P2EXlP09`2FY<L0UjG809BRa@2GYLP0
UZK809:Tb02AYLP0T:C908nSb02>Y<T0SJ?:08nUc02=XlX0SZC908fTaP2?XlP0Sj?608bP``2AX/H0
Sik5092OaP2@WlP0SYo:08fNb@2<WLP0S9o908ZMb029W/T0R9o908FNa`23W/T0PIk808BQb`20X<L0
OIg607jNa`20WLL0OY[5082Ha00207jF`P80P9K501h0PIG707nCa@1mTL<0O93207bA`01mT/40OY?2
07bA`01kT;d0N8nk07J=^@1dS;P0KhZe07:=]`1aSKD0LX^d07::]P1dR[T0LhRg07:7]P1dQ[H0MHJd
07>4/01dQK40LXF_07>4[`1aQ:`0L8BY06j2Y`1/P:D206UmXP0E06MjX@1TMYh0I7JN061bVP1SLY/0
GFnG05i_VP1LKIP0G6^D05Y/U01KKID0F6Z@05=US@1DIX`0D6B905=WS01AI8`0DVF=05EVT@1HJIH0
Gg2N00<0GW2N00P0Gg6O061cWP1ML9/0Gg2L05m`WP1OL9`0GVnK05a]V@<0FV^G0P1IJYH00`1JJ9D0
FFRC05QWTP0205EVT@0605AUT01CI8l0EFN?05AVS01EIHT0DV:40P1EIHH04@1BHX@0DF63059UQP1?
HX<0C5n004aPP`1;Gh80BUj404ILP`17GHH0AUb504ULQP16FH<0AER004QJPP17EWd0AUEl0080AeEj
00<0AE=h04ABN@13DGP00P13D7X01`12DGX0?e5i045ANP0kCG<0>Tab03a>LP0gBfh00P0jCW4303M;
KP0A03E9K00fBVd0=TQ/03E7J`0fB6`0<dEY0394JP0d@fX0=DA[03I4K00c@6X0<3iU034oIP0`?6H0
<SiV02dkH00`?6800P0_>f4302`iG00802hkGP0[>5X0:SMG02XhE@0Y=e@09cEB02HbD00W<4l202Pa
DP0I02L_D`0V;U809RiB02H^D`0T;5408BYA024^D@0N;4l06bY;01`]B`0J:dL05b]401PY@`0G:D40
6B]101LX?00I:3l062Ln01TU?`0J93l06R@m01/U?P0I93X05Qhc01HN<@09ooooo`001oooool00`0d
;bT0=C0Z03Da:00203Te;00C03Ld:`0f=2P0<S0S038c8`0c=b@0=3TU03<h900a>B80=3TS030h8`0_
=R@0:C8Q02/a9@0]=BX0;C@]02Xa:P0[;bh0;S8a02/_;P0302<W9P0T02<X900Z;RP0:R`W02`]9`0/
;BD09RDP024P6`0[:2<0CTU506IPH01SGEd0KVEX06aSJ01SG6<0E4eE03Xd?P0j=d80=CE102h`?@0`
<d80<CQ8059KK01AG6h0DUe_07B1U024TJ@0Pi2S08FBY@28U:X0RYJ/08^G[@2=VJl0TIbb092L/P2<
Vk00Sijc0P2>WK802P2?WkH0Sing092Q^`2=XKX0T:Bm08nT_`2>Xl00Sj;209:Ua@2DY<H209BTb003
09BSbP2FY</0VJO>0080V:K;00@0UZK:09NWb`2EYLT0U:C80`2DXlX01P2EY<d0TjG=09>Tc`2AX/d0
T:7<096TcP80SJ?<00d0SJC=08^Sb@2@Y/d0SjG:08fSbP2;XLH0RZ3508jRa`2=X<P0R9k508NMaP29
W/T0QY_60080Qic701D0Qic908BKa`21VLD0PIW507nJa`1kV<@0O9W507fJa01iV<@0NY[307RH`@1k
Ukl0NiNn07RD^`1lU[/0Ni:k07fD_@1nUKh0OIBm07jC_P1mT[d00P1jSkX02@1lTKh0OI:o07^@_@1g
S[X0Mhfl07F=_@1dS;`0MHfm07::^P0207B:^`0307F9_01cQkX0M8Bh0080MX>g01<0MH>d07J4/@1b
Pjl0MH>`0762[@1_P:/0LH>[06n1Z@1]OjL0Kh2[06YlYP1XNjD0IWVS06EhXP1TMJ00HgJP069eW`1P
Lid0HG>K0080H7:H00<0G72C05Y/TP1HJY000P1GJHl01@1FJ900EfRC05MUTP1IIiD0FVRI0080GVbK
00@0HFfM069^WP1QKi`0HW2M0P1PKY/03`1QKih0GVbK05e[VP1LJYT0FFZH05UYVP1KJIX0G6VM05MW
VP1GIYL0F6JE05UWUP1GII80E6:?05ETS`0205ETS@04055SR@1BHHP0Df>705=QQP80DV270140DEn6
055OQ01AHHD0Cej5051OQP1;GHD0BUf704ULQ`16FH@0B5V704UJR017F8@0B5J304QGPP17E800B5>0
04IAOP0204E@O@0904=@O014DG/0@E1i049AN00oDGT0?e1j03]<M`0hBW80>Tee0080=dYb00H0>Dad
03U<MP0hBgD0=dYe03A5L@0eAW@203I4L@0703Q6L`0e@g00<T1]038oJ`0e@Vh0=T9]03A0JP0203<l
I@80<SUS00D0<c]R034iH00_=V00;CAN02dfG`0202hgH00J02dfG@0/=UX0;3MG02`gE@0/=E80:S=@
02PbCP0W<D`092i902H_C00X<E009Bi=02D^C`0R;4l07bU=01dZC@0O:e406BM<01/YC00I:D/06BU:
01TZB00I:4L06BQ501PWA00I9d8201PV@@0701LU@00F8Cd05b8n01TS?P0I8c`0620g01HN<`09oooo
o`001oooool0300d<BP0=c@[03Lc:00h=2P0>3HY03Le9P0h=B@0=cHT03Li900f>B@0=S/U03Dj9080
=3TS02P0;cLR02dd8P0]=2@0;38V02/a9`0[<2T0;S<]02db;P0Z;b/09BXV02<X900R9b<092TS02DX
8@0X:b@0:R/S02TZ8P0[;2@0:RXR038b:P0l>C80@3dh061LF@2DSXh0RH>505aFFP17@TP0=C0g038_
>P0g=D80=cI403LiB00o@U<0AT]O06]bQ@1fOY<0L7^A07^6W025TJL0Q92V0P25U:T05`28Uj`0RIZ^
08VJ[P2=W:l0SYf`08fN/02>XK80SYnc08jP]02=WkD0Sj6i08jR^`2<X[X0SjFm096V`@2>Xl00T:?1
09:Ua@2FY/P0U:;509FSb02DX/L0Tj760080UJ?600D0UZK809FUa`2CY/L0T:?409:Vb002096UbP06
096Tc02AY<h0T:?>092ScP2AY<l0T:7=0P2?X/d208bRb`0C08^QbP2;XLP0S:;908fSb02;XLH0RZ35
08ZPaP2:X<L0QYg608FLaP27W/X0Q9_708>JaP24VlL0PYS708:Hb@20V<P0OYK607fGb00207VEa006
07ZG``1jU/D0N9O307VF`01jU[h0NYJm0P1jU[/207^E^P0407^C^@1mUK/0OYFn07jE_P80OIBn00H0
OIC007jD``1oU<<0O9;307fCa@1iT<8207J=`@0D07>:_01fS;h0MXbn07B9_P1dR;/0M8Fi07F5^@1f
PkL0Lh>d0762/01bPjl0LX>a0762[P1^PJ`0K7nZ06j1[01/OjX0KGn]06j0[P1[OJ/206YlZP0606Ik
Z01UNZD0JG^Y06IiY01XNJ@0IgVQ0P1SMYh03`1QLi/0H7:J05i_VP1NKIP0GVbK05aZV@1NK9d0FfRJ
05]WV`1NJY`0Gf^M061/WP1RKYh0HFfM061]VP0205m[V`0=05m]W01NK9/0FVRI05aZV`1HJ9T0F6RK
05YWV`1IIY/0F6RL05ITV01FI9D0EfFD05EST00205ARS`0J05ASSP1BHH`0Df:=051ORP1CH8X0E66;
04mLR01@GHL0DEf7055NR01?G8H0CUf604mNQ`1;G8H0BU^704QJR016F8H0AeN804IFQ`18EXD0AeF4
04UGQ018EH80AU>004EBO`13D7d2049?N`0:049ANP11D7L0@U5h03mAM`0nCgT0>dag03Y<M00kCWH0
>Teg03I9L`80=dQd00D0>DYh03Q9M`0gAGH0=dEf03Q4MP0303M3M@0J03DoLP0b?6d0<C]/03@mK00e
?F/0=3]Y03@kI`0c>VH0<SIS038gH@0c>680<CER02heH`0[<f40;3AR02/cH@0]=V40;3EL02/eF00]
=UL0:S=B02/bC`0Y<4`0:C1:02H`B@0V<4/202@]BP0602<^C00Q;Th07ba>01h[CP0M:dh06BM<0P0J
:4d301TWBP0501LUB00J9dX06RM901TVAP0G94@00P0F94401@0G8T005b8n01TS?P0D6cD04QXa00Wo
oooo0007ooooo`06030`9P0f=RX0=3DW03Df9P0i>RP0=3HQ0P0f=B00J00f>280=SXS03@f800c=B00
=3HQ038e800c=R<0<C@S034e9`0_<RL0;S4X02lb:`0^<BX0;c8[02HY800Q91d08bPQ028X7P0T;240
9B/O02<Y700X;1h0:BdO02/^8`0^<2D0;2hS03@f:`12@c/0N7Mb0:f/Z01THf40>CTk03Th?@0a<3H0
<S8l03Dg@`0i>dP0=3M603`oD01AEVX0KW>707QmT`1mPi/0PhjT08>?Y`26TZX0QIB[08NFZ`26Uj/0
QIRY08NJZ`2:WJh0Rij_08^M/@29W[40RYbb08VN/`2:Wk@0SJ6h08^Q^@2<X[T0SJJl08nU_@2=Xk/0
T:Jn08nS_02BXkl0U:G309BSa02EY<D0UJC309BS`P2CY<80TjO2092U`02@YL80SJG108nVa@2>YLD0
Rj?708^Sb@2=Xl`0S:;;08^Pb`2>Xlh0Sj7?096Sd@2<W/`0SJ3;08bObP2:X<T0RIo608RN``29X<80
Qik008JN`027Wl80QYk408JLa@26VlH0QI_:08>IbP21VLT0PY[:0P21UlT03@1oU/P0P9O9082Gb`1j
U<L0NiO707VEa01jU/H0NIG407bGaP1iU<40NIBo07RD_01jU[h00P1hTkh02P1iTKd0NY:n07ZB_P1k
Tkl0NY:n07VA_`1lU<@0Ni;407bAaP1iS/<207bAb080MX_200H0MHZo07:8^P1dR[`0LhVk07:8^P1b
Q[T20724]P0906f1/`1^Pk80K8>_06b2/@1/Pjl0JH2/06MnZP1YOZd0J7f/0080J7b^0`1WNjh0301R
N:X0HWRY06AhZ`1UNJ/0J7Z/06IhZ01WMjP0IGJT06MeYP1ULj@0IW>W06=`Y080H6fT0P1OK:<05@1L
JJ00GfZP05aWW@1NJYh0Gf^M061/WP1OJi/0GFVK05m[W@1MJI/0G6RJ05]WV`1IIYX0F6RK05UYW01J
Ii/0EfBH05EUV01GIYL0EVBC05IST00205ERS`0H05AQSP1CH8d0DEj;059OS01CH8d0D5f:059OS01A
GX/0D5j;051MRP1<FhH0CEb704YKQP19FXD0BEb604QKQP17FHL0AEN504EGQ`13EHD0AEJ404AEP`13
E880A5:10P13DGh00`12DG`0@E1i049AN00203mAM@80?U1d00H0?4ab03]=L`0hBW80?U1h03]<M`0e
AW4203Q7LP0603U6L`0lB7P0>dEf03Q2M@0i@gH0=d5d0P0i@7H08P0h?gD0=Sec030jK`0a>Fh0<SY[
034iJP0a>FP0<SYX034hIP0`=fD0;SES02hdI00^=VD0;3AS02P`G`0[<F40:S5O02XaG@0Z<UT0;35G
02`bE00/<U80:2i;02H]B@0T;TT09Bm:028[B00S;4T07bY601h/B@0M:TX07Re>01/ZB`0I9dX201/W
C@0601TUC@0K9dl06RI@01TUC@0I9dh062I;0P0H9TT01`0F9DH052=401HS@`0G8Sh06R@o014H<P0C
6C402Oooool000Oooooo00d0;2hQ02``8P0]<B80<CHR030e7`0`=Ah0=3HP03Dg8@0f>R<0=3LQ034c
7P0e<b@0=38U0080<S<U00d0<C4U038d:@0c=2h0<c@^02ha:P0W:R<09bXQ02HY800U:1l09B/O02@/
7`0T;1d08RXK008092dL02P08R/J02L^7P0Y;Al0:2`N0454>@1gNW40N7Uc04]:AP0a<C40<34c038c
=`0a<SL0<cHm03<g@00n@Td0@dUE055GI@1RIgX0NGjB08B9W`28SZH0Q8jW08NCZ`26UJ`0Q9>Z08NG
[P25UJ`0QYR/08FJ[@2:W;00Qiba08bN]02;X;D0RIfe08^O]`2<X;P0Rj2h08fS^`2;Y;X0RZ>g102=
XkX06`2?Xk/0TJ:l096R_P2CY<00U:?0096R_P2@Y;l0SZ>n08ZR_02<Y[l0SJO208bV``29Y<80Qj72
08VSaP28X<H0Qik708ZObP29W/T0S9k<08^Mb`29VlT0Rig;08ZLbP2:WLP0QYc508FK`P0208JL`@0H
08BL`025WL<0QIc608FJa`26VlX0PYK808>IbP22VL/0OiK807nDb@20ULX0OiC907bCa`1nUL/0O9?7
07ZDa@1iULD0NI?407ZDa@1hTl80NIC207RC`01gT[l0N9?00P1eT;d0601fTL00MY6n07JA_P1gT[l0
MY6n07F@_`1hSl40MHc007N>`P1eR[l0Mhc307J;`P1cR;l0L8Fk0766^`1`Q[P0KhFg0727^@1^QKL0
K8Bd06n7]`1/Q;@0JHBc06^6/`<0J8>`0140J82^06Al[01ZP;40J7j`06Mk[P1WNjl0Ig^`06=f[P1U
N;00HWJ[05mcZ01UMZ`0IWN]06Mf[@1VMZX0IgN[06=cY`0206EbY`0:06IcZ01SL:L0HFjU06=_Z@1Q
KJL0H6fT05m/X@1QK:80Gf^O061/X080GVZL00@0G6RJ05iZW01MJI/0GFVK0P1JIYP0201GHiD0F6JG
05MUUP1HIYL0FVRI05IWU@1FIY80EfJA0P1EHX`02`1EHXh0DUn<055NR`1CH8d0E62@055MS@1@G8`0
D5j=051NS`1@GXd0CUb;0080Beb800H0BEZ504ULQP17FX@0BEb704QKQP13EH<204AFQ00904EFQ014
EH<0@U>1049DPP11DX00?E1k041CO@0nDG/0?E1h0080?U9g00h0?E5d03a@L`0kCW80>4Y`03Q;L`0j
C7@0>D]c03]:L`0iB740>TUb03Q5L@0jAG80>d=b03Q0K`80>D5b00@0>3mc03LnLP0i@7@0=Sea0P0_
>F`06`0^=FT0<3QY030hI`0a>FP0<CUW034hIP0_=V@0;cEU02hfI@0/=6<0:S9Q02X`H00Y<5h0:C1L
02XaF`0[<5H0:S1D02`bE00V;D/09bi;02@^B@0S;dT08Ba8020[A`0N;4L07B]601d/B@0201`[BP0B
01XYBP0J9dX06bM=01/WC`0L:5806bMA01/VD`0H94h062A=01PTC00H9T/05RA701@QA00C84005b90
01DO>P0C6C404aT_2Oooool000Oooooo00H0:RhO02H]7@0X;ad0:30K02/e7@0]=al2034f800_03Hi
9P0d=RL0;BdQ02l/9@0b;R/0;b/X02l^:P0g=S@0<c8`034a;`0_;bd09bTT02DW8P0T:B809R/T02D[
8@0Q:A`08BTJ028[6P0N:AP08B`K028]700P;1P08BXG03Y1<@1LH580I6ML05EFCP0o?SX0@T4o02`/
;00];Bl0:BX^02X]<P0^<cT09Rde04]BG01KHFd0EUaZ06E/O`1oQI/0Ph^R08:=X`25SjP0QY:/08BB
[024U:d00`25UJh08`2:W;@0RIVc08VJ]P2;V[L0Ribh08VJ^02=W[`0R9bg08^O^P2;XKT0RJ:h08ZS
^@2<YKT0RjBh08VR]P2=Y[X0SJ>j08^Q^@2<X;T0T:Bo08jO^`2<X;/0Rj2m08^S_`2:Y;l0R:?008ZU
`P28Y<80R:?108VSa028X/D0R:3608RNa`28VlH0RIc70080S9g;01h0Ric:08bMb`29VlT0R9[808BI
aP23V<D0Q9W408JKaP25V/D0QY_808JKbP25VL/0Q9S:08>GbP25VL`0PIG707jDaP1oTlP0PIG:086D
c01nTlX0NY7507bCa`1jU<D0N9;307ZDa@1iTl@0NIC307RC`P1gT/4207F@_`0307B?_P1gT/40Mi?3
0080N9C30180MI7007FB_P1cT;`0M8nn07J>_P1eSKd0MH^j07F9^`1aQKL0L8Bg06n3]P1]PK<0Jgna
06b2/`1YPK40IH2_06F1/01TP:l20660[P06061oZ`1OOZX0HWj]065m[01QO:/0HWZZ0P1SNJ/01@1U
NJ`0IGN/06AeZ`1TMJ/0IGB[0080HW6X00@0Ig>]06IcZP1TLJP0IG:Y0P1TLJP0301SLZT0HW:V06=c
Y`1QLJ@0GVjQ061`X`1RLZD0GfjO069`X@1PK9h0GVZJ05m[V`80G6RJ00D0FfNI05aXVP1JIYP0FVJF
05UUU@0205QTU00H05IRTP1DHY40EVBA05ITT@1FII00E6><05=RR@1DI8P0E6>:05AQR`1DHHd0Df2=
059NSP1AGHl0Ce^=04mMSP1>G8d0CEZ>04aLS@1;Fh`0BEZ804UJQP18FHD0BEb60P17FX@04`17F8<0
@U=n04EFPP15EX@0@eB203m@OP0mCgl0?eB3049DQ012EhH0?EB003Q@O00hDGX0>U=k03YANP0iD7T0
=Dec03I=M00dBW400P0eBg805P0hBg<0>4Y`03Q8K00hB6`0=dE/03I4J`0f@VX0=D5[03Q0KP0e@6d0
=3m/03I3K`0e@Vh0<Sm[02hkI`0a?FX0;SUW02hiIP0_>VL0<CUW038kIP0a>VD202lfHP0B030gH`0[
<Uh0:C1L02T]FP0X;5T0:RmI02T^EP0Z<5@0:BmA02H_CP0U;d`08Ba8024]A`0P;TP07be701h/AP0K
:d@06BU20P0L:TL00`0J:DH06RU801`YC00201`UC00>01TRB`0J8dh06R=>01TRC@0G84X06R=<01TR
B@0H8TH05Qi301DM@@0E7S/05Qdg01HL<P0E6Rh9ooooo`001oooool05@0Z;Ql0:BdL02L^700Y<1h0
:S<N02`f7P0^=R40;C8N034d8`0a<RD0;RhV02`[9`0_:bX0;RX[034];P0a;c00;bd^02h^;00[:bT0
9RLR02P[900202X]9P0a028X7P0Q9a/08BTL02<[700R;Ad08BdM024/700K9QD0=Sl^05aRE01KGU<0
C4i303@e;@0c<Rh0=C@b030^;`0e=CL0=SLi03a0@`0h?D<0ATeE06edO01^M800Jg>007j6V@22SJ<0
PhnU082?YP24TjX0Q9B[08>CZP23UJ/0Q9J^08JH/027Uk00RIVc08bK^02:VKH0RiZg08^L^02:VkT0
Ribj08bM^`29W;X0RYji08ZO^P2=Xk/0SjFm08fS^`0208^Q^00908^S^`2<XK`0S:6l08ZO_02<XKh0
SJ:o08VP_`29X/00R:6o0080Qj:o01@0QjC108FR`028Xl40RJC208bTb026W<<0QYW308RKaP2;W<X0
S9k<08jPcP2>X=00SIo?08RLcP27Vld0R9c>08JJc023UlT0Q9S:08JJc0<0QIW<00@0QiS<08JGb`20
U<L0Oi?60P21ULX01020U<T0Ni3507V@a01jTLD307VCa00307VD``1fTL00M8nn0080MI2o0300Lhjm
07:=_01cSkh0L8bl06n>_01aSK`0LHjj06n<^01]R[H0L8^j06j9]P1`R;H0KhJb06n4/`1`QK@0KX>b
06b1/01]P[40K86`06^1/01XP:h0IX6`06B0[`1QP:h0HH:_05n0[@1QPZl0H86^06:1[`1SOjh0Gg^Z
061kZP1RNJ/0HgV[069hZ@1WNjd0I7R[06Qi[@1VN:X0IGFY06AdZ01VMZX0HW:V06=cY`1TM:P0Hg>W
069cZ@1PLJL205mcYP0A05a`XP1MLJ<0H7FT05maX@1OKYl0GffL05m[V`1PK9`0H6ZK05aVV@1OJI`0
GFNJ05aXVP1MJI/0FVJH05UUU@1HI9H00P1IIID0501EHXl0E6:?05EST01EI8l0Df:;05ASRP1EI8/0
E6>:059QRP1BGh`0DUj>051LS01@G8h0CEV;04]HS01=FXh0C5V=04]KSP1:FXd0Be^<0P17F8H00`17
F8@0AeR3045CN`0204=EO@0504IEP015EX40@e5n03i?O@0mCgd00`0nDh807`0lDX40>E5m03Q@O00j
DWh0>U5m03I=M`0hCgT0=Tef03I<M@0aAg00<TQ_03E8L00dB6d0=dU]03=6I`0b@V@0<d=U0351H`0c
@F@0<d5V0390I@0b@VH0;d5U0392IP0`?fH0;ciU02hlI@0]>F<0;3US02hkI@0a>VD00P0]=Ul03P0/
=Eh0<3EO030eG`0^<ed0:BiH02/^F@0Z;EH0:2]D02P/DP0Y;e<09Ra>02P^D00S;D`08Bm:0P0O;DP0
2@0M;DL072a601`/A@0M;DL072]801TXA`0K:TT06RU801XWBP0201TUB`0701DQA`0G84T05ai801TP
C00J8D/06b=:01HN@`0201TO@`0501XN@@0G73X05A/e01@I;`0@5BT02Oooool000Oooooo00d0;2`P
02X[7@0Z;1h0;S4P030d8`0/=1l0;30O02X^7@0/;ah0;c4S02d_900[;2@0:bXU0080:BPT02D0:bXV
02d/:00b<Bd0;2/V02PW8P0Z:R80;2`T02XZ8P0T9Ad08bHO024V7`0U;2@08bXR028Z8P0R:B807bHN
03@l<@1YKVL0BTe603dn>00Y:R@0;B`X034`;P0d<c40>SXj04=5A011@T@0CU5F06ebN01_MWh0LgZ4
07R0S@1oRI`0NXVP07f=Y01oTJL0PI>Y0080P9FX00d0PYNZ086FZ`23V:d0QYR^08NI[`29Vk<0Rife
08RI/`2;W;H0RY^g08^L^02;W;X0S9fk0080Ri^l0`2=WKh00`2;W[h0SJ3008^O`00208bP`@0308ZQ
`@2;X/80RJ3000<0Qj2o00`0Qj2n08RQ_`26XKd0Q9nj08NQ_02:Y;l0S:?308VP`P2:X<D0RIo808ZM
b02:Wl`208VNc@0508ZNd@27WLl0Qig?08NMc`25Vld00P23VL/01P23V<`0PYK;08:Fb`20U<T0PY?9
082Aa`80OY;700P0O97607^@a@1kT<D0N8o107N>`01eSl00MY3107B>_`80MXjn00D0Lh^k07>;^P1d
S;`0LXfj06n:]`0206n<^00306f9^01^RkL0Khbh0080KX^g00H0KHZd06f8]@1[Q[<0L8Rf0767]P1^
Q;<206f3/P0806j4/@1^Pk00Jh2]06UnZ`1YP:`0Ign]06J1/01TP:l206F1/@0506:1/01OOZd0HGf]
06B0/01QOJ`00P1SOZd02@1TO:X0HGVU06ElZ01VOJT0HgRU06EjY@1WNJL0HWNT06=hY@0205ieX@0@
05ifY01KLj<0FW6S05YaX`1LLjD0FW6S05MaXP1HKj40FFnQ05Y^X@1LKJ00GVbM05YXV@1LJ9X0G6JI
05eWW080H6NM00H0GVRM05aVV`1HI9P0FFFG05USV01JI9L205MSU@0@05=QTP1DHY<0E6:A05ART@1C
HHh0DF:>04iOR`1=GX`0CUb;04mMSP1<FX/0CUZ<04eIR`1=FHd0BUJ:04aGS@80BUN<01T0BeR<04QE
R@17E8P0B5J704QFP`14Dg`0@e9k049AN017E7h0AeIo049?N`11D7/0?Tmk03e?O@0lCW`0?Dmm03]@
O@0kD7/0>Dii03Q=NP0jC7`0>TYk03U9NP0hBGL0=TMe0080=4Mb00L0=DQ`03=7K00cBV`0;TEU02e4
H`0^AF@0;4AP00<0;T=P00L0;3mM02a1GP0]@5h0;3mO02`oH00/>el0:SQO0080;3YQ00d0;SMP02df
G`0[=5d0:S=J02X_E`0^<e/0;S5J02/^E`0];eP0:beF02`[E@0Y:e80:BeB008092Y<00@08BY901lZ
B00L:TL07Ra90P0L:dX03P0J:dT06BY801PXB@0J:T/06b]<01XZB`0G9DP05RA701LWB`0G9DX05216
01DNA@0G84T06B570P0I7d<01`0J7T406ai101/N?`0H73T06A/d01HH;`0B52T02Oooool000Oooooo
00T0<RlV02/[7`0[:al0;2hP02da8P0`=2<0:blP02T]700Z;A`00P0/;R4202d_900G02//900V9al0
9RLO02X[8`0^;RH0;blW02XZ8P0[:b<0:BTO02TY8@0W:2809RLR02<U800S:2@07b<R028V9P0Q9B@0
:Bl]02ld<00f>3D0<38_02h^;00a<Rd00P0e=3803@0e<c@0A4A406Y[K@19CE009RT^07AiO`2CVZ@0
O8B?07Z1T@1lR9`0O8^R07b>Y01nT:H00P20UJP208:GZ080QIN[00/0QiV]08VK[`27VJl0QYR^08RJ
/P2:W;@0Ribf08bM^@2=W;/0S9Zl08^I_00208fK`080RiW001/0S9_208bNa02?XLT0Rik608VOaP28
W/D0Qio508JN`P29XLD0QIfo08BL_P27W[h0Qijm08NP^`25WkX0QYjh08VQ^`28Wkh0RJ3008jRa@2<
X/T0RIk908VNb`27W/X0PIO608:HbP25Vld00P24Vld00`24V/`0PiW;08>Ib`0208:Fb`80PI;800L0
Oi3607j?a@1mS/@0O93507fAaP1kT<D0NHk30080N8o100H0LH^l07:<_@1dS[l0M8bl07J>_P1cRk/3
0769^@090769]`1_R[T0KXVf06b7]P1]R;D0KXVh06f8]@1/Qk@0KHRe0080KhNg0P1`Q[L06P1_QKH0
KXBe0726]`1^Pk40KX>`06b1[P1ZPJd0IWfY06R0[P1VOZ`0I7n^069m[01ONJX0H7b/05]gY`1MMjP0
GGRW05iiZ01ONZT0H7RV05]cX@1LLil0H7NQ05mfX01OMYl0H7JO0P1RN:401`1RNJ80GGJN05]dW@1I
M9l0FGBQ05YeY01JM:D00P1HLZ<01P1GLJ@0FWBW05YaY@1LL:D0G6fQ05aYWP80FfRM00L0FfJL05]T
V`1OIY`0H6NM05]UVP1IIIT0Ef>G0080EV:F00<0E62D05MSU@1FI9D00P1DHID01P1BH940DF6C055Q
U01?Gi00C5j>04mOT080CEf>0P1>G8d0401@G8h0CUZ<04aHRP1;EHX0C5J;04aHS01;Eh/0BUJ:04UE
R@18E8H0Ae:104E@O@15DG/0A55k04EAN`16Dgd204=@O00803m=NP0oCG`0?Dil03e>O00lCG/0>T]g
03a=N`0kC7X203e9N`0>03Y6N00jAWL0>4Ie03Q6M@0eAW80=TMb03=7K00bBF/0;DIU02a5H`0[A680
;DMR02i8H`0/AUl202Y2G00502XoFP0Z?e`0:SeK02/nGP0/>eh00P0/>5h0500Y=E/0;SMP02ddGP0/
=5/0:C5H02X_E@0/<5H0;BmH02`^E`0/:eD0;ReG02d/E00Z;5<0:2aB02D[C`0V;5008BY;01hYB@0M
:T`07R]=0P0J:4/05`0I:D/05bM901TYC@0K:dl06b]=01TYB`0H9TT0529501LWB@0F9TP05B5701HS
AP0F7dH05Qi301XPA00I7d406Qi101TL?@0L7ch061`i01TM=P0H6S404aDZ00Wooooo0007ooooo`09
02d]9@0];RH0:R/S02`^8`0/<280:blP02X^800/<2408bLH0080:2`N00L0:BdO02/_8@0[;R<092LL
01lR5`0T9a`09bTN0080:B/P01`0:2XO02HW7`0V9al0:2TS02`]:00Z:RP09bLW02LW:@0U9RX0:BX^
02DY;00[;c80<34e030a<`0];S00<C8d03Lg>@0f=cT0=cPl04m@E01_LWL0KW5h05ULI@1_Lgh0SYBR
0827U`22RI/0PHfQ0P22TJP00`24U:/0PiBX08BEZ@0208NFZ@0F08NFZ`28Ujh0RYV`08VH[`2:VK00
RIV`08^K]02:V[@0RY^g08bL_@2<W;h0S9^o08ZH_@2<Vl80SYg608bIaP2>VlP0RYW408ZKaP2<WLT0
SIo=08ZOc080RYo:01L0RIo808ZPb@29WlH0QYc108RL_`29W[d0R9bj08FH]P23V;<0QIZe08BI^029
WKh0Rig108^Oa026W<D0Qic708FLaP21V/<0PIO6086Gb023VLX0P9K707nCa@02082DaP0708:CaP21
T/P0PI37082?aP22SlH0Pi37082Ab@0207n@b00707fAaP1kT<D0N8o307V@`P1dRkd0MXjn07B<_002
07B;_@0=07N=_`1eRkd0M8Zl07>9^`1bR;T0LhVk0726]`1`Q[P0KXBe06n5]`1`Q[L0KhFf0726^002
06n3^00<0723^`1^PKT0KH2h06f0^01^PkP0Jh6b06Z0/@1[PK00J82^06V1[`1WOjd0IGf[0P1TO:X3
06=kZ`08069jZP1OMjL0HWRY069hY`1SMjT0IGNW06=eX`1SN:82069hX@0F06AgX@1UN:00HgVP069j
X01NMIh0GgJP065iY@1QNJL0GGFU05ieY`1LLjD0G7>W05edZP1LLjT0GgBY061dZ@1NKjD0GFbS05YY
X01LJJ00GFRP05]VWP80FfBK01@0FfNK05QTV01HI9H0EfFF05ITU@1CHI80E6:C05=SU01BHYD0E6BG
055QU01>Gi80D66E055RUP1:GY40C5fA04aNT01=Ghl0CEf>04iLR`80CEV90100C5J704eEQ01<E8D0
CUJ704iER@1:DHD0CEF604YEP`1;DX40BDmo04M?O@14Cg`0ATim04IAO`15Ch00A4io0P12CX001012
C7l0@4Ym03i:O00lB7P203i:O00?0417N`0oAWX0?DEf03m7M`0lAgD0>dIc03Y7L`0hAg00=DA]03=7
K00aB6X0;TEW02a4IP0[A6<0:TER0080:DAQ00l0:dEP02]2H@0/@640;3mP02hnH00/>Eh0;cQQ02hg
H00^=El0<3EO02ldGP0/<ET0:RmG02``EP0[;eD00P0];eP02@0/;UL0:beF02X^E00Z;U@09baB02@/
D@0S:e008baA01h[CP0201l[D@807BU?0P0L:U405@0L:5007BUA01`XCP0L:4h06bM=01XWBP0F94L0
62E701@QA00I8dH05am401LO@`0F7d00625201DN?`0H7T005adm01/R?`0E73H041H^014F;009oooo
o`001oooool0=`0V9b409bPR02<T700V9al09bTN02@X6P0Y;Al0:2`N02<W6@0W:Qh0:2/P02HY7P0Y
;b<09bdQ01`R5P0L7a@07B0E024U5`0R91T09BLL02DV7P0V9Qh0;2/V02h]:00U9200:RHU02d[;00]
:bh0;2T_02`[<@0/;C80;Bhc02l_=`0a<CT0<SDl03`oAP14Adh0ADQA03XnA`19CEP0Mgj808:8U01c
NhP0NX6A08B;W@21RI`0Q8bO08B?Y025TJT0QY:Z08NCZ`26TZX0R9BZ08RCZ@29U:X00P2;Ujl04`2<
V;80RiVc08bJ]029VK80RiVc08bL]P2>Wkd0Ri^l08fM_`2<Vl00SYc308ZI`02<Vl@0Sic908jJbP2=
VlP0RY_708fNc02;WL/00P2:W<X04@29VlT0S9o:08VLaP29W<@0R9[008RJ_P27V[X0Q9Be08:C/@1n
TJl0OY:]082C/@21U;@0P9>d08:D^020Tk/0NY2i0080Ni:k00<0O96l07fB_`1nTl000P1nTl00101j
Sk`0Oi6o07j?_`20T<<2082@a00H08BAaP25T/L0PY78086BbP20TLT0OXo507fAaP1jSl@0Ni7307V@
`P1gSkl0N93007VA`@1fS[h0Mhfn07R=_`1gRkd0MXZl07F:^@1dR;X0MHZi07F9^`1cR;L0MXRj0P1d
Q[P02P1cQKL0M8Fk07>4^P1cQ;`0LH:j0720^`1_P[X0KH:i06b1]P1[PK<206Z1/`0606V1/@1WOjl0
Igf^06Qn[`1VO:/0I7VX0P1XOJ`02P1WO:/0IW^Z06QjZP1VN:H0IWJW06QiY`1UMZ80J7VT06MhX`1U
MZ4206MhX`09065dWP1QMj00G7:K05]`V`1MLYl0Fg:N05Y`W`1HKYl0F6jP0080F6fR0P1HK:401`1L
KJ<0GfnT05YYX01IJId0FfZQ05]XW`1LJJ000P1IIY/0201IIYX0EfBH05QVU`1IIiP0EF>D05=QTP1D
I9D0DV:C0P1BHYD0101@H9<0Cf2D04eNU01@HIL204mPU00G04eOT@1<GXh0Bef;04aMR`1=FhP0CEZ7
04aGQ01?F8<0C5F004eEP`1>E8@0CE>304eDPP1:DX00CE>104iBPP1:D800BE6004M=O`18D840Adj2
04A>P`15C8800P15C8<01P12BH00@DQn03e7O00nB7d0?dUn03m6NP80?TAf00/0@4Mf03m6LP0mAW40
>DE]03I2JP0fA6/0=TE/0394JP0bAV/0;49W02Y2I00202M1HP0<02Y4I@0Z@f80:D1R02e1I00]?fD0
;CeQ02hjH@0]=Ul0;cIP02`cG@0^<ed0<CAM0P0^<EX0200/<5H0;S9H02haFP0/;eP0;2mJ02`aF`0W
;eH09BeD0P0S;5<00`0U;UD08BaB01hZD00201l[D@08020/E00N:U8072Q@01hZDP0O:5407RM@01hW
CP0M9Td201XSBP0?01/UB@0J94P06B=701TSA`0I8DH06B5501PPA00F8D4051lo01LP@@0F7d006B8o
01HM>@0C6C404AL]00Wooooo0007ooooo`0602LX8P0Z:bD0:2PP02PY8@0W:Ah09BLL0P0W:Ah0;@0T
9a`09BLM02LZ8@0S9Ql08B@M02@W7P0M81L06A`C01hQ600R91T09BDK02DU7@0U91l09R<N02TV8@0`
:bL0:bHR02hY9@0d;b`0=c4a03@_=00`;C@0;bhf02h^=P0/;3H0=3I20455D@1:CE`0C59P04mEI@11
B5/0?DEH07N2U02;V:/0Oh^Q07V5V`1oRj40P8bR08:>Y024T:H0QI2V08F?Z026T:T0RI2Z08ZA[@02
08^B[P0E08^E/02;Uk40S9Nc08^I]029VK<0RIZd08^K]@2;W;P0Ribj08^K_02=WKh0SIbn08ZH_@2=
Vl00RiW008bI``2<VLD0S9_608^Lb02:VlL0RI[60080R9W50280RiW608ZHa@2;V/D0Ri[308VH_`26
U[X0QiNi082@/@1kS:X0NHZX07Z;Y`1gRZP0M8NW07>6Y`1eQj/0MXR^07:4[01aQ:`0LXF]07>6/01d
Qk40MHRb07>6/01fRK40MHR`07J<]@1fR[@0MXVd07J8]P1iRkT0O8jn07f=_P1lS;l0NXZn0P1hRKd0
9`1hS;l0NXk107R<`@1eRkd0MHfm07B<_01eSKd0Lh^i07B<^01dS;L0LhZd07J;]P1gSKH0MhZe07R;
]@1fRK@0NHbf07N8]01eQ[80MhFd07R6]@1hQKT0Lh>f07B4^01bP[H0Kgnc06n0]01/P;D0JWne06b1
^01ZOkH0JWnd06Ik/01YO[<0Ig^^06=gZP1YNjd0IgVY06QjZP0206UjZ00706UgY01TMJ40IGJR06Ae
X@1RLil0Hg:M06EdW`0206AcWP0=06=bW@1TLYl0HW2M05i_W@1NL9h0GFnM05a^W01JKi`0FW2O05M/
V`1JK9h0FF^M05YZW@0205MWV`0505MWVP1KJYd0FVZM05UYW01FIYT00`1FIYX01P1FIYT0EFFH059R
U@1CHiH0EFFH05ATU@80Df>D00L0DV:C05=PU01EHYH0Df2D059OU01@GI@0CenC0080CUjA00`0Bef?
04]MS@19FhT0BU^704aMR019F840BEQo04YHO@1<F7h0BEEk04YCO01:DG/204]BO00G04]AO01<D7l0
BDel04Q>OP19C7l0AD]o04E:P@15C8<0A4V304I<QP15BhL0@dV50457P`10AX80?DIo03a5O00nAG/0
?4Ae03]3M00l@fl0?4A[03]4J`0jAV`00P0g@fT01@0e@fP0=4=Z02m1J@0_@VX0:T1W00@0:41V00X0
:CmV02e0J00[?FD0:cYQ02dhH00^=f00;SIM02P`E`0/<ET0;S=I0P0]<UP04`0[<5P0;35I02hcG@0X
;eT09BaH02@]F00S;eT08BiH020]E`0P;UD08BmF01l]DP0M:e007RaA01XXB`0H9T/07BY=01/XB`0M
9d/00P0M9Td201dUBP0901`TB`0K8dX072A;01TQB00M9D`06R9901LPA`0H8TH06B=700805Am200H0
51a001HL?P0E6c/06Qlm01LK=P0I7CH9ooooo`001oooool00`0W:2<09bPR02TZ900202LX8006028U
6P0T9ah09RTP02<V7@0T9Ql08R<M0P0P8Qd08`0N8AX08bHO028S7@0S91h08b@L02HV7P0W9R409RDP
02LV8P0U8Qd09R<N02LT7`0e<2`0>3@a03Hb;`0e<S@0<c0g02l^=P0[:cD0<38n03PkBP13BET0CEAV
04mFJ@18D6D0AdmV05iZPP1fQI`0Q9B]07f=YP1jRZ<0OhnX08:AZ024TjX0QI:X0080Qi:X00`0RY:Y
08N>Z028Sj/0Ri:^08VB[`2:Tk00SIRd08ZH/`2:VKH0R9Ve08JJ]@29V[P208NJ^00908ZM_@29W;`0
Rifn08^K_`2:V[h0S9_208ZI`P27VL40QIK10080R9W400<0RIS308ZI`P28Ul000P2:Ul404P2;VL00
RYRo08VG_027UKX0Pi6d07f=[`1lS:d0NhbZ06aoW@1XNiT0JgjN06aoW`1/O9h0KGfQ06]jX@1ZNJ00
J7NP06MfW`80IgVQ00D0I7NO06EhX01XNj<0JgjV06j1ZP0206aoZ@0D06n2[@1aQ:l0LX>a07J7]@1d
Q;D0MXJi07F5^01eQkT0MhRl07J7^`1iR[h0MXZl07:8]`1eRkX0LXVe07:9/`1fSKH0M8Zc07>9/01f
S;<207F;/P0807N:/P1fRK40MhVa07:4[01dPjh0MhFb07J4/`1cPk@30761]00;0720/`1]O[80Jgnc
06Ym]@1/P;D0KX:g06]l/P1[O;00JW^_06Qj[01YNJX00P1[O:X03P1/NZL0KGbW06elY`1[NZD0IGNO
06AgW`1XNZ80J7NP06MfX01WMZ40IgBP06MdX@1VLZ80IgFT0P1SLj@2065aY00905a^WP1JKih0GFnQ
05i^X@1NJil0GFZN05aYWP1KJ9d0FVNK0080FFJJ00D0EfNJ05QXV`1HJ9/0EFFI05IXVP0205AVV005
05=UU`1BI9H0EFNI05ATU@1CHi@00P1AHI80101DH980EF6C05APTP1DH982055MS`0=04mMS01>G8/0
CE^:04]LR01;G8L0BU^604UKP`1<Fh@0B5Mn04UGO01;FGh0BEEk04QDNP0204UBN`0G04U@NP18CgX0
BE1l04M>NP16CG/0Adem04E;O@15Bgl0@DQn0497O`11B7l0@TR203m8P@10AX00?dEo03a5OP0mB7h0
?4Ii03]5MP0kAW@0>TI^03Q5J00kB6/00P0gAVL04P0eA6D0=TAW03E5J@0a@6L0;CmW02/nIP0X?VD0
:CmX02Y0J@0X?VL09ceV02`oJ@0/?VH0;SeT02`iGP0/>5h0;3IJ02TcE`80:c=G00h0;3AH02XdF00Y
<eL0:35H02H_EP0W<5T08ReJ01l/F00P;ET08C1K01l^F@0O;UL082eG01l]E08072Y?00L06bU>01XX
C@0L:4h07BY=01`VBP0K94/072E<00807RI=0P0M8T`03`0I84X06B1<01XQC@0J8Dd06R=<01TRB`0G
84L05Am301<M@00F7T805Q`n01@K>00D6CH04QH_01<E;009ooooo`001oooool01`0V:2D08bDR02DW
8P0T:B808bTO024W7@0P9Q`00P0Q9ad09`0V:2408B8L02<T7P0T9Al08B8M02DV8@0Y:2@09BHQ02HW
8P0S91l09BHQ02DW8P0Q8b008B<N020R7@0O8A`0:BXU03Tk=P0c=C00;2d/02h_<`0^;c@0:bhg034c
@00m@4l0?D=C055HJP1HGW@0EEed05UUO@1XMhh0N8RQ07N7X@1hR:80NXZS07^;Y01lS:<0OhnV08:@
Y00208BAXP0e08JAX`25T:@0QI2V08JBZP26U:h0QYB_08NG/@27U[<0QiRf08BG]@26VkP0R9^k08FJ
^@24VKP0QIVj08NK_027V[d0QYZo08BH_@24V/40PiW008JLa@23VL00Qig408NJ`P29Vl40QiVm08JI
^P27UkT0RYZl08^I_029UkX0QiNi08BD]P1mSJl0NHV[07N:ZP1eR:P0LhJV06j1X@1/Oil0KWjO071o
X01^O9l0KG^P06ajW`1XMYd0IG:L06IcW@1UM9d0IGNO065cV`1QLYd00P1RLih02P1VMj80HgBO06Ae
X01UMZ40JGNT06QfX`1/N:P0JgNW06ij[01_OJh2071m/@0<079o/`1gQKH0LH6b07B6]P1bQk@0M8Nb
07N:]01eRk80LhV`07J</`1gSK80M8b`0P1cRJh01`1dR[40MHR`06n2[01`Pjh0Kh:]0722/01`P[80
0P1]OK002`1aO[80Kgn`06]k[@1/O:l0K7V]06ej[P1^O:d0JgVZ06UiZP1/NZT0JWRU0080JWVT0P1Y
N:402P1ZNJ00J7NN06AfW01UNIh0IWZO06EgW@1SM9h0HW>N06AbW`1RL9d206IdX`0406EeYP1SLjH0
HW:V065^X`80GFfQ00<0HFjS061]XP1NJIl00P1LIid01@1JII/0G6NM05]WW@1HIIX0FFVM0080E6JH
0280EFNI05=TV01CI9P0E6FI059SU`1@I9H0DVBF05EUUP1AHI80CUn=051QS@1CH8d0DUn<059QS01B
GhT0DEf705=OR@1AGHL0Ce^5055MQ`1?GH@0CUb304aJP@1;FX<0C5V304UFP017EG`0B5Im04MDOP18
E7h0Ae=m04A@NP19DWd0Ae1k0P16CgX204E>N@0B04A<NP13BgT0?dYh0459N00nB7T0?TYl03m;O@0n
BW`0>dMi03U7N00hAWD0>4Ug03A5L@0eAW40=dU_03A7J00fBFT0<dIT0P0aA680900_@V00;d9R02m2
H`0Z?600:C]O02TmHP0Z?FD0:CaT02XmI`0[?VP0:SeU02XlHP0Y>el0:3YK02PgF00X=eH08c9A02Db
DP0W=5@09CAC02HeE00V=EH0935D02DaE`0V<UX08RmK024^F`0P;EX07baI028_G00O;5T07bYG020Z
E@0O:54082UB01`XD0806bM?01L06RI>01dVC`0L9E006B1>01dTDP0L8e407b=B01/OCP0I84h06R5?
01TOC`0H7Th0621>01HRC@0E8DT05B9501DO@P0E84005Qll01LN>00E6c404aP[014D9@09ooooo`00
1oooool0400S9bP082@S024V8P0T:BD09BXT01hU7@0G7QL061lG01/P6@0P91d0824K024R700Q8Qd0
8B0L02<R800T928202DU9@0Y02HX9`0R8bD08RHU01hT900O9B<07B<Q01/Q7@0P9R80:S0/02P^:P0U
:bX0:c0c03Ll@P0f?DL0=Sa:03]2DP0`=dT0C5AW06Q`Q`1LIWl0K7R@07N5W`1fQ9h0MH>N07V7XP1i
RJ<0NHVR07b<Y@1mSJ@0OhnS082@X021TJ00PY:Q08BCYP22TJH0PY:Y08>E[@21TZ`0PY>_08BE/`23
U[H00`23V;L01P22VKT0P9Ng08BK^`23V[`0Q9^n08:H_@80PY[000L0PYW208>K`@22V/00Pi^o08BJ
_`28W;l0QIZi0080QIRf0P26UkD02P25U[@0QYNe082@/@1iRJX0MHJX07>6Y`1aQ:@0KX6Q06n2XP1_
Oj0206mnW`0606ikWP1[Mid0JgNO06YfWP1YMIl0IgBP0P1TLih00`1PLId0Gg2L05m`W00205e^VP09
05IWTP1HJI@0G6ZG05QVT`1GI940FVJF05mYVP1NJ9/0H6bN0080HFfO0140IW:T06ijZP1/N:P0KgfZ
06n0[01_P:/0LXB/07^>]P1eR;00LXR_07>9/01bR[00LhZc06b3[01_Q:l0LHJa0725/00206j3/00=
06f2/@1XNZ`0IWRZ06Yj[@1XN:T0JW^Y06YiZ01[NJX0KGV[06ahZP1]NJT0K7ZY06]iZ00206YhY@04
06IeX01VN:00HgFM069dW080HWJK00L0H7BI05meW01RN9l0GWBK06EhXP1SMJ<0Gg2N0080HG6R00D0
GVjQ05i_X`1NKjD0H6nX05i]YP0205a[Y080FfZS00P0FFRQ05MVW@1HIih0EfJM05IUW01GIY`0DV>I
05AUV@80DfBH0P1BHiL03`1@HID0DV>G059TUP1@I9H0DF>E059RT`1BHi40Cf2>051QS@1AH8/0D5n:
051RRP1AH8H0Cef204iLP@0204mKP@0704eIO`1>FX80CE^204aIP`1:FH80BUN304QEP@0204MDP@0;
04ICP018EH80AE9o04E@OP14Cgd0A4ik04A<NP15CWT0@4af049>N011CGL00P0oBgD01`0nBW@0?T]e
03U8L`0kBWD0>dUf03i<N@0gB7@00P0eAW802`0cAW40<dI`03I9LP0cAf`0<dMX0397IP0^@f80;dAS
02m4H@0]@V40;T5Q0080:SeN00<0:ceQ02`nI00Z?6@00P0[?VH01P0[?F<0:SaP02TkG`0X>e`09cMI
02DeEP<093EC00P08SEC02<fE00T=5D08c5D02<aEP0T<UT08c1J024^FP807R]H02007bYH020[F@0Q
;5T08bYG020WD`0O9U007BI?01`UCP0N9e0072E@01PQC00L8e406R5?01`SD@0M95806am?01XNCP0H
7dd05ai<01PNCP0F7Td05B1>01DQC00D8TT04b56018Q@P0@7Cd04Qdi01@O=@0F7S4051`Y01@J9PWo
oooo0007ooooo`0Z02DV:P0N7b<0824S02DY:P0/<340720O00T?3`0=4a405A/G01hR700P8Qd08B8M
028S7P0O7Q`07QhN02TZ;00/;C40:b`a02DX;@0S9Rd08BHZ024V;00P:2/06bDV01TS900L:2P07RXZ
01l[:`0I9BH062HY061]L`1[N8408blm02@`@00^>Dd0AU5W06=]QP1/N980Kg^E07F1V`1fPY`0NHFO
0P1jQJ406P1jR:80O8bU07b<X`1lSZ80Oi:S082CY021U:D0PYFV07nDY`20UJX0OiF/082D[`20Tk40
PYFe08:E]P22U[L0PYVi086H^021VK/0P9Rj086I^`20V;X0PYZl086I^`1oUk/0PYZn0P22V/008P21
VKl0OiNk07nG^`21V;P0P9Rd08>H/`25Vk<0QIVb08BH/023Uk00Oi>/07B8X`1eQZ@0Lh>T06n2XP1^
PJ40KH2P06emWP1]O9d0K7^L06YhV`1YMih0J7BN06QcX01WLYl0Ig:P06QdY01ULj80IG>T06AaY@1S
L:@0H6jO05m]W@1NK9/205]/VP0H05YXU`1IIID0FfNG05]WV@1IHiH0F6:E05]UV01LIYT0FfFF061Z
V`1RKI/0I6nL06AaV`1SL9X0IG:L06EdW@1[NZ<0JgZU06UjYP1YNjT0IW^Z06Mm[P1UNj`0JX2b0`1Y
Ok4206Z0/P0906Mk[P1XNJd0JG^]06UkZ`1YNjT0JW^Y06]lZP1]NjX0K7ZY0080JgVZ01P0J7RY06Mi
Y`1RM:80HWBR065fX@1PMj40GgJO061hWP1MMI/0G7FM05acW@1MM9h0GGBP05icX`1MLJ@0G72S05ib
Y`1KKj@0Ef^P05MZXP1GJZ@0F6^V05]^Z@1GJjP205EYYP0:05AXX`1CJJ<0E6ZS05AZX`1@JIl0CVRK
051WV`1AIY/0CVBF04mSUP<0D6BG02h0CV:E055SU@1BI9@0DVBD051RTP1?Gi00DF:@04eOS@1@Hhh0
C5n:04ULQP1<HXT0CV6504eMP@1>GX00CE]n04aJO`1:FH00BUV204UHP`19Eh@0AeR404IDP`15Dh@0
@Dj204ICR014DHH0?db0049>PP14CX40ADn204I=P013Bg`0@TYi0459M`13C7L0@DYe03e9L@0nBW80
?4Ya03]:L@0iBFd0>4Q/03Y9L00lBg@0>4Mb0P0fA7404`0b@g40=TMe03I7M@0eAW@0<dA_03E6L@0a
@f/0<DEZ0314I`0Y@680:cmR02XnG`0Y?Eh0:CeP02PlG`0Z?V<0:C]Q02`nI00]?F400P0W>Ed0100W
>El08cEK028dF00P<UH2020cE00:01haD@0Q=5@083=D024aD`0S<eL08S9F024_EP0P;UD07b]E01dY
D`8082UD01h08BYE02<ZEP0O9U807BA>01lVD00N9Dl06bA;01/TC@0J8d`06B1:01`SC@0K8Th06R5=
01/OCP0J7Td06R5?01POC@0G7dh05Qi=01<NC00C84/04B17010PA00?7d403A`k010P>P0?7S<04Ah_
01<M:@0C6bH9ooooo`001oooool0;@0W9B/08B0U028P9@0Q82H06a/O01LH700H6Q`07AlQ01`O7P0L
7aX07R0K01lO6P0M7AP07A`J034`<`0i>Cd0;c4f02@W;P0Q92`082@]01hT;00O92d06b8Z01LP9P0I
8bP06bD[020Z<@0P;3D0;C]604ABH015EFD0=TMH02HfB@0nCF80H6n60720U`1fPi/0MX>L07Z6W@1l
RIh0O8RN07f:W`1mRIl0OHZP07b;X@0207b=X@0=07f@X`1lTJD0OYBX07nGZ`1mU:/0OYF]07nG[`1o
Uk40P9Fc086E]020Tk<0PIBd08:E]P02086G]`06086I^P1oUkP0P9Nh07nG^@20UkX0OiJj0P1oUk/2
082F_@1607jE^@1lTkP0OIBh07jF]P1oUkH0OiNe08:J]`20VK@0Q9Zf07nF/P1gSJX0MHVY07>5Y`1`
PJ@0JgfP06anX@1ZOIl0IWNK06AeV@1SMIT0HG>I065aV`1QL9`0GfjJ05a[V@1MK9X0GffL05e[V`1M
Jid0G6ZM05UXVP1HIiT0F6NH05IVU@1GIYH0EfFC05QTT`1GHi80F66A05IOS`1FGHh0EUj=05INS01D
GXX0E5j805EOR01DHHL0Den3059OPP1DHH@0EF6405QUR@1LIhl0GFRD05eXU@1PJi`0GfbP05m]XP1N
KjD0Hg:[069aZ`1RLjd0IWN`06Eh/@1WN[<0IgVa06Mg[`1YNK00Jgb`06Uk[`80JGV[01P0JWZ/06Uh
ZP1[NZ`0JWZ/06IfZP1VN:T0IGJY061dY@1PMJD0GWFS065fY@1NMZ<0GGBP05acW`1KLZ00Fg2Q05Y_
X@1LL:<0Fg2T05a^X`1LLJL0FVjT05U]Y@1IKJH205U]Y`0405Q]Y`1FJjL0EFZV05EZYP80DfVT00P0
Df^T059ZXP1?J9h0CfRJ055ZV`1?IIL0DVJG059UUP80DfBF04<0E6BF055QT`1CHI40Df6B051OS`1?
GX`0CUf=04aLRP1<G8/0C5j;04eMRP1=GHT0B5b504UMQ@1:G8@0B5^304YLP`17FX40AUV004EHP@15
Eh80@eB204=EP`12Dh<0@E:2049@P`12DH<0@52103m?P012CX00AE6304E?P@16C7h0AD]l04E<N`13
BWP0@d]i049;N010C7H0@Dag03i;M@0lBg@0>TYa03M7K`0eA6d0=TE`03Y8M@0iAWP0=d=g03I2M`0e
@7P0=D9i03E2M`0c@gP0<D5d0353L`0^@Vh0;D=]02]1J00[?fH0:SiS02XnHP0Z?F80:C]P02LhG`0[
>F40;3YR0080:cQQ02@0;CYS02PfH@0U=F008SAM024dF`0Q<UT0835F024bE`0P<5H08S5G028aEP0Q
<5H08BiD020]D`0Q;U@08BeC01l/D00P:Dh08B]@028ZCP0Q:4`07R=8024XC@0Q9dh082Q>01dUB`0J
8TP06b5801/RB00K8DP07B=:01`RBP0K84P06Ai701DMA@0G7TL201LPB00;01DQB00B84D041i300dM
?`0=73`04Alm00hM>00?7c@04b8c018N;@0C7BP02Oooool000Oooooo03X08A`P01/I700J61d08QlV
01PF6`0J6Ah07A`Q02@T9P0P82806ATH034a;`0J6aH07A`J04E3A01RHV@0EeMI01dN8P0L7b@07b@X
01`Q9`0I82H051TO01DI8P0I82P06R4[01`R;P0S:CL08BPj02/dB`0_>eD0:cUC03M7H@1>GWP0HG>;
0761VP1bPYT0LX6H07J5VP1jQiX0NHJI07^8V`1nRih0OHZM07^:W@1lRj00O8fQ07b>XP1kSj<0O9:Y
07bBZP1mUJl0Ni>_07bC/P1mUK40OYJb082E]01oU;<0P9>c0P22UKD208>F]P0<082E]021UKH0OiJf
082G^@21Uk/0PYRm082H_021Uk`0OiFl07nE^P1mTkP0OYBi0P1oUKX0501mU;H0OiJh07nE^P1nU;T0
OiFj082F^`1nU;/0OI2h07^>]P1kSKD0N8Z`07B8[@1gRk00LhF[07B6[P1cQZh0KH2X06j1[01]P:/0
JG^Y0P1WNJL0=P1VN:H0I7FS06AdY@1RM:@0GW2P05maX@1LKYd0FfbJ05e[V01KJ9@0GVVF05]TS`1I
HXd0FV6;05UNR01IGXH0EEf205ALP@1BG7l0Dein04eHMP18EW40AeEb04QCL@17DW00@Te]041:KP16
CWD0@4Mc04mCPP1EFh/0DUR<059IS`1FGI@0DebE05YSW01OJJ@0GFNR069/Z@1XLZd0IG6[06Ue[`1]
N[40KWfd06Ui[@1XN:`0IWJY06EeZ01XN:`0IGFY06IfZP1UMJT0I7BX061aY@80HG:V01<0Gg2T061a
Y@1OLJ<0FVjP05e^XP1NKj<0Gg6S05e_X@1NL:80FV^O05IWV`1IJYh0FFfR05]_Y01IKZD0FFbT05EZ
X@1GJZ80EfZT0080DfJP00X0EFRR05IYX`1DIil0DVJK051TU`1CIYP0DfFE05IVU`1GII@0E6:A0P1E
HI403`1EHXl0DUb=05=NS01AG8X0DEj:055LRP1>FhP0Ce^;04eIR@1?Fh/0CUZ:04eJQ`1;FhT0BE^9
04QJR00204AGPP03049EP013EX40A5N20080A5N200/0@eB0041AO@13E7l0@U=n049AO013DWd0@e1l
04AAO@16DGh0Admm0499M`0204A;N@0N03m7N00nAWL0?dYh03m:N010BgT0?DYg03a:M`0iAg@0=dEb
03E3L00jAWH0>DEg03Y4N@0h@GP0>45j03M1NP0d?gL0<Smd02hnL@0_?g80;Cm_02m1K`0]@6/0:CaW
02`mJ@0[?6L0:CYU02XiI00Y=V80:cQU0P0Z=F<06@0Y=680:cIT02/fI00Y=V<09cAP02HeGP0R;eT0
7baF02HdF`0V<UX08bmI02</E`0Q:U<08R]D02</E@0Q:U<08baC028/D00R;4l08R]<020YB00O9d@0
6bA301`UAP0O9d/00P0K8dP00`0M9DX06R9701XRA`0201`TB@0B01TQAP0J8TL05am401DM@@0G7d<0
6B=601HP@`0D8D<05B94010M?`0=6SX03a`l018M>`0D7c/05B4i01DP=0094R<02A8Q2Oooool000Oo
oooo00<08AlR01XJ700G5Q/00P0N7B82020Q9@0L01lP900N7b<06AXL024Q8@0G5aT051@F03De=`0a
<C<09BHX01XN7`0P92D07b@W01hS9P0M9BL07R<W01XO9@0L82T082La03PnBP0e>d/0:Bi203]1F@0l
@el0?dYV05=QO01YMi80L82I07F3W@80MhJM01L0NHRM07Z9W01kRYd0O8^N07f<X@1kRYl0OXfR07j=
Y020T:T0OY2X07j@Z`1mTZd0O96^07jC/021U[D0P9Fd07jF/P1lU;00OiJe082E]020Tk<0P9>a086D
/P0208>F]00C086D]020Tk@0PIBe086C]`21U[/0P9Jk08BJ_`23VKh0PYJk086E^P1oU[P0OYFg082D
]`1nT[D0OY:g07nC^020Tk/0P9>m082C_P02086D_`0@07nB_@1oT[`0OY6k07^>]P1kSK<0Nhfa07b<
/01gRJl0NXbd07F8/01bQK00LhJa0725/01[P:d0KX>`06f2/@80JGj]00/0Igb[069gYP1RMjH0HWBS
069`W`1QKi`0GfbH065]U@1OJ8l0G6F<05eWR`0305QQPP04055JN`1<EGH0CUUg04]FLP80?4MS01H0
?4ER03]4H`0kA6<0>dAU03e3I`0m@VP0@TE^04M:L`15B7D0BDai04e?O`1>DX80DeN705AJRP1EFhl0
EefA05]PU`1LHiT0GFNL05eYW@1SKj<0IG6W0P1WM:T00`1SLjL0IGFX06AdY`0206AdZ00406=cY`1R
LZH0I7BW065aY080Hg2T00D0HG6T061bY01QLJD0H72S061`X@0205i^W`80FVZM0100Ff^N05UZWP1K
K:00Ef^P05QYW`1EJIh0FV^Q05QYX@1GIj80EFFP05QYX@1FIil0EfJO05IUW01EIIT0EVJI0P1FI9D0
501GHi<0EF:?05MRT01EH8h0E5n<059JR@1DG8X0EUn:055MQ`1BFXP0CeZ7055LRP1>FHL0CUR9055M
S@1?Fh/0CEZ;04aJR`19FHX0AUR60P13EH<01P15EX@0AEJ204EFPP15EX40AUF004ACO080@e9i0100
@Dmf04=AN014DG/0Ae=m04QAO017Cgd0@TYh0459M`13BgT0@TYk04=;O00nB7T0?DMh041:N`0mB7H0
?4Uf0P0jAg<01P0kB7@0=d9_03I1KP0h@6h0=Si]03Q0L@80>D5b00L0<C]/038lK@0b?6d0;SYZ030l
K00^?6/0:cUZ0080:CUZ00H0:c]/02PhJ@0X=VL0:3IW02PdIP0W<f<202XdI@0602XbH@0W;eh0:S9P
02dfH@0X<E`09RmH0P0U;5H04@0V;EL09BaF028ZD@0T;5<09baF02H[E@0S:U@08b]B028ZC`0P:4`0
8ba=01lYB00K9T@06bI601`VB@0J94P05b5500806bA;00X06R=:01/TB`0K94/06B9901PQB00H84L0
5Ae401TQB00I8dL05b550P0E7d<02@0C7D004Qm1010M?@0C7S`04ahj01@N>@0E83H04a/^01DL;P09
ooooo`001oooool01`0N81l06adL01HH5`0K7A`07AlN01lQ800N7b400P0L7Al07@0M7R006Q/M01XK
7`0E5QX071dQ01dN800J7Ql0728R020T9`0P9BP07BDW01lW:@0O8RL08B@[020T;@0S9c80@TQD03Pn
CP0a=TT0>T1G04]BK01TKXT0LGfG071lUP1cPYT0MhJM07J5W01hQih0O8^P0080OHjR01<0O8bS07j>
Y@1lS:<0OHfT07j>Y`1nT:P0OHjX07n@[01mT:h0OY6a07nB/P20Tk@0Oi:b08:E]@21U[D0OiBc082D
]@20Tk<0Oi:b0080PIBd0P23Tk@05022T[<0Pi>e08:B]P21U;P0PYJi086E^024V;d0PYBj086C]`1o
TkH0P9Bg07nC]P20T[P0OY2f07nA^@1oT;`0P96m07j@_P1oTKl0P9;00P1mT;/0@01nTK/0OI2h07b@
]@1nT;@0NXb`07R:/01jS;@0Nhjh07R;]P1fRkP0MXfi07B;]`1cRKP0LhVj06n5]`1^Q;D0KhFf06b2
/`1]P[40Jgj]06UjYP1WN:@0IWFN06EcVP1SLIH0HFjA061]S`1NJHT0FVF305AOO`1?FWX0CUMh04UB
L`1;EW@0Ae9`03m8I`0j@f80>45P03]4H`0i?el0>CmQ03XnH@0i?5l0?3iT03`nI@0n@6T0@49[04A6
K`1;CGH0CE1k059EPP1CEHD0E5R805ILS01KHi@0FVBE05]WV@1MJYd0H6fQ065^XP1TLJD0I7:S06Ad
Y@1RLZD406=`Y005069`X@1SKj<0I72R069_X`1MKJ000P1OKj80101OKj00Gg2N05]/VP1KJi`305][
WP0?05i^X@1KJil0FFVM05MXWP1KJZ40FFRO05QWX01EI9d0EVFN05ETW@1HI9h0EV>J05MTV@1EHYH0
E66E0080Df6B0P1EHI405P1FHY80EF:?055KS01AG8X0DUf:05AOS01?FXP0CUV7051KR@1>FhP0CEV9
04iJRP1<F8P0C5Z<04aIS@17EhP0B5R904AFQP12E880AUN504AEP@16EH0204QGP00<04EDN`15DgX0
@e5f045?M012D7L0@e5h04AAN`13CgT0@Tej045<N@12CG/0@Daj0P0mAgP01P0mBG/0?4Qj03]5N00l
AWL0?4Uf03Y8M@80>TMc00T0>4Ea03M4KP0g@fd0>45/03DnJ@0g?f`0>3m]03@lJP0f?V`00P0d?6/0
1`0`>fT0<C]/02diJ`0/>V/0:3QY02TiJP0X>6/00P0V=VL0200W=FH09SAS02PeHP0Z=F<0:SAP02H_
FP0Z<E/0;3AK0P0V;UD01P0[<5P09R]C02T^EP0W;eH09baD02X_E`80:2eG01L09b]H02D/EP0Q:580
7RI=020XC@0M:4/06BI601XWA`0J:DX062E701DSAP0I9TT062E801TUB`0K9dd06RI<01TUB`0E8DT0
5b1901@MAP0F7dP05B5701<P@`0201DRA@09010M?`0C8T<041ln010N>`0C7SX051hg01<N=00?5RT0
51/]00Wooooo0007ooooo`0Y01hS700L8QP051X@01XP500L8QP08RPN02<V7`0P8Qd06Q`I01/M700K
71h04aLJ018G6`0I7R806b0T01PM8@0M9BP092T_01hU:`0L8bT061lU01hQ:P0Q8bl092Hb024U<@0/
<T00<SQ603HmC@0l@e@0IFf006iiS@1_Ni40L7bB07J2V01fQI`0MhJM07R8W`1kRj@0NXbT07R<Y01i
Rj<00P1kSJD0301jS:@0O8jV07f?Y`1mSZP0Oi2Z082?[020Sjh0Pi:c08BA/`23T[<0Q9>d08FC]P@0
Pi>g0P22T[@04`20Tk@0Pi>d08:B/`23T[<0QIBe08BD]@23TkD0PYFf08:D^024U;P0PY:f08:D^01o
TKD0P9:h08:A^P23T[/0PY6l082A_@1nT;h00P1mT[l03`1nTkh0O9:k07bB^`1oUK`0O9:g07^A]P1n
T[L0NHfb07^>]P1lSkT0N8fh07J;^P1gSK`0MH^l07>9^P0207:9^`80L8Nk0280KhJj06j5]`1aQkP0
L8Fc06QkYP1]P:/0JGbT06EiWP1UNI`0IGNK069eUP1PL980GF^>059QPP1FHhD0EV23059LO`1@F7`0
CeMk04YBMP19DGD0Adea0457J@13AfX0?T9U03`oHP0k?V40>CaO03LfGP0k>V80>SUQ03`kH`0m?6@0
@D=/0P18BgH04`1:CW/0CEB004mGQ@1<FHH0DV2=05=ST01HJIL0GFjJ061^V`1RL9d0HFnL069`W@1S
LIh0I72P06EaX@1TL:00HfnO06A`XP1TL:000P1SLJ801`1QKj00GVbM05a/W@1MK9`0GffL05i/V`1L
JY/00P1KJIX06`1JJ9T0GFZN05m/X@1JJYh0FVNL05YWWP1IIYd0EfBK05ERV@1DHIP0EF:I05ISVP1D
I9P0DV:F05=SU`1BHYH0DV:E059RUP1@H9@0Df2E059OT`1@GI80Ceb@04aLS`1@GXl0CUb=04iLR`02
04eKRP0504aJR`1=Fh`0BEV:04YJS01:FXd00P15EhL01@13EH<0@UB204AGPP16Eh80AEAo0080AUEn
00@0AUEl04EDN`12DGP0@E1g0`10CgP02@0mCWT0?Tij03a:M`0lBWT0?Tak03a:N`0kBGX0?DYn03]8
O00203Y7N`0303M7N00iBGX0=4Id0080=4Mb00h0=TMb03U8L@0fAFh0=4=/03E1JP0f?fP0<S]T03@m
IP0e?6X0=Ce[034lJ@0a?6X0:cQU02XhI`80:CYX01/0:CUZ02HgI@0U=V809CIR02HgHP0Y>6409CAK
02LeF@0Y=UP09c9B02PcD`0U;Tl09c1A02D]D@0T;5009RiC02@^DP0U;E@08b]B02<ZEP0Q:5@08RUG
02<ZF00R:EL07bQC01`UD00K9dh00P0H9TT06P0H:4T062M801PYA`0J:DP05RE401LVA`0J:DX062M8
01HTA`0D8TL0529901@QB`0E8dX04b9900hPA00=7d<03b9300`O?`0=83h03Qlk010P>P0@7SP04ale
01<N<00?5RP04APX2Oooool000Oooooo00l05QhA01PP4`0F70h072<C01XS4P0P9QP08bHK01lR6@0K
7QL071dI01hN7P0G61X061`O01`P8`0L8BD00P0K82@0100Q9R`09RXc02P/=@0Y;CH202T[=`0@02`^
>`0[;c/0;cE303LoC00lA540G6Md07F1S`1hQID0M86B07J3U01iR9/0NHRM07^:X@1iRJ00N8ZR07R<
Y080NHfV0140N8bU07Z>Y`1hS:@0O8fW07Z;Y@1mSZP0OXjY08:@[@1nRj/0Phf`08B</024S[40Qi6e
08BA]023SkL0PHnf08>A^00308:A^00?08>C]`20T;@0PY:d086A/`21TK80PI6c07n?/@23TkD0PY:f
086A]@20SkH0PY6h08>B^@23T[d0PI2k0080PHnl00P0Nhbj07Z<^P1jSk`0N8fj07V>^@1jT;T0Mhff
07R>]@80Mhfb00`0MXba07F;/P1cRK00M8Zc07F:]@1dRKP0M8Zi07B8^P1eRk`0LhVk0767^@1`QkT2
0768^P0f0726]`1aQkP0LXRf06n6/P1`Qk40L8N`06j5[P1]QJ/0KH>Z06b0Y@1YOJ80J7ZP06IfVP1X
MY/0Ig>I06A]U01RJY40G6B;05MOQP1IHHH0EEZ004U>L`14BVh0>3aQ03LkGP0c=eX0<CEH02h`EP0a
<eX0;BmE02PZD00^;ED0;BmH02haFP0a=5l0>CiX03i5L@0nAW@0@4]h04ICO`18Eh<0DEn<05EST01D
Hhh0FVND05]XU@1MJYL0GfbI05iXV@1PJY/0H6bN05m[W@1NJY`0Gf^K0P1MJiX405]YV080GFVI0300
G6RH05eYV`1KIiT0G6JI05aXVP1LJ9`0FFJJ05]WV`1KJ9`0FVNL05QUVP1CH9D0E66F05ISV01CHiL0
EFFI059RU`1BHiT0D66G04iRU`1AHYP0CUnG04mPV01>GiD0BebB04eNU01:Fhl0CEnA04aLS@19FXP0
BU^904UJR017EH@0BEN604UJR017FHP0AUR804EGQ`14EX@0@eF304=FP@15F880B5Z204AFOP15E7d0
AeIm04IHOP17EWd203mAN@0O045BO@0nCgX0?Tmj03mBO@0mCW`0>DYh03]<NP0mCW`0?D]l03Y7N`0i
AWX0?T]o03m<P00eAGP0=dMj03M7N00dAW@0<dIa0395L00eB780=TQ`03M6K`0fAF`0=45Y03HoJ00e
?VD0=3eT03HmJ@0e?6X0<CUW030hIP0202`gI@0N02XfIP0Y=fH0:cUX02HgI@0U=V809SMR02HhH00T
=U`09CEI02LfF00X=ED0:3=A02D`CP0V;e009c1A02@]CP0U;E409RiB02<]D@0U;UD08baE02@]F00T
:eT08bYH028YE`0W;U`06b=A01PPCP0K9e0062A:0P0I9dX01@0I:4T072]:01XYB00G9TD05BA30080
5bI5018052=201<QA00F94T05RA900lO@`0<7T803Am300hQ@P0?8T803B0n00lS?P0?8c`02a/d00`K
<00B7c804Ad]01<J:P0D72T9ooooo`001oooool08@0D71405QhA01PN400I81006b8B01hU5@0P91D0
828E01dO500L6Q@07a/H01/J5P0M7A/0820P024Q8`0O82@08B8W02TY<@0[:cD0:R`h02/]>@0Z;3T0
:2Xg034e@@0d>TH0=Si904A>F01EHV/0Kgj806inR`1aPHh0LXBB07B6U00207J7U`0>07V:W01jRil0
NXZQ07Z<XP1jS:@0N8VS07V:Y01jRjD0OXnY07n>Z`1mSZX0OXn[086?[@25T:h208F>[`0708V?/`26
S;00RHjd08J>/`26SKL0Qi2i08FA^`0208:?^@05086@^@20SkP0PI2i08:A^01nT;H00P1nT;@0201l
S[80P9:f07j@]P1oTKL0Oi6i082B^P21T[d0Oi2n0P1oSl00101mSKh0OXjo07b<_@1kSKd207V;^@04
07Z=^01jSKL0Mhfd07F;/P80MXjb00<0LhV^07>9/01aQk000P1cR;<0101cR;D0M8Jd0766/`1fRkX2
07R=_00407R=^P1dRKH0MXfi07F<^080LHVe0380M8bh0769]@1`R;@0KhNc06n8/@1aR;80K86/06ao
Z@1/OZH0KGbU06ijY01SKiT0H6VB069[U01KHX`0EEb6059IP`17CgD0@d]_03LoH`0h@F80<SeM034l
G00`>5`0;CEI02ldFP0/<5H0;S1I02d_F00]<5/0:biK030dH@0f>VL0=CaZ03a2LP11BGP0@4]i04A?
O@19E880CER604mIRP1@FX/0EV2A05MQTP1JHID0FVBG05]WV`1JIYX0Gf^O061/WP80FfVJ00h0FfbJ
05e[VP1JJ9L0FVND05eXUP1NJIL0GfZH05mYVP1MIiP0GfNH05aVU`1IHiH0F6BF05USUP80F6BF00X0
EfFF05ITU@1EIIP0DV:E05=SUP1DI9L0D66F051QU`1<H9D0BUnF0P1;GYP02P1:GIL0B5^C04QKT`19
GI80B5b?04QLSP19Fh/0Beb:04YKQ`17F8@204UGQ00M04MHQ019FXL0B5V504IGP`12Dgl0A5F104=D
O`15Egl0AEMm045CN@12E7X0AEMo04=FOP14EWh0?e9l03iAN`0mD7/0?U5l03e?O@0kCG/0=dQi03I6
M`0jB7L0?D]j03e9N`0kAgT0>DEg03a8NP0jAWP00P0hA7@08P0e@g00<d5^0391K00a@6/0<d9[03I3
K@0fA6/0=D9/03=0JP0e?VT0=3eV03<lI@0e?6P0<cYV034hI00b>FL0<CEU02hdI00]=FH0:cEX02/g
J@0V<V@09C5Q02@bG`0U<f008c9M02@cG00V<eX09S=F02D_D`0V<5@09bmF02T^E00X;E<202H[D@80
92aC00H09BaF028YE@0V:UT08bMD024UDP0T:5D201dTCP0<01lWCP0K8dP072A901`TB@0M9DT072I9
01/UB00H9DL05bA601LTA00F9D@05BA10P0C8T403`0E94<04R50010O@00?7d004R9300dN?00=7SX0
3Qlk00hN>00>7SD03aha01@Q<P0C7bd04a/V014I9009ooooo`001oooool0800I7QL05Q/D01DK4@0H
7Q806AlC01LM4@0L7a@0824I01`M5@0L6QD07a/H01hJ5`0P71T08alN02<O800Y9bX0;B/`02XW<00X
9C00<c4n03dmB@0b=4407R0]02P/>00V;3P0;3A105MQK@1cOh/0LH2<0722SP1aPhl0M8JD0P1eQiD0
901fR9H0N8VI07Z;W@1gR9`0NhbP07b<X`1jRZ<0NXZT07b;Z01mS:/0Ohj]07j=[01mS:/0P8j^08:=
[@25SZl0Q8f^08V?/`27SK40QHfb08N?]025SK@0QHjg08FA^`26T[`0QY6n08>@_021S[X0PI2k08>B
_@21T[d0PI>k07jA^@1kSk@0OI6f08>G_080P9>k00T0OI2h08:E_`25UlD0Oi7107f?_`20T<40OXjo
07Z<_01mSkl00P1iRkT0901iS;L0NHbf07N=]01eSK40M8b`07>;[@1bRZ`0M8Z_0726Z`1`QZd0LhJ`
0764[P1bQJl0Kh:/07:5/01cQ[00LHB^0726[@1_QJh0LHRa06n6[`1[QZh0KhZe06b7]01ZQK80JhJe
06b4]01/Q;80KXJd06^1/01^Pk00KH:]06f0Z`1aOj`0KGZW06YgX`80K7NT02/0HFbI05iZU01KIhl0
EF67055NP@1>Fgd0C5Uk04MDMP10CFl0>dEY03Q2IP0_=eh0:BiF02LZD`0U:5<08bQB024VD00O94h0
9RYG02L[F00`=6<0<SUW03Y1K`0l@W80@TQh04A:NP18CWh0DEV:05=KS01AF8`0E5jA05IRUP1DH9@0
Ef>E05UWV01KJIX0FFZH05MXUP1HJID0FVRE05UWT`1GI900FVFC0080FfJD0P1KIIH02@1IIID0F6BD
05MST`1GHi<0EV:B05ESTP1EHi@0EFFF059TU002055SU@05059TUP1AHYL0DF:H04aPU@1<GiL00P1;
GYP05@1:GID0AeZB04ULU019GI80Cf>F04aPTP1;GHd0Bef;04]NR@19FXD0C5f904UJQ@17FX@0B5^5
04MJQ015F880@UEm045DO012EGd0A5Qm049FN`0203mCN00I049EO@12EGl0@5=m041COP0mCgd0?4il
03e?O`0kCGd0>d]n03M7NP0hB7T0>DMh03a:N@0mBGT0>dMg03a6M`0kB7D0>TEc03U6LP0hAG40>DI`
03E2K00c@6X0;ceT03A2J@0203I2JP0H03A0J00h@V`0=SmX03@mIP0e?VL0=SmX03DlIP0b>F<0=CUV
03HjJ@0a=FD0;CEV02XdI@0Y<fH09S9T02@`H00T<Eh09C=P02@cGP0S<U/0935J02HbF00V;eP09BiG
0P0X;eT01@0U;E@092aA02@/D`0W;eH09BeD00<092]E01T08RUC024YD00P:4l07RI=01lWCP0P:4d0
7B9801hSB@0P9D/08RM=028XC00J8TH0629501TSAP0G94H05B9201DT@@0C84005RA101DS@00C8Ch0
525101<P@P0B7d403Q/l00803Q/k00L03Q`i018N>00B7SH04Qda014M;@0C7BT06R8]00Wooooo0007
ooooo`0401TK6P0H6QT05aTF01XL6@8061dI03L06AdL01/L7P0K71h07QhP024O800V8R<09b<T02XQ
900^9BP0;RDZ03@Z<P0`9S40@CU6059<FP1?CEX0BdYH03HhA`0c=TD0>Cm=061WM`1bNhX0Lgn=06im
R`1`P8l0Lh>B07F5U01fQYD0MHFD07V9UP1jRYL0Nh^J07^;V`1kRYl0NXVP07b8XP1nRJL0OX^[07j;
[@1oS:h0PHj`07f:[021Sk00PXn_08BA/@20SJd0PXb_08>=/021Rjh0QHnc08J?]P23SkL0Phni08>>
^`22SK/0Phjl0080PXfk01/0PHjk08>A_P23TKh0Oi6l07f@^01jT;D0OI>h07^A]P1jT;D0NHnd07V?
]P1jT;T0N8fh07J;]P1hRkH0N8Zh07R;]P1gR[D0MHZe07>8/`1bR;40LXR_0769[@1]QjP0KhbZ06f:
Z01`RJP00P1aRZT01@1_QjT0L8J[06j4Z@1^QJL0KhJX0080KXBY0P1`QjT02P1bR:d0L8R^0769[`1c
S;@0Lh^g0728]P1_QkD0L8Rh0727^@1^Q[H306f5]@0W06b4/P1_QK@0KH>b06b1/01]Ojd0KGj/06]l
ZP1YNZP0IGJR06EdW`1GIH`0EF>805MUR01EHhH0Cef004=AM00hAV/0>TI/03Q1J00e?F@0;SIM02L_
EP0V:e<09BY@028WC@0R9T`0829902DWD00Y:e@0<C=L03@gHP0j?FP0>Si[0455LP1;DX00Be>104YB
P@1:EH<0DEf=0080Cef<01@0Cf2>059TTP1DIi80EVVD05U/U`1IK9H0F6^D05MZTP1GJ9<0F6VD05IW
T`1DII40EFJB05IWT`1BHi40DF:@059TU01@HY80Cf6A04eOT@80CF6C01X0CF6D04iOT`1CI9P0D62E
051QU`1<GI40CEjB04YKT@1;G980C5fC04]LTP1=GY@0BU^?04]LT01>H980Bef=04YLRP19FhT0Aeb7
04IKR017G8L0A5^404=KP@11FGl0@Ub103mIO080?UIj0100@EQj03mFN00oEGX0>e5f03mBNP0oDW`0
?e1n041@P@0mCH00?Tj103];O`0jBH00?DZ103a9O`0jAg/0=dMh0P0jB7L0100hAW<0>dQb03M6K@0g
AF`303M5JP0803U5J`0g@fT0=41V034mH`0e?VD0=SmV03DnI@0e?VH2034jH@80<caS0140;SMN02df
G@0_=eh0<CQR02ddH00[<f40;3MT02`gI@0X=F80935N02<bG@0V=F009CAM02@aF`0S;eT09C5I02L`
F`0202D^F@0402</E@0R:e808baC02@^DP808c1C00@08RmB02<]D@0R;5007RQ<0P0P:Th04P0L9TX0
72I901`UB@0M9DT07bA:01hSB@0P94X07bA:01`QA`0I8DH072A901PRAP0I8dH05bA401LQA00G8T80
62=301DP@0805b5500/05Qi301@K@@0B5cl051U1018G?@0C6cl05Ahm014K=P0=62h03ADX00dF9`09
ooooo`001oooool07P0J6Q`061PJ01TJ700L7Al0720Q01/O800J7B8071lT01hO900M7B8071/P02@O
8`0Z92P0<2LZ038W:`0^8bT0=b`d03``>P1=@dh0MFel06iZN01MFV/0>ce<04M:F`1HGVh0KWF507=l
R`1_Nh/0Kgf=0761T@80LX:B01<0MHFD07F5TP1fQY<0NHZD07V9V01hR9P0NHRK07^:X@20RZD0OhZX
07j9Z@1mRZ`0OHZ]07n<[`1nRjh0Ohf_082?/022TK00OXf/0080PHj`01`0O8V[082=/021SK<0PHfe
08>>^`22SKX0Q8bk08>;^P24S;/0Phjl07n9^P1nR[X0PHnn07n@_01kTKP0NY2g07ZB]P1mTkP0O9:g
07VA]@1gSk<0N8nh07J=]P1cRK80MH^d07J9]01hRkH0MH^d0P1dR[<06`1cRK00LHV_06n8ZP1[R:H0
KHZX06n=Z@1^RJH0KXNU06n8YP1/QJ<0LHRZ0727Z@1_QZH0LHRX07:9Z`1cRZX0MHj]0729Z01fSJl0
M8b`07::/01bRk80LHZc07::^01^Q[@0L8Jh06n5]`0206f4]P0706b3]@1ZPK<0IH2_06Ao[P1WOjl0
IGf]06MlZ`0206Un[@0606Qm[01XNZP0JW^W06UhX@1XMih0IGFI0P1PKY<0<01BHXH0BUYn04YFOP1:
EWh0?dQ_03Q1J00d?6409RiC01dSA`0Q9d/07R1601TK@@0J6T007Qe402<RBP0T9Tl09RQA03HiI00e
>V@0>CeZ03m8L`0mAG<0?DYf049?O019Eh@0B5V504QKQP1@Hhh0CF:=04mRS@1DIi40DVRA05E[TP1C
JI00EFR@05=VSP1DIi80DfJA055VT@1DJI@0DfFC051RT01AIYD0CV>B04eQT`1;Gi40BV2B04UOT@80
BenB00D0CEfA04iOU01=GY80BUZ>04]KSP0204]KS`0404aLT01=GI40BUZ>04UIS@80BE^=02H0B5Z:
04MIR@16FhP0AU^804=JQP16GHL0@U^3041JO`0mEg`0?EYl03aIN`0lEWL0?EMh03mGN@0nEWP0?EEi
03]CM`0nDG/0?4mj03e>O00iBGX0>d]o03m?P`0oBhD0>dN1041<QP0lBH00>TMk03M7NP0jBgT0>dUh
03U8L`0kBW40>DU]03I6J00dA6H0=DAU03=2H`80=dAW01X0>4EX038oHP0e?VD0=SmV03<lH`0e?VD0
<CYQ030jGP0^>5`0:cQK02`iG00`>Uh0<C]O02heG`0_>640;SMR02`hHP0Y=V80:SMS02DdG`0X=f80
9cIO02DdG@0S<5X09C9L02<_F@809RmJ02`09BiI02D^E`0Q;ED07BU?024^D@0R;e807Re>01l^C`0S
;E0072I901XWB@0K:4X07BY=01dZC00L:D/072M901hVBP0N8dT07bA:020SC00O8T/06b1601XOA@0K
8dX06B5601HPA00H8TD05Am201LQA00K94D05Ae101PPA@0I8DP061e501LKA@0E64<05aY501LJ@`0A
5Sh04QPl014J>@0>63<03aL^010H;@Wooooo003ooooood7ooooo003ooooood7ooooo003ooooood7o
oooo003ooooood7ooooo003ooooood7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 319}, {239, 0}} -> {-8.17573, -5.99999, 1.05439, \
1.05439}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Continuous-time vs. discrete-time signals", "Section"],

Cell[CellGroupData[{

Cell["Continuous-time signal #1", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f1[t_] := 
        Exp[\(-\((t - 4)\)^2\)] 
          Sin[3  \[Pi]\ t];\)\), "\[IndentingNewLine]", 
    \(\[Florin][t] == f1[t]\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](
        t) == \[ExponentialE]\^\(-\((t - 4)\)\^2\)\ \(sin(
          3\ \[Pi]\ t)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g1 = 
        Plot[f1[t], {t, 0, 8}, \ PlotRange \[Rule] All, \ 
          PlotStyle \[Rule] {Blue}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.308941 0.302543 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0064 -12 -4.5 ]
[-0.0125 .0064 0 4.5 ]
[-0.0125 .15767 -24 -4.5 ]
[-0.0125 .15767 0 4.5 ]
[-0.0125 .30894 -6 -4.5 ]
[-0.0125 .30894 0 4.5 ]
[-0.0125 .46021 -18 -4.5 ]
[-0.0125 .46021 0 4.5 ]
[-0.0125 .61148 -6 -4.5 ]
[-0.0125 .61148 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(6)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(8)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0064 m
.00625 .0064 L
s
[(-1)] -0.0125 .0064 1 0 Mshowa
0 .15767 m
.00625 .15767 L
s
[(-0.5)] -0.0125 .15767 1 0 Mshowa
0 .30894 m
.00625 .30894 L
s
[(0)] -0.0125 .30894 1 0 Mshowa
0 .46021 m
.00625 .46021 L
s
[(0.5)] -0.0125 .46021 1 0 Mshowa
0 .61148 m
.00625 .61148 L
s
[(1)] -0.0125 .61148 1 0 Mshowa
.125 Mabswid
0 .03665 m
.00375 .03665 L
s
0 .06691 m
.00375 .06691 L
s
0 .09716 m
.00375 .09716 L
s
0 .12741 m
.00375 .12741 L
s
0 .18792 m
.00375 .18792 L
s
0 .21818 m
.00375 .21818 L
s
0 .24843 m
.00375 .24843 L
s
0 .27869 m
.00375 .27869 L
s
0 .3392 m
.00375 .3392 L
s
0 .36945 m
.00375 .36945 L
s
0 .3997 m
.00375 .3997 L
s
0 .42996 m
.00375 .42996 L
s
0 .49047 m
.00375 .49047 L
s
0 .52072 m
.00375 .52072 L
s
0 .55098 m
.00375 .55098 L
s
0 .58123 m
.00375 .58123 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0064 m
1 .0064 L
s
.99375 .15767 m
1 .15767 L
s
.99375 .30894 m
1 .30894 L
s
.99375 .46021 m
1 .46021 L
s
.99375 .61148 m
1 .61148 L
s
.125 Mabswid
.99625 .03665 m
1 .03665 L
s
.99625 .06691 m
1 .06691 L
s
.99625 .09716 m
1 .09716 L
s
.99625 .12741 m
1 .12741 L
s
.99625 .18792 m
1 .18792 L
s
.99625 .21818 m
1 .21818 L
s
.99625 .24843 m
1 .24843 L
s
.99625 .27869 m
1 .27869 L
s
.99625 .3392 m
1 .3392 L
s
.99625 .36945 m
1 .36945 L
s
.99625 .3997 m
1 .3997 L
s
.99625 .42996 m
1 .42996 L
s
.99625 .49047 m
1 .49047 L
s
.99625 .52072 m
1 .52072 L
s
.99625 .55098 m
1 .55098 L
s
.99625 .58123 m
1 .58123 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30894 m
1 .30894 L
s
0 0 1 r
.5 Mabswid
.02381 .30894 m
.02605 .30894 L
.02846 .30894 L
.03279 .30894 L
.03793 .30894 L
.04262 .30894 L
.04499 .30894 L
.0475 .30894 L
.04882 .30894 L
.04951 .30894 L
.05026 .30894 L
.05158 .30894 L
.05281 .30894 L
.05404 .30894 L
.05474 .30894 L
.05539 .30894 L
.05658 .30894 L
.05784 .30894 L
.05908 .30894 L
.06026 .30894 L
.06244 .30894 L
.06489 .30894 L
.06757 .30894 L
.07299 .30894 L
.08269 .30894 L
.08549 .30894 L
.08687 .30894 L
.08815 .30894 L
.08886 .30894 L
.08962 .30894 L
.09038 .30894 L
.09121 .30894 L
.09191 .30894 L
.09266 .30894 L
.09336 .30894 L
.09401 .30894 L
.09528 .30894 L
.09647 .30894 L
.09777 .30894 L
.09916 .30894 L
.102 .30894 L
.10458 .30894 L
.10943 .30894 L
.11456 .30895 L
.119 .30895 L
.12376 .30895 L
.12514 .30896 L
.12644 .30896 L
.12761 .30896 L
.12888 .30896 L
Mistroke
.13008 .30896 L
.13137 .30896 L
.13257 .30896 L
.13367 .30896 L
.13435 .30896 L
.13507 .30896 L
.13637 .30895 L
.13776 .30895 L
.13928 .30895 L
.14201 .30894 L
.14456 .30894 L
.14958 .30891 L
.15504 .30888 L
.15985 .30886 L
.16248 .30884 L
.16377 .30884 L
.16495 .30883 L
.16601 .30883 L
.16716 .30883 L
.16832 .30882 L
.16954 .30882 L
.17081 .30882 L
.17152 .30883 L
.17217 .30883 L
.17342 .30883 L
.17461 .30884 L
.17569 .30885 L
.17683 .30886 L
.17889 .30888 L
.1811 .30891 L
.18352 .30896 L
.18875 .30909 L
.19371 .30925 L
.19822 .3094 L
.20069 .30948 L
.20301 .30954 L
.2043 .30957 L
.20548 .30959 L
.20679 .3096 L
.20748 .3096 L
.20821 .30961 L
.2094 .3096 L
.2105 .3096 L
.21172 .30958 L
.21302 .30954 L
.21443 .3095 L
.21595 .30943 L
.21872 .30925 L
.22142 .30902 L
.22391 .30875 L
Mistroke
.23295 .30746 L
.23792 .30669 L
.24038 .30636 L
.24265 .30612 L
.24394 .30601 L
.2446 .30597 L
.24532 .30593 L
.2461 .3059 L
.24684 .30589 L
.24756 .30588 L
.24822 .30589 L
.2494 .30593 L
.2507 .30602 L
.25135 .30608 L
.25205 .30616 L
.25331 .30634 L
.25459 .30658 L
.25599 .3069 L
.25853 .30764 L
.26329 .30957 L
.27349 .31537 L
.27593 .31678 L
.27849 .31812 L
.28087 .31913 L
.28202 .31953 L
.28307 .31981 L
.28419 .32004 L
.28537 .32019 L
.28666 .32022 L
.28788 .32012 L
.28918 .31988 L
.29037 .31951 L
.29168 .31894 L
.29307 .31815 L
.29578 .31602 L
.29832 .31333 L
.30409 .30498 L
.30907 .29604 L
.3145 .28616 L
.31699 .28221 L
.31835 .28032 L
.31964 .27878 L
.32084 .27756 L
.32213 .27653 L
.32331 .27588 L
.32439 .27554 L
.32547 .27546 L
.32662 .27569 L
.32771 .2762 L
.3287 .27693 L
Mistroke
.32986 .27812 L
.33112 .27983 L
.33341 .28407 L
.33582 .29004 L
.33836 .29802 L
.34293 .3159 L
.35234 .35884 L
.35505 .36986 L
.35762 .37857 L
.35874 .38165 L
.35993 .3844 L
.36124 .3867 L
.36246 .38812 L
.36369 .3888 L
.36483 .3887 L
.36608 .38777 L
.3674 .38582 L
.36854 .38329 L
.36962 .38021 L
.37205 .37068 L
.37425 .35912 L
.37625 .34628 L
.38075 .31068 L
.39 .22434 L
.39467 .18656 L
.39595 .17822 L
.39733 .1705 L
.39863 .16458 L
.39983 .16033 L
.40114 .15719 L
.40183 .15618 L
.40257 .15562 L
.40335 .15563 L
.40408 .15619 L
.40474 .15718 L
.40545 .15876 L
.40676 .16304 L
.40741 .16588 L
.40814 .16954 L
.41061 .18621 L
.41309 .20913 L
.41576 .23996 L
.42059 .30821 L
.42549 .38562 L
.43071 .46327 L
.43372 .49982 L
.43644 .52493 L
.43776 .5338 L
.43845 .53753 L
.43918 .54074 L
Mistroke
.43982 .54293 L
.44052 .54464 L
.44175 .54586 L
.4424 .54557 L
.4431 .54452 L
.44438 .54063 L
.44562 .5344 L
.44677 .52651 L
.44938 .50123 L
.45215 .46399 L
.45676 .38254 L
.46185 .27587 L
.46678 .17191 L
.46947 .12122 L
.47196 .08086 L
.47411 .05288 L
.4752 .04126 L
.47639 .03091 L
.4777 .02237 L
.47893 .01713 L
.48012 .01472 L
.48123 .01488 L
.48243 .0177 L
.48373 .02376 L
.48495 .03232 L
.48606 .04249 L
.48878 .07631 L
.49137 .11892 L
.50209 .35886 L
.50706 .4688 L
.50949 .51419 L
.51173 .54882 L
.51407 .57665 L
.5153 .58747 L
.51659 .5959 L
.51723 .59892 L
.51792 .60129 L
.51916 .60332 L
.51992 .60313 L
.52063 .60196 L
.52127 .6001 L
.52197 .59721 L
.52311 .59058 L
.52418 .58228 L
.52662 .55631 L
.52899 .52248 L
.53154 .47836 L
.54038 .29407 L
.54527 .19682 L
.54796 .15222 L
Mistroke
.55049 .11816 L
.55193 .10268 L
.55349 .08939 L
.55418 .0847 L
.55491 .08053 L
.55621 .07514 L
.55752 .0724 L
.55874 .07223 L
.55944 .07316 L
.56008 .07466 L
.56082 .07713 L
.56152 .08019 L
.56267 .08672 L
.56394 .09596 L
.56652 .12063 L
.57114 .18069 L
.57624 .25983 L
.58161 .34239 L
.58643 .40375 L
.58917 .42986 L
.59047 .43976 L
.59171 .44748 L
.59283 .45312 L
.59405 .45771 L
.59516 .46052 L
.59618 .46196 L
.59729 .4623 L
.59851 .46127 L
.59978 .45866 L
.60096 .45489 L
.60225 .44942 L
.60366 .44196 L
.60622 .42491 L
.61102 .3842 L
.61659 .33139 L
.62182 .28581 L
.62424 .26824 L
.6268 .25292 L
.62813 .24636 L
.6296 .24036 L
.63094 .23598 L
.63217 .23292 L
.63337 .2308 L
.63451 .22956 L
.63571 .22905 L
.63702 .22938 L
.63816 .23039 L
.63937 .23216 L
.6404 .23419 L
.64154 .23695 L
Mistroke
.64426 .24548 L
.64676 .25518 L
.65237 .28058 L
.65729 .30292 L
.65998 .31387 L
.66253 .32283 L
.665 .33005 L
.66631 .3332 L
.66768 .33602 L
.66884 .33799 L
.67012 .33973 L
.67128 .34093 L
.67236 .34172 L
.67354 .34225 L
.67466 .34242 L
.67567 .34233 L
.67677 .34196 L
.67796 .34129 L
.67922 .34027 L
.68149 .33776 L
.68657 .32986 L
.69134 .32108 L
.69653 .31189 L
.69928 .30769 L
.70221 .30394 L
.70487 .30128 L
.7073 .29951 L
.70846 .29887 L
.70973 .29834 L
.71093 .29798 L
.71203 .29777 L
.71327 .29766 L
.71442 .29768 L
.71569 .29782 L
.7164 .29795 L
.71705 .2981 L
.71836 .29848 L
.71978 .299 L
.72238 .30019 L
.7319 .30574 L
.73658 .30824 L
.74087 .31004 L
.74329 .3108 L
.74584 .31139 L
.74716 .31161 L
.7484 .31177 L
.74909 .31184 L
.74975 .3119 L
.75051 .31195 L
.75121 .31198 L
Mistroke
.75234 .312 L
.75354 .31199 L
.75456 .31196 L
.75569 .31189 L
.7569 .3118 L
.75821 .31168 L
.76057 .3114 L
.77059 .30987 L
.77589 .30915 L
.77885 .30883 L
.78155 .30861 L
.78411 .30845 L
.78556 .30839 L
.7869 .30834 L
.78806 .30831 L
.78935 .30829 L
.79 .30828 L
.79069 .30828 L
.79194 .30827 L
.79318 .30828 L
.79389 .30829 L
.79454 .3083 L
.79573 .30832 L
.797 .30834 L
.80161 .30847 L
.80696 .30865 L
.81261 .30883 L
.81743 .30894 L
.82017 .30899 L
.82271 .30902 L
.82406 .30903 L
.82533 .30904 L
.82647 .30905 L
.8277 .30905 L
.82834 .30905 L
.82905 .30906 L
.82979 .30906 L
.83048 .30906 L
.83171 .30906 L
.83241 .30906 L
.83304 .30905 L
.83446 .30905 L
.83577 .30905 L
.83876 .30903 L
.84419 .309 L
.84922 .30897 L
.85396 .30895 L
.85658 .30894 L
.85942 .30893 L
.86068 .30893 L
Mistroke
.862 .30893 L
.86324 .30893 L
.86438 .30893 L
.8656 .30893 L
.86624 .30893 L
.86692 .30892 L
.86807 .30892 L
.86933 .30892 L
.87045 .30892 L
.87166 .30892 L
.87281 .30892 L
.87385 .30893 L
.87622 .30893 L
.8788 .30893 L
.88401 .30893 L
.8886 .30894 L
.89113 .30894 L
.89351 .30894 L
.89573 .30894 L
.89814 .30894 L
.90033 .30894 L
.90234 .30894 L
.9036 .30894 L
.90478 .30894 L
.90585 .30894 L
.90702 .30894 L
.90828 .30894 L
.90898 .30894 L
.90962 .30894 L
.91086 .30894 L
.91204 .30894 L
.91314 .30894 L
.91431 .30894 L
.91639 .30894 L
.9211 .30894 L
.92586 .30894 L
.93095 .30894 L
.93387 .30894 L
.93653 .30894 L
.93782 .30894 L
.93921 .30894 L
.94053 .30894 L
.94174 .30894 L
.94269 .30894 L
.94372 .30894 L
.94475 .30894 L
.94584 .30894 L
.94681 .30894 L
.94784 .30894 L
.94881 .30894 L
Mistroke
.94969 .30894 L
.95082 .30894 L
.95186 .30894 L
.9542 .30894 L
.95846 .30894 L
.97619 .30894 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008?ooool2o`0003[ooooo1Ol0000kooooo`?o0000>Oooool3o`0003_ooooo0ol00007oooo
o`007oooool01?l0003oooooooooool0000jooooo`04o`000?ooooooooooo`0003cooooo00?o0000
ooooooooool0=oooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000oooooooooooooooo
o`000006ooooo`007oooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Wooooo
1Ol0000hooooo`05o`000?ooooooooooooooool00000>Oooool01Ol0003ooooooooooooooooo0000
00Kooooo000Oooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0>?ooool01?l0
003oooooooooool0000iooooo`Co0000>oooool3o`0000Oooooo000Oooooo`04o`000?oooooooooo
o`0003Wooooo00Go0000ooooooooooooooooo`00000jooooo`03o`000?oooooo000003Wooooo00?o
0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000000Kooooo000Oooooo`04o`000?oo
ooooooooo`0003Wooooo00Go0000ooooooooooooooooo`00000kooooo`;o0000>_ooool00ol0003o
ooooooooo`0jooooo`05o`000?ooooooooooooooool000001_ooool0023ooooo0_l0000kooooo`?o
0000?Oooool00ol0003oooooooooo`0iooooo`;o0000>oooool3o`0000Oooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Cooooo`?o0000ooooool;ooooo`00
5?ooool00ol0003oooooooooo`04oooooooo00001Ol00001ooooo`003?ooool5o`0000?ooooo00?o
0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`02ooooo`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooo`7ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
07Wooooo0_l00?n5ooooo`7o00000Oooool001?ooooo0_l00006ooooo`03o`000?oooooooooo07Wo
oooo0_l00?n5ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1iooooo`;o003oQOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Wooooo0_l0
0?n5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool00ol00?ooooooo`00o`25
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool01?l00?ooooooooooool00?n4
ooooo`7o00000Oooool001_ooooo0_l0001iooooo`04o`00ooooooooooooo`00oh?ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`05o`00ooooooooooooooooool00?l0Poooool1
o`00007ooooo000Kooooo`;o0000NOooool01Ol00?oooooooooooooooooo003o08;ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool03_ooool2o`00og7ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool2o`00og7ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
3_ooool3o`00og3ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03_ooool00ol00?ooooooo`00o`1`ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0Moooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooool00?l0L?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
07Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`04o`00oooooooooooo
o`00og3ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool03Oooool01?l00?ooooooooooool00?m`ooooo`7o00000Oooool0
01_ooooo0_l0001hooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01?l0
0?ooooooooooool00?m_ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Moooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00Co003ooooooooooooo003oL?ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0=ooooo`04o`00ooooooooooooo`00og3ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol0
0?oooooooooooooooooo003o06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1goooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo
003o06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o06oooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool03Oooool01Ol00?oooooooooooooooooo003o06oooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol0
0?oooooooooooooooooo003o06oooooo0Ol00001ooooo`006oooool2o`0007Sooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l0K_ooool2
o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0=ooooo`05o`00ooooooooooooooooool00?l0Koooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0KOooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo07Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool0KOooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool0KOooool1o`00007ooooo0008ooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1fooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo06gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`1fooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo06cooooo
0Ol00001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
0_ooool2o`0006Kooooo0_l00?l?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo06_ooooo0_l00001ooooo`001ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
IOooool2o`00o`oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool0K?ooool1o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo06Cooooo00?o003oooooool00?l0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Cooooo00Co003ooooooooooooo
003o3_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool000Sooooo0_l00008ooooo`Go0000
1?ooool00ol0003oooooooooo`1Tooooo`04o`00ooooooooooooo`00o`kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Cooooo00Co003ooooooooooooo
003o3_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
I?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06cooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1Tooooo`04o`00ooooooooooooo`00o`kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool0K?ooool1o`00007ooooo000Kooooo`;o0000I?ooool01Ol00?oooooooooooooooooo003o00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool0Joooool2o`00007ooooo000Kooooo`03o`000?oooooooooo06?ooooo
00Go003oooooooooooooooooo`00o`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo06cooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1Sooooo`05o`00ooooooooooooooooool00?l03_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`1/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Hoooool01Ol00?oooooo
oooooooooooo003o00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0K?ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo06?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo06cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Sooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1/ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0H_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
06;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
06cooooo0Ol00001ooooo`006oooool2o`0006?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo06_ooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`1Rooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`1[ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0H_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0Joooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00cooooo0_l00?mMooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0H_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooo`00o`1Looooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0H_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooo`00o`1Looooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
H_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
2oooool01?l00?ooooooooooool00?mLooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
H_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
2oooool01Ol00?oooooooooooooooooo003o05_ooooo0Ol00001ooooo`006oooool2o`0006;ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00_ooooo
00Go003oooooooooooooooooo`00o`1Jooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
HOooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo05Sooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0F?oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`1Hooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0HOooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo05Sooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0F?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`1Gooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0D?ooool3o`00o`kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`1Gooooo`7o00000Oooool001_ooooo0_l0001@
ooooo`;o003o00?oooooo`00ool00?l03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo05Kooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1?ooooo`05o`00oooooooooooo
ooooool00?l03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Oooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1>ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Oooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1>ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo05Kooooo0Ol00001ooooo`005?oo
ool2o`0000Gooooo00?o0000ooooooooool0COooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`Ko003oA_oo
ool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0C?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`09ooooo`;o003o1Oooool00ol00?ooooooooooo`13ooooo`7o00000Ooo
ool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0hooooo`Wo003o2ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0@_oo
ool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo1_l0000eo`00o`Wo00000ol0
0?l7o`000003o`00ool0003o000000So000000?o003oo`000?l000001ol000000ol00?oo0000o`00
0007o`000003o`00ool0003o000000Oo000000?o003oo`000?l000001ol000000ol00?oo0000o`00
0008o`000003o`00ool0003o000000Oo000000?o003oo`000?l000002?l000000ol00?oo0000o`00
0007o`000003o`00ool0003o000000Oo000000?o003oo`000?l000001ol00004o`00o`03o`000?l0
0?oo003o037o003o1`000?l6o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0A?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02_ooool3o`00ockooooo0Ol00001ooooo`004oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo04Cooooo0ol00?l01?oooooo003oo`00ool00?l;ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo04cooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0A_oo
ool3o`00o`gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0COooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo05Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0COooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
05Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool0C_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05Oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool0C_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05Oooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooool0
0?l0DOooool1o`00007ooooo000Kooooo`;o0000F?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00_ooooo0ol00?mAooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Eooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo063ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1Gooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0HOooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`1Qooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0F?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo067ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1Hooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0HOooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo05Sooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1Qooooo`7o00000Oooool001_ooooo0_l0001Jooooo`05o`00ooooooooooooooooool00?l03Ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0H?oo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo05Wooooo00Go003oooooooooooooooooo`00
o`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`1Qooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0FOooool01Ol00?oooooooooooooo
oooo003o00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo06;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Jooooo`04o`00oooooooo
ooooo`00o`gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo06;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Jooooo`03o`00oooooooo
003o00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo06;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Kooooo`;o003o3_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0H_ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo06_ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo06;ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1[ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`1Rooooo`7o00000Oooool001_ooooo0_l0001/ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`1Qooooo`;o00000Oooool001_ooooo00?o0000
ooooooooool0Joooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool0H_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06_ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06?ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1/ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`1Sooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
K?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
Hoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06cooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02ooo
ool01Ol00?oooooooooooooooooo003o06Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1/ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00o`1Uooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0;ooooo`05o`00oooo
ooooooooooooool00?l0IOooool1o`00007ooooo000Kooooo`;o0000KOooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0;ooooo`05o`00ooooooooooooooooool00?l0I?ooool2o`00007ooooo000Kooooo`03o`000?oo
oooooooo06cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool02oooool01Ol00?oooooooooooooooooo003o06Gooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1/ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00Co
003ooooooooooooo003oI_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03?ooool01?l00?ooooooooooool00?mVooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0K?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`04o`00ooooooooooooo`00ofKooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1]ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00Co
003ooooooooooooo003oI_ooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`1]ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o
003oooooool00?l0I_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06gooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3Oooool00ol00?ooooooo`00o`1Vooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo0000
2oooool00ol0003oooooooooo`02ooooo`;o0000K_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`;o003o
I_ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1]ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
IOooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`00
0?oooooooooo06gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool0M_ooool1o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1]ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo07Kooooo0Ol00001ooooo`002?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oo
oooooooo06gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool0M_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo06gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool0M_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
06gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool0M_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06go
oooo00Go003oooooooooooooooooo`00o`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool0M_ooool1o`00007ooooo000Kooooo`;o0000K_ooool01Ol00?oooooooooooooooooo003o
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`1eooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool0KOooool01Ol00?oooooooooooooooooo003o00oooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`1fooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0KOooool01Ol00?oooooooooooooooooo003o00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`1fooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0KOooool01Ol00?oo
oooooooooooooooo003o00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1goooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0KOooool01Ol00?oooooooooooooooooo003o
00oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1gooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0KOooool01Ol00?oooooooooooooooooo003o00oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`1gooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0K_ooool01?l00?ooooooooooool00?l?ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool0Moooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06kooooo00Co003ooooooooo
oooo003o3oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo07Oooooo0Ol00001oooo
o`006oooool2o`0006oooooo00Co003ooooooooooooo003o3oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo07Kooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1^ooooo`04
o`00ooooooooooooo`00o`oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1goooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0K_ooool01?l00?ooooooooooool00?l?oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Moooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo06kooooo00?o003oooooool00?l04Oooool01Ol00?oooooooooooooooooo003o
07Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`;o003o4Oooool01Ol00?oo
oooooooooooooooo003o07Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`;o
003o4Oooool01?l00?ooooooooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0Koooool2o`00oa7ooooo00Co003ooooooooooooo003oN_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo08;ooooo00Co003ooooooooooooo003oN_ooool1o`00007ooooo000Kooooo`;o
0000Poooool01?l00?ooooooooooool00?miooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool0P_ooool01?l00?ooooooooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0P_ooool01?l00?ooooooooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0P_ooool01?l00?ooooooooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0P_ooool01?l00?ooooooooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0P_ooool01?l00?ooooooooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0P_ooool01?l00?ooooooooooool00?mjooooo`7o00000Oooool001_ooooo0_l00023ooooo`04
o`00ooooooooooooo`00ogWooooo0_l00001ooooo`006oooool00ol0003oooooooooo`23ooooo`03
o`00oooooooo003o07[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`23ooooo`03o`00
oooooooo003o07[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`23ooooo`03o`00oooo
oooo003o07[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`23ooooo`03o`00oooooooo
003o07[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`23ooooo`;o003oNoooool1o`00
007ooooo000Cooooo`?o00001Oooool00ol0003oooooooooo`23ooooo`;o003oNoooool1o`00007o
oooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool1ooooo`7o0000
0Oooool001Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`02ooooo`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool1
o`00007ooooo000Dooooo`03o`000?oooooooooo00Coooooool00005o`00007ooooo000Cooooo`;o
0000ooooool<ooooo`005?ooool00ol0003oooooooooo`3oooooo`[ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.08154, -1.18618, \
0.032354, 0.012731}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sample discrete-time signal (continuous-time to discrete-time \
conversion)\
\>", "Subsection"],

Cell["\<\
Adjust sampling rate below (in Hz) to see different sampling \
results.\
\>", "Text"],

Cell[BoxData[
    \(\(sampleRate = 10;\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sampled\  = 
        Table[{t, f1[t]}, {t, 0, 8, 
            1/sampleRate}];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        DiscreteListPlot[sampled, Red, PlotRange \[Rule] All, \ 
          Frame \[Rule] True, \ 
          Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(Show[g2, g1];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.309017 0.322076 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06746 -30 -4.5 ]
[-0.0125 .06746 0 4.5 ]
[-0.0125 .14798 -24 -4.5 ]
[-0.0125 .14798 0 4.5 ]
[-0.0125 .2285 -30 -4.5 ]
[-0.0125 .2285 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38954 -24 -4.5 ]
[-0.0125 .38954 0 4.5 ]
[-0.0125 .47006 -18 -4.5 ]
[-0.0125 .47006 0 4.5 ]
[-0.0125 .55057 -24 -4.5 ]
[-0.0125 .55057 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(6)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(8)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06746 m
.00625 .06746 L
s
[(-0.75)] -0.0125 .06746 1 0 Mshowa
0 .14798 m
.00625 .14798 L
s
[(-0.5)] -0.0125 .14798 1 0 Mshowa
0 .2285 m
.00625 .2285 L
s
[(-0.25)] -0.0125 .2285 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .38954 m
.00625 .38954 L
s
[(0.25)] -0.0125 .38954 1 0 Mshowa
0 .47006 m
.00625 .47006 L
s
[(0.5)] -0.0125 .47006 1 0 Mshowa
0 .55057 m
.00625 .55057 L
s
[(0.75)] -0.0125 .55057 1 0 Mshowa
.125 Mabswid
0 .08356 m
.00375 .08356 L
s
0 .09967 m
.00375 .09967 L
s
0 .11577 m
.00375 .11577 L
s
0 .13188 m
.00375 .13188 L
s
0 .16408 m
.00375 .16408 L
s
0 .18019 m
.00375 .18019 L
s
0 .19629 m
.00375 .19629 L
s
0 .21239 m
.00375 .21239 L
s
0 .2446 m
.00375 .2446 L
s
0 .26071 m
.00375 .26071 L
s
0 .27681 m
.00375 .27681 L
s
0 .29291 m
.00375 .29291 L
s
0 .32512 m
.00375 .32512 L
s
0 .34122 m
.00375 .34122 L
s
0 .35733 m
.00375 .35733 L
s
0 .37343 m
.00375 .37343 L
s
0 .40564 m
.00375 .40564 L
s
0 .42174 m
.00375 .42174 L
s
0 .43785 m
.00375 .43785 L
s
0 .45395 m
.00375 .45395 L
s
0 .48616 m
.00375 .48616 L
s
0 .50226 m
.00375 .50226 L
s
0 .51837 m
.00375 .51837 L
s
0 .53447 m
.00375 .53447 L
s
0 .05136 m
.00375 .05136 L
s
0 .03525 m
.00375 .03525 L
s
0 .01915 m
.00375 .01915 L
s
0 .00304 m
.00375 .00304 L
s
0 .56668 m
.00375 .56668 L
s
0 .58278 m
.00375 .58278 L
s
0 .59889 m
.00375 .59889 L
s
0 .61499 m
.00375 .61499 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06746 m
1 .06746 L
s
.99375 .14798 m
1 .14798 L
s
.99375 .2285 m
1 .2285 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38954 m
1 .38954 L
s
.99375 .47006 m
1 .47006 L
s
.99375 .55057 m
1 .55057 L
s
.125 Mabswid
.99625 .08356 m
1 .08356 L
s
.99625 .09967 m
1 .09967 L
s
.99625 .11577 m
1 .11577 L
s
.99625 .13188 m
1 .13188 L
s
.99625 .16408 m
1 .16408 L
s
.99625 .18019 m
1 .18019 L
s
.99625 .19629 m
1 .19629 L
s
.99625 .21239 m
1 .21239 L
s
.99625 .2446 m
1 .2446 L
s
.99625 .26071 m
1 .26071 L
s
.99625 .27681 m
1 .27681 L
s
.99625 .29291 m
1 .29291 L
s
.99625 .32512 m
1 .32512 L
s
.99625 .34122 m
1 .34122 L
s
.99625 .35733 m
1 .35733 L
s
.99625 .37343 m
1 .37343 L
s
.99625 .40564 m
1 .40564 L
s
.99625 .42174 m
1 .42174 L
s
.99625 .43785 m
1 .43785 L
s
.99625 .45395 m
1 .45395 L
s
.99625 .48616 m
1 .48616 L
s
.99625 .50226 m
1 .50226 L
s
.99625 .51837 m
1 .51837 L
s
.99625 .53447 m
1 .53447 L
s
.99625 .05136 m
1 .05136 L
s
.99625 .03525 m
1 .03525 L
s
.99625 .01915 m
1 .01915 L
s
.99625 .00304 m
1 .00304 L
s
.99625 .56668 m
1 .56668 L
s
.99625 .58278 m
1 .58278 L
s
.99625 .59889 m
1 .59889 L
s
.99625 .61499 m
1 .61499 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.03571 .30902 m
.03571 .30902 L
s
.04762 .30902 m
.04762 .30902 L
s
.05952 .30902 m
.05952 .30902 L
s
.07143 .30902 m
.07143 .30902 L
s
.08333 .30902 m
.08333 .30902 L
s
.09524 .30902 m
.09524 .30902 L
s
.10714 .30902 m
.10714 .30902 L
s
.11905 .30902 m
.11905 .30903 L
s
.13095 .30902 m
.13095 .30903 L
s
.14286 .30902 m
.14286 .30902 L
s
.15476 .30902 m
.15476 .30896 L
s
.16667 .30902 m
.16667 .3089 L
s
.17857 .30902 m
.17857 .30895 L
s
.19048 .30902 m
.19048 .30924 L
s
.20238 .30902 m
.20238 .30964 L
s
.21429 .30902 m
.21429 .30961 L
s
.22619 .30902 m
.22619 .30852 L
s
.2381 .30902 m
.2381 .30659 L
s
.25 .30902 m
.25 .30585 L
s
.2619 .30902 m
.2619 .30902 L
s
.27381 .30902 m
.27381 .31607 L
s
.28571 .30902 m
.28571 .32101 L
s
.29762 .30902 m
.29762 .31455 L
s
.30952 .30902 m
.30952 .29438 L
s
.32143 .30902 m
.32143 .27507 L
s
.33333 .30902 m
.33333 .28235 L
s
.34524 .30902 m
.34524 .32738 L
s
.35714 .30902 m
.35714 .38159 L
s
.36905 .30902 m
.36905 .38672 L
s
.38095 .30902 m
.38095 .30902 L
s
.39286 .30902 m
.39286 .1931 L
s
.40476 .30902 m
.40476 .1475 L
s
.41667 .30902 m
.41667 .24804 L
s
.42857 .30902 m
.42857 .4411 L
s
.44048 .30902 m
.44048 .55985 L
s
.45238 .30902 m
.45238 .47034 L
s
.46429 .30902 m
.46429 .21806 L
s
.47619 .30902 m
.47619 .01472 L
s
.4881 .30902 m
.4881 .05104 L
s
.5 .30902 m
.5 .30902 L
s
.5119 .30902 m
.5119 .56699 L
s
.52381 .30902 m
.52381 .60332 L
s
.53571 .30902 m
.53571 .39998 L
s
.54762 .30902 m
.54762 .1477 L
s
.55952 .30902 m
.55952 .05818 L
s
.57143 .30902 m
.57143 .17694 L
s
.58333 .30902 m
.58333 .36999 L
s
.59524 .30902 m
.59524 .47053 L
s
.60714 .30902 m
.60714 .42493 L
s
.61905 .30902 m
.61905 .30902 L
s
.63095 .30902 m
.63095 .23132 L
s
.64286 .30902 m
.64286 .23644 L
s
.65476 .30902 m
.65476 .29065 L
s
.66667 .30902 m
.66667 .33568 L
s
.67857 .30902 m
.67857 .34296 L
s
.69048 .30902 m
.69048 .32365 L
s
.70238 .30902 m
.70238 .30349 L
s
.71429 .30902 m
.71429 .29702 L
s
.72619 .30902 m
.72619 .30197 L
s
.7381 .30902 m
.7381 .30902 L
s
.75 .30902 m
.75 .31218 L
s
.7619 .30902 m
.7619 .31144 L
s
.77381 .30902 m
.77381 .30952 L
s
.78571 .30902 m
.78571 .30842 L
s
.79762 .30902 m
.79762 .3084 L
s
.80952 .30902 m
.80952 .3088 L
s
.82143 .30902 m
.82143 .30908 L
s
.83333 .30902 m
.83333 .30914 L
s
.84524 .30902 m
.84524 .30908 L
s
.85714 .30902 m
.85714 .30902 L
s
.86905 .30902 m
.86905 .309 L
s
.88095 .30902 m
.88095 .30901 L
s
.89286 .30902 m
.89286 .30902 L
s
.90476 .30902 m
.90476 .30902 L
s
.91667 .30902 m
.91667 .30902 L
s
.92857 .30902 m
.92857 .30902 L
s
.94048 .30902 m
.94048 .30902 L
s
.95238 .30902 m
.95238 .30902 L
s
.96429 .30902 m
.96429 .30902 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .30902 Mdot
.03571 .30902 Mdot
.04762 .30902 Mdot
.05952 .30902 Mdot
.07143 .30902 Mdot
.08333 .30902 Mdot
.09524 .30902 Mdot
.10714 .30902 Mdot
.11905 .30903 Mdot
.13095 .30903 Mdot
.14286 .30902 Mdot
.15476 .30896 Mdot
.16667 .3089 Mdot
.17857 .30895 Mdot
.19048 .30924 Mdot
.20238 .30964 Mdot
.21429 .30961 Mdot
.22619 .30852 Mdot
.2381 .30659 Mdot
.25 .30585 Mdot
.2619 .30902 Mdot
.27381 .31607 Mdot
.28571 .32101 Mdot
.29762 .31455 Mdot
.30952 .29438 Mdot
.32143 .27507 Mdot
.33333 .28235 Mdot
.34524 .32738 Mdot
.35714 .38159 Mdot
.36905 .38672 Mdot
.38095 .30902 Mdot
.39286 .1931 Mdot
.40476 .1475 Mdot
.41667 .24804 Mdot
.42857 .4411 Mdot
.44048 .55985 Mdot
.45238 .47034 Mdot
.46429 .21806 Mdot
.47619 .01472 Mdot
.4881 .05104 Mdot
.5 .30902 Mdot
.5119 .56699 Mdot
.52381 .60332 Mdot
.53571 .39998 Mdot
.54762 .1477 Mdot
.55952 .05818 Mdot
.57143 .17694 Mdot
.58333 .36999 Mdot
.59524 .47053 Mdot
.60714 .42493 Mdot
.61905 .30902 Mdot
.63095 .23132 Mdot
.64286 .23644 Mdot
.65476 .29065 Mdot
.66667 .33568 Mdot
.67857 .34296 Mdot
.69048 .32365 Mdot
.70238 .30349 Mdot
.71429 .29702 Mdot
.72619 .30197 Mdot
.7381 .30902 Mdot
.75 .31218 Mdot
.7619 .31144 Mdot
.77381 .30952 Mdot
.78571 .30842 Mdot
.79762 .3084 Mdot
.80952 .3088 Mdot
.82143 .30908 Mdot
.83333 .30914 Mdot
.84524 .30908 Mdot
.85714 .30902 Mdot
.86905 .309 Mdot
.88095 .30901 Mdot
.89286 .30902 Mdot
.90476 .30902 Mdot
.91667 .30902 Mdot
.92857 .30902 Mdot
.94048 .30902 Mdot
.95238 .30902 Mdot
.96429 .30902 Mdot
.97619 .30902 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`009_ooool2
o`0003Sooooo1Ol0000jooooo`?o0000>?ooool3o`0003Wooooo0ol00007ooooo`009Oooool01?l0
003oooooooooool0000hooooo`04o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool0=_oo
ool01Ol0003ooooooooooooooooo000003Oooooo00Go0000ooooooooooooooooo`000006ooooo`00
9Oooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo03Sooooo1Ol0000gooooo`05
o`000?ooooooooooooooool00000=oooool01Ol0003ooooooooooooooooo000000Kooooo000Uoooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0=oooool01?l0003oooooooooool0
000hooooo`Co0000>Oooool3o`0000Oooooo000Uooooo`04o`000?ooooooooooo`0003Oooooo00Go
0000ooooooooooooooooo`00000iooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0
>Oooool01Ol0003ooooooooooooooooo000000Kooooo000Uooooo`04o`000?ooooooooooo`0003Oo
oooo00Go0000ooooooooooooooooo`00000jooooo`;o0000>Oooool00ol0003oooooooooo`0hoooo
o`05o`000?ooooooooooooooool000001_ooool002Kooooo0_l0000iooooo`?o0000??ooool00ol0
003oooooooooo`0hooooo`;o0000>Oooool3o`0000Oooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo000Qooooo`0300000?l0003o00000?[o00000@000001oooo
o`008Oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool10000007ooooo000Qooooo`0300000?oooooooooo0?[ooooo0@000001ooooo`008Ooo
ool00`00003oooooooooo`1dooooo`?oo`00Poooool10000007ooooo000Qooooo`0300000?oooooo
oooo07Cooooo0ooo0023ooooo`4000000Oooool0027ooooo00<00000o`000?ooool0M?ooool3ool0
08;ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo07Gooooo00<0o`00oooooooo
ool0P_ooool10000007ooooo000Qooooo`0300000?oooooooooo07Gooooo00<0o`00ooooooooool0
P_ooool10000007ooooo000Qooooo`0300000?oooooooooo07Gooooo00<0o`00ooooooooool0P_oo
ool10000007ooooo000Qooooo`0300000?l0003ooooo07Gooooo00<0o`00ooooooooool0POooool1
o`00004000000Oooool0027ooooo00<00000ooooooooool0MOooool00`3o003oooooooooo`22oooo
o`4000000Oooool0027ooooo00<00000ooooooooool0MOooool00`3o003oooooooooo`22ooooo`40
00000Oooool0027ooooo00<00000ooooooooool0MOooool00`3o003oooooool00002ool0083ooooo
0@000001ooooo`008Oooool00`00003o0000ooooo`1eooooo`030?l00?ooooooo`0000;oo`00Oooo
ool1o`00004000000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00<00000ooooooooool0MOooool00`3o003oooooool00002
ool000oooooo0ooo001^ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00`00003ooooooooo
o`1eooooo`050?l00?ooooooooooooooo`3o00003oooool3ool006kooooo0@000001ooooo`001Ol0
0002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`0300000?oooooooooo07Gooooo00D0o`00oooooooooooooooo0?l0000?ooooo`?o
o`00K_ooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`0300000?l0003ooooo07Gooooo00D0o`00oooooooo
oooooooo0?l0000Aooooo`030?l00?oooooooooo06_ooooo0Ol000010000007ooooo0007ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooool000000ol00005ooooo`0300000?oooooooooo
07Gooooo00D0o`00oooooooooooooooo0?l0000Aooooo`030?l00?oooooooooo06cooooo0@000001
ooooo`001oooool01?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003ooooo
o`000008ooooo`0300000?oooooooooo07Gooooo00D0o`00oooooooooooooooo0?l0000Aooooo`03
0?l00?oooooooooo06cooooo0@000001ooooo`002?ooool2o`0000Sooooo1Ol000000ooooooo0000
o`000003o`0000Cooooo00<00000ooooooooool0MOooool01@3o003oooooooooooooool0o`00017o
oooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?l0003ooooo07Gooooo
00D0o`00oooooooooooooooo0?l0000Aooooo`030?l00?oooooooooo06_ooooo0Ol000010000007o
oooo000Qooooo`0300000?oooooooooo07Gooooo00D0o`00oooooooooooooooo0?l0000Aooooo`03
0?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003oooooooooo`1eooooo`050?l0
0?ooooooooooooooo`3o00004Oooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo
00<00000ooooooooool0MOooool01@3o003oooooooooooooool0o`00017ooooo00<0o`00oooooooo
ool0K?ooool10000007ooooo000Qooooo`0300000?l0003ooooo07Gooooo00D0o`00oooooooooooo
oooo0?l0000Aooooo`030?l00?oooooooooo06_ooooo0Ol000010000007ooooo000Qooooo`030000
0?oooooooooo07Gooooo00D0o`00oooooooooooooooo0?l0000Aooooo`030?l00?oooooooooo06co
oooo0@000001ooooo`008Oooool00`00003oooooooooo`1eooooo`050?l00?ooooooooooooooo`3o
00004Oooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo00<00000ooooooooool0
MOooool01@3o003oooooooooooooool0o`00017ooooo00<0o`00ooooooooool0K?ooool10000007o
oooo000Qooooo`0300000?l0003ooooo07Gooooo00D0o`00oooooooooooooooo0?l0000Aooooo`03
0?l00?oooooooooo06_ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo07Gooooo
00D0o`00oooooooooooooooo0?l0000Aooooo`030?l00?oooooooooo06cooooo0@000001ooooo`00
8Oooool00`00003oooooooooo`1eooooo`050?l00?ooooooooooooooo`3o00004Oooool00`3o003o
ooooooooo`1/ooooo`4000000Oooool0027ooooo00<00000ooooooooool0MOooool01@3o003ooooo
ooooooooool0o`00017ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`030000
0?l0003ooooo07Gooooo00D0o`00oooooooooooooooo0?l0000Aooooo`030?l00?oooooooooo06_o
oooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo07Gooooo00D0o`00oooooooooooo
oooo0?l0000Aooooo`030?l00?oooooooooo06cooooo0@000001ooooo`003_ooool2o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000Gooooo00<00000ooooooooool0MOooool01@3o003ooooo
ooooooooool0o`00017ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000=ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooooooo
07Gooooo00D0o`00oooooooooooooooo0?l0000Aooooo`030?l00?oooooooooo06cooooo0@000001
ooooo`001_ooool5o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02
ooooo`0300000?l0003ooooo06;ooooo0ooo000@ooooo`050?l00?ooooooooooooooo`3o00003?oo
ool3ool000;ooooo00<0o`00ooooooooool0Joooool1o`00004000000Oooool000gooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo06;ooooo0ooo
000@ooooo`050?l00?ooooooooooooooo`3o00003?ooool3ool000;ooooo00<0o`00ooooooooool0
K?ooool10000007ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`030000
0?oooooooooo06;ooooo0ooo000@ooooo`050?l00?ooooooooooooooo`3o00003?ooool3ool000;o
oooo00<0o`00ooooooooool0K?ooool10000007ooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool01_ooool00`00003oooooooooo`1Sooooo`030?l00?oooooooooo00oo
oooo00D0o`00oooooooooooooooo0?l0000>ooooo`040?l00?oooooooooo0?l006kooooo0@000001
ooooo`003_ooool2o`0000Sooooo1Ol00004ooooo`0300000?l0003ooooo06?ooooo00<0o`00oooo
ooooool03oooool01@3o003oooooooooooooool0o`0000kooooo00@0o`00ooooooooool0o`00KOoo
ool1o`00004000000Oooool0027ooooo00<00000ooooooooool0Hoooool00`3o003oooooooooo`0?
ooooo`050?l00?ooooooooooooooo`3o00003_ooool0103o003oooooooooo`3o001^ooooo`400000
0Oooool0027ooooo00<00000ooooooooool0Hoooool00`3o003oooooooooo`0?ooooo`050?l00?oo
ooooooooooooo`3o00003_ooool0103o003oooooooooo`3o001^ooooo`4000000Oooool0027ooooo
00<00000ooooooooool0Hoooool00`3o003oooooooooo`0?ooooo`050?l00?ooooooooooooooo`3o
00003_ooool0103o003oooooooooo`3o0003ool006_ooooo0@000001ooooo`008Oooool00`00003o
0000ooooo`1Sooooo`030?l00?oooooooooo00oooooo00D0o`00oooooooooooooooo0?l0000>oooo
o`040?l00?oooooooooo0?l000?oo`00J_ooool1o`00004000000Oooool0027ooooo00<00000oooo
ooooool0Hoooool00`3o003oooooooooo`0?ooooo`050?l00?ooooooooooooooo`3o00003_ooool0
103o003oooooooooo`3o0003ool006_ooooo0@000001ooooo`008Oooool00`00003oooooooooo`1S
ooooo`030?l00?oooooooooo00oooooo00D0o`00oooooooooooooooo0?l0000>ooooo`040?l00?oo
oooooooo0?l000;ooooo00<0o`00ooooooooool0JOooool10000007ooooo000Qooooo`0300000?oo
oooooooo05oooooo0ooo00000oooool0o`00ooooo`0@ooooo`050?l00?ooooooooooooooo`3o0000
3_ooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo06Wooooo0@000001ooooo`00
8Oooool00`00003oooooooooo`1Oooooo`?oo`0000?ooooo0?l00?ooool04?ooool01@3o003ooooo
ooooooooool0o`0000kooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`1Yoooo
o`4000000Oooool0027ooooo00<00000o`000?ooool0Goooool3ool00003ooooo`3o003ooooo013o
oooo00D0o`00oooooooooooooooo0?l0000>ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00
ooooooooool0J?ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0H?ooool0103o
003oooooooooo`3o000Aooooo`050?l00?ooooooooooooooo`3o00003_ooool0103o003ooooooooo
o`3o0002ooooo`030?l00?oooooooooo06Wooooo0@000001ooooo`008Oooool00`00003ooooooooo
o`1Pooooo`040?l00?oooooooooo0?l0017ooooo00D0o`00oooooooooooooooo0?l0000>ooooo`04
0?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool0JOooool10000007ooooo000Qooooo`03
00000?oooooooooo063ooooo00@0o`00ooooooooool0o`004Oooool01@3o003oooooooooooooool0
o`0000kooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`1Yooooo`4000000Ooo
ool0027ooooo00<00000o`000?ooool0H?ooool0103o003oooooooooo`3o000=ooooo`?oo`0000?o
oooo0?l00?ooool00_ooool00`3o003oooooooooo`0<ooooo`040?l00?oooooooooo0?l000;ooooo
00<0o`00ooooooooool0J?ooool1o`00004000000Oooool000Sooooo0_l00004ooooo`04o`000?oo
ooooooooooooo`Go00000_ooool3o`0000Gooooo00<00000ooooooooool0H?ooool0103o003ooooo
ooooo`3o000=ooooo`?oo`0000?ooooo0?l00?ooool00_ooool00`3o003oooooooooo`0<ooooo`04
0?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool0JOooool10000007ooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00;ooooo00<00000ooooooooool0H?ooool0103o003oooooooooo`3o000=ooooo`?oo`00
00?ooooo0?l00?ooool00_ooool00`3o003oooooooooo`0<ooooo`040?l00?oooooooooo0?l000;o
oooo00<0o`00ooooooooool0JOooool10000007ooooo0005o`0000;ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00<00000oooooooo
ool0H?ooool0103o003oooooooooo`3o000>ooooo`040?l00?oooooooooo0?l000?ooooo00<0o`00
ooooooooool03?ooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo06Wooooo0@00
0001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00`00003o0000ooooo`1Pooooo`040?l00?oooooooooo0?l000kooooo
00@0o`00ooooooooool0o`000oooool00`3o003oooooooooo`0<ooooo`040?l00?oooooooooo0?l0
00;ooooo00<0o`00ooooooooool02_ooool3ool005_ooooo0Ol000010000007ooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Gooooo00<0
0000ooooooooool0H?ooool0103o003oooooooooo`3o000>ooooo`040?l00?oooooooooo0?l000?o
oooo00<0o`00ooooooooool03?ooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo
00[ooooo1_oo001Iooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00001oooool01ol0
003ooooooooooooooooo0000ooooool000002?ooool00`00003oooooooooo`1Pooooo`040?l00?oo
oooooooo0?l000kooooo00@0o`00ooooooooool0o`000oooool00`3o003oooooooooo`0<ooooo`04
0?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool02_ooool6ool005Wooooo0@000001oooo
o`002?ooool2o`0000Wooooo0ol00002ooooo`Go00001?ooool00`00003oooooooooo`1Pooooo`04
0?l00?oooooooooo0?l000kooooo00@0o`00ooooooooool0o`000oooool00`3o003oooooooooo`0<
ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool03?ooool0103o003oo`00ool0
0?oo001Iooooo`4000000Oooool0027ooooo00<00000o`000?ooool0H?ooool01@3o003ooooooooo
o`3o003ooooo00?oo`002_ooool0103o003oooooooooo`3o0003ooooo`030?l00?oooooooooo00co
oooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0<ooooo`040?l00?oooooooooo
0?l005Sooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo063ooooo00D0o`00oooo
ooooool0o`00ooooo`03ool000[ooooo00@0o`00ooooooooool0o`000oooool00`3o003ooooooooo
o`0<ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool03?ooool0103o003ooooo
ooooo`3o001Iooooo`4000000Oooool0027ooooo00<00000ooooooooool0H?ooool01@3o003ooooo
ooooo`3o003ooooo00?oo`002_ooool0103o003oooooooooo`3o0003ooooo`030?l00?oooooooooo
00cooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0<ooooo`040?l00?oooooo
oooo0?l005Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`1Pooooo`040?l00?oooooo
oooo0?l000;ooooo00<0o`00ooooooooool02Oooool0103o003oooooooooo`3o0003ooooo`030?l0
0?oooooooooo00cooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0<ooooo`04
0?l00?oooooooooo0?l005Wooooo0@000001ooooo`008Oooool00`00003o0000ooooo`1Pooooo`04
0?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool02Oooool0103o003oooooooooo`3o0003
ooooo`030?l00?oooooooooo00cooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooooooo
o`0<ooooo`040?l00?oooooooooo0?l005Sooooo0Ol000010000007ooooo000Qooooo`0300000?oo
oooooooo063ooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`09ooooo`040?l0
0?oooooooooo0?l000?ooooo00<0o`00ooooooooool03?ooool0103o003oooooooooo`3o0002oooo
o`030?l00?oooooooooo00cooooo00@0o`00ooooooooool0o`00FOooool10000007ooooo000Qoooo
o`0300000?oooooooooo063ooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`09
ooooo`040?l00?oooooooooo0?l000?ooooo00<0o`00ooooooooool03?ooool0103o003ooooooooo
o`3o0002ooooo`030?l00?oooooooooo00cooooo00@0o`00ooooooooool0o`00FOooool10000007o
oooo000Qooooo`0300000?oooooooooo04gooooo0ooo000@ooooo`040?l00?oooooooooo0?l000;o
oooo00<0o`00ooooooooool02Oooool0103o003oooooooooo`3o0003ooooo`030?l00?oooooooooo
00cooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0<ooooo`040?l00?oooooo
oooo0?l005Wooooo0@000001ooooo`008Oooool00`00003o0000ooooo`1=ooooo`?oo`004?ooool0
103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo00Wooooo00@0o`00ooooooooool0o`00
0oooool00`3o003oooooooooo`0<ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00oooooooo
ool03?ooool0103o003oooooooooo`3o001Hooooo`7o00000@000001ooooo`008Oooool00`00003o
ooooooooo`1=ooooo`Koo`003Oooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo
00Wooooo00@0o`00ooooooooool0o`000oooool00`3o003oooooooooo`0<ooooo`040?l00?oooooo
oooo0?l000;ooooo00<0o`00ooooooooool03?ooool0103o003oooooooooo`3o001Iooooo`400000
0Oooool0027ooooo00<00000ooooooooool0C_ooool00`3o003oooooool00002ool000gooooo00@0
o`00ooooooooool0o`000_ooool00`3o003oooooooooo`09ooooo`040?l00?oooooooooo0?l000?o
oooo00<0o`00ooooooooool03?ooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo
00cooooo00@0o`00ooooooooool0o`00FOooool10000007ooooo000Qooooo`0300000?oooooooooo
04kooooo00<0o`00oooooooo00000_oo000=ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00
ooooooooool02Oooool0103o003oooooooooo`3o0003ooooo`030?l00?oooooooooo00cooooo00@0
o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0<ooooo`040?l00?oooooooooo0?l000?o
o`00E_ooool10000007ooooo000Qooooo`0300000?l0003ooooo04[ooooo0ooo00001Oooool0o`00
ooooooooool0o`0000kooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`09oooo
o`040?l00?oooooooooo0?l000?ooooo00<0o`00ooooooooool03?ooool0103o003oooooooooo`3o
0002ooooo`030?l00?oooooooooo00cooooo00@0o`00ooooooooool0o`000ooo000=ooooo`?oo`00
AOooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0B_ooool3ool00005ooooo`3o
003oooooooooo`3o00003_ooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo00Wo
oooo00@0o`00ooooooooool0o`000oooool00`3o003oooooooooo`0<ooooo`040?l00?oooooooooo
0?l000;ooooo00<0o`00ooooooooool03?ooool0103o003oooooooooo`3o0003ool000gooooo0ooo
0016ooooo`4000000Oooool001[ooooo0_l00005ooooo`0300000?oooooooooo04[ooooo0ooo0000
1Oooool0o`00ooooooooool0o`0000kooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo
ooooo`09ooooo`040?l00?oooooooooo0?l000?ooooo00<0o`00ooooooooool03?ooool0103o003o
ooooooooo`3o0002ooooo`030?l00?oooooooooo00cooooo00@0o`00ooooooooool0o`000_ooool0
0`3o003oooooooooo`07ooooo`?oo`0000?oooooool00?oo00001?oo0013ooooo`4000000Oooool0
01Wooooo00Co0000oooooooooooo00001?ooool01000003ooooooooooooooolHool00003oooooooo
003oo`00013oo`002Oooool<ool000[ooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo
ooooo`08ooooo`?oo`0000Gooooo0?l00?oooooooooo0?l00002ooooo`030?l00?oooooooooo00Wo
oooo00@0o`00ooooooooool0o`000oooool0103o003oo`00ool00?oo000;ooooo`040?l00?oooooo
oooo0?l000;ooooo00<0o`00ooooooooool01oooool3ool000;ooooo00@0o`00ooooooooool0o`00
0_ooool00`3o003oooooooooo`07ooooo`?oo`000_ooool00`3o003oooooool00005ool000Wooooo
2Ooo0009ooooob7oo`001?ooool10000007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo
1000000Hool0000300000?oo003oo`0002Goo`0000D000000?l00000000000000?l0000200000004
0?l00000000000000?l00080000000@0o`00000000000000o`000P000000103o000000000000003o
0002000000030?l00000003oo`0000;oo`0000D000000?l00000000000000?l00002000000040?l0
0000000000000?l00080000000@0o`00000000000000o`000P000000103o000000000000003o0003
000000040?l00?oo003oo`00ool00080000000@0o`00000000000000o`000P000000103o00000000
0000003o0002000000040?l00000000000000?l00080000000@0o`00000000000000o`000P000000
103o003oo`00ool00?oo0002000000040?l00000000000000?l00080000000@0o`00000000000000
o`000P000000103o000000000000003o0003ool00080000000<0o`0000000?oo0000@Ooo00050000
007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00@00000oooooooooooooooo6?oo0000
0oooooooo`00ool0000Xool00003ooooo`3o003ooooo00?oo`002_ooool0103o003oooooooooo`3o
0002ooooo`030?l00?ooooooo`0000;oo`002_ooool0103o003oooooooooo`3o0002ooooo`030?l0
0?oooooooooo00Sooooo0ooo0002ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00oooooooo
ool02Oooool0103o003oooooooooo`3o0002ooooo`040?l00?oo003oo`00ool000_ooooo00@0o`00
ooooooooool0o`000_ooool00`3o003oooooooooo`08ooooocooo`001?ooool10000007ooooo000I
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0;?ooool9ool000cooooo0ooo
00000oooool0o`00ooooo`03ool000[ooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo
ooooo`0<ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool03Oooool0103o003o
ooooooooo`3o0002ooooo`030?l00?oooooooooo00Wooooo00@0o`00ooooooooool0o`000_ooool0
0`3o003oooooooooo`0<ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool02ooo
ool9ool000Wooooo2Ooo000Uooooo`4000000Oooool001Wooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`11ooooo`Woo`002_ooool0103o003oooooooooo`3o0002ooooo`030?l0
0?oooooooooo00cooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0=ooooo`04
0?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool02Oooool0103o003oooooooooo`3o0002
ooooo`030?l00?oooooooooo00cooooo00@0o`00ooooooooool0o`000ooo001=ooooo`4000000Ooo
ool001[ooooo0_l00005ooooo`0300000?l0003ooooo04Cooooo0ooo000<ooooo`?oo`0000Gooooo
0?l00?oooooooooo0?l0000>ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool0
3Oooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo00Wooooo00@0o`00oooooooo
ool0o`000_ooool00`3o003oooooooooo`0<ooooo`040?l00?oooooooooo0?l000?oo`00C?ooool1
o`00004000000Oooool0027ooooo00<00000ooooooooool0A?ooool3ool000cooooo0ooo00001Ooo
ool0o`00ooooooooool0o`0000kooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooooooo
o`0=ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool02Oooool0103o003ooooo
ooooo`3o0002ooooo`030?l00?oooooooooo00cooooo00@0o`00ooooooooool0o`000ooo001=oooo
o`4000000Oooool0027ooooo00<00000ooooooooool0Doooool3ool00005ooooo`3o003ooooooooo
o`3o00003_ooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo00gooooo00@0o`00
ooooooooool0o`000_ooool00`3o003oooooooooo`09ooooo`040?l00?oooooooooo0?l000;ooooo
00<0o`00ooooooooool02_ooool3ool000;ooooo00<0o`00ooooooooool0C_ooool10000007ooooo
000Qooooo`0300000?oooooooooo05Oooooo00@0o`00ooooooooool0o`003_ooool0103o003ooooo
ooooo`3o0002ooooo`030?l00?oooooooooo00gooooo00@0o`00ooooooooool0o`000_ooool00`3o
003oooooooooo`09ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool02_ooool3
ool000;ooooo00<0o`00ooooooooool0C_ooool10000007ooooo000Qooooo`0300000?l0003ooooo
05Oooooo00@0o`00ooooooooool0o`003_ooool0103o003oooooooooo`3o0002ooooo`030?l00?oo
oooooooo00gooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`09ooooo`040?l0
0?oooooooooo0?l000;ooooo00<0o`00ooooooooool02_ooool6ool004oooooo0Ol000010000007o
oooo000Qooooo`0300000?oooooooooo05Oooooo00@0o`00ooooooooool0o`003_ooool0103o003o
ooooooooo`3o0002ooooo`030?l00?oooooooooo00gooooo00@0o`00ooooooooool0o`000_ooool0
0`3o003oooooooooo`09ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool03Ooo
ool3ool0053ooooo0@000001ooooo`008Oooool00`00003oooooooooo`1Gooooo`040?l00?oooooo
oooo0?l000kooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0=ooooo`040?l0
0?oooooooooo0?l000;ooooo00<0o`00ooooooooool02Oooool0103o003oooooooooo`3o0002oooo
o`030?l00?oooooooooo00gooooo0ooo001@ooooo`4000000Oooool0027ooooo00<00000oooooooo
ool0Eoooool0103o003oooooooooo`3o000>ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00
ooooooooool03Oooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo00Wooooo00@0
o`00ooooooooool0o`000_ooool00`3o003oooooooooo`1Pooooo`4000000Oooool0027ooooo00<0
0000o`000?ooool0Eoooool0103o003oooooooooo`3o000>ooooo`040?l00?oooooooooo0?l000;o
oooo00<0o`00ooooooooool03Oooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo
00Wooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`1Oooooo`7o00000@000001
ooooo`008Oooool00`00003oooooooooo`1Gooooo`040?l00?oooooooooo0?l000kooooo00@0o`00
ooooooooool0o`000_ooool00`3o003oooooooooo`0=ooooo`040?l00?oooooooooo0?l000;ooooo
00<0o`00ooooooooool02Oooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo063o
oooo0@000001ooooo`008Oooool00`00003oooooooooo`1Gooooo`040?l00?oooooooooo0?l000ko
oooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0=ooooo`040?l00?oooooooooo
0?l000;ooooo00<0o`00ooooooooool02Oooool0103o003oooooooooo`3o0002ooooo`030?l00?oo
oooooooo063ooooo0@000001ooooo`008Oooool00`00003oooooooooo`1Gooooo`040?l00?oooooo
oooo0?l000kooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0=ooooo`040?l0
0?oooooooooo0?l000;ooooo00<0o`00ooooooooool01oooool3ool000;ooooo00@0o`00oooooooo
ool0o`00H_ooool10000007ooooo000Qooooo`0300000?l0003ooooo05Oooooo00@0o`00oooooooo
ool0o`003_ooool0103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo00gooooo00@0o`00
ooooooooool0o`000_ooool00`3o003oooooooooo`07ooooo`?oo`000_ooool0103o003ooooooooo
o`3o001Qooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`1Gooooo`040?l00?oo
oooooooo0?l000kooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0=ooooo`04
0?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool01oooool3ool000;ooooo00@0o`00oooo
ooooool0o`00H_ooool10000007ooooo0008ooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000;ooooo0ol00005ooooo`0300000?oooooooooo05Kooooo0ooo00000oooool0o`00ooooo`0=
ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool03Oooool0103o003ooooooooo
o`3o0002ooooo`030?l00?oooooooooo00cooooo00@0o`00ooooooooool0o`00H_ooool10000007o
oooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0E_ooool6ool000gooooo00@0o`00
ooooooooool0o`000_ooool00`3o003oooooooooo`0=ooooo`040?l00?oooooooooo0?l000;ooooo
00<0o`00ooooooooool03?ooool0103o003oooooooooo`3o001Rooooo`4000000Oooool000Oooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00<00000ooooooooool0E_ooool6ool000gooooo00@0o`00ooooooooool0o`000_ooool00`3o
003oooooooooo`0=ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool03?ooool0
103o003oooooooooo`3o001Rooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00<00000o`000?ooool0FOoo
ool3ool000gooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0=ooooo`040?l0
0?oooooooooo0?l000;ooooo00<0o`00ooooooooool03?ooool0103o003oooooooooo`3o001Qoooo
o`7o00000@000001ooooo`001oooool01?l0003oooooooooool00007ooooo`06o`000?oooooooooo
ooooool0003ooooo1?l00005ooooo`0300000?oooooooooo06Wooooo00@0o`00ooooooooool0o`00
0_ooool00`3o003oooooooooo`0=ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00oooooooo
ool03?ooool0103o003oooooooooo`3o001Rooooo`4000000Oooool000Oooooo00Co0000oooooooo
oooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool00`00003ooooooooo
o`1Yooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooooooool03Oooool0103o003ooooo
ooooo`3o0003ool000kooooo00@0o`00ooooooooool0o`00H_ooool10000007ooooo0008ooooo`;o
00002Oooool3o`0000;ooooo1Ol00004ooooo`0300000?oooooooooo06Wooooo00@0o`00oooooooo
ool0o`000_ooool00`3o003oooooooooo`0=ooooo`040?l00?oooooooooo0?l000?oo`003_ooool0
103o003oooooooooo`3o001Rooooo`4000000Oooool0027ooooo00<00000o`000?ooool0JOooool0
103o003oooooooooo`3o0002ooooo`030?l00?oooooooooo00gooooo00@0o`00ooooooooool0o`00
0ooo000>ooooo`040?l00?oooooooooo0?l0067ooooo0Ol000010000007ooooo000Qooooo`030000
0?oooooooooo06Wooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0=ooooo`04
0?l00?oooooooooo0?l0017ooooo00@0o`00ooooooooool0o`00H_ooool10000007ooooo000Qoooo
o`0300000?oooooooooo06Wooooo00@0o`00ooooooooool0o`000_ooool00`3o003oooooooooo`0=
ooooo`040?l00?oooooooooo0?l0017ooooo00@0o`00ooooooooool0o`00H_ooool10000007ooooo
000Qooooo`0300000?oooooooooo06Wooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo
ooooo`0=ooooo`040?l00?oooooooooo0?l0017ooooo00@0o`00ooooooooool0o`00H_ooool10000
007ooooo000Qooooo`0300000?l0003ooooo06Wooooo00@0o`00ooooooooool0o`000_ooool00`3o
003oooooooooo`0=ooooo`040?l00?oooooooooo0?l0017ooooo00@0o`00ool00?oo003oo`00HOoo
ool1o`00004000000Oooool0027ooooo00<00000ooooooooool0JOooool0103o003oooooooooo`3o
0002ooooo`030?l00?oooooooooo00gooooo00@0o`00ooooooooool0o`004Oooool0103o003oo`00
ool00?oo001Rooooo`4000000Oooool0027ooooo00<00000ooooooooool0JOooool0103o003ooooo
ooooo`3o0002ooooo`030?l00?oooooooooo00gooooo00@0o`00ooooooooool0o`004Oooool0103o
003oo`00ool00?oo001Rooooo`4000000Oooool0027ooooo00<00000ooooooooool0JOooool0103o
003oooooooooo`3o0002ooooo`030?l00?oooooooooo00gooooo00@0o`00ooooooooool0o`004Ooo
ool00`3o003oooooooooo`1Sooooo`4000000Oooool0027ooooo00<00000o`000?ooool0J?ooool3
ool00005ooooo`3o003oooooooooo`3o00003oooool0103o003oooooooooo`3o000Aooooo`030?l0
0?oooooooooo06;ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo06Sooooo0ooo
00001Oooool0o`00ooooooooool0o`0000oooooo00@0o`00ooooooooool0o`004Oooool00`3o003o
ooooooooo`1Sooooo`4000000Oooool0027ooooo00<00000ooooooooool0J?ooool3ool00005oooo
o`3o003oooooooooo`3o00003oooool0103o003oooooooooo`3o000Aooooo`030?l00?oooooooooo
06?ooooo0@000001ooooo`008Oooool00`00003oooooooooo`1/ooooo`040?l00?oooooooooo0?l0
00oooooo00@0o`00ooooooooool0o`004Oooool00`3o003oooooooooo`1Sooooo`4000000Oooool0
027ooooo00<00000o`000?ooool0K?ooool0103o003oooooooooo`3o000?ooooo`040?l00?oooooo
oooo0?l0017ooooo00<0o`00ooooooooool0H_ooool1o`00004000000Oooool000kooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`0300000?oooooooooo06cooooo00@0o`00
ooooooooool0o`003oooool0103o003oooooooooo`3o000Aooooo`030?l00?oooooooooo06?ooooo
0@000001ooooo`003Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00`00003oooooooooo`1/ooooo`040?l00?oooooooooo0?l000oooooo00@0o`00oooo
ooooool0o`004Oooool00`3o003oooooooooo`1Sooooo`4000000Oooool000gooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo06cooooo00<0o`00
oooooooo00000_oo000>ooooo`040?l00?oooooooooo0?l000oooooo0ooo001Uooooo`4000000Ooo
ool000gooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`0300000?l0
003ooooo06cooooo00<0o`00oooooooo00000_oo000>ooooo`040?l00?oooooooooo0?l000oooooo
0ooo001Tooooo`7o00000@000001ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co0000
1Oooool00`00003oooooooooo`1/ooooo`030?l00?ooooooo`0000;oo`003_ooool0103o003ooooo
ooooo`3o000?ooooo`?oo`00IOooool10000007ooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool01_ooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo013o
oooo00@0o`00ooooooooool0o`00Moooool10000007ooooo000>ooooo`;o00002?ooool5o`0000Co
oooo00<00000ooooooooool0K?ooool00`3o003oooooooooo`0@ooooo`040?l00?oooooooooo0?l0
07Oooooo0@000001ooooo`008Oooool00`00003o0000ooooo`1/ooooo`030?l00?oooooooooo013o
oooo00@0o`00ooooooooool0o`00M_ooool1o`00004000000Oooool0027ooooo00<00000oooooooo
ool0K?ooool00`3o003oooooooooo`0@ooooo`040?l00?oooooooooo0?l007Oooooo0@000001oooo
o`008Oooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo013ooooo00@0o`00oooooooo
ool0o`00Moooool10000007ooooo000Qooooo`0300000?oooooooooo06cooooo00<0o`00oooooooo
ool04?ooool0103o003oooooooooo`3o001gooooo`4000000Oooool0027ooooo00<00000o`000?oo
ool0K?ooool00`3o003oooooooooo`0@ooooo`040?l00?oooooooooo0?l007Kooooo0Ol000010000
007ooooo000Qooooo`0300000?oooooooooo06cooooo00<0o`00ooooooooool04?ooool0103o003o
ooooooooo`3o001gooooo`4000000Oooool0027ooooo00<00000ooooooooool0K?ooool00`3o003o
ooooooooo`0@ooooo`040?l00?oooooooooo0?l007Oooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`1/ooooo`030?l00?oooooooooo013ooooo00@0o`00ooooooooool0o`00Moooool10000
007ooooo000Qooooo`0300000?l0003ooooo06cooooo00<0o`00ooooooooool04?ooool0103o003o
ooooooooo`3o001fooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`1/ooooo`03
0?l00?oooooooooo013ooooo00@0o`00ooooooooool0o`00Moooool10000007ooooo000Qooooo`03
00000?oooooooooo06cooooo00<0o`00ooooooooool04?ooool0103o003oooooooooo`3o001goooo
o`4000000Oooool0027ooooo00<00000ooooooooool0K?ooool00`3o003oooooooooo`0@ooooo`04
0?l00?oooooooooo0?l007Oooooo0@000001ooooo`008Oooool00`00003o0000ooooo`1/ooooo`03
0?l00?oooooooooo013ooooo00@0o`00ooooooooool0o`00M_ooool1o`00004000000Oooool0027o
oooo00<00000ooooooooool0K?ooool00`3o003oooooooooo`0@ooooo`040?l00?oooooooooo0?l0
07Oooooo0@000001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`?o00001Oooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo013o
oooo00@0o`00ooooooooool0o`00Moooool10000007ooooo0007ooooo`04o`000?ooooooooooo`00
00Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00<00000
ooooooooool0K?ooool00`3o003oooooooooo`0@ooooo`040?l00?oooooooooo0?l007Oooooo0@00
0001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00`00003o0000ooooo`1/ooooo`030?l00?oooooooooo013ooooo00@0
o`00ooooooooool0o`00M_ooool1o`00004000000Oooool000Oooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0
K?ooool00`3o003oooooooooo`0@ooooo`040?l00?oooooooooo0?l007Oooooo0@000001ooooo`00
1oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000?o00001Oooool00`00003o
ooooooooo`1[ooooo`?oo`004Oooool0103o003oooooooooo`3o001gooooo`4000000Oooool000Oo
oooo00Co0000oooooooooooo00001oooool01ol0003ooooooooooooooooo0000ooooool000002?oo
ool00`00003oooooooooo`1[ooooo`?oo`004Oooool0103o003oooooooooo`3o001gooooo`400000
0Oooool000Sooooo0_l00008ooooo`Go000000?oooooo`000?l000000ol00004ooooo`0300000?l0
003ooooo06_ooooo0ooo000?ooooo`?oo`000_ooool00`3o003oooooooooo`1dooooo`7o00000@00
0001ooooo`008Oooool00`00003oooooooooo`1mooooo`?oo`000_ooool00`3o003oooooooooo`1e
ooooo`4000000Oooool0027ooooo00<00000ooooooooool0OOooool3ool000;ooooo00<0o`00oooo
ooooool0MOooool10000007ooooo000Qooooo`0300000?oooooooooo08;ooooo00<0o`00oooooooo
ool0MOooool10000007ooooo000Qooooo`0300000?oooooooooo08;ooooo00<0o`00ooooooooool0
MOooool10000007ooooo000Qooooo`0300000?l0003ooooo08;ooooo00<0o`00ooooooooool0M?oo
ool1o`00004000000Oooool0027ooooo00<00000ooooooooool0P_ooool00`3o003oooooooooo`1e
ooooo`4000000Oooool0027ooooo00<00000ooooooooool0P_ooool00`3o003oooooooooo`1eoooo
o`4000000Oooool0027ooooo00<00000ooooooooool0P_ooool00`3o003oooooooooo`1eooooo`40
00000Oooool0027ooooo00<00000o`000?ooool0P?ooool3ool007Kooooo0Ol000010000007ooooo
000Qooooo`0300000?oooooooooo083ooooo0ooo001gooooo`4000000Oooool0027ooooo00<00000
ooooooooool0P?ooool3ool007Oooooo0@000001ooooo`008Oooool00`00003oooooooooo`03oooo
o`0300000?oooooooooo03Wooooo00<00000ooooooooool0>_ooool00`00003oooooooooo`0ioooo
o`0300000?oooooooooo03Wooooo00<00000ooooooooool00oooool10000007ooooo000Qooooo`03
00000?l0003ooooo00?ooooo00<00000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00`00003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
00000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00<00000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00`00003oooooooooo`02ooooo`7o
00000@000001ooooo`008Oooooon0000007ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.29833, -1.15719, \
0.0331097, 0.0122382}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.308941 0.302543 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0064 -12 -4.5 ]
[-0.0125 .0064 0 4.5 ]
[-0.0125 .15767 -24 -4.5 ]
[-0.0125 .15767 0 4.5 ]
[-0.0125 .30894 -6 -4.5 ]
[-0.0125 .30894 0 4.5 ]
[-0.0125 .46021 -18 -4.5 ]
[-0.0125 .46021 0 4.5 ]
[-0.0125 .61148 -6 -4.5 ]
[-0.0125 .61148 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(6)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(8)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0064 m
.00625 .0064 L
s
[(-1)] -0.0125 .0064 1 0 Mshowa
0 .15767 m
.00625 .15767 L
s
[(-0.5)] -0.0125 .15767 1 0 Mshowa
0 .30894 m
.00625 .30894 L
s
[(0)] -0.0125 .30894 1 0 Mshowa
0 .46021 m
.00625 .46021 L
s
[(0.5)] -0.0125 .46021 1 0 Mshowa
0 .61148 m
.00625 .61148 L
s
[(1)] -0.0125 .61148 1 0 Mshowa
.125 Mabswid
0 .03665 m
.00375 .03665 L
s
0 .06691 m
.00375 .06691 L
s
0 .09716 m
.00375 .09716 L
s
0 .12741 m
.00375 .12741 L
s
0 .18792 m
.00375 .18792 L
s
0 .21818 m
.00375 .21818 L
s
0 .24843 m
.00375 .24843 L
s
0 .27869 m
.00375 .27869 L
s
0 .3392 m
.00375 .3392 L
s
0 .36945 m
.00375 .36945 L
s
0 .3997 m
.00375 .3997 L
s
0 .42996 m
.00375 .42996 L
s
0 .49047 m
.00375 .49047 L
s
0 .52072 m
.00375 .52072 L
s
0 .55098 m
.00375 .55098 L
s
0 .58123 m
.00375 .58123 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0064 m
1 .0064 L
s
.99375 .15767 m
1 .15767 L
s
.99375 .30894 m
1 .30894 L
s
.99375 .46021 m
1 .46021 L
s
.99375 .61148 m
1 .61148 L
s
.125 Mabswid
.99625 .03665 m
1 .03665 L
s
.99625 .06691 m
1 .06691 L
s
.99625 .09716 m
1 .09716 L
s
.99625 .12741 m
1 .12741 L
s
.99625 .18792 m
1 .18792 L
s
.99625 .21818 m
1 .21818 L
s
.99625 .24843 m
1 .24843 L
s
.99625 .27869 m
1 .27869 L
s
.99625 .3392 m
1 .3392 L
s
.99625 .36945 m
1 .36945 L
s
.99625 .3997 m
1 .3997 L
s
.99625 .42996 m
1 .42996 L
s
.99625 .49047 m
1 .49047 L
s
.99625 .52072 m
1 .52072 L
s
.99625 .55098 m
1 .55098 L
s
.99625 .58123 m
1 .58123 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30894 m
1 .30894 L
s
1 0 0 r
.5 Mabswid
.02381 .30894 m
.02381 .30894 L
s
.03571 .30894 m
.03571 .30894 L
s
.04762 .30894 m
.04762 .30894 L
s
.05952 .30894 m
.05952 .30894 L
s
.07143 .30894 m
.07143 .30894 L
s
.08333 .30894 m
.08333 .30894 L
s
.09524 .30894 m
.09524 .30894 L
s
.10714 .30894 m
.10714 .30894 L
s
.11905 .30894 m
.11905 .30895 L
s
.13095 .30894 m
.13095 .30896 L
s
.14286 .30894 m
.14286 .30894 L
s
.15476 .30894 m
.15476 .30889 L
s
.16667 .30894 m
.16667 .30883 L
s
.17857 .30894 m
.17857 .30888 L
s
.19048 .30894 m
.19048 .30915 L
s
.20238 .30894 m
.20238 .30952 L
s
.21429 .30894 m
.21429 .3095 L
s
.22619 .30894 m
.22619 .30847 L
s
.2381 .30894 m
.2381 .30667 L
s
.25 .30894 m
.25 .30597 L
s
.2619 .30894 m
.2619 .30894 L
s
.27381 .30894 m
.27381 .31556 L
s
.28571 .30894 m
.28571 .32021 L
s
.29762 .30894 m
.29762 .31414 L
s
.30952 .30894 m
.30952 .29519 L
s
.32143 .30894 m
.32143 .27705 L
s
.33333 .30894 m
.33333 .28389 L
s
.34524 .30894 m
.34524 .32619 L
s
.35714 .30894 m
.35714 .37711 L
s
.36905 .30894 m
.36905 .38193 L
s
.38095 .30894 m
.38095 .30894 L
s
.39286 .30894 m
.39286 .20006 L
s
.40476 .30894 m
.40476 .15722 L
s
.41667 .30894 m
.41667 .25167 L
s
.42857 .30894 m
.42857 .43301 L
s
.44048 .30894 m
.44048 .54456 L
s
.45238 .30894 m
.45238 .46048 L
s
.46429 .30894 m
.46429 .2235 L
s
.47619 .30894 m
.47619 .03249 L
s
.4881 .30894 m
.4881 .06661 L
s
.5 .30894 m
.5 .30894 L
s
.5119 .30894 m
.5119 .55127 L
s
.52381 .30894 m
.52381 .58539 L
s
.53571 .30894 m
.53571 .39439 L
s
.54762 .30894 m
.54762 .1574 L
s
.55952 .30894 m
.55952 .07332 L
s
.57143 .30894 m
.57143 .18487 L
s
.58333 .30894 m
.58333 .36622 L
s
.59524 .30894 m
.59524 .46066 L
s
.60714 .30894 m
.60714 .41783 L
s
.61905 .30894 m
.61905 .30894 L
s
.63095 .30894 m
.63095 .23595 L
s
.64286 .30894 m
.64286 .24077 L
s
.65476 .30894 m
.65476 .29169 L
s
.66667 .30894 m
.66667 .33399 L
s
.67857 .30894 m
.67857 .34083 L
s
.69048 .30894 m
.69048 .32269 L
s
.70238 .30894 m
.70238 .30374 L
s
.71429 .30894 m
.71429 .29767 L
s
.72619 .30894 m
.72619 .30232 L
s
.7381 .30894 m
.7381 .30894 L
s
.75 .30894 m
.75 .31192 L
s
.7619 .30894 m
.7619 .31122 L
s
.77381 .30894 m
.77381 .30941 L
s
.78571 .30894 m
.78571 .30838 L
s
.79762 .30894 m
.79762 .30836 L
s
.80952 .30894 m
.80952 .30873 L
s
.82143 .30894 m
.82143 .309 L
s
.83333 .30894 m
.83333 .30905 L
s
.84524 .30894 m
.84524 .309 L
s
.85714 .30894 m
.85714 .30894 L
s
.86905 .30894 m
.86905 .30892 L
s
.88095 .30894 m
.88095 .30893 L
s
.89286 .30894 m
.89286 .30894 L
s
.90476 .30894 m
.90476 .30894 L
s
.91667 .30894 m
.91667 .30894 L
s
.92857 .30894 m
.92857 .30894 L
s
.94048 .30894 m
.94048 .30894 L
s
.95238 .30894 m
.95238 .30894 L
s
.96429 .30894 m
.96429 .30894 L
s
.97619 .30894 m
.97619 .30894 L
s
.015 w
.02381 .30894 Mdot
.03571 .30894 Mdot
.04762 .30894 Mdot
.05952 .30894 Mdot
.07143 .30894 Mdot
.08333 .30894 Mdot
.09524 .30894 Mdot
.10714 .30894 Mdot
.11905 .30895 Mdot
.13095 .30896 Mdot
.14286 .30894 Mdot
.15476 .30889 Mdot
.16667 .30883 Mdot
.17857 .30888 Mdot
.19048 .30915 Mdot
.20238 .30952 Mdot
.21429 .3095 Mdot
.22619 .30847 Mdot
.2381 .30667 Mdot
.25 .30597 Mdot
.2619 .30894 Mdot
.27381 .31556 Mdot
.28571 .32021 Mdot
.29762 .31414 Mdot
.30952 .29519 Mdot
.32143 .27705 Mdot
.33333 .28389 Mdot
.34524 .32619 Mdot
.35714 .37711 Mdot
.36905 .38193 Mdot
.38095 .30894 Mdot
.39286 .20006 Mdot
.40476 .15722 Mdot
.41667 .25167 Mdot
.42857 .43301 Mdot
.44048 .54456 Mdot
.45238 .46048 Mdot
.46429 .2235 Mdot
.47619 .03249 Mdot
.4881 .06661 Mdot
.5 .30894 Mdot
.5119 .55127 Mdot
.52381 .58539 Mdot
.53571 .39439 Mdot
.54762 .1574 Mdot
.55952 .07332 Mdot
.57143 .18487 Mdot
.58333 .36622 Mdot
.59524 .46066 Mdot
.60714 .41783 Mdot
.61905 .30894 Mdot
.63095 .23595 Mdot
.64286 .24077 Mdot
.65476 .29169 Mdot
.66667 .33399 Mdot
.67857 .34083 Mdot
.69048 .32269 Mdot
.70238 .30374 Mdot
.71429 .29767 Mdot
.72619 .30232 Mdot
.7381 .30894 Mdot
.75 .31192 Mdot
.7619 .31122 Mdot
.77381 .30941 Mdot
.78571 .30838 Mdot
.79762 .30836 Mdot
.80952 .30873 Mdot
.82143 .309 Mdot
.83333 .30905 Mdot
.84524 .309 Mdot
.85714 .30894 Mdot
.86905 .30892 Mdot
.88095 .30893 Mdot
.89286 .30894 Mdot
.90476 .30894 Mdot
.91667 .30894 Mdot
.92857 .30894 Mdot
.94048 .30894 Mdot
.95238 .30894 Mdot
.96429 .30894 Mdot
.97619 .30894 Mdot
0 0 1 r
.5 Mabswid
.02381 .30894 m
.02605 .30894 L
.02846 .30894 L
.03279 .30894 L
.03793 .30894 L
.04262 .30894 L
.04499 .30894 L
.0475 .30894 L
.04882 .30894 L
.04951 .30894 L
.05026 .30894 L
.05158 .30894 L
.05281 .30894 L
.05404 .30894 L
.05474 .30894 L
.05539 .30894 L
.05658 .30894 L
.05784 .30894 L
.05908 .30894 L
.06026 .30894 L
.06244 .30894 L
.06489 .30894 L
.06757 .30894 L
.07299 .30894 L
.08269 .30894 L
.08549 .30894 L
.08687 .30894 L
.08815 .30894 L
.08886 .30894 L
.08962 .30894 L
.09038 .30894 L
.09121 .30894 L
.09191 .30894 L
.09266 .30894 L
.09336 .30894 L
.09401 .30894 L
.09528 .30894 L
.09647 .30894 L
.09777 .30894 L
.09916 .30894 L
.102 .30894 L
.10458 .30894 L
.10943 .30894 L
.11456 .30895 L
.119 .30895 L
.12376 .30895 L
.12514 .30896 L
.12644 .30896 L
.12761 .30896 L
.12888 .30896 L
Mistroke
.13008 .30896 L
.13137 .30896 L
.13257 .30896 L
.13367 .30896 L
.13435 .30896 L
.13507 .30896 L
.13637 .30895 L
.13776 .30895 L
.13928 .30895 L
.14201 .30894 L
.14456 .30894 L
.14958 .30891 L
.15504 .30888 L
.15985 .30886 L
.16248 .30884 L
.16377 .30884 L
.16495 .30883 L
.16601 .30883 L
.16716 .30883 L
.16832 .30882 L
.16954 .30882 L
.17081 .30882 L
.17152 .30883 L
.17217 .30883 L
.17342 .30883 L
.17461 .30884 L
.17569 .30885 L
.17683 .30886 L
.17889 .30888 L
.1811 .30891 L
.18352 .30896 L
.18875 .30909 L
.19371 .30925 L
.19822 .3094 L
.20069 .30948 L
.20301 .30954 L
.2043 .30957 L
.20548 .30959 L
.20679 .3096 L
.20748 .3096 L
.20821 .30961 L
.2094 .3096 L
.2105 .3096 L
.21172 .30958 L
.21302 .30954 L
.21443 .3095 L
.21595 .30943 L
.21872 .30925 L
.22142 .30902 L
.22391 .30875 L
Mistroke
.23295 .30746 L
.23792 .30669 L
.24038 .30636 L
.24265 .30612 L
.24394 .30601 L
.2446 .30597 L
.24532 .30593 L
.2461 .3059 L
.24684 .30589 L
.24756 .30588 L
.24822 .30589 L
.2494 .30593 L
.2507 .30602 L
.25135 .30608 L
.25205 .30616 L
.25331 .30634 L
.25459 .30658 L
.25599 .3069 L
.25853 .30764 L
.26329 .30957 L
.27349 .31537 L
.27593 .31678 L
.27849 .31812 L
.28087 .31913 L
.28202 .31953 L
.28307 .31981 L
.28419 .32004 L
.28537 .32019 L
.28666 .32022 L
.28788 .32012 L
.28918 .31988 L
.29037 .31951 L
.29168 .31894 L
.29307 .31815 L
.29578 .31602 L
.29832 .31333 L
.30409 .30498 L
.30907 .29604 L
.3145 .28616 L
.31699 .28221 L
.31835 .28032 L
.31964 .27878 L
.32084 .27756 L
.32213 .27653 L
.32331 .27588 L
.32439 .27554 L
.32547 .27546 L
.32662 .27569 L
.32771 .2762 L
.3287 .27693 L
Mistroke
.32986 .27812 L
.33112 .27983 L
.33341 .28407 L
.33582 .29004 L
.33836 .29802 L
.34293 .3159 L
.35234 .35884 L
.35505 .36986 L
.35762 .37857 L
.35874 .38165 L
.35993 .3844 L
.36124 .3867 L
.36246 .38812 L
.36369 .3888 L
.36483 .3887 L
.36608 .38777 L
.3674 .38582 L
.36854 .38329 L
.36962 .38021 L
.37205 .37068 L
.37425 .35912 L
.37625 .34628 L
.38075 .31068 L
.39 .22434 L
.39467 .18656 L
.39595 .17822 L
.39733 .1705 L
.39863 .16458 L
.39983 .16033 L
.40114 .15719 L
.40183 .15618 L
.40257 .15562 L
.40335 .15563 L
.40408 .15619 L
.40474 .15718 L
.40545 .15876 L
.40676 .16304 L
.40741 .16588 L
.40814 .16954 L
.41061 .18621 L
.41309 .20913 L
.41576 .23996 L
.42059 .30821 L
.42549 .38562 L
.43071 .46327 L
.43372 .49982 L
.43644 .52493 L
.43776 .5338 L
.43845 .53753 L
.43918 .54074 L
Mistroke
.43982 .54293 L
.44052 .54464 L
.44175 .54586 L
.4424 .54557 L
.4431 .54452 L
.44438 .54063 L
.44562 .5344 L
.44677 .52651 L
.44938 .50123 L
.45215 .46399 L
.45676 .38254 L
.46185 .27587 L
.46678 .17191 L
.46947 .12122 L
.47196 .08086 L
.47411 .05288 L
.4752 .04126 L
.47639 .03091 L
.4777 .02237 L
.47893 .01713 L
.48012 .01472 L
.48123 .01488 L
.48243 .0177 L
.48373 .02376 L
.48495 .03232 L
.48606 .04249 L
.48878 .07631 L
.49137 .11892 L
.50209 .35886 L
.50706 .4688 L
.50949 .51419 L
.51173 .54882 L
.51407 .57665 L
.5153 .58747 L
.51659 .5959 L
.51723 .59892 L
.51792 .60129 L
.51916 .60332 L
.51992 .60313 L
.52063 .60196 L
.52127 .6001 L
.52197 .59721 L
.52311 .59058 L
.52418 .58228 L
.52662 .55631 L
.52899 .52248 L
.53154 .47836 L
.54038 .29407 L
.54527 .19682 L
.54796 .15222 L
Mistroke
.55049 .11816 L
.55193 .10268 L
.55349 .08939 L
.55418 .0847 L
.55491 .08053 L
.55621 .07514 L
.55752 .0724 L
.55874 .07223 L
.55944 .07316 L
.56008 .07466 L
.56082 .07713 L
.56152 .08019 L
.56267 .08672 L
.56394 .09596 L
.56652 .12063 L
.57114 .18069 L
.57624 .25983 L
.58161 .34239 L
.58643 .40375 L
.58917 .42986 L
.59047 .43976 L
.59171 .44748 L
.59283 .45312 L
.59405 .45771 L
.59516 .46052 L
.59618 .46196 L
.59729 .4623 L
.59851 .46127 L
.59978 .45866 L
.60096 .45489 L
.60225 .44942 L
.60366 .44196 L
.60622 .42491 L
.61102 .3842 L
.61659 .33139 L
.62182 .28581 L
.62424 .26824 L
.6268 .25292 L
.62813 .24636 L
.6296 .24036 L
.63094 .23598 L
.63217 .23292 L
.63337 .2308 L
.63451 .22956 L
.63571 .22905 L
.63702 .22938 L
.63816 .23039 L
.63937 .23216 L
.6404 .23419 L
.64154 .23695 L
Mistroke
.64426 .24548 L
.64676 .25518 L
.65237 .28058 L
.65729 .30292 L
.65998 .31387 L
.66253 .32283 L
.665 .33005 L
.66631 .3332 L
.66768 .33602 L
.66884 .33799 L
.67012 .33973 L
.67128 .34093 L
.67236 .34172 L
.67354 .34225 L
.67466 .34242 L
.67567 .34233 L
.67677 .34196 L
.67796 .34129 L
.67922 .34027 L
.68149 .33776 L
.68657 .32986 L
.69134 .32108 L
.69653 .31189 L
.69928 .30769 L
.70221 .30394 L
.70487 .30128 L
.7073 .29951 L
.70846 .29887 L
.70973 .29834 L
.71093 .29798 L
.71203 .29777 L
.71327 .29766 L
.71442 .29768 L
.71569 .29782 L
.7164 .29795 L
.71705 .2981 L
.71836 .29848 L
.71978 .299 L
.72238 .30019 L
.7319 .30574 L
.73658 .30824 L
.74087 .31004 L
.74329 .3108 L
.74584 .31139 L
.74716 .31161 L
.7484 .31177 L
.74909 .31184 L
.74975 .3119 L
.75051 .31195 L
.75121 .31198 L
Mistroke
.75234 .312 L
.75354 .31199 L
.75456 .31196 L
.75569 .31189 L
.7569 .3118 L
.75821 .31168 L
.76057 .3114 L
.77059 .30987 L
.77589 .30915 L
.77885 .30883 L
.78155 .30861 L
.78411 .30845 L
.78556 .30839 L
.7869 .30834 L
.78806 .30831 L
.78935 .30829 L
.79 .30828 L
.79069 .30828 L
.79194 .30827 L
.79318 .30828 L
.79389 .30829 L
.79454 .3083 L
.79573 .30832 L
.797 .30834 L
.80161 .30847 L
.80696 .30865 L
.81261 .30883 L
.81743 .30894 L
.82017 .30899 L
.82271 .30902 L
.82406 .30903 L
.82533 .30904 L
.82647 .30905 L
.8277 .30905 L
.82834 .30905 L
.82905 .30906 L
.82979 .30906 L
.83048 .30906 L
.83171 .30906 L
.83241 .30906 L
.83304 .30905 L
.83446 .30905 L
.83577 .30905 L
.83876 .30903 L
.84419 .309 L
.84922 .30897 L
.85396 .30895 L
.85658 .30894 L
.85942 .30893 L
.86068 .30893 L
Mistroke
.862 .30893 L
.86324 .30893 L
.86438 .30893 L
.8656 .30893 L
.86624 .30893 L
.86692 .30892 L
.86807 .30892 L
.86933 .30892 L
.87045 .30892 L
.87166 .30892 L
.87281 .30892 L
.87385 .30893 L
.87622 .30893 L
.8788 .30893 L
.88401 .30893 L
.8886 .30894 L
.89113 .30894 L
.89351 .30894 L
.89573 .30894 L
.89814 .30894 L
.90033 .30894 L
.90234 .30894 L
.9036 .30894 L
.90478 .30894 L
.90585 .30894 L
.90702 .30894 L
.90828 .30894 L
.90898 .30894 L
.90962 .30894 L
.91086 .30894 L
.91204 .30894 L
.91314 .30894 L
.91431 .30894 L
.91639 .30894 L
.9211 .30894 L
.92586 .30894 L
.93095 .30894 L
.93387 .30894 L
.93653 .30894 L
.93782 .30894 L
.93921 .30894 L
.94053 .30894 L
.94174 .30894 L
.94269 .30894 L
.94372 .30894 L
.94475 .30894 L
.94584 .30894 L
.94681 .30894 L
.94784 .30894 L
.94881 .30894 L
Mistroke
.94969 .30894 L
.95082 .30894 L
.95186 .30894 L
.9542 .30894 L
.95846 .30894 L
.97619 .30894 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008?ooool2o`0003[ooooo1Ol0000kooooo`?o0000>Oooool3o`0003_ooooo0ol00007oooo
o`007oooool01?l0003oooooooooool0000jooooo`04o`000?ooooooooooo`0003cooooo00?o0000
ooooooooool0=oooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000oooooooooooooooo
o`000006ooooo`007oooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Wooooo
1Ol0000hooooo`05o`000?ooooooooooooooool00000>Oooool01Ol0003ooooooooooooooooo0000
00Kooooo000Oooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0>?ooool01?l0
003oooooooooool0000iooooo`Co0000>oooool3o`0000Oooooo000Oooooo`04o`000?oooooooooo
o`0003Wooooo00Go0000ooooooooooooooooo`00000jooooo`03o`000?oooooo000003Wooooo00?o
0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000000Kooooo000Oooooo`04o`000?oo
ooooooooo`0003Wooooo00Go0000ooooooooooooooooo`00000kooooo`;o0000>_ooool00ol0003o
ooooooooo`0jooooo`05o`000?ooooooooooooooool000001_ooool0023ooooo0_l0000kooooo`?o
0000?Oooool00ol0003oooooooooo`0iooooo`;o0000>oooool3o`0000Oooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Cooooo`?o0000ooooool;ooooo`00
5?ooool00ol0003oooooooooo`04oooooooo00001Ol00001ooooo`003?ooool5o`0000?ooooo00?o
0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`02ooooo`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooo`7ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
07Wooooo0_l00?n5ooooo`7o00000Oooool001?ooooo0_l00006ooooo`03o`000?oooooooooo07Wo
oooo0_l00?n5ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1iooooo`;o003oQOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Wooooo0_l0
0?n5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool01?oo003o003oool00?l0
0?n5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool01Ooo003o003oool00?oo
oooo003o08Cooooo0Ol00001ooooo`006oooool2o`0007Sooooo00Goo`00o`00oooo003oooooo`00
o`23ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool01?l00?ooooooooooool0
0?n4ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool01?l00?ooooooooooool0
0?n4ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool01?l00?ooooooooooool0
0?n4ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool01?l00?ooooooooooool0
0?n4ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool01?l00?ooooooooooool0
0?n4ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool01?l00?ooooooooooool0
0?n4ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool01Ol00?ooooooool00?oo
003o003o08?ooooo0Ol00001ooooo`006oooool2o`0007Wooooo00Go003ooooooooo003oo`00o`00
o`22ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Moooool00ol00?l0o`00ooooo`02
ool00003o`00oooooooooooo00kooooo0_l00?l00ooo003oooooooooo`1^ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0Moooool01_l00?l0o`00ooooooooool0o`00o`00oa3ooooo0_l0
0?l00ooo003oooooooooo`1^ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool0
1_l00?l0o`00ooooooooool0o`00o`00oa3ooooo0ol00?m`ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0Moooool01_l00?l0o`00ooooooooool0o`00o`00oa3ooooo00?o003o0?l00?l0
0?l0L?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00Ko003o0?l00?oooooo
oooo0?l00?l00?l@ooooo`03o`00o`3o003o003o073ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1gooooo`06o`00o`3o003oooooooooo`3o003o003o3oooool01?l00?oooooo0?l00?l0
0?m`ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool01_l00?l0o`00oooooooo
ool0o`00o`00o`oooooo00Co003oooooo`3o003o003oL?ooool1o`00007ooooo000Kooooo`;o0000
N?ooool01_l00?l0o`00ooooooooool0o`00o`00o`oooooo00Co003oooooo`3o003o003oKoooool2
o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00Ko003o0?l00?oooooooooo0?l00?l0
0?l?ooooo`04o`00ooooool0o`00o`00og3ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1gooooo`06o`00o`3o003oooooooooo`3o003o003o3oooool01?l00?oooooo0?l00?l00?m`oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool01_l00?l0o`00ooooooooool0o`00
o`00o`oooooo00Go003oooooo`3o003oooooo`00o`1_ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0Moooool01_l00?l0o`00ooooooooool0o`00o`00o`oooooo00Go003oooooo`3o003o
ooooo`00o`1_ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool01_l00?l0o`00
ooooooooool0o`00o`00o`oooooo00Go003oooooo`3o003oooooo`00o`1_ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0Moooool01_l00?l0o`00ooooooooool0o`00o`00o`oooooo00Go
003oooooo`3o003oooooo`00o`1_ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Mooo
ool01_l00?l0o`00ooooooooool0o`00o`00o`oooooo00Go003oooooo`3o003oooooo`00o`1_oooo
o`7o00000Oooool001_ooooo0_l0001hooooo`06o`00o`3o003oooooooooo`3o003o003o3oooool0
1Ol00?oooooo0?l00?oooooo003o06kooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1g
ooooo`06o`00o`3o003oooooooooo`3o003o003o3oooool01Ol00?oooooo0?l00?oooooo003o06oo
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`06o`00o`3o003oooooooooo`3o
003o003o3_ooool01_l00?ooooooooooo`3o003oooooo`00ofoooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1gooooo`06o`00o`3o003oooooooooo`3o003o003o3_ooool01_l00?oooooo
ooooo`3o003oooooo`00ofoooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`06
o`00o`3o003oooooooooo`3o003o003o3_ooool01_l00?ooooooooooo`3o003oooooo`00ofoooooo
0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o
0000ooooooooool0M_ooool00ol00?oooooo0?l00002ooooo`030?l00?l00?oooooo00gooooo00Ko
003oooooooooool0o`00ooooool00?m_ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0M_ooool00ol0
0?oooooo0?l00002ooooo`030?l00?l00?oooooo00gooooo00Co003oooooooooool0o`000_ooool0
0ol00?ooooooooooo`1/ooooo`7o00000Oooool000Go00000_ooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00;ooooo0_l0001Uooooo`03ool00?l00?oo003o00oooooo00?o003o
ooooo`3o00000_ooool00`3o003o003oooooo`0;ooooo`;oo`0000Co003oooooooooool0o`000_oo
ool00ol00?ooooooooooo`1[ooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Cooooo00?oo`00o`00ool00?l03ooo
ool00ol00?oooooo0?l00002ooooo`030?l00?oooooo003o00_ooooo0_oo00001?l00?oooooooooo
o`3o0002ooooo`03o`00oooooooooooo06cooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`Co00001Oooool00ol0003oooooooooo`1Tooooo`03o`00oooo003o003o00oooooo
00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`0;ooooo`;oo`0000Co003oooooooooool0
o`000_ooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Cooooo00Co003oooooo`3o
003o003o3_ooool00ol00?oooooo0?l00002ooooo`030?l00?oooooo003o00gooooo00Co003ooooo
ooooool0o`000_ooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool000Sooooo0_l00008oooo
o`Go00001?ooool00ol0003oooooooooo`1Tooooo`04o`00ooooool0o`00o`00o`kooooo00?o003o
ooooo`3o00000_ooool00`3o003oooooo`00o`0=ooooo`04o`00oooooooooooo0?l000;ooooo00?o
003oooooooooool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Cooooo00Co003o
ooooo`3o003o003o3_ooool00ol00?oooooo0?l00002ooooo`030?l00?oooooo003o00gooooo00Co
003oooooooooool0o`000_ooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0I?ooool01?l00?oooooo0?l00?l00?l>ooooo`03o`00ooooool0o`0000;ooooo
00<0o`00ooooool00?l03?ooool01Ol00?l0o`00ooooooooool0o`0000;ooooo00?o003ooooooooo
ool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Cooooo00Co003oooooo`3o003o
003o3_ooool00ol00?oooooo0?l00002ooooo`030?l00?oooooo003o00cooooo00Wo003o0?l00?oo
oooooooo0?l00?ooooooo`00o`00oooo0000KOooool1o`00007ooooo000Kooooo`;o0000I?ooool0
1Ol00?ooooooooooo`3o003o003o00kooooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00
o`0<ooooo`09o`00o`3o003oooooooooo`3o003oooooool00?l00?ooo`0006cooooo0_l00001oooo
o`006oooool00ol0003oooooooooo`1Sooooo`05o`00oooooooooooo0?l00?l00?l03_ooool00ol0
0?oooooo0?l00002ooooo`030?l00?oooooo003o00cooooo00Wo003o0?l00?oooooooooo0?l00?oo
ooooo`00o`00oooo0000KOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06?ooooo00Go
003oooooooooool0o`00o`00o`0>ooooo`03o`00ooooool0o`0000;ooooo00<0o`00ooooool00?l0
3?ooool01Ol00?l0o`00ooooooooool0o`0000;ooooo00?o003oooooooooool0K?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo067ooooo0_oo00001Ol00?ooooooooooo`3o003o003o00ko
oooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`0<ooooo`05o`00o`3o003ooooooooo
o`3o00000_ooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0HOooool2ool00006o`00oooooooooooo0?l00?oooooo003o3Oooool00ol00?oooooo0?l00002
ooooo`030?l00?oooooo003o00cooooo00Go003o0?l00?oooooooooo0?l00002ooooo`03o`00oooo
oooooooo06cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Qooooo`;oo`0000Ko003o
ooooooooool0o`00ooooool00?l=ooooo`03o`00ooooool0o`0000;ooooo00<0o`00ooooool00?l0
3?ooool01Ol00?l0o`00ooooooooool0o`0000;ooooo00?o003oooooooooool0K?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo06;ooooo00Oo003o0?l00?oooooooooo0?l00?oooooo003o
00gooooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`0<ooooo`05o`00o`3o003ooooo
ooooo`3o00000_ooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0H_ooool01ol00?l0o`00ooooooooool0o`00ooooool00?l03Oooool00ol00?oooooo0?l0
0002ooooo`030?l00?oooooo003o00cooooo00Go003o0?l00?oooooooooo0?l00002ooooo`03o`00
oooooooooooo06cooooo0Ol00001ooooo`006oooool2o`0006?ooooo00Oo003o0?l00?oooooooooo
0?l00?oooooo003o00gooooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`0<ooooo`05
o`00o`3o003oooooooooo`3o00000_ooool00ol00?ooooooooooo`1[ooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool0H_ooool01ol00?l0o`00ooooooooool0o`00ooooool00?l02oooool2
ool00003o`00ooooool0o`0000;ooooo00<0o`00ooooool00?l03?ooool01Ol00?l0o`00oooooooo
ool0o`0000;ooooo00<0o`00o`00ooooool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo06;ooooo00Oo003o0?l00?oooooooooo0?l00?oooooo003o00_ooooo00Goo`00o`00oooo003o
oooo0?l00002ooooo`030?l00?oooooo003o00cooooo00Go003o0?l00?oooooooooo0?l00002oooo
o`030?l00?l00?oooooo06cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Rooooo`05
o`00o`3o003oooooooooo`3o00000_ooool00ol00?ooooooooooo`08ooooo`05ool00?l00?ooo`00
ooooo`3o00000_ooool00`3o003oooooo`00o`0<ooooo`05o`00o`3o003oooooooooo`3o00000_oo
ool00`3o003o003oooooo`0=ooooo`;o003oGOooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo06;ooooo00Go003o0?l00?oooooooooo0?l00002ooooo`03o`00oooooooooooo00Wooooo00Co
003oooooooooool0o`000_ooool00`3o003oooooo`00o`0<ooooo`05o`00o`3o003oooooooooo`3o
00000_ooool00`3o003o003oooooo`0;ooooo`;oo`0000?o003oooooool00?l0G?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo06;ooooo00Go003o0?l00?oooooooooo0?l00002ooooo`03
o`00oooooooooooo00Wooooo00Co003oooooooooool0o`000_ooool00`3o003oooooo`00o`0<oooo
o`05o`00o`3o003oooooooooo`3o00000_ooool00`3o003o003oooooo`0;ooooo`;oo`0000Co003o
ool00?l00?ooo`00Foooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06;ooooo00Go003o
0?l00?oooooooooo0?l00002ooooo`03o`00oooooooooooo00Wooooo00Co003oooooooooool0o`00
0_ooool0103o003oooooooooool00?l;ooooo`05o`00o`3o003oooooooooo`3o00000_ooool00`3o
003o003oooooo`0;ooooo`06ool00?l00?ooo`00ool00?l00?ooo`00Foooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo06;ooooo00Go003o0?l00?oooooooooo0?l00002ooooo`03o`00oooo
oooooooo00Wooooo00Co003oooooooooool0o`000_ooool0103o003oooooooooool00?l;ooooo`05
o`00o`3o003oooooooooo`3o00000_ooool00`3o003o003oooooo`0<ooooo`05o`00o`3o003oo`00
ool00?l00?l0Foooool1o`00007ooooo000Kooooo`;o0000H_ooool00ol00?oooooo0?l00002oooo
o`040?l00?oo003oo`00o`00o`_ooooo00Co003oooooooooool0o`000_ooool0103o003ooooooooo
ool00?l:ooooo`03o`00ooooool0o`0000;ooooo00D0o`00ooooooooool0o`00o`00o`0=ooooo`05
o`00o`3o003oooooooooool00?l0F_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo067o
oooo00?o003oooooo`3o00000_ooool0103o003oo`00ool00?l00?l;ooooo`04o`00oooooooooooo
0?l000;ooooo00@0o`00oooooooooooo003o2_ooool00ol00?oooooo0?l00002ooooo`050?l00?oo
oooooooo0?l00?l00?l03?ooool00ol00?oooooo0?l00002ooooo`030?l00?l00?oooooo05Wooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1Qooooo`03o`00ooooool0o`0000;ooooo00@0
o`00ool00?oo003o003o2oooool01?l00?ooooooooooo`3o0002ooooo`040?l00?ooooooooooo`00
o`[ooooo00?o003oooooo`3o00000_ooool01@3o003oooooooooo`3o003o003o00cooooo00?o003o
ooooo`3o00000_ooool00`3o003o003oooooo`1Iooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0HOooool00ol00?oooooo0?l00002ooooo`040?l00?ooooooooooo`00o`_ooooo00Co003o
ooooooooool0o`000_ooool0103o003oooooooooool00?l:ooooo`03o`00ooooool0o`0000;ooooo
00D0o`00ooooooooool0o`00o`00o`0<ooooo`03o`00ooooool0o`0000;ooooo00<0o`00o`00oooo
ool0FOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo067ooooo00?o003oooooo`3o0000
0_ooool0103o003oooooooooool00?l;ooooo`04o`00oooooooooooo0?l000;ooooo00@0o`00oooo
oooooooo003o2_ooool00ol00?oooooo0?l00002ooooo`050?l00?oooooooooo0?l00?l00?l03?oo
ool00ol00?oooooo0?l00002ooooo`030?l00?l00?oooooo05Wooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1Qooooo`03o`00ooooool0o`0000;ooooo00@0o`00oooooooooooo003o2ooo
ool01?l00?ooooooooooo`3o0002ooooo`040?l00?ooooooooooo`00o`[ooooo00?o003oooooo`3o
00000_ooool01@3o003oooooooooo`3o003o003o00cooooo00?o003oooooo`3o00000_ooool00`3o
003o003oooooo`1Iooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0HOooool00ol00?oo
oooo0?l00002ooooo`040?l00?ooooooooooo`00o`_ooooo00Co003oooooooooool0o`000_ooool0
103o003oooooooooool00?l:ooooo`03o`00ooooool0o`0000;ooooo00D0o`00ooooooooool0o`00
o`00o`0<ooooo`03o`00ooooool0o`0000;ooooo00<0o`00ooooool00?l0FOooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo04oooooo00Coo`00o`00ool00?oo003o3_ooool00ol00?oooooo
0?l00002ooooo`040?l00?ooooooooooo`00o`_ooooo00Co003oooooooooool0o`000_ooool0103o
003oooooooooool00?l:ooooo`03o`00ooooool0o`0000;ooooo00D0o`00ooooooooool0o`00o`00
o`0<ooooo`03o`00ooooool0o`0000;ooooo00<0o`00ooooool00?l0FOooool1o`00007ooooo000K
ooooo`;o0000D?ooool2o`00o`03ool00?l00?oo003o00gooooo00?o003oooooo`3o00000_ooool0
1@3o003oooooooooo`3o003o003o00[ooooo00Co003oooooooooool0o`000_ooool0103o003ooooo
ooooool00?l:ooooo`03o`00ooooool0o`0000;ooooo00D0o`00ooooooooool0o`00o`00o`0;oooo
o`04o`00oooooooooooo0?l000;ooooo00<0o`00ooooool00?l0F?ooool2o`00007ooooo000Koooo
o`03o`000?oooooooooo04oooooo00Ko003oool00?oo003oo`00o`00oooo000<ooooo`03o`00oooo
ool0o`0000;ooooo00D0o`00ooooooooool0o`00o`00o`0:ooooo`04o`00oooooooooooo0?l000;o
oooo00@0o`00oooooooooooo003o2_ooool00ol00?oooooo0?l00002ooooo`060?l00?oooooooooo
0?l00?oooooo003o2_ooool01?l00?ooooooooooo`3o0002ooooo`030?l00?oooooo003o05Wooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1>ooooo`07o`00ooooool0o`00oooooooo003o
003oool0000<ooooo`03o`00ooooool0o`0000;ooooo00D0o`00ooooooooool0o`00o`00o`0:oooo
o`04o`00oooooooooooo0?l000;ooooo00@0o`00oooooooooooo003o2_ooool00ol00?oooooo0?l0
0002ooooo`060?l00?oooooooooo0?l00?oooooo003o2_ooool01?l00?ooooooooooo`3o0002oooo
o`030?l00?oooooo003o05Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1>ooooo`04
o`00ooooool0o`00ooooo`;oo`0000?o003oooooooooool02Oooool01?l00?ooooooooooo`3o0002
ooooo`050?l00?oooooooooo0?l00?l00?l02_ooool01?l00?ooooooooooo`3o0002ooooo`040?l0
0?ooooooooooo`00o`[ooooo00?o003oooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo
o`00o`[ooooo00Co003oooooooooool0o`000_ooool0103o003oo`00o`00oooo001Hooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0C?ooool01Ooo003o003oool00?ooool0o`0000;ooooo
00<0o`00o`00ooooool02_ooool01?l00?ooooooooooo`3o0002ooooo`050?l00?oooooooooo0?l0
0?l00?l02_ooool01?l00?ooooooooooo`3o0002ooooo`040?l00?ooooooooooo`00o`[ooooo00?o
003oooooo`3o00000_ooool01P3o003oooooooooo`3o003oooooo`00o`[ooooo00Co003ooooooooo
ool0o`000_ooool0103o003oo`00ool00?l00?l=ooooo`?oo`00B?ooool1o`00007ooooo000Doooo
o`;o00001Oooool00ol0003oooooooooo`1<ooooo`05ool00?l00?ooo`00ooooo`3o00000_ooool0
0`3o003oooooo`00o`0:ooooo`04o`00oooooooooooo0?l000;ooooo00D0o`00ooooooooool0o`00
o`00o`0:ooooo`04o`00oooooooooooo0?l000;ooooo00@0o`00oooooooooooo003o2_ooool00ol0
0?oooooo0?l00002ooooo`060?l00?oooooooooo0?l00?oooooo003o2_ooool01?l00?oooooooooo
o`3o0002ooooo`040?l00?oo003oo`00o`00o`cooooo1_l00?l00ooo003oooooooooo`13ooooo`7o
00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0looooo`?o
o`003Oooool01Ol00?ooo`00ool00?ooool0o`0000;ooooo00<0o`00ooooool00?l02_ooool01?l0
0?ooooooooooo`3o0002ooooo`050?l00?oooooooooo0?l00?l00?l02_ooool01?l00?oooooooooo
o`3o0002ooooo`040?l00?ooooooooooo`00o`[ooooo00?o003oooooo`3o00000_ooool01P3o003o
ooooooooo`3o003oooooo`00o`[ooooo00Co003oooooooooool0o`000_ooool0103o003ooooooooo
ool00?l:ooooo`03ool00?l00?oo003o00Goo`0000?o003oooooooooool0@oooool1o`00007ooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0ooo00000ooooooo
o`00ool0000Oool00003oooooooo003oo`0000ooo`002Ol00?l00ooo003oooooooooo`08ooooo`05
o`00o`3o003oooooooooo`3o00000_ooool00`3o003oooooo`00o`08ooooo`;oo`0000Co003ooooo
ooooool0o`000_ooool01@3o003oooooooooo`3o003o003o00Wooooo00Go003o0?l00?oooooooooo
0?l00002ooooo`050?l00?ooooooo`00o`00oooo00002Oooool00ol00?oooooo0?l00002ooooo`06
0?l00?oooooooooo0?l00?oooooo003o2?ooool2ool00004o`00oooooooooooo0?l000;ooooo00@0
o`00oooooooooooo003o2_ooool01_l00?ooo`00ool00?ooool0o`00ooooo`?oo`0000?o003oool0
0?oo00001_ooool<ool00003oooooooo003oo`0001ooo`0000?oooooool00?oo00001ooo0004oooo
o`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool4o`0000;oo`00=Ol00?l9ool0
00?o003o00Coo`00o`000?l00000o`000_l000001?oo003o003oo`00003o0002o`0000040?l00?l0
003o00000?l000;o000000Co003oo`000?l00000o`000ol00000103o003oo`00ool00?l00?l2o`00
00040?l00?l0003o00000?l000;o000000@0o`00o`00ool00000o`000_l000001`3o003o0000o`00
003o003o0000o`00o`3o00000_l00000203o003o0000o`00003o003o0000ool00?l00?ooo`000_l0
0000103o003o0000o`00003o0002o`0000040?l00?l00?oo00000?l000;o000000L0o`00o`000?l0
0000o`00o`000?l00?l0o`0000;o000000D0o`00o`000?l00000o`00o`000002ool00004o`00ool0
003o00000?l000;o000000L0o`00o`000?l00000o`00o`00ool00000o`0000;o000000H0o`00o`00
0?l00000o`00o`000?l00?l2ool00007o`00003o003o0000o`00003o003o0000ool00004o`00o`03
ool00?l00?oo003o037o003o1`000?l00ooo003o0000o`000003o`00007ooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0ooo00000oooooooo`00ool0000Oool0
0003oooooooo003oo`0001?oo`000oooool5ool00008o`00oooooooooooo0?l00?ooooooo`00o`00
oooo000:ooooo`04o`00oooooooooooo0?l000?ooooo00@0o`00ool00?oo003o003o2Oooool00ol0
0?oooooo0?l00002ooooo`060?l00?oooooooooo0?l00?oooooo003o2?ooool00ooo003o003oool0
0002ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00o`00ooooool02?ooool01Ol00?l0o`00
ooooooooool0o`0000;ooooo00D0o`00oooooooo003o003oool00009ooooo`03o`00ooooool0o`00
00;ooooo00H0o`00ooooooooool0o`00ooooool00?l8ooooo`Coo`000ol00?l>ool00003oooooooo
003oo`0001ooo`0000?oooooool00?oo00001ooo0004ooooo`7o00000Oooool001?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`12ooooo`;oo`000ol00?l01Ooo003o003oo`00
ool00?ooo`0000[ooooo00Co003oooooooooool0o`000oooool0103o003oooooooooool00?l9oooo
o`03o`00ooooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooool00?l9ooooo`05o`00oooo
ooooooooooooo`3o00000_ooool01@3o003oooooooooo`3o003o003o00Wooooo00Go003o0?l00?oo
oooooooo0?l00002ooooo`040?l00?ooooooooooo`00o`[ooooo00?o003oooooo`3o00000_ooool0
1@3o003oooooooooo`3o003o003o00cooooo1_oo000looooo`7o00000Oooool001Cooooo0_l00005
ooooo`03o`000?oooooooooo04;ooooo1?oo0003o`00o`?oo`002_ooool01?l00?ooooooooooo`3o
0003ooooo`030?l00?oooooo003o00[ooooo00?o003oooooo`3o00000_ooool01P3o003ooooooooo
o`3o003oooooo`00o`[ooooo00Co003oooooooooool0o`000_ooool01@3o003oooooooooo`3o003o
003o00Wooooo00Go003o0?l00?oooooooooo0?l00002ooooo`040?l00?ooooooooooo`00o`_ooooo
00Wo003o0?l00?oooooooooo0?l00?ooooooo`00o`00oooo0000C_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo04Gooooo0ooo000=ooooo`05ool00?l00?ooo`00ooooo`3o00000oooool0
0`3o003oooooo`00o`0:ooooo`03o`00ooooool0o`0000;ooooo00H0o`00ooooooooool0o`00oooo
ool00?l:ooooo`04o`00oooooooooooo0?l000;ooooo00D0o`00ooooooooool0o`00o`00o`0:oooo
o`04o`00oooooooooooo0?l000;ooooo00@0o`00oooooooooooo003o2oooool02Ol00?l0o`00oooo
ooooool0o`00oooooooo003o003oool0001>ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0EOooool01Ooo003o003oool00?ooool0o`0000?ooooo00<0o`00ooooool00?l02_ooool00ol0
0?oooooo0?l00002ooooo`060?l00?oooooooooo0?l00?oooooo003o2_ooool01?l00?oooooooooo
o`3o0002ooooo`050?l00?oooooooooo0?l00?l00?l02_ooool01?l00?ooooooooooo`3o0002oooo
o`040?l00?ooooooooooo`00o`_ooooo00Oo003o0?l00?oooooooooo0?l00?oooooo003o00;oo`00
C_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05Gooooo0_oo00000ol00?oooooo0?l0
0003ooooo`030?l00?oooooo003o00[ooooo00?o003oooooo`3o00000_ooool01P3o003ooooooooo
o`3o003oooooo`00o`[ooooo00Co003oooooooooool0o`000_ooool01@3o003oooooooooo`3o003o
003o00[ooooo00Co003oooooooooool0o`000_ooool0103o003oooooooooool00?l:ooooo`;oo`00
00Ko003oooooooooool0o`00ooooool00?m@ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0Eoooool00ol00?oooooo0?l00003ooooo`030?l00?oooooo003o00[ooooo00?o003oooooo`3o
00000_ooool01P3o003oooooooooo`3o003oooooo`00o`[ooooo00Co003oooooooooool0o`000_oo
ool01@3o003oooooooooo`3o003o003o00[ooooo00Co003oooooooooool0o`000_ooool0103o003o
ooooooooool00?l:ooooo`;oo`0000Go003oool00?oo003oo`00o`00o`1Aooooo`7o00000Oooool0
01_ooooo0_l0001Hooooo`03o`00ooooool0o`0000?ooooo00<0o`00o`00ooooool02_ooool00ol0
0?oooooo0?l00002ooooo`060?l00?oooooooooo0?l00?oooooo003o2_ooool01?l00?oooooooooo
o`3o0002ooooo`050?l00?oooooooooo0?l00?l00?l02_ooool01?l00?ooooooooooo`3o0002oooo
o`040?l00?ooooooooooo`00o`[ooooo0ooo0003o`00oe7ooooo0_l00001ooooo`006oooool00ol0
003oooooooooo`1Gooooo`03o`00ooooool0o`0000?ooooo00<0o`00o`00ooooool02_ooool00ol0
0?oooooo0?l00002ooooo`060?l00?oooooooooo0?l00?oooooo003o2_ooool01?l00?oooooooooo
o`3o0002ooooo`040?l00?ooooooooooo`00o`_ooooo00Co003oooooooooool0o`000_ooool0103o
003oooooooooool00?l=ooooo`?oo`00D_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
05Oooooo00?o003oooooo`3o00000oooool00`3o003o003oooooo`0:ooooo`03o`00ooooool0o`00
00;ooooo00H0o`00ooooooooool0o`00ooooool00?l:ooooo`04o`00oooooooooooo0?l000;ooooo
00@0o`00oooooooooooo003o2oooool01?l00?ooooooooooo`3o0002ooooo`030?l00?oooooo003o
06?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Hooooo`03o`00o`3o003ooooo00;o
oooo00<0o`00o`00ooooool02oooool01Ol00?l0o`00ooooooooool0o`0000;ooooo00<0o`00oooo
ool00?l02_ooool01?l00?ooooooooooo`3o0002ooooo`040?l00?ooooooooooo`00o`_ooooo00Co
003oooooooooool0o`000_ooool00`3o003oooooo`00o`1Sooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0F?ooool00ol00?l0o`00ooooo`02ooooo`030?l00?l00?oooooo00_ooooo00Go
003o0?l00?oooooooooo0?l00002ooooo`030?l00?oooooo003o00[ooooo00Co003oooooooooool0
o`000_ooool0103o003oooooooooool00?l;ooooo`04o`00oooooooooooo0?l000;ooooo00<0o`00
ooooool00?l0Hoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05Sooooo00?o003o0?l0
0?ooool00_ooool00`3o003o003oooooo`0;ooooo`05o`00o`3o003oooooooooo`3o00000_ooool0
0`3o003o003oooooo`0:ooooo`04o`00oooooooooooo0?l000;ooooo00@0o`00oooooooooooo003o
2oooool01?l00?ooooooooooo`3o0002ooooo`030?l00?oooooo003o06?ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1Hooooo`03o`00o`3o003ooooo00;ooooo00<0o`00o`00ooooool0
2oooool01Ol00?l0o`00ooooooooool0o`0000;ooooo00<0o`00o`00ooooool02_ooool01?l00?oo
ooooooooo`3o0002ooooo`040?l00?ooooooooooo`00o`[ooooo00Goo`00o`00oooo003ooooo0?l0
0002ooooo`030?l00?oooooo003o06?ooooo0Ol00001ooooo`006oooool2o`0005[ooooo00Go003o
ooooooooooooooooo`00o`0=ooooo`05o`00o`3o003oooooooooo`3o00000_ooool00`3o003o003o
ooooo`0:ooooo`04o`00oooooooooooo0?l000;ooooo00@0o`00oooooooooooo003o2_ooool01Ooo
003o003oool00?ooool0o`0000;ooooo00<0o`00ooooool00?l0H_ooool2o`00007ooooo000Koooo
o`03o`000?oooooooooo05Wooooo00Go003oooooooooooooooooo`00o`0=ooooo`05o`00o`3o003o
ooooooooo`3o00000_ooool00`3o003o003oooooo`0:ooooo`04o`00oooooooooooo0?l000;ooooo
00@0o`00oooooooooooo003o2_ooool01Ooo003o003oool00?ooool0o`0000;ooooo00<0o`00oooo
ool00?l0Hoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05Sooooo00?oo`00o`00oooo
00000_ooool00ol00?ooooooooooo`0;ooooo`05o`00o`3o003oooooooooo`3o00000_ooool00`3o
003o003oooooo`0:ooooo`04o`00oooooooooooo0?l000;ooooo00@0o`00oooooooooooo003o3?oo
ool00ol00?oooooo0?l00002ooooo`030?l00?l00?oooooo06?ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1Hooooo`;oo`0000Co003oool00?oo003o003o3Oooool01Ol00?l0o`00oooo
ooooool0o`0000;ooooo00<0o`00o`00ooooool02_ooool01?l00?ooooooooooo`3o0002ooooo`04
0?l00?ooooooooooo`00o`cooooo00?o003oooooo`3o00000_ooool00`3o003o003oooooo`1Soooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0F?ooool2ool00004o`00oooo003o003oool0
00gooooo00Go003o0?l00?oooooooooo0?l00002ooooo`030?l00?l00?oooooo00[ooooo00Co003o
ooooooooool0o`000_ooool0103o003oooooooooool00?l<ooooo`03o`00ooooool0o`0000;ooooo
00<0o`00o`00ooooool0Hoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05_ooooo0_l0
0?l00ooo003oooooooooo`0;ooooo`05o`00o`3o003oooooooooo`3o00000_ooool00`3o003o003o
ooooo`0:ooooo`04o`00oooooooooooo0?l000;ooooo00@0o`00oooooooooooo003o3?ooool00ol0
0?oooooo0?l00002ooooo`030?l00?l00?oooooo06?ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1[ooooo`05o`00o`3o003oooooooooo`3o00000_ooool00`3o003o003oooooo`0:oooo
o`04o`00oooooooooooo0?l000;ooooo00@0o`00ool00?oo003o003o3?ooool00ol00?oooooo0?l0
0002ooooo`030?l00?l00?oooooo06?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1[
ooooo`05o`00o`3o003oooooooooo`3o00000_ooool00`3o003o003oooooo`0:ooooo`04o`00oooo
oooooooo0?l000;ooooo00@0o`00ool00?oo003o003o3?ooool00ol00?oooooo0?l00002ooooo`03
0?l00?l00?oooooo06?ooooo0Ol00001ooooo`006oooool2o`0006cooooo00Go003o0?l00?oooooo
oooo0?l00002ooooo`030?l00?l00?oooooo00[ooooo00Co003oooooooooool0o`000_ooool0103o
003oo`00ool00?l00?l<ooooo`03o`00ooooool0o`0000;ooooo00<0o`00o`00ooooool0H_ooool2
o`00007ooooo000Kooooo`03o`000?oooooooooo06_ooooo00Go003o0?l00?oooooooooo0?l00002
ooooo`030?l00?l00?oooooo00[ooooo00Co003oooooooooool0o`000_ooool0103o003ooooooooo
ool00?l<ooooo`03o`00ooooool0o`0000;ooooo00<0o`00o`00ooooool0Hoooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo06_ooooo00Go003o0?l00?oooooooooo0?l00002ooooo`030?l0
0?l00?oooooo00[ooooo00Co003oooooooooool0o`000_ooool0103o003oooooooooool00?l<oooo
o`03o`00ooooool0o`0000;ooooo00?o003oooooooooool0Hoooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo06cooooo00Co003oooooooooool0o`000_ooool00`3o003o003oooooo`0:oooo
o`04o`00oooooooooooo0?l000;ooooo00@0o`00oooooooooooo003o3?ooool00ol00?oooooo0?l0
0002ooooo`03o`00oooooooooooo06?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1/
ooooo`04o`00oooooooooooo0?l000;ooooo00<0o`00o`00ooooool02_ooool01?l00?oooooooooo
o`3o0002ooooo`040?l00?ooooooooooo`00o`cooooo00Oo003oooooo`3o003oooooool00?l00?oo
o`0006Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1/ooooo`04o`00oooooooooooo
0?l000;ooooo00<0o`00o`00ooooool02oooool00ol00?oooooo0?l00002ooooo`040?l00?oooooo
ooooo`00o`gooooo00Ko003o0?l00?ooooooo`00o`00oooo001Tooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0K?ooool01?l00?ooooooooooo`3o0002ooooo`030?l00?l00?oooooo00_o
oooo00?o003oooooo`3o00000_ooool0103o003oooooooooool00?l=ooooo`06o`00o`3o003ooooo
ool00?l00?ooo`00I?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06cooooo00Co003o
ooooooooool0o`000_ooool00ol00?ooooooooooo`0;ooooo`03o`00ooooool0o`0000;ooooo00@0
o`00oooooooooooo003o3Oooool01Ol00?l0o`00oooooooooooo003o06Gooooo0Ol00001ooooo`00
6oooool2o`0006cooooo00Goo`00o`00oooo003ooooo0?l00002ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooo`3o00000_ooool0103o003oooooooooool00?l=ooooo`05o`00o`3o003ooooo
ooooool00?l0I?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo06_ooooo00Goo`00o`00
oooo003ooooo0?l00002ooooo`03o`00oooooooooooo00_ooooo00?o003oooooo`3o00000_ooool0
103o003oooooooooool00?l=ooooo`05o`00o`3o003oooooooooool00?l0IOooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo06_ooooo00Goo`00o`00oooo003ooooo0?l00002ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`0>ooooo`04o`00
o`3o003oooooo`00ofKooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1/ooooo`04o`00
oooooooooooo0?l000;ooooo00?o003oooooooooool02oooool00ol00?oooooo0?l00002ooooo`03
0?l00?oooooo003o00kooooo00Co003o0?l00?oooooo003oI_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo06cooooo00Co003oooooooooool0o`000_ooool00ol00?ooooooooooo`0;oooo
o`03o`00ooooool0o`0000;ooooo00<0o`00ooooool00?l03_ooool01?l00?l0o`00ooooool00?mV
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0KOooool00ol00?oooooo0?l00002oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`0>oooo
o`04o`00o`3o003oooooo`00ofKooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0KOooool00ol00?oooooo0?l00002oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`0?oooo
o`03o`00oooooooo003o06Kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1]ooooo`03o`00ooooool0
o`0000;ooooo00?o003oooooooooool02oooool00ol00?oooooo0?l00002ooooo`030?l00?oooooo
003o00oooooo00?o003oooooool00?l0I_ooool1o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooooooool00_ooool2o`0006kooooo00Oo003oooooo`3o003oooooool0
0?l00?ooo`0000cooooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`0>ooooo`03ool0
0?l00?oo003o06Kooooo0_l00001ooooo`001oooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0KOooool01ol00?oooooo0?l00?ooooooo`00o`00
oooo00003?ooool00ol00?oooooo0?l00002ooooo`030?l00?oooooo003o00kooooo0_oo00000ol0
0?ooooooooooo`1Uooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool4o`00
00Gooooo00?o0000ooooooooool0KOooool01ol00?oooooo0?l00?ooooooo`00o`00oooo00003?oo
ool00ol00?oooooo0?l00002ooooo`030?l00?oooooo003o00kooooo0ooo001Wooooo`7o00000Ooo
ool000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo06gooooo00?o003oooooo`3o00000_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
ool0o`0000;ooooo00<0o`00ooooool00?l0N?ooool1o`00007ooooo0008ooooo`;o00002?ooool5
o`0000Cooooo00?o0000ooooooooool0KOooool00ol00?oooooo0?l00002ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`1hooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0KOooool00ol00?oooooo0?l00002ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`1hooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0KOooool00ol00?oooooo0?l00002ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooo`3o00000_ooool00`3o003oooooo`00o`1hooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0KOooool01Ol00?oooooo0?l00?oooooo003o00kooooo00?o003oooooo`3o
00000_ooool00`3o003oooooo`00o`1hooooo`7o00000Oooool001_ooooo0_l0001^ooooo`05o`00
ooooool0o`00ooooool00?l03_ooool00ol00?oooooo0?l00002ooooo`030?l00?oooooo003o07Oo
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`1]ooooo`05o`00ooooool0o`00ooooool0
0?l03oooool01ol00?l0o`00ooooooooool0o`00ooooool00?l0N?ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo06gooooo00Go003oooooo`3o003oooooo`00o`0?ooooo`07o`00o`3o003o
ooooooooo`3o003oooooo`00o`1hooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0KOoo
ool01Ol00?oooooo0?l00?oooooo003o00oooooo00Ko003o0?l00?oooooooooo0?l00?l00?mioooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0KOooool01Ol00?oooooo0?l00?oooooo003o
00oooooo00Ko003o0?l00?oooooooooo0?l00?l00?miooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0KOooool01Ol00?oooooo0?l00?oooooo003o00oooooo00Ko003o0?l00?oooooooooo
0?l00?l00?miooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0K_ooool01?l00?l0o`00
ooooool00?l?ooooo`06o`00o`3o003oooooooooo`3o003o003oNOooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo06kooooo00Co003o0?l00?oooooo003o3oooool01_l00?l0o`00oooooooo
ool0o`00o`00ogWooooo0Ol00001ooooo`006oooool2o`0006oooooo00Co003o0?l00?oooooo003o
3oooool01_l00?l0o`00ooooooooool0o`00o`00ogSooooo0_l00001ooooo`006oooool00ol0003o
ooooooooo`1^ooooo`04o`00o`3o003oooooo`00o`oooooo00Ko003o0?l00?oooooooooo0?l00?l0
0?miooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0K_ooool01?l00?l0o`00ooooool0
0?l?ooooo`06o`00o`3o003oooooooooo`3o003o003oNOooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo06kooooo00?o003o0?l00?l00?l04Oooool01Ol00?ooooooooooo`3o003o003o07Wo
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`;o003o4Oooool01Ol00?oooooo
ooooo`3o003o003o07Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1^ooooo`03ool0
0?l00?oo003o017ooooo00Co003ooooooooooooo003oN_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo06kooooo00?oo`00o`00ool00?l04Oooool01?l00?ooooooooooool00?mjooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0K_ooool3ool000oooooo0_oo00001?l00?oooooo
ooooool00?mjooooo`7o00000Oooool001_ooooo0_l00021ooooo`;oo`0000Co003ooooooooooooo
003oNOooool2o`00007ooooo000Kooooo`03o`000?oooooooooo083ooooo0_oo00001?l00?oooooo
ooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0P_ooool01?l00?oooooo
ooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0P_ooool01?l00?oooooo
ooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0P_ooool01?l00?oooooo
ooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0P_ooool01?l00?oooooo
ooooool00?mjooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0P_ooool01?l00?oooooo
ooooool00?mjooooo`7o00000Oooool001_ooooo0_l00023ooooo`04o`00ooooooooooooo`00ogWo
oooo0_l00001ooooo`006oooool00ol0003oooooooooo`23ooooo`03o`00oooo003o003o07[ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`23ooooo`03o`00oooo003o003o07[ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`23ooooo`03o`00oooo003o003o07[ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`23ooooo`03o`00oooooooo003o07[ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`23ooooo`;o003oNoooool1o`00007ooooo000Cooooo`?o0000
1Oooool00ol0003oooooooooo`23ooooo`;o003oNoooool1o`00007ooooo000Dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0ooooool1ooooo`7o00000Oooool001Cooooo00?o0000
ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02
ooooo`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool1o`00007ooooo000Dooooo`03
o`000?oooooooooo00Coooooool00005o`00007ooooo000Cooooo`;o0000ooooool<ooooo`005?oo
ool00ol0003oooooooooo`3oooooo`[ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.08154, -1.18618, \
0.032354, 0.012731}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sample discrete-time signal (continuous-time to discrete-time \
conversion, very undersampled)\
\>", "Subsection"],

Cell["\<\
Adjust sampling rate below (in Hz) to see different sampling \
results.\
\>", "Text"],

Cell[BoxData[
    \(\(sampleRate = 2;\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sampled\  = 
        Table[{t, f1[t]}, {t, 0, 8, 
            1/sampleRate}];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        DiscreteListPlot[sampled, Red, PlotRange \[Rule] All, \ 
          Frame \[Rule] True, \ 
          Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(Show[g2, g1];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.309017 0.377891 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0256 -30 -4.5 ]
[-0.0125 .0256 0 4.5 ]
[-0.0125 .12007 -24 -4.5 ]
[-0.0125 .12007 0 4.5 ]
[-0.0125 .21454 -30 -4.5 ]
[-0.0125 .21454 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40349 -24 -4.5 ]
[-0.0125 .40349 0 4.5 ]
[-0.0125 .49796 -18 -4.5 ]
[-0.0125 .49796 0 4.5 ]
[-0.0125 .59244 -24 -4.5 ]
[-0.0125 .59244 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(6)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(8)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0256 m
.00625 .0256 L
s
[(-0.75)] -0.0125 .0256 1 0 Mshowa
0 .12007 m
.00625 .12007 L
s
[(-0.5)] -0.0125 .12007 1 0 Mshowa
0 .21454 m
.00625 .21454 L
s
[(-0.25)] -0.0125 .21454 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .40349 m
.00625 .40349 L
s
[(0.25)] -0.0125 .40349 1 0 Mshowa
0 .49796 m
.00625 .49796 L
s
[(0.5)] -0.0125 .49796 1 0 Mshowa
0 .59244 m
.00625 .59244 L
s
[(0.75)] -0.0125 .59244 1 0 Mshowa
.125 Mabswid
0 .04449 m
.00375 .04449 L
s
0 .06339 m
.00375 .06339 L
s
0 .08228 m
.00375 .08228 L
s
0 .10118 m
.00375 .10118 L
s
0 .13897 m
.00375 .13897 L
s
0 .15786 m
.00375 .15786 L
s
0 .17676 m
.00375 .17676 L
s
0 .19565 m
.00375 .19565 L
s
0 .23344 m
.00375 .23344 L
s
0 .25233 m
.00375 .25233 L
s
0 .27123 m
.00375 .27123 L
s
0 .29012 m
.00375 .29012 L
s
0 .32791 m
.00375 .32791 L
s
0 .34681 m
.00375 .34681 L
s
0 .3657 m
.00375 .3657 L
s
0 .3846 m
.00375 .3846 L
s
0 .42238 m
.00375 .42238 L
s
0 .44128 m
.00375 .44128 L
s
0 .46017 m
.00375 .46017 L
s
0 .47907 m
.00375 .47907 L
s
0 .51686 m
.00375 .51686 L
s
0 .53575 m
.00375 .53575 L
s
0 .55465 m
.00375 .55465 L
s
0 .57354 m
.00375 .57354 L
s
0 .0067 m
.00375 .0067 L
s
0 .61133 m
.00375 .61133 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0256 m
1 .0256 L
s
.99375 .12007 m
1 .12007 L
s
.99375 .21454 m
1 .21454 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .40349 m
1 .40349 L
s
.99375 .49796 m
1 .49796 L
s
.99375 .59244 m
1 .59244 L
s
.125 Mabswid
.99625 .04449 m
1 .04449 L
s
.99625 .06339 m
1 .06339 L
s
.99625 .08228 m
1 .08228 L
s
.99625 .10118 m
1 .10118 L
s
.99625 .13897 m
1 .13897 L
s
.99625 .15786 m
1 .15786 L
s
.99625 .17676 m
1 .17676 L
s
.99625 .19565 m
1 .19565 L
s
.99625 .23344 m
1 .23344 L
s
.99625 .25233 m
1 .25233 L
s
.99625 .27123 m
1 .27123 L
s
.99625 .29012 m
1 .29012 L
s
.99625 .32791 m
1 .32791 L
s
.99625 .34681 m
1 .34681 L
s
.99625 .3657 m
1 .3657 L
s
.99625 .3846 m
1 .3846 L
s
.99625 .42238 m
1 .42238 L
s
.99625 .44128 m
1 .44128 L
s
.99625 .46017 m
1 .46017 L
s
.99625 .47907 m
1 .47907 L
s
.99625 .51686 m
1 .51686 L
s
.99625 .53575 m
1 .53575 L
s
.99625 .55465 m
1 .55465 L
s
.99625 .57354 m
1 .57354 L
s
.99625 .0067 m
1 .0067 L
s
.99625 .61133 m
1 .61133 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .30902 L
s
.08333 .30902 m
.08333 .30902 L
s
.14286 .30902 m
.14286 .30902 L
s
.20238 .30902 m
.20238 .30975 L
s
.2619 .30902 m
.2619 .30902 L
s
.32143 .30902 m
.32143 .26919 L
s
.38095 .30902 m
.38095 .30902 L
s
.44048 .30902 m
.44048 .60332 L
s
.5 .30902 m
.5 .30902 L
s
.55952 .30902 m
.55952 .01472 L
s
.61905 .30902 m
.61905 .30902 L
s
.67857 .30902 m
.67857 .34885 L
s
.7381 .30902 m
.7381 .30902 L
s
.79762 .30902 m
.79762 .30829 L
s
.85714 .30902 m
.85714 .30902 L
s
.91667 .30902 m
.91667 .30902 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .30902 Mdot
.08333 .30902 Mdot
.14286 .30902 Mdot
.20238 .30975 Mdot
.2619 .30902 Mdot
.32143 .26919 Mdot
.38095 .30902 Mdot
.44048 .60332 Mdot
.5 .30902 Mdot
.55952 .01472 Mdot
.61905 .30902 Mdot
.67857 .34885 Mdot
.7381 .30902 Mdot
.79762 .30829 Mdot
.85714 .30902 Mdot
.91667 .30902 Mdot
.97619 .30902 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`009_ooool2
o`0003Sooooo1Ol0000jooooo`?o0000>?ooool3o`0003Wooooo0ol00007ooooo`009Oooool01?l0
003oooooooooool0000hooooo`04o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool0=_oo
ool01Ol0003ooooooooooooooooo000003Oooooo00Go0000ooooooooooooooooo`000006ooooo`00
9Oooool01?l0003oooooooooool0000iooooo`03o`000?oooooooooo03Sooooo1Ol0000gooooo`05
o`000?ooooooooooooooool00000=oooool01Ol0003ooooooooooooooooo000000Kooooo000Uoooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0=oooool01?l0003oooooooooool0
000hooooo`Co0000>Oooool3o`0000Oooooo000Uooooo`04o`000?ooooooooooo`0003Oooooo00Go
0000ooooooooooooooooo`00000iooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool0
>Oooool01Ol0003ooooooooooooooooo000000Kooooo000Uooooo`04o`000?ooooooooooo`0003Oo
oooo00Go0000ooooooooooooooooo`00000jooooo`;o0000>Oooool00ol0003oooooooooo`0hoooo
o`05o`000?ooooooooooooooool000001_ooool002Kooooo0_l0000iooooo`?o0000??ooool00ol0
003oooooooooo`0hooooo`;o0000>Oooool3o`0000Oooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo000Qooooo`0300000?l0003o00000?[o00000@000001oooo
o`008Oooool00`00003o0000ooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0n_ooool10000007ooooo
000Qooooo`0300000?oooooooooo08Wooooo0ooo001^ooooo`4000000Oooool000Sooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00<00000
ooooooooool0ROooool3ool006kooooo0@000001ooooo`001oooool01?l0003oooooooooool00009
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo08Wooooo0ooo001^ooooo`4000000Oooool000Go00000_ooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00`00003o0000oooo
o`2;ooooo`030?l00?oooooooooo06_ooooo0Ol000010000007ooooo0007ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo0007ooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooool000000ol00005ooooo`0300000?oooooooooo08_ooooo00<0
o`00ooooooooool0K?ooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Oo
0000ooooooooooooooooo`000?oooooo000000Sooooo00<00000ooooooooool0Roooool00`3o003o
ooooooooo`1/ooooo`4000000Oooool000Sooooo0_l00008ooooo`Go000000?oooooo`000?l00000
0ol00004ooooo`0300000?oooooooooo08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo
000Qooooo`0300000?l0003ooooo08_ooooo00<0o`00ooooooooool0Joooool1o`00004000000Ooo
ool0027ooooo00<00000ooooooooool0Roooool00`3o003oooooooooo`1/ooooo`4000000Oooool0
027ooooo00<00000ooooooooool0Roooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027o
oooo00<00000ooooooooool0Roooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo
00<00000ooooooooool0Roooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo00<0
0000o`000?ooool0Roooool00`3o003oooooooooo`1[ooooo`7o00000@000001ooooo`008Oooool0
0`00003oooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00
003oooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003ooooo
ooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003o0000oooo
o`2;ooooo`030?l00?oooooooooo06_ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooo
oooo08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?oooooooooo
08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?oooooooooo08_o
oooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?l0003ooooo08_ooooo
00<0o`00ooooooooool0Joooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0Rooo
ool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo00<00000ooooooooool0Roooool0
0`3o003oooooooooo`1/ooooo`4000000Oooool000kooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00005ooooo`0300000?oooooooooo08_ooooo00<0o`00ooooooooool0K?ooool10000
007ooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`0300000?oooooooooo08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo0006oooo
o`Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00<00000
o`000?ooool0Roooool00`3o003oooooooooo`1[ooooo`7o00000@000001ooooo`003Oooool01?l0
003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0Roooool0
0`3o003oooooooooo`1/ooooo`4000000Oooool000gooooo00Co0000oooooooooooo00001oooool4
o`0000Gooooo00<00000ooooooooool0Roooool00`3o003oooooooooo`1/ooooo`4000000Oooool0
00gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`0300000?oooooo
oooo08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000>ooooo`;o00002?ooool5o`00
00Cooooo00<00000ooooooooool0Roooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027o
oooo00<00000o`000?ooool0Roooool00`3o003oooooooooo`1[ooooo`7o00000@000001ooooo`00
8Oooool00`00003oooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Ooo
ool00`00003oooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool0
0`00003oooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00
003oooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003o
0000ooooo`2;ooooo`030?l00?oooooooooo06_ooooo0Ol000010000007ooooo000Qooooo`030000
0?oooooooooo08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?oo
oooooooo08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?oooooo
oooo08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?oooooooooo
08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?l0003ooooo08_o
oooo00<0o`00ooooooooool0Joooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0
Roooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo00<00000ooooooooool0Rooo
ool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo00<00000ooooooooool0Roooool0
0`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo00<00000o`000?ooool0Roooool00`3o
003oooooooooo`1[ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`2;ooooo`03
0?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003oooooooooo`2;ooooo`030?l0
0?oooooooooo06cooooo0@000001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo
1Ol00002ooooo`?o00001Oooool00`00003oooooooooo`2;ooooo`030?l00?oooooooooo06cooooo
0@000001ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo08_ooooo00<0o`00oooo
ooooool0K?ooool10000007ooooo0005o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00<00000o`000?ooool0Roooool00`3o
003oooooooooo`1[ooooo`7o00000@000001ooooo`001oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`2;oooo
o`030?l00?oooooooooo06cooooo0@000001ooooo`001oooool01?l0003oooooooooool00007oooo
o`06o`000?ooooooooooooooool0003ooooo1?l00005ooooo`0300000?oooooooooo08_ooooo00<0
o`00ooooooooool0K?ooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Oo
0000ooooooooooooooooo`000?oooooo000000Sooooo00<00000ooooooooool0Roooool00`3o003o
ooooooooo`1/ooooo`4000000Oooool000Sooooo0_l00009ooooo`?o00000_ooool5o`0000Cooooo
00<00000ooooooooool0Roooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo00<0
0000o`000?ooool0Roooool00`3o003oooooooooo`1[ooooo`7o00000@000001ooooo`008Oooool0
0`00003oooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00
003oooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003ooooo
ooooo`2;ooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003o0000oooo
o`2;ooooo`030?l00?oooooooooo06_ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooo
oooo08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?oooooooooo
08_ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?oooooooooo04go
oooo0ooo000kooooo`030?l00?oooooooooo06cooooo0@000001ooooo`008Oooool00`00003ooooo
ooooo`1=ooooo`?oo`00>oooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo00<0
0000o`000?ooool0COooool3ool003_ooooo00<0o`00ooooooooool0Joooool1o`00004000000Ooo
ool0027ooooo00<00000ooooooooool0C_ooool00`3o003oooooooooo`0jooooo`030?l00?oooooo
oooo06cooooo0@000001ooooo`008Oooool00`00003oooooooooo`1>ooooo`030?l00?oooooooooo
03[ooooo00<0o`00ooooooooool0K?ooool10000007ooooo000Qooooo`0300000?oooooooooo04ko
oooo00<0o`00ooooooooool0>_ooool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo
00<00000o`000?ooool0C_ooool00`3o003oooooooooo`0jooooo`030?l00?oooooooooo06_ooooo
0Ol000010000007ooooo000Qooooo`0300000?oooooooooo04kooooo00<0o`00ooooooooool0>_oo
ool00`3o003oooooooooo`1/ooooo`4000000Oooool0027ooooo00<00000ooooooooool0C_ooool0
0`3o003oooooooooo`0jooooo`030?l00?oooooooooo06cooooo0@000001ooooo`006_ooool2o`00
00Gooooo00<00000ooooooooool0C_ooool00`3o003oooooooooo`0jooooo`030?l00?oooooooooo
06cooooo0@000001ooooo`006Oooool01?l0003oooooooooool00004ooooo`0400000?oooooooooo
ooooo`?oo`003?ooool3ool000gooooo0ooo000Kooooo`?oo`003Oooool00`3o003oooooooooo`0;
ooooo`?oo`006oooool3ool000kooooo00<0o`00ooooooooool02_ooool3ool001cooooo0ooo000<
ooooo`?oo`003?ooool3ool000cooooo0ooo000<ooooo`?oo`001?ooool10000007ooooo000Ioooo
o`04o`000?ooooooooooo`0000Cooooo10000003ool000`000000ooo000=000000?oo`0030000003
ool000`000000ooo000=000000030?l000000000000000/000000ooo000=000000030?l000000000
000000/000000ooo000>000000030?l000000000000000X000000ooo000>000000030?l000000000
000000/000000ooo000<000000?oo`0030000003ool000`000000ooo000<000000?oo`001@000001
ooooo`006Oooool01?l0003oooooooooool00004ooooo`0400000?ooooooooooooooo`?oo`003?oo
ool3ool000gooooo0ooo000<ooooo`?oo`003?ooool3ool001_ooooo0ooo000=ooooo`030?l00?oo
oooooooo00_ooooo0ooo000Kooooo`?oo`003_ooool00`3o003oooooooooo`0;ooooo`?oo`003?oo
ool3ool000cooooo0ooo000<ooooo`?oo`003?ooool3ool000Cooooo0@000001ooooo`006Oooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo02oooooo0ooo000jooooo`030?l00?oo
oooooooo03[ooooo00<0o`00ooooooooool0C_ooool10000007ooooo000Iooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool0K?ooool00`3o003oooooooooo`0jooooo`030?l00?oo
oooooooo04kooooo0@000001ooooo`006_ooool2o`0000Gooooo00<00000ooooooooool0K?ooool0
0`3o003oooooooooo`0jooooo`030?l00?oooooooooo04kooooo0@000001ooooo`008Oooool00`00
003o0000ooooo`1/ooooo`030?l00?oooooooooo03[ooooo00<0o`00ooooooooool0COooool1o`00
004000000Oooool0027ooooo00<00000ooooooooool0K?ooool00`3o003oooooooooo`0jooooo`03
0?l00?oooooooooo04kooooo0@000001ooooo`008Oooool00`00003oooooooooo`1/ooooo`030?l0
0?oooooooooo03[ooooo00<0o`00ooooooooool0C_ooool10000007ooooo000Qooooo`0300000?oo
oooooooo06cooooo00<0o`00ooooooooool0>_ooool00`3o003oooooooooo`1>ooooo`4000000Ooo
ool0027ooooo00<00000ooooooooool0K?ooool00`3o003oooooooooo`0jooooo`030?l00?oooooo
oooo04kooooo0@000001ooooo`008Oooool00`00003o0000ooooo`1/ooooo`030?l00?oooooooooo
03Sooooo0ooo001?ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`1/ooooo`03
0?l00?oooooooooo03Sooooo0ooo001@ooooo`4000000Oooool0027ooooo00<00000ooooooooool0
K?ooool00`3o003oooooooooo`0hooooo`?oo`00D?ooool10000007ooooo000Qooooo`0300000?oo
oooooooo06cooooo00<0o`00ooooooooool0Roooool10000007ooooo000Qooooo`0300000?l0003o
oooo06cooooo00<0o`00ooooooooool0R_ooool1o`00004000000Oooool0027ooooo00<00000oooo
ooooool0K?ooool00`3o003oooooooooo`2;ooooo`4000000Oooool0027ooooo00<00000oooooooo
ool0K?ooool00`3o003oooooooooo`2;ooooo`4000000Oooool0027ooooo00<00000ooooooooool0
K?ooool00`3o003oooooooooo`2;ooooo`4000000Oooool0027ooooo00<00000ooooooooool0K?oo
ool00`3o003oooooooooo`2;ooooo`4000000Oooool0027ooooo00<00000o`000?ooool0K?ooool0
0`3o003oooooooooo`2:ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`1/oooo
o`030?l00?oooooooooo08_ooooo0@000001ooooo`008Oooool00`00003oooooooooo`1/ooooo`03
0?l00?oooooooooo08_ooooo0@000001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooo
oooo1Ol00002ooooo`?o00001Oooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo08_o
oooo0@000001ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo06cooooo00<0o`00
ooooooooool0Roooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`0300000?l0003ooooo06cooooo00<0o`00
ooooooooool0R_ooool1o`00004000000Oooool000Oooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0K?ooool0
0`3o003oooooooooo`2;ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00001oooool0
1_l0003ooooooooooooooooo0000ooooo`Co00001Oooool00`00003oooooooooo`1/ooooo`030?l0
0?oooooooooo08_ooooo0@000001ooooo`001oooool01?l0003oooooooooool00007ooooo`07o`00
0?ooooooooooooooool0003oooooo`000008ooooo`0300000?oooooooooo06cooooo00<0o`00oooo
ooooool0Roooool10000007ooooo0008ooooo`;o00002Oooool3o`0000;ooooo1Ol00004ooooo`03
00000?oooooooooo06cooooo00<0o`00ooooooooool0Roooool10000007ooooo000Qooooo`030000
0?l0003ooooo06cooooo00<0o`00ooooooooool0R_ooool1o`00004000000Oooool0027ooooo00<0
0000ooooooooool0K?ooool00`3o003oooooooooo`2;ooooo`4000000Oooool0027ooooo00<00000
ooooooooool0K?ooool00`3o003oooooooooo`2;ooooo`4000000Oooool0027ooooo00<00000oooo
ooooool0K?ooool00`3o003oooooooooo`2;ooooo`4000000Oooool0027ooooo00<00000oooooooo
ool0K?ooool00`3o003oooooooooo`2;ooooo`4000000Oooool0027ooooo00<00000o`000?ooool0
K?ooool00`3o003oooooooooo`2:ooooo`7o00000@000001ooooo`008Oooool00`00003ooooooooo
o`1/ooooo`030?l00?oooooooooo08_ooooo0@000001ooooo`008Oooool00`00003oooooooooo`1/
ooooo`030?l00?oooooooooo08_ooooo0@000001ooooo`008Oooool00`00003oooooooooo`1/oooo
o`030?l00?oooooooooo08_ooooo0@000001ooooo`008Oooool00`00003o0000ooooo`1/ooooo`03
0?l00?oooooooooo08[ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo06cooooo
00<0o`00ooooooooool0Roooool10000007ooooo000Qooooo`0300000?oooooooooo06cooooo00<0
o`00ooooooooool0Roooool10000007ooooo000Qooooo`0300000?oooooooooo06cooooo00<0o`00
ooooooooool0Roooool10000007ooooo000Qooooo`0300000?oooooooooo06cooooo00<0o`00oooo
ooooool0Roooool10000007ooooo000Qooooo`0300000?l0003ooooo06cooooo00<0o`00oooooooo
ool0R_ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0K?ooool00`3o003ooooo
ooooo`2;ooooo`4000000Oooool0027ooooo00<00000ooooooooool0K?ooool00`3o003ooooooooo
o`2;ooooo`4000000Oooool000kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`0300000?oooooooooo06cooooo00<0o`00ooooooooool0Roooool10000007ooooo000=oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oo
oooooooo06cooooo00<0o`00ooooooooool0Roooool10000007ooooo000=ooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooooooool00_ooool00`00003o0000ooooo`1/ooooo`030?l00?oo
oooooooo08[ooooo0Ol000010000007ooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool00_ooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo08_ooooo0@00
0001ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co00001Oooool00`00003ooooooooo
o`1/ooooo`030?l00?oooooooooo08_ooooo0@000001ooooo`003Oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool0K?ooool00`3o003ooooooooo
o`2;ooooo`4000000Oooool000kooooo0_l00008ooooo`Go00001?ooool00`00003oooooooooo`1/
ooooo`030?l00?oooooooooo08_ooooo0@000001ooooo`008Oooool00`00003o0000ooooo`1/oooo
o`030?l00?oooooooooo08[ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo06co
oooo00<0o`00ooooooooool0Roooool10000007ooooo000Qooooo`0300000?oooooooooo06cooooo
00<0o`00ooooooooool0Roooool10000007ooooo000Qooooo`0300000?oooooooooo06cooooo00<0
o`00ooooooooool0Roooool10000007ooooo000Qooooo`0300000?oooooooooo06cooooo00<0o`00
ooooooooool0Roooool10000007ooooo000Qooooo`0300000?l0003ooooo06cooooo00<0o`00oooo
ooooool0R_ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0K?ooool00`3o003o
ooooooooo`2;ooooo`4000000Oooool0027ooooo00<00000ooooooooool0K?ooool00`3o003ooooo
ooooo`2;ooooo`4000000Oooool0027ooooo00<00000ooooooooool0K?ooool00`3o003ooooooooo
o`2;ooooo`4000000Oooool0027ooooo00<00000o`000?ooool0K?ooool00`3o003oooooooooo`2:
ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo
08_ooooo0@000001ooooo`008Oooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo08_o
oooo0@000001ooooo`008Oooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo08_ooooo
0@000001ooooo`008Oooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo08_ooooo0@00
0001ooooo`008Oooool00`00003o0000ooooo`1/ooooo`030?l00?oooooooooo08[ooooo0Ol00001
0000007ooooo000Qooooo`0300000?oooooooooo06cooooo00<0o`00ooooooooool0Roooool10000
007ooooo000Qooooo`0300000?oooooooooo06cooooo00<0o`00ooooooooool0Roooool10000007o
oooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
0ol00005ooooo`0300000?oooooooooo06cooooo00<0o`00ooooooooool0Roooool10000007ooooo
0007ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00<00000ooooooooool0K?ooool00`3o003oooooooooo`2;ooooo`40
00000Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00<00000o`000?ooool0K?ooool00`3o003oooooooooo`2:ooooo`7o
00000@000001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00`00003oooooooooo`1/ooooo`030?l00?oooooooooo08_o
oooo0@000001ooooo`001oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000?o
00001Oooool00`00003oooooooooo`1[ooooo`?oo`00S?ooool10000007ooooo0007ooooo`04o`00
0?ooooooooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00<00000
ooooooooool0Joooool3ool008cooooo0@000001ooooo`002?ooool2o`0000Sooooo1Ol000000ooo
oooo0000o`000003o`0000Cooooo00<00000ooooooooool0Joooool3ool008cooooo0@000001oooo
o`008Oooool00`00003o0000ooooo`03ooooo`0300000?oooooooooo03Wooooo00<00000oooooooo
ool0>_ooool00`00003oooooooooo`0iooooo`0300000?oooooooooo03Wooooo00<00000oooooooo
ool00_ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool00oooool00`00003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00<00000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00`00003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`0300000?oooooooooo00?ooooo0@000001ooooo`008Oooooon0000007ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.29833, -0.986268, \
0.0331097, 0.0104306}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.308941 0.302543 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0064 -12 -4.5 ]
[-0.0125 .0064 0 4.5 ]
[-0.0125 .15767 -24 -4.5 ]
[-0.0125 .15767 0 4.5 ]
[-0.0125 .30894 -6 -4.5 ]
[-0.0125 .30894 0 4.5 ]
[-0.0125 .46021 -18 -4.5 ]
[-0.0125 .46021 0 4.5 ]
[-0.0125 .61148 -6 -4.5 ]
[-0.0125 .61148 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(6)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(8)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0064 m
.00625 .0064 L
s
[(-1)] -0.0125 .0064 1 0 Mshowa
0 .15767 m
.00625 .15767 L
s
[(-0.5)] -0.0125 .15767 1 0 Mshowa
0 .30894 m
.00625 .30894 L
s
[(0)] -0.0125 .30894 1 0 Mshowa
0 .46021 m
.00625 .46021 L
s
[(0.5)] -0.0125 .46021 1 0 Mshowa
0 .61148 m
.00625 .61148 L
s
[(1)] -0.0125 .61148 1 0 Mshowa
.125 Mabswid
0 .03665 m
.00375 .03665 L
s
0 .06691 m
.00375 .06691 L
s
0 .09716 m
.00375 .09716 L
s
0 .12741 m
.00375 .12741 L
s
0 .18792 m
.00375 .18792 L
s
0 .21818 m
.00375 .21818 L
s
0 .24843 m
.00375 .24843 L
s
0 .27869 m
.00375 .27869 L
s
0 .3392 m
.00375 .3392 L
s
0 .36945 m
.00375 .36945 L
s
0 .3997 m
.00375 .3997 L
s
0 .42996 m
.00375 .42996 L
s
0 .49047 m
.00375 .49047 L
s
0 .52072 m
.00375 .52072 L
s
0 .55098 m
.00375 .55098 L
s
0 .58123 m
.00375 .58123 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0064 m
1 .0064 L
s
.99375 .15767 m
1 .15767 L
s
.99375 .30894 m
1 .30894 L
s
.99375 .46021 m
1 .46021 L
s
.99375 .61148 m
1 .61148 L
s
.125 Mabswid
.99625 .03665 m
1 .03665 L
s
.99625 .06691 m
1 .06691 L
s
.99625 .09716 m
1 .09716 L
s
.99625 .12741 m
1 .12741 L
s
.99625 .18792 m
1 .18792 L
s
.99625 .21818 m
1 .21818 L
s
.99625 .24843 m
1 .24843 L
s
.99625 .27869 m
1 .27869 L
s
.99625 .3392 m
1 .3392 L
s
.99625 .36945 m
1 .36945 L
s
.99625 .3997 m
1 .3997 L
s
.99625 .42996 m
1 .42996 L
s
.99625 .49047 m
1 .49047 L
s
.99625 .52072 m
1 .52072 L
s
.99625 .55098 m
1 .55098 L
s
.99625 .58123 m
1 .58123 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30894 m
1 .30894 L
s
1 0 0 r
.5 Mabswid
.02381 .30894 m
.02381 .30894 L
s
.08333 .30894 m
.08333 .30894 L
s
.14286 .30894 m
.14286 .30894 L
s
.20238 .30894 m
.20238 .30952 L
s
.2619 .30894 m
.2619 .30894 L
s
.32143 .30894 m
.32143 .27705 L
s
.38095 .30894 m
.38095 .30894 L
s
.44048 .30894 m
.44048 .54456 L
s
.5 .30894 m
.5 .30894 L
s
.55952 .30894 m
.55952 .07332 L
s
.61905 .30894 m
.61905 .30894 L
s
.67857 .30894 m
.67857 .34083 L
s
.7381 .30894 m
.7381 .30894 L
s
.79762 .30894 m
.79762 .30836 L
s
.85714 .30894 m
.85714 .30894 L
s
.91667 .30894 m
.91667 .30894 L
s
.97619 .30894 m
.97619 .30894 L
s
.015 w
.02381 .30894 Mdot
.08333 .30894 Mdot
.14286 .30894 Mdot
.20238 .30952 Mdot
.2619 .30894 Mdot
.32143 .27705 Mdot
.38095 .30894 Mdot
.44048 .54456 Mdot
.5 .30894 Mdot
.55952 .07332 Mdot
.61905 .30894 Mdot
.67857 .34083 Mdot
.7381 .30894 Mdot
.79762 .30836 Mdot
.85714 .30894 Mdot
.91667 .30894 Mdot
.97619 .30894 Mdot
0 0 1 r
.5 Mabswid
.02381 .30894 m
.02605 .30894 L
.02846 .30894 L
.03279 .30894 L
.03793 .30894 L
.04262 .30894 L
.04499 .30894 L
.0475 .30894 L
.04882 .30894 L
.04951 .30894 L
.05026 .30894 L
.05158 .30894 L
.05281 .30894 L
.05404 .30894 L
.05474 .30894 L
.05539 .30894 L
.05658 .30894 L
.05784 .30894 L
.05908 .30894 L
.06026 .30894 L
.06244 .30894 L
.06489 .30894 L
.06757 .30894 L
.07299 .30894 L
.08269 .30894 L
.08549 .30894 L
.08687 .30894 L
.08815 .30894 L
.08886 .30894 L
.08962 .30894 L
.09038 .30894 L
.09121 .30894 L
.09191 .30894 L
.09266 .30894 L
.09336 .30894 L
.09401 .30894 L
.09528 .30894 L
.09647 .30894 L
.09777 .30894 L
.09916 .30894 L
.102 .30894 L
.10458 .30894 L
.10943 .30894 L
.11456 .30895 L
.119 .30895 L
.12376 .30895 L
.12514 .30896 L
.12644 .30896 L
.12761 .30896 L
.12888 .30896 L
Mistroke
.13008 .30896 L
.13137 .30896 L
.13257 .30896 L
.13367 .30896 L
.13435 .30896 L
.13507 .30896 L
.13637 .30895 L
.13776 .30895 L
.13928 .30895 L
.14201 .30894 L
.14456 .30894 L
.14958 .30891 L
.15504 .30888 L
.15985 .30886 L
.16248 .30884 L
.16377 .30884 L
.16495 .30883 L
.16601 .30883 L
.16716 .30883 L
.16832 .30882 L
.16954 .30882 L
.17081 .30882 L
.17152 .30883 L
.17217 .30883 L
.17342 .30883 L
.17461 .30884 L
.17569 .30885 L
.17683 .30886 L
.17889 .30888 L
.1811 .30891 L
.18352 .30896 L
.18875 .30909 L
.19371 .30925 L
.19822 .3094 L
.20069 .30948 L
.20301 .30954 L
.2043 .30957 L
.20548 .30959 L
.20679 .3096 L
.20748 .3096 L
.20821 .30961 L
.2094 .3096 L
.2105 .3096 L
.21172 .30958 L
.21302 .30954 L
.21443 .3095 L
.21595 .30943 L
.21872 .30925 L
.22142 .30902 L
.22391 .30875 L
Mistroke
.23295 .30746 L
.23792 .30669 L
.24038 .30636 L
.24265 .30612 L
.24394 .30601 L
.2446 .30597 L
.24532 .30593 L
.2461 .3059 L
.24684 .30589 L
.24756 .30588 L
.24822 .30589 L
.2494 .30593 L
.2507 .30602 L
.25135 .30608 L
.25205 .30616 L
.25331 .30634 L
.25459 .30658 L
.25599 .3069 L
.25853 .30764 L
.26329 .30957 L
.27349 .31537 L
.27593 .31678 L
.27849 .31812 L
.28087 .31913 L
.28202 .31953 L
.28307 .31981 L
.28419 .32004 L
.28537 .32019 L
.28666 .32022 L
.28788 .32012 L
.28918 .31988 L
.29037 .31951 L
.29168 .31894 L
.29307 .31815 L
.29578 .31602 L
.29832 .31333 L
.30409 .30498 L
.30907 .29604 L
.3145 .28616 L
.31699 .28221 L
.31835 .28032 L
.31964 .27878 L
.32084 .27756 L
.32213 .27653 L
.32331 .27588 L
.32439 .27554 L
.32547 .27546 L
.32662 .27569 L
.32771 .2762 L
.3287 .27693 L
Mistroke
.32986 .27812 L
.33112 .27983 L
.33341 .28407 L
.33582 .29004 L
.33836 .29802 L
.34293 .3159 L
.35234 .35884 L
.35505 .36986 L
.35762 .37857 L
.35874 .38165 L
.35993 .3844 L
.36124 .3867 L
.36246 .38812 L
.36369 .3888 L
.36483 .3887 L
.36608 .38777 L
.3674 .38582 L
.36854 .38329 L
.36962 .38021 L
.37205 .37068 L
.37425 .35912 L
.37625 .34628 L
.38075 .31068 L
.39 .22434 L
.39467 .18656 L
.39595 .17822 L
.39733 .1705 L
.39863 .16458 L
.39983 .16033 L
.40114 .15719 L
.40183 .15618 L
.40257 .15562 L
.40335 .15563 L
.40408 .15619 L
.40474 .15718 L
.40545 .15876 L
.40676 .16304 L
.40741 .16588 L
.40814 .16954 L
.41061 .18621 L
.41309 .20913 L
.41576 .23996 L
.42059 .30821 L
.42549 .38562 L
.43071 .46327 L
.43372 .49982 L
.43644 .52493 L
.43776 .5338 L
.43845 .53753 L
.43918 .54074 L
Mistroke
.43982 .54293 L
.44052 .54464 L
.44175 .54586 L
.4424 .54557 L
.4431 .54452 L
.44438 .54063 L
.44562 .5344 L
.44677 .52651 L
.44938 .50123 L
.45215 .46399 L
.45676 .38254 L
.46185 .27587 L
.46678 .17191 L
.46947 .12122 L
.47196 .08086 L
.47411 .05288 L
.4752 .04126 L
.47639 .03091 L
.4777 .02237 L
.47893 .01713 L
.48012 .01472 L
.48123 .01488 L
.48243 .0177 L
.48373 .02376 L
.48495 .03232 L
.48606 .04249 L
.48878 .07631 L
.49137 .11892 L
.50209 .35886 L
.50706 .4688 L
.50949 .51419 L
.51173 .54882 L
.51407 .57665 L
.5153 .58747 L
.51659 .5959 L
.51723 .59892 L
.51792 .60129 L
.51916 .60332 L
.51992 .60313 L
.52063 .60196 L
.52127 .6001 L
.52197 .59721 L
.52311 .59058 L
.52418 .58228 L
.52662 .55631 L
.52899 .52248 L
.53154 .47836 L
.54038 .29407 L
.54527 .19682 L
.54796 .15222 L
Mistroke
.55049 .11816 L
.55193 .10268 L
.55349 .08939 L
.55418 .0847 L
.55491 .08053 L
.55621 .07514 L
.55752 .0724 L
.55874 .07223 L
.55944 .07316 L
.56008 .07466 L
.56082 .07713 L
.56152 .08019 L
.56267 .08672 L
.56394 .09596 L
.56652 .12063 L
.57114 .18069 L
.57624 .25983 L
.58161 .34239 L
.58643 .40375 L
.58917 .42986 L
.59047 .43976 L
.59171 .44748 L
.59283 .45312 L
.59405 .45771 L
.59516 .46052 L
.59618 .46196 L
.59729 .4623 L
.59851 .46127 L
.59978 .45866 L
.60096 .45489 L
.60225 .44942 L
.60366 .44196 L
.60622 .42491 L
.61102 .3842 L
.61659 .33139 L
.62182 .28581 L
.62424 .26824 L
.6268 .25292 L
.62813 .24636 L
.6296 .24036 L
.63094 .23598 L
.63217 .23292 L
.63337 .2308 L
.63451 .22956 L
.63571 .22905 L
.63702 .22938 L
.63816 .23039 L
.63937 .23216 L
.6404 .23419 L
.64154 .23695 L
Mistroke
.64426 .24548 L
.64676 .25518 L
.65237 .28058 L
.65729 .30292 L
.65998 .31387 L
.66253 .32283 L
.665 .33005 L
.66631 .3332 L
.66768 .33602 L
.66884 .33799 L
.67012 .33973 L
.67128 .34093 L
.67236 .34172 L
.67354 .34225 L
.67466 .34242 L
.67567 .34233 L
.67677 .34196 L
.67796 .34129 L
.67922 .34027 L
.68149 .33776 L
.68657 .32986 L
.69134 .32108 L
.69653 .31189 L
.69928 .30769 L
.70221 .30394 L
.70487 .30128 L
.7073 .29951 L
.70846 .29887 L
.70973 .29834 L
.71093 .29798 L
.71203 .29777 L
.71327 .29766 L
.71442 .29768 L
.71569 .29782 L
.7164 .29795 L
.71705 .2981 L
.71836 .29848 L
.71978 .299 L
.72238 .30019 L
.7319 .30574 L
.73658 .30824 L
.74087 .31004 L
.74329 .3108 L
.74584 .31139 L
.74716 .31161 L
.7484 .31177 L
.74909 .31184 L
.74975 .3119 L
.75051 .31195 L
.75121 .31198 L
Mistroke
.75234 .312 L
.75354 .31199 L
.75456 .31196 L
.75569 .31189 L
.7569 .3118 L
.75821 .31168 L
.76057 .3114 L
.77059 .30987 L
.77589 .30915 L
.77885 .30883 L
.78155 .30861 L
.78411 .30845 L
.78556 .30839 L
.7869 .30834 L
.78806 .30831 L
.78935 .30829 L
.79 .30828 L
.79069 .30828 L
.79194 .30827 L
.79318 .30828 L
.79389 .30829 L
.79454 .3083 L
.79573 .30832 L
.797 .30834 L
.80161 .30847 L
.80696 .30865 L
.81261 .30883 L
.81743 .30894 L
.82017 .30899 L
.82271 .30902 L
.82406 .30903 L
.82533 .30904 L
.82647 .30905 L
.8277 .30905 L
.82834 .30905 L
.82905 .30906 L
.82979 .30906 L
.83048 .30906 L
.83171 .30906 L
.83241 .30906 L
.83304 .30905 L
.83446 .30905 L
.83577 .30905 L
.83876 .30903 L
.84419 .309 L
.84922 .30897 L
.85396 .30895 L
.85658 .30894 L
.85942 .30893 L
.86068 .30893 L
Mistroke
.862 .30893 L
.86324 .30893 L
.86438 .30893 L
.8656 .30893 L
.86624 .30893 L
.86692 .30892 L
.86807 .30892 L
.86933 .30892 L
.87045 .30892 L
.87166 .30892 L
.87281 .30892 L
.87385 .30893 L
.87622 .30893 L
.8788 .30893 L
.88401 .30893 L
.8886 .30894 L
.89113 .30894 L
.89351 .30894 L
.89573 .30894 L
.89814 .30894 L
.90033 .30894 L
.90234 .30894 L
.9036 .30894 L
.90478 .30894 L
.90585 .30894 L
.90702 .30894 L
.90828 .30894 L
.90898 .30894 L
.90962 .30894 L
.91086 .30894 L
.91204 .30894 L
.91314 .30894 L
.91431 .30894 L
.91639 .30894 L
.9211 .30894 L
.92586 .30894 L
.93095 .30894 L
.93387 .30894 L
.93653 .30894 L
.93782 .30894 L
.93921 .30894 L
.94053 .30894 L
.94174 .30894 L
.94269 .30894 L
.94372 .30894 L
.94475 .30894 L
.94584 .30894 L
.94681 .30894 L
.94784 .30894 L
.94881 .30894 L
Mistroke
.94969 .30894 L
.95082 .30894 L
.95186 .30894 L
.9542 .30894 L
.95846 .30894 L
.97619 .30894 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`008?ooool2o`0003[ooooo1Ol0000kooooo`?o0000>Oooool3o`0003_ooooo0ol00007oooo
o`007oooool01?l0003oooooooooool0000jooooo`04o`000?ooooooooooo`0003cooooo00?o0000
ooooooooool0=oooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000oooooooooooooooo
o`000006ooooo`007oooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Wooooo
1Ol0000hooooo`05o`000?ooooooooooooooool00000>Oooool01Ol0003ooooooooooooooooo0000
00Kooooo000Oooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0>?ooool01?l0
003oooooooooool0000iooooo`Co0000>oooool3o`0000Oooooo000Oooooo`04o`000?oooooooooo
o`0003Wooooo00Go0000ooooooooooooooooo`00000jooooo`03o`000?oooooo000003Wooooo00?o
0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000000Kooooo000Oooooo`04o`000?oo
ooooooooo`0003Wooooo00Go0000ooooooooooooooooo`00000kooooo`;o0000>_ooool00ol0003o
ooooooooo`0jooooo`05o`000?ooooooooooooooool000001_ooool0023ooooo0_l0000kooooo`?o
0000?Oooool00ol0003oooooooooo`0iooooo`;o0000>oooool3o`0000Oooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Cooooo`?o0000ooooool;ooooo`00
5?ooool00ol0003oooooooooo`04oooooooo00001Ol00001ooooo`003?ooool5o`0000?ooooo00?o
0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`02ooooo`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooo`7ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
07Wooooo0_l00?n5ooooo`7o00000Oooool001?ooooo0_l00006ooooo`03o`000?oooooooooo07Wo
oooo0_l00?n5ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1iooooo`;o003oQOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Wooooo0_l0
0?n5ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool00ol00?ooooooo`00o`25
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool01?l00?ooooooooooool00?n4
ooooo`7o00000Oooool001_ooooo0_l0001iooooo`04o`00ooooooooooooo`00oh?ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`04o`00ooooooooooooo`00ohCooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1hooooo`05o`00ooooooooooooooooool00?l0Poooool1
o`00007ooooo000Kooooo`;o0000NOooool01Ol00?oooooooooooooooooo003o08;ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool03_ooool2o`00o`03ool00?oooooooooo06kooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_ooool2o`00o`03
ool00?oooooooooo06kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03_ooool3o`00og3ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03_oo
ool00ol00?l0o`00o`00o`1`ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00kooooo00?o003o0?l00?l00?l0L?ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0=ooooo`04o`00ooooool0o`00o`00og3ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01?l0
0?oooooo0?l00?l00?m`ooooo`7o00000Oooool001_ooooo0_l0001hooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool03Oooool01?l00?oooooo0?l00?l00?m_ooooo`;o00000Oooool0
01_ooooo00?o0000ooooooooool0Moooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00gooooo00Co003oooooo`3o003o003oL?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
07Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`04o`00ooooool0o`00
o`00og3ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool03Oooool01Ol00?oooooo0?l00?oooooo003o06oooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool03Oooool01Ol00?oooooo0?l00?oooooo003o06oooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1gooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol0
0?oooooo0?l00?oooooo003o06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1goooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool03Oooool01Ol00?oooooo0?l00?oooooo
003o06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1gooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool03Oooool01Ol00?oooooo0?l00?oooooo003o06oooooo0Ol00001
ooooo`006oooool2o`0007Sooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=oooo
o`05o`00ooooool0o`00ooooool00?l0K_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo
07Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0=ooooo`05o`00ooooool0o`00
ooooool00?l0Koooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0<ooooo`06o`00oooooooooooo0?l00?oooooo003oKooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0<ooooo`06o`00oooooooooooo0?l00?oooooo003oKoooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo07Oooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0<ooooo`06o`00oooooooooooo0?l00?oooooo003oKoooool1o`00007ooooo0008ooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1fooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool03?ooool01_l00?ooooooooooo`3o003oooooo`00
ofoooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`1fooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03?ooool01?l00?ooooooooooo`3o0002ooooo`03o`00oooooooooooo06cooooo0Ol0
0001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_oo
ool2o`0006Kooooo0_l00?l?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03?oo
ool01?l00?ooooooooooo`3o0002ooooo`03o`00oooooooooooo06_ooooo0_l00001ooooo`001ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
IOooool2o`00o`oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`04o`00
oooooooooooo0?l000;ooooo00?o003oooooooooool0K?ooool1o`00007ooooo0007ooooo`04o`00
0?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo06Cooooo00?o003oooooool0
0?l03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooo
ool0o`000_ooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool000Oooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Cooooo00Co003ooooo
oooooooo003o3_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo00Co003o
ooooooooool0o`000_ooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool000Sooooo0_l00008
ooooo`Go00001?ooool00ol0003oooooooooo`1Tooooo`04o`00ooooooooooooo`00o`kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0;ooooo`04o`00oooooooooooo0?l000;ooooo
00?o003oooooooooool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Cooooo00Co
003ooooooooooooo003o3_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00_ooooo
00Co003oooooooooool0o`000_ooool00ol00?ooooooooooo`1/ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0I?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02_ooool01Ol00?ooooooooooooooool0o`0000;ooooo00?o003ooooo
ooooool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Cooooo00Co003ooooooooo
oooo003o3_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00[ooooo00Go003ooooo
oooooooooooo0?l00002ooooo`03o`00oooooooooooo06cooooo0Ol00001ooooo`006oooool2o`00
06Cooooo00Go003oooooooooooooooooo`00o`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool02_ooool01Ol00?ooooooooooooooool0o`0000;ooooo00?o003oooooooooool0Jooo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo06?ooooo00Go003oooooooooooooooooo`00
o`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02_ooool01Ol00?oooooooooo
ooooool0o`0000;ooooo00?o003oooooooooool0K?ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo06?ooooo00Go003oooooooooooooooooo`00o`0>ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool02_ooool01Ol00?ooooooooooooooool0o`0000;ooooo00?o003ooooooooo
ool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06?ooooo00Go003ooooooooooooo
ooooo`00o`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02_ooool01Ol00?oo
ooooooooooooool0o`0000;ooooo00?o003oooooooooool0K?ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo06?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool02_ooool01Ol00?ooooooooooooooool0o`00
00;ooooo00?o003oooooooooool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02_ooool01Ol00?ooooooooooooooool0o`0000;ooooo00?o003ooooo
ooooool0K?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06;ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02_ooool01Ol00?ooooooooooooooool0o`0000;ooooo00?o003oooooooooool0K?ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02_ooool01Ol00?oo
ooooooooooooool0o`0000;ooooo00?o003oooooooooool0K?ooool1o`00007ooooo000Kooooo`;o
0000Hoooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooo`3o00000_ooool00ol0
0?ooooooooooo`1[ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0H_ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0:ooooo`05o`00ooooooooooooooooo`3o00000oooool00ol00?ooooooooooo`1[oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0H_ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`05
o`00ooooooooooooooooo`3o00000oooool00ol00?ooooooooooo`1[ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0H_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooooooo
o`3o00000oooool00ol00?ooooooooooo`0<ooooo`;o003oGOooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo06;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool02_ooool01Ol00?ooooooooooooooool0o`00
00?ooooo00?o003oooooooooool03?ooool00ol00?ooooooo`00o`1Looooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0H_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0:ooooo`05o`00oooooooooooooooo
o`3o00000oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo003o05cooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1Rooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Wooooo00Go003ooooooooo
oooooooo0?l00003ooooo`03o`00oooooooooooo00_ooooo00Co003ooooooooooooo003oG?ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo06;ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02Oooool01Ol0
0?ooooooooooooooool0o`0000?ooooo00?o003oooooooooool02oooool01Ol00?oooooooooooooo
oooo003o05_ooooo0Ol00001ooooo`006oooool2o`0006;ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`02ooooo`050?l00?ooooooooooooooool00?l03Oooool01Ol00?oooooooooo
oooooooo003o05[ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1Qooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool00_ooool01@3o003ooooooooooooooooo003o00cooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`1Hooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0HOooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00;ooooo00D0
o`00ooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
F?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo067ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`02ooooo`050?l00?ooooooooooooooool00?l03?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo05Sooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1Qooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00_ooool01@3o003ooooooooo
oooooooo003o00cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1Hooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0HOooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00;ooooo00D0o`00ooooooooooooooooo`00o`0<ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0F?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo067ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`02ooooo`050?l00?ooooooooooooooool00?l0
3?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1?ooooo`04ool00?l00?oo003oo`00o`kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`02ooooo`050?l00?ooooooooooooooool00?l03?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo05Oooooo0Ol00001ooooo`006oooool2o`00053ooooo
0_l00?l00ooo003o003oo`00o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
0_ooool01@3o003ooooooooooooooooo003o00_ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1Fooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Coooool01Ol00?ooo`00
ool00?oooooo003o00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`02ooooo`03
0?l00?oooooooooo00;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo05Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1>ooooo`03o`00
ooooool0o`0000;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00;ooooo00<0o`00ooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool0Eoooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo04kooooo00?o003oooooo`3o00000oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool00_ooool00`3o003oooooooooo`02ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Gooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0COooool01?l00?ooooooooooo`3o0003ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`02ooooo`030?l00?oo
oooooooo00;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo05Kooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0COooool0
1?l00?ooooooooooo`3o0004ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo1_l00?m6ooooo`7o00000Ooo
ool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1<ooooo`05o`00oooo
ooooooooooooo`3o00001?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool00_ooool00`3o003oooooooooo`02ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`09ooooo`;o003o1Oooool00ol00?oooooo
ooooo`13ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool01?l0003ooooo
ooooooooool3ool000gooooo0ooo000<ooooo`?oo`003Oooool3ool000Gooooo2Ol00?l00ooo003o
ooooooooo`08ooooo`05o`00ooooooooooooooooo`3o00001?ooool00ol00?ooooooooooo`06oooo
o`;oo`0000?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?oo`00o`00oooo00002Oooool00ol00?ooooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00?o003oooooooooool01_ooool2ool00003o`00oooooooooooo00Kooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo003oo`0000cooooo0ooo000=oooo
o`?oo`003?ooool3ool000gooooo0ooo0004ooooo`7o00000Oooool001?ooooo00Co0000oooooooo
oooo00001?ooool4o`0000;oo`00=Ol00?l7o`0000;oo`000ol00?l7o`000003o`00ool0003o0000
00;o000000<0o`00o`000?l000000ol000000ol00?oo0000o`000005o`0000;oo`0000?o003oo`00
0?l000001ol000000ol00?oo0000o`000002o`0000030?l00?l0003o000000;o000000?o003oo`00
0?l000001_l000000ooo003o003oool00009o`000003o`00ool0003o000000;o000000<0o`00o`00
0?l000000_l000000ol00?oo0000o`000006o`0000;oo`0000?o003oo`000?l000001ol000000ol0
0?oo0000o`000002o`0000030?l00?l0003o000000;o000000?o003oo`000?l000001_l000000ooo
003o003oo`00o`02o`00o`03o`000?l00?oo003o037o003o1`000?l00ooo003o0000o`000003o`00
007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0ooo000=
ooooo`?oo`003?ooool3ool000gooooo0ooo000<ooooo`?oo`000_ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01Oooool2ool00003o`00oooooooo
oooo00Oooooo00?o003oooooooooool00_ooool00`3o003oooooooooo`02ooooo`03o`00oooooooo
oooo00Kooooo00?oo`00o`00oooo00002Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00Kooooo00?oo`00o`00oooo00002Oooool00ol00?ooooooooooo`02ooooo`030?l00?oooooo
oooo00;ooooo00?o003oooooooooool01_ooool3ool00004ooooool00?oo003oo`00o`Sooooo0ooo
000=ooooo`?oo`003?ooool3ool000gooooo0ooo0004ooooo`7o00000Oooool001?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`14ooooo`?o003o00Coooooo`00ool00?oo003o
2oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
0_ooool00`3o003oooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`02ooooo`050?l00?ooooooooooooooool00?l0C_ooool1o`00007o
oooo000Dooooo`;o00001Oooool00ol0003oooooooooo`16ooooo`?o003o3Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02Oooool01Ol00?oooooo
ooooooooool0o`0000;ooooo00?o003oooooooooool0COooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo05Kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00;ooooo00<0o`00ooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Wooooo00Go003ooooooooooooooooo0?l00002ooooo`03o`00oooooooooooo04go
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Fooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`02ooooo`030?l00?oooooooooo00;ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`09ooooo`07o`00ooooooooooooooooo`3o
003oooooo`00o`1@ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Eoooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool01_l00?oo
ooooooooo`3o003oooooo`00oe3ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Goooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:oooo
o`05o`00oooo003oo`00ool00?l00?l0DOooool1o`00007ooooo000Kooooo`;o0000F?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool00`3o
003oooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02oooool3o`00
oe7ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1Gooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`030?l00?oooooooooo00;o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`?oo`00D_ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo05Oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00;ooooo00<0o`00ooooooooool00_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo067ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1Hooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02_ooool01Ol00?oooooooooo
ooooool0o`0000Cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`1Qooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0F?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00[ooooo00Go003ooooooooooooooooo0?l00004ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool0HOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05Sooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0:ooooo`05o`00ooooooooooooooooo`3o0000
0oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo067ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1Hooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02_oo
ool01Ol00?ooooooooooooooool0o`0000?ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`1Qooooo`7o00000Oooool001_ooooo0_l0001Jooooo`05o`00ooooooooooooooooool00?l0
3Oooool01Ol00?ooooooooooooooool0o`0000?ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1Pooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0FOooool01Ol00?oooooo
oooooooooooo003o00gooooo00Go003ooooooooooooooooo0?l00003ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0HOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05Wo
oooo00Go003oooooooooooooooooo`00o`0=ooooo`05o`00ooooooooooooooooo`3o00000oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo06;ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1Jooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooooooooooooooo0?l0
0003ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0H_ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo05[ooooo00?o003oooooool00?l03_ooool01Ol00?oooooooooooooo
ool0o`0000?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1Rooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0Foooool2o`00o`kooooo00Go003ooooooooooooooooo0?l0
0003ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0H_ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo06_ooooo00Go003ooooooooooooooooo0?l00003ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0H_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo06_ooooo00Go003ooooooooooooooooo0?l00003ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0H_ooool1o`00007ooooo000Kooooo`;o0000K?ooool01Ol00?oooooooooooooo
ool0o`0000?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`1Qooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool0Joooool01Ol00?ooooooooooooooool0o`0000?ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`1Rooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0Joooool01Ol00?ooooooooooooooool0o`0000?ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1Sooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0K?ooool0
1?l00?ooooooooooo`3o0003ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Hooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo06cooooo00Co003oooooooooool0o`000ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo06?ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1/ooooo`04o`00oooooooooooo0?l000?ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00_ooooo00Go003ooooooooooooooooo
o`00o`1Uooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0K?ooool01?l00?oooooooooo
o`3o0003ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0;ooooo`05o`00ooooooooooooooooool00?l0IOooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo06cooooo00Co003oooooooooool0o`000_ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool01Ol00?oooooooooooooooooo003o
06Gooooo0Ol00001ooooo`006oooool2o`0006gooooo00Co003oooooooooool0o`000_ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool02oooool01Ol0
0?oooooooooooooooooo003o06Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1/oooo
o`04o`00oooooooooooo0?l000;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00_ooooo00Go003oooooooooooooooooo`00o`1Uooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0K?ooool01?l00?ooooooooooo`3o0002ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`04o`00oooo
ooooooooo`00ofKooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1/ooooo`04o`00oooo
oooooooo0?l000;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00cooooo00Co003ooooooooooooo003oI_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo06cooooo00Co003oooooooooool0o`000_ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03?ooool01?l00?ooooooooooool00?mVoooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0KOooool00ol00?oooooo0?l00002ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0<ooooo`04
o`00ooooooooooooo`00ofKooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0KOooool00ol00?oooooo0?l00002ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooo003o06Kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1]ooooo`03o`00ooooool0o`00
00;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00gooooo00?o003oooooool00?l0I_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooooooool00_ooool2o`0006kooooo00?o003oooooo`3o00000_ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03Oooool2o`00
ofKooooo0_l00001ooooo`001oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0KOooool00ol00?oooooo0?l00002ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
06Gooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0
003oooooooooo`1]ooooo`03o`00ooooool0o`0000;ooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo07Kooooo0Ol00001ooooo`001oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0KOooool00ol0
0?oooooo0?l00002ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`1fooooo`7o00000Oooool000Sooooo0_l00008ooooo`Go00001?ooool00ol0003o
ooooooooo`1]ooooo`03o`00ooooool0o`0000;ooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo07Kooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1]ooooo`03o`00ooooool0o`0000;ooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo07Kooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1]ooooo`03o`00ooooool0o`0000;ooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo07Kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1]
ooooo`05o`00ooooool0o`00ooooool00?l03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo07Kooooo0Ol00001ooooo`006oooool2o`0006kooooo00Go003oooooo`3o003oooooo`00
o`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0MOooool2o`00007ooooo000K
ooooo`03o`000?oooooooooo06gooooo00Go003oooooo`3o003oooooo`00o`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0M_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo06gooooo00Go003oooooo`3o003oooooo`00o`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool0M_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06gooooo00Go003o
ooooo`3o003oooooo`00o`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Mooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo06gooooo00Go003oooooo`3o003oooooo`00
o`0?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Moooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo06gooooo00Go003oooooo`3o003oooooo`00o`0?ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool0Moooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo06kooooo00Co003o0?l00?oooooo003o3oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo07Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1^ooooo`04o`00o`3o003o
ooooo`00o`oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`1gooooo`7o00000Ooo
ool001_ooooo0_l0001_ooooo`04o`00o`3o003oooooo`00o`oooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`1fooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0K_ooool0
1?l00?l0o`00ooooool00?l?ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0Mooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo06kooooo00Co003o0?l00?oooooo003o3ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo07Oooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1^ooooo`03o`00o`3o003o003o017ooooo00Go003oooooooooooooooooo`00
o`1iooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Koooool2o`00oa7ooooo00Go003o
ooooooooooooooooo`00o`1iooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0K_ooool0
0ooo003o003oo`00o`0Aooooo`04o`00ooooooooooooo`00og[ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1^ooooo`03ool00?l00?oo003o017ooooo00Co003ooooooooooooo003oN_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo06kooooo0ooo000Aooooo`04o`00oooooooo
ooooo`00og[ooooo0Ol00001ooooo`006oooool2o`0008?ooooo00Co003ooooooooooooo003oNOoo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo08;ooooo00Co003ooooooooooooo003oN_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo08;ooooo00Co003ooooooooooooo003oN_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo08;ooooo00Co003ooooooooooooo003oN_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo08;ooooo00Co003ooooooooooooo003oN_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo08;ooooo00Co003ooooooooooooo003oN_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo08;ooooo00Co003ooooooooooooo003oN_oo
ool1o`00007ooooo000Kooooo`;o0000Poooool01?l00?ooooooooooool00?miooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool0Poooool00ol00?ooooooo`00o`1jooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0Poooool00ol00?ooooooo`00o`1jooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0Poooool00ol00?ooooooo`00o`1jooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0Poooool00ol00?ooooooo`00o`1jooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0Poooool2o`00og_ooooo0Ol00001ooooo`004oooool3o`0000Gooooo00?o0000
ooooooooool0Poooool2o`00og_ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo0Oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Co
oooo0_l00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool2o`00007o
oooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`005?ooool00ol0003ooooooooo
o`04oooooooo00001Ol00001ooooo`004oooool2o`000?oooooo3?ooool001Cooooo00?o0000oooo
ooooool0ooooool:ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.08154, -1.18618, \
0.032354, 0.012731}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuous-time signal #2", "Subsection"],

Cell[BoxData[{
    \(\(Pulse1[t_] := 
        UnitStep[t]\  - \ UnitStep[t - 1/2]\  - \ 
          1/2;\)\), "\[IndentingNewLine]", 
    \(\(fnc1 = PeriodicSignal[Pulse1, {0, 1}, {t, 0, 4}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g1 = 
        Plot[fnc1, {t, 0, 4}, \ PlotStyle \[Rule] {Blue}, 
          PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.309017 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07358 -24 -4.5 ]
[-0.0125 .07358 0 4.5 ]
[-0.0125 .1913 -24 -4.5 ]
[-0.0125 .1913 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .42674 -18 -4.5 ]
[-0.0125 .42674 0 4.5 ]
[-0.0125 .54446 -18 -4.5 ]
[-0.0125 .54446 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07358 m
.00625 .07358 L
s
[(-0.4)] -0.0125 .07358 1 0 Mshowa
0 .1913 m
.00625 .1913 L
s
[(-0.2)] -0.0125 .1913 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .42674 m
.00625 .42674 L
s
[(0.2)] -0.0125 .42674 1 0 Mshowa
0 .54446 m
.00625 .54446 L
s
[(0.4)] -0.0125 .54446 1 0 Mshowa
.125 Mabswid
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .16187 m
.00375 .16187 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .45617 m
.00375 .45617 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .04415 m
.00375 .04415 L
s
0 .01472 m
.00375 .01472 L
s
0 .57389 m
.00375 .57389 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07358 m
1 .07358 L
s
.99375 .1913 m
1 .1913 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .42674 m
1 .42674 L
s
.99375 .54446 m
1 .54446 L
s
.125 Mabswid
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .04415 m
1 .04415 L
s
.99625 .01472 m
1 .01472 L
s
.99625 .57389 m
1 .57389 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .60332 L
.08255 .60332 L
.10458 .60332 L
.11448 .60332 L
.12507 .60332 L
.1302 .60332 L
.13506 .60332 L
.13942 .60332 L
.14061 .60332 L
.14188 .60332 L
.14296 .01472 L
.14415 .01472 L
.18444 .01472 L
.22321 .01472 L
.23332 .01472 L
.24435 .01472 L
.24939 .01472 L
.25476 .01472 L
.25738 .01472 L
.25866 .01472 L
.25984 .01472 L
.26091 .01472 L
.26205 .60332 L
.26318 .60332 L
.26444 .60332 L
.30486 .60332 L
.34377 .60332 L
.35394 .60332 L
.36501 .60332 L
.37008 .60332 L
.37546 .60332 L
.37767 .60332 L
.37883 .60332 L
.38006 .60332 L
.38071 .60332 L
.38142 .01472 L
.38267 .01472 L
.38513 .01472 L
.42569 .01472 L
.46474 .01472 L
.47498 .01472 L
.48608 .01472 L
.49117 .01472 L
.49396 .01472 L
.49657 .01472 L
.4977 .01472 L
.49879 .01472 L
.50003 .60332 L
.50117 .60332 L
Mistroke
.50623 .60332 L
.54448 .60332 L
.56584 .60332 L
.58518 .60332 L
.59488 .60332 L
.60536 .60332 L
.61018 .60332 L
.61281 .60332 L
.61526 .60332 L
.61736 .60332 L
.61853 .60332 L
.6196 .01472 L
.62077 .01472 L
.62205 .01472 L
.62436 .01472 L
.66519 .01472 L
.68548 .01472 L
.70451 .01472 L
.72272 .01472 L
.7277 .01472 L
.73295 .01472 L
.73511 .01472 L
.7363 .01472 L
.73742 .01472 L
.73806 .01472 L
.73875 .60332 L
.73996 .60332 L
.74231 .60332 L
.78328 .60332 L
.80368 .60332 L
.82274 .60332 L
.84104 .60332 L
.84631 .60332 L
.85131 .60332 L
.85348 .60332 L
.8558 .60332 L
.857 .60332 L
.85769 .01472 L
.85833 .01472 L
.86068 .01472 L
.89933 .01472 L
.94044 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0003_ooooo0ol0000jooooo`Go0000
>Oooool3o`0003cooooo0ol00006ooooo`007oooool01?l0003oooooooooool0000kooooo`03o`00
0?oooooooooo03[ooooo00Co0000oooooooooooo0000>?ooool01Ol0003ooooooooooooooooo0000
03cooooo00?o0000ooooooooool01Oooool001oooooo00Co0000oooooooooooo0000>oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=oooool5o`00
00Kooooo000Oooooo`04o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0iooooo`;o0000>_ooool01?l0003oooooooooool00007ooooo`007oooool01?l0
003oooooooooool0000kooooo`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00
000looooo`03o`000?oooooooooo03Sooooo00?o0000ooooool000001oooool001oooooo00Co0000
oooooooooooo0000>_ooool2o`0003_ooooo00Go0000ooooooooooooooooo`00000hooooo`05o`00
0?ooooooooooooooool00000>oooool2o`0000Oooooo000Pooooo`;o0000??ooool00ol0003ooooo
ooooo`0jooooo`?o0000>_ooool3o`0003gooooo00?o0000ooooooooool01Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool001_ooooo00<00000o`000?l00000
ool00001o`00004000000Oooool001_ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool10000007ooooo000K
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0>oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03
ooooo`4000000Oooool001_ooooo00<00000ooooooooool0ooooool1ooooo`4000000Oooool001_o
oooo00<00000o`000?ooool08_oooolOo`00oaoooooo7ol00?lOooooo`03o`00o`000?l0003o01T0
003o0_l00?l00`000?ooooooooooo`0Looooo`03o`00o`000?l0003o01d0003o1?ooool1o`000040
00000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo01gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000
oooooooooooo01_ooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`0Rooooo`400000
0Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo01gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooo
oooooooo01_ooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo01gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooo
oooo01_ooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool0
01_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
01gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo
01_ooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_o
oooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_o
oooo00<0003oooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo
00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo
00<0003oooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<0
0000o`000?ooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0
003oooooooooool07?ooool00`000?ooooooooooo`0Qooooo`7o00000@000001ooooo`006oooool0
0`00003oooooooooo`0Rooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00<0003oooooooooool06oooool0
0`000?ooooooooooo`0Looooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00
003oooooooooo`0Rooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00<0003oooooooooool06oooool00`00
0?ooooooooooo`0Looooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0Rooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?oo
ooooooooo`0Looooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0Rooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?oooooo
ooooo`0Kooooo`03o`00oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?oooooo
ooooo`0Looooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0Rooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?oooooooooo
o`0Looooo`030000oooooooooooo02;ooooo0@000001ooooo`002?ooool2o`0000Cooooo00?o0000
ooooooooool00oooool3o`0000Cooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0K
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0M
ooooo`030000oooooooooooo01_ooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`0R
ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03
ooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0K
ooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo0005o`00
00;ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo00<00000o`000?ooool08_ooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool07?ooool0
0`000?ooooooooooo`0Qooooo`7o00000@000001ooooo`001oooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool08_ooool00ol00?oooooooooo
o`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool07?ooool00`000?oooooooooo
o`0Rooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
0005ooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?oooooooooo
o`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo0007
ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`0300000?oooooooooo02;ooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0
003oooooooooool08_ooool10000007ooooo0008ooooo`;o00002oooool00ol0003oooooooooo`03
ooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0K
ooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo000Koooo
o`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0Koooo
o`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`03
00000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`03
0000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`030000
0?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000
oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?l0
003ooooo02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooo
oooooooo01cooooo00<0003oooooooooool08Oooool1o`00004000000Oooool001_ooooo00<00000
ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003o
ooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000oooo
ooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003ooooo
ooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000oooooooo
ool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003ooooooooo
ool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool0
8_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool0
7?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool08_oo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool07?oo
ool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool07?ooool0
0`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000o`000?ooool08_ooool00ol0
0?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool07?ooool00`00
0?ooooooooooo`0Qooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`03
0000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000
oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooo
oooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooooooo
oooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo
02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo01_o
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01go
oooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo02;o
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo
00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo02;ooooo
0@000001ooooo`006oooool00`00003o0000ooooo`0Rooooo`03o`00oooooooooooo01_ooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00<0
003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo027ooooo0Ol0
00010000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool0
0`000?ooooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`00
0?ooooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000
007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?oo
ooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007o
oooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?oooooo
ooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo
0008ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00<00000ooooooooool0
8_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool0
7?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool000Oooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo02;ooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003ooooooooo
ool07Oooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003ooooooooo
ool08_ooool10000007ooooo0005o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`04ooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?oo
ooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007o
oooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00`00003o
0000ooooo`0Rooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?oo
ooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?oo
ooooooooo`0Looooo`030000oooooooooooo027ooooo0Ol000010000007ooooo0007ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooooooo
02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo
01cooooo00<0003oooooooooool08_ooool10000007ooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooooooo02;ooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003o
ooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003o
ooooooooool08_ooool10000007ooooo0008ooooo`;o00002Oooool3o`0000Gooooo00<00000oooo
ooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003ooooo
ooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000oooooooo
ool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003ooooooooo
ool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool0
8_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool0
6oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool0
7?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool08_oo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool07?oo
ool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000o`000?ooool08_ooool0
0ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool07?ooool0
0`000?ooooooooooo`0Qooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Roooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Koooo
o`03o`00oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Loooo
o`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03
o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03
o`00oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`03
0000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00
oooooooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00
oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000
oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooo
oooooooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooo
oooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooo
oooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooo
oooo01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooo
oooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooooooo
oooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo
01_ooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo
01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo
02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo01_o
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01go
oooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo02;o
oooo0@000001ooooo`006oooool00`00003o0000ooooo`0Rooooo`03o`00oooooooooooo01_ooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo
00<0003oooooooooool06oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo027ooooo
0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06ooo
ool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Ooo
ool00`000?ooooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool0
0ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool0
0`000?ooooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`00
0?ooooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000
007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?oo
ooooooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?oo
ooooooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007o
oooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?oooooo
ooooo`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?oooooo
ooooo`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo
000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?oooooooooo
o`0Mooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?oooooooooo
o`0Kooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo000K
ooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0K
ooooo`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo000Koooo
o`0300000?l0003ooooo02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0Koooo
o`030000oooooooooooo01cooooo00<0003oooooooooool08Oooool1o`00004000000Oooool001_o
oooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_o
oooo00<0003oooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo
00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo
00<0003oooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<0
0000ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o
003oooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0
003oooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000
ooooooooool08_ooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo01gooooo00?o003o
ooooooooool06oooool00ol00?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003o
ooooooooool07?ooool00`000?ooooooooooo`0Rooooo`4000000Oooool001Cooooo0_l00005oooo
o`0300000?oooooooooo02;ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo01_ooooo00?o003oooooooooool07Oooool00`000?ooooooooooo`0Koooo
o`030000oooooooooooo01cooooo00<0003oooooooooool08_ooool10000007ooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Koooo
o`03o`00oooooooooooo01gooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Moooo
o`030000oooooooooooo01_ooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`0Roooo
o`4000000Oooool001?ooooo00Co0000oooooooooooo00001?oooolU00000003o`00o`0000000000
01/0000000?o003o0000000000007@0000000ol00?l000000000000K00000003o`00o`0000000000
01d0000000<0003o0000000000006`0000000`000?l000000000000L000000030000o`0000000000
02<000000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Roooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Koooo
o`030000oooooooooooo02;ooooo0@000001ooooo`004oooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`000?ooooooooooo`0Moooo
o`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool10000007ooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Koooo
o`030000oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Roooo
o`4000000Oooool001Cooooo0_l00005ooooo`0300000?oooooooooo02;ooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool06oooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003ooooooooo
ool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
6oooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool0
8_ooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06ooo
ool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool0
0`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool1
0000007ooooo000Kooooo`0300000?l0003ooooo02;ooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`00
0?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08Oooool1o`00
004000000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`03
0000oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`40
00000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000
oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`400000
0Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooo
oooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooo
oooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool0
01_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo
01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_o
oooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01go
oooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo
00<00000o`000?ooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo
00<0003oooooooooool06oooool00`000?ooooooooooo`0Qooooo`7o00000@000001ooooo`006ooo
ool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Ooo
ool00`000?ooooooooooo`0Kooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool0
0`000?ooooooooooo`0Kooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00
003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`00
0?ooooooooooo`0Kooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?oo
ooooooooo`0Kooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?oooooo
ooooo`0Kooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?oooooooooo
o`0Kooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0R
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0K
ooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Roooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Koooo
o`030000oooooooooooo027ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02;o
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool06oooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_o
oooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool06oooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo
00<0003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool06oooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0
003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool06oooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003o
ooooooooool08_ooool10000007ooooo0008ooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000Cooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooo
oooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool06oooool00`000?ooooooooooo`0Mooooo`030000oooo
oooooooo01_ooooo00<0003oooooooooool08_ooool10000007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0Rooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooo
oooooooo02;ooooo0@000001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo00?ooooo00<00000o`000?ooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooo
oooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Qooooo`7o00000@00
0001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1?ooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool0
7Oooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo02;ooooo0@000001ooooo`001ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00`00003o
ooooooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?oo
ooooooooo`0Kooooo`030000oooooooooooo02;ooooo0@000001ooooo`002?ooool2o`0000Wooooo
0ol00005ooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`000?oooooo
ooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool10000007ooooo
000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`000?oooooooooo
o`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool10000007ooooo000K
ooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`000?ooooooooooo`0M
ooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool10000007ooooo000Koooo
o`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`000?ooooooooooo`0Moooo
o`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`03
00000?l0003ooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`000?ooooooooooo`0Mooooo`03
0000oooooooooooo01_ooooo00<0003oooooooooool08Oooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo
00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<0
0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo00<0
003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000
ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo00<0003o
ooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000oooo
ooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo00<0003ooooo
ooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000oooooooo
ool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo00<0003ooooooooo
ool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool0
8_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo00<0003oooooooooool0
6oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool08_oo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo00<0003oooooooooool06ooo
ool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000o`000?ooool08_ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo00<0003oooooooooool06oooool0
0`000?ooooooooooo`0Qooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Roooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Koooo
o`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`03
0000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000
oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooo
oooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooooooo
oooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01_ooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo
02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_o
oooo00<0003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo02;o
oooo0@000001ooooo`006oooool00`00003o0000ooooo`0Rooooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01_ooooo
00<0003oooooooooool07Oooool00`000?ooooooooooo`0Kooooo`030000oooooooooooo027ooooo
0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06ooo
ool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool0
0`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`00
0?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool10000
007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`000?oo
ooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool10000007o
oooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00`00003ooooo
ooooo`0Rooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01_ooooo00<0003oooooooooool07Oooool00`000?oooooo
ooooo`0Kooooo`030000oooooooooooo02;ooooo0@000001ooooo`001oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool08_ooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`0Kooooo`030000oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?oooooo
ooooo`0Rooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo
00<00000o`000?ooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo
00<0003oooooooooool06oooool00`000?ooooooooooo`0Qooooo`7o00000@000001ooooo`001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo00<00000oooooooo
ool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo00<0003ooooooooo
ool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool000Oooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000005ooooo`0300000?oooooooooo02;ooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool06oooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003ooooooooo
ool08_ooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03
00000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`000?ooooooooooo`0Mooooo`03
0000oooooooooooo01_ooooo00<0003oooooooooool08_ooool10000007ooooo0008ooooo`;o0000
2oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
6oooool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool0
8_ooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06ooo
ool00`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool0
0`000?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`00
0?ooooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08_ooool10000
007ooooo000Kooooo`0300000?l0003ooooo02;ooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o003oooooooooool06oooool00`000?oo
ooooooooo`0Mooooo`030000oooooooooooo01_ooooo00<0003oooooooooool08Oooool1o`000040
00000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000
oooooooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`400000
0Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooo
oooooooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooo
oooo01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool0
01_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo
01gooooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_o
oooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01go
oooo00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo
00<00000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo
00<0003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<0
0000ooooooooool08_ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`0Kooooo`030000oooooooooooo01gooooo00<0
003oooooooooool06oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000
o`000?ooool00ooooolPo`00oakooooo8?l00?lNooooo`03o`00o`000?l0003o01P0003o0ol00?l0
0`000?ooooooooooo`0MoooooaX0003o00Go003o0000o`000?oo003o0000o`0Sooooo`7o00000@00
0001ooooo`006oooool00`00003oooooooooo`3oooooo`7ooooo0@000001ooooo`006oooool00`00
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`03ooooo`4000000Oooool001_oooooo`0000050000007ooooo003oooooob7ooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.540771, -0.618986, \
0.0161771, 0.00654375}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sample signal (continuous-time to discrete-time conversion)", \
"Subsection"],

Cell["\<\
Adjust sampling rate below (in Hz) to see different sampling \
results.\
\>", "Text"],

Cell[BoxData[
    \(\(sampleRate = 6;\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sampled\  = 
        Table[{ti, fnc1\  /. \ t \[Rule] ti}, {ti, 0, 4, 
            1/sampleRate}];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        DiscreteListPlot[sampled, Red, PlotRange \[Rule] All, \ 
          Frame \[Rule] True, \ 
          Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(Show[g2, g1];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.309017 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07358 -24 -4.5 ]
[-0.0125 .07358 0 4.5 ]
[-0.0125 .1913 -24 -4.5 ]
[-0.0125 .1913 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .42674 -18 -4.5 ]
[-0.0125 .42674 0 4.5 ]
[-0.0125 .54446 -18 -4.5 ]
[-0.0125 .54446 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07358 m
.00625 .07358 L
s
[(-0.4)] -0.0125 .07358 1 0 Mshowa
0 .1913 m
.00625 .1913 L
s
[(-0.2)] -0.0125 .1913 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .42674 m
.00625 .42674 L
s
[(0.2)] -0.0125 .42674 1 0 Mshowa
0 .54446 m
.00625 .54446 L
s
[(0.4)] -0.0125 .54446 1 0 Mshowa
.125 Mabswid
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .16187 m
.00375 .16187 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .45617 m
.00375 .45617 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .04415 m
.00375 .04415 L
s
0 .01472 m
.00375 .01472 L
s
0 .57389 m
.00375 .57389 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07358 m
1 .07358 L
s
.99375 .1913 m
1 .1913 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .42674 m
1 .42674 L
s
.99375 .54446 m
1 .54446 L
s
.125 Mabswid
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .04415 m
1 .04415 L
s
.99625 .01472 m
1 .01472 L
s
.99625 .57389 m
1 .57389 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .60332 L
s
.06349 .30902 m
.06349 .60332 L
s
.10317 .30902 m
.10317 .60332 L
s
.14286 .30902 m
.14286 .01472 L
s
.18254 .30902 m
.18254 .01472 L
s
.22222 .30902 m
.22222 .01472 L
s
.2619 .30902 m
.2619 .60332 L
s
.30159 .30902 m
.30159 .60332 L
s
.34127 .30902 m
.34127 .60332 L
s
.38095 .30902 m
.38095 .01472 L
s
.42063 .30902 m
.42063 .01472 L
s
.46032 .30902 m
.46032 .01472 L
s
.5 .30902 m
.5 .60332 L
s
.53968 .30902 m
.53968 .60332 L
s
.57937 .30902 m
.57937 .60332 L
s
.61905 .30902 m
.61905 .01472 L
s
.65873 .30902 m
.65873 .01472 L
s
.69841 .30902 m
.69841 .01472 L
s
.7381 .30902 m
.7381 .60332 L
s
.77778 .30902 m
.77778 .60332 L
s
.81746 .30902 m
.81746 .60332 L
s
.85714 .30902 m
.85714 .01472 L
s
.89683 .30902 m
.89683 .01472 L
s
.93651 .30902 m
.93651 .01472 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .60332 Mdot
.06349 .60332 Mdot
.10317 .60332 Mdot
.14286 .01472 Mdot
.18254 .01472 Mdot
.22222 .01472 Mdot
.2619 .60332 Mdot
.30159 .60332 Mdot
.34127 .60332 Mdot
.38095 .01472 Mdot
.42063 .01472 Mdot
.46032 .01472 Mdot
.5 .60332 Mdot
.53968 .60332 Mdot
.57937 .60332 Mdot
.61905 .01472 Mdot
.65873 .01472 Mdot
.69841 .01472 Mdot
.7381 .60332 Mdot
.77778 .60332 Mdot
.81746 .60332 Mdot
.85714 .01472 Mdot
.89683 .01472 Mdot
.93651 .01472 Mdot
.97619 .30902 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0003_ooooo0ol0000jooooo`Go0000
>Oooool3o`0003cooooo0ol00006ooooo`007oooool01?l0003oooooooooool0000kooooo`03o`00
0?oooooooooo03[ooooo00Co0000oooooooooooo0000>?ooool01Ol0003ooooooooooooooooo0000
03cooooo00?o0000ooooooooool01Oooool001oooooo00Co0000oooooooooooo0000>oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=oooool5o`00
00Kooooo000Oooooo`04o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0iooooo`;o0000>_ooool01?l0003oooooooooool00007ooooo`007oooool01?l0
003oooooooooool0000kooooo`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00
000looooo`03o`000?oooooooooo03Sooooo00?o0000ooooool000001oooool001oooooo00Co0000
oooooooooooo0000>_ooool2o`0003_ooooo00Go0000ooooooooooooooooo`00000hooooo`05o`00
0?ooooooooooooooool00000>oooool2o`0000Oooooo000Pooooo`;o0000??ooool00ol0003ooooo
ooooo`0jooooo`?o0000>_ooool3o`0003gooooo00?o0000ooooooooool01Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool001_ooooo00<00000o`000?l00000
ool00001o`00004000000Oooool001_ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool10000007ooooo000K
ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0>oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03
ooooo`4000000Oooool001_ooooo00<00000ooooooooool08?ooool3ool000Sooooo0ooo0007oooo
o`?oo`009_ooool3ool000Sooooo0ooo0007ooooo`?oo`009_ooool3ool000Oooooo0ooo0008oooo
o`?oo`009_ooool3ool000Oooooo0ooo0007ooooo`?oo`003oooool10000007ooooo000Kooooo`03
00000?l0003ooooo023ooooo0ooo0008ooooo`?oo`001oooool3ool002Kooooo0ooo0008ooooo`?o
o`001oooool3ool002Kooooo0ooo0007ooooo`?oo`002?ooool3ool002Kooooo0ooo0007ooooo`?o
o`001oooool3ool000kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo023ooooo
0ooo0008ooooo`?oo`001oooool3ool002Kooooo0ooo0008ooooo`?oo`001oooool3ool002Kooooo
0ooo0007ooooo`?oo`002?ooool3ool002Kooooo0ooo0007ooooo`?oo`001oooool3ool000oooooo
0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000
ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001oooo
o`006oooool00`00003oooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000ooooooooool0
8_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
3Oooool10000007ooooo000Kooooo`0300000?l0003ooooo02;ooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00cooooo0Ol000010000007ooooo000K
ooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Roooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Woooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=oooo
o`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`030000
0?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oo
oooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oo
oooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Ooo
ool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`0300000?oooooo
oooo02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00gooooo0@000001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00?ooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo0005o`0000;ooooo00Co0000oooo
oooooooo00001oooool5o`0000Cooooo00<00000o`000?ooool08_ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03?ooool1o`00004000000Oooool0
00Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00005ooooo`0300000?oo
oooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00gooooo0@000001ooooo`001oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Gooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Wooooo0_l00005ooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`002?ooool2
o`0000_ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`0Rooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooo
oooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooo
oooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;o
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Ko
oooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Ko
oooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00go
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<0
0000o`000?ooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool03?ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool08_ooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool0
0`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool0
0`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool1
0000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003ooooo
ooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003ooooo
ooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo
000Kooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0R
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0W
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0V
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0V
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=
ooooo`4000000Oooool001_ooooo00<00000o`000?ooool08_ooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03?ooool1o`00004000000Oooool001_o
oooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo
00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo
00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo
0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000
ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001oooo
o`006oooool00`00003oooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000ooooooooool0
8_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
3Oooool10000007ooooo000Kooooo`0300000?l0003ooooo02;ooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00cooooo0Ol000010000007ooooo000K
ooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Roooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Woooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=oooo
o`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`030000
0?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00gooooo0@000001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo
1Ol00004ooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool08_ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003o
ooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003o
ooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007o
oooo0005o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03
00000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00gooooo0@000001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00?ooooo00<00000o`000?ooool08_ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool03?ooool1o`00004000000Oooool000Oooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00<00000oooo
ooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool03Oooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`002?ooool2o`00
00Wooooo0ol00005ooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003ooooo
ooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003ooooo
ooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo
000Kooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003o0000ooooo`0R
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0W
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0V
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0V
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0<
ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo
00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo
00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_o
oooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo
00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo
00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo
0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000
ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001oooo
o`006oooool00`00003oooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000o`000?ooool0
8_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
3?ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool08_ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003ooooooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003ooooooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000K
ooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Roooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Woooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=oooo
o`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`030000
0?oooooooooo02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oo
oooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oo
oooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?l0003ooooo
02;ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00cooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooooooo
ool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooooooo
ool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0Rooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_oo
ool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_oo
ool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Ooo
ool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`005?ooool2o`00
00Gooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo1P0000000`3o0000000000000007000000030?l000000000000000P0000000<0o`000000
000000001`0000000`3o0000000000000007000000030?l000000000000000L0000000<0o`000000
00000000200000000`3o0000000000000007000000030?l000000000000000L0000000<0o`000000
00000000200000000`3o0000000000000007000000030?l000000000000000L0000000<0o`000000
00000000200000000`3o0000000000000007000000030?l000000000000000L0000000<0o`000000
000000001`0000000`3o0000000000000008000000030?l000000000000000L0000000<0o`000000
000000001`0000000`3o0000000000000008000000030?l000000000000000L0000000<0o`000000
000000001`0000000`3o0000000000000008000000030?l000000000000000L0000000<0o`000000
000000001P000003ool000D000000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0Uooooo`?oo`001?ooool10000007ooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Sooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool09Oooool3ool000Cooooo0@000001ooooo`004oooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`005?ooool2o`0000Go
oooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00So
oooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool0;?ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo
00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo
0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0/ooooo`4000000Oooool001_ooooo00<00000
ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool0;?ooool10000007ooooo000Kooooo`0300000?l0003ooooo00?ooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02_ooooo0Ol000010000
007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003ooooo
ooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`0/ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003ooooooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000007ooooo000K
ooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`006oooool00`00003oooooooooo`03oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Woooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/oooo
o`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000007ooooo000Kooooo`030000
0?l0003ooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02_ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0
o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@00
0001ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`0/ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00oooo
ooooool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool0;?ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooooooo
ool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`00
6oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
2?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0/ooooo`4000000Oooool001_ooooo00<00000ooooooooool00ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_oo
ool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?oo
ool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`006oooool00`00
003o0000ooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0[ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`03ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`03
0?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/ooooo`40
00000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000007ooooo000Kooooo`0300000?oo
oooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oo
oooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo02cooooo0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooo
oooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/ooooo`4000000Oooool0
00Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00`00003oooooooooo`03
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0V
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0W
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0V
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/
ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`001oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool00oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003ooooooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000007ooooo0007
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00`00003o0000oooo
o`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003ooooooooo
o`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`0[ooooo`7o00000@000001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/ooooo`4000000Oooool000Oooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00<00000oooooooo
ool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00oooooooo
ool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool0;?ooool10000007ooooo0008ooooo`;o00002Oooool3o`0000Gooooo00<00000ooooooooool0
0oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool0
9_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
9_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
;?ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`006oooool0
0`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool0
0`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`0/ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o
003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000
007ooooo000Kooooo`0300000?l0003ooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo02_ooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02cooooo0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oo
oooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/ooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool0;?ooool10000007ooooo000Kooooo`0300000?oooooooooo
00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo
02Kooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
02cooooo0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00So
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/ooooo`4000000Oooool001_ooooo
00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo
00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool0;?ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0
o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@00
0001ooooo`006oooool00`00003o0000ooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`0[ooooo`7o00000@000001ooooo`006oooool00`00
003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0/ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003o
ooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000007o
oooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`006oooool00`00003ooooooooo
o`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003ooooooooo
o`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`0/ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000007ooooo000Koooo
o`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08oooo
o`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo02cooooo0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`03
0?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/ooooo`40
00000Oooool001_ooooo00<00000o`000?ooool00oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool0:oooool1o`00004000000Oooool001_ooooo00<0
0000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool0;?ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00
ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@000001
ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`0/ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00oooooooo
ool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool0;?ooool10000007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o0000
1?ooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
2?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`0/ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool0
2?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`001ooo
ool01?l0003oooooooooool00007ooooo`Go00001?ooool00`00003o0000ooooo`03ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l0
0?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0[ooooo`7o0000
0@000001ooooo`001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Go
oooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00So
oooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool0;?ooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000001Oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00So
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/ooooo`4000000Oooool000Oooooo
00Co0000oooooooooooo00002Oooool2o`0000Gooooo00<00000ooooooooool00oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003o
ooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000007o
oooo0008ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo
00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo
0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`0/ooooo`4000000Oooool001_ooooo00<00000
ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool09_ooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool0;?ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02Kooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo02cooooo0@000001oooo
o`006oooool00`00003o0000ooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool02?ooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0[ooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003ooooo
ooooo`0Vooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`0Wooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`0Vooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`0/ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003ooooooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000007ooooo000K
ooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo02cooooo0@000001ooooo`006oooool00`00003oooooooooo`03oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Woooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0Voooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0/oooo
o`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Sooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool09_ooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool0;?ooool10000007ooooo000Kooooo`030000
0?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02Kooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo02cooooo0@000001ooooo`006oooool01000003oooooooooooooool3ool000Sooooo
0ooo0007ooooo`?oo`009_ooool3ool000Sooooo0ooo0007ooooo`?oo`009_ooool3ool000Oooooo
0ooo0008ooooo`?oo`009_ooool3ool000Oooooo0ooo0008ooooo`?oo`00;Oooool10000007ooooo
000Kooooo`0400000?l0003oooooooooo`?oo`002?ooool3ool000Oooooo0ooo000Vooooo`?oo`00
2?ooool3ool000Oooooo0ooo000Vooooo`?oo`001oooool3ool000Sooooo0ooo000Vooooo`?oo`00
1oooool3ool000Sooooo0ooo000/ooooo`7o00000@000001ooooo`006oooool01000003ooooooooo
ooooool3ool000Sooooo0ooo0007ooooo`?oo`009_ooool3ool000Sooooo0ooo0007ooooo`?oo`00
9_ooool3ool000Oooooo0ooo0008ooooo`?oo`009_ooool3ool000Oooooo0ooo0008ooooo`?oo`00
;Oooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0@000001ooooo`006ooooooo
000000D000000Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.540771, -0.618986, \
0.0161771, 0.00654375}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.309017 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07358 -24 -4.5 ]
[-0.0125 .07358 0 4.5 ]
[-0.0125 .1913 -24 -4.5 ]
[-0.0125 .1913 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .42674 -18 -4.5 ]
[-0.0125 .42674 0 4.5 ]
[-0.0125 .54446 -18 -4.5 ]
[-0.0125 .54446 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07358 m
.00625 .07358 L
s
[(-0.4)] -0.0125 .07358 1 0 Mshowa
0 .1913 m
.00625 .1913 L
s
[(-0.2)] -0.0125 .1913 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .42674 m
.00625 .42674 L
s
[(0.2)] -0.0125 .42674 1 0 Mshowa
0 .54446 m
.00625 .54446 L
s
[(0.4)] -0.0125 .54446 1 0 Mshowa
.125 Mabswid
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .16187 m
.00375 .16187 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .45617 m
.00375 .45617 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .04415 m
.00375 .04415 L
s
0 .01472 m
.00375 .01472 L
s
0 .57389 m
.00375 .57389 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07358 m
1 .07358 L
s
.99375 .1913 m
1 .1913 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .42674 m
1 .42674 L
s
.99375 .54446 m
1 .54446 L
s
.125 Mabswid
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .04415 m
1 .04415 L
s
.99625 .01472 m
1 .01472 L
s
.99625 .57389 m
1 .57389 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
1 0 0 r
.5 Mabswid
.02381 .30902 m
.02381 .60332 L
s
.06349 .30902 m
.06349 .60332 L
s
.10317 .30902 m
.10317 .60332 L
s
.14286 .30902 m
.14286 .01472 L
s
.18254 .30902 m
.18254 .01472 L
s
.22222 .30902 m
.22222 .01472 L
s
.2619 .30902 m
.2619 .60332 L
s
.30159 .30902 m
.30159 .60332 L
s
.34127 .30902 m
.34127 .60332 L
s
.38095 .30902 m
.38095 .01472 L
s
.42063 .30902 m
.42063 .01472 L
s
.46032 .30902 m
.46032 .01472 L
s
.5 .30902 m
.5 .60332 L
s
.53968 .30902 m
.53968 .60332 L
s
.57937 .30902 m
.57937 .60332 L
s
.61905 .30902 m
.61905 .01472 L
s
.65873 .30902 m
.65873 .01472 L
s
.69841 .30902 m
.69841 .01472 L
s
.7381 .30902 m
.7381 .60332 L
s
.77778 .30902 m
.77778 .60332 L
s
.81746 .30902 m
.81746 .60332 L
s
.85714 .30902 m
.85714 .01472 L
s
.89683 .30902 m
.89683 .01472 L
s
.93651 .30902 m
.93651 .01472 L
s
.97619 .30902 m
.97619 .30902 L
s
.015 w
.02381 .60332 Mdot
.06349 .60332 Mdot
.10317 .60332 Mdot
.14286 .01472 Mdot
.18254 .01472 Mdot
.22222 .01472 Mdot
.2619 .60332 Mdot
.30159 .60332 Mdot
.34127 .60332 Mdot
.38095 .01472 Mdot
.42063 .01472 Mdot
.46032 .01472 Mdot
.5 .60332 Mdot
.53968 .60332 Mdot
.57937 .60332 Mdot
.61905 .01472 Mdot
.65873 .01472 Mdot
.69841 .01472 Mdot
.7381 .60332 Mdot
.77778 .60332 Mdot
.81746 .60332 Mdot
.85714 .01472 Mdot
.89683 .01472 Mdot
.93651 .01472 Mdot
.97619 .30902 Mdot
0 0 1 r
.5 Mabswid
.02381 .60332 m
.06244 .60332 L
.08255 .60332 L
.10458 .60332 L
.11448 .60332 L
.12507 .60332 L
.1302 .60332 L
.13506 .60332 L
.13942 .60332 L
.14061 .60332 L
.14188 .60332 L
.14296 .01472 L
.14415 .01472 L
.18444 .01472 L
.22321 .01472 L
.23332 .01472 L
.24435 .01472 L
.24939 .01472 L
.25476 .01472 L
.25738 .01472 L
.25866 .01472 L
.25984 .01472 L
.26091 .01472 L
.26205 .60332 L
.26319 .60332 L
.26444 .60332 L
.30486 .60332 L
.34377 .60332 L
.35394 .60332 L
.36501 .60332 L
.37008 .60332 L
.37546 .60332 L
.37767 .60332 L
.37883 .60332 L
.38006 .60332 L
.38071 .60332 L
.38142 .01472 L
.38267 .01472 L
.38513 .01472 L
.42569 .01472 L
.46474 .01472 L
.47498 .01472 L
.48608 .01472 L
.49117 .01472 L
.49396 .01472 L
.49657 .01472 L
.4977 .01472 L
.49879 .01472 L
.50003 .60332 L
.50117 .60332 L
Mistroke
.50623 .60332 L
.54448 .60332 L
.56584 .60332 L
.58518 .60332 L
.59488 .60332 L
.60536 .60332 L
.61018 .60332 L
.61281 .60332 L
.61526 .60332 L
.61736 .60332 L
.61853 .60332 L
.6196 .01472 L
.62077 .01472 L
.62205 .01472 L
.62436 .01472 L
.66519 .01472 L
.68548 .01472 L
.70451 .01472 L
.72272 .01472 L
.7277 .01472 L
.73295 .01472 L
.73511 .01472 L
.7363 .01472 L
.73742 .01472 L
.73806 .01472 L
.73875 .60332 L
.73996 .60332 L
.74231 .60332 L
.78328 .60332 L
.80368 .60332 L
.82274 .60332 L
.84104 .60332 L
.84631 .60332 L
.85131 .60332 L
.85348 .60332 L
.8558 .60332 L
.857 .60332 L
.85769 .01472 L
.85833 .01472 L
.86068 .01472 L
.89933 .01472 L
.94044 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0003_ooooo0ol0000jooooo`Go0000
>Oooool3o`0003cooooo0ol00006ooooo`007oooool01?l0003oooooooooool0000kooooo`03o`00
0?oooooooooo03[ooooo00Co0000oooooooooooo0000>?ooool01Ol0003ooooooooooooooooo0000
03cooooo00?o0000ooooooooool01Oooool001oooooo00Co0000oooooooooooo0000>oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0=oooool5o`00
00Kooooo000Oooooo`04o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0iooooo`;o0000>_ooool01?l0003oooooooooool00007ooooo`007oooool01?l0
003oooooooooool0000kooooo`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00
000looooo`03o`000?oooooooooo03Sooooo00?o0000ooooool000001oooool001oooooo00Co0000
oooooooooooo0000>_ooool2o`0003_ooooo00Go0000ooooooooooooooooo`00000hooooo`05o`00
0?ooooooooooooooool00000>oooool2o`0000Oooooo000Pooooo`;o0000??ooool00ol0003ooooo
ooooo`0jooooo`?o0000>_ooool3o`0003gooooo00?o0000ooooooooool01Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool001_ooooo00<00000o`000?l00000
ool00001o`00004000000Oooool001_ooooo00<00000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool10000007ooooo000K
ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03
ooooo`4000000Oooool001_ooooo00<00000ooooooooool08?ooool3ool000Sooooo0ooo0007oooo
o`?oo`009_ooool3ool000Sooooo0ooo0007ooooo`?oo`009_ooool3ool000Oooooo0ooo0008oooo
o`?oo`009_ooool3ool000Oooooo0ooo0007ooooo`?oo`003oooool10000007ooooo000Kooooo`03
00000?l0003ooooo023ooooo0_oo000Oo`00oagooooo0_oo000Oo`00oagooooo0_oo00000ol00?l0
003o0000o`0I0000o`;o003o00<0003oooooooooool06oooool00ooo003o003o0000o`0N0000o`Co
oooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo023ooooo0_oo00000ol00?oooooo
ooooo`06ooooo`?oo`001oooool3ool000Sooooo00?o003oooooooooool06oooool2ool00003o`00
oooooooooooo00Kooooo0ooo0007ooooo`?oo`002?ooool00ol00?ooooooooooo`0Kooooo`;oo`00
00<0003oooooooooool01Oooool3ool000Sooooo0ooo0008ooooo`030000oooooooooooo01_ooooo
00?oo`000000oooo00001oooool3ool000Oooooo0ooo000?ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00<0
o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
003oooooooooool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003o
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003o
ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001
ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003ooooo
ooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00<0o`000000oooo
ool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003ooooooooo
ool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003oooooooooool0
2?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006ooo
ool00`00003o0000ooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?oo
ool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01ooo
ool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`0<ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0R
ooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0L
ooooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=
ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07oooo
o`03o`00oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`08oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`03
00000?oooooooooo02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03
0?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00
oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00
oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030000
oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`400000
0Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooo
oooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo0008ooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00001?ooool00`00003oooooooooo`0Rooooo`03o`00oooooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooo
oooo01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030000oooooooo
oooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool0
00Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`0300000?oooooo
oooo02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oo
oooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooo
oooo01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00gooooo0@000001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00004
ooooo`0300000?l0003ooooo02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0L
ooooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00cooooo0Ol000010000007ooooo0007ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Rooooo`03o`00oooo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooo
oooooooo01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030000oooo
oooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Ooo
ool000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`0300000?oo
oooooooo02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l00000
0?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooo
oooooooo01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00gooooo0@000001ooooo`001oooool01?l0003oooooooooool00009ooooo`;o00001Ooo
ool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?oo
ool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01ooo
ool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`0=ooooo`4000000Oooool000Sooooo0_l0000;ooooo`03o`000?oooooo
oooo00?ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooo
oooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo
02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo
00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo
01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01go
oooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo00So
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo
00<00000ooooooooool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo
00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0003oooooooooool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?l0003ooooo02;ooooo00?o
003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o
003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0
003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00cooooo0Ol0
00010000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool0
0ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool0
0ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003oooooooooool02?ooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00
003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o
0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`00
0?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?oo
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?oo
ooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`03o`00oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`000?oo
ooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007o
oooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?oooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?oooooo
ooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003ooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooooooo
o`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`0=ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`03o`00oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Koooo
o`0300000?l0003ooooo02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Loooo
o`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07oooo
o`030000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00cooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo02;o
oooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00So
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01co
oooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00go
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00<0
o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
003oooooooooool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003o
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003o
ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001
ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003ooooo
ooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00<0o`000000oooo
ool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003ooooooooo
ool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003oooooooooool0
2?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006ooo
ool00`00003o0000ooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?oo
ool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01ooo
ool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`0<ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0R
ooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0L
ooooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=
ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07oooo
o`03o`00oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`08oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`03
00000?oooooooooo02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03
0?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00
oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00
oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030000
oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`400000
0Oooool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00`00003ooooo
ooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003o
ooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooo
ooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`0=ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?oo
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?oo
ooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`001Ol00002ooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0Rooooo`03
o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`03
0000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`40
00000Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03
00000?l0003ooooo02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03
0?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00cooooo0Ol000010000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooooooo02;ooooo00?o003ooooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003ooooo
ooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003ooooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001oooo
o`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool0
0`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool0
0`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`0=ooooo`4000000Oooool000Sooooo0_l00009ooooo`?o00001Oooool00`00
003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o
0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`00
0?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?oo
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?oo
ooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`03o`00oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`000?oo
ooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007o
oooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?oooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?oooooo
ooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003ooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooooooo
o`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`0=ooooo`4000000Oooool001_ooooo00<00000o`000?ooool08_ooool00ol00?ooooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0M
ooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`03o`00oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03?ooool1o`00004000000Oooool0
01_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo
00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo
01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;o
oooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00So
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01co
oooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00go
oooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00<0
o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
003oooooooooool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003o
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003o
ooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003o
ooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001
ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003ooooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003ooooo
ooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00<0o`000000oooo
ool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003ooooooooo
ool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool03Oooool10000007ooooo000Kooooo`0300000?l0003ooooo02;ooooo00?o003oooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool0
7Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003oooooooooool0
2?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00cooooo0Ol000010000007ooooo
000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?oooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?oooooooooo
o`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0R
ooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0L
ooooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=
ooooo`4000000Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Moooo
o`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07oooo
o`03o`00oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`08oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`03
00000?oooooooooo02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03
0?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0000oooooooooooo01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00gooooo0@000001ooooo`006oooool00`00003oooooooooo`0Rooooo`03o`00
oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00
oooooooooooo01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030000
oooooooooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0=ooooo`400000
0Oooool001_ooooo00<00000ooooooooool08_ooool00ol00?ooooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooo
oooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`08ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool03Oooool10000007ooooo000Kooooo`0300000?oooooo
oooo02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oo
oooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooo
oooo01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00gooooo0@000001ooooo`006oooool00`00003o0000ooooo`0Rooooo`03o`00oooooooooooo
00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo
01gooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00?o003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo
00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`0<ooooo`7o00000@000001oooo
o`006oooool00`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003ooooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003ooooooooo
ool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`0=ooooo`4000000Oooool001_ooooo00<00000ooooooooool0
8_ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00ol00?ooooooooooo`0Mooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00<0o`000000ooooool0
2?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool0
7?ooool00`000?ooooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
3Oooool10000007ooooo000Kooooo`0300000?oooooooooo02;ooooo00?o003oooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07Ooo
ool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01ooo
ool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0003oooooooooool02?oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00gooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0Rooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`03o`00oooooooooooo01gooooo00?o003oooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool0
0`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool0
0`000?ooooooooooo`0Looooo`030000oooooooooooo00Sooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`0=ooooo`4000000Oooool001Cooooo0_l00005ooooo`0300000?oooooooooo
02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo
00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo
01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00gooooo0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
02;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00?o003oooooooooool07Oooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`030?l000000?oooooo
00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo
01cooooo00<0003oooooooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00gooooo0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`H0000000<0o`000000
000000001`0000000`3o0000000000000008000000030?l000000000000000L0000000?o003o0000
000000001`0000000`3o0000000000000007000000030?l000000000000000L0000000?o003o0?l0
00000000200000000`3o0000000000000007000000030?l000000000000000P0000000?o003o0000
000000001`0000000`3o0000000000000007000000030?l000000000000000L0000000?o003o0?l0
00000000200000000`3o0000000000000007000000030?l000000000000000L0000000<0o`000000
o`000000200000000`3o0000000000000007000000030?l000000000000000L0000000<0003o0000
00000000200000000`3o0000000000000007000000030?l000000000000000L0000000<0003o0000
00000000200000000`3o0000000000000007000000030?l000000000000000H000000ooo00050000
007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`08ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o
0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`00
0?ooooooooooo`0Kooooo`?oo`001?ooool10000007ooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Kooooo`?oo`001?ooool10000
007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`08ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o
0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`00
0?ooooooooooo`0Rooooo`4000000Oooool001Cooooo0_l00005ooooo`0300000?oooooooooo00?o
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01co
oooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo
00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0
o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`00
0000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003o
ooooooooool08_ooool10000007ooooo000Kooooo`0300000?l0003ooooo00?ooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003ooooo
ooooool08Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`08ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000
003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oo
ooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`08ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003o
ooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooo
ooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`08ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003ooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooooooo
o`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0R
ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Roooo
o`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`40
00000Oooool001_ooooo00<00000o`000?ooool00oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Qooooo`7o0000
0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@00
0001ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool02?ooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001
ooooo`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool02?ooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001oooo
o`006oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool02?ooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`00
6oooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
2?ooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?oo
ool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01ooo
ool00`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool0
0`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool0
0`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool0
0`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00
003o0000ooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`00
0?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`030000oooooooooooo027ooooo0Ol000010000007ooooo000Kooooo`03
00000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0000oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`030000
0?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000
oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oo
oooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oo
oooooooo00Oooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooo
oooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooo
oooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooo
oooo00Oooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooo
oooo01cooooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0003oooooooooool08_ooool10000007ooooo0008ooooo`;o00001?ooool01?l0
003oooooooooooooool5o`0000Cooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0R
ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030000oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool08_ooool10000007ooooo0007
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00`00003ooooooooo
o`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003ooooooooo
o`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooooooo
o`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`001oooool01?l0003oooooooooool0
000:ooooo`03o`000?oooooooooo00?ooooo00<00000o`000?ooool00oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`08ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003ooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooooooo
o`0Qooooo`7o00000@000001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo
0@000001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool02?ooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003ooooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`00
2?ooool2o`0000Wooooo0ol00005ooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
2?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000ooooool0
2?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool0
8_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?oo
ool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?oo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01ooo
ool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000ooooool02?oo
ool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool08_oo
ool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool0
0ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool0
0ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool0
0`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000ooooool02?ooool0
0`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool08_ooool1
0000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00ol0
0?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool08_ooool10000
007ooooo000Kooooo`0300000?l0003ooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool08Oooool1o`000040
00000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`400000
0Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00oooo
oooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oo
oooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oo
oooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooo
oooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooo
oooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`4000000Oooool0
01_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo
00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00oooooooooooo
01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo
00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo
00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_o
oooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00So
oooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo
00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo
00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00oooooooooooo01cooooo
00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<0
0000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0
o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00oooooooooooo01cooooo00?o
003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`4000000Oooool001_ooooo00<00000
o`000?ooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00
ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00oooooooooooo01cooooo00?o003o
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003o
ooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`000?ooooooooooo`0Qooooo`7o00000@000001ooooo`006oooool00`00
003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o
003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o
003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol0
0?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`00
0?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o
003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003o
ooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003o
ooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oo
ooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003ooooo
ooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol00?oooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooo
ooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003ooooooooo
o`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003ooooooooo
o`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol00?oooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooooooo
o`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`03
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0L
ooooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07
ooooo`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`03oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Loooo
o`030?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07oooo
o`030000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003oooooooooo`03ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`03
0?l000000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0000oooooooooooo02;ooooo0@000001ooooo`006oooool00`00003o0000ooooo`03ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00`3o003oooooooooo`07ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Sooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Looooo`030?l0
00000?oooooo00Sooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000
oooooooooooo027ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0
o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`00
0000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003o
ooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003ooooo
ooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000oooo
ool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003ooooooooo
ool08_ooool10000007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o0000
1?ooool00`00003oooooooooo`03ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
2?ooool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00?o003oooooooooool0
7?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`000?ooooooooooo`0Looooo`030?l000000?oooooo00Sooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo02;ooooo0@000001ooooo`001ooo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool0
0oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool0
1oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`3o003oooooooooo`08ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool0
1oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool0
7?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool0
1oooool00`000?ooooooooooo`0Rooooo`4000000Oooool000Oooooo00Co0000oooooooooooo0000
1oooool5o`0000Cooooo00<00000o`000?ooool00oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Qooooo`7o0000
0@000001ooooo`001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Go
oooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00So
oooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00oooooooooooo01co
oooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`4000000Oooool000Oooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`0300000?oooooooooo00?o
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oo
oooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oo
oooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01co
oooo00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oo
oooo00<0003oooooooooool08_ooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00005ooooo`0300000?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003oooooooooool07?ooool00ol00?oo
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool02?ooool00ol00?oo
ooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000ooooool02?ooool00`3o003o
ooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool08_ooool10000007o
oooo0008ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo
00?o003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo
00<0o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo
00<0o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo
00<0003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o
003oooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
o`00ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0
o`00ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0
o`000000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0
003oooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00
ooooooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00
ooooooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`00
0000ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003o
ooooooooool08_ooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooo
ooooool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00oooo
ooooool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000
ooooool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003ooooo
ooooool08_ooool10000007ooooo000Kooooo`0300000?l0003ooooo00?ooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`08ooooo`030?l00?oooooooooo00Oooooo00?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0o`00oooooooo
ool02?ooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00oooooooo
ool01oooool00`3o003oooooooooo`07ooooo`030000oooooooooooo01cooooo00<0o`000000oooo
ool02?ooool00`3o003oooooooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003ooooooooo
ool08Oooool1o`00004000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?oooooo
ooooo`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooo
ooooo`08ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003ooooo
ooooo`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003o
ooooo`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooo
ooooo`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?oooooooooo
o`0Looooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003ooooooooo
o`08ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003ooooooooo
o`07ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003ooooo
o`08ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?oooooooooo
o`0Rooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0L
ooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08
ooooo`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07
ooooo`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08
ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0R
ooooo`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Loooo
o`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08oooo
o`03o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07oooo
o`030?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08oooo
o`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Roooo
o`4000000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03
o`00oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03
o`00oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`03
0?l00?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`03
0?l00?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`40
00000Oooool001_ooooo00<00000ooooooooool00oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Sooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Looooo`03o`00
oooooooooooo00Oooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`08ooooo`03o`00
oooooooooooo01cooooo00?o003oooooooooool01oooool00`3o003oooooooooo`07ooooo`030?l0
0?oooooooooo00Oooooo00<0003oooooooooool07?ooool00`3o0000003oooooo`08ooooo`030?l0
0?oooooooooo00Oooooo00<0o`00ooooooooool01oooool00`000?ooooooooooo`0Rooooo`400000
0Oooool001_ooooo00@00000oooooooooooooooo0ooo0008ooooo`?oo`001oooool3ool000Wooooo
00?o003oooooooooool06_ooool2ool00003o`00oooooooooooo00Kooooo0ooo0007ooooo`?oo`00
2Oooool00ol00?ooooooooooo`0Jooooo`;oo`0000?o003oooooooooool01Oooool3ool000Sooooo
0ooo0008ooooo`030000oooooooooooo01_ooooo0_oo00000`000?ooooooooooo`05ooooo`?oo`00
2?ooool3ool000Sooooo00<0003oooooooooool08_ooool10000007ooooo000Kooooo`0400000?l0
003oooooooooo`;oo`008?l00?lLooooo`;oo`008?l00?lLooooo`;oo`0000?o003o0000o`000?l0
60000?l3o`00o`030000oooooooooooo01_ooooo0_oo000J0000o`05o`00o`000?l0003oo`00o`00
0?l08oooool1o`00004000000Oooool001_ooooo00@00000oooooooooooooooo0ooo0008ooooo`?o
o`001oooool3ool002Kooooo0ooo0008ooooo`?oo`001oooool3ool002Kooooo0ooo0007ooooo`?o
o`002?ooool3ool002Kooooo0ooo0007ooooo`?oo`002?ooool3ool002gooooo0@000001ooooo`00
6oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`03ooooo`4000000Oooool001_oooooo`0000050000007ooooo003o
ooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.540771, -0.618986, \
0.0161771, 0.00654375}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Listening to frequencies", "Section"],

Cell[CellGroupData[{

Cell["Simple sine waves", "Subsection"],

Cell[CellGroupData[{

Cell["400Hz sine wave", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Play[Sin[2  \[Pi]\ 400\ t], {t, 0, 2}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`00000Q
0000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooo`00003oo`0001co
00000Oooool10000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oo
oooo00000?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool1
0000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo
00007?l00001ooooo`40000000000`00003oooooo`00000@o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000001_l000000ooooooo0000o`000006o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000008?l000000ooooooo0000o`000006o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000001_l000000ooooooo0000o`00000Po`000003ooooool0003o000000Ko0000
00?oooooo`000?l000001_l000000ooooooo0000o`000006o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000008?l000000ooooooo0000o`000006o`000003ooooool0003o000000Ko0000
00?oooooo`000?l000001_l000000ooooooo0000o`00000Po`0000;ooooo0@000000000300000?oo
oooo00000?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool1
0000000000<00000ooooool000000ol000000ooooooo0000o`000006o`000003ooooool0003o0000
023o000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`000003ooooool0003o0000
00Ko000000?oooooo`000?l000001_l000000ooooooo0000o`00000Po`000003ooooool0003o0000
00Ko000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`000003ooooool0003o0000
023o000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`000003ooooool0003o0000
00Ko000000?oooooo`000?l000001_l000000ooooooo0000o`00000Po`000003ooooool0003o0000
00Ko000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`000003ooooool0003o0000
00;o00000Oooool10000000000<00000ooooool00000ool0000Lo`00007ooooo0@00000000030000
0?oooooo00000?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Ooo
ool10000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo0000
0?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool100000000
00<00000ooooooooool0oooooolMooooo`400000003o00000240000000000`00003oooooooooo`3o
oooooagooooo0@000000000300000?oooooo00000?oo00007?l00001ooooo`40000000000`00003o
ooooo`000004o`0000?ooooo1_l00003ooooo`Ko00000oooool6o`0000?ooooo1_l00002ooooo`Oo
00000_ooool7o`0000;ooooo1_l00003ooooo`Ko00000oooool6o`0000?ooooo1_l00003ooooo`Ko
00000_ooool7o`0000;ooooo1ol00002ooooo`Ko00000oooool6o`0000?ooooo1_l00003ooooo`Ko
00000oooool6o`0000?ooooo1_l00002ooooo`Oo00000_ooool7o`0000;ooooo1_l00003ooooo`Ko
00000oooool6o`0000?ooooo1_l00003ooooo`Ko00000_ooool7o`0000;ooooo1ol00002ooooo`Ko
00000oooool6o`0000?ooooo1_l00003ooooo`7o00000Oooool10000000000<00000ooooool00000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool1o`00007ooooo0@000000000300000?oooooooooo00Cooooo1?l00005ooooo`?o
00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`Co
00001Oooool4o`0000Gooooo0ol00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`Co
00001Oooool4o`0000Gooooo1?l00005ooooo`?o00001Oooool4o`0000Gooooo1?l00005ooooo`Co
00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo0ol00005ooooo`Co
00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`?o
00000_ooool10000000000D00000ooooool0003o0000ooooo`02o`0000?ooooo1_l00003ooooo`Ko
00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000004oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?ooooo0ol000000ooo
oooo0000o`000003ooooo`?o000000?oooooo`000?l000000oooool6o`0000?ooooo1_l00003oooo
o`;o000000Coooooo`000?l0003o00000oooool2o`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000oooool3o`000003ooooool0003o
000000?ooooo1_l00003ooooo`Ko00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l0
00000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0
003o000000?ooooo0ol000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000000ooo
ool6o`0000?ooooo1_l00003ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0oooool3o`000003ooooool0003o000000?ooooo1_l00003ooooo`7o00000Oooool10000000000<0
0000ooooooooool00_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_oo
ool3o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001ooo
ool2o`0000Oooooo0_l00006ooooo`?o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001ooo
ool2o`0000Oooooo0_l00007ooooo`;o00001_ooool3o`0000Kooooo0_l00007ooooo`;o00001ooo
ool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`?o00001_oo
ool2o`0000Oooooo0_l00007ooooo`;o00001oooool10000000000<00000ooooool000000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o0000
0_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`00
0?l0003o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_oo
ool3o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o
000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0003o000000?ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l0
0002ooooo`?o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0Ol00001ooooo`40000000000`00003oooooooooo`04ooooo`?o00001_oo
ool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Gooooo1?l00005ooooo`?o00001_oo
ool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001Ooo
ool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_oo
ool3o`0000Gooooo1?l00005ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_oo
ool3o`0000Kooooo0ol00006ooooo`?o00001Oooool3o`0000Kooooo0ol00006ooooo`?o00001_oo
ool3o`0000;ooooo0@000000000300000?oooooooooo00Cooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000002ooooo`40000000000`00003oooooo`000002oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l0
0002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000003ooooool0003o000000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`00
0004ooooool0003o0000o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o0000
0_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
000000Coooooo`000?l0003o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol00000
1?oooooo0000o`000?l00002ooooo`?o000000?oooooo`000?l000000oooool3o`000003ooooool0
003o000000?ooooo0_l00002ooooo`;o00000oooool1o`00007ooooo0@000000000300000?oooooo
oooo00;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0@000000000600000?oooooo0000o`000?oooooo00001Ooo
ool4o`0000Gooooo1?l00005ooooo`04o`000?oooooo0000o`0000Gooooo00Co0000ooooool0003o
00001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?ooool01?ooool2o`000003ooooool0003ooooo00Cooooo1?l00005ooooo`04
o`000?oooooo0000o`0000Gooooo00Co0000ooooool0003o00001?ooool2o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?ooool01?ooool2
o`000003ooooool0003ooooo00Cooooo1?l00005ooooo`Co00001Oooool01?l0003oooooo`000?l0
0005ooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000001?ooool2o`000003ooooool0003ooooo00Cooooo0_l000000ooooooo0000
ooooo`04ooooo`Co00001Oooool01?l0003oooooo`000?l00005ooooo`04o`000?oooooo0000o`00
00Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003ooooo00Cooooo0_l000000ooooooo0000ooooo`04ooooo`;o000000?oooooo`00
0?ooool01Oooool10000000000<00000ooooooooool00oooool2o`0000;ooooo00?o0000oooooooo
ool00_ooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool00_l00004ooooo`03
o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000oooooooo
ool00_ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`03
o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o
00000_ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000001?ooool00ol0003o
ooooooooo`02o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o
00000_ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000000Cooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03
o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo
0000o`000?ooool10000000000<00000ooooooooool01?ooool3o`0000Kooooo0ol00006ooooo`?o
00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`?o
00001_ooool3o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o
00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool2o`0000Oooooo0_l00007ooooo`;o
00001oooool2o`0000Oooooo0_l00006ooooo`?o00001_ooool3o`0000Kooooo0_l00007ooooo`;o
00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool3o`0000Kooooo0ol00002ooooo`40
000000000`00003oooooooooo`04ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o0000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o0000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000002ooooo`40000000000`00003oooooooooo`03ooooo`;o00000_oo
ool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000001?ooool00ol0003ooooooooo
o`02o`0000Cooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool00ol0003ooooooooo
o`02ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001?oo
ool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool00_oo
ool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000Cooooo00?o
0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oo
oooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`00
0?ooool10000000000H00000ooooool0003o0000ooooool00005ooooo`Co00001Oooool4o`0000Go
oooo00Co0000ooooool0003o00001Oooool01?l0003oooooo`000?l00004ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003ooooo00Cooooo0_l000000ooooooo0000ooooo`04
ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`04o`000?oooooo0000o`0000Gooooo00Co
0000ooooool0003o00001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
ooooo`04ooooo`;o000000?oooooo`000?ooool01?ooool4o`0000Gooooo1?l00005ooooo`04o`00
0?oooooo0000o`0000Gooooo00Co0000ooooool0003o00001?ooool2o`000003ooooool0003o0000
00Cooooo0_l000000ooooooo0000ooooo`04ooooo`;o000000?oooooo`000?ooool01?ooool4o`00
00Gooooo1?l00005ooooo`Co00001Oooool01?l0003oooooo`000?l00005ooooo`04o`000?oooooo
0000o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?ooool01?oo
ool2o`000003ooooool0003ooooo00Cooooo1?l00006ooooo`40000000001@00003ooooooooooooo
oooo000000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`4000000000
0`00003oooooo`000003o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo0ol00006
ooooo`03o`000?oooooo000000Kooooo0ol00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005
ooooo`Co00001Oooool4o`0000Gooooo0ol00006ooooo`03o`000?oooooo000000Kooooo0ol00005
ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool3o`0000Kooooo00?o0000
ooooool000001_ooool3o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005
ooooo`Co00001Oooool3o`0000Kooooo00?o0000ooooool000001_ooool3o`0000Gooooo1?l00005
ooooo`Co00001_ooool10000000000<00000ooooool000000oooool01?l0003oooooooooooooool2
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003ooooooooo
ooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`06o`000?ooooooooooooooool0003ooooo0@000000000300000?oooooooooo00Cooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000002ooooo`40000000000`00003oooooooooo`05oooo
o`;o00001oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool01?l0003oooooooooooooool10000000000<00000ooooooooool00oooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000000Cooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?ooool01?ooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003ooooo
00Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooo`000?l00004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003ooooo00Cooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`;o000000?oooooo`000?l0
00001?ooool2o`000003ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?ooool10000
000000<00000ooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`04o`000?ooooooooooo`0000Kooooo0@000000000600000?ooooooooooo`00
0?oooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003ooooooooo
ool00006ooooo`40000000000`00003oooooooooo`02o`0000Oooooo0_l00007ooooo`;o00001ooo
ool2o`0000Oooooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001ooo
ool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo0_l00007ooooo`;o00001ooo
ool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_oo
ool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001ooo
ool2o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`4000000000
1P00003oooooooooool0003oooooo`0000Kooooo00?o0000ooooool000001Oooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool10000000000<00000ooooool000000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo0Ol00001ooooo`40000000000`00003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oo
oooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000_ooool10000000000<0
0000ooooooooool01?ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l0
0007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l0
0007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000002ooooo`40000000000`00003oooooooooo`04
ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006
ooooo`?o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool3o`0000Kooooo0ol00006
ooooo`?o00001_ooool3o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006
ooooo`?o00001_ooool3o`0000;ooooo0@000000000300000?oooooooooo00Cooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000002ooooo`40
000000000`00003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01_l0003ooooooooooooooooo
0000ooooo`40000000001P00003oooooo`000?l0003oooooo`0000Gooooo1?l00005ooooo`Co0000
1Oooool01?l0003oooooo`000?l00005ooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?ooool01?ooool2o`000003ooooool0003ooooo
00Cooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo00Co0000ooooool0003o00001Oooool0
1?l0003oooooo`000?l00004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0
003ooooo00Cooooo0_l000000ooooooo0000ooooo`04ooooo`Co00001Oooool4o`0000Gooooo00Co
0000ooooool0003o00001Oooool01?l0003oooooo`000?l00005ooooo`04o`000?oooooo0000o`00
00Cooooo0_l000000ooooooo0000ooooo`04ooooo`;o000000?oooooo`000?ooool01?ooool4o`00
00Gooooo1?l00005ooooo`Co00001Oooool01?l0003oooooo`000?l00005ooooo`04o`000?oooooo
0000o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?ooool01?oo
ool2o`000003ooooool0003ooooo00Cooooo1?l00006ooooo`40000000001@00003ooooooooooooo
oooo000000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool2o`0000Oooooo0@000000000300000?oooooooooo00;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000
ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`40000000000`00003oooooo`000002oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000<00000ooooool00000
0oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00003ooooo`06o`000?ooooooooooooooool0003ooooo0@0000000003
00000?oooooooooo00Cooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000002ooooo`40
000000000`00003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o0000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o0000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o0000
1oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`04o`00
0?ooooooooooooooo`40000000000`00003oooooooooo`05ooooo`;o00001oooool00ol0003ooooo
ooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003ooooo
ooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool01?l0003ooooo
ooooooooool10000000000<00000ooooooooool01?ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003o
ooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000;ooooo0@000000000300000?oooooo0000
00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00000oooool1o`00007ooooo0@000000000600000?ooooooooooo`000?oooooo00001Oooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00006ooooo`40000000000`00
003oooooooooo`02o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0@0000000003
00000?oooooooooo00;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oo
oooo0_l00007ooooo`40000000001P00003oooooooooool0003oooooo`0000Kooooo00?o0000oooo
ool000001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`;o00001_ooool00ol0003oooooo`000006oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006oooo
o`03o`000?oooooo000000Kooooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo0@0000000003
00000?oooooo000000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Kooooo0@000000000300000?oooooooooo00?ooooo0_l000000ooooooo
0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Co
oooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003o
ooooooooo`02ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Co
oooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003o
ooooooooo`02ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Co
oooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003o
ooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o0000oooooooo
ool00_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000Co
oooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003o
ooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o0000oooooooo
ool00_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000Co
oooo0_l000001?oooooo0000o`000?ooool10000000000<00000ooooooooool01?ooool00ol0003o
ooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oo
oooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oo
oooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Ko
oooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003o
ooooo`000006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oo
oooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000000_ooool100000000
00<00000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00Co0000oooooooooooooooo0@000000000300000?oooooooooo00Cooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o0000
1oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o0000
1oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000;ooooo0@000000000300000?oooooooooo00Cooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`00
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool01Ol0003oooooooooool0003ooooo004000000000
0`00003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool01_l0003ooooooooooooooooo0000oooo
o`40000000000`00003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00006ooooo`40000000000`00003o
ooooooooo`03o`0000Kooooo0_l00007ooooo`;o00001_ooool3o`0000Kooooo0ol00006ooooo`?o
00001_ooool3o`0000Kooooo0ol00006ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`?o
00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0_l00007ooooo`;o
00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`;o
00001oooool2o`0000Oooooo0_l00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o
00001_ooool3o`0000Kooooo0_l00007ooooo`40000000000`00003oooooooooo`3ooooooagooooo
0@000000000300000?oooooo000000?o00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Ooo
ool3o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`Co00001Ooo
ool4o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`?o00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Ooo
ool4o`0000Gooooo0ol00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Ooo
ool4o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`?o00001_oo
ool00ol0003oooooo`000006ooooo`?o00001Oooool4o`0000Gooooo1?l00006ooooo`4000000000
0`00003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000005ooooo`40000000000`00003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01_l0
003ooooooooooooooooo0000ooooo`40000000000`00003oooooooooo`04ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000000_ooool10000000000<00000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0@000000
000300000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool01?l0003oooooooooooooool10000000000<00000ooooooooool01?ooool00ol0
003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0
003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000;ooooo
0@000000000300000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0
003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Ko0000ooooooooooooooooo`000?ooool10000000000<00000ooooool0
00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001_ooool10000000000H00000oooooooooooo0000ooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo0@000000000300000?oooooo
oooo00;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000
ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`05
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000600000?ooooooooooo`00
0?oooooo00001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo0_l00006
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool10000000000<00000ooooool000000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool1o`00007ooooo0@00
0000000300000?oooooooooo0?oooooo7Oooool10000000000<00000ooooooooool01?ooool3o`00
00Kooooo00?o0000ooooool000001_ooool3o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`00
00Gooooo1?l00005ooooo`Co00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool3o`00
00Kooooo00?o0000ooooool000001_ooool3o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`00
00Gooooo1?l00005ooooo`Co00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool3o`00
00Kooooo00?o0000ooooool000000_ooool10000000000<00000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool10000000000<00000oooooooo
ool01?ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000;ooooo0@00000000030000
0?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`05o`000?ooooooooooo`000?ooool00@000000000300000?oooooooooo00?o
oooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool04oooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00
000Aooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`05o`00
0?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`40000000000`00003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0004ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_l00003ooooo`;o0000
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo
0_l00004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`02
o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_l00004ooooo`04o`000?ooooooooooo`0000Cooooo0_l0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l00004ooooo`04o`000?oo
ooooooooo`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_l00004ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00;o
oooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo
00;o00000oooool1o`00007ooooo0@000000000300000?oooooooooo00;o00001oooool2o`0000Oo
oooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oo
oooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003o
ooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oo
oooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oo
oooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003o
ooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oo
oooo0@000000000500000?ooooooooooooooool000001oooool2o`0000Oooooo0_l00007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o
00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0@00000000030000
0?oooooooooo00;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool10000000000<0
0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Kooooo
0@000000000300000?oooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Gooooo0@000000000300000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Ko0000
ooooooooooooooooo`000?ooool10000000000<00000ooooooooool01?ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000000_ooool10000000000<00000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0@000000000300000?oooooo
oooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2
o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`;o00001oooool2
o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool0
0ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2
o`0000Oooooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2
o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00Co0000oooooooooooooooo0@00
0000000300000?oooooooooo00?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000001?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`00
0?l000001?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo0_l0
0002ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000?oooooo`000?l000001?ooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l0
00001?ooool2o`000004ooooool0003o0000ooooo`40000000000`00003oooooooooo`3ooooooago
oooo0@000000000500000?oooooo0000o`000?ooool00_l00004ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001?ooool2o`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`;o000000?oooooo`000?l0
00001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00004ooooo`;o000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000ooooo`04
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`04o`00
0?ooooooooooo`0000Kooooo0@000000000300000?oooooooooo00;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003ooooo
ooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`40000000000`00003ooooooooo
o`02o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001ooo
ool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001ooo
ool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001ooo
ool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo0_l00007ooooo`;o00001oooool10000000000H00000oooooooooooo0000oooo
ool00006ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`40000000000`00003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000<0
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Ko
0000ooooooooooooooooo`000?ooool10000000000<00000ooooooooool01?ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000;ooooo0@000000000300000?oooooooooo00Gooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l0
0007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l0
0007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000;ooooo0@000000000300000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooooooo`40000000000`00003oooooooooo`04ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2
o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2
o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000000_ooool10000000000<00000ooooooooool00oooool2o`00
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
o`0000Cooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;o00001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oo
oooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l0
0004ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooool0003ooooo0@00000000030000
0?oooooooooo0?oooooo7Oooool10000000000<00000ooooool000000ol00005ooooo`Co00001Ooo
ool4o`0000Gooooo1?l00005ooooo`04o`000?oooooo0000o`0000Gooooo00Co0000ooooool0003o
00001?ooool2o`000003ooooool0003ooooo00Cooooo0_l000000ooooooo0000ooooo`04ooooo`Co
00001Oooool4o`0000Gooooo1?l00005ooooo`04o`000?oooooo0000o`0000Gooooo00Co0000oooo
ool0003o00001?ooool2o`000003ooooool0003ooooo00Cooooo0_l000000ooooooo0000ooooo`04
ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool01?l0003oooooo`000?l0
0005ooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000ooooo`04ooooo`;o0000
00?oooooo`000?ooool01?ooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool01?l0003ooooo
o`000?l00005ooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000ooooo`04oooo
o`;o000000?oooooo`000?ooool01?ooool4o`0000Gooooo1?l00006ooooo`40000000001@00003o
oooooooooooooooo000000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0@0000000003
00000?oooooooooo00;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Ko
oooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oo
oooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003o
ooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oo
oooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oo
oooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool100000000
00<00000ooooool000000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Kooooo0@000000000300000?oooooo000000?ooooo00Co0000oooooooooooooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool10000000000<0
0000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`04ooooo`?o00001_ooool3
o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0_l00006ooooo`?o00001_ooool3
o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`;o00001_ooool3
o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3
o`0000Kooooo0_l00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3
o`0000Kooooo0ol00006ooooo`;o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3
o`0000;ooooo0@000000000300000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo
00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo00Co0000oooooooooooooooo0@000000000300000?oooooooooo00Cooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000002
ooooo`40000000000`00003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo0@000000000500000?oo
oooo0000o`000?ooool00_l00004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000004ooooo`;o000000?oooooo`000?ooool01?ooool01?l0003oooooooooool00005
ooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?o
ooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000?oooooo`000?l000001?ooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l0
00001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?l000001?ooool2o`000003ooooool0003ooooo00Cooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00004ooooo`;o000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000Cooooo00Co0000oooooooooooo00001_oo
ool10000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`02o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo
00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool10000
000000H00000oooooooooooo0000ooooool00006ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo0@00
0000000300000?oooooo000000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00006ooooo`40000000000`00003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01_l0003ooooooooooooooooo0000ooooo`40
000000000`00003oooooooooo`04ooooo`?o00001_ooool00ol0003oooooo`000006ooooo`?o0000
1Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool3o`0000Gooooo1?l00005ooooo`Co0000
1Oooool4o`0000Gooooo1?l00005ooooo`?o00001_ooool00ol0003oooooo`000006ooooo`?o0000
1Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool3o`0000Gooooo1?l00005ooooo`Co0000
1Oooool4o`0000Gooooo1?l00005ooooo`?o00001_ooool00ol0003oooooo`000002ooooo`400000
00000`00003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`40000000000`00003ooooooooo
o`04ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0002ooooo`40000000000`00003oooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_l0
0003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`02o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool00_ooool01_l0003ooooo
oooooooooooo0000ooooo`40000000000`00003oooooo`000002ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000<0
0000ooooooooool00_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001ooo
ool2o`0000Oooooo0@000000000300000?oooooooooo00;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Kooooo0ol00006ooooo`?o00001_ooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`?o00001_ooool3o`0000Kooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo0ol00006
ooooo`?o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006
ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`;o00001oooool2o`0000Oooooo0@000000
000300000?oooooo000000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00006ooooo`40000000000`00003oooooo`000003ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000005oooo
o`40000000000`00003oooooooooo`03ooooo`;o000000?oooooo`000?l000001?ooool2o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?oo
ool01?ooool2o`000003ooooool0003ooooo00Cooooo1?l00005ooooo`04o`000?oooooo0000o`00
00Gooooo00Co0000ooooool0003o00001?ooool2o`000003ooooool0003o000000Cooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?ooool01?ooool2o`000003ooooool0003o
oooo00Cooooo1?l00005ooooo`04o`000?oooooo0000o`0000Gooooo00Co0000ooooool0003o0000
1?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000001?ooool2o`000003ooooool0003ooooo00Cooooo0_l000000ooooooo0000
ooooo`04ooooo`Co00001Oooool01?l0003oooooo`000?l00005ooooo`04o`000?oooooo0000o`00
00Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`00
0003ooooool0003ooooo00Cooooo0_l000000ooooooo0000ooooo`04ooooo`Co00001Oooool01?l0
003oooooo`000?l00005ooooo`04o`000?oooooo0000o`0000Gooooo00Co0000ooooool0003o0000
1?ooool2o`000004ooooool0003o0000ooooo`40000000000`00003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool0
1_ooool01?l0003oooooooooooooool10000000000<00000ooooooooool01Oooool2o`0000Oooooo
00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000;ooooo0@000000000300000?oooooooooo00?ooooo0_l0
00000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0
003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00;o00001?oo
ool01?l0003oooooooooool00004ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o0000
00?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`02o`0000Cooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`;o000000?oooooo`00
0?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004oooo
o`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo00?o0000oooo
ooooool00_l00004ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002ooooo`03o`000?oooooo
oooo00;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2
o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooo
oooo00;o00001?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo
0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`000004oooo
ool0003o0000ooooo`40000000000`00003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`04o`000?ooooooooooo`0000Kooooo0@000000000300000?oooooooooo00?o0000
1Oooool4o`0000Gooooo1?l00005ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o0000
1_ooool3o`0000Kooooo0ol00005ooooo`Co00001Oooool3o`0000Kooooo0ol00006ooooo`?o0000
1_ooool3o`0000Kooooo0ol00006ooooo`?o00001Oooool4o`0000Gooooo1?l00005ooooo`?o0000
1_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00005ooooo`Co0000
1Oooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o0000
1Oooool4o`0000Kooooo0@000000000300000?oooooooooo00?o00001_ooool3o`0000Gooooo0ol0
0006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol0
0005ooooo`Co00001Oooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol0
0006ooooo`?o00001_ooool3o`0000Gooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol0
0006ooooo`?o00001_ooool3o`0000Kooooo0ol00005ooooo`Co00001Oooool3o`0000Kooooo0ol0
0006ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0@00
0000000300000?oooooo000000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000<00000
ooooooooool00oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004
ooooo`;o000000?oooooo`000?l000001?ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000
ooooooooool00_l00003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool0
0ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool0
0ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool0
0ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000004
ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00002
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
000000Cooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00;o00001?ooool0
0ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00002
ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000004ooooo`;o000000Cooooo
o`000?l0003ooooo0@000000000300000?oooooooooo00Gooooo0_l00006ooooo`?o00001_ooool2
o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool3
o`0000Kooooo0ol00006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2
o`0000Oooooo0_l00006ooooo`?o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2
o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo0ol00006ooooo`;o00001oooool2
o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`?o00000_ooool1
0000000000<00000ooooooooool01?ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`00
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000002ooooo`40000000000`00003o
ooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool0
0ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000ooooo`40
000000000`00003oooooo`000003o`0000Gooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo
00Co0000ooooool0003o00001Oooool00ol0003oooooo`000005ooooo`;o000000?oooooo`000?oo
ool01?ooool2o`000003ooooool0003ooooo00Cooooo1?l00005ooooo`Co00001Oooool4o`0000Go
oooo00Co0000ooooool0003o00001Oooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo
000000Gooooo0_l000000ooooooo0000ooooo`04ooooo`Co00001Oooool4o`0000Gooooo1?l00005
ooooo`Co00001Oooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo000000Gooooo0_l0
00000ooooooo0000ooooo`04ooooo`;o000000?oooooo`000?ooool01?ooool4o`0000Gooooo1?l0
0005ooooo`Co00001Oooool4o`0000Gooooo00Co0000ooooool0003o00001Oooool00ol0003ooooo
o`000005ooooo`;o000000?oooooo`000?ooool01?ooool4o`0000Gooooo1?l00006ooooo`400000
00001@00003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo0@000000000300000?oooooo000000?o00001Ooo
ool4o`0000Gooooo1?l00005ooooo`Co00001Oooool01?l0003oooooo`000?l00005ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001Oooool4o`0000Gooooo1?l00005ooooo`Co0000
1Oooool4o`0000Gooooo1?l00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1Oooool2o`000003ooooool0003ooooo00Cooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo
1?l00005ooooo`Co00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo
1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Gooooo0_l000000ooooooo0000ooooo`04ooooo`Co0000
1Oooool4o`0000Kooooo0@000000000300000?oooooo000000?ooooo0_l000000ooooooo0000o`00
0004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?ooooo0ol0
00000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000000oooool6o`0000?ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003
ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l0
00000oooool3o`000003ooooool0003o000000?ooooo1_l00003ooooo`;o000000Coooooo`000?l0
003o00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000004
ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000?ooooo0ol00000
0ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000000oooool6o`0000?ooooo0_l00000
1?oooooo0000o`000?l00003ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l00000
0oooool3o`000003ooooool0003o000000?ooooo1_l00003ooooo`;o000000Coooooo`000?l0003o
00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000000ooooooo0000o`000004oooo
o`;o000000Coooooo`000?l0003ooooo0@000000000300000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooooooool10000000000<00000ooooooooool01?ooool3o`00
00Kooooo00?o0000ooooool000001_ooool3o`0000Kooooo0ol00005ooooo`Co00001Oooool4o`00
00Gooooo1?l00005ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001Oooool4o`00
00Gooooo1?l00005ooooo`Co00001Oooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`00
00Kooooo0ol00005ooooo`Co00001Oooool4o`0000Gooooo1?l00005ooooo`?o00001_ooool3o`00
00Kooooo0ol00006ooooo`?o00001Oooool4o`0000Gooooo1?l00005ooooo`Co00001Oooool3o`00
00Kooooo0ol00006ooooo`?o00000_ooool10000000000D00000ooooool0003o0000ooooo`02o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`00
0?l0003o00000oooool2o`000004ooooool0003o0000o`0000?ooooo0_l000001?oooooo0000o`00
0?l00002ooooo`?o000000?oooooo`000?l000000oooool3o`000003ooooool0003o000000?ooooo
0ol000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000004ooooool0003o0000
o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`?o000000?oooooo`000?l000000oooool3
o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00000oooool2o`000004ooooool0003o0000o`0000?ooooo
0_l000001?oooooo0000o`000?l00002ooooo`?o000000?oooooo`000?l000000oooool3o`000003
ooooool0003o000000?ooooo0ol000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000?o
oooo0_l000001?oooooo0000o`000?l00003ooooo`;o000000Coooooo`000?l0003o00000oooool2
o`000004ooooool0003o0000o`0000;ooooo0ol000000ooooooo0000o`000003ooooo`?o000000?o
ooooo`000?l000000oooool3o`000003ooooool0003o000000?ooooo0_l00002ooooo`;o00000ooo
ool1o`00007ooooo0@000000000300000?oooooooooo00;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool10000000000<00000ooooool000000ol00005ooooo`Co00001Oooool4o`00
00Gooooo1?l00004ooooo`Go00001?ooool5o`0000Cooooo1Ol00004ooooo`Go00001?ooool4o`00
00Gooooo1?l00005ooooo`Co00001?ooool5o`0000Cooooo1Ol00004ooooo`Go00001?ooool5o`00
00Cooooo1?l00005ooooo`Co00001Oooool4o`0000Gooooo1?l00004ooooo`Go00001?ooool5o`00
00Cooooo1Ol00004ooooo`Go00001?ooool4o`0000Gooooo1?l00005ooooo`Co00001?ooool5o`00
00Cooooo1Ol00004ooooo`Go00001?ooool5o`0000Cooooo1?l00005ooooo`Co00001_ooool10000
000000<00000ooooooooool00oooool5o`0000Cooooo1Ol00004ooooo`Go00001?ooool5o`0000Co
oooo1Ol00003ooooo`Go00001?ooool5o`0000Cooooo1Ol00004ooooo`Go00001?ooool5o`0000Co
oooo1Ol00004ooooo`Go00001?ooool5o`0000?ooooo1Ol00004ooooo`Go00001?ooool5o`0000Co
oooo1Ol00004ooooo`Go00001?ooool5o`0000Cooooo1Ol00004ooooo`Co00001?ooool5o`0000Co
oooo1Ol00004ooooo`Go00001?ooool5o`0000Cooooo1Ol00004ooooo`Go00001?ooool5o`0000?o
oooo1Ol00004ooooo`Go00001?ooool5o`0000Cooooo1Ol00001ooooo`40000000000`00003ooooo
ooooo`04ooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o
000000?oooooo`000?ooool01?ooool2o`000003ooooool0003ooooo00Cooooo1?l00005ooooo`Co
00001Oooool01?l0003oooooo`000?l00005ooooo`04o`000?oooooo0000o`0000Cooooo0_l00000
0ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o
oooo00Cooooo0_l000000ooooooo0000ooooo`04ooooo`Co00001Oooool4o`0000Gooooo00Co0000
ooooool0003o00001Oooool01?l0003oooooo`000?l00004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003ooooo00Cooooo0_l000000ooooooo0000ooooo`04ooooo`Co0000
1Oooool4o`0000Gooooo00Co0000ooooool0003o00001Oooool01?l0003oooooo`000?l00005oooo
o`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?ooooo
o`000?ooool01?ooool2o`000003ooooool0003ooooo00Cooooo1?l00005ooooo`Co00001Oooool0
1?l0003oooooo`000?l00005ooooo`04o`000?oooooo0000o`0000Cooooo0_l000001?oooooo0000
o`000?ooool10000000000<00000ooooool000001?l00003ooooo`Ko00000oooool6o`0000?ooooo
1Ol00004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`000004ooooo`Go00000oooool6o`0000?ooooo1_l00003ooooo`Ko0000
0oooool5o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
1?ooool2o`000003ooooool0003o000000Cooooo1Ol00003ooooo`Ko00000oooool6o`0000?ooooo
1Ol00004ooooo`;o000000?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo
0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l000000oooool6o`0000?ooooo
1_l00003ooooo`Ko00000oooool5o`0000Cooooo0_l000000ooooooo0000o`000004ooooo`;o0000
00?oooooo`000?l000001?ooool2o`000003ooooool0003o000000Cooooo1Ol00003ooooo`Ko0000
1Oooool10000000000<00000ooooool000001Ol00002ooooo`Ko00000oooool6o`0000;ooooo1ol0
0002ooooo`Oo00000_ooool7o`0000;ooooo1ol00002ooooo`Oo00000_ooool6o`0000?ooooo1_l0
0003ooooo`Ko00000_ooool7o`0000;ooooo1ol00002ooooo`Oo00000_ooool7o`0000;ooooo1ol0
0002ooooo`Ko00000oooool6o`0000;ooooo1ol00002ooooo`Oo00000_ooool7o`0000;ooooo1ol0
0002ooooo`Oo00000_ooool6o`0000?ooooo1_l00003ooooo`Ko00000_ooool7o`0000;ooooo1ol0
0002ooooo`Oo00000_ooool7o`0000;ooooo1ol00002ooooo`Ko00000oooool1o`00007ooooo0@00
0000000300000?oooooooooo00Cooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006
ooooo`?o00001_ooool2o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00006
ooooo`?o00001_ooool3o`0000Kooooo0_l00007ooooo`;o00001_ooool3o`0000Kooooo0ol00006
ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool2o`0000Kooooo0ol00006
ooooo`?o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0_l00007
ooooo`;o00001_ooool3o`0000Kooooo0ol00006ooooo`?o00000_ooool10000000000<00000oooo
ool000001Ol000000ooooooo0000o`000006o`000003ooooool0003o000000Ko000000?oooooo`00
0?l000001_l000000ooooooo0000o`000005o`0000;ooooo1ol00002ooooo`Oo00000_ooool7o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`00
0003ooooool0003o000000Go00000_ooool7o`0000;ooooo1ol00002ooooo`Oo00000_ooool7o`00
0003ooooool0003o000000Ko000000?oooooo`000?l000001_l000000ooooooo0000o`000006o`00
0003ooooool0003o000000Go00000_ooool7o`0000;ooooo1ol00002ooooo`Oo000000?oooooo`00
0?l000001_l000000ooooooo0000o`000006o`000003ooooool0003o000000Ko000000?oooooo`00
0?l000001Ol00002ooooo`Oo00000_ooool7o`0000;ooooo1ol00002ooooo`Oo000000?oooooo`00
0?l000001_l000001?oooooo0000o`000?ooool10000000000<00000ooooool00000ool0000Lo`00
007ooooo0@000000000300000?oooooooooo0?oooooo7Oooool100000000o`00000Q00000000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000l002VbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJIoFCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIP:K9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YX1I=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UV0Y/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVOeTf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFGnVbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJIoFCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIP:K9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YX1I=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UV0Y/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVP5Tf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFGnVbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJIoFCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIP:K9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YX1I=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UV0Y/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVOeTf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFGnVbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJJ0FCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIP:K9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YX1I=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UUoY/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVOeTf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFGnVbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJJ0FCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIP:K9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YWmI=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UV0Y/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVP5Tf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFGnVbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJJ0FCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIP:K9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YWmI=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UV0Y/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVOeTf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFGnVbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJJ0FCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIOjK9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YWmI=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UV0Y/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVOeTf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFGnVbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJJ0FCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIOjK9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YWmI=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UV0Y/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVOeTf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFGnVbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJJ0FCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIOjK9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YWmI=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UV0Y/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVOeTf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFH2VbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJIoFCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIP:K9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YWmI=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UUoY/WUn?okjm6_RF8n80X00PlWAffD^MW`oOodg/2LMDl]4`@0
21/gFX6Xb^Kioo[Zcjj7H3`O2P0242Q9KYFjf_7no_?M_iYcCB`C0`0873QLPjW<
ioWon^W>[8IO>ah900<A:TY`UkcKl_knlmbmV75<:a8300TM>Uf4ZlgXn_ojj<f[
Q5dj7@T00a8[C76H_Mcco_kbfkbGL4XZ4@<02AhkGhJ/c^WjooWWc:V3G3PL2003
4ba=LiZogO?no_7J^YE^BBP@0P0:7caPQjk?j_[onNK:Z85J=a/800@C;DmeW<3N
m?oml=ViU6e79`l200XP?V:9[m7[noohiLVVP5Tf6PL011@^D7JM`Moeoog`f;RB
JdHV3`802b4oHhZ`d^ckooOTb:EnEcDI1P055C1AN9o3h?GooNoG]Y5ZABD>0@4<
8T1US;;Ck?comn?7XgaF<aP600DF<E=iX<CQm_olk]FeSfQ390d10@`S@VN>/mC]
o?ofh/FRNe@b5`D01ALbE7^RaN;fooc]e;>>Id8S30413BA3J8neeNklooKQa:1i
Dc4F1@0663=FO:?7hoOoo>cC/XaU@28<0@4>9DEZTKKGkogomN33WgQA<1D500HI
=EMnYLSTmookk=:`RV<o8@/00PlVAV^B^=S`oOoegl6MMU0^50@01aXfFGnVbNGh
oo_[dJn9HShP2P023bM7KIBifO3mooCN`9aeCbdC10086cMJPJS:i_Won^[?[XMP
?1l:008@:4U^UK[JlOknlmfoVW==;1<300PL>5b3ZLcWnOojjLj/QUlk7PT00a4Z
BW2G_=_bo_kcg;fHLD`[4P<02AdjGHB[cNSjoo[XcJ^4GCXM2@034R]<LIRmg??n
o_;K_9M`BRXA0`097S]OQZc>jO[onNO<ZH=L>1`800<C;4ecV[oMloknlMZjUFi9
:10200XO?627[/oZn_oii/ZXPEXg6`P011<]CgFL`=kdoog`fKVDKDLW3`802R0n
HXV_dN_kooSUbJJ0FCHJ1`0452i@MYg1goGooO3H^99[ARH?0P0;8CmSR[3Bk?_o
mnC8YGiG=AT600DE<55hWl?PmOomkmNfTFY59@h10@`R@6F</]?/o?oghlNSO5Hc
60H01AHaDgVPa>7fooc^eKF?J4<T3@4132=2Ihjce>glooKRaJ9kE38G1@055c9D
Nj;5h_Koo>gD/hiW@R<<0@4=94=XSkGEk_com^74X7UC<AH500HH<eIlXlOSmool
k=>bS6E08P`10@hUAFZA]]O_oOoeh<>ON54`5@D01QTeEgjUb>Cgoo_/d[2:HclQ
2`023bI6Ji:hf?3mooGO`IefD2hD10076SIIOjK9iOSonn_A[hUR?R0:008?9dM]
U;WIl?gom=k0W7E?;A<400PK=eZ1Z<[VnOojj/n^Qf0l7`X00Q0XBFjE^][ao_kc
gKnJLdd/4`<021`hG8>Yc>Oioo[YcZb6Gc/N2@034BY:L9Nlfo;no_?L_IQaC2/B
0`097CYMQ:_=j?[on^S=ZhAM>Qd900<B:daaV;gLloknl]^lUg1::Q4300TN>en6
[<kYn_oiilbYPe`h70P00a</CG>J_mgco_kaf[ZEKTTX40802QllH8N^cn[jooWV
bZR1FSLK20044be?MIc0g_CooO3I^IA]AbL?0P0:83iRRJoAjo_on>G9YX1I=QX7
00@D;U1fWL7OmOoml=RhTV]69Pl200/Q?f>:/=;/noogi<RUOULe6@H01AD`DGRO
`n3eoog_ekJAJTDU3P413290IHbbdnclooOSaj=lES<H1P055S5CNJ34hOKoo>kE
]HmX@b@=0@4<8d9WS[?DkOcom^;5XW]D<QL500DG<UAkX/GRm_olkMBcSVM28``1
0@dT@fR?]MG^o?ofhLBPNE<a5PD01QPcEWbSan?gooc/dk:<ID0R30413RE5JY6f
enomooGP`imhDC0E1@066CEGOZG8i?OonncB/8YS?b4;008?9TI[T[SHl?gomMo1
WGI@;Q@400LJ=UV0\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["800Hz sine wave", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Play[Sin[2  \[Pi]\ 800\ t], {t, 0, 2}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`00000Q
0000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooo`00003oo`0001co
00000Oooool10000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oo
oooo00000?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool1
0000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo
00007?l00001ooooo`40000000000`00003oooooo`000003o`000003ooooool0003o000001co0000
00?oooooo`000?l000007?l000000ooooooo0000o`00000Lo`000003ooooool0003o000002Go0000
00?oooooo`000?l000007?l000000ooooooo0000o`00000Lo`000003ooooool0003o000001co0000
00?oooooo`000?l000001_l000000ooooooo0000o`00000Lo`000003ooooool0003o000000_o0000
0Oooool10000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo
00000?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000
000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo0000
7?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000000000<00000
ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo00007?l00001oooo
o`40000000000`00003oooooo`00003oo`0001co00000Oooool10000000000<00000ooooooooool0
oooooolMooooo`400000003o00000240000000000`00003oooooooooo`3ooooooagooooo0@000000
000300000?oooooo00000?oo00007?l00001ooooo`40000000000`00003oooooo`000002o`000005
ooooool0003o0000o`000?ooool00ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3
o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`;o0000
0_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l00002oooo
o`?o000000Coooooo`000?l0003o00000_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?l0
0002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000004ooooool0003o0000o`0000;o
oooo0ol000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool3o`000004ooooool0003o0000
o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Goooooo`000?l0003o0000
ooooo`03o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0
003o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`?o000000Cooooo
o`000?l0003o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000
o`000?l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo0ol000001?oo
oooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000005ooooool0
003o0000o`000?ooool00ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000004
ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`;o00000_ooool3
o`0000?ooooo0@000000000;00000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool0
00000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0
003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0
003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oo
oooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0
003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oo
oooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool0
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oo
oooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0
003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0
003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`08o`000?oo
oooo0000ooooool0003oooooo`000?ooool10000000000@00000oooooooooooooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool00ol0003oooooooooo`010000000000<00000oooo
ool000000_l000001Ooooooo0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o0000oooo
o`03o`0000;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o
0000ooooo`04o`000005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000o`000?l0003o
oooo00?o00000_ooool3o`000005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000o`00
0?l0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo0ol000001Ooooooo
0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`04o`000005ooooool0003o
0000o`000?ooool00ol00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`04o`000005oooo
ool0003o0000o`000?ooool01?l000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool3o`00
0005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000o`000?l0003ooooo00Co000000Go
ooooo`000?l0003o0000ooooo`04o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`?o
000000Goooooo`000?l0003o0000ooooo`04o`000005ooooool0003o0000o`000?ooool01?l00000
1Ooooooo0000o`000?l0003ooooo00?o00000_ooool3o`000005ooooool0003o0000o`000?ooool0
1?l000001Ooooooo0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`03o`00
00;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o0000oooo
o`04o`000007ooooool0003o0000o`000?oooooo0000ooooo`010000000000@00000ooooool0003o
00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`00
00;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`04
o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo
00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003
ooooo`03o`000?oooooooooo00;ooooo0@000000000=00000?oooooo0000ooooool0003oooooo`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool02ol0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00_o0000ooooool0003oooooo`000?oooooo0000ooooool0003o
ooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo00_o0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool02ol0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo000000;o
oooo00?o0000ooooool000000oooool10000000000@00000oooooooooooooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0ol00002ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00001ooooo`40000000000`00003oooooooooo`3ooooooagooooo
0@000000000300000?oooooo000000;o000000Goooooo`000?oooooo0000ooooo`04o`000005oooo
ool0003o0000o`000?ooool02?l000000ooooooo0000o`000006o`000005ooooool0003oooooo`00
0?ooool01?l000001Ooooooo0000ooooool0003ooooo00So000000?oooooo`000?l000001_l00000
1Ooooooo0000ooooool0003ooooo00Co000000Goooooo`000?oooooo0000ooooo`04o`000005oooo
ool0003o0000o`000?ooool02?l000001Ooooooo0000o`000?l0003ooooo00Co000000Goooooo`00
0?oooooo0000ooooo`04o`000005ooooool0003o0000o`000?ooool02?l000001Ooooooo0000o`00
0?l0003ooooo00Co000000Goooooo`000?oooooo0000ooooo`04o`000005ooooool0003oooooo`00
0?ooool02?l000000ooooooo0000o`000006o`000005ooooool0003oooooo`000?ooool01?l00000
1Ooooooo0000ooooool0003ooooo00So000000?oooooo`000?l000001_l000001Ooooooo0000oooo
ool0003ooooo00Co000000Goooooo`000?oooooo0000ooooo`04o`000005ooooool0003o0000o`00
0?ooool02?l000001Ooooooo0000o`000?l0003ooooo00Co000000Goooooo`000?oooooo0000oooo
o`04o`000005ooooool0003o0000o`000?ooool02?l000001Ooooooo0000o`000?l0003ooooo00Co
000000Goooooo`000?oooooo0000ooooo`04o`000007ooooool0003oooooo`000?oooooo0000oooo
o`010000000000@00000ooooool0003o00000oooool01?l0003oooooooooooooool2o`0000?ooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o
00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0@00000000040000
0?oooooo0000o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`00
00;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`40000000001`00003ooooooooo
oooooooo0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000oooo
o`40000000000`00003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`4000000000
0`00003oooooooooo`3ooooooagooooo0@000000000700000?ooooooooooooooool0003oooooo`00
0002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000_ooool0
1?l0003oooooo`000?ooool10000000000@00000ooooool0003o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000oooo
ool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000?ooooo0@000000000400000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`;o00000oooool00ol0003oooooooooo`02ooooo`40000000001000003oooooo`000?l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000?ooooo0@000000000;
00000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`00
00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo
0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`08
o`000?oooooo0000ooooool0003oooooo`000?ooool10000000000<00000ooooooooool0oooooolM
ooooo`40000000000`00003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooooooo
ooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`400000
00001000003oooooooooooooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000Oooool10000000000T00000ooooool0003oooooo`000?oooooo0000oooo
ool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool02ol0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00_o0000ooooool0003oooooo`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`40000000000`00
003oooooooooo`3ooooooagooooo0@000000000400000?oooooo0000o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003ooooooooo
o`02ooooo`40000000001000003oooooo`000?l00003ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0@000000000;00000?oooooooooo
ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool02ol0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00_o0000ooooool0003oooooo`000?oooooo0000ooooool0003ooooo
o`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003ooooo
o`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00_o0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000002ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool000000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`09
o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_oo
ool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool10000
000000<00000ooooooooool0oooooolMooooo`40000000001000003oooooooooooooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo00?o0000ooooooooool00@000000000400000?ooooooooooooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooooooo
ooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000Oooool10000000000<00000ooooooooool0oooooolMooooo`400000
00002`00003ooooooooooooooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000
ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`09
o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000
ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003ooooo
o`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003ooooo
o`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003ooooo
o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000
ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02?l0003oooooo`000?oooooo0000
ooooool0003ooooo0@000000000400000?oooooo0000o`0000?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00004ooooo`40000000000`00003ooooooooo
o`3ooooooagooooo0@000000000400000?oooooo0000o`0000?ooooo00Co0000oooooooooooooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`00
00;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo
00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool00_ooool10000000000<0
0000ooooooooool0oooooolMooooo`40000000003@00003oooooo`000?oooooo0000ooooool0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02ol0003oooooo`000?oooooo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00_o0000ooooool0003oooooo`000?oooooo0000ooooool0003o
ooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool02ol0003oooooo`000?oooooo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo
0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool00000
0_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool02ol0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00_o0000ooooool0003oooooo`000?oooooo0000ooooool0003o
ooooo`000002ooooo`03o`000?oooooo000000?ooooo0@000000000400000?ooooooooooooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000Oooool10000000000<00000ooooooooool0
oooooolMooooo`40000000000`00003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`03o`000?oooooooooo0040
000000000`00003oooooooooo`3ooooooagooooo0@000000000;00000?ooooooooooooooool0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002oooo
o`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2
o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l0
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool100000000
00@00000ooooool0003o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00004ooooo`40000000000`00003ooooo
ooooo`3ooooooagooooo0@000000000400000?oooooo0000o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`02oooo
o`40000000000`00003oooooooooo`3ooooooagooooo0@000000000400000?oooooo0000o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`40000000001000003ooooooooooooo
ool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_oo
ool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_oo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`04o`000?oo
oooo0000ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000;00000?oo
ooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`;o00000_ooool01?l0003oooooo`000?ooool10000000000<00000oooo
ooooool0oooooolMooooo`40000000001000003oooooo`000?l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_oo
ool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool0
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo
0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`00
00;ooooo00?o0000ooooool000000oooool10000000000@00000oooooooooooo00000oooool01?l0
003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000ooo
ool2o`0000?ooooo00?o0000ooooooooool00_ooool10000000000<00000ooooooooool0oooooolM
ooooo`40000000001000003oooooo`000?l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000?ooooo0@000000000300000?oooooooooo0?oooooo7Oooool10000
000000/00000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool00000
0_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00So0000oooo
ool0003oooooo`000?oooooo0000ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@00
0000000300000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`00
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000;ooooo0@00000000030000
0?oooooooooo0?oooooo7Oooool10000000000@00000oooooooooooooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00007ooooo0@000000000300000?oo
oooooooo0?oooooo7Oooool10000000000T00000ooooool0003oooooo`000?oooooo0000ooooool0
00000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0
003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0
003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`40000000000`00003oooooooooo`3ooooo
oagooooo0@000000000400000?oooooo0000o`0000?ooooo00Co0000oooooooooooooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04
o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`02ooooo`4000000000
0`00003oooooooooo`3ooooooagooooo0@000000000400000?oooooo0000o`0000?ooooo0_l00002
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00004ooooo`40000000002`00003ooooooooo
oooooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00_o0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`00
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oooooo0000oooo
ool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`00
0002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000oooo
ool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool02ol0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool0
2Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`0;o`00
0?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0@00
0000000300000?oooooooooo0?oooooo7Oooool10000000000@00000oooooooooooooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`04
o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo
00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo
00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?o0000ooooooooool00@0000000003
00000?oooooooooo0?oooooo7Oooool10000000000@00000oooooooooooooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00001
ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo0?oo
oooo7Oooool10000000000/00000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`00
0002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000oooo
ool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000oooo
ool0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`00
0?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`00
0?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool0
2Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`00
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000oooo
ool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`00
0?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00So0000oooo
ool0003oooooo`000?oooooo0000ooooo`40000000001000003oooooo`000?l00003ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool0
0ol0003oooooooooo`02ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@0000000004
00000?oooooo0000o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooooooo
ooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool01?l0003ooooooooo
ooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool0
0_ooool10000000000<00000ooooooooool0oooooolMooooo`40000000003@00003oooooo`000?oo
oooo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0
003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00_o0000ooooool0003oooooo`000?oo
oooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`0;o`000?oooooo0000ooooool0
003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool0
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02ol0003oooooo`000?oo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0
003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0
003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000002ooooo`0;o`000?oooooo0000ooooool0003oooooo`000?oo
oooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0
003oooooo`000?oooooo0000ooooool000000_ooool02ol0003oooooo`000?oooooo0000ooooool0
003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00_o0000ooooool0003oooooo`000?oo
oooo0000ooooool0003oooooo`000002ooooo`03o`000?oooooo000000?ooooo0@00000000030000
0?oooooooooo0?oooooo7Oooool10000000000@00000oooooooooooooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool2o`00007ooooo0@000000000300000?oooooooooo0?oooooo
7Oooool10000000000<00000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`00
00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04
o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool00ol0003oooooooooo`0100000000
00/00000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0
003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`00
00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0
003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00So0000ooooool0
003oooooo`000?oooooo0000ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000
000400000?oooooo0000o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo0_l00004ooooo`40000000000`00003oooooooooo`3ooooo
oagooooo0@000000000400000?oooooo0000o`0000?ooooo00Co0000oooooooooooooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000ooo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`02ooooo`4000000000
0`00003oooooooooo`3ooooooagooooo0@000000000400000?oooooo0000o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo
00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`00
00;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`40000000000`00003ooooooooo
o`3ooooooagooooo0@000000000400000?ooooooooooooooo`;o00000oooool2o`0000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0003ooooo0@000000000300000?oo
oooooooo0?oooooo7Oooool10000000000<00000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000;ooooo0@000000000300000?oooooooooo0?oooooo7Oooool10000000000/0
0000ooooooooooooooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2
o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`04o`00
0?oooooo0000ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000000400000?oo
oooo0000o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool00000
0_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2
o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`40000000001000
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00?o0000ooooooooool0
0_ooool10000000000<00000ooooooooool0oooooolMooooo`40000000001000003oooooo`000?l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`40000000000`00003oooooooooo`3o
oooooagooooo0@000000000;00000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool0
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`08o`000?oo
oooo0000ooooool0003oooooo`000?ooool10000000000<00000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000000_ooool10000000000<00000ooooooooool0oooooolMooooo`40000000001000
003oooooooooooooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000Oooool10000000000<00000oooo
ooooool0oooooolMooooo`40000000002@00003oooooo`000?oooooo0000ooooool0003oooooo`00
0002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo
0000ooooool0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000?ooooo0@000000000300000?oooooooooo0?oooooo7Oooool100000000
00@00000ooooool0003o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003o
oooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0@000000000400000?oooooo0000
o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo0@000000000300000?oooooooooo
0?oooooo7Oooool10000000000/00000ooooooooooooooooo`000?oooooo0000ooooool0003ooooo
o`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`0;o`000?oooooo0000
ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02ol0003ooooo
o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00_o0000
ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`0;o`000?oooooo0000ooooool0003ooooo
o`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02ol0003oooooo`000?oooooo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo0000
00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00_o0000ooooool0003ooooo
o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`0;o`000?oooooo0000
ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool02ol0003oooooo`000?oooooo0000ooooool0003ooooo
o`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00So0000
ooooool0003oooooo`000?oooooo0000ooooo`40000000000`00003oooooooooo`02ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?o0000ooooooooool0
0@000000000300000?oooooooooo0?oooooo7Oooool10000000000@00000oooooooooooooooo0_l0
0003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooooooo
ooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00007ooooo0@00
0000000;00000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0
003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0
003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002
ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0
003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool0
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oo
oooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002
ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0
003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool0
00000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0
003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0
003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oo
oooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0
003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000ooooool0
00000oooool10000000000<00000ooooooooool0oooooolMooooo`40000000001000003oooooo`00
0?l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04
o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool00_ooool10000000000@0
0000ooooool0003o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool00_ooool10000
000000<00000ooooooooool0oooooolMooooo`40000000003@00003oooooo`000?oooooo0000oooo
ool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`00
0?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000oooo
ool0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`0;o`000?oooooo0000ooooool0003oooooo`00
0?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000oooo
ool0003oooooo`000002ooooo`09o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`00
0?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`00
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`09o`000?oooooo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000oooo
ool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool02ol0003oooooo`000?oooooo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Wo0000ooooool0003oooooo`000?oooooo0000oooo
ool000000_ooool01Ol0003oooooo`000?oooooo000000?ooooo0@000000000400000?oooooooooo
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00001ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@00000000030000
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?o
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003ooooooooo
ooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000000oooool2o`0000?ooooo00?o0000ooooooooool00@000000000;00000?oooooooooooooo
ool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00_o0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00_o0000ooooool0003o
ooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`0;o`000?oooooo
0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`08o`000?oooooo
0000ooooool0003oooooo`000?ooool10000000000<00000ooooooooool0oooooolMooooo`400000
00001000003oooooo`000?l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool00000
0_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o0000
1?ooool10000000000@00000ooooool0003o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0@0000000004
00000?oooooo0000o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000003ooooo`40000000001000003oooooooooooooool2o`0000?ooooo0_l00002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00Co0000ooooool0
003ooooo0@000000000300000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
0oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000;ooooo0@00
0000000300000?oooooooooo0?oooooo7Oooool10000000000/00000ooooooooooooooooo`000?oo
oooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0
003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0
003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`04o`000?oooooo0000ooooo`40
000000001000003oooooo`000?l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo00?o0000ooooool000000oooool10000000000@00000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo
0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000000oooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo0@000000000400000?oooooo0000o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`40000000002`00003ooooooooooooooooo
0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000oooo
ool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool0
2?l0003oooooo`000?oooooo0000ooooool0003ooooo0@000000000300000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2o`00
00?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o
00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000000oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000;ooooo0@000000000400000?ooooooooooooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000Oooool10000000000@00000ooooool0003o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000?ooooo0@000000000400000?oooooo0000o`0000?ooooo00Co0000oooo
oooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`05o`000?ooooooooooooooool000000oooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003ooooooooo
o`02ooooo`40000000001000003oooooo`000?l00003ooooo`;o00000_ooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000_ooool2o`0000Cooooo0@000000000400000?ooooooooooooooo`?o000000Co
ooooo`000?l0003o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001Ooooooo
0000o`000?l0003ooooo00?o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol00000
1?oooooo0000o`000?l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo
0ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`00
0005ooooool0003o0000o`000?ooool00ol00002ooooo`?o000000Coooooo`000?l0003o00000_oo
ool3o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o
000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo0ol000001?oooooo0000o`000?l00002
ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000005ooooool0003o0000o`000?ooool0
0ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000004ooooool0003o0000o`00
00;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool3o`000004ooooool0003o
0000o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o
00000_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`00
0?l0003o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001Ooooooo0000o`00
0?l0003ooooo00?o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001Ooooooo
0000o`000?l0003ooooo0040000000001000003oooooooooooooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00001ooooo`40000000000`00003oooooo`000002o`000005ooooool0
003o0000o`000?ooool01?l000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool3o`000004
ooooool0003o0000o`0000;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co000000Gooooo
o`000?l0003o0000ooooo`03o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o0000
00Goooooo`000?l0003o0000ooooo`04o`000005ooooool0003o0000o`000?ooool00ol00002oooo
o`?o000000Coooooo`000?l0003o00000_ooool3o`000005ooooool0003o0000o`000?ooool01?l0
00001Ooooooo0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`03o`0000;o
oooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`04
o`000005ooooool0003o0000o`000?ooool00ol00002ooooo`?o000000Coooooo`000?l0003o0000
0_ooool3o`000005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000o`000?l0003ooooo
00?o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001Ooooooo0000o`000?l0
003ooooo00Co000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo0ol000001?oooooo0000
o`000?l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`04o`000005ooooool0003o0000
o`000?ooool01?l000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool3o`000004ooooool0
003o0000o`0000;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co000000Coooooo`000?l0
003o00000oooool10000000000<00000ooooool000000_l000001Ooooooo0000o`000?l0003ooooo
00Co000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo0ol000001?oooooo0000o`000?l0
0002ooooo`?o000000Goooooo`000?l0003o0000ooooo`04o`000005ooooool0003o0000o`000?oo
ool00ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000005ooooool0003o0000
o`000?ooool01?l000001Ooooooo0000o`000?l0003ooooo00?o00000_ooool3o`000004ooooool0
003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Goooooo`000?l0
003o0000ooooo`03o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Cooooo
o`000?l0003o00000_ooool3o`000005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000
o`000?l0003ooooo00?o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001Ooo
oooo0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`03o`0000;ooooo0ol0
00001?oooooo0000o`000?l00002ooooo`?o000000Goooooo`000?l0003o0000ooooo`04o`000005
ooooool0003o0000o`000?ooool00ol00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3
o`000004ooooool0003o0000o`0000;ooooo0ol000001Ooooooo0000o`000?l0003ooooo00?o0000
0_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000o`000?l00002oooo
o`?o000000Goooooo`000?l0003o0000ooooo`04o`000004ooooool0003o0000o`0000?ooooo0@00
0000000400000?ooooooooooooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000Oooool10000000000<0
0000ooooool000000_l000001Ooooooo0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o
0000ooooo`04o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000o`000002o`00
0005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000o`000?l0003ooooo00Co000000Go
ooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000;o000000Goooooo`000?l0003o
0000ooooo`04o`000005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000o`000?l0003o
oooo00So000000Goooooo`000?l0003o0000ooooo`04o`000005ooooool0003o0000o`000?ooool0
1?l000001Ooooooo0000o`000?l0003ooooo00So000000Goooooo`000?l0003o0000ooooo`04o`00
0005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000o`000?l0003ooooo00Co000000Go
ooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000;o000000Goooooo`000?l0003o
0000ooooo`04o`000005ooooool0003o0000o`000?ooool01?l000001Ooooooo0000o`000?l0003o
oooo00?o000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00Co000000Go
ooooo`000?l0003o0000ooooo`04o`000005ooooool0003o0000o`000?ooool02?l000001Ooooooo
0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`04o`000005ooooool0003o
0000o`000?ooool02?l000001Ooooooo0000o`000?l0003ooooo00Co000000Goooooo`000?l0003o
0000ooooo`04o`000007ooooool0003o0000o`000?oooooo0000ooooo`010000000000<00000oooo
ool00000ool0000Lo`00007ooooo0@000000000300000?oooooooooo0?oooooo7Oooool100000000
o`00000Q00000000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000l0039n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0bOSkdHTn2P8WKKW`omjLCa<06eZXi_oZ[V0O0119UM[nlkmc
;0<8>8?<nO[>QS/90bY`_?;ng9Q<4P0MGJ_XonR[GAd04TbHg?kb_70Z0`TkQ/kj
nLb3>0P3;7>olokJUDT@01mP[^[oiZQJ6`0CCicNoo2iKBL22Sj9dO_hbH0f1`@^
M/7eoMRBAPl08F>ak?oTYELI01EAWn3okkIZ9@4<@8cCo?O7O3<61C5ia?KleHm3
3@4SIk?]on:RE1L05eBRh_o]/fLS0@e3SmGlm/Ai<@D6<gc7mocCS40<0BEZ]^oo
h9mA5@0IEjGTonbaHb403dJBf?ge`GH^10LfP<Whnm69?PX29ffil?oNW4lC01]J
Z>KojZiP7`0@BIGJo_>oLb`323R3c?WjcXHk2@<ZL;cbo]bHC1807Ef[j?oXZedM
019<V=cnl[a`:P<9>hK>n_W<PcP80bac_o?nfYE9400OH:kZonJXFQ/04dnLg_o`
^FdW0PXnRM7kn<V0=PL4;WK1mOgHTTH?025S/Ncoi:EG6@0EDIoPonnfJRD1342<
docgag`c1PDaNLCfo=F?@`d18fNckOoRXU@G01MDX^;okK=W8`4=@hoEo?K4NC45
1S=laoOldha0304UJ[K_on2ODAD06ENUi?o//F<Q00m6T]SmmL5f;P@7=X39n?_A
RCh:0RM]^O3ogYa?4`0KFZSVonZ^H1l044VEf_kc_g</0`PhPlcin/j6>`T3:W2l
l_kLV4`B01eMZnSoj:]M7@0BC9SLo_:lL2X32C^6c_[ic8<h20</Lkoco]ZEBA00
7f2^j_oVZ5XK01=?W=kol;U]9`8:?XWAnoS9P3H712if`OGmf9963`0QHk7/onBU
EaT05E6Oh?o_]VXU0@a0S=?lmlMl<`H5<GW4m_cESd<=0B=W/ngohZ9D5`0GE:;R
onfcIb<13D>?eOcfa7Ta1@HcO<Ogo=><@0`19FZfkooPWe4E01UGYNCok;5S8@0?
AY;HoOG1MRh41cJ0\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2KHz sine wave", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Play[Sin[2  \[Pi]\ 2000\ t], {t, 0, 2}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`00000Q
0000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooo`00003oo`0001co
00000Oooool10000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oo
oooo00000?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool1
0000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo
00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000000000<0
0000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo00007?l00001
ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000000000<00000ooooool0
0000ool0000Lo`00007ooooo0@000000000300000?oooooo00000?oo00007?l00001ooooo`400000
00000`00003oooooo`00003oo`0001co00000Oooool10000000000<00000ooooool00000ool0000L
o`00007ooooo0@000000000300000?oooooo00000?oo00007?l00001ooooo`40000000000`00003o
ooooo`00003oo`0001co00000Oooool10000000000<00000ooooooooool0oooooolMooooo`400000
003o00000240000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooo0000
0?oo00007?l00001ooooo`40000000001000003oooooo`000?ooool4o`000003ooooool0003o0000
00Ko000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Ko000000?oooooo`000?ooool00_l000000ooooooo0000o`000003o`000004ooooool0003o0000
ooooo`[o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000003ooooool0003o
000000Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`000003ooooool0003o
000000So000000Coooooo`000?l0003ooooo1Ol000001_oooooo0000o`000?oooooo0000ooooo`So
000000?oooooo`000?l000002ol000000ooooooo0000o`000006o`000003ooooool0003o000000;o
000000?oooooo`000?l000001_l000000ooooooo0000ooooo`02o`000003ooooool0003o000000?o
000000Coooooo`000?l0003ooooo2_l000000ooooooo0000o`000006o`000003ooooool0003o0000
00;o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000003ooooool0003o0000
00Ko000000?oooooo`000?l000002?l000001?oooooo0000o`000?ooool5o`000006ooooool0003o
0000ooooool0003ooooo2?l000000ooooooo0000o`00000;o`000004ooooool0003o0000ooooo`40
000000000`00003oooooo`000003ooooo`;o000000?oooooo`000?l000001?ooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`000003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l00000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo0000
o`000004ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?oooooo
oooo0@000000000300000?oooooooooo00Ko000000?oooooo`000?ooool00_l000001ooooooo0000
ooooool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`06o`000003ooooool0003ooooo
00Ko000000?oooooo`000?l000001?l000000ooooooo0000o`000006o`000003ooooool0003o0000
00;o000000?oooooo`000?ooool01_l000000ooooooo0000ooooo`04o`000005ooooool0003ooooo
o`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Co000000?oooooo`000?ooool01_l0
00000ooooooo0000ooooo`04o`000003ooooool0003o000000Ko000000?oooooo`000?l000001?l0
00000ooooooo0000o`000004o`000003ooooool0003ooooo00Ko000000?oooooo`000?ooool00_l0
00001ooooooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo
00Co000000?oooooo`000?ooool01_l000000ooooooo0000o`000004o`000003ooooool0003o0000
00Ko000000?oooooo`000?l000000_l000000ooooooo0000ooooo`06o`000003ooooool0003ooooo
00Co000000Goooooo`000?oooooo0000ooooo`02o`000005ooooool0003oooooo`000?ooool01?l0
00000ooooooo0000ooooo`06o`000003ooooool0003ooooo00go000000?oooooo`000?l000001?l0
00000ooooooo0000o`000004o`000003ooooool0003ooooo00Ko000000?oooooo`000?ooool00_l0
00001ooooooo0000ooooool0003oooooo`000?ooool00@000000000400000?oooooo0000ooooo`;o
00000_ooool2o`000003ooooool0003o000000;o000000Goooooo`000?oooooo0000ooooo`04o`00
0003ooooool0003o000000;ooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo0ol00002oooo
o`;o00000_ooool3o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`000003ooooool0003ooooo
00;o00000_ooool2o`000003ooooool0003o000000;o000000Goooooo`000?oooooo0000ooooo`04
o`000005ooooool0003oooooo`000?ooool01?l000000ooooooo0000o`000002ooooo`;o000000?o
ooooo`000?ooool00_l00002ooooo`?o00000_ooool2o`0000;ooooo0ol00002ooooo`;o00000_oo
ool3o`0000;ooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo0_l000000ooooooo0000o`00
0002o`000005ooooool0003oooooo`000?ooool01?l000000ooooooo0000o`000002ooooo`;o0000
00?oooooo`000?ooool00_l00002ooooo`?o00000_ooool2o`0000;ooooo0ol00002ooooo`;o0000
0_ooool3o`0000;ooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo0_l000000ooooooo0000
o`000002o`0000;ooooo0_l000000ooooooo0000o`000002o`000005ooooool0003oooooo`000?oo
ool01?l000000ooooooo0000o`000002ooooo`;o000000?oooooo`000?ooool00_l00002ooooo`?o
00000_ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo
0000ooooo`02o`0000;ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003oooooo`00
00;ooooo0@000000000300000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co
0000ooooool0003ooooo0_l00003ooooo`06o`000?oooooo0000o`000?oooooo00000oooool2o`00
0004ooooool0003oooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo
00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0
003ooooo0_l00003ooooo`06o`000?oooooo0000o`000?oooooo00000oooool2o`000004ooooool0
003oooooo`0000?ooooo0_l000001?oooooo0000ooooool00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`04o`000?oooooo0000ooooo`;o00000oooool01_l0003oooooo`000?l0003oooooo`00
00?ooooo0_l000001?oooooo0000ooooool00002ooooo`07o`000?oooooo0000ooooool0003ooooo
o`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000
ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04
o`000?oooooo0000ooooo`;o00000oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo0_l0
00001?oooooo0000ooooool00003ooooo`;o000000Coooooo`000?oooooo00000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0@00
0000000300000?oooooo000000;o000000Koooooo`000?l0003oooooo`000?ooool3o`000004oooo
ool0003o0000ooooo`;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000?ooooo
o`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`?o000000Cooooo
o`000?l0003o00000_ooool4o`000003ooooool0003o000000;ooooo1?l000001_oooooo0000o`00
0?oooooo0000ooooo`?o000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2
o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?ooool00_l000000ooooooo0000o`00
0002o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol000001?oooooo0000o`00
0?l00002ooooo`Co000000?oooooo`000?l000000_ooool4o`000006ooooool0003o0000ooooool0
003ooooo0ol000001?oooooo0000o`000?ooool2o`000007ooooool0003o0000o`000?oooooo0000
ooooo`02o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000;o0000
0_ooool2o`000003ooooool0003o000000;o00000_ooool4o`000003ooooool0003o000000;ooooo
1?l000001_oooooo0000o`000?oooooo0000ooooo`?o000000Coooooo`000?l0003ooooo0_l00000
1?oooooo0000o`000?ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?ooool0
0_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0ol000001?oooooo0000o`000?l00002ooooo`Co000000?oooooo`000?l000000_ooool4o`000006
ooooool0003o0000ooooool0003ooooo0ol000001Ooooooo0000o`000?oooooo000000;ooooo0@00
0000000500000?ooooooooooo`000?ooool00_l000001ooooooo0000ooooool0003oooooo`000?oo
ool00_l000000ooooooo0000ooooo`02o`000007ooooool0003oooooo`000?oooooo0000ooooo`02
o`000005ooooool0003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Co0000
00Goooooo`000?oooooo0000ooooo`04o`000005ooooool0003oooooo`000?ooool01?l000001Ooo
oooo0000ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`02o`000005ooooool0
003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00;o000000Ooooooo`000?oo
oooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool01?l000001Ooooooo0000ooooool0
003ooooo00Co000000Goooooo`000?oooooo0000ooooo`04o`000005ooooool0003oooooo`000?oo
ool00_l000001Ooooooo0000ooooool0003ooooo00;o000000Ooooooo`000?oooooo0000ooooool0
003ooooo00;o000000?oooooo`000?ooool00_l000001ooooooo0000ooooool0003oooooo`000?oo
ool00_l000001Ooooooo0000ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`04
o`000005ooooool0003oooooo`000?ooool01?l000001Ooooooo0000ooooool0003ooooo00Co0000
00Goooooo`000?oooooo0000ooooo`02o`000005ooooool0003oooooo`000?ooool00_l000001Ooo
oooo0000ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`02o`000007ooooool0
003oooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00Co000000Goooooo`000?oo
oooo0000ooooo`04o`000005ooooool0003oooooo`000?ooool01?l000001Ooooooo0000ooooool0
003ooooo00;o000000Goooooo`000?oooooo0000ooooo`02o`000007ooooool0003oooooo`000?oo
oooo0000ooooo`02o`000005ooooool0003oooooo`000?ooool00@000000000300000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003ooooo
0@000000000300000?oooooo000000?o00000_ooool2o`000003ooooool0003o000000;o000000Go
ooooo`000?oooooo0000ooooo`04o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000
o`000002ooooo`?o00000_ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool3o`0000;ooooo
0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`000003oooo
ool0003o000000;o000000?oooooo`000?l000000_ooool4o`000003ooooool0003o000000;ooooo
0ol00002ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo
0ol00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002ooooo`Co0000
00?oooooo`000?l000000_ooool3o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo
0ol00002ooooo`;o00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo1?l000000ooooooo0000
o`000002ooooo`?o00000_ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool3o`0000;ooooo
0_l00002ooooo`?o00000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`000003oooo
ool0003o000000;o00000_ooool2o`0000;ooooo0@000000000300000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003o
oooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2o`000004ooooool0003ooooo
o`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`;o000000Coooooo`000?oooooo0000
0_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003o
ooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`;o000000Cooooo
o`000?oooooo00000oooool2o`000004ooooool0003oooooo`0000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo0_l00003oooo
o`04o`000?oooooo0000ooooo`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo0_l0
00001?oooooo0000ooooool00003ooooo`;o000000Coooooo`000?oooooo00000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool2
o`0000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo0000
0oooool2o`000004ooooool0003oooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`40000000000`00003oooooo`000003
ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000003ooooool0003o000000?ooooo00Co
0000ooooool0003ooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000004
ooooool0003oooooo`0000?ooooo0_l000001?oooooo0000ooooool00002ooooo`04o`000?oooooo
0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000
ooooool00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000003ooooool0003o0000
00?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`000004ooooool0003oooooo`0000?ooooo0_l000001?oooooo0000ooooool00002ooooo`04
o`000?oooooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00000
1?oooooo0000ooooool00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004oooo
ool0003oooooooooo`40000000000`00003oooooooooo`02o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0@000000000500000?oooooooooo
o`000?ooool00_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2o`000004ooooool0
003oooooo`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`;o000000Coooooo`000?oo
oooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000oooo
ool0003ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000ooooool0
0003ooooo`;o000000Coooooo`000?oooooo00000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`00
0?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000oooo
ool0003ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0
003oooooo`0000?ooooo0_l000001?oooooo0000ooooool00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`00
0?oooooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo0_l000001?oooooo0000ooooool0
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`00
0?oooooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo0Ol00001oooo
o`40000000000`00003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Ko0000ooooooooooooooooo`000?oo
ool10000000000H00000oooooooooooo0000ooooool00002ooooo`;o000000Goooooo`000?oooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Go
ooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0
003o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o000000Goooooo`000?ooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Goooooo`000?oo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00000_oo
ool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_oo
ool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_oo
ool00ol0003oooooo`000002ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`04o`00
0?ooooooooooooooo`40000000000`00003oooooooooo`02o`0000;ooooo00?o0000ooooool00000
0_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool00000
0_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o
0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01_l0003o
ooooooooool0003oooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`40000000000`00003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01?l0003oooooooooool00006ooooo`40000000000`00003oooooo`000003ooooo`;o0000
00Coooooo`000?oooooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool0
1?l0003oooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003oooooo`0000?o
oooo0_l000001?oooooo0000ooooool00003ooooo`;o000000Coooooo`000?oooooo00000_ooool0
1?l0003oooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`00
0?oooooo0000ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo0_l000001?oooooo0000ooooool00003ooooo`;o000000Coooooo`000?oooooo00000_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool2o`0000?o
oooo00Co0000ooooool0003ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo0_l000001?oooooo0000ooooool0
0003ooooo`;o000000Coooooo`000?oooooo00000_ooool01?l0003oooooo`000?ooool2o`0000?o
oooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000ooooool0
0003ooooo`;o000000Coooooo`000?oooooo00000_ooool01Ol0003oooooo`000?oooooo000000;o
oooo0@000000000300000?oooooooooo00;o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooooooool10000000000H00000oooooooooooo0000ooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003o
ooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0
003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0
003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo0@00000000030000
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool2o`0000;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`06o`000?ooooooooooooooool0003ooooo0@000000000600000?ooooooooooo`000?oo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
00001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l000001Ooooooo0000oooo
oooooooo000000;ooooo00Co0000oooooooooooooooo0@000000000300000?oooooooooo00;o0000
1oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o0000
1oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o0000
1oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o0000
1oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool10000000000<00000ooooooooool01?oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00;ooooo0@000000000300000?oooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02o`0000Cooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_l00004oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`04o`000?ooooooooooo`0000Kooooo0@000000000300000?oooooooooo00Cooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000002ooooo`40000000000`00
003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co
0000oooooooooooooooo0@000000000600000?ooooooooooo`000?oooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001Oooool01?l0003oooooooooool00006ooooo`40000000000`00003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001?ooool01_l0003ooooooooooooooooo0000ooooo`40000000001@00003oooooooooool0
003ooooo00;o00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo0_l000001?oooooo0000
ooooool00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0003ooooo
o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`000?oooooo
0000ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo0000
0oooool2o`000004ooooool0003oooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003o
oooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2
o`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`;o000000Coooooo`000?oooooo0000
0oooool2o`000004ooooool0003oooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003o
oooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0003oooooo`0000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o0000
0oooool01?l0003oooooo`000?ooool2o`0000?ooooo0Ol00001ooooo`40000000000`00003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`40
000000000`00003oooooooooo`02o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool10000000000<00000ooooool000000oooool2o`000004ooooool0
003oooooo`0000?ooooo0_l000000ooooooo0000o`000003ooooo`04o`000?oooooo0000ooooo`;o
00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000ooooool00003
ooooo`;o000000Coooooo`000?oooooo00000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo
00Co0000ooooool0003ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`00
0004ooooool0003oooooo`0000?ooooo0_l000001?oooooo0000ooooool00002ooooo`04o`000?oo
oooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo
0000ooooool00003ooooo`;o000000Coooooo`000?oooooo00000_ooool01?l0003oooooo`000?oo
ool2o`0000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo
00000oooool2o`000004ooooool0003oooooo`0000?ooooo0_l000001?oooooo0000ooooooooool1
0000000000<00000ooooool000000_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool1
0000000000<00000ooooooooool01?ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00;ooooo0@000000000300000?oooooooooo00;o00001oooool2o`0000Oooooo0_l00007ooooo`;o
00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o
00001oooool2o`0000Oooooo0@000000000300000?oooooo000000;ooooo00?o0000ooooooooool0
0_l000001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooo`000?l00002ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l000001Ooooooo0000oooo
oooooooo000000;ooooo0_l000001_oooooo0000oooooooooooo0000ooooo`;o00000_ooool01Ol0
003oooooooooool0003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Go
ooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0
003o00000_ooool01Ol0003oooooooooool0003ooooo00;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o000000Goooooo`000?ooooooooooo`00
0002ooooo`;o000000Koooooo`000?ooooooooooo`000?ooool2o`0000;ooooo00Go0000oooooooo
oooo0000ooooo`02o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000oooo
ool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000oooo
ool000000_ooool2o`000005ooooool0003oooooooooool000000_ooool2o`000005ooooool0003o
ooooooooool000000_ooool2o`0000;ooooo0@000000000300000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01_l0003ooooooooooooooooo0000ooooo`40000000000`00003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Ko0000ooooooooooooooooo`000?ooool10000000000H00000oooo
oooooooo0000ooooool00006ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooool000001Oooool00ol0003oooooo`000006ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`40000000000`00003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2
o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2
o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooooooool10000000000<00000ooooooooool00_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo0_l000001Ooooooo0000oooo
oooooooo000000;ooooo0_l000001_oooooo0000oooooooooooo0000ooooo`;o00000_ooool01Ol0
003oooooooooool0003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`;o000000Ko
ooooo`000?ooooooooooo`000?ooool2o`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`00
00;ooooo00Go0000oooooooooooo0000ooooo`02o`0000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2
o`000005ooooool0003oooooooooool000000_ooool2o`000005ooooool0003oooooooooool00000
0_ooool2o`000006ooooool0003oooooooooool0003ooooo0_l00002ooooo`05o`000?oooooooooo
o`000?ooool00_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo0_l000002ooooooo0000oooo
oooooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003o00000_oo
ool01Ol0003oooooooooool0003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`40000000000`00003oooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000005ooooo`4000000000
0`00003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000<00000ooooooooool01?ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo0_l00006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool2o`0000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000000_ooool1
0000000000D00000ooooooooooooooooo`000007ooooo`;o00001oooool2o`0000Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007
ooooo`40000000000`00003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooo`000006oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006oooo
o`03o`000?oooooo000000;ooooo0@000000000300000?oooooo000000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
000000Coooooo`000?oooooo00000oooool2o`000003ooooool0003o000000Cooooo0_l000000ooo
oooo0000o`000003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
0003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`04o`000?oooooo0000
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000ooo
ool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo
0_l000000ooooooo0000o`000003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2o`0000;o
oooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0Ol00001ooooo`40000000000`00003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01_l0003o
oooooooooooooooo0000ooooo`40000000001P00003oooooooooool0003oooooo`0000Kooooo0_l0
0007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo0_l0
0007ooooo`40000000000`00003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007
ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`4000000000
0`00003oooooooooo`02o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006
ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Kooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000
ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool10000000000<00000ooooooooool01?ooool00ol0003oooooo`000006oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool00ol0
003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006oooo
o`03o`000?oooooo000000;ooooo0@000000000300000?oooooo000000?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Gooooo0@000000000300000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Ko0000ooooool0003o0000ooooool00003ooooo`06o`000?oooooo0000o`000?oooooo0000
0oooool2o`000004ooooool0003oooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co
0000ooooool0003ooooo0_l00003ooooo`06o`000?oooooo0000o`000?oooooo00000oooool01_l0
003oooooo`000?l0003oooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Ko0000ooooool0003o0000ooooool00003ooooo`06
o`000?oooooo0000o`000?oooooo00000oooool2o`000004ooooool0003oooooo`0000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Ko
0000ooooool0003o0000ooooool00003ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0@000000000300000?oooooooooo
0?oooooo7Oooool10000000000D00000ooooooooooooooooo`000003ooooo`;o00000_ooool2o`00
00;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`00
00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01_l0003oooooooooool0003oooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000
oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000_ooool00ol0
003oooooo`000002ooooo`40000000000`00003oooooo`000002ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000<00000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Ko0000ooooooooooooooooo`000?ooool10000000000<00000oooooooo
ool01?ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00001?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001?ooool01_l0003ooooooooooooooooo0000ooooo`4000000000
1P00003oooooooooool0003oooooo`0000Kooooo0_l00007ooooo`;o00001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo
0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo
0@000000000300000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l0
0007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooooooo0@000000000300000?oooooooooo00;o00001oooool2o`0000Oooooo0_l0
0007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l0
0007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`;o00001oooool2o`0000Oooooo0@000000000300000?oooooooooo00Cooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000002ooooo`40000000000`00
003oooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`4000000000
0`00003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000D00000
ooooooooooooooooo`000002ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`07o`000?oooooo
ooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co
0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool01_l0003oooooooooool0003oooooo`0000;ooooo00Oo0000
ooooooooooooooooo`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00;ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000ooo
ool01?l0003oooooooooooooool2o`0000?ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool2o`0000;ooooo00?o0000ooooool000000_oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooooooool2o`00
00?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000ooo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool10000000000<00000ooooooooool0oooo
oolMooooo`40000000000`00003oooooooooo`04ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000002
ooooo`40000000000`00003oooooo`000002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool00_l00004oooo
o`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000Cooooo00?o0000oooo
ooooool00_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo
00;ooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo00;o00001?ooool00ol0
003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00002oooo
o`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000004ooooo`03o`000?oooooooooo
00;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0Ol00001oooo
o`40000000000`00003oooooooooo`3ooooooagooooo0@000000000300000?oooooooooo00;o0000
0_ooool01Ol0003oooooooooool0003ooooo00;o000000?oooooo`000?ooool00_ooool01_l0003o
ooooo`000?l0003oooooo`0000;ooooo00?o0000ooooooooool00_l000002ooooooo0000oooooooo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0
003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003o00000_ooool01Ol0003ooooooooo
ool0003ooooo00;o000000Goooooo`000?ooooooooooo`000002ooooo`;o000000_oooooo`000?oo
ooooooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0
003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oo
oooo0000ooooool0003oooooo`000002ooooo`04o`000?oooooo0000o`0000;ooooo00Go0000oooo
oooooooo0000ooooo`02o`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`000005ooooool0
003oooooooooool000000_ooool2o`00000;ooooool0003oooooooooool0003oooooo`000?oooooo
0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003o
ooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool00000
0_ooool01?l0003oooooo`000?l00002ooooo`05o`000?ooooooooooo`000?ooool00_l000001Ooo
oooo0000oooooooooooo000000;ooooo0_l000002ooooooo0000oooooooooooo0000ooooool0003o
ooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Co0000ooooool0003o00000_ooool01Ol0003oooooooooool0003ooooo00;o0000
0_ooool01Ol0003oooooooooool0003ooooo0040000000000`00003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00Co0000oooooooooooooooo0@000000000300000?oooooooooo00;o0000
1oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o0000
1oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o0000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o0000
1_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool00000
1_ooool2o`0000Oooooo0_l00007ooooo`40000000000`00003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000_ooool1
0000000000<00000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool10000
000000<00000ooooool000000_ooool2o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`03
o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`02o`0000Cooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o00001?ooool0
0ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooo
oooo00;o00001?ooool00ol0003oooooooooo`02o`0000Cooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000oooooooo
ool00_l00004ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`02o`0000Co
oooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00001?ooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_l00004
ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000
ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00001?ooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000ooooool0003o00001?ooool00ol0003o
ooooooooo`02o`0000Cooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o
00001Oooool10000000000<00000ooooooooool01?ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o0000
1oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o0000
1oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000000_ooool10000000000D00000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`40000000000`00003oooooooooo`04ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l0
0007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l0
0007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000000_ooool10000000000<00000
ooooool000000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Kooooo0@000000000300000?oooooo000000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo0@000000000300000?oooooooooo00Cooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000002ooooo`40
000000000`00003oooooooooo`02o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo
0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo
0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`40000000000`00003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l0
0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ooooool10000000000<00000ooooooooool00_l00007ooooo`;o00001oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool10000000000<00000
ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oo
oooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00001?oo
ool00ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02o`0000Cooooo
00?o0000ooooooooool00_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000Cooooo
00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool10000
000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?oooooo0000o`00
00;ooooo00Go0000oooooooooooo0000ooooo`02o`0000;ooooo00?o0000ooooool000000_ooool2
o`000005ooooool0003oooooooooool000000_ooool2o`000005ooooool0003oooooooooool00000
0_ooool2o`00000;ooooool0003oooooooooool0003oooooo`000?oooooo0000ooooool000000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?l00002oooo
o`05o`000?ooooooooooo`000?ooool00_l00002ooooo`05o`000?ooooooooooo`000?ooool00_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo
0_l000002ooooooo0000oooooooooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo
000000;ooooo00Co0000ooooool0003o00000_ooool01Ol0003oooooooooool0003ooooo00;o0000
0_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
00Goooooo`000?ooooooooooo`000002ooooo`;o000000_oooooo`000?ooooooooooo`000?oooooo
0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002oooo
o`04o`000?oooooo0000o`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`0000;ooooo00Go
0000oooooooooooo0000ooooo`02o`0000;ooooo00?o0000ooooool000000_ooool2o`000005oooo
ool0003oooooooooool000000_ooool2o`00000;ooooool0003oooooooooool0003oooooo`000?oo
oooo0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo0@00000000050000
0?ooooooooooooooool000001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oo
oooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool2o`0000Oooooo0@000000000300000?oooooooooo00Cooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000;ooooo
0@000000000300000?oooooo000000;ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0
003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Kooooo
0@000000000300000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo0@000000000300000?oooooooooo00Cooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo
000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooo`000002ooooo`40000000000`00003oooooooooo`02o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool2o`0000Oooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000006
ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007
ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo0_l00007
ooooo`;o00001oooool2o`0000Oooooo0@000000000300000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007oooo
o`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
oooooooooooo0@000000000600000?ooooooooooo`000?oooooo00001_ooool2o`0000Oooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`40000000000`00003oooooooooo`04
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool100000000
00<00000ooooool000000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000o`000003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool2o`000003ooooool0003o000000Cooooo0_l000000ooooooo0000
o`000003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l000000ooooooo0000o`000004ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000004ooooo`;o000000?oooooo`000?l000000oooool01?l0003oooooo`000?ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`7o00000Oooool10000
000000<00000ooooooooool0oooooolMooooo`40000000001@00003ooooooooooooooooo000000?o
oooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool01?l0003o
ooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool10000000000<00000ooooooooool01?ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo0_l00006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo
0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000;ooooo0@000000000300000?oooooo000000;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000<0
0000ooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001Oooool10000000000<00000ooooooooool00_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo0_l00000
2ooooooo0000oooooooooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooo
ool0003o00000_ooool01Ol0003oooooooooool0003ooooo00;o00000_ooool01Ol0003ooooooooo
ool0003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o000000Goooooo`000?oooooo
ooooo`000002ooooo`;o000000_oooooo`000?ooooooooooo`000?oooooo0000ooooool0003ooooo
o`000002ooooo`04o`000?oooooo0000o`0000;ooooo00Go0000oooooooooooo0000ooooo`02o`00
00;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`00
00;ooooo00?o0000ooooool000000_ooool2o`000005ooooool0003oooooooooool000000_ooool2
o`00000;ooooool0003oooooooooool0003oooooo`000?oooooo0000ooooool000000_ooool01?l0
003oooooo`000?l00002ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`05o`000?oo
ooooooooo`000?ooool00_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l000001Ooooooo0000
oooooooooooo000000;ooooo0_l000002ooooooo0000oooooooooooo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Co0000ooooool0003o00000_ooool01Ol0003oooooooooool0003ooooo
00;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`40000000000`00003oooooooooo`3ooooooagooooo0@000000000600000?ooooooooooo`000?oo
oooo00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01ol0003ooooo
oooooooooooo0000ooooool000000_ooool01?l0003oooooooooooooool2o`0000?ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool2o`00
00;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`00
00;ooooo00?o0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooooooool2o`00
00?ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`06o`000?ooooooooooo`000?oooooo
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool01?l0003oooooooooooooool2o`0000?ooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01ol0003ooooo
oooooooooooo0000ooooool000000_ooool01?l0003oooooooooooooool10000000000<00000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool0
1_l0003ooooooooooooooooo0000ooooo`40000000000`00003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01_l0003ooooooooooooooooo0000ooooo`40000000000`00003o
ooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000<00000oooo
ooooool00_l00003ooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`00
00;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003
ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo
00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`;o
00000oooool2o`0000;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0
003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool2o`00
00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0@000000000300000?oooooooooo0?oooooo7Oooool10000
000000<00000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool0
1ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003ooooo0_l0
0003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0003oooooo`0000;o
oooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`00
0?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`00
0?oooooo0000ooooo`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo0_l000001?oo
oooo0000ooooool00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07o`00
0?oooooo0000ooooool0003oooooo`000002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0002ooooo`04o`000?oooooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000?o
oooo00Ko0000ooooool0003o0000ooooool00003ooooo`;o000000Coooooo`000?oooooo00000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000
ooooool0003ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004oooo
ool0003oooooo`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Go0000
ooooool0003oooooo`000002ooooo`40000000000`00003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003o
ooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Gooooo0@000000000300000?oooooooooo00Cooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Ko
oooo00?o0000ooooool000001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`00
00Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001_ooool00ol0
003oooooo`000002ooooo`40000000000`00003oooooooooo`02o`0000Oooooo0_l00007ooooo`;o
00001oooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo0_l00007ooooo`;o
00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo0_l00007ooooo`;o
00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o
00001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o
00001oooool2o`0000Kooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`40
000000001P00003oooooooooool0003oooooo`0000;ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`06o`000?ooooooooooo`00
0?oooooo00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000
ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01_l0
003oooooooooool0003oooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l0
0002ooooo`03o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool00000
0_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool00000
0_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01ol0003ooooooooooooooooo
0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04o`00
0?ooooooooooooooo`40000000000`00003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Ko0000oooooooo
ooooooooo`000?ooool10000000000<00000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?oooooo
ooooooooool0003ooooo0@000000000600000?ooooooooooo`000?oooooo00000_ooool2o`000005
ooooool0003oooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
0000o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_oo
ool2o`0000;ooooo00?o0000ooooool000000_ooool2o`000005ooooool0003oooooooooool00000
0_ooool2o`000006ooooool0003oooooooooool0003ooooo0_l00002ooooo`05o`000?oooooooooo
o`000?ooool00_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l000001Ooooooo0000oooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00002ooooo`05
o`000?ooooooooooo`000?ooool00_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooo000000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo0_l00000
1_oooooo0000oooooooooooo0000ooooo`;o00000_ooool01Ol0003oooooooooool0003ooooo00;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o
00000_ooool00ol0003oooooo`000002ooooo`;o000000Goooooo`000?ooooooooooo`000002oooo
o`04o`000?ooooooooooooooo`40000000000`00003oooooooooo`02o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007oooo
o`40000000000`00003oooooooooo`04ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000000_ooool10000000000<00000ooooool000000_ooool2o`0000Cooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00004ooooo`;o00000_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02o`0000Cooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00_l00004ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_l0
0004ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;o00001?ooool01?l0003oooooooooool00006ooooo`40000000000`00003ooooooooo
o`04ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003o
ooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003o
ooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000000_ooool10000000000<00000ooooooooool00_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0
003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo
00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0@000000000600000?ooooooooooo`00
0?oooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooooooo0@000000000300000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003o
oooo0@000000000300000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Ko0000ooooooooooooooooo`000?ooool10000000000H00000oooo
oooooooo0000ooooool00002ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`00
0002ooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000ooooool0003o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0
003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0
003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0
003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003oooooooooool0003ooooo00;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
00Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooooooo`40000000000`00003o
ooooooooo`02o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o
00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o
00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o
00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0@00000000030000
0?oooooo000000?ooooo0_l000001?oooooo0000ooooool00002ooooo`07o`000?oooooo0000oooo
ool0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o00000oooool01?l0003oooooo`00
0?ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
00Coooooo`000?oooooo00000oooool2o`000004ooooool0003oooooo`0000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000ooooool0
0003ooooo`;o000000Coooooo`000?oooooo00000_ooool01ol0003oooooo`000?oooooo0000oooo
ool000000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003ooooo0_l0
0003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o0000
00Coooooo`000?oooooo00000oooool2o`000004ooooool0003oooooo`0000;ooooo00Oo0000oooo
ool0003oooooo`000?oooooo000000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;o
oooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool2
o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000ooooool0
0003ooooo`;o000000Coooooo`000?oooooo00000_ooool01Ol0003oooooo`000?oooooo000000;o
oooo0@000000000300000?oooooo000000?ooooo0_l000001?oooooo0000ooooool00002ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o00000ooo
ool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`;o
00000_ooool2o`0000?ooooo0_l000001?oooooo0000ooooool00003ooooo`;o000000Coooooo`00
0?oooooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000
ooooool0003ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000oooo
ool00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0003oooooo`00
00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo
0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo0_l00000
1?oooooo0000ooooool00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o00000ooo
ool01?l0003oooooo`000?ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0003oooooo`00
00;ooooo00Go0000ooooool0003oooooo`000002ooooo`40000000000`00003oooooooooo`02o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo0_l00007ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`40000000001P00003o
ooooooooool0003oooooo`0000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`00
0?oooooo000000;ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooooooo0@000000
000300000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool2
o`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00_l00004ooooo`04o`000?oooooooooo
o`0000Gooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00_l00004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`06o`000?ooooooooooooooool0003ooooo0@000000000600000?ooooooooooo`000?oo
oooo00001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000006ooooo`40000000000`00003oooooooooo`02
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?o
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o0000
0oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l0
0002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2
o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?ooooooooooooooo`400000
00000`00003oooooo`000003ooooo`;o000000Coooooo`000?oooooo00000_ooool01ol0003ooooo
o`000?oooooo0000ooooool000000_ooool01?l0003oooooo`000?ooool2o`0000?ooooo00Co0000
ooooool0003ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004oooo
ool0003oooooo`0000;ooooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`000?oooooo0000
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`000004ooooool0003oooooo`0000?ooooo0_l000001?oooooo0000oooo
ool00002ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?oooooo0000
ooooo`;o00000oooool01?l0003oooooo`000?ooool2o`0000?ooooo0_l00002ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000oooo
ool00003ooooo`;o000000Coooooo`000?oooooo00000_ooool01?l0003oooooo`000?ooool2o`00
00?ooooo00Co0000ooooool0003ooooo0_l00003ooooo`04o`000?oooooo0000ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l000001?oooooo0000oooo
ool00003ooooo`;o000000Coooooo`000?oooooo00000oooool2o`000004ooooool0003ooooooooo
o`40000000000`00003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003ooooo
ooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00006oooo
o`40000000000`00003oooooooooo`02o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;o
oooo00?o0000ooooool000000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002oooo
o`;o00000_ooool00ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01_l0003oooooooooool0003ooooo
o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03
o`000?oooooo000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool2o`00
00;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool10000
000000<00000ooooool000000_ooool2o`000003ooooool0003o000000;o00000_ooool2o`000003
ooooool0003ooooo00;o00000_ooool4o`000003ooooool0003o000000;ooooo1?l000001_oooooo
0000o`000?oooooo0000ooooo`?o000000Koooooo`000?l0003oooooo`000?ooool4o`000003oooo
ool0003ooooo00;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o000000?oooooo`00
0?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`Co000000?oooooo`00
0?l000000_ooool4o`000006ooooool0003o0000ooooool0003ooooo0ol000001_oooooo0000o`00
0?oooooo0000ooooo`Co000000?oooooo`000?ooool00_l000001ooooooo0000o`000?l0003ooooo
o`000?ooool00_l000000ooooooo0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000002
o`0000;ooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo1?l000000ooooooo0000o`000002
ooooo`Co000000Koooooo`000?l0003oooooo`000?ooool3o`000006ooooool0003o0000ooooool0
003ooooo1?l000000ooooooo0000ooooo`02o`000007ooooool0003o0000o`000?oooooo0000oooo
o`02o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000;o00000_oo
ool4o`000003ooooool0003o000000;ooooo1?l000001_oooooo0000o`000?oooooo0000ooooo`?o
000000Koooooo`000?l0003oooooo`000?ooool3o`000004ooooool0003o0000ooooo`;o000000Oo
ooooo`000?l0003o0000ooooool0003ooooo00;o000000Ooooooo`000?l0003o0000ooooool0003o
oooo00;o000000?oooooo`000?l000000_l00002ooooo`;o000000Goooooo`000?oooooo0000oooo
o`010000000000<00000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00004ooooo`05o`000?oooooo
ooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?ooooooooooooooool0003o
oooo0@000000000600000?ooooooooooo`000?oooooo00000_ooool01ol0003ooooooooooooooooo
0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool0
0ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04o`00
0?ooooooooooooooo`;o00000oooool01_l0003oooooooooool0003oooooo`0000?ooooo00Ko0000
oooooooooooo0000ooooool00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000002oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01_l0003oooooooooool0003oooooo`0000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000;o
oooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooooooo0_l0
0003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01_l0003oooooooooool0003ooooo
o`0000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooo
000000;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000oooooooooooo
oooo0@000000000300000?oooooo000000;o000000Koooooo`000?l0003oooooo`000?ooool3o`00
0004ooooool0003o0000ooooo`;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o0000
00?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
00?oooooo`000?l000000_l00002ooooo`Co000000?oooooo`000?l000000_ooool4o`000006oooo
ool0003o0000ooooool0003ooooo0ol000001_oooooo0000o`000?oooooo0000ooooo`Co000000?o
ooooo`000?ooool00_l000001ooooooo0000o`000?l0003oooooo`000?ooool00_l000000ooooooo
0000o`000002o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo1?l000000ooooooo
0000o`000002ooooo`Co000000?oooooo`000?l000000_ooool4o`000006ooooool0003o0000oooo
ool0003ooooo0ol000001?oooooo0000o`000?ooool2o`000007ooooool0003o0000o`000?oooooo
0000ooooo`02o`000003ooooool0003o000000;o00000_ooool2o`000003ooooool0003o000000;o
00000_ooool2o`000003ooooool0003o000000;o00000_ooool4o`000003ooooool0003o000000;o
oooo1?l000001_oooooo0000o`000?oooooo0000ooooo`?o000000Koooooo`000?l0003oooooo`00
0?ooool3o`000004ooooool0003o0000ooooo`;o000000Ooooooo`000?l0003o0000ooooool0003o
oooo00;o000000?oooooo`000?l000000_l00002ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`Co000000?oooooo`000?l000000_ooool4o`000003ooooool0003o000000;ooooo1?l00000
1_oooooo0000o`000?oooooo0000ooooo`?o000000Goooooo`000?l0003oooooo`000002ooooo`40
000000000`00003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool01?l0003ooooo
ooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001Oooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oo
ooooooooo`0000Gooooo00Co0000oooooooooooo00001_ooool10000000000<00000ooooooooool0
0_l00002ooooo`?o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo
0ol00002ooooo`;o00000_ooool3o`0000;ooooo00Co0000oooooooooooooooo0ol00002ooooo`04
o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`03o`0000?ooooo00?o0000oooo
ooooool00ol00002ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`00
00;ooooo0ol00002ooooo`04o`000?ooooooooooooooo`?o00000_ooool01?l0003ooooooooooooo
ool2o`0000?ooooo00?o0000ooooooooool00ol00003ooooo`03o`000?oooooooooo00?o00000_oo
ool2o`0000;ooooo0ol00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_oo
ool3o`0000;ooooo0_l00002ooooo`?o00000_ooool01?l0003oooooooooooooool3o`0000;ooooo
00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00?o00000oooool00ol0003o
ooooooooo`03o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0ol00002ooooo`;o
00000_ooool3o`0000;ooooo00Co0000oooooooooooooooo0ol00002ooooo`04o`000?oooooooooo
ooooo`;o00000oooool00ol0003oooooooooo`03o`0000?ooooo00?o0000ooooooooool00ol00003
ooooo`03o`000?oooooooooo00?o00000_ooool2o`0000;ooooo00?o0000ooooool000000_ooool1
0000000000D00000ooooool0003o0000ooooo`02o`0000?ooooo1_l00003ooooo`Ko00000oooool2
o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000ooooool00002ooooo`?o0000
00Coooooo`000?l0003o00000_ooool01?l0003oooooo`000?ooool3o`0000;ooooo0ol000001?oo
oooo0000o`000?l00002ooooo`?o000000?oooooo`000?l000000oooool6o`0000?ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000004oooo
ool0003oooooo`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`04o`000?oooooo0000
ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo1_l00003ooooo`Ko00000oooool2
o`000004ooooool0003o0000o`0000;ooooo0ol000001?oooooo0000ooooool00002ooooo`?o0000
00Coooooo`000?l0003o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0ol000001?oo
oooo0000o`000?l00002ooooo`?o000000?oooooo`000?l000000oooool6o`0000?ooooo0_l00000
1?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000004oooo
ool0003oooooo`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`04o`000?oooooo0000
ooooo`?o00000_ooool3o`000003ooooool0003o000000?ooooo0ol000000ooooooo0000o`000003
ooooo`7o00000Oooool10000000000<00000ooooooooool00_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo
0_l00002ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`;o00000oooool01?l0003ooooo
ooooooooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`;o00000_ooool2o`0000?ooooo
0_l00002ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00Co0000oooooooo
oooooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003ooooooooooooo
ool2o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000_ooool00ol0003ooooo
o`000002ooooo`;o00000_ooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`04
o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooooooool10000000000<00000oooo
ool000000_ooool3o`000004ooooool0003oooooo`0000;ooooo0ol000001?oooooo0000o`000?l0
0002ooooo`04o`000?oooooo0000ooooo`?o00000_ooool2o`0000;ooooo0ol00002ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00002ooooo`?o0000
0_ooool2o`0000;ooooo0ol000001?oooooo0000o`000?l00002ooooo`?o000000Coooooo`000?l0
003o00000_ooool2o`0000;ooooo0ol00002ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000oooool2o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0ol000001?oo
oooo0000ooooool00002ooooo`?o000000Coooooo`000?l0003o00000_ooool3o`000004ooooool0
003o0000o`0000;ooooo0_l00002ooooo`?o00000_ooool2o`0000;ooooo0_l00003ooooo`;o0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool3o`0000;ooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00002oooo
o`?o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002oooo
o`;o00000_ooool3o`0000;ooooo0_l00002ooooo`?o000000Coooooo`000?oooooo00000_ooool3
o`000004ooooool0003oooooooooo`40000000001000003oooooo`000?ooool=o`000003ooooool0
003o000000_o000000?oooooo`000?l000001_l000000ooooooo0000o`000002o`000003ooooool0
003o000000?o000000Coooooo`000?l0003ooooo2_l000000ooooooo0000o`00000;o`000003oooo
ool0003o000000Ko000000?oooooo`000?l000002ol000000ooooooo0000o`000008o`000004oooo
ool0003o0000ooooo`Go000000Koooooo`000?l0003oooooo`000?ooool8o`000003ooooool0003o
000000_o000000?oooooo`000?l000002ol000000ooooooo0000o`000006o`000003ooooool0003o
000000;o000000?oooooo`000?l000000ol000001?oooooo0000o`000?ooool:o`000003ooooool0
003o000000Ko000000?oooooo`000?l000000_l000000ooooooo0000o`000006o`000003ooooool0
003o000000_o000000?oooooo`000?l000002?l000001?oooooo0000o`000?ooool5o`000006oooo
ool0003o0000ooooool0003ooooo2?l000000ooooooo0000o`00000;o`000004ooooool0003o0000
ooooo`40000000001`00003oooooooooool0003oooooo`000?ooool00_l000000ooooooo0000oooo
o`02o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`000003ooooool0003ooooo00;o
000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000Goooooo`000?oooooo0000oooo
o`04o`000005ooooool0003oooooo`000?ooool01?l000001Ooooooo0000ooooool0003ooooo00;o
000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_l00000
1ooooooo0000ooooool0003oooooo`000?ooool00_l000001ooooooo0000ooooool0003oooooo`00
0?ooool00_l000000ooooooo0000ooooo`02o`000007ooooool0003oooooo`000?oooooo0000oooo
o`02o`000005ooooool0003oooooo`000?ooool01?l000001Ooooooo0000ooooool0003ooooo00Co
000000Goooooo`000?oooooo0000ooooo`02o`000007ooooool0003oooooo`000?oooooo0000oooo
o`02o`000003ooooool0003ooooo00;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o
000000?oooooo`000?ooool00_l000001ooooooo0000ooooool0003oooooo`000?ooool00_l00000
1ooooooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Co
000000Goooooo`000?oooooo0000ooooo`02o`000007ooooool0003oooooo`000?oooooo0000oooo
o`02o`000003ooooool0003ooooo00;o000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o
000000Ooooooo`000?oooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_l00000
1ooooooo0000ooooool0003oooooo`000?ooool00_l000001Ooooooo0000ooooool0003ooooo00Co
000000Goooooo`000?oooooo0000ooooo`04o`000005ooooool0003oooooo`000?ooool00_l00000
1ooooooo0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`02o`000007oooo
ool0003oooooo`000?oooooo0000ooooo`010000000000<00000ooooool000001Ol000000ooooooo
0000o`000006o`000003ooooool0003o000000Ko000000?oooooo`000?l00000<_l000000ooooooo
0000o`000006o`000003ooooool0003o000003;o000000?oooooo`000?l000001_l000000ooooooo
0000o`000006o`000003ooooool0003o000003;o000000?oooooo`000?l000001_l000000ooooooo
0000o`00000bo`000003ooooool0003o000000Ko000000Coooooo`000?oooooooooo0@0000000003
00000?oooooo00000?oo00007?l00001ooooo`40000000000`00003oooooooooo`3ooooooagooooo
0@0000000?l000008@0000000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000l003oR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1oohT0KOfL15[i[PY9lKlC>>O>7R[Kg2/McNPj4[gbBPV/nE`3
V_i^08OoP@1eoi@2H_^V1e3e^0lok<PI<>3G9B;Chc<Fa>i33;?fE0FRo6L1Somi
07coS05ZoIl5EoN`2dK``A@fiM4P9mWN;A_:jS`@^_==2:WjG`>GoW40Q?n4077n
U`=OnZT8CO>j43cZbQ/]g]TW8=7U=QC1l4H;/?MG1IomJP6<og`0NOn?0FOlXPED
m[<<@nk45S?Sdb8Uen0`6LS/?`nhmE07Y_]R0YCoM@21ohL0K_jJ0eci[0U:l[dB
>^S=7B_LfbXNc^Lh4koaB@Z^nEX4W?e]08WoP01foi82Ho^U1U7e]Pi0k<LH<N7E
92?DhS8GaNe23KGfD`JSo6D1TOmh07koRP1[oId4FOR_2TO``1<gi/lO:=[M;1c<
jC/A_?=<2J_jG@>HoW00Q_n307?nU@9PnZP8CoBi3ck[bAX^gmPV8M;T=AG3kdD<
/_MF1J3lJ06>og/0Non>0FSlX0EFmk8<ANo35CGTdR4Vf=l^6/W[?Pnim4l8Z?YP
0YGnL`23ohH0L?jH0egjZ`U<lk`A>nW<72cMfRPOcnHg4l3`A`Z_n5T4WOe[08[o
OP1hoi41IObS1U?f]@e2kLDG<^;D8bCEhC4Hana03[KeD@JUnf<2T_mf07ooR@1]
oI`4F_V^2TWa_a<hilhN:]_L:ag=j3XB_O9:2JciG0>JoVh0Qon107GoU09RnjH7
D?Fh3co/b1T`h=LU8]?S<aK4kT<</oID1J;lI`6?ogT0O?n<0F[mW`EGmk0;A_31
53KUdB0WfMh]6l[Z?12jldd8ZOYO0iOnL@24oh@0LOjG0eojZ@Q=lkX@?>[:6bgN
fBLPdNDf5<7`AP^`meL5WoeZ0HcoO01iohl1IobR1ECf/`a3k/@F<n?C8RGGh30I
b>`o3kSeD0NVnf82U?me087oQ`1^oYX3G?V/2D[b_A8jj<dM:mcK:Qk>icPC_o59
2ZkiFPBLoFd0ROn007KoTP9SnjD6DOFf3T3/aaPahMDT8mCR<QO5kD8=]OIC1Z?l
I@6AogP0O_n:06_mW@AIn:l:Ao304cOVcalXf]d/7<cY>a6lld`9ZoYM0iSnL026
oh<0LojE0V3jZ0Q?m;T??^_96RkOf2HQd^@e5L?_A@bbmeH5X?aX0HkoN`1kohh1
J?bP1EKg/Pa5kl<E=NCB8BKHgbhJbN/n3kWdC`RXnV02UOic08?oQP1`oYP3GOZ[
2Dcc_14kjL`L;=gJ:1o?iSLC`?172ZohF@BMoF/0R_mn07SoT@5Uo:<6DoJe3D;]
aALbh]@S9=GQ<AS7k40>]_EA1ZGkH`:BogH0Oon906gmW0AJnJh:BO6o4cSWcQhZ
fm`[7LgX>Q:mlTX9[?UL0i[nKP27oh40MOnD0V;kYPM@mKP??nc86C3PebDRdn<c
5/C^@`bcmU@5X_aW0HooN@1loh`1J_fO1EOg/0]6l<4D=^GA82OIgRdKb^Xl4;[c
C@RYnUl3Uoia08CoQ01aoYL3GoZY24gc^Q0lj/XK;MkI9b3AiCHD`O162k3gE`FO
oFX1S?ml07WoS`5Wo:85E?Jc34?^a1Hchm<R9MOP<1W8k3l?^?E@1jKkHP:DogD0
POn706knVP=LnJ`9B_:m4S[XcAd[g=/Z7/kW>1>olDT:[_UJ19cmK@29oh00M_nB
0V?kY@IAmKH>@>c7637QeB@Se>8b5lG]@PfemU<6XoaU0I7oN01nohX0JofM15Wh
[`Y7l<0C=nK?7bSJgB`Lc>Tk4KccC0V[nUd3V?i`08KoP`1coYD2H?ZX24od^@ln
jlTJ;]oH9R7Bi3DE`nm53;;gEPFPo6P1S_mk07_oSP5Xo:05E_Nb34G_`aDei=8Q
9]SO;Q[9jch?^OA?2:SjH0:EoW<0Pon6073nV0=MnZ/9C?>l4C_Yc1`/gMXX7loV
=a?0l4L:[oQI19gmJ`2:ogh0N?nA0FGlX`ICm[D=@^g55c;Re2<TeN4a6<O/@0jf
mE46YO]S0Y;oMP1o\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["More complex sine waves", "Subsection"],

Cell[CellGroupData[{

Cell["Sum of two sine waves", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f1[t_] := 
        Sin[2  \[Pi]\ 400\ t]\  + \ 
          Sin[2  \[Pi]\ 600\ t];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f1[t], {t, 0, 0.02}];\)\), "\[IndentingNewLine]", 
    \(\(Play[f1[t], {t, 0, 2}];\)\), "\[IndentingNewLine]", 
    \(\[Florin][t] == f1[t]\  // \ TraditionalForm\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 47.619 0.309013 0.154414 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7381 -0.0125 -15 -9 ]
[.7381 -0.0125 15 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00019 -12 -4.5 ]
[-0.0125 .00019 0 4.5 ]
[-0.0125 .1546 -12 -4.5 ]
[-0.0125 .1546 0 4.5 ]
[-0.0125 .30901 -6 -4.5 ]
[-0.0125 .30901 0 4.5 ]
[-0.0125 .46343 -6 -4.5 ]
[-0.0125 .46343 0 4.5 ]
[-0.0125 .61784 -6 -4.5 ]
[-0.0125 .61784 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.005)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.01)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.015)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.02)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00019 m
.00625 .00019 L
s
[(-2)] -0.0125 .00019 1 0 Mshowa
0 .1546 m
.00625 .1546 L
s
[(-1)] -0.0125 .1546 1 0 Mshowa
0 .30901 m
.00625 .30901 L
s
[(0)] -0.0125 .30901 1 0 Mshowa
0 .46343 m
.00625 .46343 L
s
[(1)] -0.0125 .46343 1 0 Mshowa
0 .61784 m
.00625 .61784 L
s
[(2)] -0.0125 .61784 1 0 Mshowa
.125 Mabswid
0 .03107 m
.00375 .03107 L
s
0 .06195 m
.00375 .06195 L
s
0 .09283 m
.00375 .09283 L
s
0 .12372 m
.00375 .12372 L
s
0 .18548 m
.00375 .18548 L
s
0 .21636 m
.00375 .21636 L
s
0 .24725 m
.00375 .24725 L
s
0 .27813 m
.00375 .27813 L
s
0 .3399 m
.00375 .3399 L
s
0 .37078 m
.00375 .37078 L
s
0 .40166 m
.00375 .40166 L
s
0 .43254 m
.00375 .43254 L
s
0 .49431 m
.00375 .49431 L
s
0 .52519 m
.00375 .52519 L
s
0 .55607 m
.00375 .55607 L
s
0 .58696 m
.00375 .58696 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00019 m
1 .00019 L
s
.99375 .1546 m
1 .1546 L
s
.99375 .30901 m
1 .30901 L
s
.99375 .46343 m
1 .46343 L
s
.99375 .61784 m
1 .61784 L
s
.125 Mabswid
.99625 .03107 m
1 .03107 L
s
.99625 .06195 m
1 .06195 L
s
.99625 .09283 m
1 .09283 L
s
.99625 .12372 m
1 .12372 L
s
.99625 .18548 m
1 .18548 L
s
.99625 .21636 m
1 .21636 L
s
.99625 .24725 m
1 .24725 L
s
.99625 .27813 m
1 .27813 L
s
.99625 .3399 m
1 .3399 L
s
.99625 .37078 m
1 .37078 L
s
.99625 .40166 m
1 .40166 L
s
.99625 .43254 m
1 .43254 L
s
.99625 .49431 m
1 .49431 L
s
.99625 .52519 m
1 .52519 L
s
.99625 .55607 m
1 .55607 L
s
.99625 .58696 m
1 .58696 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30901 m
1 .30901 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30901 m
.02846 .40204 L
.03279 .48018 L
.03754 .54802 L
.0389 .56306 L
.0402 .5752 L
.04135 .58425 L
.04262 .59223 L
.04386 .59796 L
.04502 .60146 L
.04624 .60319 L
.04756 .6028 L
.04878 .60036 L
.04994 .59625 L
.05099 .59109 L
.05212 .58393 L
.05472 .56201 L
.05748 .53095 L
.06244 .45959 L
.06791 .36835 L
.07382 .27062 L
.07904 .19817 L
.08166 .16956 L
.08317 .15595 L
.08454 .14545 L
.08579 .13754 L
.08715 .13071 L
.08789 .12775 L
.08858 .12551 L
.08924 .12381 L
.08994 .12248 L
.09118 .12131 L
.09234 .12155 L
.09361 .12324 L
.09432 .12482 L
.09498 .12666 L
.09721 .13554 L
.09848 .14222 L
.09966 .14938 L
.10458 .18708 L
.10963 .23269 L
.1151 .28056 L
.11761 .29947 L
.12027 .31633 L
.12254 .3277 L
.12382 .33279 L
.12504 .33671 L
.12619 .33961 L
.12746 .34184 L
.1286 .34305 L
Mistroke
.12967 .34349 L
.13093 .34319 L
.13208 .34218 L
.1334 .34021 L
.13464 .33764 L
.13689 .33144 L
.13896 .32437 L
.14363 .30589 L
.14834 .28814 L
.1497 .28397 L
.15098 .28061 L
.15215 .27812 L
.15339 .27616 L
.15446 .27505 L
.15565 .27454 L
.15673 .27475 L
.15775 .27555 L
.15894 .27727 L
.16003 .2796 L
.16123 .28298 L
.16249 .28748 L
.16497 .29907 L
.16761 .31517 L
.17237 .35209 L
.17799 .40284 L
.18316 .44776 L
.18575 .4666 L
.18816 .48077 L
.18937 .48639 L
.19067 .49116 L
.19141 .49326 L
.19212 .49481 L
.19343 .49652 L
.19407 .49677 L
.19477 .4966 L
.19551 .49592 L
.1962 .49479 L
.19743 .49161 L
.19812 .48915 L
.19876 .48647 L
.20158 .46966 L
.203 .45822 L
.20455 .44351 L
.2096 .38151 L
.21499 .29729 L
.22471 .13604 L
.2273 .09924 L
.23003 .06604 L
.23237 .04348 L
.23369 .03342 L
Mistroke
.23494 .02577 L
.23563 .02239 L
.23638 .01939 L
.2377 .0159 L
.23845 .01494 L
.23924 .01473 L
.23999 .01532 L
.24067 .0165 L
.24136 .01835 L
.242 .02061 L
.24343 .02771 L
.2447 .03622 L
.24604 .04744 L
.24843 .07306 L
.251 .10768 L
.25564 .18542 L
.26618 .39483 L
.27112 .4841 L
.27382 .52491 L
.27636 .55635 L
.2791 .58172 L
.28055 .59133 L
.28137 .59551 L
.28212 .59857 L
.28335 .60197 L
.28406 .60297 L
.28471 .60332 L
.28603 .60227 L
.28677 .60067 L
.28744 .5986 L
.28869 .59318 L
.29002 .58528 L
.29241 .56593 L
.29497 .53833 L
.29779 .50115 L
.30756 .34187 L
.31278 .25745 L
.31773 .19108 L
.31989 .16829 L
.32218 .14876 L
.3235 .13983 L
.32469 .13325 L
.32589 .12809 L
.32702 .12456 L
.32824 .12219 L
.32893 .12149 L
.32957 .12125 L
.33087 .12196 L
.3316 .12304 L
.33226 .12443 L
Mistroke
.33345 .12787 L
.33473 .13289 L
.33707 .14514 L
.33981 .16381 L
.34271 .18739 L
.34792 .23449 L
.35274 .27686 L
.35733 .31016 L
.35985 .3241 L
.36119 .33001 L
.36261 .33513 L
.36393 .33878 L
.36512 .34118 L
.36632 .34273 L
.36745 .34343 L
.36851 .34342 L
.36967 .3427 L
.37089 .34122 L
.37202 .3392 L
.37405 .33422 L
.37623 .3273 L
.38084 .30945 L
.38574 .29047 L
.38825 .28269 L
.38968 .27924 L
.39034 .27795 L
.39102 .2768 L
.39225 .27531 L
.39338 .27462 L
.39459 .27464 L
.39527 .27502 L
.39591 .27563 L
.3966 .27655 L
.39735 .27787 L
.39871 .28115 L
.40004 .28541 L
.40126 .29029 L
.40403 .30457 L
.40697 .32413 L
.41667 .4082 L
.42202 .45361 L
.42465 .47177 L
.42593 .47911 L
.42709 .48479 L
.42823 .48937 L
.42946 .49314 L
.43076 .49571 L
.43198 .49674 L
.43263 .49672 L
.43333 .49623 L
Mistroke
.43407 .49521 L
.43476 .49376 L
.43599 .49 L
.43731 .48426 L
.43852 .4775 L
.43983 .46852 L
.4422 .44793 L
.44666 .39582 L
.45611 .24614 L
.46497 .10497 L
.46718 .07681 L
.4695 .05207 L
.47072 .04138 L
.47205 .03162 L
.47326 .0246 L
.47439 .01972 L
.47504 .01763 L
.47574 .016 L
.47702 .01472 L
.47826 .01557 L
.47941 .0182 L
.48065 .02304 L
.48136 .02671 L
.48202 .03073 L
.48477 .05361 L
.48749 .0852 L
.49007 .12249 L
.49491 .20746 L
.50579 .42378 L
.51075 .50818 L
.51319 .5415 L
.51542 .56632 L
.51776 .5858 L
.51899 .59321 L
.52029 .59884 L
.52093 .60079 L
.52162 .60227 L
.52285 .60332 L
.52361 .60295 L
.52433 .6019 L
.52497 .60038 L
.52566 .59812 L
.52681 .59308 L
.52788 .58687 L
.53031 .56769 L
.53269 .54282 L
.53524 .51024 L
.54407 .36881 L
.54897 .28711 L
.55418 .21115 L
Mistroke
.55718 .17627 L
.5599 .15157 L
.56122 .1422 L
.56264 .134 L
.56329 .13092 L
.56398 .12812 L
.56521 .12432 L
.56647 .12202 L
.56761 .12126 L
.56892 .12191 L
.57017 .124 L
.57132 .12713 L
.57238 .13101 L
.57479 .14294 L
.57722 .15875 L
.57989 .17963 L
.58531 .22797 L
.59023 .27179 L
.59291 .29302 L
.5954 .31004 L
.59772 .32299 L
.59982 .3321 L
.60103 .33612 L
.60216 .33911 L
.60336 .34142 L
.60466 .34295 L
.60596 .3435 L
.60717 .34316 L
.60787 .34261 L
.6085 .34189 L
.60923 .34082 L
.60993 .33957 L
.6126 .33291 L
.61551 .32302 L
.62032 .30384 L
.62285 .29401 L
.62552 .28504 L
.62684 .28141 L
.6283 .2782 L
.62962 .2761 L
.63085 .27492 L
.63212 .27453 L
.63327 .27495 L
.63391 .27552 L
.63461 .27641 L
.63587 .27876 L
.63699 .28167 L
.63823 .28577 L
.64074 .29685 L
.64306 .31029 L
Mistroke
.64523 .32535 L
.65599 .41924 L
.65856 .44132 L
.66129 .46223 L
.66366 .47713 L
.66491 .4835 L
.66622 .48899 L
.66687 .49119 L
.66758 .4932 L
.66883 .49568 L
.6701 .49674 L
.67129 .49636 L
.67245 .49467 L
.67351 .49195 L
.67473 .48742 L
.67589 .48174 L
.67852 .46387 L
.68095 .44139 L
.68645 .37197 L
.69536 .22637 L
.70004 .14933 L
.70497 .08042 L
.70736 .05431 L
.70863 .0429 L
.70998 .0327 L
.71123 .02524 L
.71237 .02014 L
.71351 .01668 L
.71458 .01498 L
.71568 .01484 L
.71684 .01645 L
.71783 .01926 L
.71892 .02387 L
.72009 .03058 L
.72134 .03978 L
.72362 .06146 L
.72626 .09422 L
.72913 .13808 L
.73437 .23406 L
.74421 .42987 L
.74677 .47515 L
.74953 .51815 L
.75197 .54976 L
.7533 .56419 L
.75454 .57572 L
.75576 .58514 L
.75687 .59204 L
.7581 .5978 L
.75942 .60172 L
.76052 .60319 L
Mistroke
.76172 .60293 L
.76286 .60093 L
.7639 .59757 L
.76511 .592 L
.7664 .58399 L
.76874 .56452 L
.77153 .53385 L
.77408 .49972 L
.78488 .3228 L
.78963 .24763 L
.79224 .21164 L
.7947 .18239 L
.797 .15985 L
.79821 .14998 L
.79948 .1411 L
.80056 .13489 L
.80175 .1294 L
.80282 .12564 L
.80383 .12318 L
.80511 .12149 L
.80584 .12125 L
.80651 .12147 L
.80774 .12295 L
.80905 .12601 L
.81034 .13044 L
.81155 .13579 L
.81381 .14857 L
.81897 .18798 L
.82454 .23838 L
.82915 .2786 L
.83408 .31357 L
.83554 .32159 L
.83691 .32807 L
.83825 .33331 L
.83949 .33718 L
.84067 .33999 L
.84191 .34207 L
.84316 .34322 L
.84387 .34348 L
.84453 .34346 L
.84583 .34273 L
.84657 .34193 L
.84725 .34094 L
.8485 .33859 L
.84984 .33535 L
.85469 .31887 L
.86038 .29612 L
.86288 .28731 L
.8642 .28335 L
.86562 .2798 L
Mistroke
.86631 .27835 L
.86697 .27718 L
.8682 .27554 L
.86936 .27469 L
.87062 .27459 L
.87125 .27488 L
.87195 .27546 L
.87268 .27638 L
.87336 .27753 L
.87458 .28028 L
.8759 .28427 L
.87873 .29633 L
.88171 .3139 L
.88703 .3553 L
.89678 .44235 L
.89959 .46359 L
.90224 .47971 L
.90339 .48527 L
.90462 .49005 L
.90526 .49206 L
.90596 .49388 L
.9072 .49603 L
.90851 .49678 L
.90976 .49596 L
.91089 .49392 L
.91211 .49026 L
.91281 .48751 L
.91344 .48459 L
.91485 .4766 L
.91739 .45725 L
.91976 .43376 L
.92231 .40297 L
.92693 .33552 L
.9357 .18865 L
.94033 .11646 L
.94289 .0826 L
.9453 .05586 L
.94725 .03868 L
.94828 .03138 L
.94937 .02502 L
.95029 .02082 L
.9513 .01744 L
.95222 .01553 L
.95308 .01475 L
.95397 .01498 L
.9549 .01638 L
.9557 .01851 L
.95657 .02181 L
.95751 .02652 L
.95852 .03285 L
Mistroke
.96033 .04752 L
.96239 .06908 L
.96461 .09785 L
.96864 .16228 L
.97619 .30901 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`00033ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`;o00000oooool3o`0002Oooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`?o00009_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00003oooo
o`?o00009oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00006oooo
o`005_ooool01?l0003oooooooooool0000^ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool08oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool09?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo000F
ooooo`04o`000?ooooooooooo`0002kooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool08oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool09?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`06ooooo`005_ooool01?l0003oooooooooool0000^
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
8oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool001Kooooo00Co0000oooooooooooo0000;_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo0000ooooo`04o`0002Kooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
02Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooooooo`Co00009_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`04ooooo`005_ooool01?l0003oooooooooool0000^
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool01_l0003ooooo
ooooool0003oooooo`0002Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0002ooooo`;o00009_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo0_l00003ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01?ooool001Oooooo0_l0000`
ooooo`;o00002_ooool2o`0000Cooooo0_l00002ooooo`Go00009_ooool2o`0000[ooooo0_l00004
ooooo`03o`000?oooooooooo02Gooooo0_l0000:ooooo`;o00001?ooool01?l0003ooooooooooooo
ool5o`0002Kooooo0_l0000:ooooo`;o00000oooool3o`0000Oooooo003oooooob7ooooo0009oooo
o`Go0000oooooolCooooo`002_ooool01?l0003oooooooooool0003ooooooa?ooooo0003ooooo`Go
00000oooool00ol0003oooooooooo`3ooooooa?ooooo000<ooooo`03o`000?oooooooooo00?ooooo
00?o0000000000000000o`000002o`0000[ooooo0009ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool0
2?ooool000[ooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003ooooooooo
o`08ooooo`004_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03[ooooo0_l0000l
ooooo`;o0000??ooool2o`0000[ooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooo`00000kooooo`;o0000??ooool2o`0003_ooooo00?o0000oooo
ool000002_ooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooo000003_ooooo00?o0000ooooool00000>_ooool00ol0003oooooo`00000kooooo`03
o`000?oooooo000000[ooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooo`00000kooooo`03o`000?oooooo000003[ooooo00?o0000ooooool00000
>oooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00Sooooo000Booooo`;o0000>ooo
ool00ol0003oooooo`00000jooooo`04o`000?ooooooooooo`0003[ooooo00Co0000oooooooooooo
0000>_ooool01?l0003oooooooooo`000008ooooo`;o00002_ooool001;ooooo00?o0000oooooooo
ool0>_ooool01?l0003oooooooooool0000iooooo`04o`000?ooooooooooo`0003[ooooo00Co0000
oooooooooooo0000>_ooool01?l0003oooooooooo`000009ooooo`03o`000?oooooooooo00Sooooo
000Booooo`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00000iooooo`04o`00
0?ooooooooooo`0003[ooooo00Co0000oooooooooooo0000>_ooool01?l0003oooooooooo`000009
ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo03Wooooo00Go0000oooo
ooooooooooooo`00000iooooo`04o`000?ooooooooooo`0003[ooooo00Co0000oooooooooooo0000
>_ooool01?l0003oooooooooo`000009ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`00
0?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00000iooooo`05o`000?oooooooooooooo
ool00000>Oooool01?l0003oooooooooool0000jooooo`04o`000?oooooooooo000000Wooooo00?o
0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooo
oooo000003Wooooo00Go0000ooooooooooooooooo`00000hooooo`05o`000?ooooooooooooooool0
0000>Oooool01Ol0003oooooooooooooool0000000Wooooo00?o0000ooooooooool02?ooool001;o
oooo00?o0000ooooooooool0>Oooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000oooo
ooooooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool0
1Ol0003oooooooooooooool0000000Wooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000
ooooooooool0>Oooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000oooooooooooooooo
o`00000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool01Ol0003ooooo
ooooooooool0000000Wooooo00?o0000ooooooooool02?ooool001;ooooo0_l0000jooooo`05o`00
0?ooooooooooooooool00000>Oooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00<00000oooo
ooooool01Oooool2o`0000[ooooo000Booooo`03o`000?oooooooooo03Wooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00`00
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo03Wo
oooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool00_ooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Booooo`03
o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo000Booooo`03o`000?oooooooooo03Wooooo00Go0000ooooooooooooooooo`00000hoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`06oooo
o`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo03Wooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00`00
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool00_ooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo000Booooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00`00003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo000Booooo`;o0000>Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo00Gooooo0_l0000:ooooo`004_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`004_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00<00000oooo
ooooool01_ooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00?ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`00
4_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00?ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`004_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool01_ooool0
0ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`;o00008_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo0_l0000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00?ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`004_ooool2o`0001Go
oooo0ol0000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool2o`0002;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`;o00008Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool000008Oooool00ol0003o
ooooooooo`03ooooo`0300000?oooooooooo00Gooooo0_l0000:ooooo`004_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool00oooool00`00003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo01Cooooo00?o
0000ooooool000008?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00Co
0000oooooooooooo00008?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooool000008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooool000008Oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool04oooool01?l0003ooooooooo
ool0000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01?l0003ooooo
ooooool0000Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooo`00000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooo`00000Qooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool01Oooool00ol0003o
ooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`00023o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooo`00
023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`04o`000?oooooooooo
o`00023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooo`00027ooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo000:ooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`05o`000?oooooo
ooooooooool000007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00Co
0000oooooooooooo00008?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo
00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oo
oooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo00Cooooo00<00000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000Pooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0000Pooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo0000023ooooo
00?o0000ooooooooool01?ooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
0003ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00Go
0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
3oooool01?l0003oooooooooool0000Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03oooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000008?ooool00ol0003oooooooooo`04
ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000oooo
ooooool01?ooool3o`0001?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000001oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00Go
0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool0
1?ooool2o`0000[ooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04ooo
ool01Ol0003ooooooooooooooooo000001oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool01Ol0003ooooo
oooooooooooo000001oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo000:ooooo`;o00001_ooool00ol0003oooooooooo`0Cooooo`05o`00
0?ooooooooooooooool000007oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooooooo
ool000007oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Gooooo00?o0000oooo
ooooool02?ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`05
o`000?ooooooooooooooool000007oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00`00003o
ooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo
00<00000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`05ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool01Oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Boooo
o`;o00004oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01Oooool00`00003oooooooooo`04ooooo`;o00002_ooool001;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool01Oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Gooooo00<00000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`004_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool02?oo
ool001;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo000Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01_ooool00`00003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo000Booooo`;o00004oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00`00003ooooooooo
o`03ooooo`;o00002_ooool001;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00`00003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00<00000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03
00000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Oooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`004_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`07ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo000Booooo`;o00004_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01oooool00`00003oooooooooo`03ooooo`;o00002_ooool001;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
000Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool001;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00`00003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00<00000oooooooo
ool01?ooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`030000
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l0000>ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo0_l0000>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0ol0000=ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo0_l0000>ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`004_ooool2o`00017ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`?o00003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
000000kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000=ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`09ooooo`0300000?oooooo
oooo00;ooooo0_l0000:ooooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
000000gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0000=ooooo`03o`000?oo
oooooooo00Wooooo00<00000ooooooooool00oooool00ol0003oooooooooo`08ooooo`004_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool02Oooool00`00
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00`00
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo000;ooooo`;o00001Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo000:ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`002_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`0300000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool000[ooooo00Co0000oooooooooooo00001?ooooom
o`00000300000?l0003o000000Co00002_ooool000[ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo000:ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`002oooool2o`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo000Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000Booooo`;o00001?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0;ooooo`Co00002?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`?o00002?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0?ooooo`;o00002_ooool001;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo0_l0000:ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00cooooo0_l00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo0_l00009ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool001;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo000B
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08
ooooo`004_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02?ooool001;ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo0_l0000:ooooo`00
4_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2?ooool001;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Sooooo000Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool001;ooooo0_l00005
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo013ooooo0_l0000:ooooo`004_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`004_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?oo
ool001;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Sooooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool02?ooool001;ooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo
0_l0000:ooooo`004_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool000[ooooo0ol00005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`002ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Ooo
ool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`08ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool07Oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`04ooooo`?o00001_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Ooo
ool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Mooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`;o
00002_ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo0000017o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`05o`000?oooooooooooooo
ool000004?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo00Go0000oooo
ooooooooooooo`00000Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool0
1Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool02?ooool000[ooooo0_l00006
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0M
ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01gooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000005Oooool00ol0
003oooooooooo`08ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`04o`000?ooooooooooo`00
017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`05o`000?oooooooooo
ooooool000004Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00Co0000
oooooooooooo00004_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00Co
0000oooooooooooo00005Oooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool01?l0003ooooooooo
ool0000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool01?l0003ooooo
ooooool0000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool01?l0003o
ooooooooool0000Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool01?l0
003oooooooooool0000Eooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`04o`000?oooooooooo
o`00017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
000001;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`04o`000?oooooo
ooooo`0001;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`04o`000?oo
ooooooooo`0001Gooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo0000
4Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooool00000
4_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo
00004_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooo
oooo00005Oooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool2o`0001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000001;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000001Gooooo00?o0000oooooooo
ool02?ooool001;ooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7oooool2o`0001;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`?o0000
4_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo0_l0000Cooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool07oooool2o`0001Gooooo0_l0000:ooooo`004_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?oo
ool2o`0001;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool0
01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool001;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool02?ooool001;ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0=oooool2o`0000[ooooo000Booooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo00Sooooo000Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo000Booooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03Kooooo00Go0000ooooooooooooooooo`00000kooooo`03o`000?oooooooooo00Sooooo000Boooo
o`;o00002?ooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000ooooooooooooooooo`00
000iooooo`05o`000?ooooooooooooooool00000>?ooool01Ol0003ooooooooooooooooo000003[o
oooo0_l0000:ooooo`004_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
0000>Oooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000ooooooooooooooooo`00000h
ooooo`05o`000?ooooooooooooooool00000>oooool00ol0003oooooooooo`08ooooo`004_ooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000>Oooool01Ol0003ooooooooo
oooooooo000003Wooooo00Go0000ooooooooooooooooo`00000hooooo`05o`000?oooooooooooooo
ool00000>oooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`07ooooo`05
o`000?ooooooooooooooool00000>Oooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000
ooooooooooooooooo`00000hooooo`05o`000?ooooooooooooooool00000>oooool00ol0003ooooo
ooooo`08ooooo`004_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
>Oooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000ooooooooooooooooo`00000ioooo
o`04o`000?ooooooooooo`0003_ooooo00?o0000ooooooooool02?ooool001;ooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000003Wooooo00Go0000ooooooooooooooooo`00
000iooooo`05o`000?ooooooooooooooool00000>Oooool01?l0003oooooooooool0000kooooo`03
o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooo
ooooo`00000iooooo`04o`000?ooooooooooo`0003[ooooo00Co0000oooooooooooo0000>_ooool0
1?l0003oooooooooool0000kooooo`03o`000?oooooooooo00Sooooo000Booooo`03o`000?oooooo
oooo00Sooooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000jooooo`04o`00
0?ooooooooooo`0003[ooooo00Co0000oooooooooooo0000>oooool00ol0003oooooooooo`08oooo
o`004_ooool2o`0000Wooooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000j
ooooo`04o`000?ooooooooooo`0003[ooooo00Co0000oooooooooooo0000>_ooool2o`0000[ooooo
000Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooool00000>oooool00ol0003oooooo`00
000jooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooool00000??ooool00ol0003ooooo
ooooo`08ooooo`004_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000003_ooooo00?o
0000ooooool00000>oooool00ol0003oooooo`00000jooooo`03o`000?oooooo000003cooooo00?o
0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00000k
ooooo`03o`000?oooooo000003_ooooo0_l0000looooo`;o0000??ooool00ol0003oooooooooo`08
ooooo`004_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0>_ooool2o`0003cooooo0_l0000looooo`03o`000?oooooooooo00Sooooo0009ooooo`Go
00001?ooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool02?ooool000[ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000cooooo00?o
0000ooooooooool00oooooooo`0000Go00002_ooool000Wooooo00Go0000ooooooooooooooooo`00
003ooooooa?ooooo0009ooooo`05o`000?ooooooooooooooool00000oooooolCooooo`002_ooool3
o`000?oooooo5?ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00200373, -2.30696, \
8.0993*^-5, 0.024977}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`00000Q
0000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooo`00003oo`0001co
00000Oooool10000000000@00000oooooooooooooooo3_l00003ooooo`ko00001?ooool>o`0000Co
oooo3_l00003ooooo`oo00000oooool>o`0000Cooooo3_l00004ooooo`ko00000oooool>o`0000Co
oooo3_l00004ooooo`ko00001?ooool>o`0000?ooooo3_l00004ooooo`ko00001?ooool>o`0000Co
oooo3_l00003ooooo`40000000000`00003oooooo`000006o`0000Cooooo3_l00003ooooo`oo0000
0oooool>o`0000Cooooo3_l00004ooooo`ko00000oooool>o`0000Cooooo3_l00004ooooo`ko0000
1?ooool>o`0000?ooooo3_l00004ooooo`ko00001?ooool>o`0000Cooooo3_l00003ooooo`ko0000
1?ooool>o`0000Cooooo1ol00001ooooo`40000000001000003oooooooooooooool=o`0000Gooooo
3Ol00005ooooo`co00001Oooool=o`0000Gooooo3Ol00005ooooo`go00001Oooool<o`0000Gooooo
3Ol00005ooooo`go00001Oooool<o`0000Kooooo3?l00005ooooo`go00001Oooool=o`0000Gooooo
3?l00006ooooo`co00001Oooool=o`0000Cooooo0@000000000300000?oooooo000000Oo000000?o
ooooo`000?l000003ol000000ooooooo0000o`00000?o`000003ooooool0003o000000oo000000?o
ooooo`000?l000003_l000000ooooooo0000o`00000?o`000003ooooool0003o000000oo000000?o
ooooo`000?l000008?l000000ooooooo0000o`00000?o`000003ooooool0003o000000oo000000?o
ooooo`000?l000003_l000000ooooooo0000o`00000?o`000003ooooool0003o000000oo000000?o
ooooo`000?l000003ol000000ooooooo0000o`00000>o`000003ooooool0003o000000Oo00000Ooo
ool10000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo0000
0?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool100000000
00<00000ooooool00000H?l000000ooooooo0000o`000014o`000003ooooool0003o0000077o0000
0Oooool10000000000<00000ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooo
00000?oo00007?l00001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000
000000<00000ooooool000001_l00004ooooo`ko00001?ooool6o`000003ooooool0003o000000Co
00001?ooool>o`0000Cooooo3_l00004ooooo`ko00001?ooool6o`000003ooooool0003o000000Co
00001?ooool>o`0000Cooooo3_l00004ooooo`Ko000000?oooooo`000?l000001?l00005ooooo`Ko
000000?oooooo`000?l000001?l00004ooooo`ko00001?ooool>o`0000Cooooo1_l000000ooooooo
0000o`000004o`0000Cooooo3_l00004ooooo`ko00001?ooool7o`00007ooooo0@00000000030000
0?oooooooooo00;ooooo3?l00006ooooo`_o00001oooool;o`0000Kooooo3?l00006ooooo`co0000
1_ooool;o`0000Kooooo3?l00006ooooo`co00001_ooool<o`0000Kooooo2ol00006ooooo`co0000
1_ooool<o`0000Kooooo2ol00007ooooo`_o00001_ooool<o`0000Kooooo3?l00004ooooo`400000
00000`00003oooooo`000004o`0000Oooooo2ol00006ooooo`co00001_ooool<o`0000Kooooo2ol0
0007ooooo`_o00001_ooool<o`0000Kooooo3?l00006ooooo`_o00001_ooool<o`0000Kooooo3?l0
0006ooooo`co00001_ooool;o`0000Kooooo3?l00006ooooo`co00001_ooool;o`0000Oooooo1_l0
0001ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000000000<00000oooo
ooooool0oooooolMooooo`400000003o00000240000000000`00003oooooooooo`3ooooooagooooo
0@000000000300000?oooooo000000Wo000000?oooooo`000?l000003_l000000ooooooo0000o`00
000?o`000003ooooool0003o000000oo000000?oooooo`000?l000003ol000000ooooooo0000o`00
000>o`000003ooooool0003o000000oo000000?oooooo`000?l000003ol000000ooooooo0000o`00
000?o`000003ooooool0003o000000ko000000?oooooo`000?l000003ol000000ooooooo0000o`00
000?o`000003ooooool0003o000000ko00000_ooool@o`000003ooooool0003o000000oo000000?o
ooooo`000?l000003ol000000ooooooo0000o`000005o`00007ooooo0@000000000300000?oooooo
oooo00Kooooo1Ol0000=ooooo`Go00003Oooool5o`0000cooooo1_l0000<ooooo`Go00003Oooool5
o`0000gooooo1Ol0000<ooooo`Ko00003?ooool5o`0000gooooo1Ol0000=ooooo`Go00003?ooool6
o`0000cooooo1Ol0000=ooooo`Go00003?ooool6o`0000cooooo1_l00006ooooo`40000000000`00
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`03o`000?oooooooooo
00?ooooo0_l00009ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`;o00001?ooool2o`00
00[ooooo00?o0000ooooooooool00oooool2o`0000Wooooo0_l00005ooooo`;o00002Oooool2o`00
00Gooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0_l0000:ooooo`03o`000?oooooooooo
00?ooooo0_l00009ooooo`;o00001Oooool2o`0000Wooooo0_l00005ooooo`03o`000?oooooooooo
00Sooooo0_l00004ooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`;o00002Oooool2o`00
00Gooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`00
00Gooooo0@000000000300000?oooooooooo00?ooooo0_l00008ooooo`;o00001Oooool3o`0000Oo
oooo0ol00005ooooo`?o00001oooool3o`0000Gooooo0_l00008ooooo`;o00001_ooool2o`0000So
oooo0_l00005ooooo`?o00001oooool3o`0000Gooooo0_l00008ooooo`;o00001_ooool2o`0000So
oooo0_l00006ooooo`;o00001oooool3o`0000Gooooo0ol00007ooooo`?o00001Oooool2o`0000So
oooo0_l00006ooooo`;o00002?ooool2o`0000Gooooo0ol00007ooooo`?o00001Oooool3o`0000Oo
oooo0ol00005ooooo`;o00002?ooool2o`0000Kooooo0_l00008ooooo`;o00000oooool100000000
00@00000oooooooooooooooo0_l0000<ooooo`;o000000Coooooo`000?l0003o00002oooool3o`00
0003ooooool0003o000000cooooo0ol000000ooooooo0000o`00000<ooooo`;o000000Coooooo`00
0?l0003o00003?ooool2o`000004ooooool0003o0000o`0000_ooooo0ol000000ooooooo0000o`00
000<ooooo`?o000000?oooooo`000?l000003?ooool2o`000004ooooool0003o0000o`0000cooooo
0_l000001?oooooo0000o`000?l0000;ooooo`?o000000?oooooo`000?l000003?ooool3o`000003
ooooool0003o000000cooooo0_l000001?oooooo0000o`000?l0000<ooooo`;o000000?oooooo`00
0?l000003?ooool3o`000003ooooool0003o000000cooooo0_l00002ooooo`;o00003?ooool2o`00
007ooooo0@000000000400000?oooooo0000o`00013ooooo0_l0000@ooooo`03o`000?oooooooooo
00kooooo0_l0000@ooooo`;o00004?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00kooooo0_l0000@ooooo`;o00004?ooool00ol0003oooooooooo`0>ooooo`;o00004?ooool2o`00
013ooooo0_l0000@ooooo`03o`000?oooooooooo00kooooo0_l0000@ooooo`;o00004Oooool10000
000000<00000ooooooooool00_l0000=ooooo`;o000000?oooooo`000?l000003Oooool5o`0000go
oooo1?l0000>ooooo`04o`000?oooooo0000o`0000gooooo0_l000000ooooooo0000o`00000=oooo
o`Go00003Oooool4o`0000kooooo00Co0000ooooool0003o00003Oooool5o`0000gooooo1Ol0000=
ooooo`04o`000?oooooo0000o`0000gooooo0_l000000ooooooo0000o`00000=ooooo`Go00003Ooo
ool5o`0000gooooo00Co0000ooooool0003o00003Oooool2o`00007ooooo0@000000000300000?oo
oooooooo00;ooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o00002_oo
ool2o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o00002_oo
ool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo0_l00004ooooo`;o00002_oo
ool2o`0000Cooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo0_l0000:ooooo`;o00001?ooool2o`0000[ooooo0_l00002ooooo`4000000000
0`00003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool1
0000000000<00000ooooooooool01?ooool2o`0000Gooooo0ol00008ooooo`;o00001Oooool2o`00
00Wooooo00?o0000ooooooooool01?ooool2o`0000Sooooo0_l00005ooooo`?o00002?ooool2o`00
00Gooooo0ol00008ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`03o`000?oooooooooo
00Cooooo0_l00008ooooo`;o00001Oooool3o`0000Sooooo0_l00005ooooo`;o00002Oooool00ol0
003oooooooooo`04ooooo`;o00002?ooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool3o`00
00Sooooo0_l00005ooooo`;o00002Oooool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`00
00Gooooo0ol00008ooooo`;o00001Oooool3o`0000Cooooo0@000000000300000?oooooooooo00Ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`;o00000_ooool2o`0000cooooo0_l00002oooo
o`;o00003?ooool01?l0003oooooooooooooool2o`0000_ooooo0_l00003ooooo`03o`000?oooooo
oooo00[ooooo0_l00002ooooo`;o00003?ooool2o`0000;ooooo0_l0000<ooooo`04o`000?oooooo
ooooooooo`;o00002oooool2o`0000?ooooo00?o0000ooooooooool02_ooool2o`0000;ooooo0_l0
000<ooooo`;o00000_ooool2o`0000cooooo00Co0000oooooooooooooooo0_l0000;ooooo`;o0000
0oooool00ol0003oooooooooo`0:ooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`;o0000
3?ooool01Ol0003ooooooooooooooooo000000Oooooo0@000000000300000?oooooooooo00Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool10000000000<00000ooooooooool02?ooool2o`0000oooooo0ol0
000?ooooo`;o00004?ooool2o`00013ooooo0_l0000?ooooo`?o00003oooool2o`00013ooooo0_l0
000@ooooo`;o00003oooool3o`0000oooooo0_l0000@ooooo`;o00003oooool3o`0000oooooo0ol0
000?ooooo`;o00004?ooool2o`0000Sooooo0@000000000300000?oooooooooo00Oooooo0ol0000?
ooooo`03o`000?oooooo000000kooooo0_l000000ooooooo0000ooooo`0=ooooo`?o00003oooool3
o`0000oooooo00?o0000ooooool000003_ooool3o`0000oooooo0ol0000?ooooo`03o`000?oooooo
000000oooooo00?o0000ooooool000003_ooool3o`0000oooooo0ol0000?ooooo`03o`000?oooooo
000000kooooo0_l000000ooooooo0000ooooo`0=ooooo`?o00003oooool3o`0000Sooooo0@000000
000300000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?oooooo
ooooooooool000003Oooool01?l0003oooooooooool0000=ooooo`05o`000?ooooooooooooooool0
00003Oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00003_ooool0
1?l0003oooooooooool0000=ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooo
oooooooooooo000000gooooo00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0000=
ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000gooooo
00Co0000oooooooooooo00003Oooool01Ol0003ooooooooooooooooo000000gooooo00Go0000oooo
ooooooooooooo`000007ooooo`40000000000`00003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool2o`00
00Cooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00;ooooo0_l0000:ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o00002_ooool2o`00
00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`;o00002_ooool2o`00
00Cooooo0_l0000:ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool2o`0000[ooooo0_l00004ooooo`;o00002_ooool2o`00
00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo0@000000000300000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`40000000000`00003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool10000000000<00000ooooool000000_ooool2o`0000Wooooo0_l0
0005ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`;o00002_ooool2o`0000Cooooo0_l0
000:ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`;o00001Oooool00ol0003ooooooooo
o`08ooooo`;o00001?ooool2o`0000[ooooo00?o0000ooooooooool00oooool2o`0000Wooooo0_l0
0005ooooo`;o00002Oooool2o`0000Gooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0_l0
000:ooooo`03o`000?oooooooooo00?ooooo0_l00009ooooo`;o00001Oooool00ol0003ooooooooo
o`08ooooo`;o00001?ooool2o`0000[ooooo0_l00004ooooo`;o00002_ooool00ol0003ooooooooo
o`03ooooo`;o00002Oooool2o`0000?ooooo0@000000000500000?ooooooooooooooool000003Ooo
ool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo0000
00gooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000000gooooo00Go0000oooooooooooooooo
o`00000=ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?oooooooooo
ooooool000003Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`010000000000D00000ooooooooooooooooo`00000=ooooo`04o`000?ooooooooooo`0000ko
oooo00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo
000000kooooo00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0000>ooooo`04o`00
0?ooooooooooo`0000kooooo00?o0000ooooool000003_ooool01?l0003oooooooooool0000>oooo
o`04o`000?ooooooooooo`0000kooooo00Co0000oooooooooooo00003_ooool00ol0003oooooo`00
000>ooooo`04o`000?ooooooooooo`0000kooooo00Co0000oooooooooooo00003_ooool01?l0003o
ooooooooool0000=ooooo`03o`000?oooooooooo0040000000001000003oooooo`000?l0000?oooo
o`?o00003oooool2o`00013ooooo0_l0000?ooooo`?o00003oooool2o`00013ooooo0_l0000@oooo
o`;o00003oooool3o`0000oooooo0_l0000@ooooo`;o00004?ooool2o`0000oooooo0ol0000?oooo
o`;o00004?ooool2o`0000oooooo0ol0000?ooooo`7o00000Oooool10000000000@00000ooooool0
003o00003oooool3o`0000oooooo0_l0000@ooooo`;o00003oooool3o`0000oooooo0ol0000?oooo
o`;o00004?ooool2o`0000oooooo0ol0000?ooooo`;o00004?ooool2o`0000oooooo0ol0000?oooo
o`?o00003oooool2o`00013ooooo0_l0000?ooooo`?o00003oooool1o`00007ooooo0@0000000003
00000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00@000000000500000?ooooooooooooooool0
00003Oooool00ol0003oooooooooo`02o`0000cooooo00Co0000oooooooooooooooo0_l0000<oooo
o`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
0000ooooooooool00_l0000<ooooo`04o`000?ooooooooooooooo`;o00003?ooool01Ol0003ooooo
oooooooooooo000000gooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00;o
00003?ooool01?l0003oooooooooooooool2o`0000cooooo00Go0000ooooooooooooooooo`00000=
ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`02o`0000cooooo00Co0000
oooooooooooooooo0_l0000<ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`010000000000<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`;o00001Ooo
ool00ol0003oooooooooo`08ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool2o`0000Gooooo00?o0000ooooooooool02?oo
ool2o`0000Gooooo00?o0000ooooooooool02?ooool2o`0000Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0_l00005ooooo`03o`000?oo
oooooooo00Sooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`;o00001Ooo
ool00ol0003oooooooooo`08ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`;o00001?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool2o`0000?ooooo0@000000000300000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool1
0000000000<00000ooooooooool00oooool00ol0003oooooo`00000;o`0000Cooooo00?o0000oooo
ool000002_l00005ooooo`03o`000?oooooo000000[o00001Oooool=o`0000Cooooo00?o0000oooo
ool000002ol00004ooooo`03o`000?oooooo000000[o00001Oooool=o`0000Gooooo3Ol00004oooo
o`03o`000?oooooo000000_o00001?ooool00ol0003oooooo`00000:o`0000Gooooo3Ol00004oooo
o`03o`000?oooooo000000_o00001?ooool00ol0003oooooo`00000;o`0000Cooooo00?o0000oooo
ool000002_l00005ooooo`go00001?ooool00ol0003oooooo`00000;o`00007ooooo0@0000000003
00000?oooooo000000Go00001_ooool00ol0003oooooooooo`02ooooo`Oo00001_ooool00ol0003o
ooooooooo`02ooooo`Oo00001_ooool00ol0003oooooooooo`02ooooo`Oo00001Oooool00ol0003o
ooooooooo`03ooooo`Ko00001_ooool00ol0003oooooooooo`02ooooo`Oo00001_ooool00ol0003o
ooooooooo`02ooooo`Oo00001_ooool00ol0003oooooooooo`02ooooo`Ko00001_ooool00ol0003o
ooooooooo`03ooooo`Ko00001_ooool00ol0003oooooooooo`02ooooo`Oo00001_ooool00ol0003o
ooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`Ko00001_ooool00ol0003o
ooooooooo`03ooooo`Ko00001_ooool00ol0003oooooooooo`02ooooo`Oo00001_ooool00ol0003o
ooooooooo`02ooooo`Oo00001Oooool00ol0003oooooooooo`03ooooo`Ko00001_ooool00ol0003o
ooooooooo`04ooooo`40000000000`00003oooooo`000004ooooo`?o00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo
0_l00005ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000Cooooo
00?o0000ooooooooool00_ooool2o`0000Cooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000Gooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`;o00001?ooool3o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000Cooooo
00?o0000ooooooooool00_ooool2o`0000Cooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000Cooooo
00?o0000ooooooooool00_ooool2o`0000Cooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`40000000000`00003oooooooooo`06ooooo`Go00000_ooool3o`0000Oooooo1Ol0
0003ooooo`?o00001oooool5o`0000;ooooo0ol00008ooooo`Go00000_ooool3o`0000Oooooo1_l0
0002ooooo`?o00001oooool5o`0000?ooooo0ol00007ooooo`Go00000_ooool3o`0000Sooooo1Ol0
0002ooooo`?o00001oooool6o`0000;ooooo0ol00007ooooo`Go00000_ooool4o`0000Oooooo1Ol0
0002ooooo`?o00002?ooool5o`0000;ooooo0ol00007ooooo`Co000000Coooooo`000?oooooooooo
0ol00007ooooo`Go00000_ooool4o`0000Oooooo1Ol00002ooooo`?o00002?ooool5o`0000;ooooo
0ol00002ooooo`40000000000`00003oooooooooo`06ooooo`03o`000?oooooooooo00Co00002ooo
ool00ol0003oooooooooo`04o`0000_ooooo00?o0000ooooool000001?l0000:ooooo`03o`000?oo
oooooooo00Co00002oooool00ol0003oooooooooo`04o`0000_ooooo00?o0000ooooooooool01?l0
000;ooooo`03o`000?oooooo000000Co00002_ooool00ol0003oooooooooo`04o`0000_ooooo00?o
0000ooooooooool01?l0000;ooooo`03o`000?oooooooooo00Co00002oooool00ol0003oooooo`00
0003o`0000_ooooo00?o0000ooooooooool01?l0000;ooooo`03o`000?oooooooooo00Co00002ooo
ool00ol0003oooooooooo`04o`0000_ooooo00?o0000ooooool000000ol0000;ooooo`03o`000?oo
oooooooo00Co00001Oooool10000000000<00000ooooooooool01oooool3o`0000;ooooo0_l0000;
ooooo`?o00000_ooool2o`0000[ooooo00Co0000ooooool0003o00000_ooool00ol0003ooooooooo
o`09ooooo`05o`000?oooooo0000o`000?ooool00_l0000;ooooo`?o00000_ooool2o`0000_ooooo
0ol00002ooooo`;o00002_ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00Wo
oooo0ol00002ooooo`;o00002oooool3o`0000;ooooo0_l0000;ooooo`?o00000_ooool2o`0000[o
oooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`09ooooo`?o00000_ooool2o`00
00_ooooo0ol00002ooooo`;o00002oooool3o`0000;ooooo00?o0000ooooooooool02Oooool01Ol0
003oooooo`000?l0003ooooo00;o00002oooool3o`0000;ooooo0_l00004ooooo`40000000000`00
003oooooooooo`06ooooo`?o00001Oooool2o`0000Sooooo0ol00004ooooo`?o00002?ooool2o`00
00Gooooo0_l00009ooooo`;o00001Oooool2o`0000Sooooo0ol00005ooooo`;o00002?ooool3o`00
00Cooooo0ol00008ooooo`;o00001Oooool2o`0000Wooooo0_l00005ooooo`;o00002?ooool3o`00
00Cooooo0ol00008ooooo`;o00001Oooool3o`0000Sooooo0_l00005ooooo`;o00002Oooool2o`00
00Gooooo0_l00008ooooo`?o00001?ooool3o`0000Sooooo0_l00005ooooo`?o00002?ooool2o`00
00Gooooo0_l00008ooooo`?o00001Oooool2o`0000;ooooo0@000000000300000?oooooo000000Go
oooo1?l00007ooooo`;o00001Oooool01?l0003oooooo`000?l00006ooooo`?o00001Oooool2o`00
0003ooooool0003ooooo00Gooooo0ol00004ooooo`?o000000?oooooo`000?ooool01Oooool2o`00
00Gooooo1?l00007ooooo`;o00001Oooool01?l0003oooooo`000?l00006ooooo`?o00001?ooool3
o`000003ooooool0003ooooo00Gooooo0ol00004ooooo`?o000000?oooooo`000?ooool01Oooool2
o`0000Gooooo1?l00007ooooo`;o00001Oooool2o`000003ooooool0003ooooo00Gooooo0ol00004
ooooo`?o000000?oooooo`000?ooool01Oooool2o`0000Gooooo1?l00007ooooo`;o00001Oooool4
o`0000Oooooo0_l00005ooooo`;o000000?oooooo`000?ooool01Oooool3o`0000Cooooo0ol00000
0ooooooo0000ooooo`05ooooo`;o00001Oooool4o`0000Oooooo0Ol00001ooooo`40000000000`00
003oooooooooo`02o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`06oooo
o`;o000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_l000001Ooooooo0000oooooooooooo000000Oooooo0_l00002ooooo`?o00000_oo
ool00ol0003oooooooooo`06ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oo
oooooooo00Kooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02o`000005ooooool0003oooooooooool000001oooool2o`0000;o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`06ooooo`;o00000_ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l000001Ooooooo
0000oooooooooooo000000Oooooo0_l00002ooooo`;o000000Coooooo`000?oooooo00002?ooool2
o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`06ooooo`;o000000Gooooo
o`000?l0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l0
00001Ooooooo0000oooooooooooo000000Oooooo0_l00002ooooo`?o00000_ooool00ol0003ooooo
ooooo`06ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo
0@000000000300000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oo
oooooooo00Kooooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00Kooooo0_l0
0002ooooo`05o`000?ooooooooooooooool000002Oooool2o`0000;ooooo00Go0000oooooooooooo
ooooo`000008ooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`06ooooo`?o
000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`07ooooo`;o00000_ooool01Ol0003o
oooooooooooooooo000000Wooooo0_l00002ooooo`05o`000?ooooooooooooooool000002?ooool3
o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01_ooool3o`000003ooooool0003o
oooo00;ooooo00?o0000ooooooooool01oooool2o`0000;ooooo00Go0000ooooooooooooooooo`00
0009ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Sooooo0ol000000ooooooo0000
ooooo`03ooooo`03o`000?oooooooooo00Kooooo0ol000000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Oooooo0_l00002ooooo`05o`000?ooooooooooooooool000002Oooool2o`000003
ooooool0003ooooo00?ooooo00?o0000ooooooooool01Oooool10000000000D00000oooooooooooo
ooooo`000002ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000;o
00001?ooool00ol0003oooooooooo`05ooooo`;o000000Coooooo`000?l0003o00001?ooool00ol0
003oooooooooo`05ooooo`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`05ooooo`;o000000Coooooo`00
0?l0003o00001?ooool00ol0003oooooooooo`05ooooo`;o000000Coooooo`000?l0003o00001?oo
ool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l000001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`05ooooo`;o000000Co
ooooo`000?l0003o00001?ooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l00000
1Oooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l000001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000;o00001?ooool00ol0003oooooooooo`05ooooo`;o0000
00Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l0
00001Oooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`000?l000001Oooool00ol0003o
ooooooooo`04ooooo`40000000001000003oooooooooool00005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool10000000000<00000ooooool000000oooool01Ol0003ooooo
oooooooooooo000000Cooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo
00;o00001?ooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool00_l00003
ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo0_l00004ooooo`04o`00
0?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`02o`0000Cooooo00Co0000oooooooo
oooooooo0_l00003ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`02oooo
o`;o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l00004ooooo`04o`000?ooooooooooooooo`;o0000
0oooool00ol0003oooooooooo`02o`0000Cooooo00Co0000oooooooooooooooo0_l00003ooooo`03
o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00000oooool0
0ol0003oooooooooo`02o`0000Cooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oo
oooooooo00;o00000oooool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003ooooooooo
o`02o`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`40000000000`00003ooooooooo
o`02ooooo`;o00001?ooool2o`0000?ooooo00Co0000ooooool0003o00000oooool00ol0003ooooo
ooooo`03ooooo`;o00000_ooool01?l0003oooooooooool00003ooooo`;o00001?ooool3o`0000;o
oooo00Co0000ooooool0003o00000oooool2o`0000Cooooo0ol00002ooooo`04o`000?oooooo0000
o`0000?ooooo0_l00004ooooo`;o00000oooool01?l0003oooooo`000?l00003ooooo`03o`000?oo
oooooooo00?ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo0_l00004ooooo`?o0000
0_ooool01?l0003oooooo`000?l00003ooooo`;o00001?ooool2o`0000?ooooo00Co0000ooooool0
003o00000oooool00ol0003oooooooooo`03ooooo`;o00000oooool01?l0003oooooo`000?l00003
ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`04o`000?ooooooooooo`0000?ooooo0_l0
0004ooooo`?o00000_ooool01?l0003oooooo`000?l00003ooooo`;o00001?ooool2o`0000?ooooo
00Co0000ooooool0003o00000oooool00ol0003oooooooooo`03ooooo`;o00000_ooool01?l0003o
ooooooooool00003ooooo`;o00001?ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool2
o`0000Cooooo0ol00002ooooo`04o`000?oooooo0000o`0000?ooooo0_l00004ooooo`;o00000ooo
ool01Ol0003oooooo`000?l0003ooooo0040000000000`00003oooooooooo`0:ooooo`05o`000?oo
ooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000gooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooooooo
oooo000000gooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000gooooo00Go0000oooooooo
ooooooooo`00000=ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?oo
ooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000000oooool10000
000000<00000ooooooooool00_l00009ooooo`04o`000?oooooo0000o`0000?ooooo0_l00009oooo
o`03o`000?oooooo000000Cooooo0_l00008ooooo`Co00001?ooool00ol0003oooooooooo`07oooo
o`Co00000oooool2o`0000Wooooo00?o0000ooooool000001?ooool2o`0000Sooooo0_l000000ooo
oooo0000ooooo`03ooooo`;o00002?ooool4o`0000Cooooo00?o0000ooooooooool01oooool4o`00
00?ooooo0_l00009ooooo`03o`000?oooooo000000Cooooo0_l00008ooooo`Co00001?ooool2o`00
00Sooooo1?l00004ooooo`03o`000?oooooooooo00Oooooo1?l00003ooooo`;o00002Oooool00ol0
003oooooo`000004ooooo`;o00002?ooool4o`0000Cooooo00?o0000ooooooooool01oooool4o`00
00Cooooo00?o0000ooooooooool01oooool4o`0000?ooooo0@000000000400000?ooooooooooo`00
00[ooooo1?l00003ooooo`03o`000?oooooooooo00Sooooo1?l00002ooooo`03o`000?oooooooooo
00Wooooo1?l00002ooooo`03o`000?oooooooooo00Wooooo0ol00003ooooo`03o`000?oooooooooo
00Sooooo1?l00002ooooo`03o`000?oooooooooo00Wooooo1?l00002ooooo`03o`000?oooooooooo
00Wooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo0ol00003ooooo`03o`000?oooooooooo
00Sooooo1?l00002ooooo`03o`000?oooooooooo00Wooooo1?l00002ooooo`03o`000?oooooooooo
00Wooooo0ol00003ooooo`03o`000?oooooooooo00Sooooo1?l00003ooooo`03o`000?oooooooooo
00Sooooo1?l00002ooooo`03o`000?oooooooooo00Wooooo1?l00002ooooo`03o`000?oooooooooo
00Wooooo0ol00003ooooo`03o`000?oooooooooo00Sooooo1?l00003ooooo`40000000000`00003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;o00003?ooool01?l0003oooooooooooooool2o`00
00cooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`02o`0000cooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`02o`0000gooooo00?o0000oooooooo
ool00_l0000<ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo
000000gooooo00?o0000ooooooooool00_l0000=ooooo`03o`000?oooooooooo00;o00003?ooool0
1Ol0003ooooooooooooooooo000000gooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`00
0?oooooooooo00;o00000_ooool10000000000<00000ooooool000002Oooool2o`0000Cooooo0ol0
0009ooooo`;o00001?ooool3o`0000Wooooo00?o0000ooooooooool00oooool2o`0000Wooooo0_l0
0004ooooo`?o00002Oooool2o`0000Cooooo0ol00009ooooo`;o00001?ooool2o`0000[ooooo00?o
0000ooooooooool00_ooool3o`0000Wooooo0_l00004ooooo`?o00002Oooool2o`0000Cooooo0ol0
0009ooooo`;o00001?ooool2o`0000[ooooo00?o0000ooooooooool00_ooool3o`0000Wooooo0_l0
0004ooooo`?o00002Oooool2o`0000Cooooo0ol00009ooooo`;o00001?ooool2o`0000[ooooo00?o
0000ooooooooool00_ooool3o`0000Wooooo0_l00004ooooo`;o00000Oooool10000000000@00000
ooooool0003o00002?ooool00ol0003oooooooooo`03ooooo`Co00001oooool00ol0003ooooooooo
o`04ooooo`Co00001oooool00ol0003oooooooooo`04ooooo`?o00002?ooool00ol0003ooooooooo
o`04ooooo`?o00002?ooool00ol0003oooooooooo`03ooooo`Co00001oooool00ol0003ooooooooo
o`04ooooo`Co00001oooool00ol0003oooooooooo`04ooooo`?o00002?ooool00ol0003ooooooooo
o`04ooooo`?o00001oooool00ol0003oooooooooo`04ooooo`Co00001oooool00ol0003ooooooooo
o`04ooooo`?o00002?ooool00ol0003oooooooooo`04ooooo`?o00002?ooool00ol0003ooooooooo
o`03ooooo`Co00001oooool00ol0003oooooooooo`04ooooo`Co00001oooool00ol0003ooooooooo
o`04ooooo`?o00002?ooool00ol0003oooooooooo`04ooooo`?o00002?ooool00ol0003ooooooooo
o`03ooooo`;o00000Oooool10000000000D00000ooooool0003oooooo`000006ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`;o00001_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooooooo`06ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooooooo00Kooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo0_l00006ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooo000000Kooooo00?o0000ooooooooool01_ooool2o`0000Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001_oo
ool00ol0003oooooooooo`07ooooo`40000000001P00003oooooooooool0003oooooo`0000?ooooo
0_l00007ooooo`03o`000?oooooooooo00?o00000oooool2o`0000Kooooo00Go0000oooooooooooo
0000ooooo`02o`0000?ooooo0_l00006ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool0
0ol0003oooooooooo`05ooooo`06o`000?ooooooooooo`000?oooooo00000oooool2o`0000Oooooo
00?o0000ooooooooool00ol00003ooooo`;o00001_ooool01Ol0003oooooooooool0003ooooo00;o
00000oooool2o`0000Kooooo00Ko0000oooooooooooo0000ooooool00004ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00ol00003ooooo`;o00001oooool01?l0003oooooo`000?oo
ool2o`0000?ooooo0_l00006ooooo`05o`000?ooooooooooo`000?ooool00_l00003ooooo`;o0000
1_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03o`0000?ooooo0_l00006ooooo`05o`000?ooooooooooo`000?ooool00_l00003
ooooo`;o00001_ooool01Ol0003oooooooooool0003ooooo00;o00000oooool00ol0003ooooooooo
o`05ooooo`06o`000?ooooooooooo`000?oooooo00000oooool2o`0000Oooooo00?o0000oooooooo
ool00@000000000600000?ooooooooooooooool0003ooooo0_l000000ooooooo0000ooooo`05oooo
o`;o00000oooool01_l0003oooooooooool0003oooooo`0000Oooooo0_l00003ooooo`06o`000?oo
oooo0000o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo0000o`00
0?oooooo00001_ooool2o`0000Cooooo00Ko0000ooooool0003o0000ooooool00006ooooo`;o0000
0oooool01_l0003oooooooooool0003oooooo`0000Oooooo0_l00003ooooo`06o`000?oooooo0000
o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo0000o`000?oooooo
00001_ooool2o`0000?ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`05ooooo`;o
00000oooool01_l0003oooooooooool0003oooooo`0000Oooooo0_l00003ooooo`06o`000?oooooo
0000o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo0000o`000?oo
oooo00001_ooool2o`0000?ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`05oooo
o`;o00000oooool01_l0003oooooooooool0003oooooo`0000Oooooo0_l00003ooooo`06o`000?oo
oooo0000o`000?oooooo00001oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo0000o`00
0?oooooo00001_ooool2o`0000?ooooo0@000000000300000?oooooooooo00Cooooo0_l0000@oooo
o`;o00004?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo0_l0000@oooo
o`;o00004?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo0_l0000@oooo
o`;o00004?ooool00ol0003oooooooooo`0>ooooo`;o00004?ooool2o`00013ooooo0_l0000@oooo
o`03o`000?oooooooooo00kooooo0_l0000<ooooo`40000000001@00003ooooooooooooooooo0000
00;ooooo0ol00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000ol00005oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l00006ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooool000000_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00ol00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l00006oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l00006ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00ol00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000ol00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l00006oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l00006ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00ol00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000ol00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l00006oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooool000000_l00006ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00ol00006ooooo`03o`000?oooooooooo00;ooooo0@0000000003
00000?oooooooooo00;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00001oooool2o`00
00;ooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo
00Gooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00001oooool2o`0000;ooooo0_l00003
ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o00001_ooool2o`0000?ooooo0_l00003
ooooo`03o`000?oooooooooo00Gooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00001ooo
ool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`03o`000?oo
oooooooo00Gooooo0_l00003ooooo`;o00000_ooool2o`0000Oooooo0_l00003ooooo`04o`000?oo
ooooooooooooo`;o00001oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool01?l0003ooooo
ooooooooool2o`0000?ooooo00?o0000ooooooooool01Oooool2o`0000?ooooo0_l00002ooooo`;o
00001oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l00005ooooo`40000000000`00003o
ooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo0_l00004ooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool2o`0000Cooooo00?o0000ooooooooool02Oooool2o`0000Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`;o00001?ooool00ol0003o
ooooooooo`09ooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool2o`0000Cooooo00?o0000ooooooooool02Oooool2o`0000Co
oooo00?o0000ooooooooool01oooool10000000000L00000ooooooooooooooooo`000?oooooo0000
00Gooooo0_l00008ooooo`03o`000?oooooo000000Cooooo0ol00008ooooo`03o`000?oooooo0000
00Cooooo0ol00008ooooo`03o`000?oooooo000000Cooooo0ol00007ooooo`03o`000?oooooo0000
00Gooooo0_l00008ooooo`03o`000?oooooo000000Cooooo0ol00008ooooo`03o`000?oooooo0000
00Cooooo0ol00008ooooo`03o`000?oooooo000000Cooooo0ol00007ooooo`03o`000?oooooo0000
00Gooooo0_l00008ooooo`03o`000?oooooo000000Cooooo0ol00008ooooo`03o`000?oooooo0000
00Cooooo0ol00008ooooo`03o`000?oooooo000000Cooooo0_l00008ooooo`03o`000?oooooo0000
00Cooooo0ol00008ooooo`03o`000?oooooo000000Cooooo0ol00008ooooo`03o`000?oooooo0000
00Cooooo0ol00007ooooo`03o`000?oooooo000000Gooooo0_l00007ooooo`40000000000`00003o
ooooooooo`02o`0000;ooooo00?o0000ooooooooool00oooool3o`0000Gooooo0_l00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Cooooo0ol00005ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`?o00001Oooool2o`00
00;ooooo00?o0000ooooooooool00oooool2o`0000Kooooo00Go0000ooooooooooooooooo`000004
ooooo`?o00001Oooool2o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo0_l00002
ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`;o00000_ooool00ol0003oooooooooo`03
ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000Cooooo0ol00005ooooo`;o00000_oo
ool00ol0003oooooooooo`03ooooo`?o00001Oooool2o`0000;ooooo00?o0000ooooooooool00ooo
ool3o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`05o`000?oo
ooooooooooooool000001?ooool3o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo
0ol00005ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`?o00001Oooool10000000000<0
0000ooooool000002Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool01oooool01?l0003oooooooooool00005ooooo`40000000000`00003oooooo`00
0005ooooo`04o`000?ooooooooooo`0000Cooooo0_l000000ooooooo0000ooooo`05ooooo`04o`00
0?ooooooooooo`0000Cooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo
000000?ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001?oo
ool2o`0000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`;o0000
00?oooooo`000?ooool01Oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`00
00Gooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00001?ooool2o`000003ooooool0003ooooo00Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000ooooooooooooooooo`000003
ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Cooooo0_l0
00000ooooooo0000ooooo`05ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo
00001Oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o00000_ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Cooooo0_l00003ooooo`40000000000`00003oooooooooo`06
ooooo`03o`000?oooooo000000Gooooo0ol00006ooooo`03o`000?oooooo000000Kooooo0_l00007
ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`03o`000?oooooo000000Kooooo0_l00007
ooooo`03o`000?oooooo000000Gooooo0ol00006ooooo`03o`000?oooooo000000Kooooo0_l00007
ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`03o`000?oooooo000000Gooooo0ol00006
ooooo`03o`000?oooooo000000Kooooo0ol00006ooooo`03o`000?oooooo000000Kooooo0_l00007
ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`03o`000?oooooo000000Gooooo0ol00006
ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`03o`000?oooooo000000Kooooo0_l00007
ooooo`03o`000?oooooo000000Kooooo0_l00007ooooo`03o`000?oooooo000000Gooooo0ol00001
ooooo`40000000000`00003oooooooooo`06ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool00ol0003oooooooooo`05ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00007oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`;o00001oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o0000oooo
ooooool01Oooool2o`0000Sooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007oooo
o`;o00000Oooool10000000000<00000ooooool000001_ooool2o`0000Kooooo00Co0000ooooool0
003o00001_ooool2o`0000Kooooo00Co0000ooooool0003o00001_ooool00ol0003oooooooooo`05
ooooo`04o`000?oooooo0000o`0000Gooooo0_l00006ooooo`04o`000?ooooooooooo`0000Kooooo
0_l00006ooooo`04o`000?oooooo0000o`0000Kooooo0_l00006ooooo`04o`000?oooooo0000o`00
00Kooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00005ooooo`;o00001_ooool0
1?l0003oooooooooool00006ooooo`;o00001_ooool01?l0003oooooo`000?l00006ooooo`;o0000
1_ooool01?l0003oooooo`000?l00005ooooo`;o00001oooool01?l0003oooooo`000?l00005oooo
o`;o00001_ooool01?l0003oooooooooool00006ooooo`;o00001_ooool01?l0003oooooo`000?l0
0006ooooo`;o00001_ooool01?l0003oooooo`000?l00005ooooo`;o00001oooool00ol0003ooooo
o`000006ooooo`;o00001_ooool01?l0003oooooooooooooool10000000000<00000ooooooooool0
0ol00002ooooo`04o`000?ooooooooooo`0000Cooooo0_l00003ooooo`;o00000oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oooooo000000Co
oooo0_l00003ooooo`?o00000oooool00ol0003oooooo`000004ooooo`;o00000oooool3o`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0
003oooooo`000004ooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooool000001?ooool2o`00
00?ooooo0ol00003ooooo`03o`000?oooooo000000Cooooo0_l00003ooooo`;o00000oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oooooo
000000Cooooo0_l00004ooooo`;o00000oooool00ol0003oooooo`000004ooooo`;o00000oooool3
o`0000?ooooo00?o0000ooooool000001?ooool2o`0000?ooooo0_l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooool000001?oo
ool2o`0000?ooooo0ol00003ooooo`03o`000?oooooo000000Cooooo0_l00003ooooo`?o00000_oo
ool01?l0003oooooooooool00004ooooo`;o00000oooool10000000000<00000ooooooooool00_oo
ool01?l0003oooooooooool0000>ooooo`03o`000?oooooo000000oooooo00?o0000ooooool00000
3_ooool01?l0003oooooooooool0000>ooooo`04o`000?ooooooooooo`0000kooooo00?o0000oooo
ool000003oooool00ol0003oooooo`00000>ooooo`04o`000?ooooooooooo`0000kooooo00Co0000
oooooooooooo00003_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooo000000kooooo00Co
0000oooooooooooo00003_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo000000oo
oooo00?o0000ooooool000003_ooool01?l0003oooooooooool0000<ooooo`40000000000`00003o
ooooooooo`03ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Sooooo0_l00003ooooo`03
o`000?oooooooooo00;o00001oooool2o`0000Cooooo00?o0000ooooooooool00_l00007ooooo`;o
00001?ooool01?l0003oooooooooool00008ooooo`;o00000oooool00ol0003oooooooooo`02o`00
00Sooooo0_l00003ooooo`03o`000?oooooooooo00;o00001oooool2o`0000Cooooo00?o0000oooo
ooooool00_l00007ooooo`;o00001?ooool01?l0003oooooooooool00008ooooo`;o00000oooool0
0ol0003oooooooooo`02o`0000Sooooo0_l00003ooooo`03o`000?oooooooooo00;o00001oooool2
o`0000Cooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00?o0000ooooooooool00_l0
0008ooooo`;o00000oooool00ol0003oooooooooo`02o`0000Sooooo0_l00003ooooo`03o`000?oo
oooooooo00;o00001oooool2o`0000Cooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo
00?o0000ooooooooool00_l00005ooooo`40000000000`00003oooooooooo`03ooooo`?o00000ooo
ool00ol0003oooooo`000009ooooo`?o00000oooool2o`0000[ooooo0ol00003ooooo`;o00002_oo
ool2o`0000?ooooo00?o0000ooooool000002Oooool3o`0000?ooooo00?o0000ooooool000002Ooo
ool3o`0000?ooooo0_l0000:ooooo`?o00000oooool2o`0000Wooooo00?o0000ooooool000000ooo
ool00ol0003oooooo`000009ooooo`?o00000oooool00ol0003oooooo`000009ooooo`?o00000ooo
ool2o`0000[ooooo0_l00003ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000000ooo
ool00ol0003oooooo`000009ooooo`?o00000oooool00ol0003oooooo`000009ooooo`?o00000ooo
ool2o`0000[ooooo0_l00003ooooo`03o`000?oooooo000000Wooooo0ol00003ooooo`03o`000?oo
oooo000000Kooooo0@000000000300000?oooooooooo00?ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Wooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool00003ooooo`;o00002Oooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`04
o`000?ooooooooooo`0000?ooooo0_l00009ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo0@00
0000000300000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool3o`000003ooooool0003o
oooo00Oooooo00Co0000oooooooooooooooo1Ol00008ooooo`03o`000?oooooooooo00;ooooo0_l0
00000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000oooo
o`07ooooo`04o`000?ooooooooooooooo`Go00002Oooool01?l0003oooooooooooooool5o`0000So
oooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000000Sooooo00?o0000oooooooo
ool00_ooool3o`000003ooooool0003ooooo00Oooooo00Co0000oooooooooooooooo1Ol00009oooo
o`04o`000?ooooooooooooooo`Go00002?ooool00ol0003oooooooooo`02ooooo`;o000000?ooooo
o`000?l000002?ooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?ooool01oooool0
1?l0003oooooooooooooool5o`0000Sooooo00?o0000ooooooooool00_ooool5o`0000Sooooo00?o
0000ooooooooool00_ooool2o`000003ooooool0003o000000Sooooo00?o0000ooooooooool00_oo
ool3o`000003ooooool0003ooooo00Gooooo0@000000000300000?oooooo00000?oo00007?l00001
ooooo`40000000000`00003oooooo`000007o`000004ooooool0003oooooo`0000Kooooo0ol00000
0ooooooo0000o`000002o`000004ooooool0003oooooo`0000Gooooo1?l000001_oooooo0000o`00
0?l0003oooooo`0000;ooooo00?o0000ooooooooool00oooool8o`000004ooooool0003oooooo`00
00Kooooo2?l000001?oooooo0000ooooool00006ooooo`?o000000?oooooo`000?l000000_l00000
1?oooooo0000ooooool00005ooooo`Co000000Koooooo`000?l0003o0000ooooool00002ooooo`03
o`000?oooooooooo00?ooooo2?l000001?oooooo0000ooooool00006ooooo`So000000Coooooo`00
0?oooooo00001Oooool4o`000003ooooool0003o000000?o00000_ooool00ol0003oooooooooo`03
ooooo`So000000Coooooo`000?oooooo00001_ooool8o`000004ooooool0003oooooo`0000Kooooo
2?l000001?oooooo0000ooooool00005ooooo`Co000000?oooooo`000?l000000ol00002ooooo`03
o`000?oooooooooo00?ooooo2?l000001?oooooo0000ooooool00006ooooo`So000000Coooooo`00
0?oooooo00001oooool10000000000@00000oooooooooooo00001_ooool;o`0000Kooooo3?l00006
ooooo`[o000000?oooooo`000?ooool01Oooool:o`000003ooooool0003ooooo00Gooooo2ol00006
ooooo`co00001_ooool:o`000003ooooool0003ooooo00Gooooo2_l000000ooooooo0000ooooo`05
ooooo`_o00001_ooool:o`000003ooooool0003ooooo00Gooooo2_l000000ooooooo0000ooooo`05
ooooo`[o000000?oooooo`000?ooool01Oooool;o`0000Kooooo2_l000000ooooooo0000ooooo`05
ooooo`[o000000?oooooo`000?ooool01Oooool:o`00007ooooo0@000000000300000?oooooo0000
00Kooooo1Ol000000ooooooo0000o`000002o`000003ooooool0003ooooo00Gooooo2Ol00002oooo
o`03o`000?oooooooooo00Cooooo2Ol000000ooooooo0000ooooo`06ooooo`Co000000?oooooo`00
0?l000000_l000000ooooooo0000ooooo`05ooooo`Go000000Coooooo`000?l0003o00000_ooool0
0ol0003oooooooooo`04ooooo`Wo000000?oooooo`000?ooool01_ooool9o`000003ooooool0003o
oooo00Kooooo1?l000000ooooooo0000o`000002o`000003ooooool0003ooooo00Gooooo1Ol00000
1?oooooo0000o`000?l00002ooooo`03o`000?oooooooooo00Cooooo2Ol000000ooooooo0000oooo
o`06ooooo`Wo000000?oooooo`000?ooool01_ooool4o`000003ooooool0003o000000;o000000?o
ooooo`000?ooool01Oooool9o`0000;ooooo00?o0000ooooooooool01?ooool9o`000003ooooool0
003ooooo00Kooooo1?l000000ooooooo0000o`000002o`000003ooooool0003ooooo00Gooooo1Ol0
00000ooooooo0000o`000002o`0000;ooooo0@000000000300000?oooooooooo00Gooooo0_l00006
ooooo`Co00001Oooool3o`0000Kooooo1?l00005ooooo`;o00001oooool4o`0000Gooooo0_l00007
ooooo`?o00001Oooool3o`0000Kooooo1?l00005ooooo`?o00001_ooool4o`0000Gooooo0_l00007
ooooo`?o00001_ooool2o`0000Oooooo0ol00005ooooo`?o00001_ooool4o`0000Gooooo0ol00006
ooooo`Co00001Oooool2o`0000Oooooo0ol00006ooooo`;o00001_ooool4o`0000Gooooo0ol00006
ooooo`Co00001Oooool2o`0000Oooooo1?l00005ooooo`;o00001oooool3o`0000Kooooo0_l00006
ooooo`Co00000Oooool10000000000<00000ooooool000001_l00008ooooo`[o00002?ooool9o`00
00Wooooo2Ol00008ooooo`03o`000?oooooo000000Oo00002?ooool8o`000003ooooool0003ooooo
00Oooooo2Ol00008ooooo`03o`000?oooooo000000Oo00002?ooool00ol0003oooooo`000007o`00
00Sooooo2?l000000ooooooo0000ooooo`07ooooo`Wo00002?ooool00ol0003oooooo`000007o`00
00Sooooo2_l00008ooooo`So000000?oooooo`000?ooool01oooool9o`0000Sooooo00?o0000oooo
ool000001ol00008ooooo`?o00000Oooool10000000000<00000ooooool000001Ol00009ooooo`Wo
00002Oooool9o`0000Wooooo2Ol00009ooooo`So00002Oooool9o`0000Wooooo2Ol00009ooooo`So
00002_ooool8o`0000Wooooo2Ol00009ooooo`Wo00002Oooool8o`0000[ooooo2?l00009ooooo`Wo
00002Oooool9o`0000Wooooo2?l00009ooooo`?o00000Oooool10000000000<00000ooooooooool0
0_ooool01?l0003oooooo`000?l00007ooooo`;o00001?ooool5o`0000Oooooo0_l00004ooooo`Go
00001_ooool2o`0000Gooooo1?l00007ooooo`;o00001Oooool01?l0003oooooo`000?l00007oooo
o`;o00001?ooool5o`0000Oooooo0_l00004ooooo`Go00001_ooool2o`0000Gooooo00Co0000oooo
ool0003o00001oooool2o`0000Cooooo1Ol00007ooooo`;o00001?ooool5o`0000Oooooo0_l00004
ooooo`Go00001_ooool2o`0000Gooooo00Co0000ooooool0003o00001oooool2o`0000Cooooo1Ol0
0007ooooo`;o00001?ooool5o`0000Oooooo00?o0000ooooooooool00oooool5o`0000Kooooo0_l0
0005ooooo`04o`000?oooooo0000o`0000Oooooo0_l00003ooooo`40000000000`00003ooooooooo
o`03ooooo`;o000000Coooooo`000?l0003ooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo
0_l000001?oooooo0000o`000?ooool5o`000003ooooool0003ooooo00?ooooo1_l000000ooooooo
0000o`000003o`000003ooooool0003ooooo00?ooooo1_l000000ooooooo0000o`000002o`0000;o
oooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Go000000?oooooo`00
0?ooool01?ooool2o`000004ooooool0003o0000ooooo`Go000000?oooooo`000?ooool00oooool6
o`000003ooooool0003o000000?o000000?oooooo`000?ooool00oooool6o`000003ooooool0003o
000000;o00000_ooool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?l0003ooooo1Ol0
00000ooooooo0000ooooo`03ooooo`?o000000Coooooo`000?l0003ooooo1Ol000000ooooooo0000
ooooo`03ooooo`Ko000000?oooooo`000?l000000ol000000ooooooo0000ooooo`03ooooo`Go0000
0_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Go
000000?oooooo`000?ooool00oooool3o`000004ooooool0003o0000ooooo`Go000000?oooooo`00
0?ooool00oooool6o`000003ooooool0003o000000?o000000?oooooo`000?ooool00oooool2o`00
0004ooooool0003o0000ooooo`Go00000_ooool1o`00007ooooo0@000000000300000?oooooooooo
00;ooooo00Go0000oooooooooooo0000ooooo`03o`0000Kooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooo000000;o00001_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000ooooool0003o00001oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;o00001_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000_l00006
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000002o`0000Kooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?oooooo0000o`0000Oooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`000002o`0000Kooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooo000000;o00001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000ooooool0003o00001oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool2o`00
00Oooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002o`0000Kooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;o00001_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000ooooool0003o00001oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;o00001_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooool000000_l00006ooooo`7o00000Oooool10000000000D00000ooooooooooooooooo`000003
ooooo`?o00000_ooool4o`0000Gooooo00?o0000ooooooooool01?l000000ooooooo0000o`000002
o`0000Kooooo00?o0000ooooooooool01?l000000ooooooo0000o`000002o`0000Kooooo00?o0000
ooooooooool00ol00002ooooo`Co00001Oooool00ol0003oooooooooo`04o`000003ooooool0003o
000000;o00001_ooool00ol0003oooooooooo`04o`000003ooooool0003o000000;o00001_ooool0
0ol0003oooooooooo`04o`000003ooooool0003o000000;o00001_ooool00ol0003oooooooooo`03
o`0000;ooooo1?l00005ooooo`03o`000?oooooooooo00Co000000?oooooo`000?l000000_l00006
ooooo`03o`000?oooooooooo00Co000000?oooooo`000?l000000_l00006ooooo`03o`000?oooooo
oooo00Co000000?oooooo`000?l000000_l00006ooooo`03o`000?oooooooooo00?o00000_ooool4
o`0000Gooooo00?o0000ooooooooool01?l000000ooooooo0000o`000002o`0000Kooooo00?o0000
ooooooooool01?l000000ooooooo0000o`000002o`0000Kooooo00?o0000ooooooooool01?l00000
0ooooooo0000o`000002o`0000Gooooo00Co0000oooooooooooooooo0ol00002ooooo`Co00001?oo
ool10000000000@00000ooooool0003ooooo1?l00003ooooo`Ko00000oooool6o`0000?ooooo1_l0
0003ooooo`Go00000oooool7o`0000;ooooo00?o0000ooooool000000ol00003ooooo`Ko00000ooo
ool00ol0003oooooo`000003o`0000?ooooo1_l00003ooooo`Go00001?ooool6o`0000?ooooo1Ol0
0003ooooo`Oo00000_ooool00ol0003oooooo`000003o`0000?ooooo1_l00003ooooo`03o`000?oo
oooo000000?o00000oooool6o`0000?ooooo1Ol00004ooooo`Ko00000oooool5o`0000?ooooo1_l0
0003ooooo`03o`000?oooooo000000?o00000oooool6o`0000?ooooo00?o0000ooooool000000ol0
0003ooooo`Ko00000oooool5o`0000Cooooo1_l00002ooooo`03o`000?oooooo000000?o00000ooo
ool6o`0000?ooooo00?o0000ooooool000000ol00003ooooo`Ko00001?ooool10000000000@00000
ooooool0003o00002_ooool2o`000004ooooool0003oooooooooo`;o00002_ooool01Ol0003ooooo
ooooool0003ooooo00?o00002Oooool2o`000004ooooool0003oooooooooo`;o00002_ooool2o`00
0004ooooool0003oooooooooo`;o00002_ooool01?l0003oooooooooool00002ooooo`;o00002_oo
ool00ol0003oooooo`000002ooooo`?o00002Oooool2o`000004ooooool0003oooooooooo`;o0000
2_ooool2o`000004ooooool0003oooooooooo`;o00002_ooool01Ol0003oooooooooool0003ooooo
00?o00002Oooool2o`000004ooooool0003oooooooooo`?o00002Oooool2o`000004ooooool0003o
ooooooooo`;o00002_ooool2o`000004ooooool0003oooooooooo`;o00002_ooool01Ol0003ooooo
ooooool0003ooooo00?o00002Oooool2o`000004ooooool0003oooooooooo`?o00002Oooool2o`00
0004ooooool0003oooooooooo`;o00002_ooool2o`000003ooooool0003ooooo00;ooooo0@000000
000500000?oooooo0000ooooool000002?ooool00ol0003oooooo`000006o`0000Sooooo0_l00000
0ooooooo0000o`000005o`0000Sooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o
000000Sooooo2?l000000ooooooo0000ooooo`07ooooo`03o`000?oooooo000000Ko00002?ooool2
o`000003ooooool0003o000000Go00002?ooool2o`000003ooooool0003o000000?o000000?ooooo
o`000?ooool01oooool9o`0000Wooooo00?o0000ooooool000001_l00008ooooo`;o000000?ooooo
o`000?l000001Ol00008ooooo`;o000000?oooooo`000?l000000ol000000ooooooo0000ooooo`07
ooooo`03o`000?oooooo000000Ko00002Oooool00ol0003oooooo`000006o`0000Sooooo0_l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Sooooo0_l000000ooooooo0000o`000003
o`000003ooooool0003ooooo00Oooooo00?o0000ooooool000001?l00001ooooo`40000000000`00
003oooooo`000002o`0000Oooooo1?l00002ooooo`Go00001_ooool5o`0000;ooooo1Ol00006oooo
o`Go00000_ooool5o`0000Kooooo1Ol000000ooooooo0000o`000003o`0000Oooooo1?l00002oooo
o`Go00001_ooool5o`0000;ooooo1Ol00006ooooo`Go000000?oooooo`000?l000000ol00007oooo
o`Co00000_ooool5o`0000Oooooo1?l00002ooooo`Go00001_ooool5o`0000;ooooo1Ol00006oooo
o`Go000000?oooooo`000?l000000ol00007ooooo`Co00000_ooool5o`0000Oooooo1?l00002oooo
o`Go00001_ooool5o`0000;ooooo1Ol00006ooooo`Go000000?oooooo`000?l000000ol00007oooo
o`Co00000_ooool2o`00007ooooo0@000000000300000?oooooooooo00?o00001?ooool2o`0000Oo
oooo00Co0000ooooool0003o00001?ooool3o`0000Kooooo00?o0000ooooooooool00_l00004oooo
o`?o00001_ooool00ol0003oooooo`000002o`0000Cooooo0_l00007ooooo`03o`000?oooooo0000
00;o00001?ooool2o`0000Oooooo00Co0000ooooool0003o00001?ooool3o`0000Kooooo00?o0000
ooooooooool00_l00004ooooo`;o00001oooool00ol0003oooooo`000002o`0000Cooooo0_l00007
ooooo`04o`000?oooooo0000o`0000Cooooo0ol00007ooooo`04o`000?oooooo0000o`0000Cooooo
0ol00006ooooo`03o`000?oooooooooo00;o00001?ooool2o`0000Oooooo00?o0000ooooool00000
0_l00004ooooo`;o00001oooool01?l0003oooooo`000?l00004ooooo`?o00001_ooool00ol0003o
ooooooooo`02o`0000Cooooo0ol00006ooooo`03o`000?oooooo000000;o00001?ooool2o`0000Oo
oooo00?o0000ooooool000000_l00004ooooo`;o00001oooool1o`00007ooooo0@00000000030000
0?oooooooooo00;ooooo1Ol000000ooooooo0000ooooo`05ooooo`04o`000?ooooooooooooooo`So
00001_ooool01?l0003oooooooooooooool5o`000003ooooool0003o000000Gooooo00?o0000oooo
ooooool00_ooool5o`000003ooooool0003ooooo00Gooooo00?o0000ooooooooool00_ooool7o`00
00Kooooo00Co0000oooooooooooooooo2?l00006ooooo`04o`000?ooooooooooooooo`Go000000?o
ooooo`000?l000001Oooool00ol0003oooooooooo`02ooooo`Go000000?oooooo`000?ooool01Ooo
ool00ol0003oooooooooo`02ooooo`Oo00001_ooool01?l0003oooooooooooooool8o`0000Kooooo
00Co0000oooooooooooooooo1Ol000000ooooooo0000o`000005ooooo`03o`000?oooooooooo00;o
oooo1Ol000000ooooooo0000ooooo`05ooooo`04o`000?ooooooooooooooo`So00001_ooool01?l0
003oooooooooooooool5o`000003ooooool0003o000000Gooooo00?o0000ooooooooool00_ooool5
o`000003ooooool0003o000000Gooooo00?o0000ooooooooool00_ooool5o`000003ooooool0003o
oooo00Gooooo00?o0000ooooooooool00@000000000300000?oooooo000000;o000000Goooooo`00
0?l0003o0000ooooo`0@o`000003ooooool0003o000000_o000000Goooooo`000?l0003o0000oooo
o`0=o`000005ooooool0003o0000o`000?ooool03Ol000001Ooooooo0000o`000?l0003ooooo013o
000000?oooooo`000?l000002ol000001Ooooooo0000o`000?l0003ooooo00go000000Goooooo`00
0?l0003o0000ooooo`0=o`000004ooooool0003o0000oooooa7o000000?oooooo`000?l000002ol0
00001Ooooooo0000o`000?l0003ooooo00go000000Goooooo`000?l0003o0000ooooo`0=o`000004
ooooool0003o0000ooooo`go000000Goooooo`000?l0003o0000ooooo`0=o`000005ooooool0003o
0000o`000?ooool03Ol000001Ooooooo0000o`000?l0003ooooo00[o00000Oooool10000000000<0
0000ooooool000007_l000000ooooooo0000o`000014o`000003ooooool0003o000003;o000000?o
ooooo`000?l000003ol000000ooooooo0000o`00000bo`000003ooooool0003o000000oo000000?o
ooooo`000?l000009Ol00001ooooo`40000000000`00003oooooooooo`04ooooo`Co00001Oooool0
0ol0003oooooooooo`06ooooo`?o00001_ooool00ol0003oooooooooo`06ooooo`?o00001Oooool0
0ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000Gooooo00?o0000ooooooooool01_oo
ool4o`0000Gooooo00?o0000ooooooooool01_ooool3o`0000Gooooo00?o0000ooooooooool01ooo
ool3o`0000Gooooo00?o0000ooooooooool01_ooool01?l0003oooooo`000?l00005ooooo`03o`00
0?oooooooooo00Kooooo1?l00005ooooo`03o`000?oooooooooo00Kooooo0ol00005ooooo`03o`00
0?oooooooooo00Oooooo0ol00005ooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o
00001Oooool00ol0003oooooooooo`06ooooo`Co00001Oooool00ol0003oooooooooo`06ooooo`?o
00001Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000Gooooo00?o0000oooo
ooooool01_ooool4o`0000Gooooo00?o0000ooooooooool00_ooool10000000000<00000oooooooo
ool01Oooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool01oooool2o`000004
ooooool0003o0000o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`00
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0000;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool01oooool2o`00
0004ooooool0003o0000o`0000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02o`0000;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000002o`0000;ooooo00?o0000
ooooooooool00oooool10000000000<00000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo0@000000000300000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000oooool2o`0000Wooooo00?o0000ooooool000001?ooool2o`0000Wooooo00?o0000oooo
ool000001?ooool2o`0000Wooooo00?o0000ooooool000000oooool3o`0000Sooooo00Co0000oooo
oooooooo00000oooool2o`0000Wooooo00?o0000ooooool000001?ooool2o`0000Wooooo00?o0000
ooooool000001?ooool2o`0000Sooooo00Co0000oooooooooooo00000oooool3o`0000Sooooo00?o
0000ooooool000001?ooool2o`0000Wooooo00?o0000ooooool000001?ooool2o`0000Wooooo00?o
0000ooooool000001?ooool2o`0000Sooooo00Co0000oooooooooooo00000oooool2o`0000Wooooo
00?o0000ooooool000001?ooool2o`0000Wooooo00?o0000ooooool000001?ooool2o`0000Wooooo
00?o0000ooooool000001?ooool2o`0000Sooooo00Co0000oooooooooooo00000oooool2o`0000Ko
oooo0@000000000300000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool3o`0000Oooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?oooooo0000o`0000Oooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooo`000?l00007ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ool000001oooool01Ol0003ooooooooooooooooo000000?ooooo0ol00007ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooo`000?l00007ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000ooooool0003o00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo0ol00007ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooo`000?l00007ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooool000001oooool01Ol0003ooooooooooooooooo000000?ooooo0ol00007ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooo`000?l00007ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooool000001Oooool10000000000<00000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000?o
oooo0@000000000500000?ooooooooooooooool000001_ooool2o`0000Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`?o00001?ooool2o`0000?ooooo00?o0000ooooooooool00oooool3o`00
00Cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`05o`000?oooooooooo
ooooool000001_ooool2o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo0ol00004
ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`?o00001?ooool2o`0000;ooooo00?o0000
ooooooooool01?ooool2o`0000Gooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001?oo
ool2o`0000?ooooo00?o0000ooooooooool00oooool3o`0000Cooooo0_l00003ooooo`03o`000?oo
oooooooo00?ooooo0ol00004ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`;o00001Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0_l00004ooooo`;o00000oooool00ol0003ooooo
ooooo`03ooooo`?o00001?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool3o`0000Cooooo
0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00400000
00001000003oooooo`000?l00007ooooo`03o`000?oooooooooo00Gooooo0ol00007ooooo`03o`00
0?oooooooooo00Gooooo0ol00006ooooo`;o00001_ooool4o`0000Kooooo0_l00006ooooo`?o0000
1oooool00ol0003oooooooooo`05ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`?o0000
1_ooool2o`0000Kooooo1?l00006ooooo`;o00001_ooool3o`0000Oooooo00?o0000ooooooooool0
1Oooool3o`0000Kooooo0_l00007ooooo`?o00001_ooool2o`0000Kooooo1?l00006ooooo`;o0000
1_ooool3o`0000Oooooo00?o0000ooooooooool01Oooool3o`0000Kooooo0_l00007ooooo`?o0000
1_ooool2o`0000Kooooo0ol00007ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`400000
00001000003oooooooooool0000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0?ooooo`40000000000`00003oooooo`000002o`0000Gooooo00?o
0000ooooool000001_ooool4o`0000Gooooo00?o0000ooooool000001_ooool4o`0000Gooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Kooooo1?l0
0005ooooo`03o`000?oooooo000000Kooooo1?l00005ooooo`03o`000?oooooo000000Kooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000005ooooo`Co00001Oooool00ol0003oooooo`00
0006ooooo`Co00001Oooool00ol0003oooooo`000006ooooo`Co00001Oooool00ol0003oooooo`00
0006ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001_ooool4o`0000Gooooo00?o
0000ooooool000001_ooool4o`0000Gooooo00?o0000ooooool000001_ooool4o`0000Gooooo00?o
0000ooooool000001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000Kooooo1?l0
0005ooooo`03o`000?oooooo000000Kooooo0Ol00001ooooo`40000000000`00003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ooooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ooooool2o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0040
000000000`00003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`40000000000`00003oooooooooo`04
ooooo`;o00001Oooool01?l0003oooooooooool00007ooooo`;o00001Oooool01?l0003ooooooooo
ool00006ooooo`?o00001Oooool00ol0003oooooo`000007ooooo`?o00001?ooool01?l0003ooooo
ooooool00007ooooo`;o00001Oooool01?l0003oooooooooool00007ooooo`;o00001Oooool01?l0
003oooooooooool00006ooooo`?o00001Oooool00ol0003oooooo`000007ooooo`;o00001Oooool0
1?l0003oooooooooool00007ooooo`;o00001Oooool01?l0003oooooooooool00007ooooo`;o0000
1Oooool01?l0003oooooooooool00006ooooo`?o00001Oooool00ol0003oooooo`000007ooooo`;o
00001Oooool01?l0003oooooooooool00007ooooo`;o00001Oooool01?l0003oooooooooool00006
ooooo`?o00001Oooool00ol0003oooooo`000007ooooo`?o00001Oooool00ol0003oooooo`000007
ooooo`;o00001Oooool01?l0003oooooooooool00003ooooo`40000000000`00003oooooooooo`04
ooooo`04o`000?oooooo0000o`0000Cooooo0_l00008ooooo`03o`000?oooooo000000Gooooo0_l0
0008ooooo`03o`000?oooooo000000Cooooo0ol00007ooooo`04o`000?oooooo0000o`0000Cooooo
0_l00008ooooo`04o`000?oooooo0000o`0000Cooooo0_l00008ooooo`03o`000?oooooo000000Go
oooo0_l00008ooooo`?o00001?ooool3o`0000Oooooo00Co0000ooooool0003o00001?ooool2o`00
00Sooooo00Co0000ooooool0003o00001?ooool2o`0000Sooooo00?o0000ooooool000001Oooool2
o`0000Sooooo0ol00004ooooo`?o00001oooool01?l0003oooooo`000?l00004ooooo`;o00002?oo
ool01?l0003oooooo`000?l00004ooooo`;o00002?ooool00ol0003oooooo`000005ooooo`;o0000
2?ooool3o`0000Cooooo0ol00007ooooo`04o`000?oooooo0000o`0000Cooooo0_l00004ooooo`40
000000000`00003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`40
000000000`00003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000
ooooool00007ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l00007ooooo`03o`000?oooooooooo00;o
oooo0_l000001?oooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo0_l000001?oo
oooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000007
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooool0003oooooo`000007ooooo`03o`000?oo
oooooooo00;ooooo0_l000001?oooooo0000ooooool00007ooooo`03o`000?oooooooooo00;ooooo
0_l000001?oooooo0000ooooool00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_l00007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooool0003oooooo`000007oooo
o`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooool00007ooooo`03o`000?oooooo
oooo00;ooooo0_l000000ooooooo0000o`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_l00007ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooool0
0007ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooool00004ooooo`400000
00000`00003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool2o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool01?ooool2o`0000;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo00Cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool2o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001?ooool10000000000D00000ooooooooooooooooo`000009ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0
0003ooooo`40000000001@00003ooooooooooooooooo000000Kooooo0_l00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003o000000;ooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00;o
oooo00?o0000ooooooooool01?ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`03
o`000?oooooooooo00Cooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool01Oooool2o`000005ooooool0003o0000ooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`04
ooooo`;o00000_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool01?ooool2
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`;o000000Go
ooooo`000?l0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`;o0000
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00Gooooo0_l000001Ooooooo0000o`000?oooooo0000
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02o`000003ooooool0003ooooo
00;ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool1
0000000000@00000oooooooooooo00001_ooool2o`0000Cooooo1?l000000ooooooo0000ooooo`05
ooooo`03o`000?oooooooooo00?ooooo0ol000000ooooooo0000ooooo`05ooooo`;o00001Oooool3
o`000003ooooool0003ooooo00Gooooo0_l00004ooooo`Co000000?oooooo`000?ooool01Oooool0
0ol0003oooooooooo`03ooooo`?o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo0ol000000ooooooo0000ooooo`05ooooo`;o00001Oooool3o`000003ooooool0003o
oooo00Gooooo0_l00004ooooo`Co000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`03
ooooo`?o00000_ooool00ol0003oooooooooo`03ooooo`;o00001Oooool3o`000003ooooool0003o
oooo00Gooooo0_l00004ooooo`Co000000?oooooo`000?ooool01Oooool2o`0000Cooooo1?l00000
0ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooo
oooo00?ooooo0_l00005ooooo`?o000000?oooooo`000?ooool01Oooool2o`0000Cooooo1?l00000
0ooooooo0000ooooo`05ooooo`;o00001?ooool4o`00007ooooo0@000000000300000?oooooo0000
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooooooool01_ooool2o`0000Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooo`000006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01oooool2o`00
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool01oooool2o`0000Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`010000000000<00000ooooool000001Oooool00ol0003oooooooooo`08ooooo`;o
00001Oooool00ol0003oooooooooo`08ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`;o
00001_ooool00ol0003oooooooooo`07ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`;o
00001Oooool00ol0003oooooooooo`08ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`;o
00001_ooool00ol0003oooooooooo`07ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`;o
00001Oooool00ol0003oooooooooo`08ooooo`;o00001Oooool00ol0003oooooooooo`07ooooo`;o
00001Oooool00ol0003oooooooooo`08ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`;o
00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool2o`0000Gooooo00?o0000ooooooooool02?ooool1o`00007ooooo0@00000000040000
0?ooooooooooo`0000?ooooo0_l0000:ooooo`?o00000oooool00ol0003oooooooooo`08ooooo`04
o`000?oooooo0000o`0000;ooooo0_l0000:ooooo`04o`000?oooooo0000o`0000;ooooo0_l0000:
ooooo`03o`000?oooooo000000?ooooo0_l0000:ooooo`?o00000oooool00ol0003oooooooooo`08
ooooo`04o`000?oooooo0000o`0000;ooooo0_l0000:ooooo`04o`000?oooooo0000o`0000;ooooo
0_l0000:ooooo`03o`000?oooooo000000?ooooo0_l0000:ooooo`?o00000oooool00ol0003ooooo
ooooo`08ooooo`04o`000?oooooo0000o`0000;ooooo0_l0000:ooooo`03o`000?oooooo000000?o
oooo0_l0000:ooooo`?o00000oooool2o`0000Wooooo00Co0000ooooool0003o00000oooool00ol0
003oooooooooo`08ooooo`04o`000?oooooo0000o`0000;ooooo0_l0000:ooooo`03o`000?oooooo
000000?ooooo0_l0000:ooooo`7o00000Oooool10000000000L00000ooooooooooooooooo`000?oo
oooo000000_ooooo00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000[ooooo00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`08ooooo`07o`00
0?ooooooooooooooool0003oooooo`00000;ooooo`07o`000?ooooooooooooooool0003oooooo`00
000;ooooo`07o`000?ooooooooooooooool0003oooooo`00000;ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool02?ooool01ol0003ooooooooooooooooo0000ooooool000002ooo
ool01ol0003ooooooooooooooooo0000ooooool000002oooool01ol0003ooooooooooooooooo0000
ooooool000002_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02?oo
ool01ol0003ooooooooooooooooo0000ooooool000002oooool00ol0003oooooooooo`0100000000
00@00000oooooooooooooooo0ol0000:ooooo`06o`000?ooooooooooooooool0003ooooo0_l0000:
ooooo`04o`000?ooooooooooooooo`Co00002_ooool01?l0003oooooooooooooool3o`0000[ooooo
00?o0000ooooooooool00_ooool3o`0000[ooooo00Co0000oooooooooooooooo1?l0000:ooooo`04
o`000?ooooooooooooooo`Co00002_ooool01?l0003oooooooooooooool3o`0000[ooooo00?o0000
ooooooooool00_ooool3o`0000[ooooo00Co0000oooooooooooooooo1?l0000:ooooo`04o`000?oo
ooooooooooooo`Co00002_ooool01?l0003oooooooooooooool3o`0000[ooooo00Ko0000oooooooo
ooooooooo`000?ooool2o`0000[ooooo00Co0000oooooooooooooooo1?l0000:ooooo`04o`000?oo
ooooooooooooo`?o00002_ooool00ol0003oooooooooo`02ooooo`?o00002_ooool01?l0003ooooo
ooooooooool10000000000<00000ooooooooool00_l00002ooooo`;o00001oooool00ol0003ooooo
ooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
0_l000000ooooooo0000o`000008ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000
o`000008ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Oooooo00?o0000oooooooo
ool00_ooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`;o
000000?oooooo`000?l000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
00002?ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00007ooooo`03o`000?oooooooooo
00;ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool2o`00
0003ooooool0003o000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`00
00Sooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool2o`000003ooooool0003o000000Sooooo00?o0000ooooooooool00_ooool2
o`000003ooooool0003o000000Sooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?oo
ool01?l0003oooooooooooooool10000000000H00000oooooooooooo0000ooooool00002ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool100000000
00<00000ooooool000000oooool00ol0003oooooooooo`02o`0000Cooooo00Co0000oooooooooooo
oooo0_l00002ooooo`04o`000?ooooooooooooooo`;o00001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooooooo0_l00004ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`03o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`03
o`000?oooooooooo00;o00001?ooool01?l0003oooooooooooooool2o`0000;ooooo00Co0000oooo
oooooooooooo0_l00004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`03o`0000?ooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00?o0000
0oooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool00_l00004ooooo`04
o`000?ooooooooooooooo`;o00000_ooool01?l0003oooooooooooooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o00000oooool01?l0003ooooooooo
ooooool2o`0000?ooooo00?o0000ooooooooool00ol00003ooooo`04o`000?ooooooooooooooo`;o
00000oooool00ol0003oooooooooo`02o`0000Cooooo00Co0000oooooooooooooooo0_l00002oooo
o`04o`000?ooooooooooooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00ol00003ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003ooooo
ooooo`02o`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool10000000000<00000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`Co00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo0_l000001?oooooo0000ooooooooool2o`0000Gooooo00?o0000oooo
ooooool00_ooool2o`000004ooooool0003oooooooooo`;o00001Oooool01?l0003ooooooooooooo
ool3o`000004ooooool0003oooooooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`Co0000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000
ooooooooool2o`0000Gooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003ooooooooo
o`;o00001Oooool01?l0003oooooooooooooool3o`000005ooooool0003oooooooooool000001Ooo
ool00ol0003oooooooooo`02ooooo`;o000000Coooooo`000?oooooooooo0_l00005ooooo`03o`00
0?oooooooooo00;ooooo0_l000001?oooooo0000ooooooooool2o`0000Gooooo00?o0000oooooooo
ool00_ooool2o`000004ooooool0003oooooooooo`;o00001Oooool01?l0003oooooooooooooool4
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o000000Cooooo
o`000?oooooooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000oooo
ooooool2o`0000Gooooo00Co0000oooooooooooooooo0ol000001?oooooo0000ooooooooool2o`00
00Cooooo00?o0000ooooooooool00_ooool4o`0000?ooooo00?o0000ooooooooool00@0000000003
00000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00?o
oooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`0000;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00?ooooo0_l00002ooooo`04o`000?ooooooooooooooo`40000000000`00003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1?l00009ooooo`03o`000?oooooooooo00;o
oooo1?l00008ooooo`03o`000?oooooooooo00;ooooo1Ol00008ooooo`03o`000?oooooooooo00;o
oooo1?l00009ooooo`03o`000?oooooooooo00;ooooo1?l00009ooooo`03o`000?oooooooooo00;o
oooo1?l00008ooooo`03o`000?oooooooooo00;ooooo1Ol00008ooooo`03o`000?oooooooooo00;o
oooo1?l00009ooooo`03o`000?oooooooooo00;ooooo1?l00008ooooo`03o`000?oooooooooo00?o
oooo1?l00008ooooo`03o`000?oooooooooo00;ooooo1Ol00008ooooo`03o`000?oooooooooo00;o
oooo1?l00009ooooo`03o`000?oooooooooo00;ooooo1?l00008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooool000000_l00008ooooo`03o`000?oooooooooo00;ooooo1?l00009ooooo`03
o`000?oooooooooo00;ooooo1?l00004ooooo`40000000000`00003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oo00001oooool00ol0003oooooooooo`07o`0000Sooooo00?o0000ooooooooool0
1?l000000ooooooo0000o`000008ooooo`05o`000?ooooooooooo`000?ooool01Ol00008ooooo`03
o`000?oooooo000000Oo00001oooool00ol0003oooooooooo`04o`000003ooooool0003o000000So
oooo00?o0000ooooooooool01?l000000ooooooo0000o`000008ooooo`05o`000?ooooooooooo`00
0?ooool01Ol00007ooooo`03o`000?oooooooooo00Oo00002?ooool00ol0003oooooooooo`04o`00
0003ooooool0003o000000Sooooo00?o0000ooooooooool01ol00008ooooo`03o`000?oooooooooo
00Oo00001oooool00ol0003oooooooooo`07o`0000Sooooo00?o0000ooooooooool01?l000000ooo
oooo0000o`000008ooooo`03o`000?oooooooooo00Oo00002?ooool00ol0003oooooooooo`07o`00
00;ooooo0@000000000300000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`010000000000@00000ooooool0003o00001Oooool4o`0000Kooooo0_l00006ooooo`Co
00001_ooool2o`0000Kooooo0ol00006ooooo`?o00001_ooool3o`0000Kooooo0ol00005ooooo`Co
00001_ooool2o`0000Kooooo1?l00006ooooo`;o00001_ooool3o`0000Kooooo0ol00005ooooo`Co
00001_ooool3o`0000Gooooo1?l00006ooooo`;o00001_ooool4o`0000Kooooo0_l00006ooooo`?o
00001_ooool3o`0000Gooooo1?l00006ooooo`;o00001_ooool4o`0000Kooooo0_l00006ooooo`?o
00001oooool2o`0000Kooooo0ol00006ooooo`?o00001Oooool4o`0000Kooooo0Ol00001ooooo`40
000000000`00003oooooooooo`04o`000003ooooool0003o000000;o00002Oooool3o`0000;ooooo
0ol0000:ooooo`?o00000_ooool3o`0000[ooooo0ol00002ooooo`?o00002Oooool3o`0000;ooooo
1?l00009ooooo`?o00000_ooool3o`0000[ooooo0ol00002ooooo`?o00002_ooool3o`0000;ooooo
0ol00009ooooo`?o00000_ooool4o`0000Wooooo0ol00002ooooo`?o00002_ooool3o`0000;ooooo
0ol00009ooooo`Co000000?oooooo`000?l000000_l00009ooooo`?o00000_ooool4o`0000Wooooo
0ol00002ooooo`?o00002_ooool3o`0000;ooooo0ol00009ooooo`Co000000?oooooo`000?l00000
0_l00009ooooo`40000000000`00003oooooooooo`03ooooo`?o00003oooool2o`00013ooooo0_l0
000?ooooo`?o00003oooool3o`0000oooooo0_l0000@ooooo`;o00003oooool3o`0000oooooo0ol0
000?ooooo`;o00004?ooool2o`0000oooooo0ol0000?ooooo`;o00004?ooool2o`00013ooooo0_l0
000?ooooo`?o00003?ooool10000000000@00000oooooooooooooooo0ol000000ooooooo0000o`00
0003o`0000Wooooo2Ol00009ooooo`Ko000000?oooooo`000?l000002?ooool3o`000006ooooool0
003o0000o`000?oooooo00002Oooool3o`000003ooooool0003o000000?o00002Oooool6o`000003
ooooool0003o000000Wooooo1_l000000ooooooo0000o`000008ooooo`?o000000Koooooo`000?l0
003o0000ooooool00009ooooo`?o000000?oooooo`000?l000000ol00009ooooo`Ko000000?ooooo
o`000?l000002?ooool7o`000003ooooool0003ooooo00Sooooo0ol000001_oooooo0000o`000?l0
003oooooo`0000Wooooo2Ol00009ooooo`Ko000000?oooooo`000?l000002?ooool7o`000003oooo
ool0003ooooo00Sooooo0ol000000ooooooo0000o`000003o`0000Sooooo0@000000000400000?oo
oooo0000o`0000?ooooo00?o0000ooooooooool01Ol00003ooooo`Co00000oooool00ol0003ooooo
ooooo`05o`0000?ooooo1?l00003ooooo`03o`000?oooooooooo00Go00000oooool4o`0000;ooooo
00Co0000oooooooooooooooo1?l00004ooooo`?o00000oooool00ol0003oooooooooo`05o`0000?o
oooo1?l00003ooooo`03o`000?oooooooooo00Go00000oooool4o`0000?ooooo00?o0000oooooooo
ool01?l00004ooooo`Co00000_ooool01?l0003oooooooooooooool4o`0000?ooooo1?l00003oooo
o`03o`000?oooooooooo00Go00000oooool4o`0000?ooooo00?o0000ooooooooool01Ol00003oooo
o`Co00000oooool00ol0003oooooooooo`04o`0000Cooooo1?l00002ooooo`04o`000?oooooooooo
ooooo`Co00000oooool4o`0000?ooooo00?o0000ooooooooool01Ol00003ooooo`Co00000oooool0
0ol0003oooooooooo`05o`0000?ooooo1?l00003ooooo`03o`000?oooooooooo00Co00001?ooool3
o`0000?ooooo00Co0000oooooooooooooooo1?l00003ooooo`;o00000Oooool10000000000<00000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`Go00001Oooool00ol0003oooooooooo`04
ooooo`Go00001_ooool00ol0003oooooooooo`04ooooo`Go00001_ooool00ol0003oooooooooo`04
ooooo`Go00001Oooool00ol0003oooooooooo`05ooooo`Go00001Oooool00ol0003oooooooooo`04
ooooo`Go00001_ooool00ol0003oooooooooo`04ooooo`Go00001_ooool00ol0003oooooooooo`04
ooooo`Go00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000;o00001_ooool0
0ol0003oooooooooo`04ooooo`Go00001_ooool00ol0003oooooooooo`04ooooo`Go00001_ooool0
0ol0003oooooooooo`04ooooo`Go00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000;o00001_ooool00ol0003oooooooooo`04ooooo`Go00001_ooool00ol0003oooooooooo`04
ooooo`Go00001_ooool00ol0003oooooooooo`04ooooo`Go00000_ooool10000000000<00000oooo
ool000003Ol000000ooooooo0000o`00000?o`000003ooooool0003o000003;o000000?oooooo`00
0?l000003ol000000ooooooo0000o`00000bo`000003ooooool0003o000004Co000000?oooooo`00
0?l00000<_l000001Ooooooo0000o`000?l0003ooooo0040000000000`00003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool10000000000D00000oooooooo
ooooooooo`00000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0@000000000300000?oooooooooo00;o
00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooo
oooooooo0_l0000<ooooo`04o`000?ooooooooooooooo`;o00003?ooool01?l0003ooooooooooooo
ool2o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`04o`000?oo
ooooooooooooo`;o00003?ooool01?l0003oooooooooooooool2o`0000cooooo00Co0000oooooooo
oooooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0
003oooooooooooooool2o`0000cooooo00Co0000oooooooooooooooo0_l0000;ooooo`03o`000?oo
oooooooo00;ooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool01?l0003oooooooooooooool2o`0000cooooo00Co0000oooooooooooooooo0_l0000;ooooo`03
o`000?oooooooooo00;ooooo0@000000000300000?oooooo000000kooooo00Co0000oooooooooooo
00003_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo000000kooooo00Co0000oooo
oooooooo00003_ooool01?l0003oooooooooool0000>ooooo`04o`000?ooooooooooo`0000kooooo
00?o0000ooooool000003_ooool01?l0003oooooooooool0000>ooooo`04o`000?ooooooooooo`00
00kooooo00Co0000oooooooooooo00003Oooool01?l0003oooooooooool0000>ooooo`04o`000?oo
ooooooooo`0000kooooo00Co0000oooooooooooo00003_ooool01?l0003oooooooooool0000=oooo
o`04o`000?ooooooooooo`0000kooooo00Co0000oooooooooooooooo0@000000000300000?oooooo
000000oooooo0_l0000@ooooo`;o00003oooool00ol0003oooooo`00000?ooooo`03o`000?oooooo
000000oooooo0_l0000@ooooo`;o00003oooool00ol0003oooooo`00000?ooooo`;o00004?ooool2
o`0000oooooo00?o0000ooooool000003oooool00ol0003oooooo`00000?ooooo`;o00004?ooool2
o`0000oooooo00?o0000ooooool000003oooool00ol0003oooooo`00000?ooooo`03o`000?oooooo
oooo0040000000000`00003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo0_l0000@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00oooooo0Ol00001ooooo`40000000000`00003oooooo`00000>ooooo`Co
00003_ooool4o`0000kooooo00?o0000ooooool000003_ooool4o`0000kooooo1?l0000>ooooo`Co
00003_ooool00ol0003oooooo`00000>ooooo`Co00003_ooool4o`0000kooooo1?l0000>ooooo`03
o`000?oooooo000000kooooo1?l0000>ooooo`Co00003_ooool01?l0003oooooo`000?l0000=oooo
o`;o000000?oooooo`000?ooool03Oooool2o`0000;ooooo0@000000000400000?ooooooooooo`00
00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooo
ooooool000003Oooool01Ol0003ooooooooooooooooo000000gooooo00Go0000oooooooooooooooo
o`00000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooo
oooooooooooo000000gooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?oooooooooo
ooooool000003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`00000=ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?oooooooooo
ooooool000003Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00_oo
ool10000000000D00000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo0@00
0000000400000?ooooooooooooooo`;o00002?ooool2o`0000Kooooo0_l00008ooooo`;o00001_oo
ool2o`0000Sooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?oo
ool2o`0000Sooooo0_l00006ooooo`;o00002?ooool2o`0000Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`04ooooo`;o00002?ooool2o`0000Kooooo0_l00008ooooo`;o00001_oo
ool2o`0000Sooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?oo
ool2o`0000Sooooo0_l00006ooooo`;o00002?ooool2o`0000Kooooo0_l00008ooooo`;o00001_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`;o00001Ooo
ool10000000000<00000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`40000000000`00
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`03o`000?oooooooooo
00Sooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`;o00001_ooool00ol0003oooooooooo`07ooooo`;o00001Oooool00ol0
003oooooooooo`08ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01oooool2o`0000Kooooo00?o0000ooooooooool01oooool2o`00
00Gooooo00?o0000ooooooooool02?ooool2o`0000Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0_l00005ooooo`03o`000?oooooooooo
00Sooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo0_l00005ooooo`03o`000?oooooooooo
00Gooooo0@000000000300000?oooooooooo00Cooooo0_l00003ooooo`03o`000?oooooooooo00[o
oooo0_l00002ooooo`;o00003?ooool01?l0003oooooooooooooool2o`0000_ooooo0_l00003oooo
o`03o`000?oooooooooo00[ooooo0_l00002ooooo`;o00003?ooool2o`0000;ooooo0_l0000<oooo
o`04o`000?ooooooooooooooo`;o00002oooool2o`0000?ooooo00?o0000ooooooooool02_ooool2
o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000cooooo00Co0000oooooooooooooooo0_l0
000;ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`;o00000_ooool2o`0000cooooo00Co
0000oooooooooooooooo0_l0000;ooooo`;o00000oooool2o`0000_ooooo0_l00003ooooo`03o`00
0?oooooooooo00Kooooo0@000000000300000?oooooooooo00Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01ooo
ool10000000000<00000ooooooooool01_ooool2o`0000oooooo0ol0000?ooooo`?o00003oooool2
o`00013ooooo0_l0000?ooooo`?o00003oooool2o`00013ooooo0_l0000?ooooo`?o00003oooool3
o`0000oooooo0_l0000@ooooo`;o00003oooool3o`0000oooooo0ol0000?ooooo`;o00004?ooool2
o`0000[ooooo0@000000000300000?oooooooooo00Gooooo1?l0000>ooooo`03o`000?oooooo0000
00kooooo0_l000000ooooooo0000ooooo`0=ooooo`Co00003_ooool4o`0000kooooo00?o0000oooo
ool000003_ooool4o`0000kooooo1?l0000>ooooo`Co00003_ooool00ol0003oooooo`00000>oooo
o`Co00003_ooool4o`0000kooooo00Co0000ooooool0003o00003_ooool00ol0003oooooo`00000>
ooooo`Co00003_ooool4o`0000Wooooo0@000000000300000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000=ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooo
oooooooo000000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000gooooo00Go0000oooo
ooooooooooooo`00000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
1Ol0003ooooooooooooooooo000000gooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?ooooooooooooooool000003Oooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ooooooooooooooooo`000009ooooo`400000
00000`00003oooooooooo`03ooooo`;o00001?ooool2o`0000[ooooo00?o0000ooooooooool00ooo
ool2o`0000Wooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`;o00002_oo
ool00ol0003oooooooooo`03ooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`;o00002Ooo
ool2o`0000Gooooo00?o0000ooooooooool02?ooool2o`0000Cooooo0_l0000:ooooo`03o`000?oo
oooooooo00?ooooo0_l00009ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`;o00001Ooo
ool00ol0003oooooooooo`08ooooo`;o00001?ooool2o`0000[ooooo00?o0000ooooooooool00ooo
ool2o`0000Wooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`;o00002_oo
ool2o`0000Cooooo0_l00007ooooo`40000000001000003oooooooooooooool2o`0000Sooooo00?o
0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o
0000ooooooooool01_ooool2o`0000Kooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo0_l0
0007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo00?o
0000ooooooooool01_ooool2o`0000Kooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo0_l0
0007ooooo`;o00001oooool2o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo0_l0
0006ooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`40000000001@00003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool10000000000@00000ooooool0003o00003?oo
ool01?l0003oooooooooooooool2o`0000_ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo
0_l00002ooooo`;o00003?ooool2o`0000;ooooo0_l0000<ooooo`04o`000?ooooooooooooooo`;o
00002oooool2o`0000?ooooo00?o0000ooooooooool02_ooool2o`0000;ooooo0_l0000<ooooo`;o
00000_ooool2o`0000cooooo00Co0000oooooooooooooooo0_l0000;ooooo`;o00000oooool00ol0
003oooooooooo`0:ooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`;o00003?ooool01?l0
003oooooooooooooool2o`0000_ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo0_l00002
ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`40000000000`00003oooooo`00000>oooo
o`?o00003oooool3o`0000oooooo0ol0000>ooooo`Co00003_ooool3o`0000oooooo0ol0000?oooo
o`?o00003_ooool3o`0000oooooo0ol0000?ooooo`?o00003_ooool4o`0000kooooo0ol0000?oooo
o`?o00003oooool3o`0000kooooo1?l0000>ooooo`?o00000Oooool10000000000<00000ooooool0
00003_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooo000000oooooo00?o0000ooooool0
00003_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooo000000oooooo00?o0000ooooool0
00003oooool00ol0003oooooo`00000>ooooo`03o`000?oooooo000000oooooo00?o0000ooooool0
00003oooool00ol0003oooooo`00000?ooooo`03o`000?oooooo000000kooooo00?o0000ooooool0
00003oooool00ol0003oooooo`00000?ooooo`03o`000?oooooo000000kooooo00Co0000oooooooo
oooo00003_ooool01?l0003oooooooooooooool10000000000<00000ooooool000000_l0000:oooo
o`;o00000oooool2o`0000_ooooo0_l00003ooooo`;o00002oooool2o`0000;ooooo0ol0000:oooo
o`?o00000_ooool3o`0000[ooooo0_l00003ooooo`;o00002oooool2o`0000?ooooo0_l0000:oooo
o`?o00000_ooool3o`0000[ooooo0ol00002ooooo`?o00002_ooool2o`0000?ooooo0_l0000;oooo
o`;o00000oooool2o`0000[ooooo0ol00002ooooo`?o00002_ooool3o`0000;ooooo0_l0000;oooo
o`;o00000oooool2o`0000_ooooo0_l00003ooooo`;o00002_ooool3o`0000;ooooo0ol0000:oooo
o`;o00001?ooool10000000000@00000oooooooooooooooo1?l00004ooooo`?o00001oooool3o`00
00Gooooo0ol00007ooooo`?o00001Oooool3o`0000Oooooo0ol00004ooooo`Co00001_ooool3o`00
00Gooooo0ol00007ooooo`?o00001Oooool3o`0000Oooooo0ol00005ooooo`?o00001oooool3o`00
00Cooooo0ol00007ooooo`?o00001Oooool3o`0000Oooooo0ol00005ooooo`?o00001oooool3o`00
00Gooooo0ol00006ooooo`Co00001?ooool3o`0000Oooooo0ol00005ooooo`?o00001oooool3o`00
00Gooooo0ol00007ooooo`?o00001?ooool4o`0000Kooooo1?l00004ooooo`?o00001_ooool10000
000000<00000ooooooooool01?ooool2o`0000;ooooo00?o0000ooooooooool02oooool2o`0000;o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02o`0000cooooo0_l00002ooooo`;o
00003?ooool2o`0000;ooooo00?o0000ooooooooool02oooool2o`000003ooooool0003o000000go
oooo00?o0000ooooooooool00_l0000<ooooo`;o00000_ooool2o`0000cooooo0_l00002ooooo`03
o`000?oooooooooo00_ooooo0_l000000ooooooo0000o`00000=ooooo`03o`000?oooooooooo00;o
00003?ooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;o00003?ooool2o`0000;ooooo0_l0000<ooooo`;o00000_ooool2o`0000So
oooo0@000000000300000?oooooooooo00Cooooo1_l0000;ooooo`Oo00002oooool7o`0000_ooooo
1_l0000;ooooo`Oo00002oooool7o`0000_ooooo1ol0000;ooooo`Ko00002oooool7o`0000_ooooo
1ol0000;ooooo`Oo00002oooool6o`0000_ooooo1ol0000;ooooo`Oo00002oooool6o`0000cooooo
1_l00008ooooo`40000000000`00003oooooo`000004o`0000Kooooo3?l00006ooooo`_o00001_oo
ool<o`0000Kooooo3?l00006ooooo`_o00001oooool;o`0000Kooooo3?l00006ooooo`co00001_oo
ool;o`0000Oooooo2ol00006ooooo`co00001_ooool<o`0000Kooooo2ol00006ooooo`co00001_oo
ool<o`0000Kooooo1ol00001ooooo`40000000000`00003oooooooooo`3ooooooagooooo0@000000
0?l000008@0000000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000l002bg?Oo
mMVbR612<BliCFAiR8j<Q7YbLGR7W;?6d<jlWWI;90T02BE?P[?Mn?odf;66GT4`
;cY>IGZ8SXb4NW9aN8RM]<OAcK^LM4TS2@0:9U64]Mkhoo?F[hAM@30_>diVNXV>
S8AiLW5iR9jeb=7=^Y]bAb8800XXDhJgh?Wol]F]PU`o<2lkCfIkRHj<PgUbLGV9
WkK8dLbiVG5680L02bUER;WQn_oae:b1FSh_<3a@Igb9SX^3NG9aNXZP]lWAc;RH
Kd@O1`0<:eN:^n;joo3BZWmI?Bl`?E5XO8Z>Rh9hLG5jRj6gbM7;]iI]@ah600d/
FHbmi?_okm6XOEPl;c0mDVUmRXj;PWQaLW^<X[S:dL^fUF]17@D03RiKS[kUnok^
cjMlES/_<3iCJWj:SX^2N75bNhbS^L[Ab[FCJSlK1@0?;ef@`>Klo^g>YGYE>bla
?eA[OX^>RX5gLG9lSJBjbm7:]99X?QX4010aGi;2iocnk<bSNE@j;S4oEFaoRhj:
PGMaLWb>Y;_;dLVcT6Hl6@@14C=QU<CYoOg[bj5gDST^<D1FKH2;SXZ0Mg5bOHnU
_<cAb;6>I3/H0`4B=6>Fa^[moN[9X7EA>2hb@EM^P8b>RH1fLG=mT:Jlc=78/8eS
>AL30A<fIIS7jogmjLRNM50h;S92F6j1S8j9OgIaLgjAYkg=dLN_Rf4g5P8153QW
V/W/o_cXaYabCcL^<d=IKh:<SXUoMW5cOi6X_/gAaZj:GcHE0P8E>FVLbngno>O4
VW1==Rhc@eY`PXb>R7meLGAoTZVocM76[HQN=1@20QHkJik<k_kki/>IKd`f;SA4
FW63SHj8OWEaM82CZ[o>dLF[QU`c4P4363e]X<k_oo_U`IM]BcD^=4EKLX>=SXQn
MG1dP9B[`<k@a:Z5FS4A0@<I?fnRco3on^?0UFa:=BheAUacQ8f>QgedL7B1UJc1
c]33ZH=H<10111Y0LJCAlOojh[jDJTTd;SE7GG>4SHj7OGA`MH:F[L;?d<>WPEL^
40046d9cY]?booWQ_99YB3@^=TQNM8F=SHMmM71ePiN^`/o@`ZJ0EBd?00DMA7FX
e??on>2kT6M7<bhfB5meQHj=QWadL7J3V:o3clo1YGiC:`h01Ai6Mj[Fm?ohg[V>
ITHc;SM9H7J6SXf6O7=aMXBH/<C@cl2SO58Z3@067dQi[=OeooOM]heTAC8^=dYQ
MhJ>SHEkLg5fQIV`a=3?_j9kD2T<00LQBW^^fOGom]bfRf=4<RhhBf9gQhj=QG]c
LGN5V[75d<jnX7U>9`/01b9;OK3Jm_oefkB9HD<a;SU<HgR7SXf5Ng=aMhJK//K@
c[fOMd`V2P088deo/]cgooGI/XQP@S4_>DeTNHR>S8AjLW5hQibca]3>_9ifBb@9
00TUCh:cgOSom=RaQUi1<2ljCVEjR8j<Q7YbLGR8WKC7dLfkW7A98`T02RIAQ;GN
n?oceZn4GD0`;c]>IWZ9SXb4NG9aNHRN]LSAcKZKLTLR200::5>6]n3ioo;E[H9L
?c0_>dmVNhV>S8=iLW5iRInfb=7<^IUaAR0700/YEHRihO[olMB/PEXn;c0lD6Ml
RHj;PgUbLGZ:X;O9dLbhV6m47`L032]GR[_Rn_o`dZYoFCd_<3eAJ7b:SX^2N75a
NX^Q]lWAbkNFKD<N1P0=;5V<_NCkonoAZ7eH?2l`?E9YOHZ>Rh9hLG9kS::hb]7;
]YE[@Ad500h^FhjniO_nk/nWO5Hk;c0nDfYnRXj;PWQaLW^<XkW:dLZeTfXo6`D0
3bmMT<3Vo?k]cZEjEC/_<CmDJgj;SXZ1Mg5bO8fT^/_Ab[BBJ3hJ100@<EnB`^Ol
o^c<XgUD>Rha?eE/Oh^>RX5gLG9lSZBkbm79/i1V?1T40A4cHIC4jOgmjl^QMe8i
;S50EVf0Rhj:P7MaLWf?YKc<dLRaSV@k60<14SASU/KZoOgZbJ1eDCP^<T5GKX2<
SXV0MW5cOI2V_<cAb;2=HcTG0`4C=VFHan_moNW8WWA@>2hb@UQ^PHb>RGmfLG=n
TJNmcM77[h]Q=aH20A@hIi[9k?klj<JLLTlg;S=3FFn2S8j9OgIaLgnAZ;k=dLJ^
RUlf5@825CUYW<_]o_cWa9Y`CCH^<d=JL8:<SXQoMG5dOi:Y_lgAaZf8GS@D0P8F
>f^Nc>knnnK3VFm<=RhdA5YaPhf>R7ieLGB0TjZoc]75ZhIL<a810aPmKJ3>kook
iL6GKD/e;SA5Fg:3SHj8OWE`M82DZl3>d<BZQEXa4@436Cm_X/o`oo[S`9E/BSD^
=DILLhB=SXMmM71dPIF/`Lk@`jV3F30@0@@J@76TdO7on^:nU6Y9=2heAeecQ8f>
QgedL7F2UZg2cm33Yh5G;Q0011]2LjKCl_oihKbBJDPd;SI8GWB5SHf7OGA`MH>G
[/;?d<:VP5D]3`057DAeZ=CcooSP^i1WAc<^=TQOMHF>SHIlM71fPiR_`lo?`JEn
Db/>00DNAWNZe_Con=jiSVI6<bhgBF1fQXj=QWacLGJ4V;34d<o0XgaB:Pd01Qm8
NJcGmOoggKN=I4Db;SM:HGN6SXf5Ng=aMXFI/<C@cknRNe0Y30078DYk[]WeooKL
]X]SA38^>4]RMhN>SHEkLg5gQIZaaM3>_Z1iCRL;00LRBgf`f_KomM^dRF53<Bhi
C6=hQhj=QG]cLGN6Vk;6d<jmWgM<9PX022==Ok;LmooefK:8H48a;cU=I7V8SXb4
NW9aN8NL/lK@c[bNMT/T2@099Dn2/mghooCH/HIN@C0_>TiUNXR>S8AjLW5hR9fd
am7=^iadBB<900XVDHBeg_SolmJ_Q5e0<2lkCVIjRHj<Q7UbLGV8W[G8dLfjVg97
8PP02RQCQ[OPnOobeJf2G3l`;c]?IW^9SXb3NG9aNHVO]/SAc;VILDHP1`0;:EF8
^N7joo7D[85J?Rl`?51WO8V>Rh=iLW5jRZ2gbM7<^9Q_A1l700`[EhZkh_[ol=:Z
OeTm;c0mDFQlRXj;PWQaLGZ;XKO9dL^gUVe37PH03BaIS;gTnoo_dJQmF3`_<3eB
JGf:SX^2N75bNhbR^<[AbkJEJd4M1@0>;U^>_^Gko^k?YgaF>bl`?U=ZOXZ>Rh9h
LG9kS:>ib]7:]I=Z?a/500l_GI30i_cnkLjUNUDk;c4oE6]nRhj:PGMaLWb=Y;[;
dLZdTVPn6P@0435OT/;Wo?k/c:=iE3X^<CmEK7n;SXZ1Mg5bO8jT^l_AbK>@IS`I
104A<f6Da>WmoN_;XGMB>Bha@5I]P8^>RX1gLG9mSjFlc=78/HiT>aP30A8dHiK6
j_gmj/VPME4h;S91Efj0S8j9P7IaLgf@Y[c<dLR`SF<i5`<14cIUV<O[oOgYb9id
D3P^<T9HKX6<SXUoMW5cOY6W_LgAajn;HCLF0P4D>6NJbNcno>S6W79?=bhc@eU_
PXb>RGmfLG=oTJRncM76[XYO=QD20QDiJIc;kOklilBJL4df;S=3FW22S8j8OgEa
M7nBZKo=dLJ]R5hd50825S][W/c^o__V`iU_C3H^=4AJLH>=SXQnMG5dP9>Z_lkA
aJ^6G3<B0@<H?FfPc^oonnG1Ufe;=BhdAE]bPhf>R7ieL7B0U:_0c]34ZXEJ<A41
0aToKj;?l?ojhl2EK4Xe;SE6G7>4SHj7OGA`M86E[<7>d<>YPeP`40446T1aY=7a
oo[R_YAZBC@^=DMMLhB=SXMmM71ePYJ]`/o@`jN1Ebh@00@K@W>Vdo;onN6lTVU8
=2hfB5idQHf=QgedL7F3Ujk2cm32YX1E;@l01Ae4MJSDloohh;^@IdLc;SI8GgF5
SXf6O7A`MX>H[l??cl6UOU<[3P057TIgZ]KdooSN^HiVAS<^=dUPMXJ>SHIlLg5f
Q9R`a=3?`:=lDRX=00HOB7V/eoGommfgSFA5<RhgBV5gQXj=QG]cLGJ5VK34d<no
XW]@:@`01b5:NjkImOofg;J;Hd@b;SQ;HWN7SXf5Ng=aMhFJ/LG@c[jPNDhW2`07
8T]m/=[fooGK]8UQ@c4^>DaSN8N>SHEkLg5gQY^ba]3>_ImgC2H:00PSCGnbg?Oo
mMVbR612<BliCFAiR8j<Q7YbLGR7W;?6d<jlWWI;90T02BE?P[?Mn?odf;66GT4`
;cY>IGZ8SXb4NW9aN8RM]<OAcK^LM4TS2@0:9U64]Mkhoo?F[hAM@30_>diVNXV>
S8AiLW5iR9jeb=7=^Y]bAb8800XXDhJgh?Wol]F]PU`o<2lkCfIkRHj<PgUbLGV9
WkK8dLbiVG5680L02bUER;WQn_oae:b1FSh_<3a@Igb9SX^3NG9aNXZP]lWAc;RH
Kd@O1`0<:eN:^n;joo3BZWmI?Bl`?E5XO8Z>Rh9hLG5jRj6gbM7;]iI]@ah600d/
FHbmi?_okm6XOEPl;c0mDVUmRXj;PWQaLW^<X[S:dL^fUF]17@D03RiKS[kUnok^
cjMlES/_<3iCJWj:SX^2N75bNhbS^L[Ab[FCJSlK1@0?;ef@`>Klo^g>YGYE>bla
?eA[OX^>RX5gLG9lSJBjbm7:]99X?QX4010aGi;2iocnk<bSNE@j;S4oEFaoRhj:
PGMaLWb>Y;_;dLVcT6Hl6@@14C=QU<CYoOg[bj5gDST^<D1FKH2;SXZ0Mg5bOHnU
_<cAb;6>I3/H0`4B=6>Fa^[moN[9X7EA>2hb@EM^P8b>RH1fLG=mT:Jlc=78/8eS
>AL30A<fIIS7jogmjLRNM50h;S92F6j1S8j9OgIaLgjAYkg=dLN_Rf4g5P8153QW
V/W/o_cXaYabCcL^<d=IKh:<SXUoMW5cOi6X_/gAaZj:GcHE0P8E>FVLbngno>O4
VW1==Rhc@eY`PXb>R7meLGAoTZVocM76[HQN=1@20QHkJik<k_kki/>IKd`f;SA4
FW63SHj8OWEaM82CZ[o>dLF[QU`c4P4363e]X<k_oo_U`IM]BcD^=4EKLX>=SXQn
MG1dP9B[`<k@a:Z5FS4A0@<I?fnRco3on^?0UFa:=BheAUacQ8f>QgedL7B1UJc1
c]33ZH=H<10111Y0LJCAlOojh[jDJTTd;SE7GG>4SHj7OGA`MH:F[L;?d<>WPEL^
40046d9cY]?booWQ_99YB3@^=TQNM8F=SHMmM71ePiN^`/o@`ZJ0EBd?00DMA7FX
e??on>2kT6M7<bhfB5meQHj=QWadL7J3V:o3clo1YGiC:`h01Ai6Mj[Fm?ohg[V>
ITHc;SM9H7J6SXf6O7=aMXBH/<C@cl2SO58Z3@067dQi[=OeooOM]heTAC8^=dYQ
MhJ>SHEkLg5fQIV`a=3?_j9kD2T<00LQBW^^fOGom]bfRf=4<RhhBf9gQhj=QG]c
LGN5V[75d<jnX7U>9`/01b9;OK3Jm_oefkB9HD<a;SU<HgR7SXf5Ng=aMhJK//K@
c[fOMd`V2P088deo/]cgooGI/XQP@S4_>DeTNHR>S8AjLW5hQibca]3>_9ifBb@9
00TUCh:cgOSom=RaQUi1<2ljCVEjR8j<Q7YbLGR8WKC7dLfkW7A98`T02RIAQ;GN
n?oceZn4GD0`;c]>IWZ9SXb4NG9aNHRN]LSAcKZKLTLR200::5>6]n3ioo;E[H9L
?c0_>dmVNhV>S8=iLW5iRInfb=7<^IUaAR0700/YEHRihO[olMB/PEXn;c0lD6Ml
RHj;PgUbLGZ:X;O9dLbhV6m47`L032]GR[_Rn_o`dZYoFCd_<3eAJ7b:SX^2N75a
NX^Q]lWAbkNFKD<N1P0=;5V<_NCkonoAZ7eH?2l`?E9YOHZ>Rh9hLG9kS::hb]7;
]YE[@Ad500h^FhjniO_nk/nWO5Hk;c0nDfYnRXj;PWQaLW^<XkW:dLZeTfXo6`D0
3bmMT<3Vo?k]cZEjEC/_<CmDJgj;SXZ1Mg5bO8fT^/_Ab[BBJ3hJ100@<EnB`^Ol
o^c<XgUD>Rha?eE/Oh^>RX5gLG9lSZBkbm79/i1V?1T40A4cHIC4jOgmjl^QMe8i
;S50EVf0Rhj:P7MaLWf?YKc<dLRaSV@k60<14SASU/KZoOgZbJ1eDCP^<T5GKX2<
SXV0MW5cOI2V_<cAb;2=HcTG0`4C=VFHan_moNW8WWA@>2hb@UQ^PHb>RGmfLG=n
TJNmcM77[h]Q=aH20A@hIi[9k?klj<JLLTlg;S=3FFn2S8j9OgIaLgnAZ;k=dLJ^
RUlf5@825CUYW<_]o_cWa9Y`CCH^<d=JL8:<SXQoMG5dOi:Y_lgAaZf8GS@D0P8F
>f^Nc>knnnK3VFm<=RhdA5YaPhf>R7ieLGB0TjZoc]75ZhIL<a810aPmKJ3>kook
iL6GKD/e;SA5Fg:3SHj8OWE`M82DZl3>d<BZQEXa4@436Cm_X/o`oo[S`9E/BSD^
=DILLhB=SXMmM71dPIF/`Lk@`jV3F30@0@@J@76TdO7on^:nU6Y9=2heAeecQ8f>
QgedL7F2UZg2cm33Yh5G;Q0011]2LjKCl_oihKbBJDPd;SI8GWB5SHf7OGA`MH>G
[/;?d<:VP5D]3`057DAeZ=CcooSP^i1WAc<^=TQOMHF>SHIlM71fPiR_`lo?`JEn
Db/>00DNAWNZe_Con=jiSVI6<bhgBF1fQXj=QWacLGJ4V;34d<o0XgaB:Pd01Qm8
NJcGmOoggKN=I4Db;SM:HGN6SXf5Ng=aMXFI/<C@cknRNe0Y30078DYk[]WeooKL
]X]SA38^>4]RMhN>SHEkLg5gQIZaaM3>_Z1iCRL;00LRBgf`f_KomM^dRF53<Bhi
C6=hQhj=QG]cLGN6Vk;6d<jmWgM<9PX022==Ok;LmooefK:8H48a;cU=I7V8SXb4
NW9aN8NL/lK@c[bNMT/T2@099Dn2/mghooCH/HIN@C0_>TiUNXR>S8AjLW5hR9fd
am7=^iadBB<900XVDHBeg_SolmJ_Q5e0<2lkCVIjRHj<Q7UbLGV8W[G8dLfjVg97
8PP02RQCQ[OPnOobeJf2G3l`;c]?IW^9SXb3NG9aNHVO]/SAc;VILDHP1`0;:EF8
^N7joo7D[85J?Rl`?51WO8V>Rh=iLW5jRZ2gbM7<^9Q_A1l700`[EhZkh_[ol=:Z
OeTm;c0mDFQlRXj;PWQaLGZ;XKO9dL^gUVe37PH03BaIS;gTnoo_dJQmF3`_<3eB
JGf:SX^2N75bNhbR^<[AbkJEJd4M1@0>;U^>_^Gko^k?YgaF>bl`?U=ZOXZ>Rh9h
LG9kS:>ib]7:]I=Z?a/500l_GI30i_cnkLjUNUDk;c4oE6]nRhj:PGMaLWb=Y;[;
dLZdTVPn6P@0435OT/;Wo?k/c:=iE3X^<CmEK7n;SXZ1Mg5bO8jT^l_AbK>@IS`I
104A<f6Da>WmoN_;XGMB>Bha@5I]P8^>RX1gLG9mSjFlc=78/HiT>aP30A8dHiK6
j_gmj/VPME4h;S91Efj0S8j9P7IaLgf@Y[c<dLR`SF<i5`<14cIUV<O[oOgYb9id
D3P^<T9HKX6<SXUoMW5cOY6W_LgAajn;HCLF0P4D>6NJbNcno>S6W79?=bhc@eU_
PXb>RGmfLG=oTJRncM76[XYO=QD20QDiJIc;kOklilBJL4df;S=3FW22S8j8OgEa
M7nBZKo=dLJ]R5hd50825S][W/c^o__V`iU_C3H^=4AJLH>=SXQnMG5dP9>Z_lkA
aJ^6G3<B0@<H?FfPc^oonnG1Ufe;=BhdAE]bPhf>R7ieL7B0U:_0c]34ZXEJ<A41
0aToKj;?l?ojhl2EK4Xe;SE6G7>4SHj7OGA`M86E[<7>d<>YPeP`40446T1aY=7a
oo[R_YAZBC@^=DMMLhB=SXMmM71ePYJ]`/o@`jN1Ebh@00@K@W>Vdo;onN6lTVU8
=2hfB5idQHf=QgedL7F3Ujk2cm32YX1E;@l01Ae4MJSDloohh;^@IdLc;SI8GgF5
SXf6O7A`MX>H[l??cl6UOU<[3P057TIgZ]KdooSN^HiVAS<^=dUPMXJ>SHIlLg5f
Q9R`a=3?`:=lDRX=00HOB7V/eoGommfgSFA5<RhgBV5gQXj=QG]cLGJ5VK34d<no
XW]@:@`01b5:NjkImOofg;J;Hd@b;SQ;HWN7SXf5Ng=aMhFJ/LG@c[jPNDhW2`07
8T]m/=[fooGK]8UQ@c4^>DaSN8N>SHEkLg5gQY^ba]3>_ImgC2H:00PSCGnbg?Oo
mMVbR612<BliCFAiR8j<Q7YbLGR7W;?6d<jlWWI;90T02BE?P[?Mn?odf;66GT4`
;cY>IGZ8SXb4NW9aN8RM]<OAcK^LM4TS2@0:9U64]Mkhoo?F[hAM@30_>diVNXV>
S8AiLW5iR9jeb=7=^Y]bAb8800XXDhJgh?Wol]F]PU`o<2lkCfIkRHj<PgUbLGV9
WkK8dLbiVG5680L02bUER;WQn_oae:b1FSh_<3a@Igb9SX^3NG9aNXZP]lWAc;RH
Kd@O1`0<:eN:^n;joo3BZWmI?Bl`?E5XO8Z>Rh9hLG5jRj6gbM7;]iI]@ah600d/
FHbmi?_okm6XOEPl;c0mDVUmRXj;PWQaLW^<X[S:dL^fUF]17@D03RiKS[kUnok^
cjMlES/_<3iCJWj:SX^2N75bNhbS^L[Ab[FCJSlK1@0?;ef@`>Klo^g>YGYE>bla
?eA[OX^>RX5gLG9lSJBjbm7:]99X?QX4010aGi;2iocnk<bSNE@j;S4oEFaoRhj:
PGMaLWb>Y;_;dLVcT6Hl6@@14C=QU<CYoOg[bj5gDST^<D1FKH2;SXZ0Mg5bOHnU
_<cAb;6>I3/H0`4B=6>Fa^[moN[9X7EA>2hb@EM^P8b>RH1fLG=mT:Jlc=78/8eS
>AL30A<fIIS7jogmjLRNM50h;S92F6j1S8j9OgIaLgjAYkg=dLN_Rf4g5P8153QW
V/W/o_cXaYabCcL^<d=IKh:<SXUoMW5cOi6X_/gAaZj:GcHE0P8E>FVLbngno>O4
VW1==Rhc@eY`PXb>R7meLGAoTZVocM76[HQN=1@20QHkJik<k_kki/>IKd`f;SA4
FW63SHj8OWEaM82CZ[o>dLF[QU`c4P4363e]X<k_oo_U`IM]BcD^=4EKLX>=SXQn
MG1dP9B[`<k@a:Z5FS4A0@<I?fnRco3on^?0UFa:=BheAUacQ8f>QgedL7B1UJc1
c]33ZH=H<10111Y0LJCAlOojh[jDJTTd;SE7GG>4SHj7OGA`MH:F[L;?d<>WPEL^
40046d9cY]?booWQ_99YB3@^=TQNM8F=SHMmM71ePiN^`/o@`ZJ0EBd?00DMA7FX
e??on>2kT6M7<bhfB5meQHj=QWadL7J3V:o3clo1YGiC:`h01Ai6Mj[Fm?ohg[V>
ITHc;SM9H7J6SXf6O7=aMXBH/<C@cl2SO58Z3@067dQi[=OeooOM]heTAC8^=dYQ
MhJ>SHEkLg5fQIV`a=3?_j9kD2T<00LQBW^^fOGom]bfRf=4<RhhBf9gQhj=QG]c
LGN5V[75d<jnX7U>9`/01b9;OK3Jm_oefkB9HD<a;SU<HgR7SXf5Ng=aMhJK//K@
c[fOMd`V2P088deo/]cgooGI/XQP@S4_>DeTNHR>S8AjLW5hQibca]3>_9ifBb@9
00TUCh:cgOSom=RaQUi1<2ljCVEjR8j<Q7YbLGR8WKC7dLfkW7A98`T02RIAQ;GN
n?oceZn4GD0`;c]>IWZ9SXb4NG9aNHRN]LSAcKZKLTLR200::5>6]n3ioo;E[H9L
?c0_>dmVNhV>S8=iLW5iRInfb=7<^IUaAR0700/YEHRihO[olMB/PEXn;c0lD6Ml
RHj;PgUbLGZ:X;O9dLbhV6m47`L032]GR[_Rn_o`dZYoFCd_<3eAJ7b:SX^2N75a
NX^Q]lWAbkNFKD<N1P0=;5V<_NCkonoAZ7eH?2l`?E9YOHZ>Rh9hLG9kS::hb]7;
]YE[@Ad500h^FhjniO_nk/nWO5Hk;c0nDfYnRXj;PWQaLW^<XkW:dLZeTfXo6`D0
3bmMT<3Vo?k]cZEjEC/_<CmDJgj;SXZ1Mg5bO8fT^/_Ab[BBJ3hJ100@<EnB`^Ol
o^c<XgUD>Rha?eE/Oh^>RX5gLG9lSZBkbm79/i1V?1T40A4cHIC4jOgmjl^QMe8i
;S50EVf0Rhj:P7MaLWf?YKc<dLRaSV@k60<14SASU/KZoOgZbJ1eDCP^<T5GKX2<
SXV0MW5cOI2V_<cAb;2=HcTG0`4C=VFHan_moNW8WWA@>2hb@UQ^PHb>RGmfLG=n
TJNmcM77[h]Q=aH20A@hIi[9k?klj<JLLTlg;S=3FFn2S8j9OgIaLgnAZ;k=dLJ^
RUlf5@825CUYW<_]o_cWa9Y`CCH^<d=JL8:<SXQoMG5dOi:Y_lgAaZf8GS@D0P8F
>f^Nc>knnnK3VFm<=RhdA5YaPhf>R7ieLGB0TjZoc]75ZhIL<a810aPmKJ3>kook
iL6GKD/e;SA5Fg:3SHj8OWE`M82DZl3>d<BZQEXa4@436Cm_X/o`oo[S`9E/BSD^
=DILLhB=SXMmM71dPIF/`Lk@`jV3F30@0@@J@76TdO7on^:nU6Y9=2heAeecQ8f>
QgedL7F2UZg2cm33Yh5G;Q0011]2LjKCl_oihKbBJDPd;SI8GWB5SHf7OGA`MH>G
[/;?d<:VP5D]3`057DAeZ=CcooSP^i1WAc<^=TQOMHF>SHIlM71fPiR_`lo?`JEn
Db/>00DNAWNZe_Con=jiSVI6<bhgBF1fQXj=QWacLGJ4V;34d<o0XgaB:Pd01Qm8
NJcGmOoggKN=I4Db;SM:HGN6SXf5Ng=aMXFI/<C@cknRNe0Y30078DYk[]WeooKL
]X]SA38^>4]RMhN>SHEkLg5gQIZaaM3>_Z1iCRL;00LRBgf`f_KomM^dRF53<Bhi
C6=hQhj=QG]cLGN6Vk;6d<jmWgM<9PX022==Ok;LmooefK:8H48a;cU=I7V8SXb4
NW9aN8NL/lK@c[bNMT/T2@099Dn2/mghooCH/HIN@C0_>TiUNXR>S8AjLW5hR9fd
am7=^iadBB<900XVDHBeg_SolmJ_Q5e0<2lkCVIjRHj<Q7UbLGV8W[G8dLfjVg97
8PP02RQCQ[OPnOobeJf2G3l`;c]?IW^9SXb3NG9aNHVO]/SAc;VILDHP1`0;:EF8
^N7joo7D[85J?Rl`?51WO8V>Rh=iLW5jRZ2gbM7<^9Q_A1l700`[EhZkh_[ol=:Z
OeTm;c0mDFQlRXj;PWQaLGZ;XKO9dL^gUVe37PH03BaIS;gTnoo_dJQmF3`_<3eB
JGf:SX^2N75bNhbR^<[AbkJEJd4M1@0>;U^>_^Gko^k?YgaF>bl`?U=ZOXZ>Rh9h
LG9kS:>ib]7:]I=Z?a/500l_GI30i_cnkLjUNUDk;c4oE6]nRhj:PGMaLWb=Y;[;
dLZdTVPn6P@0435OT/;Wo?k/c:=iE3X^<CmEK7n;SXZ1Mg5bO8jT^l_AbK>@IS`I
104A<f6Da>WmoN_;XGMB>Bha@5I]P8^>RX1gLG9mSjFlc=78/HiT>aP30A8dHiK6
j_gmj/VPME4h;S91Efj0S8j9P7IaLgf@Y[c<dLR`SF<i5`<14cIUV<O[oOgYb9id
D3P^<T9HKX6<SXUoMW5cOY6W_LgAajn;HCLF0P4D>6NJbNcno>S6W79?=bhc@eU_
PXb>RGmfLG=oTJRncM76[XYO=QD20QDiJIc;kOklilBJL4df;S=3FW22S8j8OgEa
M7nBZKo=dLJ]R5hd50825S][W/c^o__V`iU_C3H^=4AJLH>=SXQnMG5dP9>Z_lkA
aJ^6G3<B0@<H?FfPc^oonnG1Ufe;=BhdAE]bPhf>R7ieL7B0U:_0c]34ZXEJ<A41
0aToKj;?l?ojhl2EK4Xe;SE6G7>4SHj7OGA`M86E[<7>d<>YPeP`40446T1aY=7a
oo[R_YAZBC@^=DMMLhB=SXMmM71ePYJ]`/o@`jN1Ebh@00@K@W>Vdo;onN6lTVU8
=2hfB5idQHf=QgedL7F3Ujk2cm32YX1E;@l01Ae4MJSDloohh;^@IdLc;SI8GgF5
SXf6O7A`MX>H[l??cl6UOU<[3P057TIgZ]KdooSN^HiVAS<^=dUPMXJ>SHIlLg5f
Q9R`a=3?`:=lDRX=00HOB7V/eoGommfgSFA5<RhgBV5gQXj=QG]cLGJ5VK34d<no
XW]@:@`01b5:NjkImOofg;J;Hd@b;SQ;HWN7SXf5Ng=aMhFJ/LG@c[jPNDhW2`07
8T]m/=[fooGK]8UQ@c4^>DaSN8N>SHEkLg5gQY^ba]3>_ImgC2H:00PSCGnbg?Oo
mMVbR612<BliCFAiR8j<Q7YbLGR7W;?6d<jlWWI;90T02BE?P[?Mn?odf;66GT4`
;cY>IGZ8SXb4NW9aN8RM]<OAcK^LM4TS2@0:9U64]Mkhoo?F[hAM@30_>diVNXV>
S8AiLW5iR9jeb=7=^Y]bAb8800XXDhJgh?Wol]F]PU`o<2lkCfIkRHj<PgUbLGV9
WkK8dLbiVG5680L02bUER;WQn_oae:b1FSh_<3a@Igb9SX^3NG9aNXZP]lWAc;RH
Kd@O1`0<:eN:^n;joo3BZWmI?Bl`?E5XO8Z>Rh9hLG5jRj6gbM7;]iI]@ah600d/
FHbmi?_okm6XOEPl;c0mDVUmRXj;PWQaLW^<X[S:dL^fUF]17@D03RiKS[kUnok^
cjMlES/_<3iCJWj:SX^2N75bNhbS^L[Ab[FCJSlK1@0?;ef@`>Klo^g>YGYE>bla
?eA[OX^>RX5gLG9lSJBjbm7:]99X?QX4010aGi;2iocnk<bSNE@j;S4oEFaoRhj:
PGMaLWb>Y;_;dLVcT6Hl6@@14C=QU<CYoOg[bj5gDST^<D1FKH2;SXZ0Mg5bOHnU
_<cAb;6>I3/H0`4B=6>Fa^[moN[9X7EA>2hb@EM^P8b>RH1fLG=mT:Jlc=78/8eS
>AL30A<fIIS7jogmjLRNM50h;S92F6j1S8j9OgIaLgjAYkg=dLN_Rf4g5P8153QW
V/W/o_cXaYabCcL^<d=IKh:<SXUoMW5cOi6X_/gAaZj:GcHE0P8E>FVLbngno>O4
VW1==Rhc@eY`PXb>R7meLGAoTZVocM76[HQN=1@20QHkJik<k_kki/>IKd`f;SA4
FW63SHj8OWEaM82CZ[o>dLF[QU`c4P4363e]X<k_oo_U`IM]BcD^=4EKLX>=SXQn
MG1dP9B[`<k@a:Z5FS4A0@<I?fnRco3on^?0UFa:=BheAUacQ8f>QgedL7B1UJc1
c]33ZH=H<10111Y0LJCAlOojh[jDJTTd;SE7GG>4SHj7OGA`MH:F[L;?d<>WPEL^
40046d9cY]?booWQ_99YB3@^=TQNM8F=SHMmM71ePiN^`/o@`ZJ0EBd?00DMA7FX
e??on>2kT6M7<bhfB5meQHj=QWadL7J3V:o3clo1YGiC:`h01Ai6Mj[Fm?ohg[V>
ITHc;SM9H7J6SXf6O7=aMXBH/<C@cl2SO58Z3@067dQi[=OeooOM]heTAC8^=dYQ
MhJ>SHEkLg5fQIV`a=3?_j9kD2T<00LQBW^^fOGom]bfRf=4<RhhBf9gQhj=QG]c
LGN5V[75d<jnX7U>9`/01b9;OK3Jm_oefkB9HD<a;SU<HgR7SXf5Ng=aMhJK//K@
c[fOMd`V2P088deo/]cgooGI/XQP@S4_>DeTNHR>S8AjLW5hQibca]3>_9ifBb@9
00TUCh:cgOSom=RaQUi1<2ljCVEjR8j<Q7YbLGR8WKC7dLfkW7A98`T02RIAQ;GN
n?oceZn4GD0`;c]>IWZ9SXb4NG9aNHRN]LSAcKZKLTLR200::5>6]n3ioo;E[H9L
?c0_>dmVNhV>S8=iLW5iRInfb=7<^IUaAR0700/YEHRihO[olMB/PEXn;c0lD6Ml
RHj;PgUbLGZ:X;O9dLbhV6m47`L032]GR[_Rn_o`dZYoFCd_<3eAJ7b:SX^2N75a
NX^Q]lWAbkNFKD<N1P0=;5V<_NCkonoAZ7eH?2l`?E9YOHZ>Rh9hLG9kS::hb]7;
]YE[@Ad500h^FhjniO_nk/nWO5Hk;c0nDfYnRXj;PWQaLW^<XkW:dLZeTfXo6`D0
3bmMT<3Vo?k]cZEjEC/_<CmDJgj;SXZ1Mg5bO8fT^/_Ab[BBJ3hJ100@<EnB`^Ol
o^c<XgUD>Rha?eE/Oh^>RX5gLG9lSZBkbm79/i1V?1T40A4cHIC4jOgmjl^QMe8i
;S50EVf0Rhj:P7MaLWf?YKc<dLRaSV@k60<14SASU/KZoOgZbJ1eDCP^<T5GKX2<
SXV0MW5cOI2V_<cAb;2=HcTG0`4C=VFHan_moNW8WWA@>2hb@UQ^PHb>RGmfLG=n
TJNmcM77[h]Q=aH20A@hIi[9k?klj<JLLTlg;S=3FFn2S8j9OgIaLgnAZ;k=dLJ^
RUlf5@825CUYW<_]o_cWa9Y`CCH^<d=JL8:<SXQoMG5dOi:Y_lgAaZf8GS@D0P8F
>f^Nc>knnnK3VFm<=RhdA5YaPhf>R7ieLGB0TjZoc]75ZhIL<a810aPmKJ3>kook
iL6GKD/e;SA5Fg:3SHj8OWE`M82DZl3>d<BZQEXa4@436Cm_X/o`oo[S`9E/BSD^
=DILLhB=SXMmM71dPIF/`Lk@`jV3F30@0@@J@76TdO7on^:nU6Y9=2heAeecQ8f>
QgedL7F2UZg2cm33Yh5G;Q0011]2LjKCl_oihKbBJDPd;SI8GWB5SHf7OGA`MH>G
[/;?d<:VP5D]3`057DAeZ=CcooSP^i1WAc<^=TQOMHF>SHIlM71fPiR_`lo?`JEn
Db/>00DNAWNZe_Con=jiSVI6<bhgBF1fQXj=QWacLGJ4V;34d<o0XgaB:Pd01Qm8
NJcGmOoggKN=I4Db;SM:HGN6SXf5Ng=aMXFI/<C@cknRNe0Y30078DYk[]WeooKL
]X]SA38^>4]RMhN>SHEkLg5gQIZaaM3>_Z1iCRL;00LRBgf`f_KomM^dRF53<Bhi
C6=hQhj=QG]cLGN6Vk;6d<jmWgM<9PX022==Ok;LmooefK:8H48a;cU=I7V8SXb4
NW9aN8NL/lK@c[bNMT/T2@099Dn2/mghooCH/HIN@C0_>TiUNXR>S8AjLW5hR9fd
am7=^iadBB<900XVDHBeg_SolmJ_Q5e0<2lkCVIjRHj<Q7UbLGV8W[G8dLfjVg97
8PP02RQCQ[OPnOobeJf2G3l`;c]?IW^9SXb3NG9aNHVO]/SAc;VILDHP1`0;:EF8
^N7joo7D[85J?Rl`?51WO8V>Rh=iLW5jRZ2gbM7<^9Q_A1l700`[EhZkh_[ol=:Z
OeTm;c0mDFQlRXj;PWQaLGZ;XKO9dL^gUVe37PH03BaIS;gTnoo_dJQmF3`_<3eB
JGf:SX^2N75bNhbR^<[AbkJEJd4M1@0>;U^>_^Gko^k?YgaF>bl`?U=ZOXZ>Rh9h
LG9kS:>ib]7:]I=Z?a/500l_GI30i_cnkLjUNUDk;c4oE6]nRhj:PGMaLWb=Y;[;
dLZdTVPn6P@0435OT/;Wo?k/c:=iE3X^<CmEK7n;SXZ1Mg5bO8jT^l_AbK>@IS`I
104A<f6Da>WmoN_;XGMB>Bha@5I]P8^>RX1gLG9mSjFlc=78/HiT>aP30A8dHiK6
j_gmj/VPME4h;S91Efj0S8j9P7IaLgf@Y[c<dLR`SF<i5`<14cIUV<O[oOgYb9id
D3P^<T9HKX6<SXUoMW5cOY6W_LgAajn;HCLF0P4D>6NJbNcno>S6W79?=bhc@eU_
PXb>RGmfLG=oTJRncM76[XYO=QD20QDiJIc;kOklilBJL4df;S=3FW22S8j8OgEa
M7nBZKo=dLJ]R5hd50825S][W/c^o__V`iU_C3H^=4AJLH>=SXQnMG5dP9>Z_lkA
aJ^6G3<B0@<H?FfPc^oonnG1Ufe;=BhdAE]bPhf>R7ieL7B0U:_0c]34ZXEJ<A41
0aToKj;?l?ojhl2EK4Xe;SE6G7>4SHj7OGA`M86E[<7>d<>YPeP`40446T1aY=7a
oo[R_YAZBC@^=DMMLhB=SXMmM71ePYJ]`/o@`jN1Ebh@00@K@W>Vdo;onN6lTVU8
=2hfB5idQHf=QgedL7F3Ujk2cm32YX1E;@l01Ae4MJSDloohh;^@IdLc;SI8GgF5
SXf6O7A`MX>H[l??cl6UOU<[3P057TIgZ]KdooSN^HiVAS<^=dUPMXJ>SHIlLg5f
Q9R`a=3?`:=lDRX=00HOB7V/eoGommfgSFA5<RhgBV5gQXj=QG]cLGJ5VK34d<no
XW]@:@`01b5:NjkImOofg;J;Hd@b;SQ;HWN7SXf5Ng=aMhFJ/LG@c[jPNDhW2`07
8T]m/=[fooGK]8UQ@c4^>DaSN8N>SHEkLg5gQY^ba]3>_ImgC2H:00PSCGnbg?Oo
mMVbR612<BliCFAiR8j<Q7YbLGR7W;?6d<jlWWI;90T02BE?P[?Mn?odf;66GT4`
;cY>IGZ8SXb4NW9aN8RM]<OAcK^LM4TS2@0:9U64]Mkhoo?F[hAM@30_>diVNXV>
S8AiLW5iR9jeb=7=^Y]bAb8800XXDhJgh?Wol]F]PU`o<2lkCfIkRHj<PgUbLGV9
WkK8dLbiVG5680L02bUER;WQn_oae:b1FSh_<3a@Igb9SX^3NG9aNXZP]lWAc;RH
Kd@O1`0<:eN:^n;joo3BZWmI?Bl`?E5XO8Z>Rh9hLG5jRj6gbM7;]iI]@ah600d/
FHbmi?_okm6XOEPl;c0mDVUmRXj;PWQaLW^<X[S:dL^fUF]17@D03RiKS[kUnok^
cjMlES/_<3iCJWj:SX^2N75bNhbS^L[Ab[FCJSlK1@0?;ef@`>Klo^g>YGYE>bla
?eA[OX^>RX5gLG9lSJBjbm7:]99X?QX4010aGi;2iocnk<bSNE@j;S4oEFaoRhj:
PGMaLWb>Y;_;dLVcT6Hl6@@14C=QU<CYoOg[bj5gDST^<D1FKH2;SXZ0Mg5bOHnU
_<cAb;6>I3/H0`4B=6>Fa^[moN[9X7EA>2hb@EM^P8b>RH1fLG=mT:Jlc=78/8eS
>AL30A<fIIS7jogmjLRNM50h;S92F6j1S8j9OgIaLgjAYkg=dLN_Rf4g5P8153QW
V/W/o_cXaYabCcL^<d=IKh:<SXUoMW5cOi6X_/gAaZj:GcHE0P8E>FVLbngno>O4
VW1==Rhc@eY`PXb>R7meLGAoTZVocM76[HQN=1@20QHkJik<k_kki/>IKd`f;SA4
FW63SHj8OWEaM82CZ[o>dLF[QU`c4P4363e]X<k_oo_U`IM]BcD^=4EKLX>=SXQn
MG1dP9B[`<k@a:Z5FS4A0@<I?fnRco3on^?0UFa:=BheAUacQ8f>QgedL7B1UJc1
c]33ZH=H<10111Y0LJCAlOojh[jDJTTd;SE7GG>4SHj7OGA`MH:F[L;?d<>WPEL^
40046d9cY]?booWQ_99YB3@^=TQNM8F=SHMmM71ePiN^`/o@`ZJ0EBd?00DMA7FX
e??on>2kT6M7<bhfB5meQHj=QWadL7J3V:o3clo1YGiC:`h01Ai6Mj[Fm?ohg[V>
ITHc;SM9H7J6SXf6O7=aMXBH/<C@cl2SO58Z3@067dQi[=OeooOM]heTAC8^=dYQ
MhJ>SHEkLg5fQIV`a=3?_j9kD2T<00LQBW^^fOGom]bfRf=4<RhhBf9gQhj=QG]c
LGN5V[75d<jnX7U>9`/01b9;OK3Jm_oefkB9HD<a;SU<HgR7SXf5Ng=aMhJK//K@
c[fOMd`V2P088deo/]cgooGI/XQP@S4_>DeTNHR>S8AjLW5hQibca]3>_9ifBb@9
00TUCh:cgOSom=RaQUi1<2ljCVEjR8j<Q7YbLGR8WKC7dLfkW7A98`T02RIAQ;GN
n?oceZn4GD0`;c]>IWZ9SXb4NG9aNHRN]LSAcKZKLTLR200::5>6]n3ioo;E[H9L
?c0_>dmVNhV>S8=iLW5iRInfb=7<^IUaAR0700/YEHRihO[olMB/PEXn;c0lD6Ml
RHj;PgUbLGZ:X;O9dLbhV6m47`L032]GR[_Rn_o`dZYoFCd_<3eAJ7b:SX^2N75a
NX^Q]lWAbkNFKD<N1P0=;5V<_NCkonoAZ7eH?2l`?E9YOHZ>Rh9hLG9kS::hb]7;
]YE[@Ad500h^FhjniO_nk/nWO5Hk;c0nDfYnRXj;PWQaLW^<XkW:dLZeTfXo6`D0
3bmMT<3Vo?k]cZEjEC/_<CmDJgj;SXZ1Mg5bO8fT^/_Ab[BBJ3hJ100@<EnB`^Ol
o^c<XgUD>Rha?eE/Oh^>RX5gLG9lSZBkbm79/i1V?1T40A4cHIC4jOgmjl^QMe8i
;S50EVf0Rhj:P7MaLWf?YKc<dLRaSV@k60<14SASU/KZoOgZbJ1eDCP^<T5GKX2<
SXV0MW5cOI2V_<cAb;2=HcTG0`4C=VFHan_moNW8WWA@>2hb@UQ^PHb>RGmfLG=n
TJNmcM77[h]Q=aH20A@hIi[9k?klj<JLLTlg;S=3FFn2S8j9OgIaLgnAZ;k=dLJ^
RUlf5@825CUYW<_]o_cWa9Y`CCH^<d=JL8:<SXQoMG5dOi:Y_lgAaZf8GS@D0P8F
>f^Nc>knnnK3VFm<=RhdA5YaPhf>R7ieLGB0TjZoc]75ZhIL<a810aPmKJ3>kook
iL6GKD/e;SA5Fg:3SHj8OWE`M82DZl3>d<BZQEXa4@436Cm_X/o`oo[S`9E/BSD^
=DILLhB=SXMmM71dPIF/`Lk@`jV3F30@0@@J@76TdO7on^:nU6Y9=2heAeecQ8f>
QgedL7F2UZg2cm33Yh5G;Q0011]2LjKCl_oihKbBJDPd;SI8GWB5SHf7OGA`MH>G
[/;?d<:VP5D]3`057DAeZ=CcooSP^i1WAc<^=TQOMHF>SHIlM71fPiR_`lo?`JEn
Db/>00DNAWNZe_Con=jiSVI6<bhgBF1fQXj=QWacLGJ4V;34d<o0XgaB:Pd01Qm8
NJcGmOoggKN=I4Db;SM:HGN6SXf5Ng=aMXFI/<C@cknRNe0Y30078DYk[]WeooKL
]X]SA38^>4]RMhN>SHEkLg5gQIZaaM3>_Z1iCRL;00LRBgf`f_KomM^dRF53<Bhi
C6=hQhj=QG]cLGN6Vk;6d<jmWgM<9PX022==Ok;LmooefK:8H48a;cU=I7V8SXb4
NW9aN8NL/lK@c[bNMT/T2@099Dn2/mghooCH/HIN@C0_>TiUNXR>S8AjLW5hR9fd
am7=^iadBB<900XVDHBeg_SolmJ_Q5e0<2lkCVIjRHj<Q7UbLGV8W[G8dLfjVg97
8PP02RQCQ[OPnOobeJf2G3l`;c]?IW^9SXb3NG9aNHVO]/SAc;VILDHP1`0;:EF8
^N7joo7D[85J?Rl`?51WO8V>Rh=iLW5jRZ2gbM7<^9Q_A1l700`[EhZkh_[ol=:Z
OeTm;c0mDFQlRXj;PWQaLGZ;XKO9dL^gUVe37PH03BaIS;gTnoo_dJQmF3`_<3eB
JGf:SX^2N75bNhbR^<[AbkJEJd4M1@0>;U^>_^Gko^k?YgaF>bl`?U=ZOXZ>Rh9h
LG9kS:>ib]7:]I=Z?a/500l_GI30i_cnkLjUNUDk;c4oE6]nRhj:PGMaLWb=Y;[;
dLZdTVPn6P@0435OT/;Wo?k/c:=iE3X^<CmEK7n;SXZ1Mg5bO8jT^l_AbK>@IS`I
104A<f6Da>WmoN_;XGMB>Bha@5I]P8^>RX1gLG9mSjFlc=78/HiT>aP30A8dHiK6
j_gmj/VPME4h;S91Efj0S8j9P7IaLgf@Y[c<dLR`SF<i5`<14cIUV<O[oOgYb9id
D3P^<T9HKX6<SXUoMW5cOY6W_LgAajn;HCLF0P4D>6NJbNcno>S6W79?=bhc@eU_
PXb>RGmfLG=oTJRncM76[XYO=QD20QDiJIc;kOklilBJL4df;S=3FW22S8j8OgEa
M7nBZKo=dLJ]R5hd50825S][W/c^o__V`iU_C3H^=4AJLH>=SXQnMG5dP9>Z_lkA
aJ^6G3<B0@<H?FfPc^oonnG1Ufe;=BhdAE]bPhf>R7ieL7B0U:_0c]34ZXEJ<A41
0aToKj;?l?ojhl2EK4Xe;SE6G7>4SHj7OGA`M86E[<7>d<>YPeP`40446T1aY=7a
oo[R_YAZBC@^=DMMLhB=SXMmM71ePYJ]`/o@`jN1Ebh@00@K@W>Vdo;onN6lTVU8
=2hfB5idQHf=QgedL7F3Ujk2cm32YX1E;@l01Ae4MJSDloohh;^@IdLc;SI8GgF5
SXf6O7A`MX>H[l??cl6UOU<[3P057TIgZ]KdooSN^HiVAS<^=dUPMXJ>SHIlLg5f
Q9R`a=3?`:=lDRX=00HOB7V/eoGommfgSFA5<RhgBV5gQXj=QG]cLGJ5VK34d<no
XW]@:@`01b5:NjkImOofg;J;Hd@b;SQ;HWN7SXf5Ng=aMhFJ/LG@c[jPNDhW2`07
8T]m/=[fooGK]8UQ@c4^>DaSN8N>SHEkLg5gQY^ba]3>_ImgC2H:00PSCGnbg?Oo
mMVbR612<BliCFAiR8j<Q7YbLGR7W;?6d<jlWWI;90T02BE?P[?Mn?odf;66GT4`
;cY>IGZ8SXb4NW9aN8RM]<OAcK^LM4TS2@0:9U64]Mkhoo?F[hAM@30_>diVNXV>
S8AiLW5iR9jeb=7=^Y]bAb8800XXDhJgh?Wol]F]PU`o<2lkCfIkRHj<PgUbLGV9
WkK8dLbiVG5680L02bUER;WQn_oae:b1FSh_<3a@Igb9SX^3NG9aNXZP]lWAc;RH
Kd@O1`0<:eN:^n;joo3BZWmI?Bl`?E5XO8Z>Rh9hLG5jRj6gbM7;]iI]@ah600d/
FHbmi?_okm6XOEPl;c0mDVUmRXj;PWQaLW^<X[S:dL^fUF]17@D03RiKS[kUnok^
cjMlES/_<3iCJWj:SX^2N75bNhbS^L[Ab[FCJSlK1@0?;ef@`>Klo^g>YGYE>bla
?eA[OX^>RX5gLG9lSJBjbm7:]99X?QX4010aGi;2iocnk<bSNE@j;S4oEFaoRhj:
PGMaLWb>Y;_;dLVcT6Hl6@@14C=QU<CYoOg[bj5gDST^<D1FKH2;SXZ0Mg5bOHnU
_<cAb;6>I3/H0`4B=6>Fa^[moN[9X7EA>2hb@EM^P8b>RH1fLG=mT:Jlc=78/8eS
>AL30A<fIIS7jogmjLRNM50h;S92F6j1S8j9OgIaLgjAYkg=dLN_Rf4g5P8153QW
V/W/o_cXaYabCcL^<d=IKh:<SXUoMW5cOi6X_/gAaZj:GcHE0P8E>FVLbngno>O4
VW1==Rhc@eY`PXb>R7meLGAoTZVocM76[HQN=1@20QHkJik<k_kki/>IKd`f;SA4
FW63SHj8OWEaM82CZ[o>dLF[QU`c4P4363e]X<k_oo_U`IM]BcD^=4EKLX>=SXQn
MG1dP9B[`<k@a:Z5FS4A0@<I?fnRco3on^?0UFa:=BheAUacQ8f>QgedL7B1UJc1
c]33ZH=H<10111Y0LJCAlOojh[jDJTTd;SE7GG>4SHj7OGA`MH:F[L;?d<>WPEL^
40046d9cY]?booWQ_99YB3@^=TQNM8F=SHMmM71ePiN^`/o@`ZJ0EBd?00DMA7FX
e??on>2kT6M7<bhfB5meQHj=QWadL7J3V:o3clo1YGiC:`h01Ai6Mj[Fm?ohg[V>
ITHc;SM9H7J6SXf6O7=aMXBH/<C@cl2SO58Z3@067dQi[=OeooOM]heTAC8^=dYQ
MhJ>SHEkLg5fQIV`a=3?_j9kD2T<00LQBW^^fOGom]bfRf=4<RhhBf9gQhj=QG]c
LGN5V[75d<jnX7U>9`/01b9;OK3Jm_oefkB9HD<a;SU<HgR7SXf5Ng=aMhJK//K@
c[fOMd`V2P088deo\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](t) == 
      sin(800\ \[Pi]\ t) + sin(1200\ \[Pi]\ t)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Product of two sine waves ", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f2[t_] := 
        Sin[\[Pi]\ t]\ Sin[2  \[Pi]\ 400\ t];\)\), "\[IndentingNewLine]", 
    \(\(Play[f2[t], {t, 0, 2}];\)\), "\[IndentingNewLine]", 
    \(\[Florin][t] \[Equal] f2[t]\  // \ TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`00000Q
0000000000<00000ooooooooool0oooooolMooooo`40000000000`00003oooooooooo`0_ooooobgo
0000HOooool]o`0003;ooooo0@000000000300000?oooooooooo02Kooooo@Ol0001=oooood7o0000
9oooool10000000000<00000ooooooooool07OoooomBo`0003coooooD_l0000Oooooo`4000000000
0`00003oooooooooo`0Fooooof3o0000;OoooomQo`0001Sooooo0@000000000300000?oooooooooo
013oooooKOl0000Pooooofgo00004_ooool10000000000<00000ooooooooool02Ooooomio`0001Go
ooooNOl0000<ooooo`40000000000`00003oooooooooo`04oooood7o00000_oooom1o`0000Wooooo
QOl00006ooooo`40000000000`00003oooooo`00003oo`0001co00000Oooool10000000000<00000
ooooool00000ool0000Lo`00007ooooo0@000000000300000?oooooooooo00GoooooP_l0000<oooo
oh;o00001oooool10000000000<00000ooooooooool02ooooolfo`000003ooooool0003o000000ko
000000?oooooo`000?l00000;?l0000Hoooooc7o00000_oooom3o`0000gooooo0@00000000030000
0?oooooooooo017oooooJ_l0000Tooooof[o00004oooool10000000000<00000ooooooooool05ooo
oomMo`00037oooooGOl0000Jooooo`40000000000`00003oooooooooo`0Oooooodko0000?ooooom?
o`00027ooooo0@000000000300000?oooooooooo02Oooooo?ol0001?ooooocko0000:Oooool10000
000000<00000ooooooooool0<OoooolZo`0006Gooooo:?l0000dooooo`40000000000`00003ooooo
ooooo`3ooooooagooooo0@0000000?l000008@000000000300000?oooooooooo0?oooooo7Oooool1
0000000000<00000ooooooooool0?_ooool@o`0007gooooo4Ol00010ooooo`40000000000`00003o
ooooooooo`0jooooo`Go000000Coooooo`000?l0003o00000_ooool<o`0007Oooooo3Ol00002oooo
o`?o000000?oooooo`000?l000000_l0000mooooo`40000000000`00003oooooooooo`0iooooo`So
00001?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003ooooo07Co
oooo0_l000000ooooooo0000o`000003ooooo`04o`000?ooooooooooooooo`;o00000oooool9o`00
03_ooooo0@000000000300000?oooooooooo03Oooooo2?l00002ooooo`Go00001?ooool2o`000003
ooooool0003o000000;o000000Coooooo`000?l0003o0000Koooool<o`0000Cooooo1Ol00002oooo
o`;o000000?oooooo`000?l000000ol0000iooooo`40000000000`00003oooooooooo`0eooooo`Go
000000?oooooo`000?l000000oooool3o`0000;ooooo0ol000000ooooooo0000o`000004o`0000;o
oooo1_l0001[ooooo`Oo00000_ooool6o`000003ooooool0003o000000?ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000ol0000gooooo`40000000000`00003oooooooooo`0dooooo`?o0000
00?oooooo`000?l000001?l00002ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000000_l0001Zooooo`;o00000_ooool01Ol0003ooooo
oooooooooooo000000Kooooo0_l00006ooooo`03o`000?oooooooooo00Oo000000?oooooo`000?l0
0000=_ooool10000000000<00000ooooooooool0<_ooool6o`000003ooooool0003o000000?ooooo
1?l00003ooooo`;o00000_ooool2o`0000Cooooo0_l00003ooooo`03o`000?oooooo000000?o0000
I_ooool6o`0000?ooooo0_l00004ooooo`;o000000Coooooo`000?l0003o00000_ooool5o`0000?o
oooo0_l000000ooooooo0000o`000004o`0003Cooooo0@000000000300000?oooooooooo033ooooo
1Ol00002ooooo`;o00000oooool3o`0000?ooooo0ol00005oooooa7o0000HooooolAo`0000Gooooo
1?l00003ooooo`?o00000oooool00ol0003oooooooooo`06o`0003;ooooo0@000000000300000?oo
oooooooo02oooooo0ol00002ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooool00000
1oooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ooo
oooo0000ooooo`1Qooooo`06o`000?oooooo0000o`000?oooooo00000oooool00ol0003ooooooooo
o`02ooooo`;o00001_ooool01?l0003oooooooooool0000:ooooo`04o`000?ooooooooooo`0000;o
oooo0_l0000booooo`40000000000`00003oooooooooo`0^ooooo`?o000000?oooooo`000?l00000
2?l00005ooooo`04o`000?ooooooooooooooo`;o00000_ooool3o`000003ooooool0003o000000?o
oooo0_l00002ooooo`;o000000?oooooo`000?l000000_l0001Oooooo`Go000000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`02ooooo`;o000000Goooooo`000?l0003o0000ooooo`03o`00
00;ooooo0_l00004ooooo`ko0000<Oooool10000000000<00000ooooooooool0;Oooool6o`0000;o
oooo00Co0000oooooooooooooooo2?l00006ooooo`;o00001_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_l0001Looooo`Co000000?ooooo
o`000?l000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l00006
ooooo`Go000000?oooooo`000?ooool00_ooool2o`0000;ooooo1_l0000_ooooo`40000000000`00
003oooooooooo`0/ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`;o00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00?ooooo0ol00004ooooo`04o`000?oooooo0000o`0005[ooooo0_l000000ooooooo0000
ooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Go
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooo`000?l0000^ooooo`40000000000`00003oooooooooo`0[ooooo`Ko00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l000001?oooooo0000o`000?l00002oooo
o`04o`000?ooooooooooooooo`;o00001OoooolAo`0005Sooooo2Ol000000ooooooo0000ooooo`05
o`0000Gooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000_ooool2o`0000Cooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o0000;Oooool10000000000<0
0000ooooooooool0:Oooool4o`0000;ooooo00?o0000ooooooooool00_l00002ooooo`;o00001?oo
ool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooo`000002o`000003ooooool0
003ooooo00Cooooo00Co0000oooooooooooooooo1?l000000ooooooo0000o`00001Eooooo`Ko0000
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go0000
1_ooool2o`0000Gooooo0_l00004ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003o
ooooooooo`03o`0002cooooo0@000000000300000?oooooo000002[ooooo0_l00002ooooo`03o`00
0?oooooo000000So00002Oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo0000E?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`Wo000000Ko
ooooo`000?oooooo0000ooooool0000/ooooo`40000000000`00003oooooooooo`0Xooooo`Wo0000
1?ooool00ol0003oooooooooo`04o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo
0_l000000ooooooo0000o`000004ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;o
oooo1Ol0001Booooo`Co00000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00004oooo
o`Go00000oooool2o`0000;ooooo0_l00005ooooo`?o00000oooool01_l0003ooooooooooooooooo
0000ooooo`So0000:_ooool10000000000<00000ooooooooool09_ooool7o`0000?ooooo00Go0000
ooooooooooooooooo`000005ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool0
0oooool4o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007o`0000;ooooo
00?o0000ooooool000000_l0001@ooooo`?o000000?oooooo`000?ooool02?l000000ooooooo0000
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooool0003o00001?ooool2o`0000;o
oooo0_l000000ooooooo0000ooooo`03ooooo`;o00000oooool00ol0003oooooooooo`07o`0002Wo
oooo0@000000000300000?oooooooooo02Oooooo00?o0000ooooool000001Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0000Kooooo
00?o0000ooooooooool00_ooool3o`0000Kooooo0_l00002ooooo`03o`000?oooooo000000;o0000
C_ooool3o`000004ooooool0003oooooooooo`;o00001_ooool3o`0000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool0:?ooool100000000
00<00000ooooooooool09Oooool4o`000003ooooool0003o000000;ooooo00Co0000oooooooooooo
oooo0_l00003ooooo`;o00001Oooool3o`0000Gooooo1?l00006ooooo`Co00000_ooool01?l0003o
ooooooooooooool2o`0000;ooooo1?l00002ooooo`?o0000C?ooool3o`000003ooooool0003o0000
00?o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Co00001_ooool3o`00
00Kooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`05o`000?oooooooooo
ooooool000000_ooool4o`0002Oooooo0@000000000300000?oooooooooo02Cooooo1?l00002oooo
o`03o`000?oooooo000000So00000_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000000oooool2o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l00004
ooooo`06o`000?ooooooooooooooool0003ooooo0_l000001?oooooo0000o`000?l0001:ooooo`?o
000000Goooooo`000?l0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool3o`0000?ooooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00005oooo
o`03o`000?oooooooooo00Wo000000Coooooo`000?oooooooooo1?l0000Vooooo`40000000000`00
003oooooooooo`0Sooooo`Co00000oooool2o`000003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool00ol0000;ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`0?ooooo`;o000000?oooooo`000?ooool0B?ooool5o`00017ooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
2oooool2o`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00Co0000oooo
ool0003o00009_ooool10000000000<00000ooooooooool08oooool2o`000003ooooool0003ooooo
00?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`Go000000?oooooo`00
0?l000001_ooool2o`0000Oooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002oooo
o`;o00000_ooool2o`0000;ooooo1Ol00018ooooo`?o000000Goooooo`000?ooooooooooo`000003
ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001ooo
ool2o`0000Kooooo00?o0000ooooooooool01?l00005ooooo`06o`000?ooooooooooooooool0003o
oooo0ol000000ooooooo0000o`000002o`0002Gooooo0@000000000300000?oooooooooo02;ooooo
0_l000000ooooooo0000o`000002o`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`04
o`000?ooooooooooooooo`?o00001Oooool2o`000003ooooool0003o000000Gooooo0ol00005oooo
o`;o00001?ooool:o`000004ooooool0003o0000ooooo`Co0000A?ooool4o`000004ooooool0003o
0000ooooo`[o00001?ooool2o`0000Gooooo0ol00005ooooo`04o`000?ooooooooooo`0000Kooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`Oo
00009?ooool10000000000<00000ooooooooool08Oooool5o`0000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000co
oooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooo000000;o00000oooool4o`0004Co
oooo0ol00004ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`00
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo0000
00;o00008oooool10000000000<00000ooooooooool08?ooool5o`000003ooooool0003o000000;o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_l00002ooooo`;o00001?ooool00ol0003oooooooooo`02o`0000?ooooo0_l00005oooo
o`;o00001?ooool01Ol0003ooooooooooooooooo000000;ooooo1Ol000000ooooooo0000o`000002
o`0004;ooooo1?l000000ooooooo0000o`000002o`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000?ooooo0_l000000ooooooo0000ooooo`04
ooooo`;o00000_ooool2o`000003ooooool0003ooooo00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo0_l000000ooooooo0000o`000002o`0002?ooooo0@00
0000000300000?oooooooooo01oooooo1Ol000000ooooooo0000ooooo`02ooooo`So000000?ooooo
o`000?ooool01?ooool2o`0000Cooooo0_l00007ooooo`;o00001_ooool00ol0003oooooooooo`03
o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooo
oooo0000ooooo`;o000000?oooooo`000?l000000_l00010ooooo`Co000000Goooooo`000?oooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooo`000?l00002
ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`?o00001?ooool2o`0000Cooooo0_l00000
0ooooooo0000o`000006o`0000;ooooo00?o0000ooooooooool01Ol0000Qooooo`40000000000`00
003oooooooooo`0Pooooo`03o`000?oooooo000000Cooooo0_l00003ooooo`04o`000?oooooooooo
ooooo`?o00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Kooooo0ol00009
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000002
o`00043ooooo00?o0000ooooool000000_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool3o`0000Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0:
ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`0002?ooooo0@000000
000300000?oooooooooo01kooooo1?l00002ooooo`?o000000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooo000000Co00001Oooool2o`000003ooooool0003ooooo
00?ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o000000?ooooo
o`000?l00000?_ooool6o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`;o00001Oooool2o`0000Gooooo00Go0000ooooooooooooooooo`00
0004ooooo`;o000000?oooooo`000?l000001Oooool00ol0003oooooo`000002o`000003ooooool0
003ooooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`000003ooooool0003ooooo00?o
00008?ooool10000000000<00000ooooooooool07Oooool3o`000004ooooool0003o0000o`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00002oooo
o`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`02ooooo`Oo00000_ooool00ol0
003oooooo`000002ooooo`04o`000?oooooo0000o`0003cooooo1?l000001Ooooooo0000oooooooo
oooo000000;ooooo1_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l0
0002ooooo`;o00001?ooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00004ooooo`05o`000?ooooooooooooooool000000_ooool4o`000004oooo
ool0003o0000o`0001oooooo0@000000000300000?oooooooooo01cooooo0ol00002ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooool000002oooool00ol0
003oooooo`000003o`0000Gooooo0ol00002ooooo`03o`000?oooooooooo00?o0000??ooool00ol0
003oooooo`000002ooooo`03o`000?oooooooooo00?o00001Oooool3o`0000;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooo`000007ooooo`;o00001_ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooool000000ol0000Nooooo`40000000000`00003oooooooooo`0Kooooo`Ko00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooooooool4o`0000Kooooo0ol00007ooooo`;o00001Oooool2o`0000?ooooo
1?l00003ooooo`04o`000?ooooooooooooooo`;o00000_ooool4o`000003ooooool0003o000000?o
0000>?ooool4o`0000;ooooo1?l00002ooooo`;o00000oooool01?l0003oooooooooooooool3o`00
00Cooooo0_l00005ooooo`;o00001oooool2o`0000Oooooo0ol00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
oooooooooooo0000ooooo`03o`0001kooooo0@000000000300000?oooooooooo01[ooooo1_l00002
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool2o`0000Kooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
o`000006ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool01?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooool000000_l000000ooooooo0000o`000002o`0003Oo
oooo1Ol000001Ooooooo0000o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool01_ooool3o`00
00Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`Go00007Ooo
ool10000000000<00000ooooooooool06_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000
ooooooooool01Ol000000ooooooo0000o`000002o`0000Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooo000003Kooooo
00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`000006ooooo`03o`000?oooooooooo00?ooooo1?l000000ooooooo0000o`000003o`00
00;ooooo00Co0000oooooooooooo00000_ooool2o`0001cooooo0@000000000300000?oooooooooo
01Wooooo1_l000000ooooooo0000o`000003o`0000;ooooo00?o0000ooooooooool00oooool4o`00
0003ooooool0003ooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00?ooooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00;ooooo1?l00005
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Oo0000=?ooool7o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0
0oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00;o00000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooo000000?o00001?ooool01?l0003oooooooooooooool4o`00
00;ooooo1Ol0000Looooo`40000000000`00003oooooooooo`0Hooooo`Co000000?oooooo`000?oo
ool00_l00002ooooo`05o`000?ooooooooooooooool000000oooool2o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo00?ooooo0ol00007ooooo`03o`000?oooooooooo00Cooooo0_l000000ooo
oooo0000o`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_l0000cooooo`?o000000Cooooo
o`000?l0003o00000_ooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l00000
1Oooool2o`0000Oooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000;ooooo0ol0000Koooo
o`40000000000`00003oooooooooo`0Iooooo`;o00000_ooool3o`0000;ooooo00?o0000oooooooo
ool03?ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`So000000?oooooo`000?ooool00oooool00ol0003oooooo`000002
o`0003;ooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Oo00001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000ooooo`0=ooooo`03o`000?oooooooooo00?o00000_ooool2o`0001_ooooo0@00
0000000300000?oooooooooo01Sooooo0ol000001?oooooo0000o`000?l00002ooooo`04o`000?oo
ooooooooooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o
000000?oooooo`000?ooool01?ooool4o`0000Gooooo00Co0000oooooooooooo00001_ooool2o`00
00Kooooo00?o0000ooooooooool00_ooool7o`0000?ooooo1Ol000001?oooooo0000ooooooooool5
o`00033ooooo1Ol000000ooooooo0000ooooo`04o`000003ooooool0003ooooo00;ooooo00?o0000
ooooool000001?l00004ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooool0003o0000ooooo`03o`0001[ooooo0@000000000300000?oooooooooo01Kooooo1?l0
00001Ooooooo0000o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000Kooooo00Go0000oooooooo
ooooooooo`000003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000
ooooooooool01?ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`Co000000?oooooo`000?l000000ol0000^ooooo`Go0000
00?oooooo`000?l000000_l00003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooo`000002o`000003ooooool0003ooooo00Gooooo00Co0000oooooooooooo00000oooool2o`00
00?ooooo0_l00002ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooo000000Ko00006?ooool10000000000<00000ooooooooool06Oooool2o`00
00Wooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l0000=ooooo`03o`000?oooooooooo
00?ooooo0_l000000ooooooo0000ooooo`03o`0002kooooo1?l00002ooooo`;o00001?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`00
00Sooooo0ol0000Kooooo`40000000000`00003oooooooooo`0Eooooo`Ko00000_ooool00ol0003o
ooooo`000005o`000003ooooool0003o000000Co00000_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;o000000?oooooo`000?ooool01Oooool2o`0000Oooooo0ol00005ooooo`03
o`000?oooooooooo00;ooooo0ol00004ooooo`;o00001?ooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l00002ooooo`03o`000?oooooo000000Co0000;?ooool3o`000004ooooool0003ooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool01?ooool3o`0000Kooooo0ol0
0005ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Ko000000?oooooo`000?l000001?l000001?oooooo0000ooooooooool5o`0001Sooooo
0@000000000300000?oooooooooo01Cooooo1_l000000ooooooo0000o`000003o`0000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04o`0000Cooooo0_l00004ooooo`?o00001ooo
ool2o`0000Oooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00003ooooo`06o`000?oooooooooooooo
ool0003ooooo1ol0000[ooooo`Oo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o00000_oo
ool00ol0003oooooooooo`04ooooo`;o00001oooool2o`0000Oooooo0_l00005ooooo`;o00001?oo
ool3o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`Go00000_ooool5o`0001Oooooo
0@000000000300000?oooooooooo01Cooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo000000_ooooo
0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001oooool2o`0000Cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003ooooo
ooooo`0Xooooo`07o`000?ooooooooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00oooool2o`0000Oooooo00?o0000ooooool000001Oooool01?l0
003oooooooooool00006ooooo`;o00002_ooool00ol0003oooooo`000005ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooooooool4o`0001Kooooo0@000000000300000?oo
oooooooo01?ooooo1?l000000ooooooo0000o`000002o`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l000000ooooooo0000
ooooo`05ooooo`04o`000?oooooo0000o`0000Cooooo00Co0000oooooooooooooooo0_l00003oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo3ol00002ooooo`Oo0000:?ooool3o`000004ooooool0003o0000o`0000;ooooo3_l0
0005ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`04o`000?ooooooooooo`0000Cooooo
0_l00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooo`000002o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool3o`000003ooooool0003o000000;o00005_ooool10000
000000<00000ooooooooool04_ooool5o`000004ooooool0003oooooo`0000;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2
o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`;o00001?ooool00ol0003ooooooooo
o`02o`0000Cooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`05ooooo`03o`00
0?oooooooooo00Co00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Co0000
00?oooooo`000?l000000ol0000Wooooo`Oo000000Coooooo`000?l0003o00000_ooool01Ol0003o
oooooooooooooooo000000Cooooo0ol00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
ool0003o00000oooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool01?ooool2
o`0000;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`?o0000
00?oooooo`000?l000000_l0000Eooooo`40000000000`00003oooooooooo`0Booooo`?o00000_oo
ool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Kooooo0_l00006ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01?ooool3o`0000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02o`0000Cooooo1?l0000Vooooo`Co00000oooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo0_l00008ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00ol0000Dooooo`40000000000`00003oooooooooo`0Aooooo`Ko00000_ooool0
0ol0003oooooooooo`0:o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
o`0000;ooooo00?o0000ooooooooool01?ooool2o`0000Oooooo0_l00007ooooo`?o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool4o`000003ooooool0003o000000;o00009Oooool5o`000003ooooool0
003o000000;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Oooooo00?o
0000ooooooooool01Oooool2o`0000Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo2_l00002ooooo`03o`000?oooooooooo00;o0000
00Coooooo`000?l0003o00004oooool10000000000<00000ooooooooool04?ooool3o`000003oooo
ool0003o000000;ooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo1_l00005ooooo`;o0000
1?ooool2o`0000Oooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o0000
1_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00So00008_ooool5o`000005
ooooool0003o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo0_l0
0006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool3o`0000Cooooo0_l0
0005ooooo`Co000000?oooooo`000?ooool00oooool00ol0003oooooooooo`03o`000003ooooool0
003ooooo00Ko00004oooool10000000000<00000ooooooooool04?ooool4o`000003ooooool0003o
oooo00Co00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0ol0000;
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l000000ooooooo
0000o`00000Tooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`09ooooo`?o00001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooool000000_l000000ooooooo0000o`000004o`0001;ooooo0@00
0000000300000?oooooooooo00oooooo1_l000000ooooooo0000o`000002ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o000000?o
ooooo`000?ooool01Oooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0
003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Oo00000oooool00ol0003oooooo`000004o`000003ooooool0003o0000023ooooo1ol00002oooo
o`03o`000?oooooooooo00So00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo0_l00006ooooo`03o`000?oooooooooo00;o00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`;o000000?oooooo`000?ooool01Ooo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooo000000;o000000?oooooo`000?l000000ol0000Booooo`40
000000000`00003oooooooooo`0?ooooo`So00000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o00001Oooool01?l0003o
ooooooooooooool2o`0000;ooooo00?o0000ooooooooool00oooool4o`0000Gooooo00?o0000oooo
ool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
oooooooooooo1?l00003ooooo`04o`000?ooooooooooooooo`Co00000_ooool00ol0003oooooo`00
0004o`0001oooooo1_l000000ooooooo0000ooooo`05o`0000?ooooo00?o0000ooooooooool01Ol0
0003ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooool0003o00001?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?oooooo0000o`0000Gooooo1?l00005ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool3o`000003ooooool0003o
000000;o00004Oooool10000000000<00000ooooooooool03_ooool01?l0003oooooo`000?l00002
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00Ko0000oooooooooooo0000ooooool00002ooooo`;o00007_ooool02?l0
003ooooooooooooooooo0000ooooool0003ooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooool000001_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Co00004?ooool10000
000000<00000ooooooooool03Oooool7o`000006ooooool0003oooooooooool0003ooooo1ol00004
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo0ol00006ooooo`;o00001oooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`000?l000000ol0000Mooooo`[o0000
0oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooooooo0ol00005oooo
o`03o`000?oooooooooo00;ooooo0ol00008ooooo`03o`000?oooooooooo00Gooooo0_l00007oooo
o`;o00001_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`Oo000000Soooooo`000?ooooooooooo`000?oooooo0000ooooo`Co0000
4?ooool10000000000<00000ooooooooool03Oooool6o`000003ooooool0003ooooo00Co000000?o
ooooo`000?ooool00_ooool5o`000003ooooool0003ooooo00Cooooo00?o0000ooooooooool00_oo
ool3o`0000Oooooo0ol00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000ooooool0003o
00001Oooool2o`0000Kooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`04oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?ooooo
o`000?l000000ol0000Looooo`Go000000Coooooo`000?oooooo00000_ooool2o`0000?ooooo00Co
0000oooooooooooooooo0_l00005ooooo`04o`000?oooooo0000o`0000;ooooo00?o0000oooooooo
ool01Oooool2o`0000Gooooo0_l000000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooo`00
00Gooooo0ol00007ooooo`?o00000oooool2o`0000Gooooo00?o0000ooooool000000ol00004oooo
o`03o`000?oooooo000000Go000000?oooooo`000?l000001?l0000?ooooo`40000000000`00003o
ooooooooo`0=ooooo`03o`000?oooooo000000;o00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`;o
00001_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000000ol0000K
ooooo`Oo00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000001_ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000?ooooo
0_l000000ooooooo0000ooooo`0?ooooo`40000000000`00003oooooooooo`0<ooooo`Go00000_oo
ool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000000;o000000?oooooo`000?l000001_ooool3o`0000Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo0_l00003ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`;o00000_ooool6o`0000;ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00006_ooool6
o`0000;ooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00001_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001?l00005ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003oooooo`000?l0003ooooo00Ko00003_ooool1
0000000000<00000ooooooooool02oooool4o`000004ooooool0003o0000o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool2o`0000Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooool000001_ooool2o`0000Oooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo
0_l000000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooooooo`Ko000000Coooooo`000?oo
oooooooo1_l000000ooooooo0000ooooo`05o`0001Sooooo1_l00002ooooo`Go00000oooool00ol0
003oooooo`000004o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo
00Cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00?o000000?oooooo`000?l000000_l0000=ooooo`40000000000`00
003oooooooooo`0:ooooo`Co000000?oooooo`000?l000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo00Cooooo
00Oo0000oooooooooooo0000ooooool0003ooooo00;o00005oooool3o`000005ooooool0003ooooo
o`000?ooool00_l00006ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000ooooo`04
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`000?l00000
3Oooool10000000000<00000ooooooooool02_ooool6o`000004ooooool0003oooooo`0000;ooooo
1ol00004ooooo`03o`000?oooooooooo00?ooooo0_l000001?oooooo0000o`000?l00002ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool2o`0000Oooooo0_l00007ooooo`;o
00001oooool3o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00003ooooo`04
o`000?ooooooooooooooo`;o000000Goooooo`000?l0003o0000ooooo`06o`0001Kooooo2Ol00002
ooooo`05o`000?ooooooooooooooool000001?ooool2o`0000?ooooo0ol00005ooooo`03o`000?oo
oooooooo00;ooooo0ol00007ooooo`;o00001_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03o`000003ooooool0
003o000000Gooooo00?o0000ooooooooool00_ooool7o`000008ooooool0003oooooooooool0003o
ooooo`000?ooool4o`0000cooooo0@000000000300000?oooooooooo00Wooooo2?l000000ooooooo
0000o`000003o`0000?ooooo1ol00005ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;o
00001?ooool01?l0003oooooooooool00006ooooo`;o00001_ooool00ol0003oooooooooo`02o`00
0003ooooool0003ooooo00Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000oooo
ooooool00ol000000ooooooo0000o`000003o`0001Cooooo2Ol00002ooooo`04o`000?oooooooooo
ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool01?ooool2o`0000Kooooo00Co0000oooooooooooo00001?ooool2o`000003oooo
ool0003o000000Cooooo0_l000000ooooooo0000ooooo`04ooooo`?o00001oooool2o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000004o`0000?ooooo00?o0000ooooool00000
0ol000000ooooooo0000ooooo`06o`0000_ooooo0@000000000300000?oooooooooo00Wooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000oooool00ol0003oooooooooo`07ooooo`;o00001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`08o`000?ooooooooooooooool0003oooooo`000?oo
ool4o`0001Cooooo1?l000001?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool01?l0003oooooooooooooool3o`0000Wooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2
o`0000Wooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooo000000;o00002ooo
ool10000000000<00000ooooooooool02?ooool5o`000003ooooool0003o000000;o00000oooool0
1?l0003oooooooooooooool2o`0000Cooooo00?o0000ooooool000000_l000000ooooooo0000oooo
o`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00005ooooo`04o`000?oooooo0000o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Oo00000_ooool00ol0
003oooooo`000006o`0001;ooooo1_l000000ooooooo0000ooooo`02ooooo`So000000?oooooo`00
0?ooool01?ooool00ol0003oooooooooo`03ooooo`;o00001_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool4o`0000Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0000Ko
oooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`02ooooo`;o00000oooool01?l0
003oooooooooooooool4o`000003ooooool0003o000000?o00002_ooool10000000000<00000oooo
ooooool01oooool5o`000005ooooool0003o0000ooooool000000oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00Co0000oooooooooooooooo
0_l000000ooooooo0000o`000005ooooo`?o00001oooool00ol0003oooooooooo`06ooooo`;o0000
1_ooool01?l0003oooooo`000?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Go
oooo00?o0000ooooooooool01?l00004ooooo`04o`000?ooooooooooooooo`Co000000?oooooo`00
0?l000001?l0000Aooooo`Ko00000_ooool4o`0000?ooooo00Co0000oooooooooooooooo1?l00002
ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool00_ooool2
o`000003ooooool0003ooooo00Gooooo0_l00007ooooo`;o00001_ooool3o`0000Kooooo00?o0000
ooooooooool00_l00003ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?ooool0
1?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool01ol0000:ooooo`4000000000
0`00003oooooooooo`07ooooo`?o000000?oooooo`000?l000000oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`000?oooooooooo013ooooo0_l0
0007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`;o00002?ooool01_l0003ooooooooooooooooo0000ooooo`;o000000Coooooo`000?l0
003ooooo0ol0000@ooooo`?o000000Goooooo`000?l0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000002?ooool2o`0000_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo0_l0000Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooool000002oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
1_l00009ooooo`40000000000`00003oooooooooo`06ooooo`So000000?oooooo`000?l000002Ol0
0002ooooo`;o00001Oooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool01?oo
ool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001ooo
ool00ol0003oooooooooo`05ooooo`?o00001?ooool2o`0000Cooooo0ol00004ooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo2Ol0000>ooooo`So00000_ooool01Ol0003ooooo
oooooooooooo000000Cooooo0_l00004ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`?o
00001_ooool2o`0000Oooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00005oooo
o`?o00001oooool2o`0000Gooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool;o`000003ooooool0003o000000Ko00002?ooool10000000000<00000oooooooo
ool01Oooool:o`0000;ooooo00Co0000oooooooooooooooo0_l00003ooooo`Co00000oooool2o`00
00Gooooo0_l00006ooooo`;o000000?oooooo`000?ooool00oooool2o`0000;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`;o000000?oooooo`000?ooool01Oooool2o`0000Oooooo00Co0000ooooool0003o0000
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001ol0000<ooooo`Co000000?oooooo`000?l000000_l000000ooooooo0000
o`000002ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o
000000?oooooo`000?ooool01Oooool2o`0000Oooooo00Co0000ooooool0003o00001?ooool01?l0
003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooo`000007ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`Co0000
0oooool01?l0003oooooooooooooool2o`000005ooooool0003o0000o`000?ooool01_l00008oooo
o`40000000000`00003oooooooooo`05ooooo`03o`000?oooooo000000?o000000?oooooo`000?l0
00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool01?ooool2o`0000Wooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000006ooooo`;o00001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Go000000?oooooo`000?ooool00oooool00ol0003oooooo`000003
o`0000cooooo1Ol00004ooooo`03o`000?oooooo000000Go00000_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Sooooo
0_l00006ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`?o000000Koooooo`000?l0003o0000ooooool00007ooooo`40000000000`00
003oooooooooo`04ooooo`Wo00000_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`00
00?ooooo0ol00006ooooo`04o`000?ooooooooooo`0000Cooooo0_l00003ooooo`03o`000?oooooo
oooo00;o00001Oooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool0
0oooool2o`0000Kooooo0_l00002ooooo`Co00000oooool00ol0003oooooo`000005o`000003oooo
ool0003o000000Co00002_ooool=o`000004ooooool0003oooooooooo`Go00000_ooool2o`0000Ko
oooo0_l00005ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`;o000000?oooooo`000?ooool01Oooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Gooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`000003ooooool0003o
oooo00Kooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`?o000000?oooooo`000?l000000_l00007ooooo`40000000000`00003oooooooooo`04
ooooo`Ko000000?oooooo`000?ooool01ol00005ooooo`03o`000?oooooooooo00?ooooo1?l00003
ooooo`;o00000oooool2o`000003ooooool0003ooooo00Gooooo0_l00007ooooo`;o00001oooool2
o`0000Oooooo0_l00006ooooo`;o000000?oooooo`000?ooool00oooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00005ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`;o00000_oo
ool:o`0000Wooooo2ol00002ooooo`;o00000oooool01?l0003oooooooooooooool3o`0000Kooooo
0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`0000Ko
oooo0_l00007ooooo`;o00001_ooool2o`0000Oooooo0ol00006ooooo`04o`000?oooooo0000o`00
00?ooooo0_l00003ooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`[o000000?oooooo`00
0?l000001?l00006ooooo`40000000000`00003oooooooooo`03ooooo`;o00000_ooool00ol0003o
ooooooooo`04o`0000Cooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo0_l00007ooooo`;o00002?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000000[ooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`;o000000Coooooo`000?oooooo00002Oooool4o`000003ooooool0
003o000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`;o0000
2_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool2o`0000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02o`000003
ooooool0003ooooo00;ooooo00?o0000ooooool000000_l00002ooooo`04o`000?oooooo0000o`00
00Kooooo0@000000000300000?oooooooooo00?ooooo2?l000000ooooooo0000o`000002ooooo`;o
00001?ooool3o`0000Cooooo0_l00004ooooo`?o00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`;o
00001_ooool3o`0000Oooooo0_l00005ooooo`;o000000Coooooo`000?l0003o00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo0000o`000007o`00
00Sooooo1_l000000ooooooo0000o`000004o`0000?ooooo0_l00004ooooo`;o00000_ooool2o`00
00;ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo0ol00006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo0000
00Kooooo0_l00006ooooo`Co00001?ooool2o`0000Cooooo0ol00004ooooo`04o`000?oooooooooo
ooooo`;o000000?oooooo`000?l000001_l00005ooooo`40000000000`00003oooooooooo`02oooo
o`Oo000000?oooooo`000?l000000oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`00
0?ooool01_ooool2o`0000Kooooo00Co0000ooooool0003o00001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool00000
1oooool2o`0000Gooooo0_l00003ooooo`Go000000?oooooo`000?l000002ol00006ooooo`co0000
0_ooool5o`0000?ooooo0_l00005ooooo`;o00001oooool2o`0000Kooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00005ooooo`;o000000?o
ooooo`000?ooool01Oooool2o`0000Kooooo0_l000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`0000?ooooo00?o0000ooooooooool01ol00004ooooo`40000000000`00003oooooooooo`02
ooooo`Co000000Coooooo`000?oooooooooo1Ol00005ooooo`03o`000?oooooooooo00Cooooo0_l0
0006ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000006_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Sooooo0_l0
0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo1ol00005ooooo`So0000
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00002?ooool00ol0003o
ooooo`000005ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`;o0000
1Oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool00ol0003oooooo`000003o`0000Cooooo
0@000000000400000?ooooooooooooooo`Wo00000oooool8o`0000Gooooo00Co0000ooooool0003o
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001?ooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo1?l00005ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02o`0000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`;o00001?oo
ool00ol0003oooooooooo`08o`0000Cooooo1Ol000001?oooooo0000ooooooooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0000Gooooo00?o0000ooooooooool00_l00003ooooo`03o`00
0?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooo`0000Go
oooo00Co0000oooooooooooo00001Oooool4o`0000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00004ooooo`;o00000_ooool01?l0003oooooooooooooool2o`0000Cooooo
00?o0000ooooool000001_ooool8o`0000;ooooo2_l00003ooooo`40000000000`00003ooooooooo
o`05o`000004ooooool0003o0000o`0000;ooooo0_l00004ooooo`Go00000oooool2o`0000?ooooo
00Co0000ooooool0003o00001Oooool3o`0000Oooooo0_l00007ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`?o00001_ooool3o`0000Kooooo0_l00006ooooo`Co00001?ooool2o`0000;o
oooo0_l00002ooooo`;o00001Oooool@o`0000;ooooo4?l00004ooooo`?o000000Coooooo`000?l0
003o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Oooooo0_l00006oooo
o`03o`000?oooooo000000Kooooo00Co0000ooooool0003o00000oooool2o`0000?ooooo1Ol00004
ooooo`;o00000_ooool9o`0000;ooooo0@000000000300000?oooooooooo00co00001?ooool00ol0
003oooooooooo`03ooooo`?o00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0
003oooooooooo`02o`0000;ooooo0_l00003ooooo`;o00000_ooool5o`0000;ooooo1Ol00002oooo
o`;o00000oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00001oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00_ooool<
o`0000;ooooo0@000000000300000?oooooo000000[o000000?oooooo`000?l000000ol00006oooo
o`?o00001_ooool3o`0000Kooooo0ol00005ooooo`Co00001Oooool4o`0000Gooooo00Co0000oooo
ool0003o00001Oooool01?l0003oooooo`000?l00004ooooo`;o000000?oooooo`000?ooool01?oo
ool2o`000003ooooool0003ooooo00Gooooo0_l00007ooooo`;o00001oooool3o`0000Cooooo6ol0
0005ooooo`?o00001_ooool3o`0000Kooooo00?o0000ooooool000001Oooool2o`000003ooooool0
003ooooo00Cooooo0_l000000ooooooo0000ooooo`04ooooo`Co00001Oooool4o`0000Gooooo1?l0
0005ooooo`04o`000?oooooo0000o`0000Gooooo00?o0000ooooool000001_ooool3o`0000Kooooo
0ol00005ooooo`Go00000_ooool3o`000003ooooool0003o000000Go00000Oooool10000000000<0
0000ooooool000002?l00004ooooo`;o000000?oooooo`000?l000001?ooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0>oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool4o`0000?ooooo2ol00004ooooo`Co00001Oooool01?l0003oooooooooool00005ooooo`04o`00
0?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000?Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001Oooool2o`000003ooooool0
003ooooo00Cooooo2Ol00001ooooo`40000000000`00003oooooo`000005o`0000;ooooo1_l00003
ooooo`Ko00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooooooo`02
ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001?ooool0
0ol0003oooooooooo`02o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo0_l00002
ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000o`000004ooooo`Go00000ooooolC
o`0000Cooooo1Ol00004ooooo`;o000000?oooooo`000?l000000oooool2o`0000;ooooo0_l00003
ooooo`;o00000_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000;ooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
o`0000Cooooo00?o0000ooooooooool00_l00003ooooo`;o00000_ooool2o`0000?ooooo0_l00002
ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l000001?ooool5
o`0000?ooooo1_l00001ooooo`40000000000`00003oooooo`000009o`0000;ooooo0_l00003oooo
o`Go00001_ooool2o`0000Kooooo0ol00006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`;o00001oooool2o`0000Oooooo0_l00006oooo
o`03o`000?oooooo000000Kooooo0ol00006ooooo`?o00001OoooolIo`000003ooooool0003o0000
00So00001Oooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo00?o0000oooo
ool000001_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001_ooool4o`0000?ooooo0ol00002oooo
o`Wo00000_ooool10000000000<00000ooooooooool01_l00002ooooo`03o`000?oooooooooo00;o
oooo1?l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool2o`0000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Kooooo00Co0000ooooool0003o00000oooool00ol0
003oooooooooo`03ooooo`Ko000000?oooooo`000?l000000ol00002ooooo`Wo000000?oooooo`00
0?l000001Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool2
o`0000Oooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`;o00001oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo1?l00004ooooo`03o`000?oooooooooo00Ko00000_ooool10000000000<00000oooo
ooooool04?l00005ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02oooo
o`;o00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ool000001_ooool2o`0000Oooooo0_l00007ooooo`;o00001oooool2o`0000Kooooo1?l00004oooo
o`;o000000?oooooo`000?l000000oooool2o`0000Cooooo0ol00005ooooo`04o`000?oooooooooo
ooooo`;o000000?oooooo`000?l000001?l00002ooooo`Ko000000?oooooo`000?l000000_ooool2
o`0000Cooooo1?l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l00004
ooooo`Co00001_ooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo000000Kooooo00?o0000
ooooool000001_ooool2o`0000Oooooo0ol00005ooooo`03o`000?oooooooooo00;o00000oooool2
o`0000;ooooo0ol000000ooooooo0000o`000005ooooo`oo00000oooool10000000000@00000oooo
oooooooooooo2?l00002ooooo`;o00000oooool2o`0000Cooooo0_l00006ooooo`;o000000?ooooo
o`000?ooool00oooool2o`0000?ooooo00?o0000ooooooooool00_l00004ooooo`;o000000?ooooo
o`000?ooool01?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool2o`0000;ooooo00?o0000ooooooooool00oooool4o`0000Gooooo0_l000000ooo
oooo0000o`00000?o`0000Cooooo4Ol000000ooooooo0000ooooo`05ooooo`Co00001?ooool01Ol0
003ooooooooooooooooo000000Cooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000006ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool00_l00004ooooo`05o`000?ooooooooooooooool0
00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000005ooooo`?o00001?ooool2o`0000?o
oooo0_l00002ooooo`03o`000?oooooo000000Go00000oooool10000000000<00000ooooooooool0
0_ooool8o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool00ol0003o
ooooooooo`04ooooo`;o00002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooo`000006ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool2o`000004ooooool0003o0000o`0000Gooooo1Ol000001Ooooooo
0000oooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`;o00001_ooool00ol0003oooooo`000005ooooo`05o`000?ooooooooooooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooooooo0ol000001Ooooooo0000o`000?oooooo000000Cooooo0@00
0000000300000?oooooooooo00;ooooo4ol00004ooooo`03o`000?oooooooooo00?ooooo0_l00007
ooooo`?o00001Oooool01?l0003oooooo`000?l00005ooooo`04o`000?ooooooooooo`0000Gooooo
00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooo000000Kooooo0_l00006ooooo`03o`000?oooooo
oooo00;o00000_ooool2o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000001_l00006
ooooo`Oo00000_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00000
0ooooooo0000ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool00005ooooo`04o`000?oooooo0000o`0000Gooooo0ol00007
ooooo`;o00001?ooool2o`0000Cooooo4ol00004ooooo`40000000000`00003oooooooooo`03oooo
o`Ko00000_ooool2o`0000;ooooo0_l00002ooooo`;o00001Oooool00ol0003oooooo`000002o`00
00;ooooo0_l00004ooooo`?o00001oooool2o`0000Kooooo0ol00006ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool3o`0000Kooooo0_l00007ooooo`04o`000?oooooo0000
o`0000?ooooo0_l00004ooooo`Co00000_ooool2o`0000?ooooo00?o0000ooooool000002?l00008
ooooo`_o00000oooool2o`0000;ooooo1?l00004ooooo`;o00000oooool2o`000003ooooool0003o
oooo00Gooooo0_l00007ooooo`?o00001_ooool00ol0003oooooo`000006ooooo`;o00001_ooool3
o`0000Oooooo0_l00007ooooo`;o00001Oooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o000000?oooooo`000?l000001Ol0
0005ooooo`40000000000`00003oooooooooo`04ooooo`Co000000?oooooo`000?ooool02_ooool0
0ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Kooooo0_l0000@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?l00002ooooo`Go0000
0_ooool5o`0000Wooooo1_l00002ooooo`Go000000?oooooo`000?l000000_l00003ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`0000Oooooo0_l0000@ooooo`;o
00001_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo0_l00005oooo
o`03o`000?oooooooooo00Sooooo0ol000001?oooooo0000o`000?l00006ooooo`40000000000`00
003oooooooooo`04ooooo`Go000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool00ol0
003oooooooooo`04o`0000Kooooo00Co0000ooooool0003o00000oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Gooooo0ol00007ooooo`;o00001oooool2o`0000Kooooo00?o
0000ooooool000001Oooool2o`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;o00000_ooool00ol0003ooooo
ooooo`06o`0000[ooooo1_l000000ooooooo0000ooooo`02ooooo`?o000000?oooooo`000?ooool0
0oooool2o`0000Gooooo0ol00005ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Go
oooo0ol00006ooooo`;o00001oooool2o`0000Oooooo0ol00005ooooo`04o`000?oooooo0000o`00
00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`Go000000?ooooo
o`000?l000001?ooool01?l0003oooooooooooooool4o`000003ooooool0003o000000?o00001_oo
ool10000000000<00000ooooooooool01Oooool5o`000003ooooool0003ooooo00co00001?ooool0
0ol0003oooooooooo`04ooooo`;o00001Oooool2o`0000;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;o00001Oooool00ol0003oooooo`000005ooooo`;o000000?o
ooooo`000?l000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool2o`000003ooooool0003ooooo00Gooooo1Ol00002ooooo`03o`000?oooooooooo00;ooooo
0_l00003ooooo`03o`000?oooooooooo00Wo00002oooool:o`000003ooooool0003o000000?ooooo
0_l00004ooooo`03o`000?oooooooooo00Go00001Oooool2o`000003ooooool0003ooooo00?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00_l00004ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001Oooool2o`0000Kooooo00?o0000
ooooooooool00_ooool=o`0000;ooooo1Ol00007ooooo`40000000000`00003oooooooooo`05oooo
o`;o000000Koooooo`000?oooooo0000ooooool00006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ol0000<oooo
o`Co00000_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`;o00001?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooo`000?ooool3o`0000Sooooo0@000000000300000?oooooooooo00Kooooo2?l000000ooooooo
0000o`000003ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`000003ooooool0003o0000
00;ooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool2o`00
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04o`000?oooooo
ooooo`0000Gooooo0ol00006ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`Co00000_oo
ool01_l0003ooooooooooooooooo0000ooooo`_o00003_ooool<o`0000Cooooo00?o0000oooooooo
ool01?l00005ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`;o00001_ooool01?l0003o
ooooo`000?l00004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
o`0000Gooooo00?o0000ooooool000001_ooool2o`0000Kooooo0_l000001_oooooo0000o`000?l0
003oooooo`0000Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`000005
ooooool0003o0000o`000?ooool01?l00008ooooo`40000000000`00003oooooooooo`06ooooo`Wo
00000_ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_ooool2o`0000Ko
oooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`05ooooo`;o00001oooool3o`00
00Gooooo1?l00006ooooo`;o00001oooool2o`0000Kooooo00?o0000ooooooooool00_l00002oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Wo000000Goooooo`000?oooooo0000ooooo`05
o`0000oooooo1ol00002ooooo`[o00000oooool2o`0000Gooooo00?o0000ooooool000000_l00002
ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00001_ooool3o`0000Kooooo0_l00007
ooooo`;o00001oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo0ol00004
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`So00002Ooo
ool10000000000<00000ooooooooool01oooool3o`000004ooooool0003oooooooooo`;o000000?o
ooooo`000?ooool02?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo01kooooo0_l00006ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`02o`000005ooooool0003o0000ooooool000004?ooool4o`00
0003ooooool0003o000000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007oooo
o`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooo000000;o00000_ooool00ol0003oooooo`000002o`0000Wooooo0@000000000300000?oooooo
oooo00Oooooo1ol000000ooooooo0000o`000004o`000004ooooool0003o0000ooooo`Go00000ooo
ool00ol0003oooooooooo`04ooooo`?o00001?ooool00ol0003oooooooooo`02ooooo`;o000000?o
ooooo`000?ooool01Oooool3o`0000Kooooo0ol00006ooooo`;o00001_ooool00ol0003ooooooooo
o`02o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000
1Ol0000@ooooo`Go000000Goooooo`000?l0003oooooo`000002ooooo`;o00000oooool2o`0000Co
oooo00?o0000ooooooooool00_ooool2o`0000Oooooo00?o0000ooooooooool00_l00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000001_ooool3o`0000Kooooo0ol00006ooooo`04
o`000?oooooo0000o`0000?ooooo00?o0000ooooooooool00oooool3o`0000Gooooo00?o0000oooo
ooooool00_ooool4o`0000;ooooo0_l000000ooooooo0000o`000004o`000003ooooool0003o0000
00Co00002_ooool10000000000<00000ooooooooool02?ooool7o`000004ooooool0003ooooooooo
o`Oo00000_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooooooool0
0_ooool3o`0000Kooooo0_l000001_oooooo0000o`000?l0003oooooo`0000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04o`000003ooooool0003o000000Co00004_ooool6o`00
0003ooooool0003o000000;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo1Ol000000ooooooo0000o`000005ooooo`03o`000?oooooo000000Gooooo00Co0000oooo
oooooooooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo0_l00002ooooo`03o`00
0?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`Oo0000
00Coooooo`000?l0003ooooo1ol0000:ooooo`40000000000`00003oooooooooo`09ooooo`Co0000
00?oooooo`000?ooool02?ooool00ol0003oooooooooo`08ooooo`07o`000?ooooooooooooooool0
003oooooo`000007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooooooool02_ooool2o`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooooooool3o`0000;ooooo00?o0000ooooooooool00_l0000Dooooo`;o0000
0_ooool01Ol0003oooooo`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`;o00003?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?l0000;ooooo`40
000000000`00003oooooooooo`09ooooo`[o000000?oooooo`000?l000000oooool01?l0003ooooo
ooooooooool2o`0000Cooooo00Co0000ooooool0003o00000oooool00ol0003oooooooooo`04oooo
o`;o00001_ooool2o`000003ooooool0003ooooo00Cooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooo`000006ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000go000000?oooooo`000?l000001Ol0000E
ooooo`Ko000000?oooooo`000?ooool03Ol000000ooooooo0000ooooo`04ooooo`;o00000oooool2
o`000003ooooool0003ooooo00Gooooo0_l00006ooooo`04o`000?ooooooooooo`0000Gooooo00Co
0000oooooooooooo00001Oooool01?l0003oooooo`000?l00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?l00005ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000?o00002oooool10000
000000<00000ooooooooool02_ooool5o`000004ooooool0003o0000o`0000?ooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooooooool3o`0000Gooooo00?o0000ooooooooool00_oo
ool3o`0000Oooooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000007ooooo`;o00001Ooo
ool01?l0003oooooooooooooool2o`000003ooooool0003ooooo00Cooooo0_l00004ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`08o`0001Kooooo2?l00002ooooo`03
o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`02ooooo`;o00001Oooool01?l0003o
ooooo`000?l00002ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`;o00001oooool2o`00
00Oooooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooo
oooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`Co000000?oooooo`000?l000000ol0000<ooooo`40000000000`00003oooooooooo`0;
ooooo`?o000000?oooooo`000?ooool00_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooo`000?l00009ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;ooooo
0_l0000;ooooo`03o`000?oooooooooo00Sooooo0_l00003ooooo`?o00006?ooool3o`0000;ooooo
0_l0000:ooooo`03o`000?oooooooooo00Wooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`;o00002?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool00ol0
003oooooo`000005ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`03o`000?oooooo
000000;o00003Oooool10000000000<00000ooooooooool02oooool7o`000003ooooool0003o0000
00go00001?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo000000Kooooo00Co
0000ooooool0003o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool01?ooool3o`0000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo0_l000000ooooooo0000o`000007o`0001Sooooo2Ol000001Ooooooo0000oooooooooooo
000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`?o00001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool3o`0000Oooooo0_l0
0006ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`02ooooo`?o00001Ooo
ool2o`0000Cooooo3ol000000ooooooo0000o`000005o`0000gooooo0@000000000300000?oooooo
oooo00cooooo1ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo00;o00001?ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`?o00001_ooool00ol0003o
ooooooooo`05o`0000?ooooo0_l00003ooooo`;o00000_ooool4o`000003ooooool0003o000000Co
00006_ooool5o`0000;ooooo1?l00002ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`Co
00000oooool00ol0003oooooooooo`04ooooo`?o00001?ooool2o`0000;ooooo00Co0000oooooooo
oooooooo0_l00004ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Kooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01ol0
000>ooooo`40000000000`00003oooooooooo`0<ooooo`;o000000Goooooo`000?l0003oooooo`00
0005ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`06ooooo`;o0000
2?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool2o`0000cooooo00?o0000ooooool000000_ooool5o`0001_ooooo1_l00002ooooo`?o0000
3?ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo000000Sooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`;o000000Coooooo`000?oooooo00003oooool10000000000<00000oooooooo
ool03Oooool5o`000003ooooool0003o000000;o00000_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`Co00001_ooool2o`00
00Oooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`co00000_ooool00ol0
003oooooo`000005o`0001cooooo1_l000001?oooooo0000ooooooooool<o`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol0003oooooo`000006
ooooo`04o`000?oooooo0000o`0000Cooooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`Co000000?oooooo`000?l000000ol0000?ooooo`40
000000000`00003oooooooooo`0>ooooo`Ko000000Coooooo`000?l0003o00000_ooool01Ol0003o
oooooooooooooooo000000Cooooo00Co0000oooooooooooooooo0ol00005ooooo`;o00001?ooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool2
o`0000Kooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooo000000Go00007_ooool6o`000005ooooool0003oooooooooool000000_ooool2o`0000?ooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo0ol00004ooooo`;o00001Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo1?l000000ooooooo0000o`000003o`00013ooooo0@0000000003
00000?oooooooooo00oooooo1?l000001?oooooo0000ooooooooool2o`0000;ooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooo`000?l0000<ooooo`04o`000?ooooooooooo`0000Kooooo
0_l00007ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
0_l0000Fooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool08?ooool01?l0003ooooo
o`000?ooool2o`000003ooooool0003ooooo01Gooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Go
oooo00Go0000ooooooooooooooooo`00000<ooooo`;o000000?oooooo`000?ooool00oooool01Ol0
003ooooooooooooooooo000000;ooooo0_l00002ooooo`03o`000?oooooo000000?o00004Oooool1
0000000000<00000ooooooooool03oooool5o`000005ooooool0003oooooo`000?ooool01Ol00000
0ooooooo0000ooooo`05o`0000Cooooo00?o0000ooooooooool01?ooool3o`0000Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo
0_l00003ooooo`05o`000?ooooooooooooooool000001Oooool3o`0000?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool4o`000003ooooool0003o
000000;o00008?ooool4o`000004ooooool0003o0000o`0000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00001Oooool2o`0000?ooooo1_l000000ooooooo0000ooooo`06o`0000;ooooo00?o0000ooooool0
00001?l0000Aooooo`40000000000`00003oooooooooo`0@ooooo`?o000000Goooooo`000?l0003o
0000ooooo`02o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool2o`0000Kooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo0_l000000ooo
oooo0000ooooo`05ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool00oooool2o`00
00?ooooo00?o0000ooooooooool00_l000001?oooooo0000o`000?ooool3o`000003ooooool0003o
0000027ooooo0ol000000ooooooo0000ooooo`04o`000004ooooool0003oooooooooo`;o00000ooo
ool2o`0000Cooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo000000Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo0_l00005oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1?l000001?oooooo0000oooooooo
ool2o`000005ooooool0003o0000o`000?ooool00ol0000Booooo`40000000000`00003ooooooooo
o`0@ooooo`;o00000oooool2o`0000Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000006ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo0_l0000=ooooo`;o00001_ooool3o`0002;ooooo0ol00006ooooo`03
o`000?oooooooooo00cooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`;o00001?ooool00ol0003oooooooooo`0Aooooo`40000000000`00
003oooooooooo`0Aooooo`Oo000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00?o0000ooooooooool01?ooool2
o`0000Kooooo00?o0000ooooool000001_ooool3o`0000Kooooo0ol00004ooooo`03o`000?oooooo
oooo00?ooooo1ol00004ooooo`03o`000?oooooo000000?o000000?oooooo`000?ooool01_l0000T
ooooo`;o000000?oooooo`000?l000000_ooool00ol0003oooooo`000003o`000003ooooool0003o
oooo00;ooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`05ooooo`03o`000?oooooo
oooo00;ooooo0_l00007ooooo`?o00001_ooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooo
oooo00Go00001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooo`000007o`0001?ooooo0@000000000300000?oooooooooo01;ooooo1?l00002
ooooo`?o00000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_oo
ool2o`0000Gooooo0_l00004ooooo`04o`000?oooooo0000o`0000Kooooo0_l00007ooooo`;o0000
1_ooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00Gooooo00?o0000ooooooooool0
0_ooool8o`000005ooooool0003oooooooooool000000_ooool5o`0002Gooooo1_l000000ooooooo
0000ooooo`02ooooo`03o`000?oooooo000000Oo00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;o00000_ooool00ol0003oooooooooo`04ooooo`;o00001oooool2o`0000Ko
oooo0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`00
0?l000000ol0000Dooooo`40000000000`00003oooooooooo`0Cooooo`;o000000?oooooo`000?oo
ool00_ooool2o`0000Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000003oooool01Ol0003ooooooooooooooooo
000000?ooooo00Ko0000ooooool0003oooooo`000?ooool2o`0002Kooooo00So0000oooooooooooo
0000ooooool0003oooooo`0000;ooooo00Go0000ooooooooooooooooo`00000@ooooo`;o00001Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0:ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0000Eooooo`40
000000000`00003oooooooooo`0Booooo`Oo00000_ooool5o`0000?ooooo00?o0000ooooooooool0
0_ooool3o`0000?ooooo0_l00005ooooo`04o`000?oooooo0000o`0000?ooooo0_l00003ooooo`03
o`000?oooooooooo00;o00001?ooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000oooo
ooooool01?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool3o`000003ooooool0003o000000;o00009oooool9
o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool3o`0000Gooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`;o
000000?oooooo`000?ooool01?ooool2o`0000?ooooo0ol00003ooooo`03o`000?oooooooooo00;o
oooo1Ol000000ooooooo0000ooooo`05o`0001Gooooo0@000000000300000?oooooooooo01?ooooo
2?l000001?oooooo0000ooooooooool9o`000003ooooool0003ooooo00Cooooo00?o0000oooooooo
ool00oooool2o`0000Oooooo00Co0000ooooool0003o00001?ooool01?l0003oooooooooool00005
ooooo`04o`000?oooooo0000o`0000Gooooo00?o0000ooooooooool01Ol00004ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000?oooooo`000?l00000
1?l0000Xooooo`Co000000?oooooo`000?ooool00_l00002ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;o000000?oooooo`000?oo
ool01Oooool3o`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`;o000000?oooooo`00
0?ooool01Oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09o`00
0004ooooool0003oooooooooo`Oo00005_ooool10000000000<00000ooooooooool05?ooool01Ol0
003oooooo`000?oooooo000000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_l000001?oooooo0000ooooooooool3o`0002[ooooo
0_l00003ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`06o`000?ooooooooooooooool0003ooooo0_l000000ooooooo0000oooo
o`0Eooooo`40000000000`00003oooooooooo`0Eooooo`Oo00000_ooool01?l0003oooooooooool0
0004ooooo`04o`000?ooooooooooooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo
0_l00005ooooo`;o00001oooool2o`0000Kooooo1?l00004ooooo`03o`000?oooooooooo00Cooooo
0ol00002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo1?l000000ooooooo
0000ooooo`04o`0002cooooo1?l000000ooooooo0000ooooo`04o`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`000003
ooooool0003o000000Cooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool7o`0001Oooooo0@000000000300000?oooooooooo01Gooooo1Ol000001Ooooooo
0000o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000ooooo`05
ooooo`?o00001Oooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool00oooool2
o`0000?ooooo2ol00002ooooo`03o`000?oooooo000000Go0000;Oooool6o`0000;ooooo00?o0000
ooooool000002ol00003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00?ooooo0ol00006ooooo`04o`000?oooooo0000o`0000?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`;o000000?oooooo`000?l0
00000_l0000Hooooo`40000000000`00003oooooooooo`0Fooooo`;o000000Coooooo`000?oooooo
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0000[o
oooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?oo
ool5o`0002kooooo0ol000000ooooooo0000ooooo`05ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000Wooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000002oooool2o`0000Sooooo00Go0000oooo
ooooooooooooo`000004ooooo`?o000000Goooooo`000?l0003oooooo`00000Iooooo`4000000000
0`00003oooooooooo`0Gooooo`;o000000Coooooo`000?oooooooooo1?l00002ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooooooo1?l00002ooooo`;o00001Oooool2o`000003oooo
ool0003ooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;o
00001Oooool3o`0000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`000004ooooool0003o0000o`00033ooooo
0ol000001?oooooo0000ooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000ooooool0003o0000
1Oooool00ol0003oooooooooo`04o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04o`0000;ooooo1?l0000Iooooo`40000000000`00003oooooooooo`0Gooooo`Go000000Co
ooooo`000?oooooooooo1_l00002ooooo`Go000000?oooooo`000?ooool01?ooool00ol0003ooooo
ooooo`03ooooo`;o00001_ooool4o`0000Gooooo00?o0000ooooool000001_ooool01?l0003ooooo
o`000?l00002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000_ooool4o`000004ooooool0003o0000o`00037ooooo1?l000000ooooooo0000o`000002
o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`04o`000?ooooooooooo`0000Kooooo0ol00005ooooo`Co00001_ooool2o`0000Gooooo
00?o0000ooooooooool00oooool7o`000003ooooool0003o000000Go000000Koooooo`000?oooooo
ooooo`000?ooool2o`0001[ooooo0@000000000300000?oooooooooo01Wooooo0_l000000ooooooo
0000ooooo`06ooooo`04o`000?oooooo0000o`0001;ooooo0_l0000@ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool02_ooool01_l0
003oooooo`000?oooooo0000ooooo`;o0000<_ooool5o`000003ooooool0003ooooo00_ooooo00?o
0000ooooooooool01?ooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0>ooooo`;o00004Oooool4o`0000Sooooo00Co0000ooooool0003o00006oooool10000000000<0
0000ooooooooool06?ooool8o`000003ooooool0003ooooo00;ooooo00Co0000oooooooooooooooo
0_l00003ooooo`;o00001?ooool2o`000004ooooool0003o0000o`0000;ooooo00?o0000oooooooo
ool00oooool3o`0000Kooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`03oooo
o`?o00000oooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooool000000_l00000
0ooooooo0000o`000003o`0003Cooooo0ol000000ooooooo0000ooooo`03o`000003ooooool0003o
oooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000Kooooo00?o
0000ooooooooool00_ooool3o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00;o00000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`04o`000?oo
ooooooooo`0000;ooooo0ol000001?oooooo0000o`000?l0000Kooooo`40000000000`00003ooooo
ooooo`0Jooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o0000
1Oooool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000;o
oooo0_l00002ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000o`000003o`0000?o
oooo00?o0000ooooooooool01Ol00002ooooo`Go0000=_ooool3o`000005ooooool0003oooooo`00
0?ooool01?l00002ooooo`04o`000?ooooooooooooooo`Co00000_ooool2o`0000Gooooo00Co0000
oooooooooooo00000oooool2o`0000Cooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oo
oooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01_l0003ooooooooooooooooo0000ooooo`Oo00007?ooool10000000000<00000ooooooooool0
6oooool2o`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08oooo
o`;o00002oooool00ol0003oooooooooo`06o`0000Cooooo00Oo0000ooooool0003oooooo`000?oo
oooo000003Oooooo0_l000001_oooooo0000ooooool0003oooooo`0000?ooooo1ol000000ooooooo
0000ooooo`0:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00007ooooo`;o00003Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooooooo0_l0000Mooooo`40000000000`00003oooooooooo`0Kooooo`Co000000?ooooo
o`000?l000000_l00003ooooo`04o`000?ooooooooooooooo`;o00001?ooool4o`0000;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooo`000005ooooo`Co00001_ooool2o`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooo`000005o`0003Sooooo1Ol00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool01?l0003oooooo`000?l00005ooooo`03o`000?oooooo0000
00Gooooo0_l00002ooooo`Co00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
ooooool0003o00000_ooool4o`0001gooooo0@000000000300000?oooooooooo01cooooo1?l00000
0ooooooo0000ooooo`04o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000000ol00005
ooooo`03o`000?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00Cooooo0_l00000
0ooooooo0000o`000002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003oooooo`000?l0003ooooo00?o0000>_ooool7o`0000?ooooo
00?o0000ooooooooool00_l00004ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
00?oooooo`000?l000001_ooool00ol0003oooooooooo`05ooooo`?o00001Oooool00ol0003ooooo
ooooo`03ooooo`Co000000?oooooo`000?ooool00oooool00ol0003oooooo`000003o`000003oooo
ool0003ooooo00Co00007_ooool10000000000<00000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[o00002_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01?ooool2o`0000[ooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo
00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo03Wooooo0_l00003ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooool000001_ooool00ol0003oooooo`000004ooooo`03
o`000?oooooooooo00Sooooo2?l000001Ooooooo0000oooooooooooo000000Cooooo00?o0000oooo
ooooool07Oooool10000000000<00000ooooooooool07Oooool2o`000004ooooool0003o0000o`00
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_l00003ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`Co000000Coooooo`000?l0003o0000
??ooool3o`000003ooooool0003o000000;o00000_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_ooool2o`0000Gooooo0_l00003ooooo`;o000000?oooooo`000?l0
00001?ooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo00Cooooo0_l00004oooo
o`04o`000?ooooooooooooooo`;o00000_ooool01Ol0003oooooooooool0003ooooo00;o000000?o
ooooo`000?l000007oooool10000000000<00000ooooooooool07_ooool6o`0000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00001_oo
ool01?l0003oooooooooool00004ooooo`;o000000?oooooo`000?ooool01Oooool00ol0003ooooo
ooooo`04o`0000?ooooo0_l00003ooooo`Co00000_ooool5o`0003kooooo0ol000000ooooooo0000
ooooo`03o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool4o`0000;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`000005ooooo`04o`000?oooooo0000o`0000Go
oooo0ol00005ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`04o`000?ooooooooooo`00
00?ooooo1_l0000Pooooo`40000000000`00003oooooooooo`0Oooooo`?o000000?oooooo`000?l0
00000_ooool00ol0003oooooooooo`0;ooooo`07o`000?ooooooooooooooool0003oooooo`000008
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`Co00001?ooool4o`0000Gooooo0ol00010ooooo`?o00001Oooool3o`0000Gooooo1?l00005
ooooo`03o`000?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooool000000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o000000?ooooo
o`000?l000008Oooool10000000000<00000ooooooooool07oooool4o`000003ooooool0003o0000
00;ooooo00?o0000ooooooooool00_l00002ooooo`;o00001Oooool3o`0000?ooooo00?o0000oooo
ooooool01?ooool2o`0000Kooooo0ol00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool6o`0000;ooooo00?o0000ooooooooool01?l00012ooooo`Co000000?oooooo`00
0?l000000_ooool6o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`Co00001_ooool2o`0000Gooooo0_l00002ooooo`Co00001Oooool01?l0003oooooooooooooool2
o`0000;ooooo00?o0000ooooool000000_l000000ooooooo0000o`000002o`00027ooooo0@000000
000300000?oooooooooo023ooooo1?l000000ooooooo0000o`000002o`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000003o`0000Kooooo00Co0000oooooooooooooooo0_l00000
0ooooooo0000o`000004ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00000oooool01?l0003oooooooooool00002ooooo`Co
0000@oooool5o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_l00003ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`Co00000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo1Ol000001?oooooo0000o`000?l0000Sooooo`400000
00000`00003oooooooooo`0Qooooo`?o00000_ooool00ol0003oooooooooo`03o`0000Gooooo0ol0
0003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool01?l0003ooooo
ooooool00006ooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo0_l000001?oooooo0000o`000?l00014ooooo`;o00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool2o`0000Gooooo00Go0000oooo
ooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooooooo
0_l00006ooooo`?o00000_ooool00ol0003oooooo`000002o`0002Cooooo0@000000000300000?oo
oooooooo02;ooooo1?l000000ooooooo0000ooooo`02o`000003ooooool0003o000000Go00001Ooo
ool00ol0003oooooooooo`03ooooo`?o00001_ooool3o`0000Gooooo1?l00003ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000oooool4o`000003ooooool0003o000004Kooooo
0_l000000ooooooo0000o`000002o`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooooooo`Co00001_ooool3o`0000Kooooo0_l00006ooooo`03o`000?oooooooooo
00;ooooo2?l000001_oooooo0000o`000?oooooo0000ooooo`Co00009?ooool10000000000<00000
ooooooooool08oooool5o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`02ooooo`;o00000oooool4o`0000Kooooo0_l00006ooooo`04o`000?ooooooooooooooo`Co0000
0oooool2o`0000?ooooo2_l00017ooooo`?o000000?oooooo`000?ooool00ol000000ooooooo0000
ooooo`02ooooo`;o00000oooool4o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`Co00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`06o`0002Gooooo0@000000000300000?oooooooooo02?ooooo
00?o0000ooooool000000ol00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`05ooooo`?o00001Oooool3o`0000Gooooo0_l0001:ooooo`;o0000
1Oooool3o`0000Gooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
1Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooooooool5o`0002Kooooo0@000000000300000?oooooooooo02Cooooo0ol000001_oooooo
0000o`000?l0003oooooo`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo0ol00004
ooooo`04o`000?ooooooooooooooo`;o00000_ooool3o`000003ooooool0003ooooo00Cooooo0_l0
0004ooooo`Go00000_ooool2o`000003ooooool0003o000000;o0000Boooool5o`000004ooooool0
003oooooooooo`Ko00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o0000
0oooool2o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo00?o0000ooooool000001_l0000Vooooo`40000000000`00003ooooooooo
o`0Vooooo`Co000000Coooooo`000?l0003o00000oooool01_l0003ooooooooooooooooo0000oooo
o`?o000000?oooooo`000?ooool01Oooool3o`0000Kooooo0ol00005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003ooooo00Co0000COooool4
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo0_l00006ooooo`Co00001_ooool5o`000003ooooool0003ooooo00;ooooo00Co
0000oooooooooooooooo1?l000001?oooooo0000o`000?l0000Xooooo`40000000000`00003ooooo
ooooo`0Vooooo`;o00000_ooool00ol0003oooooooooo`0:o`0000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ool00000Coooool2o`000005ooooool0003oooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00Co0000oooooooooooooooo0ol00007ooooo`;o00001_ooool00ol0003ooooo
ooooo`03ooooo`Wo00000oooool01?l0003oooooo`000?l0000Yooooo`40000000000`00003ooooo
ooooo`0Wooooo`Go00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooooooool2o`000003ooooool0003o000000Cooooo0_l00002oooo
o`Co00001Oooool01Ol0003ooooooooooooooooo000000;ooooo1ol0001@ooooo`Ko00000oooool0
1Ol0003ooooooooooooooooo000000Cooooo00Co0000ooooool0003o00000oooool2o`0000Cooooo
1Ol00002ooooo`;o00001?ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`Go
0000:Oooool10000000000<00000ooooooooool0:?ooool5o`0000;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001?ooool2o`0000;o
oooo00?o0000ooooooooool01?ooool7o`0000?ooooo1Ol000000ooooooo0000o`000002o`0005;o
oooo1?l000000ooooooo0000o`000003o`0000?ooooo1ol00006ooooo`04o`000?ooooooooooo`00
00Cooooo0_l000000ooooooo0000ooooo`04ooooo`04o`000?ooooooooooooooo`;o00000oooool0
0ol0003oooooo`000005o`0002[ooooo0@000000000300000?oooooooooo02Wooooo1?l00002oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2o`0000Oooooo0_l00006oooo
o`03o`000?oooooooooo00?ooooo1_l00002ooooo`03o`000?oooooo000000?o0000E?ooool3o`00
00;ooooo00?o0000ooooool000001_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000001oooool2o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04o`00
02cooooo0@000000000300000?oooooooooo02[ooooo0_l000000ooooooo0000o`000003o`0000;o
oooo0_l00003ooooo`Go000000?oooooo`000?l000001Oooool4o`0000Cooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000ol0001Foooo
o`?o000000?oooooo`000?l000000_ooool01?l0003oooooooooooooool2o`0000Cooooo0_l00004
ooooo`?o00001_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00?ooooo0_l00002
ooooo`So0000;?ooool10000000000<00000ooooooooool0:oooool4o`000003ooooool0003o0000
00[o00001Oooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?ooool00oooool2o`00
00?ooooo0_l00002ooooo`Go0000FOooool6o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo
00?ooooo00Co0000ooooool0003o00000oooool2o`0000;ooooo0_l00005ooooo`go000000Cooooo
o`000?l0003o0000;Oooool10000000000<00000ooooooooool0;?ooool2o`000005ooooool0003o
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000001oooool2o`0000cooooo0_l000000ooooooo0000o`00001Kooooo`Co000000?o
ooooo`000?ooool02oooool2o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`?o0000;oooool10000000000<00000ooooooooool0;Ooo
ool5o`000003ooooool0003ooooo00;ooooo0_l00003ooooo`;o00001?ooool3o`0000Kooooo2?l0
0002ooooo`[o0000G?ooool7o`000003ooooool0003ooooo00;ooooo1Ol000000ooooooo0000o`00
0005ooooo`Co00001?ooool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003oooooo`00
0004o`0002oooooo0@000000000300000?oooooooooo02kooooo1Ol000000ooooooo0000ooooo`02
ooooo`;o00001?ooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`000003ooooool0003o
000000Wo0000H?ooool2o`000003ooooool0003o000000Ko000000?oooooo`000?ooool01?ooool2
o`0000;ooooo0_l00002ooooo`Go00001?ooool01?l0003oooooooooooooool7o`00037ooooo0@00
0000000300000?oooooooooo033ooooo00?o0000ooooool000000ol00004ooooo`03o`000?oooooo
oooo00?o00001oooool2o`0000Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;o0000H_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`;o00001oooool3o`0000;ooooo00?o0000ooooooooool00_oo
ool6o`0003;ooooo0@000000000300000?oooooooooo037ooooo3?l00003ooooo`;o00001?ooool4
o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo00Go0000I?ooool5o`0000;ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooooooool5o`0000Cooooo0_l00002ooooo`go0000<ooo
ool10000000000<00000ooooooooool0<_ooool4o`000003ooooool0003o000000?ooooo0_l00003
ooooo`Go00001?ooool@o`0006Kooooo4?l00004ooooo`Co00001?ooool2o`0000?ooooo00?o0000
ooooooooool00ol0000eooooo`40000000000`00003oooooooooo`0dooooo`?o00000_ooool01Ol0
003ooooooooooooooooo000000Cooooo0ol00005ooooo`;o00001?ooool01_l0003ooooooooooooo
oooo0000ooooo`;o0000J_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000000;o0000=oooool10000000000<00000ooooooooool0=Oooool>o`0000;ooooo0_l0
00001?oooooo0000o`000?l00003ooooo`;o00000_ooool5o`0006cooooo1?l00003ooooo`03o`00
0?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool>o`0003Oooooo0@000000000300000?oo
oooooooo03Oooooo1_l00002ooooo`Co00000oooool>o`00077ooooo3ol00003ooooo`?o00000_oo
ool6o`0003[ooooo0@000000000300000?oooooooooo03[ooooo0_l000000ooooooo0000o`000003
ooooo`Co00001Oooool2o`0000;ooooo00?o0000ooooool00000M_ooool3o`0000;ooooo0_l00005
ooooo`?o00001?ooool2o`000003ooooool0003o000003cooooo0@000000000300000?oooooooooo
03_ooooo4?l000000ooooooo0000o`000003o`0007Sooooo1Ol000000ooooooo0000o`00000=o`00
03kooooo0@000000000300000?oooooooooo03oooooo3_l00020ooooo`ko0000@Oooool100000000
00<00000ooooooooool0oooooolMooooo`400000003o0000024000000000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000l0020P820
P820P820P7moOgmoOgmoP820PH61PH61P820OgmnOWinOWmoP821PH:2PX:1PH1o
OWimOGemOWioP862Ph>3Ph:1P7mnOGelO7amOWn0PH:3Q8B4Ph:1P7mmO7]kNgal
OWn1PX>4QHF5Q8:1OgelNgYjNW]lOX22PhF6QXJ5Q8:0OWakNGUiNW]mOh63QHJ7
QhJ5Ph5oOG]iN7QhNW]nP8>5QhR8R8N5Ph1mNgUhMgMhNWaoPXB6R8V9R8J4PGil
NGMfMWMhNgf0PhJ8RXZ:R8J3P7ejMgIeMGMiO7n2QHR:Rh^:R8F2OW]hMGAdMGMj
OH64QhZ<S8^:QhB0O7QfM7=cMGQkOh>7RXb=SHb9QX9nNWIdLW9cMGUmPHF9S8j>
SH^8Q81kMgAbLG5cMWYoPhR;SXn?SHZ6PWeiMG9`L75dN7b1QXZ>T92?SHV4OgYf
LW1_L79eNWn4RHf@TI6?RhN2OGMcL6i^L7=gO8:7S8nBTY6>RXEoNGA`KVe^L7Ai
OhF:Si:CTi2=R89lMW5^K6a^LGIlPXR=TIBDThn;QGmiLfm/Jfa_LgUoQXb@U9FD
TXj8PW]eL6aZJVa`MWb3RHnCUYJDTHb5OWQbKFYYJVebNGn6SI:FUiJDShV2NgA^
JVQXJfmeO8>:T9FHV9JBS8EnMg1[J6MXK75hP8N>U9RIV9F@RH9jLfeXIVIYKWAl
Q8^BUiZJV9>=QWefKfUVIFM[LGR0R92FVI^JUY6:PGUaJfITIFQ]M7b5SIBIW9bI
UHj6OGA]IfASIFU`N829TINKWIbHTXZ1N71YI69SIVacO8F>UI^NWY^FSXIlLf]U
HV5SJ6mhPHZCVIfOWYVCRX5gKfMRH65TJg=lQXnGWJ2PWIN?QWabJVAPGf9WKWN1
RiBKWj6OViB;PGI]IV1NGf=ZLWb7T9VOXZ6NV926Ng5XHUiMH6E^Mh:<UYfQXj6L
U8^0MFaTGUaMHVUbOHRBVZ2TXj2IT8IjL6MPG5]NI6egPXfGWj>UXifERh1dJV9L
FUaPJ79mR9>LXZFUXIZ@QGY_IEiJFUeSK7N3SiVQYJNTWiJ;Og=YH5]HFUmWLGf9
UIjTYjNSVi65NFeSG5QHFf9/MhB@VZ:WZJJPUh]oLVMNFEIHGVIaOXZFX:JYZJBL
THEhK69JEUIJHF]gQ96LY:VZZ:6GRgiaIUaGE5ILIG5nRiRQZ:^ZYIfBQGM[H5QD
E5QPJgR5TYjVZjbYXYR;OW1TFeECEE]ULGn<VJ>Z[JbWWY:4MVUNEU9BEemZN8JD
WjR][Z^SV8]mKf9IDe5CFVAaOhfKYJb_[ZRNTXAeJ5aDD55EGVYhQiFQZZn`[:BI
Rga^HEMACe9II760SibW[[6_ZInBPgAVFU9>CeAMJWR8UZ>//K:^YIV;NfaOEDm=
D5QSLH2@WZV`/k6ZX9:3LfEID4a=DeaZNHVHYJjc/jnVVX]kJeeCCD]?Ef9aPI6O
Zk:e/jbPTX9bHeM>BT]AG6UiRYVV/;Fe/:NJRWYZG55;BDeFHW62TZ6]];Nd[J6B
PW5REDa9BU1KJGZ;VjRb]kNbZ9Z:NFQJCdU8C5ERLH>CXjjf^;J^XY:1L61CBTM8
CeYYNXbLZ[Bi^K>YVXYhIeQ=AdI:E65bPiFT/;Rj]jnRTX1_GU59ADM>FVUkSIj/
][^j]:VKRGMVEd]5A4UCHG:4UZJb^[bi/:>BP6eMCdM3ADeIJG^>Wjjh_KbeZY^9
MVAEBD=3B59QLXFGZ;Bl_[ZaXi9oK5]>AD54C5UYO8nQ[kZn_KN[VhQeHe=8@D56
DF1cQYVY][jo^k:STWi[FTa3?d9;F6UmT::a^l2o^:^KR7AQDDHo?dE@H7>7VZ^h
`<6m/jBAOFYHBT4n@DYHJGfAY;>m`/2i[9^7Lf1?A3hnA51PLhRL[K[1`kjcY95l
J5I8?c`oBEMZOY>V]Ko4`[Z/VhIbGTi2?3a3Cf1dRIf__<?4_kBTTGaWE4Hm>Si8
EfYoU:Ng`LK3^jfKQW1LC40j>d9?H7F:Wk2naLK0]JB@NfECA3/i?DMGJX2EZKW3
alFl[IZ5Ke]:?SPi@DiPMH^P//37b<:eY91jI552>CLkAUI[PIN[^/G9a[f^VXA^
FDPl=SQ0CV1fS::d`LW9`kJTSgQRCd0h=CY6EV^2V:blal_7_ZjJPfeHASXe=Sm=
H7N>XkK3b/_4]jB?Mf5=?cHd>DEFJh>I[[k9c<Vn[YZ3JeI4>3<e?TeQMhnU^<G<
c<FgY8ifGd`m=38hA5I/Q9^``<[>b[n^VH9ZE4<g<C@mC65hT:Nialk>a[RTSGEN
BS/b<CM4EVb5W;72c<o;`:jIPFUC@CD`<Sa<HGVAZ;_9d<o7^:B=M5a8>C0_=T=F
KHJN/lC>dLc0[iR0Ie4o<bha>daQNY>Z_L_Ad<RhY8acFdHg;bhe@eI^Qinea]3B
cL6_V7mVCcda;C0kC69kU:bocM?BbKVTRg5IA3D];CA2EVj8XKO7d]C>`ZnGOVA=
>bl[;cY<HWbE[L7>eM?9^J>:L5Q3<b/[<d9FKhVR^LWCeM32[iMmHd`i;RX^>D]S
OIN_`m3Fe<ZiXhU_ET4b:RXb@EM`RZBjbmGGd<>_UW]QBSL/:2`iBf=nV;74d]SE
bkVSR6eD?c0X:C51Eg6<Y[c=emSA`jjENV18=RXW:cQ;I7nJ//KDfMK;^J:7K5<m
;RLW<45GLHfW_/oHfM;3[YEiGTHd:2DZ>4aTP9^db=GKelbjXXI[DC//9BH`@EQb
SZW0dM[KdlB^U7QMAC8W92TgC6F1WKK:emcIcKZQQFU?>R/S9Bm1F7>@Zl;BfmcD
a:jCMe]3<2DR:CM<IX:N^<cIg][=^J24J4dh:B8T;T1IM96/`mCMgMG4[I9eFD4^
924X=TaVPj2icM[Of/jiX8=VC3HW8B<^@5UeTZk5e]oNeLB]TGAH?bdR82LfC6N4
XK_?g>3Kc[VOPVE:=2DO8Re0FWJD/<OHh=oFa:f@LeHm:b0O9SI=J8JS_M7Nh]c>
^Ij1HdPb91hQ;D5JMiFabMWQhMO5[8maE3`Y7ahU=TeYQjBodmoSgLniWX1RAc4R
720/@E]hUk?:fn?RelF/SW1C>RPM72DfCFZ8Y/3DhNCNckVMOf15;b4K7ba1FgZH
]LcMi>?HaJ^=KU4h9Q`K93E>JhZX`]KRiMo?^9amGd<]7aXN;45LNiZfc]kVi=S4
ZXa]CcHT6aXT=Di/RjW4f>CVglnhVgaM@B/M6Ad[@EelVkS@h>OTfLBZRfa>=B<I
6B<eCff<ZlKJiNOPckNJNe]0:Q`G7B]2GWfM^]7Qj>GIa:V:JT`c8APH8cI?KXj]
am_Wj>3?]iUiFShX6QHL:d9OOYjldn?Yi]W4Z8UYBS4O5QLR=U1_Sjk9gNSYhLnf
V7QH?2HI5A/[@V20X;gEi>_WfLBWR6M9<1hE5b8fDG2A/<_NjN[QckJGMeLj9APD
6b]3H86R_mKVk>SJ`jN6IDL^71@F8CIALI:bc>3[jn;?]IIeECTS5Q<J:d=QPZ?1
f>O]j=[3YXETAB`K4aDQ=U9bU;?>h^c/h/neUGAC=b8E4QX[A6:4YL;JjNkYf/:U
Q694:QTB524gDgBE]M3SkNgSckBDLU8e81@A6B]4HhFVa=_ZknWJ`ZB2HD8Y614D
8CMDMINgd^G^k^??/i=aD3@N4Q0I:dEUQjS6gN_`j][1Xh5O@2LF3a<Q=eEfV;SC
i_3^hljbTVm><QdA41T[AVJ8Z/OOkO7Zf/6RP5ho9QD>4R4hEWNJ^]GXlNoSc[:@
KTd`6a0?62]6IhZ[bN3^l^_J`:5nG3dT50dB8CQGNIble^Wbl>?>/Hm/BblJ3`hH
;4MXRjg;h^ocjm[0X7eJ>b8B3A4Q>EQjWKgHj_?`hlf`SV]9;AP>3AP/B6V=[lcS
l??[fKnONeTj8A4<4B4iFG^O_m[/m?7TcJn=JDP[5`d=62a9JXj`c^Gbm>cI_Yij
EcPO40/A8CYJOJ31fngelN?<[X]WARXF2``H;DY/T;;@i_?ek=VmW7UE=Qh?2Q0Q
>e]nX/;Mk_Kbhlb]RVI4:1@;31P]BffA]=7Wm?G/f;fKMe@e70h9424kG82Ta=k`
m_;Sbjb8I4<W4`X;62i<KY>ednWem^cH_9YfDS<K30T@8SaMPJG6h?7gln?:ZhMS
@BDB2@/H;Te`U;ODj_Kgk=RkVGA@<AX;210R?Ej3YlOQl_SchlZZQV4o91482QP_
CW6F^MK[moO/ekZGLTl`60X7428nH8BXbN?cnO?SbJR4GchR3`L:631?LYNjf>gh
mncG^IIaCBhG2@L@8cmQQZ[;i?Ciln;8Yh=N?24>1PXH<51dVKcIk_Whk=JhUFm<
;AH81Q0S@6:7[<cUmO[ch/NVPE`k7`d62APaDGFK_M[_nOS/eKNCKTX[50L642A1
HhV]c^Ofn_?QaZF0FcTN30D96C9BMibog?3jn>cE]Y9/B2XC1`D@949URZo?j?Ok
ln76Y7iI=ad;10TI<e=hW/7MlO_ijmBeT6]7:1861A0U@fJ</M7Yn?_chLFROELf
6`X42ATcEGZO`]obnoW[dk>?JDDW4@D542I4Ihfbd^[io??Pa:5kES@J2@<96SAF
Nj74h??lnN_B/XeWA2D@10D@9TEYSkCDk?[llmo3X7YD<aT80`TJ=EMmXlGQm?gi
j]:aS6I290l4114WAVZA]MG]n_gcgl:NN5<a5`L22A/fF7jTan?eoOWZdK2;I40S
3@<44BQ7K9:ge^kkoO?N`9efDC0F1P8973MJP:K8i?KnnNW@[hUS?b4<0P@A:DQ]
U;SHkocml]foVgE?;QD60PTL>5^1Yl[UmokijLn]Qf4m80`2118ZBVnE^]W`o?gb
g;jJLdh]50D12QdiG8>YbnKho_WXcZb6Gc`O2`444R];L9Nlfo7moO;L_IUbC2`C
104:7S]NQ:_=j?WonNS=ZhAN>Qh:0@@C;4abVKgLl_kmlM^lUg1;:Q840@XN?5n6
[<kYn_oiilbYPe`i70T111<]CW>J_mgco_gaf[ZFKdTY4@<12almHHR^cn[jooSV
bZR1FcPK200452i?MIc0g_CnoO3I^IA]B2P@0P4;83iRRJoAjo_on>G9YX1I=QX7
00DE;e1fWL7PmOoml=RhTf]69Pl20@/Q?fB;/M;/noohiLRUOUPe6@L01AD`DWRO
`n7eoog_ekJAJTDU3P813291IHbbdnglooOTaj=mES<H1P055S5CNJ34h_KooNkF
]HmX@b@=0@4=8d9WS[CEk_comn?6XW]E<QL500DG<UEkX/KSmoomk]FdSVM28``1
0@dT@fR?]MK_oOofh/BPNE<a5PD01QPcEWfSanCgooc]e;:<ID0R30413RE5JY6g
enomooKQ`imhDS0E10066CEGOZG8iOSoo>cB/H]T?b4;008?9TI[TkSHl?komN32
WGI@;Q@400LJ=UV0Yl[VnOokjm6_RF8n80X00PlWAffD^MWao_odgl2LMDl]4`@0
1a/gFX6XbnOioo_Zd:j8HC`O2P0242Q9KYJkfo;nooCN_iYcCB`B0`0873QLPjW<
j?[onn[?[8IO>ah900<A:TY`UkcLl_kolmfnVG9<:a8300TM>Uj4ZlgYn_ojjLf[
Q5hj7@T00a8[C7:I_]gcookbfkbGL4XZ4@<02AhkGhJ/cnWjooWXc:V3G3TL2003
4ba=LiZog_Coo_7J^iI_BBT@0P0:7ceQR:k@j__onNO;Z85K=a/800@D;DmeW<3O
m?omlMViU6e8:1020@/P?V:9[m7[noohiLVVP5Tf6PL01AD_D7JM`Moeoog`f;RB
JdHW3`81324oI8^ad^ckooOTb:EnF3DI1`055S1BN9o3h?Goo>oF]Y5ZABH?0P4=
8T5US;;Ck?_omn?6XgeF=1T700HG<E=jX<CQmOolk]FeSfQ49@h20PdT@VN>/mC]
nokfh/FRNeDc60L11aPcEG^RaN;fo__]e;>>Id<T3P833RE4JHneeNgko_GQa:1j
E38G1P476CAGOJ?6hoKnnncB/XaV@B<=0P<?9TEZTKKFk__nm=o2WWQB<AL60@PJ
=UQnY<OSm_kjj]6`RfA08Pd3110XAfbB]mO^nogcg/6MMU4`5PH22A`gFX2Vb>Cf
o_WYd:j9HclQ3@<44RU9KIBhf>oko?;M_i]eD2lF1P8:7CUKPJO9iOKmn>S>[HMQ
?R4=0`DC:TY_UKWHko_llM^mVW=>;QD60`/N>Uf3Z<[Um_ggilf[QV0m80`31Q@/
C72G^mW_no_`f[bHLTd]5@H331llGhBZbnKfo?KVbjZ4Gc`P30@75Be=LYRlf^ok
n^oI^YIaC2`D1`@=8CePQZ_<i_Klm^C:Z8=M>al<10PF;dmdVKgJl?[jk]NiUFm;
;1@71@hR?f:7[<gVm__ehlRVPE`j7P`521P`DGFK_]_`n_W/e[NCKTX[50L53bA0
HhV]c^Ofno?RajF0FcTN30D96C9BMibog?3jn>_D]Y9/BBXD1`H@9D9URZo?ioKj
l^35XgiI>1h<1PXJ<eAhWL3Ll?Wgj]>dT6]8:Q@81a8VA6N</<oWm_Wagl>ROEPg
7@`62a`eEGZO`Mg`nOKYdK:?JTLY4`P84bQ5J8fad>Sfn?3M`Z1kEcLM30L=7CMG
Nj32gO3hmNO@/HeXARPC20TD:DMZS[;Aj?Ghkmc0WWYF=Qd=20hN>5UmXL;Ml?Sd
i/j_S6M5:1<92QD[BF^@/m7XmOO^f[jMN5De70d83b0jFWjR`mk`mo?UcJf:IT@W
4`X;5be:KI6dd^Sdm^cI_I]gE3@L3@T@8C]LP:C4g^ofl^?;[8QT@bLD2P`H;Ta^
TkGBj?CejmNkVWIC=1`>2Q4S?Ej1YLGNkoGah/VZQf=29a@;3AX`CW2D]]?XloCZ
e[ZHM58c70h;4R@oGh>VaMo_mO3Pb:R5HT4V50/>6c5?LIFgdnSclnSD^9IcDC<L
3``D9T1QQ:O6gnkdk]o6YhAQ@BHD30lL<e5cU[SDj?;bim:fUG9@<Q`?3ADW@V:5
Z<OOk_?]gLBUPf109Q@=41heDWBH^=CXlO7VdKFCL4lb710>5bU4I8NYamo^l^cL
`jB1GclV5@hA7cIDMYVie>Oal>C?/i9_CS4L40lH:dEVR:[8gngaj][1XX1N?bHE
3a<Q>5IgV[[Dio3^hljaT6i=<A`A41T/AfN9ZlSOk?3Yf;nPOUdn9QH@52<jEgVK
^]GWkngQc;2?KD`a7A8A6bi9JH^/bMo/knSG_YmmG3dV5Q4E93]INYbkeNK^k>3:
[Xe[C34M4Q8L<4YZS:g9g^_^i]FlWGaK?BHG4QLV?E]lWKcEi^g[g/R/S6Y;<1dC
51haC6b=[LWNj^gUdkZLNUXm9QLC62LoG7fN_=GUk>WLaj^:JDX`7Q@E7c=>KHj^
bMkZjn?B^IYiFC`V61@J:D5NOYnmeNG[j=_5ZHUXBS0N5AHQ=Dm_Sjo:g^WZh]2g
V7QH?2HI5A/[@Un0X;gEi>[VfL>WR6M9<1hF5b<fDG2A[l[Mj>WPc[FGMeLl9QTF
7Ba4HH6Q_]GTjNGG`ZJ6ITT`7aLI93QCLY:`b]gWj=o=/iEeES/W6QLN;TISPZ:n
e>?Xi=K0Y8EUB30P61XV>UAcTk7:g>KVgL^bU7AF>bLK6B0`AfB4XkkDh^ORe;jR
Q6A8<20I72PlEWBD/L[LiNGKbK2BLeDk9a`J8C99IXFS_mCQi^3B_:62HdL`8AXM
:CeHMYFbb]_Ti=[7[Y5bEC/X7A/S<d]WQZBoe>3Tgm6kWh5SAc4R6al[?eUgU[;:
fn?Rf<J]T75D>bPN7BDeCFV7YKoCh>?MckVNP697<B8M82e1FgRG/l[Jh^7Fa:^>
L5<k:AlN9SM>JXRU_m?Oh]c=]iaoHDHa8ahR;T=MNYNcb]WQgmG2ZHe_Dc/Y820X
>E1/RJJod]kPf/^eVgePAS4T7b<`A5ikV;?9fN3Ndl2XRfiC>bXQ8BXjDVf:Y[oB
gMoHbKBIO616<RDQ9C96H7bI]<WHg]cA_ZJ:KE8k:b8S:caCKX^W_m7Lg]O8/YQk
GdHb9R8W=4QQOIZdbMOMf/nmYHU/DS//8b@]?UE`S:Nod=[LeLJ`UWYNAS<W8bPf
BV=oVkC8e]cIcK^SR6aB?2`U9Rm0Eg6=Z;o@fM_Ca:nENEi6<bPU:SM;I82K]<SE
f]O<^J66Je4l;BHW<D9HLhjX_loHfM72[I=hGDHd:BH/>DeVPIbdamCIeLZgX8EZ
DC`^9bTc@eYdSjVnc]OGd<2[TWMMASDZ:2hkCfN2W;C7dmODb;JNQ6UA?BlY:cA5
FgF@ZKk=e]K>_jZAMUe6=B/Y;ceAJH>M]<KBe];6]9f3JE4m<2X/=TMMMY2Y_/gD
e<bmZ8meG4Lf;B/a?e9ZQ9fda]7Dd<BbVh9XDCha;2hhBEmgTJVmc=?Bb[^VSWAL
AcL^;C=1E6^5W[C5d=?>`k2JPFQA?S8]<3Y:H7VBZKg;d]78^JF=M5a7>2l^=D9F
KHJN]<C>dLg1[iR0Ie4o<bla?4aRNY:Y_<[@clNgXhacG4Li<C0gA5M^Qijc`lg@
bkn]UgmWDD0d<3<nCV=kTjVlbLo=aKJRRW9KB3Xb<SQ6FFn7Wk?3c<k9_J^FOVIA
@3Hb=Cm@IGbDZK_8cLc3]:29LU]8>c<c>TQKLHRO/l;;c<NkZYAmIU51=c<g@E9V
OIBY^lK<b/6bWhQaFdTl=CDlBUabRInb`LW;aKVXTgaVDT8h=CU3DfMnUJVjaL[8
_k2MQg1KBCdf=ci;GW>:Wk;0b<W3]jJBNfEB@cTg>dEEJGnEZKW4b<Jm[ib6L5]:
?SPi@4eOM8ZO/Ko6al6fYI1jIE94>cPlAeMZP9FY^<?7a;^]VXE_Fd/o>CY2Cf5e
Rina_/G5`;BSSgYUDdDl>Si9F6b1UZRh`LG2^J^IQ6mKBd0k?4AAHWJ<Wk2m`lBn
/Z6>NFECAShl@4]JKH6FZ;O0`l6hZIN3Kea<@SdnAU=TN8bO/;c2`[b`X8ehIEA7
?ce2C5a^PYJX][o2_kJXUX9^G4e3?T18E6EiS9n_^/30^ZjNS7QUE4Q1?dA>GFn3
UZNe_L2m]:JEPFiLCTA0@TUFIgZ=Wjji_kjh[9f;MfEEBD91AU1OL8BFYkBl_[^b
Y9>1KUe?AT94BeQXNXfO[KRm_;J[VhYgIEE:A4=8DV1bQ9JV/kZl^K2STX1]GE17
@dI=FVUkSYn]]k^j]:VJRGIUET]5ADYDHW>5UZJb^K^g[Z6AOfeMDDQ5B4mKJgb>
WZbe^[VbYiV8MVEGCDM7C5ISM8FFYK2g^KF/Wi1nKEiBBTM:DEe/OHjNZkBh]k2U
UhMeIEQ>BDU>EfEeQYJT[kJg/jZNSWi]GU=;BD]CGfenSYjZ/[Je[ZBFQWEVFDm:
BU1IIWJ6UZB^];FaZIb=OFeOE4e;CEEPKgj>WJVa];>/XYB5MFIIDDa<DU]XMhNF
Xjfb/jnWVhamKF1ECde?Ef9`OhnMZ:nb/J^PThAeIUYBCTiCGFUhQiJRZk6a[JFI
Rga]H5I@CU5IHg60SibW[[6_ZInBPgEWFe=@D5ENJgV7UJ6Z[jn[XiR:O6iQF59@
DeYULX2?VjJ/[jfWWI63M6MLEE5BEf1/NXREX:V][JVQUXUkKV9IDe9EG6IcPHjK
Y:^]ZjFKSh9dJ5eFDeAIHVejR9FOYj^[Yj2ER7]^HeYEE5MNJ7B1SYZSZJ^YXiZ>
PGAXGeQEEU]SKW^8U9jVZZVUWYB7NfiTG5MFFF1YMH:>VJ:WZJNQV8f1M6UPFUMH
GFE`O8RDWJBXZ:BLTXMjKfAMFEQKHV]fPXjHXJJWYInGS81dJV5KFEYOIg5lR9>L
XjJVXY^AQWY_IEiJFUeSK7N3SYROY:FSWYF;P7EZHUeKG65XLWf8Ti^QY:BPVI25
NVmVH5aLGfE^N8>=UijRXj6LU8YoMF]SGeeNHfYcOXRBVZ2RXYjGSXAjL6QQGUiQ
IfmiPhfFW:2QWiZBRGmeK6EPGf1TJgAnR96IWZ2PW9J=Q7Y`JF=PH6=YL7Z3SIFK
WinMV968OgE]IV9QHVI]MGn8TIRLWYjJU8b3NW5ZIF9RIFYbNX><U9ZMWI^FT8Mn
MFiXI6=TJ6ifOhR@UY^LW9RBRh=jLV]VI6AWK7=kQ8bCV9^KVIF>QWifKfUVI6IZ
L7MoR8nEVI^JUY6:PWYbK6QVIVU]M7b4Ri:FVIVGThf6OWI`JVMVJ6aaN827SYBG
VIRDShV2NW=]JFQXJfmeO8B;T9FGUiFAS8EnMg5/JFQZKG=iP8N=TYFGUY>>R85j
M6m[JVY/LGImQ8Z?TiFETi2:Q7igLVi[JVa_M7Z0QhbAU9FDTHb7PG]eL6e[K6ib
Mgf3RHjBTi>BSXV4OWQcKfe/KW5eNh26RhnBTi:?RhJ0NgIaKfe^L7AhOX>8SI2A
TI2<R8=nN7AaKfi`LgMkPHJ:SY2AT8f:QH1kMg=`Kg1bMGUnPhR;SXn?SX^7PWii
MG9aL79dN7b1QHV<SXn>S8R4P7ahM79aLWAgNWn3QhZ<SXf<RHJ2OWYfM7=cM7Ii
OH65R8^<SHb:QhB0O7UfM7=dMGQkOh>6RH^<RhZ8QH5nNgQfMGEfMgYmPHB7RHZ;
RXR6Ph1lNWMfMGIgNGaoPXF7RHZ9R8J4PGikNGMgMgMiNgj1PhJ7R8V8QhF2P7ek
NGQgN7UkOGn2Q8J7R8N6QH>1OWajNGUiNG]lOX63Q8J6QhJ5Ph:0OWakNWUjNgan
P863Q8F6QHF3PX1oOGakNW]kO7eoP8:3Q8B5Q8>2PH1nOGalNgalOGj0PH:3PhB3
Ph:1P7mnOGelOGenOWn0PH:2PX:2PX60P7mnOWimOWioOh20PH61PX61PH20Ogmo
OgioOgmoP820P821P820P820P7moOh20P820P820P820OgmoP820P820P860P820
P7moOgmnOgmoOh20PH61PX61PH20OgmnOWenOWioP821PX:2PX:2PH1oOWimOGam
OGioP862Ph>4Ph>2PH1nOGalNgalOGj0PH:3Q8F4Q8>2P7mmO7]kNW]lOGn0PX>5
QHJ5Q8>1P7ilNgYiNW]lOX22PhF6QhJ6Q8>1OWakNGUiNGYlOX63QHJ7R8N6Q89o
OG]iN7MhNG]mP8:5QhR9R8N6Ph5nNgUgMgMgNG]nPHB6R8V:RHN5PWmlNGMfMGIg
NWb0PhJ8RX^:RHN4PGejMgIeMGIhNgj1QHR:Rhb;RHJ3Og]hMGAcM7IiO824QhZ<
SHb;R8F1OGUfM7=cM7IjOX:6RHb=SXb:Qh=oNWMdLW5bM7QlP8B8S8j?SXb9QH5l
N7AbL75bMGUnPXN;SXn?SX^8PgiiMG9`Kg1cMg^0QHZ=T96@SXZ6PG]gLg1^Kg5d
N7j3R8b@TI6@SHR3OWQdL6i]Kg5fNh26RhnBTi:?RhJ0NgEaKVa]Kg=hOXB9SY:C
Ti:>RH=mMg9^K6]]L7EkPHN<TIBEU96<Qh1jM6m/JV]^LWMnQ8Z@TiFEThn:Q7ef
LFaZJV]_M7Z1R8jCUYNETXf7P7UcKFYXJFaaMgj5S96EUiNET8^4O7E_JfQXJFec
NX:9SiBHVINDSXN0N75/J6IWJW1fOXJ=TiNIVIJBRhAlM6eYIVIXK79jPXZAUYZK
VIF?R7mgL6YVI6IYKgInQXjEVI^KV9><Q7]cK6MTI6I[LWZ3Ri:HW9bKUY28OgI^
J6ASI6Q^MGj7T9JKWIfJU8b3NW9ZIF9RIFYaNX><U9ZNWYbHTHQoMFeVHV5RIVee
OhRAV9fOWi^ESH=jL6USH61SJG1jQ8fFW:2PWYVAR7idJfAPGf1UK7EoRI:JWj6P
W9J=PgU_If5NGV5XL7Z4SYNNXZ:PVY:8OW=ZHeiMGf=[MGn:U9bQXj:NUhf3N6iU
GeaLH6I_NXF@VJ2TY:6KThQmLVQQG5]MHVYeP8^EWZ>UY9nHSX=gK6=MFUYNIFmj
QY6KXZJVXibCR7aaIemJFE]QJWB0S9NOYJNVXIR>PWI[HU]HFEeTKgZ7TYbTZ:RT
WIB8O71UGEQGFV1YM86=V:6WZJNRVHj2MFUPFEIGG6A^NhNDWZFYZZJNU8QkKV=K
EUEHGfQdPHjJXjV[ZJ>JSX5dJ5iGE5EJHfikR9FPYj^[YinER7Y]HUUDDeIMJ7B2
Si^UZjf[Y9^>PG=VG5EBDeURKW^9UZ6Y[JfYX9F8NVaPEe9AEEaWM8>AWJN][jbV
Vhn0LVEJDe1BF65^O8ZHXj^_[jZQUHMiJeiED51CFfMePi:OZJna[ZNLSh1aHeUA
CU1FH6elRiVU[K6aZj:FQgQYGE=>CU9JIWF4Tj2[/K:_Z9f?Og1REdm=CeEPKGf<
VjN_/k:]XiJ7MfQKDTa<DEUVMHFDXZbc];6YWHinKf1ECD]=E5m]OHfLZK6e]:jT
UXIfIUU@BTY?FFIeQYJT[[Ff/ZZNSWi]Ge=;BD]CGVenSYjZ/kNf[jBFQWEUEdi9
BDiHIGF7UjF`]kRdZij>OFaMDDY7BU9NKGj@Wjbe^KN`YIJ5M6=FC4M7CEMUMXRI
Yk:i^[F/WXilJe]?B4E8DEe]Oi6Q[[Nk^K:VUXEcHUA:ADE;EVEfRIZY];Zk]jfO
SW]YFTe6@dM@GFf0TZ>`^Kbj/jJFQ79PDTQ3A4YEIGN:Vj^f_;fh[In=NVQHBdA2
ATmMKX6CY;:k_[bdYiJ4L5m@AT52BEEUMh^M[;Rn_kV^WhejIeI9@T14CUa^PIFV
];g0_KFWUX=_GDi4?d58E6EhS9j^^/30^ZnOS7UUE4Q0?T==G6j2UZRf_l:o]ZRF
PViLC48m?dMDIGR=X;2l`/:l/9n<N6ACAShm@TaLKh>GZKS1`l2gZ9J1KEY;@3`n
AU=UNHjQ/[k4`kf`WhafHU54?3]0Be]_Q9V[^L;5`KRXUX5/F4Tn>Sa5DfEjSj>d
`<G5_[6ORgEQCd8j>Cm;Ffn5VZfka<O3^:VEP6YGAc`h>dABIGZ@YKK1alJo/In:
M5m=@3Th?TYKL8JL[kg6b<BiZIEoJEE5>cLi@e9UNi:V]l?9b<2bWhYcGT/n=cHm
BE]`Qif`_lS:aKZYUGiWDd<i=CQ2DVIlTjRiaL_9`K:ORG9LBS`e=Ca9Fg68Wk;1
b/c6^jVDOFIB@CLc=d5AIWfDZ[_7c<_2/in8LE]8>S<c>dQKLXVP]<?<cLRkZIAl
IE0o=C8f@55VOYJ[_LW>c<>cWhM_FDHh<S8jB5]bRZ:faLg?bKbYTg]SCShc<3A0
DFMoUjfobm3=`k>NQfiGA3L`<CU7G7><XkO7cm3:_:VBNV9<?34_<cmAIh2H[l7=
dLk4]9j6KEI2=Bh_>4MLM8fU^LSAd/^mZI9iH4Xj<2db?U5XPIZ``lkCd<FdWXE[
E44c;BhgAeadSZJkb];Cc;fYTGMOBCP^;34nDFR2Vk;4d=CAa[BMQ6YB?c4[;CI7
G7F?Z;g<e=C=_ZV@MUe7=R`Z<3eAJH>M]<KBe];6]9f3JE4m;bT[=DIMMY6Z_lkF
e/fnZI1eFdDd:bT_?E5YQ9jfb=CGdlNdW89WCc/^:2XeAUegTZ_0d=OGc[jYSgAJ
@c<Y9bhlDFZ5X;O:eMWDakBLPFI=>B`V:CA6GGRC[L;AfMS?_jR>LeQ2<BLV;CaA
JhJQ^LcGf]G8]9^0I4/g:RDX<dINNIF_a=?KfM2oZ8eaEd0_9RD/?59/R:>kcMWL
e/RdVgmSBSHX8bLcAUijU[36eMcJd;nWS71E?RdT8b`kDVb9YKg?f]gGbKBJOF58
=2LR9S96Gg^H//SGg]cA_jN;KU<l:b<R:c]BKHZV_]7Lg]S9]9UlH4Hb9B4U<TIP
O9VdbMSOgM:oYXY]DSXZ8B4Z>e=^RjS0dmkPfLVcV7]NA30S7b@aAV1mVkG;f^3N
d[nVRFa@>BPP82TkDfn=ZL;Egn7Ib[>GNUe3;R8N8c56HGnL]lgLh]oC_jF8JThg
9QhO:C]CL8j[a=KQh][:/iMhFd4]81dR<DMRP9jicmgSh=>oYHMYCCDU7AhX>eAa
T:g6f>;SflZbUWMI?b/O6b8aAf>1Wk_AgnCPe;nTQVM;<b<K7BPkEG:A[/OJi>CK
b[:EMUPm:AdJ8C17Hh:Q_=;Pi^7D_j>5ITTb8AXL9c]ELi:`bM_UiMc:/IAdES`X
71TP<4QTQ::ne>;Wh]BnXhATAc0P6A/W>eIdU;;;gNKVg<ZaTg=D>RHJ620`B6F5
Y<3Fi>SSe;jRPV=6;QhG6RLkEWFE/lgOj>OMb[2BLU<h91TG7c19IXJV`]OUjNCE
_Z61HD@/7AHI9SaGMiNec^3Yj=g:[i5`DCHS5aHN<4UWR:O3fNKZi=FmX81O@R/K
5ATV?5QhV;O@h^[Yg/Z_Sfm?=B4F5Ah`BVR9ZLGKj>_UeKfOOUi1:AXD62HlFGVJ
^M;Sjn[NbJj>KDhc7aDD7S1:JHZ[amcYk>GE_9imG3lW61<G9SeJNYbjdnG]j]k9
[He/C34N51<M<4]ZS:c8g^_]i]FlWGaK?BHG4QLV?E]lWKcEi^k[g/V]S6Y:<1`B
4QdaC6^=[/[Pk>kVeK^LNUTk91DA5RHmG7fO_]OXkncObJb;JDT^6a4B7C5<KHn`
c>7]knOE^Y]iEcXS510F9SiMOZ2of>W`k=o8ZhUWAb`I414L<De^T;7>hnk`imBj
VWMF>24C3aDV?ej0X/7Jj_7]glRZR6I5:aP?41`aCVnB/loTl?7We;VIMU@f7a4>
5BHoGh6T`mc/l^kOajV7I4@Y5`h@739?L9>edNKalNSD^9QdDSDN40dD9T1PPjG4
gNgck]o7Z8ER@RLE3@lL<U1bUKKBio;bj=BhUW=A<a`?31@V@F64YlKOk_C^glJW
Q6509Q@<3a`cDG>F^=CXlo?XdkNELDla6`h;52I1HXFXb>3`mNoOaJJ3GclT4P/>
73=BM9Rje^[dlnSC]YA`CS0J3@/D9d9SQj[9h_7ekmk5YH5N?B<A2PhL=5=fV[_G
joGdj=:eTfi<;QP<2Q@W@fB8[<_Sl_K_g/BTP5`k8A093A`dE7NK_MW/m_CXd[BA
KDX]5`/:4bM4IXZ]cNGcmo3N`j9nFSXP3`P=73EEN9fnf^kgmNSA/i1[BB/E2PTC
:4EWS:o>i_Chl=g2XGeI>1h>20dM=UIjW/3LkoSej=6bSVY7:A@921<XAVR=/M3W
mOS`gL:PNeLg7@d731dgEg^P`]g`n?KXd;6=J4DX4`P84bU7JXnbdNWfnO3M`Imj
ECDL2`H<7CMHOJ;3go7im^O?/8aWA2HB1`PD:TQ[T;CCj_Oil=c0WGQD<aX:1P`N
>5UnXlGPl_[filn_RVE29A061a@ZBFbB]]C[n?[`g;nLMe8b6@T531hiFh2Uan;c
noKWcZf9Hd0T3`D752]:KY>ge^cin_3K_Y]eDC0H20D<7SYLPJK8hoGkm^K=[8MR
?b8>1@LD;4]_UKWGk_[jl=ZmVGA?;aH810`O>ef3Z<[Tm_cfi/b[QV0m8@d41a@/
C76F^]W_n___f[bHLTd]5@L4320lGhBZbnKfo?KVbjZ4Gc`O30<65Be=LYRlf_3k
nnoI^iM`C2`D1P<<83ePQZ_=ioOmm^G:Z8=M>Qh;0`HE;TicV[gKlOckkmRiUFm:
:Q<50`dQ?V67[LkXn?gfiLVWPE/i7@X21QH_D7FK_mgbo?__f;RDKDTY4P@33B4o
HhV^d>Wio_KTb:J0FSLL2@865S1AMYg1g_?mnnkG]i9/AbP@10<=8T1TRk3Aj_[n
m^?7Y7iH=QX80@HG<E9hW/;Om?kkk]JfTFY59Pl30PdS@FJ</];/nokfhlJSOELd
6@L11QLbE7ZPa>7eo__]eKF?JD@U3P<23RA3Ihjce>gko_KRaJ9kEC<H1`4763=E
Nj;5h_KnnngD/hiW@R@=0P8>9DAXSkGEk_comN74X7YC<AL600LI=5ImXlKSmook
k=>bS6E18Pd10PlVAFZA]]K_o?oeh<>ON58`5PD01aTeF7jUb>Cgoo_/d[6;I3lQ
30423bM6Ji:hf?3mooGO`IefD2lE1@076SIIP:K9iOSonn_A[hUR?R0;0@8@:4Q]
U;WIlOgom=o0W7E?;A@400PK=e^1Z<_WnOokj]2^R64m7`X00Q0YBFnF^m[ao_od
g[nJLdd/4`<021`iG8>Yc>Sioo[Ycjb6Gc/N2@034BY:L9Nlfo;noo?M_YUbC2/B
0`097CYNQ:_=jO[on^W=ZhAN>Qd900<B:dabVKkMloonl]blUg1::Q4300TN>en6
[<oZnoojj<bYPe`h70P00a8/CG>J_mkdookbfk^FKTTX40802QllHHR^d>[kooWW
bjR1FSLK1`044be?MIc0goCoo_7I^IA]AbL?0P0:83iRRJoAjo_onNK:Yh1I=QX7
00@D;U1fWL;PmOonl=RhTf]69Pl200/Q?fB;/M;/o?ohiLRUOULe6@H011D`DWRO
`n7foog_ekNAJTDU3P413290IHbbe>glooOTaj=mES<H1P055S5CNJ34h_KooNoF
]HmX@b@=0@4<8d9WS[CEk_gomn?6XW]E<QL500DG<UEkX/KSmoolk]FdSVM28`d1
0@dT@fR?]MK^oOofh/BPNE<a5PD01QPcEWfSanCgooc]dk:<ID4R30423RE5JY6f
enomooGQ`imhDS0E1@076CEHOZG8iOSonncB/H]T?b4;0@8?9TI[TkSHl?gomN31
WGI@;aD500LJ=UV0Y/WUn?okjm6_RF8n80/10Q0XB6fD^MW`oOkdg/2LMDl^50@0
21/hFh6Xb^Khoo[Zcjj8HCdO2`434BU9KiJjf_7mo_?M_iYcCRdC104973ULPjW<
ioWon^W>[8IO?1h:0@@B:T]`UkcKlOgnl]bmVG9<;1<40@XN>Uj4ZlgXnOoij<f[
Q5hk7PX111</C7:I_McboOgafkbGL4/[4P@12allGhJ/c^Sio_SVbjV3G3TM2P45
52e>LiZng?;mo?3I^YE_BRXB108<83eQQjg?jOWnmnG:Yh5K>1`90PHE;TmeVkoM
l_glkmRhU6e8:A440P`Q?f>9[m3YnOkfi<RVP5Xg70T21QH`DGJM`=kcoO_^e[NB
K4LX4@@33B=0I8^`dN[ioOGSajAnF3HK2@875c5CN9k2go?mn^gE]I5ZARLA10@?
949VS;7Bj_Wmm>75XgeG=AX90`PI<eAjX<?Olocjk=BdSfU59Q05110UA6N=/];[
nOcch<BQNeHd6PT32AXdEW^Qa>3co?WZd[:=Id@V40D54BM5JHncdn_ino;O`Ymj
EC<I2@@:6cIGOJ;5hO?kn>WA/HaV@bD@1@HB:4M[T;GDjoWklMg1WWQC<aT910/M
=eUnY<KQlo_gj<n_RVE291051a<ZB6bB]]G/n?[`g;nLMe8b6@T531hiFh2Ua^7c
n_KWcZf9Hd4T40H752]:KY>geNchnNoJ_I]eDC4H2@H=7c]LPJK7h_?jmNG<[8MR
@2<@1PPF;Da_UKSFk?Sik]VlVGA@<1P:1PhQ?5j3YlSRloWdi<^ZQV4o8a072AL^
CG6F^MO/moS]f;ZGLTl`60X73b8nGhBXbN?cnO?SbJR4H3hR40L:631?LYNjencg
mn_F^IIaCRlH2PPA93mQQZ[:ho?hl^77Yh=N?B8@20/J<E1dVK_Hk?Ofj]BgU71=
;QP;2A8U@F>7Zl[SloOah<JUPEdl8Q0931/cDWJJ_=S/m_GYdkFCKT`^60/:4bM3
I8R/bn?bm_3Na:B0G3/Q40T>73EDMi^mf>cem>OA]95]BbdH30/D:4AVRZg<ho;f
k]g2XWiK>b4@2PlN=UEiW;gIk?Gci]2bT6a:;AP<2aHZAVN;[/cSlOG]fl6POEXj
8A4;41lhEgZN_]W/m?;Uc[2>JTT/60d=5b]8JHf_cNCam>cJ_imkFCTQ4@`A8CYI
NinofN_cl>?<[heYB2`H3@hH;DU[S[3=ho3cj]RmWGYH>B4A3A8R>eYmX<3Jjo?_
h/^]RfQ7;1P>3aX_Bfb?/LkSl?;Ye[bLNELh8A8=52@mG7jQ`=[[l^kPbJ^:IdH[
60l@6c1=KY2bc^?_lNSE^YYgESPQ4PhE9SmNP:;1f^[akMo7ZXQVAR/I414M<Ti_
T[;>hnk`i]>hV7IE=b4C3aHW@5n1Xl7Jj_3[gLJXQfE5:aT@4QhdD76C/loSk^kU
d[NGME@g8A@A62U2HH:T`][Ykn[Ka:J5Hd@[6A4D83EBLYBdcn?]kN?@]IEdDcLQ
518I:TARQ:G2f^W^jM[2YHARA2/J4QDR=e=dUKG?h^c/h/jcU79B=R4E4a//AFB5
Y/?Jj>gWf<6SPV53:aXC5R<iEGFF]LoRjn_Pc;:BLE4f8AHD72i7IHJW`m[Xk>KF
_j:1H4<[6a@H9CYGMiNfcn7ZjMk;/95`DCHR5aDN<4UWR:O4fNO[i=FmX81P@R/K
5ATV?5QhV;K?hNWXgLV^Sfm@=R8G5QlaBVV9Z<CIi^WSdkbNOUm2:a`F6RPnFWVI
]loPj>OKajf>KTlf8aPH8C=<JXZYa=WUj>7A^YemGT8[7ALL:T1KNiZgcn3WiM[6
Zha]CcDS6ATS=Di/Rj[4fNCWh=2hVgaM@B/M6Ad[@EelVkS?gnKTf<BYRfa>=B@J
6b@fCff<Z/CHi>KNc[JJNea1;1hJ7be3GgfL^<oOiN;F`ZR:Jdhe91/L9SQAKXf[
aMSSi=g<]IQjFd4/7a/Q;dEPOificmkThMC0YXQZCCHU71dX>U=`SZc5en;SflZc
UgQK@B`P728aAf:0W[W?gN?OdknTQfU==RDN7bTlE76?[<GGhN7IbK6EMeY1;B4N
9398Hh6N^LkLh]kA_J>6J4df9QlP:ceFLi2]a=KOh=S7/9AfFT0]8QlU=4YUPYni
c]_Pg<nkXHAWC3HW828]?eQdTJg4eMkOe/F^TWEI@2hS8BLfC6J3X;W>f]oJcKVP
PfI<=RPQ92i1FGFB[LCEgMgD`jbAM5U0;R@R:CQ=J8BP^LgJg]W<^9j2IT`g:B8U
<4=KMi>^a=CLfm;2Zi1cF44_9B<[>TmYQJ6jcMWLelZfWH5UC3LY92LbAEehU:k4
dm_JdL2YSW9H@C0V9B`kDF^6X[[<em_Eb;BKP6A<>2XU:3A6GWVE[/?BfMS?_ZN=
LEM1<2LW;SeCK8NR^L_FfMC6/YYoI4/h:bLZ=TQPNYF^`m7HelflYXaaEd4a:BP`
?eA]R:>ibmGHd/BaV7iSBcT/:2`gBV5kUZo3d=OEbkZTRW1G@C8Z:S91EVn9XkW:
e=K@`jnGOF=;>BhZ;SU<HgfG[l;@eM?9^J:9KeI2<b/[<d=HL8ZS^LWCeLk1[IEl
HT`j;b/_>deTOYN_`/kDd/NgXHQ^ET8d;BdeA5UaRjBibM;CcKn/U7]RC3/`;C4m
CfIoV:o1cM;@a[FOQfiF@cD^;cM6Fg><Y;S8d=7;_JZCNV5<>c4^<cmAIh2H[l3<
dLk4/ij6KEI3=Rl`>DQLM8fT^<O?d<VkZ95iHD`l<S0e@E=YPIV^`<_?c<:aW8E/
ET@g<C8kBUieSJBha/k>akVWT7QQC3dd<CM3E6Z2VJjob/k:`;2KQ6aFA3Pb=3e<
GgJ>Y;O5c<c5^:F?Mf5=?SDc>4AFJh>J[[k9c<Vn[YV3JeI5>C@f?deQMhnT]lC;
b/>fXhigH4do=SDjAUQ]PiZ^_/O;akb/V89[ETHj=CQ0Cf9hSjBf`lW9`KBRS7IP
CT0h=Sa8FFj4VZjma/W5^Z^GPF]FAS/g>D9AI7Z@Y;G2b<O0/Z2;MF1>@CTh?TYK
KhFJ[Kc5al>iZIF0JUM7?CTkA5=UNi2T]L36aKj`WhYeH4m2>cY0C5a`QY^]^l?6
`KNWU7mZEdPn>Se6E6MlTJBd_lC3_:nMRGAPCd<l?49>GW:6Vjbj`/Bo]JJCOVYG
BCll?dQFJ7bAY;>n`l6j[Ib8Lf1@A3hnA4mPLhNK[;W0`[fcY95mJEQ:@Ci1BUQZ
OI6T/kg1`;R[VXMcH515?cm6DF5dR9^[^;o0^k6RT7eYF4]2?d=<FV]nTZ>b^knn
]ZVIQW=PDDI1@DQCHgF8Vj^g_Kjj[j6?O6UIC4A1ADiKK7nBXk6j_[bdZ9N5LV5B
B4=3BEETMXVKZ[Fl_KR^WhikJEU=AD=7Cee]P9:S/;Vl^[:VUXAbHE=9A4E;EfIg
RI^Y];Zk]ZbNSG]YFTi7ADUAGVn0TZ:_]kZh/:BEPg9QE4Y6AdeHIgR:VZVc^KVd
ZYb<NVUJCdQ7BU=PL86BXZjf^;J^Xi>3LF9EC4Q9CeYXNHZJZ;:g]k:XVh]jJE]@
BTU<EF9aPY:Q[KBg]:fQTX9aHUI=BD]AG6YjRYZW/;Fe/:JIRWUYG55;BTiGHg:2
TZ2//kFbZinAPG5REdm;CE=MJg^;VZJ_/k>^YIR9NFYLDde<D5UULh>BX:Za/k2Y
WY20LF=HD4e?EEm/Nh^IYJjb/JbSUXQhJUeDCdiBFVIdPi:OZJna[ZNLSh1aI5UB
Ce5GHFilRiVT[;2_ZZ6EQgQZGUEAD5ALJ7F4TYjX[Zn/YI^=Og5TFU=ADeURKgf;
V:>[[ZfXWiB6N6YOEe9BEUiYMXBBWZN/[JZSVHaoLFEKEE=EFfA`OX^HXZV/ZjJN
TXEhJf1HE5AHH6]gQI:MYJZ[Z:6HRgiaIEaFE5MLIW5nRiNQZ:ZYY9bAQ7M[HEYF
EUYRK7R5TIbTZJVVX9J:OW5VGUQFFEiWLWn;Uj2VZJNRVY24MfaRFeQHG6=]NHFA
Vj>WYjBNUHUmLFMOFUQKH6UcOh^FWjBWYJ6ISh=gK6=MFUYNIFmjQI2JXJFUXYbC
R7ebJ61LFUaRJWB0RiFMXjFSWiN=PWM]I5iKG61WL7Z6T9VPXjBPVY:8OG9YHUeL
GVA/MH2;U9bQXj6MUXb2MfiUH5eNHVQaNhJ@V9jQXYnIT8MlLVYSGeiPIVefPH^D
VinQWi^DRh5gKVMRGf1TJW9lQXnGWJ2PWIN?QWacJfAQH69WKgN1RY>IWYnMVI>:
PGQ_J6=QHVE[Lgb6SYJKWYjKUHj5O7=/IV=RI6U`N86:TYRLWI^GTHV0N71YIF=T
IfedOHJ>UIVLW9VDSHElM6eXIFAVJg5iPHZAUYZKVIJ@R81hLF]WIFIYKgImQXfC
V9ZJUi:;Q7adKVUVIVQ]LgZ2RI2EV9VHU8j7P7QaK6QWJ6]`Mgj5S9:FV9RET8Z3
O7E_JfQXJVidNh:9SiBFUiJBSHIoNG9]JVUZKG9hOXF<TIBFUY>?RH=lMW1/JVY/
L7EkPXR>TYBEU92<QWmiLfm/Jfa_LgUoQH^?TiBDTHf8PWafLFi/K6iaMWb2R8f@
Ti>BShZ5OgUdL6i]KW1dNGn5RXjATY:?S8N2O7McL6i^L7=gOH:7RhnATI2=RHAo
NWEbL6m`LWIjOhB9SHn@T8j:QX5lN7AaL71bMGUmPXJ:SHn?SX^8PgmjMW=aLG9d
Mg^0Q8R;SHj>S8V5PGeiMG=bLWAfNWj2QXV<SHf<RXN3Og]hMG=cM7IhO824QhZ;
S8b:QhB1OGYgMGAdMGQkOX:5R8Z;RhZ8QH9oO7UgMGEfMgYmP8>6R8Z:RXR6Ph1m
NgQgMWIgNGanPHB6R8V9R8J4PWmlNWQgMgQiNgf0PhF7R8R8QhF3P7ikNWQhN7Uk
OGn1PhF6QhN6QH>1OgekNWUiNG]lOX22Q8F6QXJ5Ph:0OWakNWYjNgamOh62Q8F5
QHB3PX5oOWalNg]kO7eoP862PhB4Q8>2PH1oOWelO7amOGioP862Ph>3Ph:1P7mn
OWemOGenOWn0PH62PX:2PH60P7moOWinOWioOh20P861PH61PH20P7moOgmoOgmo
P820P820P820P820\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](
        t) == \(sin(\[Pi]\ t)\)\ \(sin(800\ \[Pi]\ t)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Time domain \[DoubleLongLeftRightArrow] Frequency domain", "Section"],

Cell[CellGroupData[{

Cell["Example #1(a): simple sinusoid", "Subsection"],

Cell[CellGroupData[{

Cell["Continuous-time waveform", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f1[t_] := Sin[2  \[Pi]\ 10  t];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f1[t], {t, 0, 1}, \ 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\[Florin][t] \[Equal] f1[t]\  // \ TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309019 0.294306 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -12 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60333 -6 -4.5 ]
[-0.0125 .60333 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(-1)] -0.0125 .01471 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60333 m
.00625 .60333 L
s
[(1)] -0.0125 .60333 1 0 Mshowa
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07357 m
.00375 .07357 L
s
0 .103 m
.00375 .103 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60333 m
1 .60333 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07357 m
1 .07357 L
s
.99625 .103 m
1 .103 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30902 m
.02846 .39784 L
.03279 .47329 L
.03754 .54057 L
.0402 .56874 L
.04262 .58745 L
.04385 .59428 L
.04516 .59946 L
.04627 .60217 L
.0475 .60332 L
.04882 .6024 L
.04957 .6009 L
.05024 .59892 L
.05156 .59344 L
.05281 .58624 L
.0552 .56729 L
.05742 .54396 L
.06244 .47342 L
.07295 .2796 L
.0781 .18365 L
.08284 .10781 L
.08545 .07397 L
.08832 .04487 L
.08981 .03341 L
.0912 .02511 L
.09197 .02154 L
.09267 .01894 L
.09348 .0167 L
.09424 .01535 L
.09549 .01475 L
.09612 .01521 L
.09681 .0163 L
.09804 .01973 L
.09919 .02468 L
.10055 .03257 L
.10179 .04174 L
.10458 .06886 L
.1145 .22212 L
.12511 .42355 L
.13025 .50731 L
.13278 .54066 L
.13511 .56574 L
.13723 .58329 L
.1383 .59012 L
.13947 .59603 L
.14065 .60022 L
.14192 .60276 L
.14311 .60328 L
.1442 .60216 L
.14544 .59907 L
Mistroke
.14655 .59461 L
.14784 .58754 L
.14906 .57904 L
.15122 .55965 L
.15356 .53299 L
.15887 .4538 L
.16375 .36524 L
.17272 .19465 L
.17765 .11398 L
.18007 .08136 L
.18231 .05638 L
.18476 .03538 L
.18605 .02716 L
.18671 .02374 L
.18742 .02067 L
.18856 .01705 L
.18963 .01517 L
.19091 .01483 L
.19207 .01635 L
.19317 .01936 L
.19419 .02352 L
.19531 .02958 L
.19651 .03773 L
.19896 .05958 L
.20117 .08503 L
.20629 .16079 L
.21182 .26131 L
.21701 .36154 L
.22185 .44991 L
.22681 .52551 L
.22898 .55171 L
.23134 .57459 L
.23268 .58476 L
.23392 .59225 L
.23511 .59763 L
.23637 .60142 L
.23769 .60322 L
.23893 .60287 L
.23965 .60179 L
.2403 .60023 L
.24101 .59789 L
.24177 .59473 L
.24308 .58753 L
.24428 .57915 L
.24697 .55428 L
.25182 .49072 L
.26282 .2912 L
.27213 .12525 L
.27682 .06396 L
.2781 .05103 L
Mistroke
.27949 .03921 L
.28078 .03016 L
.28198 .02358 L
.28271 .02047 L
.28337 .01823 L
.2841 .01638 L
.28488 .01516 L
.28556 .01473 L
.2863 .01493 L
.28699 .01576 L
.28763 .01706 L
.28883 .02091 L
.29014 .02719 L
.29152 .03601 L
.2928 .04625 L
.29761 .10082 L
.30277 .18223 L
.31296 .3751 L
.31833 .47048 L
.32127 .51491 L
.32403 .54959 L
.32642 .57325 L
.32765 .5829 L
.329 .59138 L
.33039 .59781 L
.33115 .60029 L
.33186 .60194 L
.33313 .6033 L
.33384 .60316 L
.33448 .60248 L
.33573 .59966 L
.33687 .59534 L
.33813 .58872 L
.33946 .57961 L
.3417 .55966 L
.34415 .53147 L
.35498 .35091 L
.36031 .248 L
.36525 .15903 L
.37009 .08713 L
.37219 .06249 L
.37447 .04123 L
.37578 .03171 L
.37698 .02478 L
.37812 .01982 L
.37933 .01639 L
.38061 .01479 L
.38181 .01518 L
.38311 .0177 L
.38385 .02006 L
Mistroke
.38451 .0228 L
.38566 .02881 L
.38693 .03729 L
.38949 .06017 L
.39409 .11844 L
.40448 .30352 L
.4091 .39219 L
.41416 .47996 L
.41646 .51433 L
.41893 .54573 L
.42105 .56787 L
.42336 .58608 L
.42405 .59033 L
.42478 .59417 L
.42609 .5994 L
.42732 .60232 L
.42802 .60313 L
.42867 .60332 L
.42989 .60222 L
.43099 .59957 L
.43227 .59459 L
.43349 .58798 L
.43579 .57055 L
.43793 .54903 L
.44276 .48357 L
.45352 .28687 L
.4588 .18814 L
.46363 .11007 L
.468 .0566 L
.4702 .03737 L
.47145 .02899 L
.47261 .02289 L
.47387 .01816 L
.47506 .01553 L
.47613 .01472 L
.47729 .01548 L
.47855 .01828 L
.47919 .02045 L
.47989 .02343 L
.48113 .03019 L
.48229 .03821 L
.48495 .06249 L
.48748 .09258 L
.49222 .16446 L
.50289 .36473 L
.50784 .45447 L
.51249 .52504 L
.51507 .55577 L
.51643 .56912 L
.51786 .58095 L
Mistroke
.51907 .58905 L
.51971 .59262 L
.52039 .59589 L
.5216 .6002 L
.52272 .60257 L
.52395 .60331 L
.52509 .60227 L
.52634 .59922 L
.52697 .59694 L
.52767 .59384 L
.52883 .58731 L
.53008 .57846 L
.53235 .55783 L
.53693 .49982 L
.54112 .43138 L
.55029 .25747 L
.55532 .16579 L
.56007 .09352 L
.56277 .0614 L
.5642 .04759 L
.5657 .03549 L
.56697 .02738 L
.56764 .02387 L
.56836 .02073 L
.56962 .0168 L
.57081 .01496 L
.57209 .01499 L
.57281 .01594 L
.57348 .01741 L
.57471 .0216 L
.57602 .02813 L
.57719 .03571 L
.57828 .04431 L
.58078 .06901 L
.59923 .3856 L
.60428 .47437 L
.60706 .51598 L
.60969 .54895 L
.61213 .57322 L
.61342 .58328 L
.61479 .59177 L
.61593 .59714 L
.6172 .60114 L
.61835 .60301 L
.61943 .60323 L
.62066 .60166 L
.62136 .59991 L
.62201 .59773 L
.6232 .59238 L
.62446 .58475 L
Mistroke
.62688 .56493 L
.62907 .54134 L
.63441 .46475 L
.63943 .37492 L
.64969 .18081 L
.65485 .09965 L
.65779 .0638 L
.6591 .05066 L
.66052 .03857 L
.66187 .0293 L
.66313 .0227 L
.66432 .01823 L
.66559 .01545 L
.66673 .01472 L
.66779 .01552 L
.66896 .01807 L
.67022 .02274 L
.67148 .02941 L
.67286 .03891 L
.67564 .06476 L
.67821 .09602 L
.68061 .13063 L
.68947 .28952 L
.69908 .46725 L
.70174 .50816 L
.70456 .54477 L
.70696 .56964 L
.70834 .58101 L
.70961 .58942 L
.71088 .59591 L
.71208 .60022 L
.71335 .60277 L
.71407 .6033 L
.71474 .60319 L
.71596 .60153 L
.71707 .59838 L
.71834 .59284 L
.71954 .5858 L
.72181 .5678 L
.7242 .54257 L
.72848 .48344 L
.73813 .30829 L
.74764 .1357 L
.75038 .0958 L
.75297 .06441 L
.75529 .04228 L
.75659 .03259 L
.75782 .02535 L
.75888 .02057 L
.76002 .01699 L
Mistroke
.76128 .01496 L
.76244 .0149 L
.76365 .01665 L
.76496 .02067 L
.7662 .02646 L
.76735 .03353 L
.76959 .05173 L
.77162 .07309 L
.77616 .13562 L
.7863 .32038 L
.79184 .42472 L
.79701 .50864 L
.79928 .53862 L
.80143 .56232 L
.80261 .57325 L
.8039 .58331 L
.80507 .59069 L
.80616 .59611 L
.80736 .60034 L
.808 .60184 L
.80869 .60288 L
.80937 .60331 L
.81009 .60312 L
.81138 .60113 L
.81257 .5974 L
.81368 .59232 L
.8149 .58499 L
.81621 .57518 L
.8188 .54996 L
.82118 .52046 L
.82658 .43579 L
.83639 .25015 L
.84099 .16665 L
.84529 .10014 L
.84764 .07066 L
.84979 .04869 L
.85217 .03041 L
.85348 .02324 L
.85473 .01843 L
.85598 .01558 L
.85668 .01485 L
.85733 .01473 L
.85851 .01592 L
.85977 .01912 L
.86089 .02368 L
.86195 .02936 L
.86433 .0472 L
.86692 .0738 L
.86927 .10398 L
.87456 .18853 L
Mistroke
.88348 .35789 L
.88837 .44733 L
.89295 .51844 L
.89542 .54913 L
.89767 .57172 L
.89887 .58138 L
.90018 .58998 L
.9015 .59652 L
.90221 .59917 L
.90288 .60106 L
.90408 .60302 L
.90521 .6032 L
.90622 .60196 L
.90732 .59915 L
.90852 .59434 L
.90979 .58731 L
.91206 .56988 L
.91452 .54437 L
.91717 .51009 L
.92195 .43351 L
.93283 .22749 L
.93774 .14164 L
.94044 .10146 L
.94297 .06963 L
.94442 .05439 L
.94598 .04055 L
.94728 .03121 L
.94802 .02681 L
.94871 .02332 L
.94941 .02034 L
.95006 .01817 L
.95074 .01643 L
.95148 .01524 L
.95279 .01482 L
.95402 .01644 L
.95518 .01971 L
.95645 .02528 L
.95779 .03323 L
.95903 .04262 L
.96126 .06383 L
.96366 .09254 L
.97413 .26913 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`008?ooool2o`0002Wooooo0_l00004ooooo`04o`000?oooooooooooooo
o`Go00008oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol0000Tooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o0000:?ooool3o`0000Oooooo000Oooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool0000Rooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000008_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:?oo
ool00ol0003oooooooooo`06ooooo`007oooool01?l0003oooooooooool0000Wooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00007ooooo`Go
00008Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003ooooo
ooooo`06ooooo`007oooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0002;ooooo00Co0000oooooooooooo00001oooool4o`0002?ooooo00Co0000oooooooooooo0000
2?ooool3o`0002Wooooo00?o0000ooooooooool01_ooool001oooooo00Co0000oooooooooooo0000
9oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo000002;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00000Xooooo`03o`000?oooooooooo00Kooooo000Oooooo`04o`000?ooooooooooo`0002Oo
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002;ooooo00Co0000
oooooooooooo00002Oooool2o`0002;ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`0Sooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Woooo
o`;o00002?ooool0023ooooo0_l0000Yooooo`;o00002Oooool3o`0002Cooooo0_l0000;ooooo`03
o`000?oooooooooo027ooooo0_l0000:ooooo`;o00009?ooool2o`0000Wooooo0ol0000Yooooo`03
o`000?oooooooooo00Kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo000Koooooooo00001Ol00001ooooo`004oooool3o`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0ooooool1ooooo`7o00000Oooool000cooooo1Ol00003ooooo`03o`000?oooooooooo
00Cooooo0_l0000Gooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo01Gooooo0_l00?lGooooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool02?ooool2o`00007ooooo000Dooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05Oooool2o`00oaOooooo0_l00?lFooooo`;o003o5oooool2o`00oaOo
oooo0_l00?lGooooo`;o003o5_ooool2o`00oaOooooo0_l00?lGooooo`;o003o5_ooool2o`00o`_o
oooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo
0_l00?lFooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l05_ooool2o`00oaOooooo
0_l00?lFooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l05_ooool2o`00oaOooooo
0_l00?lFooooo`03o`00oooooooo003o00[ooooo0Ol00001ooooo`004oooool2o`0000Kooooo00?o
0000ooooooooool05?ooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Kooooo
00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo
00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Eooooo`04o`00ooooooooooooo`00oaGo
oooo00?o003oooooool00?l05_ooool00ol00?oooooo0000o`0:ooooo`7o00000Oooool001Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`04o`00ooooooooooooo`00oaGo
oooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Go
oooo00Co003ooooooooooooo003o5Oooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o
01Gooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lEooooo`03o`00oooo
ool0003o00[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Dooooo`04o`00oooooooo
ooooo`00oaGooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Eooooo`04o`00oooo
ooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool00ol00?ooooooo`00o`0Fooooo`03
o`00oooooooo003o01Gooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lE
ooooo`03o`00ooooool0003o00[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Doooo
o`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5?ooool01?l00?oooooooooo
ool00?lEooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool01?l0
0?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o
5Oooool01?l00?ooooooooooool00?lEooooo`030000ooooool0003o00[ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`0Dooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooo
oooo003o5?ooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaGooooo00Co
003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00
oaGooooo00Co003ooooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00D0
003ooooooooooooooooo0000o`09ooooo`7o00000Oooool001_ooooo0_l0000Eooooo`04o`00oooo
ooooooooo`00oaGooooo00Co003ooooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o
01Cooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lDooooo`05o`00oooo
ooooooooooooool00?l05?ooool01?l00?ooooooooooool00?lEooooo`05o`00oooooooooooooooo
ool00?l04oooool01Ol00?oooooooooooooooooo003o01Cooooo00D0003ooooooooooooooooo0000
o`08ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool05?ooool01?l00?ooooooooooool0
0?lDooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Co
oooo00Co003ooooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003o
ooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaGooooo00Go003ooooooooooooo
ooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l05?ooool01@000?ooooooooooooooool0
003o00Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Dooooo`04o`00oooooooooooo
o`00oaCooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l0
5?ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Doooo
o`05o`00ooooooooooooooooool00?l05?ooool01?l00?ooooooooooool00?lEooooo`05o`00oooo
ooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01Cooooo00D0003ooooooooo
oooooooo0000o`09ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool05?ooool01Ol00?oo
oooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00oooooooo
ooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l0
5?ooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05?ooool01@000?ooooooooooooooool0
003o00Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Dooooo`05o`00oooooooooooo
ooooool00?l04oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooooooooooo
o`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Aooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Dooooo`050000oooooooooooo
ooooo`000?l02Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01?ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05?ooool0
1Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo017ooooo00D0003ooooooooooooooooo0000o`09ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo
00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l04oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol0
0?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01@000?oooooooooooooo
ool0003o00Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01;ooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l0
4oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Aooooo`050000ooooooooooooooooo`000?l02Oooool1o`00007o
oooo000Kooooo`;o00005?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool0
0?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01@00
0?ooooooooooooooool0003o00Sooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Coooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aoooo
o`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`050000oooooooo
ooooooooo`000?l02Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00<0003o
ooooooooool00_ooool00`000?ooooooooooo`06ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04Oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00Kooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`030000oooooooooooo00?ooooo00<0003ooooooooo
ool01_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00<0003oooooooooool0
0oooool00`000?ooooooooooo`06ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04_oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?oo
ool00`000?ooooooooooo`03ooooo`030000oooooooooooo00Kooooo0Ol00001ooooo`006oooool2
o`0001?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo013ooooo00<0003oooooooooool00oooool00`000?ooooooooooo`05ooooo`;o00000Oooool0
01_ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo
00Kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`030000oooooooooooo00?o
oooo00<0003oooooooooool01_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01;ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00<0003oooooooooool00oooool00`000?ooooooooooo`06ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool04_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00Kooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0@ooooo`030000oooooooooooo00?ooooo00<0003o
ooooooooool01_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01;ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00<0003ooooo
ooooool01Oooool00`000?ooooooooooo`05ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool04_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03_ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00Gooooo0Ol00001ooooo`00
6oooool2o`0001?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00kooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`04ooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03_ooool00`000?ooooooooooo`05ooooo`030000oooo
oooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Booooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`030000oooooooo
oooo00Gooooo00<0003oooooooooool01Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`05ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00Go
oooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo
00?o0000ooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00Gooooo
0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`030000oooooooooooo00Gooooo00<0003ooooooooo
ool01Oooool1o`00007ooooo0005o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo00<0003oooooooooool01Oooool00`000?oo
ooooooooo`05ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`02ooooo`;o00004_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00Co
oooo0_l00001ooooo`001oooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool01Oooool1o`00007o
oooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool01Oooool1o`00007o
oooo0008ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool04Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00`000?oooooo
ooooo`05ooooo`030000oooooooooooo00Gooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool01Oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00gooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`04
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00`000?ooooooooooo`07oooo
o`030000oooooooooooo00Cooooo0Ol00001ooooo`006oooool2o`0001;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`030000oooooooooooo00cooooo00<0003ooooooooo
ool01oooool00`000?ooooooooooo`03ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00<0003oooooooooool0
3?ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00Cooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_oo
ool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool01?oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`06ooooo`030000oooooooooooo00cooooo00<0003oooooooooool01oooool0
0`000?ooooooooooo`04ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00<0003oooooooooool03?ooool00`00
0?ooooooooooo`07ooooo`030000oooooooooooo00Cooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00`000?oo
ooooooooo`0<ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool01?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`07ooooo`030000oooooooooooo00cooooo00<0003oooooooooool01oooool00`000?oooooo
ooooo`04ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Oooooo00<0003oooooooooool03?ooool00`000?oooooooooo
o`07ooooo`030000oooooooooooo00Cooooo0Ol00001ooooo`006oooool2o`0001;ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`07ooooo`030000oooooooooooo00cooooo00<0003o
ooooooooool01oooool00`000?ooooooooooo`03ooooo`;o00000Oooool001_ooooo00?o0000oooo
ooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00<0003ooooo
ooooool03?ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00Cooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00Oooooo00<0003ooooooooo
ool01?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`07ooooo`030000oooooooooooo00cooooo00<0003oooooooooool0
1oooool00`000?ooooooooooo`04ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00<0003oooooooooool02ooo
ool00`000?ooooooooooo`07ooooo`030000oooooooooooo00Cooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool0
0`000?ooooooooooo`0;ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool00oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`08ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool02?ooool00`00
0?ooooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00<0003oooooooooool02oooool00`000?oo
ooooooooo`08ooooo`030000oooooooooooo00?ooooo0Ol00001ooooo`006oooool2o`00017ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`030000oooooooooooo00_ooooo
00<0003oooooooooool02?ooool00`000?ooooooooooo`02ooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool04?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00<0
003oooooooooool02oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo00?ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool02?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Sooooo00<0003o
ooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo013ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`08ooooo`030000oooooooooooo00_ooooo00<0003ooooo
ooooool02?ooool00`000?ooooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool04?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00?ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
2?ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
0oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`08ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`03ooooo`7o00000Oooool001_ooooo0_l0000Aooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool00_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo
013ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`03ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00?o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo013ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`03ooooo`7o00000Oooool001Cooooo0_l00005
ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`03
ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0@
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool00oooool1o`00007ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00?ooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004
ooooo`Ko000000?o003oo`000?l000002_l000000ol00?oo0000o`000008o`000003o`00ool0003o
000000[o000000?o003oo`000?l000002Ol000000ol00?oo0000o`00000:o`000003o`00ool0003o
000000Wo000000?o003oo`000?l000002Ol000000ol00?oo0000o`00000:o`000003o`00ool0003o
000000Wo000000?o003oo`000?l000002Ol000000ol00?oo0000o`00000:o`000003o`00ool0003o
000000Wo000000?o003oo`000?l000002_l000000ol00?oo0000o`000009o`000003o`00ool0003o
000000Wo000000?o003oo`000?l000002_l000000ol00?oo0000o`000009o`000003o`00ool0003o
000000Wo000000<0003oo`000?l000002_l000000`000?oo0000o`000009o`0000030000ool0003o
000000Co00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool1o`00007ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00oooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00oooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool03oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0?ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_oo
ool00`000?ooooooooooo`08ooooo`030000oooooooooooo013ooooo0Ol00001ooooo`006oooool2
o`0000Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0?ooooo`;o00000Oooool0
01_ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00`000?ooooooooooo`08ooooo`030000oooooooooooo
013ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool04?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00<0003oooooooooool02?ooool00`000?ooooooooooo`0@ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo013ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`030000oooooooooooo00Sooooo00<0003o
ooooooooool04?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00<0003ooooo
ooooool02?ooool00`000?ooooooooooo`0@ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo013ooooo0Ol00001ooooo`00
6oooool2o`0000Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0?ooooo`;o0000
0Oooool001_ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02oooool00`000?ooooooooooo`08ooooo`030000oooo
oooooooo013ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`030000oooooooo
oooo00Sooooo00<0003oooooooooool04?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0@ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo013o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`030000oooooooooooo00Sooooo
00<0003oooooooooool04?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00<0
003oooooooooool02?ooool00`000?ooooooooooo`0@ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo013ooooo0Ol00001
ooooo`006oooool2o`0000Gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00_ooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`0?oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00`000?ooooooooooo`07ooooo`03
0000oooooooooooo017ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`030000
oooooooooooo00Kooooo00<0003oooooooooool04Oooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00gooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0Aooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03Oooool00`000?ooooooooooo`06ooooo`030000oooooooo
oooo017ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`030000oooooooooooo
00Kooooo00<0003oooooooooool04Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Co
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0Aooooo`7o00000Oooool001_ooooo
0_l00005ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool04?ooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00<0003oooooooooool01_ooool00`000?oooooooooo
o`0Aooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00`000?ooooooooooo`06
ooooo`030000oooooooooooo017ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=oooo
o`030000oooooooooooo00Kooooo00<0003oooooooooool04Oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00gooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`0Aooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00`000?ooooooooooo`06ooooo`030000
oooooooooooo017ooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03Oooool00`000?ooooooooooo`06ooooo`030000oooo
oooooooo017ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`030000oooooooooooo00Kooooo
00<0003oooooooooool04Oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool00_ooool2o`0000Kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00gooooo00<0003oooooooooool01_ooool00`000?oooooo
ooooo`0@ooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00gooooo00<0003oooooooooool01_ooool00`000?oooooo
ooooo`0Aooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo
00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03Oooool00`000?ooooooooooo`06ooooo`030000oooooooooooo017ooooo
0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo017ooooo
0Ol00001ooooo`002?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00<0
003oooooooooool01Oooool00`000?ooooooooooo`0Aooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03_ooool00`000?ooooooooooo`04ooooo`030000oooooooooooo01;ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`030000oooooooooooo00Cooooo00<0003ooooo
ooooool04_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00<0003ooooooooo
ool01?ooool00`000?ooooooooooo`0Booooo`7o00000Oooool001_ooooo0_l00006ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`030000
oooooooooooo00Cooooo00<0003oooooooooool04Oooool2o`00007ooooo000Kooooo`03o`000?oo
oooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`0Booooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03oooool00`000?ooooooooooo`04ooooo`030000oooooooo
oooo01;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`030000oooooooooooo
00Cooooo00<0003oooooooooool04_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013o
oooo00<0003oooooooooool00oooool00`000?ooooooooooo`0Booooo`7o00000Oooool001_ooooo
00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool04?ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo01;ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`030000oooooooooooo00?ooooo00<0
003oooooooooool04_ooool1o`00007ooooo000Kooooo`;o00001oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00`000?ooooooooooo`03
ooooo`030000oooooooooooo017ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`06oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`030000oooooooooooo00?ooooo00<0003oooooooooool04_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo013ooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0Booooo`7o
00000Oooool001_ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00`000?ooooooooooo`03ooooo`030000
oooooooooooo01;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`030000oooo
oooooooo00;ooooo00<0003oooooooooool04oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo013ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0Cooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01?ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Aooooo`030000oooooooooooo00;ooooo00<0003oooooooooool04oooool1
o`00007ooooo000Kooooo`;o00001oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01;ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05?ooool0
1Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Aooooo`030000oooooooooooo00;ooooo00<0003oooooooooool04oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00oooo
ooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?ooooo00<0003ooooooooo
ool00_ooool00`000?ooooooooooo`0Cooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003ooooooooooooo
ooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oo
oooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo017ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l0
4oooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01?ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`07ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooo
oooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05
o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooooooooooo
o`00o`0Cooooo`030000oooooooooooo00;ooooo00<0003oooooooooool04oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00
ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05?ooool0
1Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00
ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Cooooo00D0003ooooo
oooooooooooo0000o`0Eooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01oooool01Ol0
0?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`04o`00oooo
ooooooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00oooooooooooooooo
ool00?l05?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00
o`0Cooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Co
oooo00D0003ooooooooooooooooo0000o`0Eooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool01oooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo003o5Oooool0
1?l00?ooooooooooool00?lDooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooo
oooooooooooo003o01Cooooo00Co003ooooooooooooo003o5Oooool01Ol00?oooooooooooooooooo
003o01?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l0
5?ooool01@000?ooooooooooooooool0003o01Gooooo0Ol00001ooooo`006oooool2o`0000Sooooo
00Go003oooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooo
oooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooooooooooo
o`00o`0Dooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool01?l0
0?ooooooooooool00?lDooooo`05o`00ooooooooooooooooool00?l05?ooool01@000?oooooooooo
ooooool0003o01Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`00oooo
oooo003o01Gooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lEooooo`04
o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool0
0?lEooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5?ooool01Ol00?oo
oooooooooooooooo003o01Cooooo00D0003ooooooooooooooooo0000o`0Eooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`0Eooooo`04o`00oooooooooooo
o`00oaGooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lEooooo`03o`00
oooooooo003o01Gooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lEoooo
o`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5Oooool010000?oooooooooo
o`000?lFooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00
o`0Eooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool01?l00?oo
ooooooooool00?lEooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l05Oooool01?l0
0?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o
5Oooool010000?ooooooooooo`000?lFooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Gooooo00Co003ooooooooooooo
003o5Oooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Kooooo00?o003ooooo
ool00?l05Oooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Kooooo00?o003o
ooooool00?l05Oooool01?l00?ooooooooooo`000?lFooooo`7o00000Oooool001?ooooo0ol00005
ooooo`03o`000?oooooooooo00Sooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0E
ooooo`04o`00ooooooooooooo`00oaGooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00
o`0Fooooo`03o`00oooooooo003o01Gooooo00Co003ooooooooooooo003o5Oooool00ol00?oooooo
o`00o`0Fooooo`03o`00oooooooo003o01Kooooo00?o003oooooo`000?l05_ooool1o`00007ooooo
000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00
o`0Fooooo`03o`00oooooooo003o01Kooooo0_l00?lGooooo`;o003o5_ooool00ol00?ooooooo`00
o`0Fooooo`?o003o5_ooool2o`00oaOooooo0_l00?lFooooo`03o`00oooooooo003o01Kooooo0_l0
0?lGooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool2o`0000[ooooo0_l00?lG
ooooo`03o`00oooooooooooo01Gooooo0_l00?lGooooo`;o003o5oooool00ol00?ooooooooooo`0E
ooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`03o`00oooooooooooo01Gooooo0_l00?lF
ooooo`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
o`7ooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`004oooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00007ooooo
000Dooooo`03o`000?oooooooooo00Coooooool00005o`00007ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.135193, -1.23349, \
0.00404426, 0.0130873}}],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](t) == sin(20\ \[Pi]\ t)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled continuous-time waveform", "Subsubsection"],

Cell[BoxData[
    \(\(sampleRate = 1000;\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(signal\  = \ 
        Table[f1[t], {t, 0, 1, 1/\((sampleRate - 1)\)}]\  // \ N;\)\), "\n", 
    \(\(ListPlot[signal, \ PlotStyle \[Rule] Blue];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.309017 0.294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -12 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(200)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(400)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(600)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(800)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(-1)] -0.0125 .01471 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04414 m
.00375 .04414 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04414 m
1 .04414 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02476 .30902 m
.02571 .32751 L
.02667 .34594 L
.02762 .36422 L
.02857 .38228 L
.02952 .40005 L
.03048 .41746 L
.03143 .43444 L
.03238 .45093 L
.03333 .46685 L
.03429 .48215 L
.03524 .49677 L
.03619 .51064 L
.03714 .52372 L
.0381 .53595 L
.03905 .54728 L
.04 .55766 L
.04095 .56707 L
.0419 .57545 L
.04286 .58278 L
.04381 .58903 L
.04476 .59417 L
.04571 .59818 L
.04667 .60105 L
.04762 .60277 L
.04857 .60332 L
.04952 .60271 L
.05048 .60094 L
.05143 .59801 L
.05238 .59394 L
.05333 .58874 L
.05429 .58244 L
.05524 .57506 L
.05619 .56662 L
.05714 .55717 L
.0581 .54673 L
.05905 .53536 L
.06 .52308 L
.06095 .50997 L
.0619 .49606 L
.06286 .4814 L
.06381 .46607 L
.06476 .45012 L
.06571 .4336 L
.06667 .4166 L
.06762 .39917 L
.06857 .38138 L
.06952 .36331 L
.07048 .34502 L
.07143 .32659 L
Mistroke
.07238 .30809 L
.07333 .2896 L
.07429 .27118 L
.07524 .25291 L
.07619 .23486 L
.07714 .2171 L
.0781 .19971 L
.07905 .18276 L
.08 .1663 L
.08095 .1504 L
.0819 .13513 L
.08286 .12055 L
.08381 .10672 L
.08476 .09368 L
.08571 .0815 L
.08667 .07022 L
.08762 .05988 L
.08857 .05052 L
.08952 .04219 L
.09048 .03491 L
.09143 .02872 L
.09238 .02364 L
.09333 .01968 L
.09429 .01687 L
.09524 .01521 L
.09619 .01472 L
.09714 .01539 L
.0981 .01722 L
.09905 .0202 L
.1 .02433 L
.10095 .02958 L
.1019 .03594 L
.10286 .04337 L
.10381 .05186 L
.10476 .06137 L
.10571 .07185 L
.10667 .08327 L
.10762 .09559 L
.10857 .10874 L
.10952 .12269 L
.11048 .13738 L
.11143 .15275 L
.11238 .16873 L
.11333 .18527 L
.11429 .2023 L
.11524 .21975 L
.11619 .23755 L
.11714 .25563 L
.1181 .27393 L
.11905 .29237 L
Mistroke
.12 .31087 L
.12095 .32936 L
.1219 .34778 L
.12286 .36604 L
.12381 .38407 L
.12476 .40181 L
.12571 .41918 L
.12667 .43611 L
.12762 .45255 L
.12857 .46841 L
.12952 .48365 L
.13048 .49819 L
.13143 .51199 L
.13238 .52498 L
.13333 .53712 L
.13429 .54836 L
.13524 .55865 L
.13619 .56795 L
.13714 .57623 L
.1381 .58346 L
.13905 .58959 L
.14 .59462 L
.14095 .59852 L
.1419 .60128 L
.14286 .60287 L
.14381 .60331 L
.14476 .60258 L
.14571 .60069 L
.14667 .59765 L
.14762 .59347 L
.14857 .58816 L
.14952 .58175 L
.15048 .57426 L
.15143 .56572 L
.15238 .55617 L
.15333 .54564 L
.15429 .53417 L
.15524 .52181 L
.15619 .50861 L
.15714 .49462 L
.1581 .4799 L
.15905 .4645 L
.16 .44849 L
.16095 .43192 L
.1619 .41487 L
.16286 .39741 L
.16381 .37959 L
.16476 .36149 L
.16571 .34318 L
.16667 .32474 L
Mistroke
.16762 .30624 L
.16857 .28775 L
.16952 .26934 L
.17048 .25109 L
.17143 .23307 L
.17238 .21535 L
.17333 .198 L
.17429 .18109 L
.17524 .16468 L
.17619 .14884 L
.17714 .13364 L
.1781 .11914 L
.17905 .10538 L
.18 .09243 L
.18095 .08033 L
.1819 .06914 L
.18286 .0589 L
.18381 .04964 L
.18476 .04142 L
.18571 .03425 L
.18667 .02816 L
.18762 .02319 L
.18857 .01935 L
.18952 .01665 L
.19048 .01511 L
.19143 .01473 L
.19238 .01552 L
.19333 .01746 L
.19429 .02056 L
.19524 .0248 L
.19619 .03017 L
.19714 .03663 L
.1981 .04418 L
.19905 .05277 L
.2 .06237 L
.20095 .07295 L
.2019 .08446 L
.20286 .09686 L
.20381 .1101 L
.20476 .12413 L
.20571 .13889 L
.20667 .15432 L
.20762 .17036 L
.20857 .18695 L
.20952 .20402 L
.21048 .22151 L
.21143 .23935 L
.21238 .25746 L
.21333 .27577 L
.21429 .29422 L
Mistroke
.21524 .31272 L
.21619 .33121 L
.21714 .34961 L
.2181 .36785 L
.21905 .38586 L
.22 .40356 L
.22095 .42089 L
.2219 .43778 L
.22286 .45416 L
.22381 .46996 L
.22476 .48513 L
.22571 .49961 L
.22667 .51332 L
.22762 .52623 L
.22857 .53829 L
.22952 .54943 L
.23048 .55962 L
.23143 .56883 L
.23238 .577 L
.23333 .58412 L
.23429 .59015 L
.23524 .59506 L
.23619 .59885 L
.23714 .60149 L
.2381 .60297 L
.23905 .60329 L
.24 .60245 L
.24095 .60044 L
.2419 .59729 L
.24286 .59299 L
.24381 .58757 L
.24476 .58105 L
.24571 .57345 L
.24667 .56481 L
.24762 .55516 L
.24857 .54453 L
.24952 .53297 L
.25048 .52053 L
.25143 .50725 L
.25238 .49318 L
.25333 .47839 L
.25429 .46293 L
.25524 .44686 L
.25619 .43024 L
.25714 .41314 L
.2581 .39564 L
.25905 .37779 L
.26 .35967 L
.26095 .34134 L
.2619 .32289 L
Mistroke
.26286 .30439 L
.26381 .2859 L
.26476 .26751 L
.26571 .24928 L
.26667 .23128 L
.26762 .2136 L
.26857 .19629 L
.26952 .17942 L
.27048 .16307 L
.27143 .1473 L
.27238 .13216 L
.27333 .11772 L
.27429 .10405 L
.27524 .09118 L
.27619 .07917 L
.27714 .06807 L
.2781 .05793 L
.27905 .04877 L
.28 .04065 L
.28095 .03359 L
.2819 .02761 L
.28286 .02275 L
.28381 .01903 L
.28476 .01645 L
.28571 .01502 L
.28667 .01476 L
.28762 .01566 L
.28857 .01772 L
.28952 .02094 L
.29048 .02529 L
.29143 .03076 L
.29238 .03734 L
.29333 .04499 L
.29429 .05368 L
.29524 .06339 L
.29619 .07406 L
.29714 .08566 L
.2981 .09815 L
.29905 .11147 L
.3 .12557 L
.30095 .1404 L
.3019 .1559 L
.30286 .172 L
.30381 .18864 L
.30476 .20576 L
.30571 .22328 L
.30667 .24115 L
.30762 .25928 L
.30857 .27761 L
.30952 .29606 L
Mistroke
.31048 .31457 L
.31143 .33305 L
.31238 .35144 L
.31333 .36966 L
.31429 .38764 L
.31524 .40531 L
.31619 .4226 L
.31714 .43944 L
.3181 .45577 L
.31905 .47151 L
.32 .48661 L
.32095 .50101 L
.3219 .51465 L
.32286 .52748 L
.32381 .53944 L
.32476 .55049 L
.32571 .56059 L
.32667 .56969 L
.32762 .57776 L
.32857 .58477 L
.32952 .59069 L
.33048 .59549 L
.33143 .59916 L
.33238 .60169 L
.33333 .60305 L
.33429 .60326 L
.33524 .6023 L
.33619 .60018 L
.33714 .59691 L
.3381 .5925 L
.33905 .58697 L
.34 .58034 L
.34095 .57264 L
.3419 .56389 L
.34286 .55414 L
.34381 .54342 L
.34476 .53177 L
.34571 .51924 L
.34667 .50587 L
.34762 .49174 L
.34857 .47687 L
.34952 .46135 L
.35048 .44522 L
.35143 .42855 L
.35238 .41141 L
.35333 .39387 L
.35429 .37599 L
.35524 .35784 L
.35619 .3395 L
.35714 .32105 L
Mistroke
.3581 .30254 L
.35905 .28406 L
.36 .26568 L
.36095 .24747 L
.3619 .2295 L
.36286 .21185 L
.36381 .19458 L
.36476 .17776 L
.36571 .16147 L
.36667 .14575 L
.36762 .13068 L
.36857 .11632 L
.36952 .10272 L
.37048 .08994 L
.37143 .07802 L
.37238 .06701 L
.37333 .05697 L
.37429 .04791 L
.37524 .0399 L
.37619 .03294 L
.37714 .02708 L
.3781 .02233 L
.37905 .01872 L
.38 .01625 L
.38095 .01494 L
.3819 .0148 L
.38286 .01581 L
.38381 .01799 L
.38476 .02132 L
.38571 .02579 L
.38667 .03137 L
.38762 .03806 L
.38857 .04581 L
.38952 .05461 L
.39048 .06441 L
.39143 .07518 L
.39238 .08687 L
.39333 .09945 L
.39429 .11285 L
.39524 .12703 L
.39619 .14192 L
.39714 .15748 L
.3981 .17364 L
.39905 .19033 L
.4 .20749 L
.40095 .22505 L
.4019 .24295 L
.40286 .26111 L
.40381 .27945 L
.40476 .29791 L
Mistroke
.40571 .31642 L
.40667 .3349 L
.40762 .35327 L
.40857 .37147 L
.40952 .38943 L
.41048 .40706 L
.41143 .42431 L
.41238 .4411 L
.41333 .45737 L
.41429 .47305 L
.41524 .48809 L
.41619 .50241 L
.41714 .51597 L
.4181 .52871 L
.41905 .54059 L
.42 .55155 L
.42095 .56155 L
.4219 .57055 L
.42286 .57851 L
.42381 .58541 L
.42476 .59122 L
.42571 .59591 L
.42667 .59947 L
.42762 .60188 L
.42857 .60313 L
.42952 .60321 L
.43048 .60214 L
.43143 .5999 L
.43238 .59652 L
.43333 .59199 L
.43429 .58635 L
.43524 .57962 L
.43619 .57181 L
.43714 .56296 L
.4381 .55311 L
.43905 .54229 L
.44 .53055 L
.44095 .51794 L
.4419 .5045 L
.44286 .49028 L
.44381 .47535 L
.44476 .45976 L
.44571 .44357 L
.44667 .42686 L
.44762 .40967 L
.44857 .39209 L
.44952 .37418 L
.45048 .35602 L
.45143 .33766 L
.45238 .3192 L
Mistroke
.45333 .30069 L
.45429 .28221 L
.45524 .26385 L
.45619 .24566 L
.45714 .22772 L
.4581 .2101 L
.45905 .19287 L
.46 .17611 L
.46095 .15987 L
.4619 .14422 L
.46286 .12922 L
.46381 .11493 L
.46476 .10141 L
.46571 .0887 L
.46667 .07688 L
.46762 .06596 L
.46857 .05601 L
.46952 .04707 L
.47048 .03915 L
.47143 .03231 L
.47238 .02655 L
.47333 .02192 L
.47429 .01842 L
.47524 .01607 L
.47619 .01488 L
.47714 .01485 L
.4781 .01598 L
.47905 .01827 L
.48 .02172 L
.48095 .02629 L
.4819 .03199 L
.48286 .03878 L
.48381 .04664 L
.48476 .05554 L
.48571 .06544 L
.48667 .07631 L
.48762 .08809 L
.48857 .10075 L
.48952 .11423 L
.49048 .12848 L
.49143 .14345 L
.49238 .15907 L
.49333 .17528 L
.49429 .19203 L
.49524 .20923 L
.49619 .22683 L
.49714 .24475 L
.4981 .26293 L
.49905 .28129 L
.5 .29976 L
Mistroke
.50095 .31827 L
.5019 .33674 L
.50286 .3551 L
.50381 .37328 L
.50476 .3912 L
.50571 .4088 L
.50667 .42601 L
.50762 .44275 L
.50857 .45896 L
.50952 .47458 L
.51048 .48955 L
.51143 .5038 L
.51238 .51728 L
.51333 .52994 L
.51429 .54173 L
.51524 .55259 L
.51619 .56249 L
.51714 .57139 L
.5181 .57925 L
.51905 .58604 L
.52 .59174 L
.52095 .59632 L
.5219 .59976 L
.52286 .60205 L
.52381 .60319 L
.52476 .60316 L
.52571 .60197 L
.52667 .59962 L
.52762 .59612 L
.52857 .59148 L
.52952 .58573 L
.53048 .57888 L
.53143 .57097 L
.53238 .56202 L
.53333 .55207 L
.53429 .54116 L
.53524 .52933 L
.53619 .51663 L
.53714 .50311 L
.5381 .48882 L
.53905 .47382 L
.54 .45817 L
.54095 .44193 L
.5419 .42516 L
.54286 .40793 L
.54381 .39032 L
.54476 .37238 L
.54571 .35419 L
.54667 .33582 L
.54762 .31735 L
Mistroke
.54857 .29884 L
.54952 .28037 L
.55048 .26202 L
.55143 .24385 L
.55238 .22594 L
.55333 .20836 L
.55429 .19118 L
.55524 .17446 L
.55619 .15827 L
.55714 .14268 L
.5581 .12775 L
.55905 .11354 L
.56 .1001 L
.56095 .08748 L
.5619 .07574 L
.56286 .06493 L
.56381 .05507 L
.56476 .04623 L
.56571 .03842 L
.56667 .03168 L
.56762 .02604 L
.56857 .02152 L
.56952 .01813 L
.57048 .0159 L
.57143 .01482 L
.57238 .01491 L
.57333 .01616 L
.57429 .01857 L
.57524 .02212 L
.57619 .02681 L
.57714 .03262 L
.5781 .03952 L
.57905 .04749 L
.58 .05649 L
.58095 .06649 L
.5819 .07745 L
.58286 .08932 L
.58381 .10206 L
.58476 .11562 L
.58571 .12995 L
.58667 .14498 L
.58762 .16067 L
.58857 .17693 L
.58952 .19373 L
.59048 .21097 L
.59143 .22861 L
.59238 .24656 L
.59333 .26476 L
.59429 .28314 L
.59524 .30161 L
Mistroke
.59619 .32012 L
.59714 .33858 L
.5981 .35693 L
.59905 .37509 L
.6 .39298 L
.60095 .41054 L
.6019 .42771 L
.60286 .4444 L
.60381 .46055 L
.60476 .47611 L
.60571 .49101 L
.60667 .50519 L
.60762 .51859 L
.60857 .53116 L
.60952 .54285 L
.61048 .55362 L
.61143 .56343 L
.61238 .57222 L
.61333 .57998 L
.61429 .58666 L
.61524 .59225 L
.61619 .59671 L
.61714 .60004 L
.6181 .60222 L
.61905 .60324 L
.62 .60309 L
.62095 .60178 L
.6219 .59932 L
.62286 .5957 L
.62381 .59096 L
.62476 .58509 L
.62571 .57814 L
.62667 .57012 L
.62762 .56107 L
.62857 .55102 L
.62952 .54002 L
.63048 .5281 L
.63143 .51531 L
.63238 .50171 L
.63333 .48735 L
.63429 .47228 L
.63524 .45657 L
.63619 .44027 L
.63714 .42346 L
.6381 .40619 L
.63905 .38854 L
.64 .37057 L
.64095 .35236 L
.6419 .33398 L
.64286 .31549 L
Mistroke
.64381 .29699 L
.64476 .27853 L
.64571 .26019 L
.64667 .24205 L
.64762 .22417 L
.64857 .20662 L
.64952 .18948 L
.65048 .17282 L
.65143 .15669 L
.65238 .14116 L
.65333 .1263 L
.65429 .11216 L
.65524 .0988 L
.65619 .08627 L
.65714 .07462 L
.6581 .0639 L
.65905 .05414 L
.66 .0454 L
.66095 .0377 L
.6619 .03107 L
.66286 .02554 L
.66381 .02113 L
.66476 .01786 L
.66571 .01574 L
.66667 .01478 L
.66762 .01498 L
.66857 .01635 L
.66952 .01887 L
.67048 .02254 L
.67143 .02735 L
.67238 .03326 L
.67333 .04027 L
.67429 .04834 L
.67524 .05744 L
.67619 .06754 L
.67714 .07859 L
.6781 .09056 L
.67905 .10338 L
.68 .11702 L
.68095 .13142 L
.6819 .14652 L
.68286 .16227 L
.68381 .17859 L
.68476 .19543 L
.68571 .21272 L
.68667 .23039 L
.68762 .24837 L
.68857 .26659 L
.68952 .28498 L
.69048 .30346 L
Mistroke
.69143 .32197 L
.69238 .34042 L
.69333 .35875 L
.69429 .37689 L
.69524 .39475 L
.69619 .41228 L
.69714 .4294 L
.6981 .44604 L
.69905 .46214 L
.7 .47763 L
.70095 .49246 L
.7019 .50656 L
.70286 .51988 L
.70381 .53237 L
.70476 .54397 L
.70571 .55465 L
.70667 .56435 L
.70762 .57305 L
.70857 .58069 L
.70952 .58727 L
.71048 .59275 L
.71143 .5971 L
.71238 .60031 L
.71333 .60237 L
.71429 .60328 L
.71524 .60301 L
.71619 .60159 L
.71714 .59901 L
.7181 .59528 L
.71905 .59042 L
.72 .58445 L
.72095 .57738 L
.7219 .56926 L
.72286 .56011 L
.72381 .54996 L
.72476 .53886 L
.72571 .52686 L
.72667 .51399 L
.72762 .50031 L
.72857 .48587 L
.72952 .47074 L
.73048 .45496 L
.73143 .43861 L
.73238 .42175 L
.73333 .40444 L
.73429 .38675 L
.73524 .36876 L
.73619 .35053 L
.73714 .33213 L
.7381 .31364 L
Mistroke
.73905 .29514 L
.74 .27669 L
.74095 .25837 L
.7419 .24025 L
.74286 .2224 L
.74381 .20489 L
.74476 .18779 L
.74571 .17118 L
.74667 .15511 L
.74762 .13964 L
.74857 .12485 L
.74952 .11079 L
.75048 .09751 L
.75143 .08506 L
.75238 .0735 L
.75333 .06288 L
.75429 .05322 L
.75524 .04458 L
.75619 .03698 L
.75714 .03046 L
.7581 .02504 L
.75905 .02075 L
.76 .01759 L
.76095 .01559 L
.7619 .01474 L
.76286 .01506 L
.76381 .01655 L
.76476 .01919 L
.76571 .02297 L
.76667 .02789 L
.76762 .03392 L
.76857 .04103 L
.76952 .04921 L
.77048 .05841 L
.77143 .0686 L
.77238 .07975 L
.77333 .0918 L
.77429 .10471 L
.77524 .11843 L
.77619 .1329 L
.77714 .14807 L
.7781 .16387 L
.77905 .18025 L
.78 .19714 L
.78095 .21447 L
.7819 .23218 L
.78286 .25018 L
.78381 .26842 L
.78476 .28683 L
.78571 .30532 L
Mistroke
.78667 .32382 L
.78762 .34226 L
.78857 .36058 L
.78952 .37869 L
.79048 .39652 L
.79143 .41401 L
.79238 .43108 L
.79333 .44767 L
.79429 .46372 L
.79524 .47915 L
.79619 .4939 L
.79714 .50793 L
.7981 .52117 L
.79905 .53357 L
.8 .54508 L
.80095 .55566 L
.8019 .56527 L
.80286 .57386 L
.80381 .5814 L
.80476 .58787 L
.80571 .59323 L
.80667 .59747 L
.80762 .60057 L
.80857 .60252 L
.80952 .6033 L
.81048 .60292 L
.81143 .60138 L
.81238 .59869 L
.81333 .59484 L
.81429 .58987 L
.81524 .58379 L
.81619 .57662 L
.81714 .56839 L
.8181 .55914 L
.81905 .54889 L
.82 .5377 L
.82095 .52561 L
.8219 .51266 L
.82286 .4989 L
.82381 .48439 L
.82476 .46919 L
.82571 .45335 L
.82667 .43695 L
.82762 .42004 L
.82857 .40269 L
.82952 .38496 L
.83048 .36694 L
.83143 .34869 L
.83238 .33029 L
.83333 .31179 L
Mistroke
.83429 .29329 L
.83524 .27485 L
.83619 .25655 L
.83714 .23845 L
.8381 .22063 L
.83905 .20316 L
.84 .18611 L
.84095 .16954 L
.8419 .15353 L
.84286 .13813 L
.84381 .12341 L
.84476 .10942 L
.84571 .09622 L
.84667 .08387 L
.84762 .0724 L
.84857 .06187 L
.84952 .05231 L
.85048 .04377 L
.85143 .03628 L
.85238 .02987 L
.85333 .02456 L
.85429 .02038 L
.85524 .01734 L
.85619 .01545 L
.85714 .01472 L
.8581 .01516 L
.85905 .01676 L
.86 .01951 L
.86095 .02341 L
.8619 .02844 L
.86286 .03458 L
.86381 .0418 L
.86476 .05008 L
.86571 .05939 L
.86667 .06968 L
.86762 .08091 L
.86857 .09305 L
.86952 .10605 L
.87048 .11984 L
.87143 .13439 L
.87238 .14962 L
.87333 .16549 L
.87429 .18192 L
.87524 .19886 L
.87619 .21623 L
.87714 .23396 L
.8781 .252 L
.87905 .27026 L
.88 .28867 L
.88095 .30717 L
Mistroke
.8819 .32567 L
.88286 .3441 L
.88381 .3624 L
.88476 .38048 L
.88571 .39829 L
.88667 .41574 L
.88762 .43277 L
.88857 .4493 L
.88952 .46529 L
.89048 .48065 L
.89143 .49534 L
.89238 .50929 L
.89333 .52245 L
.89429 .53476 L
.89524 .54618 L
.89619 .55667 L
.89714 .56617 L
.8981 .57466 L
.89905 .5821 L
.9 .58845 L
.90095 .59371 L
.9019 .59783 L
.90286 .60082 L
.90381 .60265 L
.90476 .60332 L
.90571 .60282 L
.90667 .60116 L
.90762 .59835 L
.90857 .5944 L
.90952 .58931 L
.91048 .58312 L
.91143 .57584 L
.91238 .56751 L
.91333 .55816 L
.91429 .54782 L
.91524 .53653 L
.91619 .52435 L
.91714 .51132 L
.9181 .49748 L
.91905 .4829 L
.92 .46763 L
.92095 .45174 L
.9219 .43528 L
.92286 .41832 L
.92381 .40093 L
.92476 .38317 L
.92571 .36513 L
.92667 .34686 L
.92762 .32844 L
.92857 .30994 L
Mistroke
.92952 .29144 L
.93048 .27301 L
.93143 .25473 L
.93238 .23665 L
.93333 .21887 L
.93429 .20143 L
.93524 .18443 L
.93619 .16792 L
.93714 .15196 L
.9381 .13663 L
.93905 .12198 L
.94 .10807 L
.94095 .09495 L
.9419 .08268 L
.94286 .0713 L
.94381 .06087 L
.94476 .05141 L
.94571 .04298 L
.94667 .03559 L
.94762 .02929 L
.94857 .02409 L
.94952 .02003 L
.95048 .0171 L
.95143 .01533 L
.95238 .01472 L
.95333 .01527 L
.95429 .01698 L
.95524 .01985 L
.95619 .02386 L
.95714 .029 L
.9581 .03525 L
.95905 .04258 L
.96 .05097 L
.96095 .06037 L
.9619 .07076 L
.96286 .08209 L
.96381 .09432 L
.96476 .10739 L
.96571 .12126 L
.96667 .13588 L
.96762 .15118 L
.96857 .16711 L
.96952 .18359 L
.97048 .20057 L
.97143 .21798 L
.97238 .23576 L
.97333 .25382 L
.97429 .27209 L
.97524 .29052 L
.97619 .30902 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0002Kooooo1Ol0
0003ooooo`;o00001?ooool2o`0002;ooooo0ol00003ooooo`;o00001?ooool2o`0002;ooooo0ol0
0004ooooo`;o00001?ooool2o`00027ooooo0ol00004ooooo`;o00001?ooool2o`0001oooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`007oooool01?l0003oooooooooool0
000Vooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00007oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Oooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo000Oooooo`04o`000?ooooooooooo`0002Oooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Oooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool001oooooo
00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Pooooo`Co00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo0ol00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`007oooool01?l0003oooooooooool0000Uooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00007oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`007oooool01?l0003ooooo
ooooool0000Uooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`00027ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00007oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Nooooo`;o00001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool0023ooooo0_l0000Wooooo`?o00001?ooool2o`0000Cooooo0_l0000Sooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`;o00008oooool2o`0000Cooooo0_l00004ooooo`;o00008Oooool3
o`0000Cooooo0_l00004ooooo`;o00008?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`006oooool00ol0000000000000003k00000003o`000?oooooooooo00Cooooo000Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`0300000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`0300000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool001?ooooo0ol00005ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03
00000?oooooooooo02kooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0^ooooo`03
00000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool001Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3kooooo`03o`000?oooooooooo00Cooooo000<ooooo`Go00000ooo
ool00ol0003oooooooooo`04ooooo`;o00005_ooool00ol00?ooooooooooo`0Eooooo`;o003o5_oo
ool2o`00oaKooooo0_l00?lFooooo`;o003o5oooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo01Gooooo0_l00?lFooooo`;o003o5_ooool2o`00o`Wooooo0ol00006ooooo`005?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo0ol00?lFooooo`;o003o5_ooool2
o`00oaKooooo0_l00?lFooooo`;o003o5_ooool2o`00oaKooooo00?o003oooooool00?l05_ooool2
o`00oaKooooo0_l00?lFooooo`;o003o2oooool00ol0003oooooooooo`04ooooo`005?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o003oooooool00?l05Oooool00ol0
0?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo0_l00?lFooooo`03o`00oooooooo003o
01Gooooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o
01Kooooo0_l00?lEooooo`03o`00oooooooo003o00_ooooo00?o0000ooooooooool01?ooool001?o
oooo0_l00006ooooo`03o`000?oooooooooo01Cooooo00?o003oooooool00?l05Oooool00ol00?oo
ooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00Co003ooooooooooooo003o5Oooool00ol0
0?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l05Oooool00ol0
0?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l02oooool00ol0
003oooooooooo`04ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Co
oooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Eooooo`04o`00ooooooooooooo`00
oaCooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lEooooo`03o`00oooo
oooo003o01Gooooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Eooooo`03o`00oooo
oooo003o01Gooooo00Co003ooooooooooooo003o2_ooool00ol0003oooooooooo`04ooooo`006ooo
ool00ol0003oooooooooo`0Dooooo`04o`00ooooooooooooo`00oaCooooo00?o003oooooool00?l0
5Oooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooo
oooooooo003o5Oooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00Co003o
oooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00o`[o
oooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool05?ooool01?l00?oooooo
ooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5?ooool0
1?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo
003o5?ooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaCooooo00Co003o
oooooooooooo003o5?ooool01?l00?ooooooooooool00?l:ooooo`03o`000?oooooooooo00Cooooo
000Kooooo`;o00005?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo
003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003o
oooooooooooo003o5?ooool01?l00?ooooooooooool00?lDooooo`05o`00ooooooooooooooooool0
0?l05?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003o
oooooooooooo003o2Oooool2o`0000Kooooo000Kooooo`03o`000?oooooooooo01?ooooo00Go003o
ooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo
003o5?ooool01?l00?ooooooooooool00?lDooooo`05o`00ooooooooooooooooool00?l04oooool0
1Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00
ooooooooooooooooool00?l05?ooool01?l00?ooooooooooool00?lDooooo`04o`00oooooooooooo
o`00o`[ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool04oooool01Ol0
0?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`04o`00oooo
ooooooooo`00oaCooooo00Co003ooooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o
01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04ooo
ool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`04
o`00ooooooooooooo`00o`[ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000oooooooo
ool04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0D
ooooo`04o`00ooooooooooooo`00oa?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Aooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01?o
oooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool0
1Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo003o2_ooool00ol0003ooooo
ooooo`04ooooo`006oooool00ol0003oooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l0
4oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Coooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo
003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l0
4oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Coooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`04oooo
o`006oooool00ol0003oooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol0
0?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooo
oooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool0
0?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0C
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`04
ooooo`006oooool00ol0003oooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l04oooool0
1Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00
ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool01oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003ooooo
ooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05
o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`04ooooo`006oooool2o`0001Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`;o00001_ooool001_ooooo
00?o0000ooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool04_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000
ooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o0000
ooooooooool01?ooool001_ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00Oooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000oooooooo
ool04_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o0000oooooooo
ool01?ooool001_ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Oooooo00?o0000ooooooooool01?ooool001_ooooo0_l0000Cooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01_ooool2o`0000Kooooo000Kooooo`03o`000?oooooo
oooo01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooo
oooo00Cooooo000Kooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`06ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo01;o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Co
oooo000Kooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo01;ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Cooooo000K
ooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo01;ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Cooooo000Kooooo`;o
00004_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Gooooo0_l00006ooooo`00
6oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1_ooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0Aooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`04ooooo`006oooool0
0ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01_ooool0
0ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`04ooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool04Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01?ooool000Oooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool01?ooool000Go00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo
00;ooooo0_l0000Booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool01?ooool3o`00
00Kooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
003oooooooooo`04ooooo`001oooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0
003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0
003oooooooooo`04ooooo`001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Gooooo00?o0000ooooooooool01?ooool000Sooooo0_l00008ooooo`Go00001?ooool00ol0003o
ooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`006oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01Oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003ooooooooo
o`0Aooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`006oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`006oooool2o`0001;ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`04ooooo`;o00001_ooool001_ooooo00?o0000oooooooo
ool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o0000oooooooo
ool01?ooool001_ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00Gooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool04Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool01?oo
ool001_ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00Gooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool01?ooool001_o
oooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Go
oooo00?o0000ooooooooool01?ooool001_ooooo0_l0000Aooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01?ooool2o`0000Kooooo000Kooooo`03o`000?oooooooooo013ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00Cooooo000K
ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo013ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03
o`000?oooooooooo013ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oo
oooooooo013ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo000Kooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000Kooooo`;o00004Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00?ooooo0_l00006ooooo`006oooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`04ooooo`006oooool00ol0003ooooooooo
o`0@ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0@oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`04oooo
o`006oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`006oooool2o`00017ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`03ooooo`;o00001_ooool001_ooooo00?o0000ooooooooool03ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool01?oo
ool001_ooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Cooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool03oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool01?ooool001_o
oooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Co
oooo00?o0000ooooooooool01?ooool001Cooooo0_l00005ooooo`03o`000?oooooooooo00oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool01?ooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool00oooool00ol0003oooooooooo`04ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`Ko000000?o003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00
ool0003o000000Wo000000?o003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00
ool0003o000000Wo000000?o003oo`000?l000002_l000000ol00?oo0000o`000009o`000003o`00
ool0003o000000Wo000000?o003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00
ool0003o000000Wo000000?o003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00
ool0003o000000Wo000000?o003oo`000?l000002Ol000000ol00?oo0000o`000009o`000003o`00
ool0003o000000Wo000000?o003oo`000?l000002Ol000000ol00?oo0000o`00000:o`000003o`00
ool0003o000000Co00001_ooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04?ooool00ol0003ooooo
ooooo`04ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo
000Dooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04?ooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`04
ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool04?ooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`04ooooo`00
6oooool2o`0000Cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0?ooooo`;o0000
1_ooool001_ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo013ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool01?ooool0
01_ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
013ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool01?ooool001_ooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool01?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000
ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00?o0000
ooooooooool01?ooool001_ooooo0_l00005ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool03oooool2o`0000Kooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`00
0?oooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`00
0?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooo
oooo00Cooooo000Kooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00Co
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo00Co
oooo000Kooooo`;o00001Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo013ooooo
0_l00006ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool04Oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`04
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`04
ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool04Oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`04ooooo`00
6oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
4Oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`04ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`04ooooo`006oooool0
0ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04Oooool0
0ol0003oooooooooo`04ooooo`006oooool2o`0000Kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0@ooooo`;o00001_ooool001_ooooo00?o0000ooooooooool01Oooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool01?ooool001_ooooo
00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo017ooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool01Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000
ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo017ooooo00?o0000
ooooooooool01?ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005oooo
o`03o`000?oooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Boooo
o`03o`000?oooooooooo00Cooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00Cooooo0007ooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0@ooooo`?o00001_ooool000Oooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00Cooooo0007ooooo`04o`000?oooooooooo
o`0000Oooooo1?l00005ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00Cooooo0007ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`002?ooool2o`00
00Sooooo1Ol00004ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Booooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00Co
oooo000Kooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0Booooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00Cooooo000K
ooooo`;o00001_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo017ooooo0_l00006
ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool04_ooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`06ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`00
6oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
4_ooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`006oooool0
0ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04_ooool0
0ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`006oooool2o`0000Oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`;o00001_ooool001_ooooo
00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool01_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000
ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o0000
ooooooooool01?ooool001_ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo01?ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000oooooooo
ool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01?ooooo00?o0000oooooooo
ool01?ooool001_ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01?ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool01ooo
ool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool01?ooool001_ooooo0_l0
0008ooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01?o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04_ooool2o`0000Kooooo000Kooooo`03o`000?oooooooooo00Oooooo
00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003ooooooooo
ooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0C
ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00Oooooo00Go003ooooo
ooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00
ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo00Co
oooo000Kooooo`03o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`0Cooooo`05
o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00oooooooooooo
ooooool00?l04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooo
oooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Cooooo`03
o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00Oooooo00Go003ooooooooooooo
ooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo
003o01?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l0
4oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Coooo
o`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo000K
ooooo`03o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00oooo
ooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003ooooooooo
ooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooo
oooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool0
0?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0F
ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00Oooooo00Go003ooooo
ooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooo
oooooooo003o01Cooooo00Co003ooooooooooooo003o5?ooool01?l00?ooooooooooool00?lDoooo
o`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go
003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oo
oooooooooooooooo003o01Kooooo00?o0000ooooooooool01?ooool001_ooooo0_l00008ooooo`05
o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003o
ooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo
003o5?ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0C
ooooo`05o`00ooooooooooooooooool00?l04oooool01Ol00?oooooooooooooooooo003o01Cooooo
00Co003ooooooooooooo003o5Oooool2o`0000Kooooo000Kooooo`03o`000?oooooooooo00Oooooo
00Go003oooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l05?ooool01?l0
0?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o
5?ooool01?l00?ooooooooooool00?lDooooo`05o`00ooooooooooooooooool00?l04oooool01Ol0
0?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0Dooooo`04o`00oooo
ooooooooo`00oaKooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool02?oo
ool00ol00?ooooooo`00o`0Eooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo
003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003o
oooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo
003o5?ooool01?l00?ooooooooooool00?lDooooo`04o`00ooooooooooooo`00oaKooooo00?o0000
ooooooooool01?ooool001_ooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`0Eoooo
o`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5?ooool01?l00?oooooooooo
ool00?lDooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5Oooool00ol0
0?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Gooooo00Co003ooooooooooooo003o5?ooool0
1?l00?ooooooooooool00?lFooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooo
oooo00Sooooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Eooooo`04o`00oooooooo
ooooo`00oaCooooo00Co003ooooooooooooo003o5Oooool00ol00?ooooooo`00o`0Dooooo`04o`00
ooooooooooooo`00oaGooooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Eooooo`03
o`00oooooooo003o01Gooooo00Co003ooooooooooooo003o5_ooool00ol0003oooooooooo`04oooo
o`004oooool3o`0000Gooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`0Eooooo`03
o`00oooooooo003o01Gooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Eooooo`03
o`00oooooooo003o01Gooooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Eooooo`03
o`00oooooooo003o01Gooooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Gooooo`03
o`000?oooooooooo00Cooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2?ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo0_l00?lFooooo`;o003o
5_ooool2o`00oaKooooo00?o003oooooool00?l05Oooool00ol00?ooooooo`00o`0Eooooo`03o`00
oooooooo003o01Gooooo00?o003oooooool00?l05_ooool2o`00oaOooooo00?o0000ooooooooool0
1?ooool001Cooooo00?o0000ooooooooool01?ooool2o`0000[ooooo00?o003oooooooooool05Ooo
ool2o`00oaKooooo0_l00?lFooooo`;o003o5_ooool2o`00oaKooooo0_l00?lFooooo`;o003o5ooo
ool00ol00?ooooooooooo`0Eooooo`;o003o5_ooool2o`00oaGooooo0ol00006ooooo`005?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?_ooooo00?o0000ooooooooool01?ooool0
01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3kooooo`03o`000?oooooooooo
00Cooooo000Cooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo000Dooooo`03o`000?oooooooooo00Coooooool00006ooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-137.394, -1.26045, 4.136, \
0.0133844}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete spectrum: Fast Fourier Transform (FFT)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ Fourier[signal];\)\), "\n", 
    \(\(g1 = 
        DiscreteListPlot[FourierRearrange[Abs[fft], sampleRate], Red, 
          PlotRange \[Rule] All, \ Frame \[Rule] True];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499523 0.000953334 0.0147151 0.00117799 [
[.11819 -0.0125 -12 -9 ]
[.11819 -0.0125 12 0 ]
[.30886 -0.0125 -12 -9 ]
[.30886 -0.0125 12 0 ]
[.49952 -0.0125 -3 -9 ]
[.49952 -0.0125 3 0 ]
[.69019 -0.0125 -9 -9 ]
[.69019 -0.0125 9 0 ]
[.88086 -0.0125 -9 -9 ]
[.88086 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13251 -18 -4.5 ]
[-0.0125 .13251 0 4.5 ]
[-0.0125 .25031 -18 -4.5 ]
[-0.0125 .25031 0 4.5 ]
[-0.0125 .36811 -18 -4.5 ]
[-0.0125 .36811 0 4.5 ]
[-0.0125 .48591 -18 -4.5 ]
[-0.0125 .48591 0 4.5 ]
[-0.0125 .60371 -18 -4.5 ]
[-0.0125 .60371 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11819 0 m
.11819 .00625 L
s
[(-400)] .11819 -0.0125 0 1 Mshowa
.30886 0 m
.30886 .00625 L
s
[(-200)] .30886 -0.0125 0 1 Mshowa
.49952 0 m
.49952 .00625 L
s
[(0)] .49952 -0.0125 0 1 Mshowa
.69019 0 m
.69019 .00625 L
s
[(200)] .69019 -0.0125 0 1 Mshowa
.88086 0 m
.88086 .00625 L
s
[(400)] .88086 -0.0125 0 1 Mshowa
.125 Mabswid
.16586 0 m
.16586 .00375 L
s
.21352 0 m
.21352 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.40419 0 m
.40419 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.59486 0 m
.59486 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.78552 0 m
.78552 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.07052 0 m
.07052 .00375 L
s
.02286 0 m
.02286 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13251 m
.00625 .13251 L
s
[(100)] -0.0125 .13251 1 0 Mshowa
0 .25031 m
.00625 .25031 L
s
[(200)] -0.0125 .25031 1 0 Mshowa
0 .36811 m
.00625 .36811 L
s
[(300)] -0.0125 .36811 1 0 Mshowa
0 .48591 m
.00625 .48591 L
s
[(400)] -0.0125 .48591 1 0 Mshowa
0 .60371 m
.00625 .60371 L
s
[(500)] -0.0125 .60371 1 0 Mshowa
.125 Mabswid
0 .03827 m
.00375 .03827 L
s
0 .06183 m
.00375 .06183 L
s
0 .08539 m
.00375 .08539 L
s
0 .10895 m
.00375 .10895 L
s
0 .15607 m
.00375 .15607 L
s
0 .17963 m
.00375 .17963 L
s
0 .20319 m
.00375 .20319 L
s
0 .22675 m
.00375 .22675 L
s
0 .27387 m
.00375 .27387 L
s
0 .29743 m
.00375 .29743 L
s
0 .32099 m
.00375 .32099 L
s
0 .34455 m
.00375 .34455 L
s
0 .39167 m
.00375 .39167 L
s
0 .41523 m
.00375 .41523 L
s
0 .43879 m
.00375 .43879 L
s
0 .46235 m
.00375 .46235 L
s
0 .50947 m
.00375 .50947 L
s
0 .53303 m
.00375 .53303 L
s
0 .55659 m
.00375 .55659 L
s
0 .58015 m
.00375 .58015 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11819 .61178 m
.11819 .61803 L
s
.30886 .61178 m
.30886 .61803 L
s
.49952 .61178 m
.49952 .61803 L
s
.69019 .61178 m
.69019 .61803 L
s
.88086 .61178 m
.88086 .61803 L
s
.125 Mabswid
.16586 .61428 m
.16586 .61803 L
s
.21352 .61428 m
.21352 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.40419 .61428 m
.40419 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.59486 .61428 m
.59486 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.78552 .61428 m
.78552 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.07052 .61428 m
.07052 .61803 L
s
.02286 .61428 m
.02286 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13251 m
1 .13251 L
s
.99375 .25031 m
1 .25031 L
s
.99375 .36811 m
1 .36811 L
s
.99375 .48591 m
1 .48591 L
s
.99375 .60371 m
1 .60371 L
s
.125 Mabswid
.99625 .03827 m
1 .03827 L
s
.99625 .06183 m
1 .06183 L
s
.99625 .08539 m
1 .08539 L
s
.99625 .10895 m
1 .10895 L
s
.99625 .15607 m
1 .15607 L
s
.99625 .17963 m
1 .17963 L
s
.99625 .20319 m
1 .20319 L
s
.99625 .22675 m
1 .22675 L
s
.99625 .27387 m
1 .27387 L
s
.99625 .29743 m
1 .29743 L
s
.99625 .32099 m
1 .32099 L
s
.99625 .34455 m
1 .34455 L
s
.99625 .39167 m
1 .39167 L
s
.99625 .41523 m
1 .41523 L
s
.99625 .43879 m
1 .43879 L
s
.99625 .46235 m
1 .46235 L
s
.99625 .50947 m
1 .50947 L
s
.99625 .53303 m
1 .53303 L
s
.99625 .55659 m
1 .55659 L
s
.99625 .58015 m
1 .58015 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01475 L
s
.02476 .01472 m
.02476 .01475 L
s
.02572 .01472 m
.02572 .01475 L
s
.02667 .01472 m
.02667 .01475 L
s
.02762 .01472 m
.02762 .01475 L
s
.02858 .01472 m
.02858 .01475 L
s
.02953 .01472 m
.02953 .01475 L
s
.03048 .01472 m
.03048 .01475 L
s
.03144 .01472 m
.03144 .01475 L
s
.03239 .01472 m
.03239 .01475 L
s
.03334 .01472 m
.03334 .01475 L
s
.0343 .01472 m
.0343 .01475 L
s
.03525 .01472 m
.03525 .01475 L
s
.0362 .01472 m
.0362 .01475 L
s
.03716 .01472 m
.03716 .01475 L
s
.03811 .01472 m
.03811 .01475 L
s
.03906 .01472 m
.03906 .01475 L
s
.04002 .01472 m
.04002 .01475 L
s
.04097 .01472 m
.04097 .01475 L
s
.04192 .01472 m
.04192 .01475 L
s
.04288 .01472 m
.04288 .01475 L
s
.04383 .01472 m
.04383 .01475 L
s
.04478 .01472 m
.04478 .01475 L
s
.04574 .01472 m
.04574 .01475 L
s
.04669 .01472 m
.04669 .01475 L
s
.04764 .01472 m
.04764 .01475 L
s
.0486 .01472 m
.0486 .01475 L
s
.04955 .01472 m
.04955 .01475 L
s
.0505 .01472 m
.0505 .01475 L
s
.05146 .01472 m
.05146 .01475 L
s
.05241 .01472 m
.05241 .01475 L
s
.05336 .01472 m
.05336 .01475 L
s
.05432 .01472 m
.05432 .01475 L
s
.05527 .01472 m
.05527 .01475 L
s
.05622 .01472 m
.05622 .01475 L
s
.05718 .01472 m
.05718 .01475 L
s
.05813 .01472 m
.05813 .01475 L
s
.05908 .01472 m
.05908 .01475 L
s
.06004 .01472 m
.06004 .01475 L
s
.06099 .01472 m
.06099 .01475 L
s
.06194 .01472 m
.06194 .01475 L
s
.0629 .01472 m
.0629 .01475 L
s
.06385 .01472 m
.06385 .01475 L
s
.0648 .01472 m
.0648 .01475 L
s
.06576 .01472 m
.06576 .01475 L
s
.06671 .01472 m
.06671 .01475 L
s
.06766 .01472 m
.06766 .01475 L
s
.06862 .01472 m
.06862 .01475 L
s
.06957 .01472 m
.06957 .01475 L
s
.07052 .01472 m
.07052 .01475 L
s
.07148 .01472 m
.07148 .01475 L
s
.07243 .01472 m
.07243 .01475 L
s
.07338 .01472 m
.07338 .01475 L
s
.07434 .01472 m
.07434 .01475 L
s
.07529 .01472 m
.07529 .01475 L
s
.07624 .01472 m
.07624 .01475 L
s
.0772 .01472 m
.0772 .01475 L
s
.07815 .01472 m
.07815 .01475 L
s
.0791 .01472 m
.0791 .01475 L
s
.08006 .01472 m
.08006 .01475 L
s
.08101 .01472 m
.08101 .01475 L
s
.08196 .01472 m
.08196 .01475 L
s
.08292 .01472 m
.08292 .01475 L
s
.08387 .01472 m
.08387 .01475 L
s
.08482 .01472 m
.08482 .01475 L
s
.08578 .01472 m
.08578 .01475 L
s
.08673 .01472 m
.08673 .01475 L
s
.08768 .01472 m
.08768 .01475 L
s
.08864 .01472 m
.08864 .01475 L
s
.08959 .01472 m
.08959 .01475 L
s
.09054 .01472 m
.09054 .01475 L
s
.0915 .01472 m
.0915 .01475 L
s
.09245 .01472 m
.09245 .01475 L
s
.0934 .01472 m
.0934 .01475 L
s
.09436 .01472 m
.09436 .01475 L
s
.09531 .01472 m
.09531 .01475 L
s
.09626 .01472 m
.09626 .01475 L
s
.09722 .01472 m
.09722 .01475 L
s
.09817 .01472 m
.09817 .01475 L
s
.09912 .01472 m
.09912 .01475 L
s
.10008 .01472 m
.10008 .01475 L
s
.10103 .01472 m
.10103 .01475 L
s
.10198 .01472 m
.10198 .01475 L
s
.10294 .01472 m
.10294 .01475 L
s
.10389 .01472 m
.10389 .01475 L
s
.10484 .01472 m
.10484 .01475 L
s
.1058 .01472 m
.1058 .01475 L
s
.10675 .01472 m
.10675 .01475 L
s
.1077 .01472 m
.1077 .01475 L
s
.10866 .01472 m
.10866 .01475 L
s
.10961 .01472 m
.10961 .01475 L
s
.11056 .01472 m
.11056 .01475 L
s
.11152 .01472 m
.11152 .01475 L
s
.11247 .01472 m
.11247 .01475 L
s
.11342 .01472 m
.11342 .01475 L
s
.11438 .01472 m
.11438 .01475 L
s
.11533 .01472 m
.11533 .01475 L
s
.11628 .01472 m
.11628 .01475 L
s
.11724 .01472 m
.11724 .01475 L
s
.11819 .01472 m
.11819 .01475 L
s
.11914 .01472 m
.11914 .01475 L
s
.1201 .01472 m
.1201 .01475 L
s
.12105 .01472 m
.12105 .01475 L
s
.122 .01472 m
.122 .01475 L
s
.12296 .01472 m
.12296 .01475 L
s
.12391 .01472 m
.12391 .01475 L
s
.12486 .01472 m
.12486 .01475 L
s
.12582 .01472 m
.12582 .01475 L
s
.12677 .01472 m
.12677 .01475 L
s
.12772 .01472 m
.12772 .01475 L
s
.12868 .01472 m
.12868 .01475 L
s
.12963 .01472 m
.12963 .01475 L
s
.13058 .01472 m
.13058 .01475 L
s
.13154 .01472 m
.13154 .01475 L
s
.13249 .01472 m
.13249 .01475 L
s
.13344 .01472 m
.13344 .01475 L
s
.1344 .01472 m
.1344 .01475 L
s
.13535 .01472 m
.13535 .01475 L
s
.1363 .01472 m
.1363 .01475 L
s
.13726 .01472 m
.13726 .01475 L
s
.13821 .01472 m
.13821 .01476 L
s
.13916 .01472 m
.13916 .01476 L
s
.14012 .01472 m
.14012 .01476 L
s
.14107 .01472 m
.14107 .01476 L
s
.14202 .01472 m
.14202 .01476 L
s
.14298 .01472 m
.14298 .01476 L
s
.14393 .01472 m
.14393 .01476 L
s
.14488 .01472 m
.14488 .01476 L
s
.14584 .01472 m
.14584 .01476 L
s
.14679 .01472 m
.14679 .01476 L
s
.14774 .01472 m
.14774 .01476 L
s
.1487 .01472 m
.1487 .01476 L
s
.14965 .01472 m
.14965 .01476 L
s
.1506 .01472 m
.1506 .01476 L
s
.15156 .01472 m
.15156 .01476 L
s
.15251 .01472 m
.15251 .01476 L
s
.15346 .01472 m
.15346 .01476 L
s
.15442 .01472 m
.15442 .01476 L
s
.15537 .01472 m
.15537 .01476 L
s
.15632 .01472 m
.15632 .01476 L
s
.15728 .01472 m
.15728 .01476 L
s
.15823 .01472 m
.15823 .01476 L
s
.15918 .01472 m
.15918 .01476 L
s
.16014 .01472 m
.16014 .01476 L
s
.16109 .01472 m
.16109 .01476 L
s
.16204 .01472 m
.16204 .01476 L
s
.163 .01472 m
.163 .01476 L
s
.16395 .01472 m
.16395 .01476 L
s
.1649 .01472 m
.1649 .01476 L
s
.16586 .01472 m
.16586 .01476 L
s
.16681 .01472 m
.16681 .01476 L
s
.16776 .01472 m
.16776 .01476 L
s
.16872 .01472 m
.16872 .01476 L
s
.16967 .01472 m
.16967 .01476 L
s
.17062 .01472 m
.17062 .01476 L
s
.17158 .01472 m
.17158 .01476 L
s
.17253 .01472 m
.17253 .01476 L
s
.17348 .01472 m
.17348 .01476 L
s
.17444 .01472 m
.17444 .01476 L
s
.17539 .01472 m
.17539 .01476 L
s
.17634 .01472 m
.17634 .01476 L
s
.1773 .01472 m
.1773 .01476 L
s
.17825 .01472 m
.17825 .01476 L
s
.1792 .01472 m
.1792 .01476 L
s
.18016 .01472 m
.18016 .01476 L
s
.18111 .01472 m
.18111 .01476 L
s
.18206 .01472 m
.18206 .01476 L
s
.18302 .01472 m
.18302 .01476 L
s
.18397 .01472 m
.18397 .01476 L
s
.18492 .01472 m
.18492 .01476 L
s
.18588 .01472 m
.18588 .01476 L
s
.18683 .01472 m
.18683 .01476 L
s
.18778 .01472 m
.18778 .01476 L
s
.18874 .01472 m
.18874 .01476 L
s
.18969 .01472 m
.18969 .01476 L
s
.19064 .01472 m
.19064 .01476 L
s
.1916 .01472 m
.1916 .01476 L
s
.19255 .01472 m
.19255 .01476 L
s
.1935 .01472 m
.1935 .01476 L
s
.19446 .01472 m
.19446 .01476 L
s
.19541 .01472 m
.19541 .01476 L
s
.19636 .01472 m
.19636 .01476 L
s
.19732 .01472 m
.19732 .01476 L
s
.19827 .01472 m
.19827 .01476 L
s
.19922 .01472 m
.19922 .01476 L
s
.20018 .01472 m
.20018 .01476 L
s
.20113 .01472 m
.20113 .01476 L
s
.20208 .01472 m
.20208 .01476 L
s
.20304 .01472 m
.20304 .01476 L
s
.20399 .01472 m
.20399 .01476 L
s
.20494 .01472 m
.20494 .01476 L
s
.2059 .01472 m
.2059 .01476 L
s
.20685 .01472 m
.20685 .01476 L
s
.2078 .01472 m
.2078 .01476 L
s
.20876 .01472 m
.20876 .01476 L
s
.20971 .01472 m
.20971 .01476 L
s
.21066 .01472 m
.21066 .01476 L
s
.21162 .01472 m
.21162 .01476 L
s
.21257 .01472 m
.21257 .01476 L
s
.21352 .01472 m
.21352 .01476 L
s
.21448 .01472 m
.21448 .01476 L
s
.21543 .01472 m
.21543 .01476 L
s
.21638 .01472 m
.21638 .01476 L
s
.21734 .01472 m
.21734 .01476 L
s
.21829 .01472 m
.21829 .01476 L
s
.21924 .01472 m
.21924 .01476 L
s
.2202 .01472 m
.2202 .01476 L
s
.22115 .01472 m
.22115 .01476 L
s
.2221 .01472 m
.2221 .01476 L
s
.22306 .01472 m
.22306 .01476 L
s
.22401 .01472 m
.22401 .01476 L
s
.22496 .01472 m
.22496 .01476 L
s
.22592 .01472 m
.22592 .01476 L
s
.22687 .01472 m
.22687 .01476 L
s
.22782 .01472 m
.22782 .01476 L
s
.22878 .01472 m
.22878 .01476 L
s
.22973 .01472 m
.22973 .01476 L
s
.23068 .01472 m
.23068 .01476 L
s
.23164 .01472 m
.23164 .01476 L
s
.23259 .01472 m
.23259 .01476 L
s
.23354 .01472 m
.23354 .01476 L
s
.2345 .01472 m
.2345 .01476 L
s
.23545 .01472 m
.23545 .01476 L
s
.2364 .01472 m
.2364 .01476 L
s
.23736 .01472 m
.23736 .01476 L
s
.23831 .01472 m
.23831 .01476 L
s
.23926 .01472 m
.23926 .01476 L
s
.24022 .01472 m
.24022 .01476 L
s
.24117 .01472 m
.24117 .01476 L
s
.24212 .01472 m
.24212 .01476 L
s
.24308 .01472 m
.24308 .01476 L
s
.24403 .01472 m
.24403 .01476 L
s
.24498 .01472 m
.24498 .01476 L
s
.24594 .01472 m
.24594 .01477 L
s
.24689 .01472 m
.24689 .01477 L
s
.24784 .01472 m
.24784 .01477 L
s
.2488 .01472 m
.2488 .01477 L
s
.24975 .01472 m
.24975 .01477 L
s
.2507 .01472 m
.2507 .01477 L
s
.25166 .01472 m
.25166 .01477 L
s
.25261 .01472 m
.25261 .01477 L
s
.25356 .01472 m
.25356 .01477 L
s
.25452 .01472 m
.25452 .01477 L
s
.25547 .01472 m
.25547 .01477 L
s
.25642 .01472 m
.25642 .01477 L
s
.25738 .01472 m
.25738 .01477 L
s
.25833 .01472 m
.25833 .01477 L
s
.25928 .01472 m
.25928 .01477 L
s
.26024 .01472 m
.26024 .01477 L
s
.26119 .01472 m
.26119 .01477 L
s
.26214 .01472 m
.26214 .01477 L
s
.2631 .01472 m
.2631 .01477 L
s
.26405 .01472 m
.26405 .01477 L
s
.265 .01472 m
.265 .01477 L
s
.26596 .01472 m
.26596 .01477 L
s
.26691 .01472 m
.26691 .01477 L
s
.26786 .01472 m
.26786 .01477 L
s
.26882 .01472 m
.26882 .01477 L
s
.26977 .01472 m
.26977 .01477 L
s
.27072 .01472 m
.27072 .01477 L
s
.27168 .01472 m
.27168 .01477 L
s
.27263 .01472 m
.27263 .01477 L
s
.27358 .01472 m
.27358 .01477 L
s
.27454 .01472 m
.27454 .01477 L
s
.27549 .01472 m
.27549 .01477 L
s
.27644 .01472 m
.27644 .01477 L
s
.2774 .01472 m
.2774 .01477 L
s
.27835 .01472 m
.27835 .01477 L
s
.2793 .01472 m
.2793 .01477 L
s
.28026 .01472 m
.28026 .01477 L
s
.28121 .01472 m
.28121 .01477 L
s
.28216 .01472 m
.28216 .01477 L
s
.28312 .01472 m
.28312 .01477 L
s
.28407 .01472 m
.28407 .01477 L
s
.28502 .01472 m
.28502 .01477 L
s
.28598 .01472 m
.28598 .01477 L
s
.28693 .01472 m
.28693 .01477 L
s
.28788 .01472 m
.28788 .01477 L
s
.28884 .01472 m
.28884 .01477 L
s
.28979 .01472 m
.28979 .01477 L
s
.29074 .01472 m
.29074 .01477 L
s
.2917 .01472 m
.2917 .01477 L
s
.29265 .01472 m
.29265 .01477 L
s
.2936 .01472 m
.2936 .01477 L
s
.29456 .01472 m
.29456 .01477 L
s
.29551 .01472 m
.29551 .01477 L
s
.29646 .01472 m
.29646 .01477 L
s
.29742 .01472 m
.29742 .01478 L
s
.29837 .01472 m
.29837 .01478 L
s
.29932 .01472 m
.29932 .01478 L
s
.30028 .01472 m
.30028 .01478 L
s
.30123 .01472 m
.30123 .01478 L
s
.30218 .01472 m
.30218 .01478 L
s
.30314 .01472 m
.30314 .01478 L
s
.30409 .01472 m
.30409 .01478 L
s
.30504 .01472 m
.30504 .01478 L
s
.306 .01472 m
.306 .01478 L
s
.30695 .01472 m
.30695 .01478 L
s
.3079 .01472 m
.3079 .01478 L
s
.30886 .01472 m
.30886 .01478 L
s
.30981 .01472 m
.30981 .01478 L
s
.31076 .01472 m
.31076 .01478 L
s
.31172 .01472 m
.31172 .01478 L
s
.31267 .01472 m
.31267 .01478 L
s
.31362 .01472 m
.31362 .01478 L
s
.31458 .01472 m
.31458 .01478 L
s
.31553 .01472 m
.31553 .01478 L
s
.31648 .01472 m
.31648 .01478 L
s
.31744 .01472 m
.31744 .01478 L
s
.31839 .01472 m
.31839 .01478 L
s
.31934 .01472 m
.31934 .01478 L
s
.3203 .01472 m
.3203 .01478 L
s
.32125 .01472 m
.32125 .01478 L
s
.3222 .01472 m
.3222 .01478 L
s
.32316 .01472 m
.32316 .01478 L
s
.32411 .01472 m
.32411 .01478 L
s
.32506 .01472 m
.32506 .01478 L
s
.32602 .01472 m
.32602 .01478 L
s
.32697 .01472 m
.32697 .01478 L
s
.32792 .01472 m
.32792 .01478 L
s
.32888 .01472 m
.32888 .01478 L
s
.32983 .01472 m
.32983 .01479 L
s
.33078 .01472 m
.33078 .01479 L
s
.33174 .01472 m
.33174 .01479 L
s
.33269 .01472 m
.33269 .01479 L
s
.33364 .01472 m
.33364 .01479 L
s
.3346 .01472 m
.3346 .01479 L
s
.33555 .01472 m
.33555 .01479 L
s
.3365 .01472 m
.3365 .01479 L
s
.33746 .01472 m
.33746 .01479 L
s
.33841 .01472 m
.33841 .01479 L
s
.33936 .01472 m
.33936 .01479 L
s
.34032 .01472 m
.34032 .01479 L
s
.34127 .01472 m
.34127 .01479 L
s
.34222 .01472 m
.34222 .01479 L
s
.34318 .01472 m
.34318 .01479 L
s
.34413 .01472 m
.34413 .01479 L
s
.34508 .01472 m
.34508 .01479 L
s
.34604 .01472 m
.34604 .01479 L
s
.34699 .01472 m
.34699 .01479 L
s
.34794 .01472 m
.34794 .01479 L
s
.3489 .01472 m
.3489 .01479 L
s
.34985 .01472 m
.34985 .01479 L
s
.3508 .01472 m
.3508 .01479 L
s
.35176 .01472 m
.35176 .01479 L
s
.35271 .01472 m
.35271 .0148 L
s
.35366 .01472 m
.35366 .0148 L
s
.35462 .01472 m
.35462 .0148 L
s
.35557 .01472 m
.35557 .0148 L
s
.35652 .01472 m
.35652 .0148 L
s
.35748 .01472 m
.35748 .0148 L
s
.35843 .01472 m
.35843 .0148 L
s
.35938 .01472 m
.35938 .0148 L
s
.36034 .01472 m
.36034 .0148 L
s
.36129 .01472 m
.36129 .0148 L
s
.36224 .01472 m
.36224 .0148 L
s
.3632 .01472 m
.3632 .0148 L
s
.36415 .01472 m
.36415 .0148 L
s
.3651 .01472 m
.3651 .0148 L
s
.36606 .01472 m
.36606 .0148 L
s
.36701 .01472 m
.36701 .0148 L
s
.36796 .01472 m
.36796 .0148 L
s
.36892 .01472 m
.36892 .0148 L
s
.36987 .01472 m
.36987 .0148 L
s
.37082 .01472 m
.37082 .01481 L
s
.37178 .01472 m
.37178 .01481 L
s
.37273 .01472 m
.37273 .01481 L
s
.37368 .01472 m
.37368 .01481 L
s
.37464 .01472 m
.37464 .01481 L
s
.37559 .01472 m
.37559 .01481 L
s
.37654 .01472 m
.37654 .01481 L
s
.3775 .01472 m
.3775 .01481 L
s
.37845 .01472 m
.37845 .01481 L
s
.3794 .01472 m
.3794 .01481 L
s
.38036 .01472 m
.38036 .01481 L
s
.38131 .01472 m
.38131 .01481 L
s
.38226 .01472 m
.38226 .01481 L
s
.38322 .01472 m
.38322 .01481 L
s
.38417 .01472 m
.38417 .01482 L
s
.38512 .01472 m
.38512 .01482 L
s
.38608 .01472 m
.38608 .01482 L
s
.38703 .01472 m
.38703 .01482 L
s
.38798 .01472 m
.38798 .01482 L
s
.38894 .01472 m
.38894 .01482 L
s
.38989 .01472 m
.38989 .01482 L
s
.39084 .01472 m
.39084 .01482 L
s
.3918 .01472 m
.3918 .01482 L
s
.39275 .01472 m
.39275 .01482 L
s
.3937 .01472 m
.3937 .01482 L
s
.39466 .01472 m
.39466 .01483 L
s
.39561 .01472 m
.39561 .01483 L
s
.39656 .01472 m
.39656 .01483 L
s
.39752 .01472 m
.39752 .01483 L
s
.39847 .01472 m
.39847 .01483 L
s
.39942 .01472 m
.39942 .01483 L
s
.40038 .01472 m
.40038 .01483 L
s
.40133 .01472 m
.40133 .01483 L
s
.40228 .01472 m
.40228 .01483 L
s
.40324 .01472 m
.40324 .01483 L
s
.40419 .01472 m
.40419 .01484 L
s
.40514 .01472 m
.40514 .01484 L
s
.4061 .01472 m
.4061 .01484 L
s
.40705 .01472 m
.40705 .01484 L
s
.408 .01472 m
.408 .01484 L
s
.40896 .01472 m
.40896 .01484 L
s
.40991 .01472 m
.40991 .01484 L
s
.41086 .01472 m
.41086 .01485 L
s
.41182 .01472 m
.41182 .01485 L
s
.41277 .01472 m
.41277 .01485 L
s
.41372 .01472 m
.41372 .01485 L
s
.41468 .01472 m
.41468 .01485 L
s
.41563 .01472 m
.41563 .01485 L
s
.41658 .01472 m
.41658 .01485 L
s
.41754 .01472 m
.41754 .01486 L
s
.41849 .01472 m
.41849 .01486 L
s
.41944 .01472 m
.41944 .01486 L
s
.4204 .01472 m
.4204 .01486 L
s
.42135 .01472 m
.42135 .01486 L
s
.4223 .01472 m
.4223 .01486 L
s
.42326 .01472 m
.42326 .01487 L
s
.42421 .01472 m
.42421 .01487 L
s
.42516 .01472 m
.42516 .01487 L
s
.42612 .01472 m
.42612 .01487 L
s
.42707 .01472 m
.42707 .01487 L
s
.42802 .01472 m
.42802 .01488 L
s
.42898 .01472 m
.42898 .01488 L
s
.42993 .01472 m
.42993 .01488 L
s
.43088 .01472 m
.43088 .01488 L
s
.43184 .01472 m
.43184 .01489 L
s
.43279 .01472 m
.43279 .01489 L
s
.43374 .01472 m
.43374 .01489 L
s
.4347 .01472 m
.4347 .01489 L
s
.43565 .01472 m
.43565 .0149 L
s
.4366 .01472 m
.4366 .0149 L
s
.43756 .01472 m
.43756 .0149 L
s
.43851 .01472 m
.43851 .01491 L
s
.43946 .01472 m
.43946 .01491 L
s
.44042 .01472 m
.44042 .01491 L
s
.44137 .01472 m
.44137 .01491 L
s
.44232 .01472 m
.44232 .01492 L
s
.44328 .01472 m
.44328 .01492 L
s
.44423 .01472 m
.44423 .01493 L
s
.44518 .01472 m
.44518 .01493 L
s
.44614 .01472 m
.44614 .01493 L
s
.44709 .01472 m
.44709 .01494 L
s
.44804 .01472 m
.44804 .01494 L
s
.449 .01472 m
.449 .01495 L
s
.44995 .01472 m
.44995 .01495 L
s
.4509 .01472 m
.4509 .01496 L
s
.45186 .01472 m
.45186 .01496 L
s
.45281 .01472 m
.45281 .01497 L
s
.45376 .01472 m
.45376 .01497 L
s
.45472 .01472 m
.45472 .01498 L
s
.45567 .01472 m
.45567 .01499 L
s
.45662 .01472 m
.45662 .01499 L
s
.45758 .01472 m
.45758 .015 L
s
.45853 .01472 m
.45853 .01501 L
s
.45948 .01472 m
.45948 .01501 L
s
.46044 .01472 m
.46044 .01502 L
s
.46139 .01472 m
.46139 .01503 L
s
.46234 .01472 m
.46234 .01504 L
s
.4633 .01472 m
.4633 .01505 L
s
.46425 .01472 m
.46425 .01506 L
s
.4652 .01472 m
.4652 .01507 L
s
.46616 .01472 m
.46616 .01508 L
s
.46711 .01472 m
.46711 .0151 L
s
.46806 .01472 m
.46806 .01511 L
s
.46902 .01472 m
.46902 .01512 L
s
.46997 .01472 m
.46997 .01514 L
s
.47092 .01472 m
.47092 .01516 L
s
.47188 .01472 m
.47188 .01518 L
s
.47283 .01472 m
.47283 .0152 L
s
.47378 .01472 m
.47378 .01522 L
s
.47474 .01472 m
.47474 .01525 L
s
.47569 .01472 m
.47569 .01528 L
s
.47664 .01472 m
.47664 .01531 L
s
.4776 .01472 m
.4776 .01535 L
s
.47855 .01472 m
.47855 .01539 L
s
.4795 .01472 m
.4795 .01544 L
s
.48046 .01472 m
.48046 .0155 L
s
.48141 .01472 m
.48141 .01557 L
s
.48236 .01472 m
.48236 .01566 L
s
.48332 .01472 m
.48332 .01578 L
s
.48427 .01472 m
.48427 .01593 L
s
.48522 .01472 m
.48522 .01613 L
s
.48618 .01472 m
.48618 .01644 L
s
.48713 .01472 m
.48713 .01694 L
s
.48808 .01472 m
.48808 .01795 L
s
.48904 .01472 m
.48904 .02095 L
s
.48999 .01472 m
.48999 .60332 L
s
.49094 .01472 m
.49094 .02024 L
s
.4919 .01472 m
.4919 .01732 L
s
.49285 .01472 m
.49285 .01633 L
s
.4938 .01472 m
.4938 .01582 L
s
.49476 .01472 m
.49476 .0155 L
s
.49571 .01472 m
.49571 .01528 L
s
.49666 .01472 m
.49666 .0151 L
s
.49762 .01472 m
.49762 .01496 L
s
.49857 .01472 m
.49857 .01483 L
s
.49952 .01472 m
.49952 .01472 L
s
.50048 .01472 m
.50048 .01483 L
s
.50143 .01472 m
.50143 .01496 L
s
.50238 .01472 m
.50238 .0151 L
s
.50334 .01472 m
.50334 .01528 L
s
.50429 .01472 m
.50429 .0155 L
s
.50524 .01472 m
.50524 .01582 L
s
.5062 .01472 m
.5062 .01633 L
s
.50715 .01472 m
.50715 .01732 L
s
.5081 .01472 m
.5081 .02024 L
s
.50906 .01472 m
.50906 .60332 L
s
.51001 .01472 m
.51001 .02095 L
s
.51096 .01472 m
.51096 .01795 L
s
.51192 .01472 m
.51192 .01694 L
s
.51287 .01472 m
.51287 .01644 L
s
.51382 .01472 m
.51382 .01613 L
s
.51478 .01472 m
.51478 .01593 L
s
.51573 .01472 m
.51573 .01578 L
s
.51668 .01472 m
.51668 .01566 L
s
.51764 .01472 m
.51764 .01557 L
s
.51859 .01472 m
.51859 .0155 L
s
.51954 .01472 m
.51954 .01544 L
s
.5205 .01472 m
.5205 .01539 L
s
.52145 .01472 m
.52145 .01535 L
s
.5224 .01472 m
.5224 .01531 L
s
.52336 .01472 m
.52336 .01528 L
s
.52431 .01472 m
.52431 .01525 L
s
.52526 .01472 m
.52526 .01522 L
s
.52622 .01472 m
.52622 .0152 L
s
.52717 .01472 m
.52717 .01518 L
s
.52812 .01472 m
.52812 .01516 L
s
.52908 .01472 m
.52908 .01514 L
s
.53003 .01472 m
.53003 .01512 L
s
.53098 .01472 m
.53098 .01511 L
s
.53194 .01472 m
.53194 .0151 L
s
.53289 .01472 m
.53289 .01508 L
s
.53384 .01472 m
.53384 .01507 L
s
.5348 .01472 m
.5348 .01506 L
s
.53575 .01472 m
.53575 .01505 L
s
.5367 .01472 m
.5367 .01504 L
s
.53766 .01472 m
.53766 .01503 L
s
.53861 .01472 m
.53861 .01502 L
s
.53956 .01472 m
.53956 .01501 L
s
.54052 .01472 m
.54052 .01501 L
s
.54147 .01472 m
.54147 .015 L
s
.54242 .01472 m
.54242 .01499 L
s
.54338 .01472 m
.54338 .01499 L
s
.54433 .01472 m
.54433 .01498 L
s
.54528 .01472 m
.54528 .01497 L
s
.54624 .01472 m
.54624 .01497 L
s
.54719 .01472 m
.54719 .01496 L
s
.54814 .01472 m
.54814 .01496 L
s
.5491 .01472 m
.5491 .01495 L
s
.55005 .01472 m
.55005 .01495 L
s
.551 .01472 m
.551 .01494 L
s
.55196 .01472 m
.55196 .01494 L
s
.55291 .01472 m
.55291 .01493 L
s
.55386 .01472 m
.55386 .01493 L
s
.55482 .01472 m
.55482 .01493 L
s
.55577 .01472 m
.55577 .01492 L
s
.55672 .01472 m
.55672 .01492 L
s
.55768 .01472 m
.55768 .01491 L
s
.55863 .01472 m
.55863 .01491 L
s
.55958 .01472 m
.55958 .01491 L
s
.56054 .01472 m
.56054 .01491 L
s
.56149 .01472 m
.56149 .0149 L
s
.56244 .01472 m
.56244 .0149 L
s
.5634 .01472 m
.5634 .0149 L
s
.56435 .01472 m
.56435 .01489 L
s
.5653 .01472 m
.5653 .01489 L
s
.56626 .01472 m
.56626 .01489 L
s
.56721 .01472 m
.56721 .01489 L
s
.56816 .01472 m
.56816 .01488 L
s
.56912 .01472 m
.56912 .01488 L
s
.57007 .01472 m
.57007 .01488 L
s
.57102 .01472 m
.57102 .01488 L
s
.57198 .01472 m
.57198 .01487 L
s
.57293 .01472 m
.57293 .01487 L
s
.57388 .01472 m
.57388 .01487 L
s
.57484 .01472 m
.57484 .01487 L
s
.57579 .01472 m
.57579 .01487 L
s
.57674 .01472 m
.57674 .01486 L
s
.5777 .01472 m
.5777 .01486 L
s
.57865 .01472 m
.57865 .01486 L
s
.5796 .01472 m
.5796 .01486 L
s
.58056 .01472 m
.58056 .01486 L
s
.58151 .01472 m
.58151 .01486 L
s
.58246 .01472 m
.58246 .01485 L
s
.58342 .01472 m
.58342 .01485 L
s
.58437 .01472 m
.58437 .01485 L
s
.58532 .01472 m
.58532 .01485 L
s
.58628 .01472 m
.58628 .01485 L
s
.58723 .01472 m
.58723 .01485 L
s
.58818 .01472 m
.58818 .01485 L
s
.58914 .01472 m
.58914 .01484 L
s
.59009 .01472 m
.59009 .01484 L
s
.59104 .01472 m
.59104 .01484 L
s
.592 .01472 m
.592 .01484 L
s
.59295 .01472 m
.59295 .01484 L
s
.5939 .01472 m
.5939 .01484 L
s
.59486 .01472 m
.59486 .01484 L
s
.59581 .01472 m
.59581 .01483 L
s
.59676 .01472 m
.59676 .01483 L
s
.59772 .01472 m
.59772 .01483 L
s
.59867 .01472 m
.59867 .01483 L
s
.59962 .01472 m
.59962 .01483 L
s
.60058 .01472 m
.60058 .01483 L
s
.60153 .01472 m
.60153 .01483 L
s
.60248 .01472 m
.60248 .01483 L
s
.60344 .01472 m
.60344 .01483 L
s
.60439 .01472 m
.60439 .01483 L
s
.60534 .01472 m
.60534 .01482 L
s
.6063 .01472 m
.6063 .01482 L
s
.60725 .01472 m
.60725 .01482 L
s
.6082 .01472 m
.6082 .01482 L
s
.60916 .01472 m
.60916 .01482 L
s
.61011 .01472 m
.61011 .01482 L
s
.61106 .01472 m
.61106 .01482 L
s
.61202 .01472 m
.61202 .01482 L
s
.61297 .01472 m
.61297 .01482 L
s
.61392 .01472 m
.61392 .01482 L
s
.61488 .01472 m
.61488 .01482 L
s
.61583 .01472 m
.61583 .01481 L
s
.61678 .01472 m
.61678 .01481 L
s
.61774 .01472 m
.61774 .01481 L
s
.61869 .01472 m
.61869 .01481 L
s
.61964 .01472 m
.61964 .01481 L
s
.6206 .01472 m
.6206 .01481 L
s
.62155 .01472 m
.62155 .01481 L
s
.6225 .01472 m
.6225 .01481 L
s
.62346 .01472 m
.62346 .01481 L
s
.62441 .01472 m
.62441 .01481 L
s
.62536 .01472 m
.62536 .01481 L
s
.62632 .01472 m
.62632 .01481 L
s
.62727 .01472 m
.62727 .01481 L
s
.62822 .01472 m
.62822 .01481 L
s
.62918 .01472 m
.62918 .0148 L
s
.63013 .01472 m
.63013 .0148 L
s
.63108 .01472 m
.63108 .0148 L
s
.63204 .01472 m
.63204 .0148 L
s
.63299 .01472 m
.63299 .0148 L
s
.63394 .01472 m
.63394 .0148 L
s
.6349 .01472 m
.6349 .0148 L
s
.63585 .01472 m
.63585 .0148 L
s
.6368 .01472 m
.6368 .0148 L
s
.63776 .01472 m
.63776 .0148 L
s
.63871 .01472 m
.63871 .0148 L
s
.63966 .01472 m
.63966 .0148 L
s
.64062 .01472 m
.64062 .0148 L
s
.64157 .01472 m
.64157 .0148 L
s
.64252 .01472 m
.64252 .0148 L
s
.64348 .01472 m
.64348 .0148 L
s
.64443 .01472 m
.64443 .0148 L
s
.64538 .01472 m
.64538 .0148 L
s
.64634 .01472 m
.64634 .0148 L
s
.64729 .01472 m
.64729 .01479 L
s
.64824 .01472 m
.64824 .01479 L
s
.6492 .01472 m
.6492 .01479 L
s
.65015 .01472 m
.65015 .01479 L
s
.6511 .01472 m
.6511 .01479 L
s
.65206 .01472 m
.65206 .01479 L
s
.65301 .01472 m
.65301 .01479 L
s
.65396 .01472 m
.65396 .01479 L
s
.65492 .01472 m
.65492 .01479 L
s
.65587 .01472 m
.65587 .01479 L
s
.65682 .01472 m
.65682 .01479 L
s
.65778 .01472 m
.65778 .01479 L
s
.65873 .01472 m
.65873 .01479 L
s
.65968 .01472 m
.65968 .01479 L
s
.66064 .01472 m
.66064 .01479 L
s
.66159 .01472 m
.66159 .01479 L
s
.66254 .01472 m
.66254 .01479 L
s
.6635 .01472 m
.6635 .01479 L
s
.66445 .01472 m
.66445 .01479 L
s
.6654 .01472 m
.6654 .01479 L
s
.66636 .01472 m
.66636 .01479 L
s
.66731 .01472 m
.66731 .01479 L
s
.66826 .01472 m
.66826 .01479 L
s
.66922 .01472 m
.66922 .01479 L
s
.67017 .01472 m
.67017 .01478 L
s
.67112 .01472 m
.67112 .01478 L
s
.67208 .01472 m
.67208 .01478 L
s
.67303 .01472 m
.67303 .01478 L
s
.67398 .01472 m
.67398 .01478 L
s
.67494 .01472 m
.67494 .01478 L
s
.67589 .01472 m
.67589 .01478 L
s
.67684 .01472 m
.67684 .01478 L
s
.6778 .01472 m
.6778 .01478 L
s
.67875 .01472 m
.67875 .01478 L
s
.6797 .01472 m
.6797 .01478 L
s
.68066 .01472 m
.68066 .01478 L
s
.68161 .01472 m
.68161 .01478 L
s
.68256 .01472 m
.68256 .01478 L
s
.68352 .01472 m
.68352 .01478 L
s
.68447 .01472 m
.68447 .01478 L
s
.68542 .01472 m
.68542 .01478 L
s
.68638 .01472 m
.68638 .01478 L
s
.68733 .01472 m
.68733 .01478 L
s
.68828 .01472 m
.68828 .01478 L
s
.68924 .01472 m
.68924 .01478 L
s
.69019 .01472 m
.69019 .01478 L
s
.69114 .01472 m
.69114 .01478 L
s
.6921 .01472 m
.6921 .01478 L
s
.69305 .01472 m
.69305 .01478 L
s
.694 .01472 m
.694 .01478 L
s
.69496 .01472 m
.69496 .01478 L
s
.69591 .01472 m
.69591 .01478 L
s
.69686 .01472 m
.69686 .01478 L
s
.69782 .01472 m
.69782 .01478 L
s
.69877 .01472 m
.69877 .01478 L
s
.69972 .01472 m
.69972 .01478 L
s
.70068 .01472 m
.70068 .01478 L
s
.70163 .01472 m
.70163 .01478 L
s
.70258 .01472 m
.70258 .01477 L
s
.70354 .01472 m
.70354 .01477 L
s
.70449 .01472 m
.70449 .01477 L
s
.70544 .01472 m
.70544 .01477 L
s
.7064 .01472 m
.7064 .01477 L
s
.70735 .01472 m
.70735 .01477 L
s
.7083 .01472 m
.7083 .01477 L
s
.70926 .01472 m
.70926 .01477 L
s
.71021 .01472 m
.71021 .01477 L
s
.71116 .01472 m
.71116 .01477 L
s
.71212 .01472 m
.71212 .01477 L
s
.71307 .01472 m
.71307 .01477 L
s
.71402 .01472 m
.71402 .01477 L
s
.71498 .01472 m
.71498 .01477 L
s
.71593 .01472 m
.71593 .01477 L
s
.71688 .01472 m
.71688 .01477 L
s
.71784 .01472 m
.71784 .01477 L
s
.71879 .01472 m
.71879 .01477 L
s
.71974 .01472 m
.71974 .01477 L
s
.7207 .01472 m
.7207 .01477 L
s
.72165 .01472 m
.72165 .01477 L
s
.7226 .01472 m
.7226 .01477 L
s
.72356 .01472 m
.72356 .01477 L
s
.72451 .01472 m
.72451 .01477 L
s
.72546 .01472 m
.72546 .01477 L
s
.72642 .01472 m
.72642 .01477 L
s
.72737 .01472 m
.72737 .01477 L
s
.72832 .01472 m
.72832 .01477 L
s
.72928 .01472 m
.72928 .01477 L
s
.73023 .01472 m
.73023 .01477 L
s
.73118 .01472 m
.73118 .01477 L
s
.73214 .01472 m
.73214 .01477 L
s
.73309 .01472 m
.73309 .01477 L
s
.73404 .01472 m
.73404 .01477 L
s
.735 .01472 m
.735 .01477 L
s
.73595 .01472 m
.73595 .01477 L
s
.7369 .01472 m
.7369 .01477 L
s
.73786 .01472 m
.73786 .01477 L
s
.73881 .01472 m
.73881 .01477 L
s
.73976 .01472 m
.73976 .01477 L
s
.74072 .01472 m
.74072 .01477 L
s
.74167 .01472 m
.74167 .01477 L
s
.74262 .01472 m
.74262 .01477 L
s
.74358 .01472 m
.74358 .01477 L
s
.74453 .01472 m
.74453 .01477 L
s
.74548 .01472 m
.74548 .01477 L
s
.74644 .01472 m
.74644 .01477 L
s
.74739 .01472 m
.74739 .01477 L
s
.74834 .01472 m
.74834 .01477 L
s
.7493 .01472 m
.7493 .01477 L
s
.75025 .01472 m
.75025 .01477 L
s
.7512 .01472 m
.7512 .01477 L
s
.75216 .01472 m
.75216 .01477 L
s
.75311 .01472 m
.75311 .01477 L
s
.75406 .01472 m
.75406 .01476 L
s
.75502 .01472 m
.75502 .01476 L
s
.75597 .01472 m
.75597 .01476 L
s
.75692 .01472 m
.75692 .01476 L
s
.75788 .01472 m
.75788 .01476 L
s
.75883 .01472 m
.75883 .01476 L
s
.75978 .01472 m
.75978 .01476 L
s
.76074 .01472 m
.76074 .01476 L
s
.76169 .01472 m
.76169 .01476 L
s
.76264 .01472 m
.76264 .01476 L
s
.7636 .01472 m
.7636 .01476 L
s
.76455 .01472 m
.76455 .01476 L
s
.7655 .01472 m
.7655 .01476 L
s
.76646 .01472 m
.76646 .01476 L
s
.76741 .01472 m
.76741 .01476 L
s
.76836 .01472 m
.76836 .01476 L
s
.76932 .01472 m
.76932 .01476 L
s
.77027 .01472 m
.77027 .01476 L
s
.77122 .01472 m
.77122 .01476 L
s
.77218 .01472 m
.77218 .01476 L
s
.77313 .01472 m
.77313 .01476 L
s
.77408 .01472 m
.77408 .01476 L
s
.77504 .01472 m
.77504 .01476 L
s
.77599 .01472 m
.77599 .01476 L
s
.77694 .01472 m
.77694 .01476 L
s
.7779 .01472 m
.7779 .01476 L
s
.77885 .01472 m
.77885 .01476 L
s
.7798 .01472 m
.7798 .01476 L
s
.78076 .01472 m
.78076 .01476 L
s
.78171 .01472 m
.78171 .01476 L
s
.78266 .01472 m
.78266 .01476 L
s
.78362 .01472 m
.78362 .01476 L
s
.78457 .01472 m
.78457 .01476 L
s
.78552 .01472 m
.78552 .01476 L
s
.78648 .01472 m
.78648 .01476 L
s
.78743 .01472 m
.78743 .01476 L
s
.78838 .01472 m
.78838 .01476 L
s
.78934 .01472 m
.78934 .01476 L
s
.79029 .01472 m
.79029 .01476 L
s
.79124 .01472 m
.79124 .01476 L
s
.7922 .01472 m
.7922 .01476 L
s
.79315 .01472 m
.79315 .01476 L
s
.7941 .01472 m
.7941 .01476 L
s
.79506 .01472 m
.79506 .01476 L
s
.79601 .01472 m
.79601 .01476 L
s
.79696 .01472 m
.79696 .01476 L
s
.79792 .01472 m
.79792 .01476 L
s
.79887 .01472 m
.79887 .01476 L
s
.79982 .01472 m
.79982 .01476 L
s
.80078 .01472 m
.80078 .01476 L
s
.80173 .01472 m
.80173 .01476 L
s
.80268 .01472 m
.80268 .01476 L
s
.80364 .01472 m
.80364 .01476 L
s
.80459 .01472 m
.80459 .01476 L
s
.80554 .01472 m
.80554 .01476 L
s
.8065 .01472 m
.8065 .01476 L
s
.80745 .01472 m
.80745 .01476 L
s
.8084 .01472 m
.8084 .01476 L
s
.80936 .01472 m
.80936 .01476 L
s
.81031 .01472 m
.81031 .01476 L
s
.81126 .01472 m
.81126 .01476 L
s
.81222 .01472 m
.81222 .01476 L
s
.81317 .01472 m
.81317 .01476 L
s
.81412 .01472 m
.81412 .01476 L
s
.81508 .01472 m
.81508 .01476 L
s
.81603 .01472 m
.81603 .01476 L
s
.81698 .01472 m
.81698 .01476 L
s
.81794 .01472 m
.81794 .01476 L
s
.81889 .01472 m
.81889 .01476 L
s
.81984 .01472 m
.81984 .01476 L
s
.8208 .01472 m
.8208 .01476 L
s
.82175 .01472 m
.82175 .01476 L
s
.8227 .01472 m
.8227 .01476 L
s
.82366 .01472 m
.82366 .01476 L
s
.82461 .01472 m
.82461 .01476 L
s
.82556 .01472 m
.82556 .01476 L
s
.82652 .01472 m
.82652 .01476 L
s
.82747 .01472 m
.82747 .01476 L
s
.82842 .01472 m
.82842 .01476 L
s
.82938 .01472 m
.82938 .01476 L
s
.83033 .01472 m
.83033 .01476 L
s
.83128 .01472 m
.83128 .01476 L
s
.83224 .01472 m
.83224 .01476 L
s
.83319 .01472 m
.83319 .01476 L
s
.83414 .01472 m
.83414 .01476 L
s
.8351 .01472 m
.8351 .01476 L
s
.83605 .01472 m
.83605 .01476 L
s
.837 .01472 m
.837 .01476 L
s
.83796 .01472 m
.83796 .01476 L
s
.83891 .01472 m
.83891 .01476 L
s
.83986 .01472 m
.83986 .01476 L
s
.84082 .01472 m
.84082 .01476 L
s
.84177 .01472 m
.84177 .01476 L
s
.84272 .01472 m
.84272 .01476 L
s
.84368 .01472 m
.84368 .01476 L
s
.84463 .01472 m
.84463 .01476 L
s
.84558 .01472 m
.84558 .01476 L
s
.84654 .01472 m
.84654 .01476 L
s
.84749 .01472 m
.84749 .01476 L
s
.84844 .01472 m
.84844 .01476 L
s
.8494 .01472 m
.8494 .01476 L
s
.85035 .01472 m
.85035 .01476 L
s
.8513 .01472 m
.8513 .01476 L
s
.85226 .01472 m
.85226 .01476 L
s
.85321 .01472 m
.85321 .01476 L
s
.85416 .01472 m
.85416 .01476 L
s
.85512 .01472 m
.85512 .01476 L
s
.85607 .01472 m
.85607 .01476 L
s
.85702 .01472 m
.85702 .01476 L
s
.85798 .01472 m
.85798 .01476 L
s
.85893 .01472 m
.85893 .01476 L
s
.85988 .01472 m
.85988 .01476 L
s
.86084 .01472 m
.86084 .01476 L
s
.86179 .01472 m
.86179 .01475 L
s
.86274 .01472 m
.86274 .01475 L
s
.8637 .01472 m
.8637 .01475 L
s
.86465 .01472 m
.86465 .01475 L
s
.8656 .01472 m
.8656 .01475 L
s
.86656 .01472 m
.86656 .01475 L
s
.86751 .01472 m
.86751 .01475 L
s
.86846 .01472 m
.86846 .01475 L
s
.86942 .01472 m
.86942 .01475 L
s
.87037 .01472 m
.87037 .01475 L
s
.87132 .01472 m
.87132 .01475 L
s
.87228 .01472 m
.87228 .01475 L
s
.87323 .01472 m
.87323 .01475 L
s
.87418 .01472 m
.87418 .01475 L
s
.87514 .01472 m
.87514 .01475 L
s
.87609 .01472 m
.87609 .01475 L
s
.87704 .01472 m
.87704 .01475 L
s
.878 .01472 m
.878 .01475 L
s
.87895 .01472 m
.87895 .01475 L
s
.8799 .01472 m
.8799 .01475 L
s
.88086 .01472 m
.88086 .01475 L
s
.88181 .01472 m
.88181 .01475 L
s
.88276 .01472 m
.88276 .01475 L
s
.88372 .01472 m
.88372 .01475 L
s
.88467 .01472 m
.88467 .01475 L
s
.88562 .01472 m
.88562 .01475 L
s
.88658 .01472 m
.88658 .01475 L
s
.88753 .01472 m
.88753 .01475 L
s
.88848 .01472 m
.88848 .01475 L
s
.88944 .01472 m
.88944 .01475 L
s
.89039 .01472 m
.89039 .01475 L
s
.89134 .01472 m
.89134 .01475 L
s
.8923 .01472 m
.8923 .01475 L
s
.89325 .01472 m
.89325 .01475 L
s
.8942 .01472 m
.8942 .01475 L
s
.89516 .01472 m
.89516 .01475 L
s
.89611 .01472 m
.89611 .01475 L
s
.89706 .01472 m
.89706 .01475 L
s
.89802 .01472 m
.89802 .01475 L
s
.89897 .01472 m
.89897 .01475 L
s
.89992 .01472 m
.89992 .01475 L
s
.90088 .01472 m
.90088 .01475 L
s
.90183 .01472 m
.90183 .01475 L
s
.90278 .01472 m
.90278 .01475 L
s
.90374 .01472 m
.90374 .01475 L
s
.90469 .01472 m
.90469 .01475 L
s
.90564 .01472 m
.90564 .01475 L
s
.9066 .01472 m
.9066 .01475 L
s
.90755 .01472 m
.90755 .01475 L
s
.9085 .01472 m
.9085 .01475 L
s
.90946 .01472 m
.90946 .01475 L
s
.91041 .01472 m
.91041 .01475 L
s
.91136 .01472 m
.91136 .01475 L
s
.91232 .01472 m
.91232 .01475 L
s
.91327 .01472 m
.91327 .01475 L
s
.91422 .01472 m
.91422 .01475 L
s
.91518 .01472 m
.91518 .01475 L
s
.91613 .01472 m
.91613 .01475 L
s
.91708 .01472 m
.91708 .01475 L
s
.91804 .01472 m
.91804 .01475 L
s
.91899 .01472 m
.91899 .01475 L
s
.91994 .01472 m
.91994 .01475 L
s
.9209 .01472 m
.9209 .01475 L
s
.92185 .01472 m
.92185 .01475 L
s
.9228 .01472 m
.9228 .01475 L
s
.92376 .01472 m
.92376 .01475 L
s
.92471 .01472 m
.92471 .01475 L
s
.92566 .01472 m
.92566 .01475 L
s
.92662 .01472 m
.92662 .01475 L
s
.92757 .01472 m
.92757 .01475 L
s
.92852 .01472 m
.92852 .01475 L
s
.92948 .01472 m
.92948 .01475 L
s
.93043 .01472 m
.93043 .01475 L
s
.93138 .01472 m
.93138 .01475 L
s
.93234 .01472 m
.93234 .01475 L
s
.93329 .01472 m
.93329 .01475 L
s
.93424 .01472 m
.93424 .01475 L
s
.9352 .01472 m
.9352 .01475 L
s
.93615 .01472 m
.93615 .01475 L
s
.9371 .01472 m
.9371 .01475 L
s
.93806 .01472 m
.93806 .01475 L
s
.93901 .01472 m
.93901 .01475 L
s
.93996 .01472 m
.93996 .01475 L
s
.94092 .01472 m
.94092 .01475 L
s
.94187 .01472 m
.94187 .01475 L
s
.94282 .01472 m
.94282 .01475 L
s
.94378 .01472 m
.94378 .01475 L
s
.94473 .01472 m
.94473 .01475 L
s
.94568 .01472 m
.94568 .01475 L
s
.94664 .01472 m
.94664 .01475 L
s
.94759 .01472 m
.94759 .01475 L
s
.94854 .01472 m
.94854 .01475 L
s
.9495 .01472 m
.9495 .01475 L
s
.95045 .01472 m
.95045 .01475 L
s
.9514 .01472 m
.9514 .01475 L
s
.95236 .01472 m
.95236 .01475 L
s
.95331 .01472 m
.95331 .01475 L
s
.95426 .01472 m
.95426 .01475 L
s
.95522 .01472 m
.95522 .01475 L
s
.95617 .01472 m
.95617 .01475 L
s
.95712 .01472 m
.95712 .01475 L
s
.95808 .01472 m
.95808 .01475 L
s
.95903 .01472 m
.95903 .01475 L
s
.95998 .01472 m
.95998 .01475 L
s
.96094 .01472 m
.96094 .01475 L
s
.96189 .01472 m
.96189 .01475 L
s
.96284 .01472 m
.96284 .01475 L
s
.9638 .01472 m
.9638 .01475 L
s
.96475 .01472 m
.96475 .01475 L
s
.9657 .01472 m
.9657 .01475 L
s
.96666 .01472 m
.96666 .01475 L
s
.96761 .01472 m
.96761 .01475 L
s
.96856 .01472 m
.96856 .01475 L
s
.96952 .01472 m
.96952 .01475 L
s
.97047 .01472 m
.97047 .01475 L
s
.97142 .01472 m
.97142 .01475 L
s
.97238 .01472 m
.97238 .01475 L
s
.97333 .01472 m
.97333 .01475 L
s
.97428 .01472 m
.97428 .01475 L
s
.97524 .01472 m
.97524 .01475 L
s
.97619 .01472 m
.97619 .01475 L
s
.015 w
.02381 .01475 Mdot
.02476 .01475 Mdot
.02572 .01475 Mdot
.02667 .01475 Mdot
.02762 .01475 Mdot
.02858 .01475 Mdot
.02953 .01475 Mdot
.03048 .01475 Mdot
.03144 .01475 Mdot
.03239 .01475 Mdot
.03334 .01475 Mdot
.0343 .01475 Mdot
.03525 .01475 Mdot
.0362 .01475 Mdot
.03716 .01475 Mdot
.03811 .01475 Mdot
.03906 .01475 Mdot
.04002 .01475 Mdot
.04097 .01475 Mdot
.04192 .01475 Mdot
.04288 .01475 Mdot
.04383 .01475 Mdot
.04478 .01475 Mdot
.04574 .01475 Mdot
.04669 .01475 Mdot
.04764 .01475 Mdot
.0486 .01475 Mdot
.04955 .01475 Mdot
.0505 .01475 Mdot
.05146 .01475 Mdot
.05241 .01475 Mdot
.05336 .01475 Mdot
.05432 .01475 Mdot
.05527 .01475 Mdot
.05622 .01475 Mdot
.05718 .01475 Mdot
.05813 .01475 Mdot
.05908 .01475 Mdot
.06004 .01475 Mdot
.06099 .01475 Mdot
.06194 .01475 Mdot
.0629 .01475 Mdot
.06385 .01475 Mdot
.0648 .01475 Mdot
.06576 .01475 Mdot
.06671 .01475 Mdot
.06766 .01475 Mdot
.06862 .01475 Mdot
.06957 .01475 Mdot
.07052 .01475 Mdot
.07148 .01475 Mdot
.07243 .01475 Mdot
.07338 .01475 Mdot
.07434 .01475 Mdot
.07529 .01475 Mdot
.07624 .01475 Mdot
.0772 .01475 Mdot
.07815 .01475 Mdot
.0791 .01475 Mdot
.08006 .01475 Mdot
.08101 .01475 Mdot
.08196 .01475 Mdot
.08292 .01475 Mdot
.08387 .01475 Mdot
.08482 .01475 Mdot
.08578 .01475 Mdot
.08673 .01475 Mdot
.08768 .01475 Mdot
.08864 .01475 Mdot
.08959 .01475 Mdot
.09054 .01475 Mdot
.0915 .01475 Mdot
.09245 .01475 Mdot
.0934 .01475 Mdot
.09436 .01475 Mdot
.09531 .01475 Mdot
.09626 .01475 Mdot
.09722 .01475 Mdot
.09817 .01475 Mdot
.09912 .01475 Mdot
.10008 .01475 Mdot
.10103 .01475 Mdot
.10198 .01475 Mdot
.10294 .01475 Mdot
.10389 .01475 Mdot
.10484 .01475 Mdot
.1058 .01475 Mdot
.10675 .01475 Mdot
.1077 .01475 Mdot
.10866 .01475 Mdot
.10961 .01475 Mdot
.11056 .01475 Mdot
.11152 .01475 Mdot
.11247 .01475 Mdot
.11342 .01475 Mdot
.11438 .01475 Mdot
.11533 .01475 Mdot
.11628 .01475 Mdot
.11724 .01475 Mdot
.11819 .01475 Mdot
.11914 .01475 Mdot
.1201 .01475 Mdot
.12105 .01475 Mdot
.122 .01475 Mdot
.12296 .01475 Mdot
.12391 .01475 Mdot
.12486 .01475 Mdot
.12582 .01475 Mdot
.12677 .01475 Mdot
.12772 .01475 Mdot
.12868 .01475 Mdot
.12963 .01475 Mdot
.13058 .01475 Mdot
.13154 .01475 Mdot
.13249 .01475 Mdot
.13344 .01475 Mdot
.1344 .01475 Mdot
.13535 .01475 Mdot
.1363 .01475 Mdot
.13726 .01475 Mdot
.13821 .01476 Mdot
.13916 .01476 Mdot
.14012 .01476 Mdot
.14107 .01476 Mdot
.14202 .01476 Mdot
.14298 .01476 Mdot
.14393 .01476 Mdot
.14488 .01476 Mdot
.14584 .01476 Mdot
.14679 .01476 Mdot
.14774 .01476 Mdot
.1487 .01476 Mdot
.14965 .01476 Mdot
.1506 .01476 Mdot
.15156 .01476 Mdot
.15251 .01476 Mdot
.15346 .01476 Mdot
.15442 .01476 Mdot
.15537 .01476 Mdot
.15632 .01476 Mdot
.15728 .01476 Mdot
.15823 .01476 Mdot
.15918 .01476 Mdot
.16014 .01476 Mdot
.16109 .01476 Mdot
.16204 .01476 Mdot
.163 .01476 Mdot
.16395 .01476 Mdot
.1649 .01476 Mdot
.16586 .01476 Mdot
.16681 .01476 Mdot
.16776 .01476 Mdot
.16872 .01476 Mdot
.16967 .01476 Mdot
.17062 .01476 Mdot
.17158 .01476 Mdot
.17253 .01476 Mdot
.17348 .01476 Mdot
.17444 .01476 Mdot
.17539 .01476 Mdot
.17634 .01476 Mdot
.1773 .01476 Mdot
.17825 .01476 Mdot
.1792 .01476 Mdot
.18016 .01476 Mdot
.18111 .01476 Mdot
.18206 .01476 Mdot
.18302 .01476 Mdot
.18397 .01476 Mdot
.18492 .01476 Mdot
.18588 .01476 Mdot
.18683 .01476 Mdot
.18778 .01476 Mdot
.18874 .01476 Mdot
.18969 .01476 Mdot
.19064 .01476 Mdot
.1916 .01476 Mdot
.19255 .01476 Mdot
.1935 .01476 Mdot
.19446 .01476 Mdot
.19541 .01476 Mdot
.19636 .01476 Mdot
.19732 .01476 Mdot
.19827 .01476 Mdot
.19922 .01476 Mdot
.20018 .01476 Mdot
.20113 .01476 Mdot
.20208 .01476 Mdot
.20304 .01476 Mdot
.20399 .01476 Mdot
.20494 .01476 Mdot
.2059 .01476 Mdot
.20685 .01476 Mdot
.2078 .01476 Mdot
.20876 .01476 Mdot
.20971 .01476 Mdot
.21066 .01476 Mdot
.21162 .01476 Mdot
.21257 .01476 Mdot
.21352 .01476 Mdot
.21448 .01476 Mdot
.21543 .01476 Mdot
.21638 .01476 Mdot
.21734 .01476 Mdot
.21829 .01476 Mdot
.21924 .01476 Mdot
.2202 .01476 Mdot
.22115 .01476 Mdot
.2221 .01476 Mdot
.22306 .01476 Mdot
.22401 .01476 Mdot
.22496 .01476 Mdot
.22592 .01476 Mdot
.22687 .01476 Mdot
.22782 .01476 Mdot
.22878 .01476 Mdot
.22973 .01476 Mdot
.23068 .01476 Mdot
.23164 .01476 Mdot
.23259 .01476 Mdot
.23354 .01476 Mdot
.2345 .01476 Mdot
.23545 .01476 Mdot
.2364 .01476 Mdot
.23736 .01476 Mdot
.23831 .01476 Mdot
.23926 .01476 Mdot
.24022 .01476 Mdot
.24117 .01476 Mdot
.24212 .01476 Mdot
.24308 .01476 Mdot
.24403 .01476 Mdot
.24498 .01476 Mdot
.24594 .01477 Mdot
.24689 .01477 Mdot
.24784 .01477 Mdot
.2488 .01477 Mdot
.24975 .01477 Mdot
.2507 .01477 Mdot
.25166 .01477 Mdot
.25261 .01477 Mdot
.25356 .01477 Mdot
.25452 .01477 Mdot
.25547 .01477 Mdot
.25642 .01477 Mdot
.25738 .01477 Mdot
.25833 .01477 Mdot
.25928 .01477 Mdot
.26024 .01477 Mdot
.26119 .01477 Mdot
.26214 .01477 Mdot
.2631 .01477 Mdot
.26405 .01477 Mdot
.265 .01477 Mdot
.26596 .01477 Mdot
.26691 .01477 Mdot
.26786 .01477 Mdot
.26882 .01477 Mdot
.26977 .01477 Mdot
.27072 .01477 Mdot
.27168 .01477 Mdot
.27263 .01477 Mdot
.27358 .01477 Mdot
.27454 .01477 Mdot
.27549 .01477 Mdot
.27644 .01477 Mdot
.2774 .01477 Mdot
.27835 .01477 Mdot
.2793 .01477 Mdot
.28026 .01477 Mdot
.28121 .01477 Mdot
.28216 .01477 Mdot
.28312 .01477 Mdot
.28407 .01477 Mdot
.28502 .01477 Mdot
.28598 .01477 Mdot
.28693 .01477 Mdot
.28788 .01477 Mdot
.28884 .01477 Mdot
.28979 .01477 Mdot
.29074 .01477 Mdot
.2917 .01477 Mdot
.29265 .01477 Mdot
.2936 .01477 Mdot
.29456 .01477 Mdot
.29551 .01477 Mdot
.29646 .01477 Mdot
.29742 .01478 Mdot
.29837 .01478 Mdot
.29932 .01478 Mdot
.30028 .01478 Mdot
.30123 .01478 Mdot
.30218 .01478 Mdot
.30314 .01478 Mdot
.30409 .01478 Mdot
.30504 .01478 Mdot
.306 .01478 Mdot
.30695 .01478 Mdot
.3079 .01478 Mdot
.30886 .01478 Mdot
.30981 .01478 Mdot
.31076 .01478 Mdot
.31172 .01478 Mdot
.31267 .01478 Mdot
.31362 .01478 Mdot
.31458 .01478 Mdot
.31553 .01478 Mdot
.31648 .01478 Mdot
.31744 .01478 Mdot
.31839 .01478 Mdot
.31934 .01478 Mdot
.3203 .01478 Mdot
.32125 .01478 Mdot
.3222 .01478 Mdot
.32316 .01478 Mdot
.32411 .01478 Mdot
.32506 .01478 Mdot
.32602 .01478 Mdot
.32697 .01478 Mdot
.32792 .01478 Mdot
.32888 .01478 Mdot
.32983 .01479 Mdot
.33078 .01479 Mdot
.33174 .01479 Mdot
.33269 .01479 Mdot
.33364 .01479 Mdot
.3346 .01479 Mdot
.33555 .01479 Mdot
.3365 .01479 Mdot
.33746 .01479 Mdot
.33841 .01479 Mdot
.33936 .01479 Mdot
.34032 .01479 Mdot
.34127 .01479 Mdot
.34222 .01479 Mdot
.34318 .01479 Mdot
.34413 .01479 Mdot
.34508 .01479 Mdot
.34604 .01479 Mdot
.34699 .01479 Mdot
.34794 .01479 Mdot
.3489 .01479 Mdot
.34985 .01479 Mdot
.3508 .01479 Mdot
.35176 .01479 Mdot
.35271 .0148 Mdot
.35366 .0148 Mdot
.35462 .0148 Mdot
.35557 .0148 Mdot
.35652 .0148 Mdot
.35748 .0148 Mdot
.35843 .0148 Mdot
.35938 .0148 Mdot
.36034 .0148 Mdot
.36129 .0148 Mdot
.36224 .0148 Mdot
.3632 .0148 Mdot
.36415 .0148 Mdot
.3651 .0148 Mdot
.36606 .0148 Mdot
.36701 .0148 Mdot
.36796 .0148 Mdot
.36892 .0148 Mdot
.36987 .0148 Mdot
.37082 .01481 Mdot
.37178 .01481 Mdot
.37273 .01481 Mdot
.37368 .01481 Mdot
.37464 .01481 Mdot
.37559 .01481 Mdot
.37654 .01481 Mdot
.3775 .01481 Mdot
.37845 .01481 Mdot
.3794 .01481 Mdot
.38036 .01481 Mdot
.38131 .01481 Mdot
.38226 .01481 Mdot
.38322 .01481 Mdot
.38417 .01482 Mdot
.38512 .01482 Mdot
.38608 .01482 Mdot
.38703 .01482 Mdot
.38798 .01482 Mdot
.38894 .01482 Mdot
.38989 .01482 Mdot
.39084 .01482 Mdot
.3918 .01482 Mdot
.39275 .01482 Mdot
.3937 .01482 Mdot
.39466 .01483 Mdot
.39561 .01483 Mdot
.39656 .01483 Mdot
.39752 .01483 Mdot
.39847 .01483 Mdot
.39942 .01483 Mdot
.40038 .01483 Mdot
.40133 .01483 Mdot
.40228 .01483 Mdot
.40324 .01483 Mdot
.40419 .01484 Mdot
.40514 .01484 Mdot
.4061 .01484 Mdot
.40705 .01484 Mdot
.408 .01484 Mdot
.40896 .01484 Mdot
.40991 .01484 Mdot
.41086 .01485 Mdot
.41182 .01485 Mdot
.41277 .01485 Mdot
.41372 .01485 Mdot
.41468 .01485 Mdot
.41563 .01485 Mdot
.41658 .01485 Mdot
.41754 .01486 Mdot
.41849 .01486 Mdot
.41944 .01486 Mdot
.4204 .01486 Mdot
.42135 .01486 Mdot
.4223 .01486 Mdot
.42326 .01487 Mdot
.42421 .01487 Mdot
.42516 .01487 Mdot
.42612 .01487 Mdot
.42707 .01487 Mdot
.42802 .01488 Mdot
.42898 .01488 Mdot
.42993 .01488 Mdot
.43088 .01488 Mdot
.43184 .01489 Mdot
.43279 .01489 Mdot
.43374 .01489 Mdot
.4347 .01489 Mdot
.43565 .0149 Mdot
.4366 .0149 Mdot
.43756 .0149 Mdot
.43851 .01491 Mdot
.43946 .01491 Mdot
.44042 .01491 Mdot
.44137 .01491 Mdot
.44232 .01492 Mdot
.44328 .01492 Mdot
.44423 .01493 Mdot
.44518 .01493 Mdot
.44614 .01493 Mdot
.44709 .01494 Mdot
.44804 .01494 Mdot
.449 .01495 Mdot
.44995 .01495 Mdot
.4509 .01496 Mdot
.45186 .01496 Mdot
.45281 .01497 Mdot
.45376 .01497 Mdot
.45472 .01498 Mdot
.45567 .01499 Mdot
.45662 .01499 Mdot
.45758 .015 Mdot
.45853 .01501 Mdot
.45948 .01501 Mdot
.46044 .01502 Mdot
.46139 .01503 Mdot
.46234 .01504 Mdot
.4633 .01505 Mdot
.46425 .01506 Mdot
.4652 .01507 Mdot
.46616 .01508 Mdot
.46711 .0151 Mdot
.46806 .01511 Mdot
.46902 .01512 Mdot
.46997 .01514 Mdot
.47092 .01516 Mdot
.47188 .01518 Mdot
.47283 .0152 Mdot
.47378 .01522 Mdot
.47474 .01525 Mdot
.47569 .01528 Mdot
.47664 .01531 Mdot
.4776 .01535 Mdot
.47855 .01539 Mdot
.4795 .01544 Mdot
.48046 .0155 Mdot
.48141 .01557 Mdot
.48236 .01566 Mdot
.48332 .01578 Mdot
.48427 .01593 Mdot
.48522 .01613 Mdot
.48618 .01644 Mdot
.48713 .01694 Mdot
.48808 .01795 Mdot
.48904 .02095 Mdot
.48999 .60332 Mdot
.49094 .02024 Mdot
.4919 .01732 Mdot
.49285 .01633 Mdot
.4938 .01582 Mdot
.49476 .0155 Mdot
.49571 .01528 Mdot
.49666 .0151 Mdot
.49762 .01496 Mdot
.49857 .01483 Mdot
.49952 .01472 Mdot
.50048 .01483 Mdot
.50143 .01496 Mdot
.50238 .0151 Mdot
.50334 .01528 Mdot
.50429 .0155 Mdot
.50524 .01582 Mdot
.5062 .01633 Mdot
.50715 .01732 Mdot
.5081 .02024 Mdot
.50906 .60332 Mdot
.51001 .02095 Mdot
.51096 .01795 Mdot
.51192 .01694 Mdot
.51287 .01644 Mdot
.51382 .01613 Mdot
.51478 .01593 Mdot
.51573 .01578 Mdot
.51668 .01566 Mdot
.51764 .01557 Mdot
.51859 .0155 Mdot
.51954 .01544 Mdot
.5205 .01539 Mdot
.52145 .01535 Mdot
.5224 .01531 Mdot
.52336 .01528 Mdot
.52431 .01525 Mdot
.52526 .01522 Mdot
.52622 .0152 Mdot
.52717 .01518 Mdot
.52812 .01516 Mdot
.52908 .01514 Mdot
.53003 .01512 Mdot
.53098 .01511 Mdot
.53194 .0151 Mdot
.53289 .01508 Mdot
.53384 .01507 Mdot
.5348 .01506 Mdot
.53575 .01505 Mdot
.5367 .01504 Mdot
.53766 .01503 Mdot
.53861 .01502 Mdot
.53956 .01501 Mdot
.54052 .01501 Mdot
.54147 .015 Mdot
.54242 .01499 Mdot
.54338 .01499 Mdot
.54433 .01498 Mdot
.54528 .01497 Mdot
.54624 .01497 Mdot
.54719 .01496 Mdot
.54814 .01496 Mdot
.5491 .01495 Mdot
.55005 .01495 Mdot
.551 .01494 Mdot
.55196 .01494 Mdot
.55291 .01493 Mdot
.55386 .01493 Mdot
.55482 .01493 Mdot
.55577 .01492 Mdot
.55672 .01492 Mdot
.55768 .01491 Mdot
.55863 .01491 Mdot
.55958 .01491 Mdot
.56054 .01491 Mdot
.56149 .0149 Mdot
.56244 .0149 Mdot
.5634 .0149 Mdot
.56435 .01489 Mdot
.5653 .01489 Mdot
.56626 .01489 Mdot
.56721 .01489 Mdot
.56816 .01488 Mdot
.56912 .01488 Mdot
.57007 .01488 Mdot
.57102 .01488 Mdot
.57198 .01487 Mdot
.57293 .01487 Mdot
.57388 .01487 Mdot
.57484 .01487 Mdot
.57579 .01487 Mdot
.57674 .01486 Mdot
.5777 .01486 Mdot
.57865 .01486 Mdot
.5796 .01486 Mdot
.58056 .01486 Mdot
.58151 .01486 Mdot
.58246 .01485 Mdot
.58342 .01485 Mdot
.58437 .01485 Mdot
.58532 .01485 Mdot
.58628 .01485 Mdot
.58723 .01485 Mdot
.58818 .01485 Mdot
.58914 .01484 Mdot
.59009 .01484 Mdot
.59104 .01484 Mdot
.592 .01484 Mdot
.59295 .01484 Mdot
.5939 .01484 Mdot
.59486 .01484 Mdot
.59581 .01483 Mdot
.59676 .01483 Mdot
.59772 .01483 Mdot
.59867 .01483 Mdot
.59962 .01483 Mdot
.60058 .01483 Mdot
.60153 .01483 Mdot
.60248 .01483 Mdot
.60344 .01483 Mdot
.60439 .01483 Mdot
.60534 .01482 Mdot
.6063 .01482 Mdot
.60725 .01482 Mdot
.6082 .01482 Mdot
.60916 .01482 Mdot
.61011 .01482 Mdot
.61106 .01482 Mdot
.61202 .01482 Mdot
.61297 .01482 Mdot
.61392 .01482 Mdot
.61488 .01482 Mdot
.61583 .01481 Mdot
.61678 .01481 Mdot
.61774 .01481 Mdot
.61869 .01481 Mdot
.61964 .01481 Mdot
.6206 .01481 Mdot
.62155 .01481 Mdot
.6225 .01481 Mdot
.62346 .01481 Mdot
.62441 .01481 Mdot
.62536 .01481 Mdot
.62632 .01481 Mdot
.62727 .01481 Mdot
.62822 .01481 Mdot
.62918 .0148 Mdot
.63013 .0148 Mdot
.63108 .0148 Mdot
.63204 .0148 Mdot
.63299 .0148 Mdot
.63394 .0148 Mdot
.6349 .0148 Mdot
.63585 .0148 Mdot
.6368 .0148 Mdot
.63776 .0148 Mdot
.63871 .0148 Mdot
.63966 .0148 Mdot
.64062 .0148 Mdot
.64157 .0148 Mdot
.64252 .0148 Mdot
.64348 .0148 Mdot
.64443 .0148 Mdot
.64538 .0148 Mdot
.64634 .0148 Mdot
.64729 .01479 Mdot
.64824 .01479 Mdot
.6492 .01479 Mdot
.65015 .01479 Mdot
.6511 .01479 Mdot
.65206 .01479 Mdot
.65301 .01479 Mdot
.65396 .01479 Mdot
.65492 .01479 Mdot
.65587 .01479 Mdot
.65682 .01479 Mdot
.65778 .01479 Mdot
.65873 .01479 Mdot
.65968 .01479 Mdot
.66064 .01479 Mdot
.66159 .01479 Mdot
.66254 .01479 Mdot
.6635 .01479 Mdot
.66445 .01479 Mdot
.6654 .01479 Mdot
.66636 .01479 Mdot
.66731 .01479 Mdot
.66826 .01479 Mdot
.66922 .01479 Mdot
.67017 .01478 Mdot
.67112 .01478 Mdot
.67208 .01478 Mdot
.67303 .01478 Mdot
.67398 .01478 Mdot
.67494 .01478 Mdot
.67589 .01478 Mdot
.67684 .01478 Mdot
.6778 .01478 Mdot
.67875 .01478 Mdot
.6797 .01478 Mdot
.68066 .01478 Mdot
.68161 .01478 Mdot
.68256 .01478 Mdot
.68352 .01478 Mdot
.68447 .01478 Mdot
.68542 .01478 Mdot
.68638 .01478 Mdot
.68733 .01478 Mdot
.68828 .01478 Mdot
.68924 .01478 Mdot
.69019 .01478 Mdot
.69114 .01478 Mdot
.6921 .01478 Mdot
.69305 .01478 Mdot
.694 .01478 Mdot
.69496 .01478 Mdot
.69591 .01478 Mdot
.69686 .01478 Mdot
.69782 .01478 Mdot
.69877 .01478 Mdot
.69972 .01478 Mdot
.70068 .01478 Mdot
.70163 .01478 Mdot
.70258 .01477 Mdot
.70354 .01477 Mdot
.70449 .01477 Mdot
.70544 .01477 Mdot
.7064 .01477 Mdot
.70735 .01477 Mdot
.7083 .01477 Mdot
.70926 .01477 Mdot
.71021 .01477 Mdot
.71116 .01477 Mdot
.71212 .01477 Mdot
.71307 .01477 Mdot
.71402 .01477 Mdot
.71498 .01477 Mdot
.71593 .01477 Mdot
.71688 .01477 Mdot
.71784 .01477 Mdot
.71879 .01477 Mdot
.71974 .01477 Mdot
.7207 .01477 Mdot
.72165 .01477 Mdot
.7226 .01477 Mdot
.72356 .01477 Mdot
.72451 .01477 Mdot
.72546 .01477 Mdot
.72642 .01477 Mdot
.72737 .01477 Mdot
.72832 .01477 Mdot
.72928 .01477 Mdot
.73023 .01477 Mdot
.73118 .01477 Mdot
.73214 .01477 Mdot
.73309 .01477 Mdot
.73404 .01477 Mdot
.735 .01477 Mdot
.73595 .01477 Mdot
.7369 .01477 Mdot
.73786 .01477 Mdot
.73881 .01477 Mdot
.73976 .01477 Mdot
.74072 .01477 Mdot
.74167 .01477 Mdot
.74262 .01477 Mdot
.74358 .01477 Mdot
.74453 .01477 Mdot
.74548 .01477 Mdot
.74644 .01477 Mdot
.74739 .01477 Mdot
.74834 .01477 Mdot
.7493 .01477 Mdot
.75025 .01477 Mdot
.7512 .01477 Mdot
.75216 .01477 Mdot
.75311 .01477 Mdot
.75406 .01476 Mdot
.75502 .01476 Mdot
.75597 .01476 Mdot
.75692 .01476 Mdot
.75788 .01476 Mdot
.75883 .01476 Mdot
.75978 .01476 Mdot
.76074 .01476 Mdot
.76169 .01476 Mdot
.76264 .01476 Mdot
.7636 .01476 Mdot
.76455 .01476 Mdot
.7655 .01476 Mdot
.76646 .01476 Mdot
.76741 .01476 Mdot
.76836 .01476 Mdot
.76932 .01476 Mdot
.77027 .01476 Mdot
.77122 .01476 Mdot
.77218 .01476 Mdot
.77313 .01476 Mdot
.77408 .01476 Mdot
.77504 .01476 Mdot
.77599 .01476 Mdot
.77694 .01476 Mdot
.7779 .01476 Mdot
.77885 .01476 Mdot
.7798 .01476 Mdot
.78076 .01476 Mdot
.78171 .01476 Mdot
.78266 .01476 Mdot
.78362 .01476 Mdot
.78457 .01476 Mdot
.78552 .01476 Mdot
.78648 .01476 Mdot
.78743 .01476 Mdot
.78838 .01476 Mdot
.78934 .01476 Mdot
.79029 .01476 Mdot
.79124 .01476 Mdot
.7922 .01476 Mdot
.79315 .01476 Mdot
.7941 .01476 Mdot
.79506 .01476 Mdot
.79601 .01476 Mdot
.79696 .01476 Mdot
.79792 .01476 Mdot
.79887 .01476 Mdot
.79982 .01476 Mdot
.80078 .01476 Mdot
.80173 .01476 Mdot
.80268 .01476 Mdot
.80364 .01476 Mdot
.80459 .01476 Mdot
.80554 .01476 Mdot
.8065 .01476 Mdot
.80745 .01476 Mdot
.8084 .01476 Mdot
.80936 .01476 Mdot
.81031 .01476 Mdot
.81126 .01476 Mdot
.81222 .01476 Mdot
.81317 .01476 Mdot
.81412 .01476 Mdot
.81508 .01476 Mdot
.81603 .01476 Mdot
.81698 .01476 Mdot
.81794 .01476 Mdot
.81889 .01476 Mdot
.81984 .01476 Mdot
.8208 .01476 Mdot
.82175 .01476 Mdot
.8227 .01476 Mdot
.82366 .01476 Mdot
.82461 .01476 Mdot
.82556 .01476 Mdot
.82652 .01476 Mdot
.82747 .01476 Mdot
.82842 .01476 Mdot
.82938 .01476 Mdot
.83033 .01476 Mdot
.83128 .01476 Mdot
.83224 .01476 Mdot
.83319 .01476 Mdot
.83414 .01476 Mdot
.8351 .01476 Mdot
.83605 .01476 Mdot
.837 .01476 Mdot
.83796 .01476 Mdot
.83891 .01476 Mdot
.83986 .01476 Mdot
.84082 .01476 Mdot
.84177 .01476 Mdot
.84272 .01476 Mdot
.84368 .01476 Mdot
.84463 .01476 Mdot
.84558 .01476 Mdot
.84654 .01476 Mdot
.84749 .01476 Mdot
.84844 .01476 Mdot
.8494 .01476 Mdot
.85035 .01476 Mdot
.8513 .01476 Mdot
.85226 .01476 Mdot
.85321 .01476 Mdot
.85416 .01476 Mdot
.85512 .01476 Mdot
.85607 .01476 Mdot
.85702 .01476 Mdot
.85798 .01476 Mdot
.85893 .01476 Mdot
.85988 .01476 Mdot
.86084 .01476 Mdot
.86179 .01475 Mdot
.86274 .01475 Mdot
.8637 .01475 Mdot
.86465 .01475 Mdot
.8656 .01475 Mdot
.86656 .01475 Mdot
.86751 .01475 Mdot
.86846 .01475 Mdot
.86942 .01475 Mdot
.87037 .01475 Mdot
.87132 .01475 Mdot
.87228 .01475 Mdot
.87323 .01475 Mdot
.87418 .01475 Mdot
.87514 .01475 Mdot
.87609 .01475 Mdot
.87704 .01475 Mdot
.878 .01475 Mdot
.87895 .01475 Mdot
.8799 .01475 Mdot
.88086 .01475 Mdot
.88181 .01475 Mdot
.88276 .01475 Mdot
.88372 .01475 Mdot
.88467 .01475 Mdot
.88562 .01475 Mdot
.88658 .01475 Mdot
.88753 .01475 Mdot
.88848 .01475 Mdot
.88944 .01475 Mdot
.89039 .01475 Mdot
.89134 .01475 Mdot
.8923 .01475 Mdot
.89325 .01475 Mdot
.8942 .01475 Mdot
.89516 .01475 Mdot
.89611 .01475 Mdot
.89706 .01475 Mdot
.89802 .01475 Mdot
.89897 .01475 Mdot
.89992 .01475 Mdot
.90088 .01475 Mdot
.90183 .01475 Mdot
.90278 .01475 Mdot
.90374 .01475 Mdot
.90469 .01475 Mdot
.90564 .01475 Mdot
.9066 .01475 Mdot
.90755 .01475 Mdot
.9085 .01475 Mdot
.90946 .01475 Mdot
.91041 .01475 Mdot
.91136 .01475 Mdot
.91232 .01475 Mdot
.91327 .01475 Mdot
.91422 .01475 Mdot
.91518 .01475 Mdot
.91613 .01475 Mdot
.91708 .01475 Mdot
.91804 .01475 Mdot
.91899 .01475 Mdot
.91994 .01475 Mdot
.9209 .01475 Mdot
.92185 .01475 Mdot
.9228 .01475 Mdot
.92376 .01475 Mdot
.92471 .01475 Mdot
.92566 .01475 Mdot
.92662 .01475 Mdot
.92757 .01475 Mdot
.92852 .01475 Mdot
.92948 .01475 Mdot
.93043 .01475 Mdot
.93138 .01475 Mdot
.93234 .01475 Mdot
.93329 .01475 Mdot
.93424 .01475 Mdot
.9352 .01475 Mdot
.93615 .01475 Mdot
.9371 .01475 Mdot
.93806 .01475 Mdot
.93901 .01475 Mdot
.93996 .01475 Mdot
.94092 .01475 Mdot
.94187 .01475 Mdot
.94282 .01475 Mdot
.94378 .01475 Mdot
.94473 .01475 Mdot
.94568 .01475 Mdot
.94664 .01475 Mdot
.94759 .01475 Mdot
.94854 .01475 Mdot
.9495 .01475 Mdot
.95045 .01475 Mdot
.9514 .01475 Mdot
.95236 .01475 Mdot
.95331 .01475 Mdot
.95426 .01475 Mdot
.95522 .01475 Mdot
.95617 .01475 Mdot
.95712 .01475 Mdot
.95808 .01475 Mdot
.95903 .01475 Mdot
.95998 .01475 Mdot
.96094 .01475 Mdot
.96189 .01475 Mdot
.96284 .01475 Mdot
.9638 .01475 Mdot
.96475 .01475 Mdot
.9657 .01475 Mdot
.96666 .01475 Mdot
.96761 .01475 Mdot
.96856 .01475 Mdot
.96952 .01475 Mdot
.97047 .01475 Mdot
.97142 .01475 Mdot
.97238 .01475 Mdot
.97333 .01475 Mdot
.97428 .01475 Mdot
.97524 .01475 Mdot
.97619 .01475 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool3o`0000?ooooo0_l00004ooooo`;o00008oooool5o`0000?ooooo0_l00004oooo
o`;o00009oooool2o`0002Wooooo1Ol00003ooooo`;o00001?ooool2o`0002Gooooo0ol00003oooo
o`;o00001?ooool2o`0001[ooooo000aooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Gooooo00Co0000oooooooo
oooo0000:Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00009Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0Gooooo`00:?ooool5o`000003ooooool0003o000000?o
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001cooooo1Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Uooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0002;ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00006Oooool002kooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08ooo
ool01?l0003oooooooooool0000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000_ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Rooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Gooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Iooooo`00<?oo
ool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Rooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Gooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Tooooo`;o00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000aooooo`03o`000?oo
oooooooo00;ooooo0_l00004ooooo`;o00009?ooool3o`0000Cooooo0_l00004ooooo`;o00009ooo
ool2o`0002[ooooo0ol00004ooooo`;o00001?ooool2o`0002Kooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l0000Jooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`005Ooooooo000000/000000Oooool000kooooo0_l00005ooooo`0300000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo0@000001ooooo`003Oooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo01cooooo00?o0000ooooooooool0<?ooool00`00003oooooooooo`0_ooooo`0300000?oooooo
oooo033ooooo00?o0000ooooooooool0<?ooool00`00003oooooooooo`0Looooo`4000000Oooool0
00gooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`02ooooooooo`001Oooool1
0000007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo0`000002ooooooooo`001?ooool1
o`00004000000Oooool000gooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`02
ooooooooo`001Oooool10000007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool0O?ooool;ool007oooooo0@000001ooooo`003_ooool2o`0000Gooooo00<00000oooo
ooooool0OOooool4ool00003oooooooo003oo`0000;oo`00P?ooool10000007ooooo000Eooooo`03
00000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`40
00000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l0
0?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1oooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001Gooooo00<00000
ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001
ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0
Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Oooo
ool10000007ooooo000Eooooo`0300000?l0003ooooo07oooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`1nooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1ooooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`03
00000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`40
00000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l0
0?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooo
oooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
07oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1oooooo`030?l00?oooooooooo00;o
oooo00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0
Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Oooo
ool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007o
oooo000Eooooo`0300000?l0003ooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`1nooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooo
oooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
07oooooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005oooo
o`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1ooooo
o`4000000Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`000_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o0000o`00
001oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0O_ooool1o`00004000000Ooo
ool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l0
0?oooooooooo07oooooo0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1oooooo`03
0?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo00000ooooooo0000
o`000004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000
007ooooo0002ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00`00003o
ooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007o
oooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`1oooooo`4000000Oooool001Gooooo00<00000o`000?ooool0Ooooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo07kooooo0Ol000010000007ooooo000Eooooo`0300000?oooooo
oooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;o
oooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo
00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<0
0000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?l0003ooooo07oooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`1nooooo`7o00000@000001ooooo`005Oooool00`00003o
ooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007o
oooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1o
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eoooo
o`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1ooooo
o`4000000Oooool001Gooooo00<00000o`000?ooool0Ooooool00`3o003oooooooooo`02ooooo`03
0?l00?oooooooooo07kooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo07oooooo
00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<0
0000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`00
5Oooool00`00003o0000ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
O_ooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1o
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eoooo
o`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1ooooo
o`4000000Oooool000Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo07oo
oooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool00005oooo
ool0003oooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooo
oooo07oooooo0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool3000007oooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`1nooooo`7o00000@000001ooooo`000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`030000
0?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`400000
0Oooool00005o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo07oooooo0@000001ooooo`0000Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo0000
1?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0Oooo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool1
0000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000o`000?ooool0Ooooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol000010000007ooooo000Eooooo`030000
0?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`400000
0Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oo
oooooooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooo
oooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo
07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Go
oooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oo
oooo0@000001ooooo`005Oooool00`00003o0000ooooo`1oooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0Oooo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool1
0000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo
000Eooooo`0300000?l0003ooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`1nooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooo
oooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo
07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Go
oooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oo
oooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000
o`000?ooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol00001
0000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo
00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0
Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`0000Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool0Ooooool10000007ooooo0004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo07oooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000;ooooo0_l00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool3000007oooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`1nooooo`7o00000@000001ooooo`001?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
Ooooool10000007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07oooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool00004ooooool0003o0000o`00
00Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oo
oooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo
00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo
0@000001ooooo`005Oooool00`00003o0000ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0
o`00ooooooooool0O_ooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0Ooooool0
0`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00
003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000
007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000E
ooooo`0300000?l0003ooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1n
ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oo
oooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo
00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo
0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0
o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000o`00
0?ooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol000010000
007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000E
ooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1o
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`03
0?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`030000
0?l0003ooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1nooooo`7o0000
0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0
o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000;ooooo0ol00003oooo
o`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo07oooooo0@000001ooooo`000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooo
oooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool0
00Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@00
0001ooooo`0000Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo0`00001oooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool0O_ooool1o`00004000000Oooool00004ooooool0003oooooo`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07oooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000;ooooo0_l00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo0003
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1o
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eoooo
o`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1ooooo
o`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`03
0?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1oooooo`030?l0
0?oooooooooo00;ooooo00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001Gooooo00<0
0000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
Ooooool10000007ooooo000Eooooo`0300000?l0003ooooo07oooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`1nooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1o
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eoooo
o`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1ooooo
o`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`03
0?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l0
0?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oo
oooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Ooo
ool001Gooooo00<00000o`000?ooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooo
oooo07kooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool0
0`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00
003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000
007ooooo000Eooooo`0300000?l0003ooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`1nooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l0
0?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oo
oooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Ooo
ool00004ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003ooooooooo
o`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo0000
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`1oooooo`4000000Oooool000Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0O_ooool3ool0
00;ooooo0ooo0020ooooo`4000000Oooool000Cooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0`00001nooooo`?oo`000_ooool3
ool007oooooo0Ol000010000007ooooo0004o`0000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo07kooooo0ooo0002ooooo`?oo`00P?oo
ool10000007ooooo00000ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo033ooooo
00<00000ooooooooool0;oooool00`00003oooooooooo`0`ooooo`0300000?oooooooooo033ooooo
00<00000ooooooooool07?ooool10000007ooooo0005o`0000?ooooo0_l00004ooooo`;o00001Ooo
ool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`03ooooo`4000000Oooool001Goooooo`00000;0000007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-608.932, -51.9116, 3.95491, \
3.20066}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[g1, \ PlotRange \[Rule] {{\(-20\), 20}, All}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.0147151 0.00117799 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -6 -9 ]
[.875 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13251 -18 -4.5 ]
[-0.0125 .13251 0 4.5 ]
[-0.0125 .25031 -18 -4.5 ]
[-0.0125 .25031 0 4.5 ]
[-0.0125 .36811 -18 -4.5 ]
[-0.0125 .36811 0 4.5 ]
[-0.0125 .48591 -18 -4.5 ]
[-0.0125 .48591 0 4.5 ]
[-0.0125 .60371 -18 -4.5 ]
[-0.0125 .60371 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-15)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-10)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(10)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(15)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(20)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13251 m
.00625 .13251 L
s
[(100)] -0.0125 .13251 1 0 Mshowa
0 .25031 m
.00625 .25031 L
s
[(200)] -0.0125 .25031 1 0 Mshowa
0 .36811 m
.00625 .36811 L
s
[(300)] -0.0125 .36811 1 0 Mshowa
0 .48591 m
.00625 .48591 L
s
[(400)] -0.0125 .48591 1 0 Mshowa
0 .60371 m
.00625 .60371 L
s
[(500)] -0.0125 .60371 1 0 Mshowa
.125 Mabswid
0 .03827 m
.00375 .03827 L
s
0 .06183 m
.00375 .06183 L
s
0 .08539 m
.00375 .08539 L
s
0 .10895 m
.00375 .10895 L
s
0 .15607 m
.00375 .15607 L
s
0 .17963 m
.00375 .17963 L
s
0 .20319 m
.00375 .20319 L
s
0 .22675 m
.00375 .22675 L
s
0 .27387 m
.00375 .27387 L
s
0 .29743 m
.00375 .29743 L
s
0 .32099 m
.00375 .32099 L
s
0 .34455 m
.00375 .34455 L
s
0 .39167 m
.00375 .39167 L
s
0 .41523 m
.00375 .41523 L
s
0 .43879 m
.00375 .43879 L
s
0 .46235 m
.00375 .46235 L
s
0 .50947 m
.00375 .50947 L
s
0 .53303 m
.00375 .53303 L
s
0 .55659 m
.00375 .55659 L
s
0 .58015 m
.00375 .58015 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13251 m
1 .13251 L
s
.99375 .25031 m
1 .25031 L
s
.99375 .36811 m
1 .36811 L
s
.99375 .48591 m
1 .48591 L
s
.99375 .60371 m
1 .60371 L
s
.125 Mabswid
.99625 .03827 m
1 .03827 L
s
.99625 .06183 m
1 .06183 L
s
.99625 .08539 m
1 .08539 L
s
.99625 .10895 m
1 .10895 L
s
.99625 .15607 m
1 .15607 L
s
.99625 .17963 m
1 .17963 L
s
.99625 .20319 m
1 .20319 L
s
.99625 .22675 m
1 .22675 L
s
.99625 .27387 m
1 .27387 L
s
.99625 .29743 m
1 .29743 L
s
.99625 .32099 m
1 .32099 L
s
.99625 .34455 m
1 .34455 L
s
.99625 .39167 m
1 .39167 L
s
.99625 .41523 m
1 .41523 L
s
.99625 .43879 m
1 .43879 L
s
.99625 .46235 m
1 .46235 L
s
.99625 .50947 m
1 .50947 L
s
.99625 .53303 m
1 .53303 L
s
.99625 .55659 m
1 .55659 L
s
.99625 .58015 m
1 .58015 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .01472 m
0 .0155 L
s
.025 .01472 m
.025 .01557 L
s
.05 .01472 m
.05 .01566 L
s
.075 .01472 m
.075 .01578 L
s
.1 .01472 m
.1 .01593 L
s
.125 .01472 m
.125 .01613 L
s
.15 .01472 m
.15 .01644 L
s
.175 .01472 m
.175 .01694 L
s
.2 .01472 m
.2 .01795 L
s
.225 .01472 m
.225 .02095 L
s
.25 .01472 m
.25 .60332 L
s
.275 .01472 m
.275 .02024 L
s
.3 .01472 m
.3 .01732 L
s
.325 .01472 m
.325 .01633 L
s
.35 .01472 m
.35 .01582 L
s
.375 .01472 m
.375 .0155 L
s
.4 .01472 m
.4 .01528 L
s
.425 .01472 m
.425 .0151 L
s
.45 .01472 m
.45 .01496 L
s
.475 .01472 m
.475 .01483 L
s
.5 .01472 m
.5 .01472 L
s
.525 .01472 m
.525 .01483 L
s
.55 .01472 m
.55 .01496 L
s
.575 .01472 m
.575 .0151 L
s
.6 .01472 m
.6 .01528 L
s
.625 .01472 m
.625 .0155 L
s
.65 .01472 m
.65 .01582 L
s
.675 .01472 m
.675 .01633 L
s
.7 .01472 m
.7 .01732 L
s
.725 .01472 m
.725 .02024 L
s
.75 .01472 m
.75 .60332 L
s
.775 .01472 m
.775 .02095 L
s
.8 .01472 m
.8 .01795 L
s
.825 .01472 m
.825 .01694 L
s
.85 .01472 m
.85 .01644 L
s
.875 .01472 m
.875 .01613 L
s
.9 .01472 m
.9 .01593 L
s
.925 .01472 m
.925 .01578 L
s
.95 .01472 m
.95 .01566 L
s
.975 .01472 m
.975 .01557 L
s
1 .01472 m
1 .0155 L
s
.015 w
0 .0155 Mdot
.025 .01557 Mdot
.05 .01566 Mdot
.075 .01578 Mdot
.1 .01593 Mdot
.125 .01613 Mdot
.15 .01644 Mdot
.175 .01694 Mdot
.2 .01795 Mdot
.225 .02095 Mdot
.25 .60332 Mdot
.275 .02024 Mdot
.3 .01732 Mdot
.325 .01633 Mdot
.35 .01582 Mdot
.375 .0155 Mdot
.4 .01528 Mdot
.425 .0151 Mdot
.45 .01496 Mdot
.475 .01483 Mdot
.5 .01472 Mdot
.525 .01483 Mdot
.55 .01496 Mdot
.575 .0151 Mdot
.6 .01528 Mdot
.625 .0155 Mdot
.65 .01582 Mdot
.675 .01633 Mdot
.7 .01732 Mdot
.725 .02024 Mdot
.75 .60332 Mdot
.775 .02095 Mdot
.8 .01795 Mdot
.825 .01694 Mdot
.85 .01644 Mdot
.875 .01613 Mdot
.9 .01593 Mdot
.925 .01578 Mdot
.95 .01566 Mdot
.975 .01557 Mdot
1 .0155 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00<oooool3o`0000?ooooo0ol0000Hooooo`?o00001?ooool2o`0001[o
oooo0ol0000Looooo`;o00007Oooool3o`0001_ooooo0ol00004ooooo`;o00005oooool3o`0000?o
oooo0ol0000Gooooo`Go00000oooool2o`0000?ooooo000dooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00006?ooool01Ol0003ooooooooooooooooo000001[ooooo00Co0000oooooooooooo00006ooo
ool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Gooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Eoooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool002cooooo1Ol00003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool5o`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Booooo`Go00001Oooool00ol0003ooooooooo
o`0Hooooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool003Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Hooooo`04o`000?oooooooooo
o`0001oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0001Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`05o`000?oo
ooooooooooooool000000_ooool1o`00007ooooo0Oooool003Cooooo00Co0000oooooooooooooooo
1?l0000Iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006?ooool4o`0001_o
oooo00Co0000oooooooooooo00006oooool4o`0001cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Gooooo`04o`000?ooooooooooooooo`Co00005oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool003?ooooo0_l00003ooooo`03o`00
0?oooooooooo01Wooooo0_l00004ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000oooooooo
ool07?ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo01cooooo0_l00004oooo
o`04o`000?ooooooooooo`0001Kooooo0_l00003ooooo`03o`000?oooooooooo01Sooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo000dooooo`04o`000?oo
ooooooooooooo`Go00006?ooool00ol0003oooooooooo`03ooooo`;o00006Oooool5o`0001_ooooo
0_l0000Looooo`Go00006oooool00ol0003oooooooooo`03ooooo`;o00006?ooool01?l0003ooooo
ooooooooool5o`0001Oooooo0ol00004ooooo`;o00000oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool001Gooooo00<00000o`000?l00000ool00002o`000003
00000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0
1?ooool000kooooo0_l00005ooooo`0300000?oooooooooo01gooooo00?o0000ooooooooool07_oo
ool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_oo
ool00`00003oooooooooo`04ooooo`003Oooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo0?oooooo0_ooool00`00003oooooooooo`04ooooo`003Oooool01?l0003oooooooooool0
0002ooooo`?oo`0000Co0000oooooooooooooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo
0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0005ooooo`03ool00?oooooooooo00?ooooo
00<0o`00ooooooooool01?ooool00`3o003oooooooooo`03ooooo`030?l00?oooooooooo00;ooooo
0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo
0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo
0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001Oooool00`3o003ooooo
ooooo`04ooooo`030?l00?oooooooooo00?ooooo00<0o`00ooooooooool01?ooool00ooo003ooooo
ooooo`02ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo
0ooo0004ooooo`?oo`000oooool3ool000Kooooo000=ooooo`04o`000?ooooooooooo`0000;ooooo
0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo
0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0005ooooo`030?l00?oooooooooo00;ooooo
0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo
0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo
0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo
0ooo0005ooooo`030?l00?oooooooooo00;ooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo
0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo
0ooo0006ooooo`003Oooool01?l0003oooooooooool00002ooooo`?oo`001?ooool3ool000?ooooo
0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo
0ooo0004ooooo`?oo`001Oooool00`3o003oooooooooo`02ooooo`?oo`000oooool3ool000Cooooo
0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo
0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo
0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`001Oooool00`3o003ooooo
ooooo`02ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo
0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001_ooool000gooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`0_ooooo`?oo`001?ooool3ool000Gooooo
00<0o`00ooooooooool00_ooool3ool007;ooooo0ooo0005ooooo`030?l00?oooooooooo00;ooooo
0ooo0003ooooo`?oo`00<oooool00`00003oooooooooo`04ooooo`003_ooool2o`0000Gooooo00<0
0000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<0
0000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1o
ooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000o`00
0?ooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03gooooo00?o00000000
0?ooool01Oooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`03
0?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0
?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool0
1?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oo
oooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool0
0`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool0
01Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo
03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003o
ooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo
00<00000o`000?ooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03gooooo
00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0?_ooool00`3o003ooooooooo
o`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000
ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000
ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1ooooo
o`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooooooo
ool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000oooooooo
ool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l0
0?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0?_oo
ool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03gooooo00?o000000000?ooool01Ooo
ool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooo
oooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o
003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Go
oooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03ko
oooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003ooooo
ooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<0
0000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<0
0000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0?_ooool00`3o003oooooooooo`1o
ooooo`030?l00?oooooooooo03gooooo00?o000000000?ooool01Oooool001Gooooo00<00000oooo
ooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000oooo
ooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`03
0?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool00004ooooool0003o0000o`0000Co
oooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0nooooo`030?l00?oooooooooo07oo
oooo00<0o`00ooooooooool0?_ooool00`00003oooooooooo`04ooooo`000_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`0nooooo`030?l00?oooooooooo07oooooo00<0o`00ooooooooool0?_ooool00`00
003oooooooooo`04ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0nooooo`030?l00?oooooo
oooo07oooooo00<0o`00ooooooooool0?_ooool00`00003oooooooooo`04ooooo`000_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003o0000ooooo`0nooooo`030?l00?oooooooooo07oooooo00<0o`00ooooooooool0??oo
ool3000000Kooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0
Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo00000ooooooo0000o`00
0004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`0nooooo`030?l00?oooooooooo07oooooo00<0o`00ooooooooool0?_ooool00`00003o
ooooooooo`04ooooo`000_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo
00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo
00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003ooooooooo
o`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000
ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000
ooooooooool01?ooool001Gooooo00<00000o`000?ooool0?_ooool00`3o003oooooooooo`1ooooo
o`030?l00?oooooooooo03gooooo00?o000000000?ooool01Oooool001Gooooo00<00000oooooooo
ool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000oooooooo
ool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l0
0?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_oo
ool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?oo
ool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooo
oooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o
003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Go
oooo00<00000o`000?ooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03go
oooo00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0?_ooool00`3o003ooooo
ooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<0
0000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<0
0000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1o
ooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooo
ooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000oooo
ooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`03
0?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0
?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03gooooo00?o000000000?ooool0
1Oooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oo
oooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool0
0`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool0
01Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo
03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003o
ooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo
00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo
00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0?_ooool00`3o003ooooooooo
o`1oooooo`030?l00?oooooooooo03gooooo00?o000000000?ooool01Oooool001Gooooo00<00000
ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000
ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1ooooo
o`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooooooo
ool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000oooooooo
ool01?ooool000Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo03kooooo
00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo
00001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o
003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo0002ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooo
oooo00Cooooo0003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00<00000o`000?ooool0?_ooool00`3o003ooooooooo
o`1oooooo`030?l00?oooooooooo03cooooo0`000006ooooo`0000Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`0nooooo`030?l00?oooooooooo07oooooo00<0o`00ooooooooool0?_ooool00`00003o
ooooooooo`04ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0nooooo`030?l00?oooooo
oooo07oooooo00<0o`00ooooooooool0?_ooool00`00003oooooooooo`04ooooo`0000Coooooo`00
0?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo03kooooo00<0o`00
ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo000Eoooo
o`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0noooo
o`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00oooooooo
ool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo000Eooooo`030000
0?l0003ooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0mooooo`03o`00
0000003ooooo00Gooooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Oooo
ool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooo
oooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooo
oooo00Cooooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o
003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo03ko
oooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Co
oooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003ooooo
ooooo`0nooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?l0003ooooo03kooooo00<0
o`00ooooooooool0Ooooool00`3o003oooooooooo`0mooooo`03o`000000003ooooo00Gooooo000E
ooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0n
ooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00oooo
ooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo000Eooooo`03
00000?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`03
00000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0
Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oo
oooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oo
oooooooo00Cooooo000Eooooo`0300000?l0003ooooo03kooooo00<0o`00ooooooooool0Ooooool0
0`3o003oooooooooo`0mooooo`03o`000000003ooooo00Gooooo000Eooooo`0300000?oooooooooo
03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo
00Cooooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003o
ooooooooo`0nooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo03kooooo
00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo
000Eooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003ooooooooo
o`0nooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00
ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo000Eoooo
o`0300000?l0003ooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0moooo
o`03o`000000003ooooo00Gooooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00oooooooo
ool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo000Eooooo`030000
0?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`030000
0?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Oooo
ool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo00001?oooooo0000o`000?l0
0004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0?_ooool00`3o003ooooooooo
o`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool00005o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03ko
oooo00<00000ooooooooool01?ooool000Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`000?ooool0?_ooool00`3o
003oooooooooo`1oooooo`030?l00?oooooooooo03cooooo0`000006ooooo`000_ooool2o`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`0300000?oooooo
oooo00Cooooo0004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`0300000?oooooooooo03kooooo00<0o`00ooooooooool0Oooo
ool00`3o003oooooooooo`0nooooo`0300000?oooooooooo00Cooooo00001Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?oooooooooo03kooooo00<0o`00ooooooooool0Ooooool00`3o003oooooooooo`0nooooo`03
00000?oooooooooo00Cooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Go
oooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03ko
oooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003ooooo
ooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<0
0000o`000?ooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03gooooo00?o
000000000?ooool01Oooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1o
ooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooo
ooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000oooo
ooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`03
0?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0
?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool0
1?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oo
oooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0?_ooool0
0`3o003oooooooooo`1oooooo`030?l00?oooooooooo03gooooo00?o000000000?ooool01Oooool0
01Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo
03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003o
ooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo
00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo
00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003ooooooooo
o`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000
ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000
ooooooooool01?ooool001Gooooo00<00000o`000?ooool0?_ooool00`3o003oooooooooo`1ooooo
o`030?l00?oooooooooo03gooooo00?o000000000?ooool01Oooool001Gooooo00<00000oooooooo
ool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000oooooooo
ool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l0
0?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_oo
ool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?oo
ool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooo
oooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o
003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Go
oooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03ko
oooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0?_ooool00`3o003ooooo
ooooo`1oooooo`030?l00?oooooooooo03gooooo00?o000000000?ooool01Oooool001Gooooo00<0
0000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<0
0000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1o
ooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool000;ooooo0ol00003oooo
o`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1ooooo
o`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0`00003oooooooooo`0nooooo`030?l00?oooooooooo07oooooo00<0o`00ooooooooool0?_ooool0
0`00003oooooooooo`04ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`0nooooo`030?l00?oooooooooo07oooooo00<0
o`00ooooooooool0?_ooool00`00003oooooooooo`04ooooo`0000Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000?oo
ool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03cooooo0`000006ooooo`00
00Coooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooo
oooo03kooooo00<00000ooooooooool01?ooool000;ooooo0_l00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0nooooo`030?l00?oo
oooooooo07oooooo00<0o`00ooooooooool0?_ooool00`00003oooooooooo`04ooooo`000oooool0
0ol0003oooooooooo`02ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0?_ooool0
0`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool0
01Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo
03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003o
ooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo
00<00000o`000?ooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03gooooo
00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0?_ooool00`3o003ooooooooo
o`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000
ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000
ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1ooooo
o`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooooooo
ool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000oooooooo
ool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l0
0?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0?_oo
ool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03gooooo00?o000000000?ooool01Ooo
ool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooo
oooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o
003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Go
oooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03ko
oooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003ooooo
ooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<0
0000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<0
0000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0?_ooool00`3o003oooooooooo`1o
ooooo`030?l00?oooooooooo03gooooo00?o000000000?ooool01Oooool001Gooooo00<00000oooo
ooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000oooo
ooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`03
0?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0
?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool0
1?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oo
oooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool0
0`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool0
01Gooooo00<00000o`000?ooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo
03gooooo00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0?_ooool00`3o003o
ooooooooo`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool001Gooooo
00<00000ooooooooool0?_ooool00`3o003oooooooooo`1oooooo`030?l00?oooooooooo03kooooo
00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0?_ooool00`3o003ooooooooo
o`1oooooo`030?l00?oooooooooo03kooooo00<00000ooooooooool01?ooool00004ooooool0003o
0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0nooooo`030?l00?oo
oooooooo07oooooo00<0o`00ooooooooool0?_ooool00`00003oooooooooo`04ooooo`0000Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`0nooooo`030?l00?oooooooooo07oooooo00<0o`00oooooooo
ool0?_ooool00`00003oooooooooo`04ooooo`001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003o0000ooooo`0loooo
o`?oo`00Ooooool3ool003kooooo0`000006ooooo`001?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0l
ooooo`?oo`00Ooooool3ool0043ooooo00<00000ooooooooool01?ooool000Co00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Looooo`?oo`007oooool00`00003oooooooooo`0Nooooo`0300000?oo
oooooooo01gooooo00<00000ooooooooool07?ooool3ool001oooooo00<00000ooooooooool07_oo
ool00`00003oooooooooo`04ooooo`0000?o0000ooooooooool01?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00`00003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00`00003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00`00003ooooo
ooooo`04ooooo`001Ol00003ooooo`;o00001?ooool2o`0000Goooooo`000006000000Kooooo003o
ooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-23.2721, -58.0341, \
0.153994, 3.26815}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example #1(b): simple sinusoid with DC offset", "Subsection"],

Cell[CellGroupData[{

Cell["Continuous-time waveform", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f1[t_] := Sin[2  \[Pi]\ 10  t] + 1;\)\), "\[IndentingNewLine]", 
    \(\(Plot[f1[t], {t, 0, 1}, \ 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\[Florin][t] \[Equal] f1[t]\  // \ TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.294305 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60333 -6 -4.5 ]
[-0.0125 .60333 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60333 m
.00625 .60333 L
s
[(2)] -0.0125 .60333 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60333 m
1 .60333 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30902 m
.02846 .39784 L
.03279 .47329 L
.03754 .54057 L
.0402 .56874 L
.04262 .58745 L
.04385 .59428 L
.04516 .59946 L
.04627 .60217 L
.0475 .60332 L
.04882 .6024 L
.04957 .6009 L
.05024 .59892 L
.05156 .59344 L
.05281 .58624 L
.0552 .56729 L
.05742 .54396 L
.06244 .47342 L
.07295 .27961 L
.0781 .18366 L
.08284 .10781 L
.08545 .07397 L
.08832 .04487 L
.08981 .03341 L
.0912 .02511 L
.09197 .02155 L
.09267 .01894 L
.09348 .0167 L
.09424 .01535 L
.09549 .01476 L
.09612 .01521 L
.09681 .0163 L
.09804 .01973 L
.09919 .02468 L
.10055 .03257 L
.10179 .04175 L
.10458 .06886 L
.1145 .22212 L
.12511 .42355 L
.13025 .50731 L
.13278 .54066 L
.13511 .56574 L
.13723 .58329 L
.1383 .59012 L
.13947 .59603 L
.14065 .60022 L
.14192 .60276 L
.14311 .60328 L
.1442 .60216 L
.14544 .59907 L
Mistroke
.14655 .59461 L
.14784 .58754 L
.14906 .57904 L
.15122 .55965 L
.15356 .53299 L
.15887 .4538 L
.16375 .36524 L
.17272 .19465 L
.17765 .11398 L
.18007 .08136 L
.18231 .05638 L
.18476 .03539 L
.18605 .02716 L
.18671 .02375 L
.18742 .02067 L
.18856 .01705 L
.18963 .01517 L
.19091 .01483 L
.19207 .01635 L
.19317 .01936 L
.19419 .02352 L
.19531 .02958 L
.19651 .03773 L
.19896 .05958 L
.20117 .08503 L
.20629 .16079 L
.21182 .26131 L
.21701 .36154 L
.22185 .44991 L
.22681 .52551 L
.22898 .55171 L
.23134 .57459 L
.23268 .58476 L
.23392 .59225 L
.23511 .59763 L
.23637 .60142 L
.23769 .60322 L
.23893 .60287 L
.23965 .60179 L
.2403 .60023 L
.24101 .59789 L
.24177 .59473 L
.24308 .58753 L
.24428 .57915 L
.24697 .55428 L
.25182 .49072 L
.26282 .2912 L
.27213 .12525 L
.27682 .06396 L
.2781 .05103 L
Mistroke
.27949 .03921 L
.28078 .03016 L
.28198 .02358 L
.28271 .02047 L
.28337 .01823 L
.2841 .01638 L
.28488 .01516 L
.28556 .01473 L
.2863 .01493 L
.28699 .01576 L
.28763 .01707 L
.28883 .02091 L
.29014 .02719 L
.29152 .03601 L
.2928 .04626 L
.29761 .10082 L
.30277 .18223 L
.31296 .3751 L
.31833 .47048 L
.32127 .51491 L
.32403 .54959 L
.32642 .57325 L
.32765 .5829 L
.329 .59138 L
.33039 .59781 L
.33115 .60029 L
.33186 .60194 L
.33313 .6033 L
.33384 .60316 L
.33448 .60248 L
.33573 .59966 L
.33687 .59534 L
.33813 .58872 L
.33946 .57961 L
.3417 .55966 L
.34415 .53147 L
.35498 .35091 L
.36031 .248 L
.36525 .15903 L
.37009 .08713 L
.37219 .06249 L
.37447 .04124 L
.37578 .03171 L
.37698 .02478 L
.37812 .01982 L
.37933 .01639 L
.38061 .01479 L
.38181 .01518 L
.38311 .0177 L
.38385 .02006 L
Mistroke
.38451 .0228 L
.38566 .02881 L
.38693 .0373 L
.38949 .06018 L
.39409 .11844 L
.40448 .30352 L
.4091 .39219 L
.41416 .47996 L
.41646 .51433 L
.41893 .54573 L
.42105 .56787 L
.42336 .58609 L
.42405 .59033 L
.42478 .59417 L
.42609 .5994 L
.42732 .60232 L
.42802 .60313 L
.42867 .60332 L
.42989 .60222 L
.43099 .59957 L
.43227 .59459 L
.43349 .58798 L
.43579 .57055 L
.43793 .54903 L
.44276 .48357 L
.45352 .28687 L
.4588 .18814 L
.46363 .11007 L
.468 .0566 L
.4702 .03738 L
.47145 .02899 L
.47261 .02289 L
.47387 .01816 L
.47506 .01553 L
.47613 .01472 L
.47729 .01549 L
.47855 .01828 L
.47919 .02045 L
.47989 .02343 L
.48113 .0302 L
.48229 .03821 L
.48495 .0625 L
.48748 .09259 L
.49222 .16446 L
.50289 .36473 L
.50784 .45447 L
.51249 .52504 L
.51507 .55577 L
.51643 .56912 L
.51786 .58095 L
Mistroke
.51907 .58905 L
.51971 .59262 L
.52039 .59589 L
.5216 .6002 L
.52272 .60257 L
.52395 .60331 L
.52509 .60227 L
.52634 .59922 L
.52697 .59694 L
.52767 .59384 L
.52883 .58731 L
.53008 .57846 L
.53235 .55783 L
.53693 .49982 L
.54112 .43138 L
.55029 .25747 L
.55532 .16579 L
.56007 .09352 L
.56277 .0614 L
.5642 .04759 L
.5657 .03549 L
.56697 .02738 L
.56764 .02387 L
.56836 .02073 L
.56962 .0168 L
.57081 .01496 L
.57209 .01499 L
.57281 .01594 L
.57348 .01742 L
.57471 .0216 L
.57602 .02813 L
.57719 .03571 L
.57828 .04431 L
.58078 .06901 L
.59923 .3856 L
.60428 .47437 L
.60706 .51598 L
.60969 .54895 L
.61213 .57322 L
.61342 .58328 L
.61479 .59177 L
.61593 .59714 L
.6172 .60114 L
.61835 .60301 L
.61943 .60323 L
.62066 .60166 L
.62136 .59991 L
.62201 .59773 L
.6232 .59238 L
.62446 .58475 L
Mistroke
.62688 .56493 L
.62907 .54134 L
.63441 .46475 L
.63943 .37492 L
.64969 .18081 L
.65485 .09966 L
.65779 .0638 L
.6591 .05066 L
.66052 .03857 L
.66187 .0293 L
.66313 .02271 L
.66432 .01823 L
.66559 .01545 L
.66673 .01472 L
.66779 .01552 L
.66896 .01807 L
.67022 .02275 L
.67148 .02941 L
.67286 .03892 L
.67564 .06476 L
.67821 .09602 L
.68061 .13063 L
.68947 .28952 L
.69908 .46725 L
.70174 .50816 L
.70456 .54477 L
.70696 .56964 L
.70834 .58101 L
.70961 .58942 L
.71088 .59591 L
.71208 .60022 L
.71335 .60277 L
.71407 .6033 L
.71474 .60319 L
.71596 .60153 L
.71707 .59838 L
.71834 .59284 L
.71954 .5858 L
.72181 .5678 L
.7242 .54257 L
.72848 .48344 L
.73813 .30829 L
.74764 .1357 L
.75038 .0958 L
.75297 .06442 L
.75529 .04229 L
.75659 .03259 L
.75782 .02536 L
.75888 .02057 L
.76002 .01699 L
Mistroke
.76128 .01496 L
.76244 .0149 L
.76365 .01666 L
.76496 .02068 L
.7662 .02646 L
.76735 .03353 L
.76959 .05173 L
.77162 .07309 L
.77616 .13563 L
.7863 .32038 L
.79184 .42472 L
.79701 .50864 L
.79928 .53862 L
.80143 .56232 L
.80261 .57325 L
.8039 .58331 L
.80507 .59069 L
.80616 .59611 L
.80736 .60034 L
.808 .60184 L
.80869 .60288 L
.80937 .60331 L
.81009 .60312 L
.81138 .60113 L
.81257 .5974 L
.81368 .59232 L
.8149 .58499 L
.81621 .57518 L
.8188 .54996 L
.82118 .52046 L
.82658 .43579 L
.83639 .25016 L
.84099 .16665 L
.84529 .10014 L
.84764 .07067 L
.84979 .04869 L
.85217 .03041 L
.85348 .02325 L
.85473 .01843 L
.85598 .01558 L
.85668 .01485 L
.85733 .01474 L
.85851 .01592 L
.85977 .01912 L
.86089 .02369 L
.86195 .02936 L
.86433 .0472 L
.86692 .0738 L
.86927 .10399 L
.87456 .18853 L
Mistroke
.88348 .35789 L
.88837 .44733 L
.89295 .51844 L
.89542 .54913 L
.89767 .57172 L
.89887 .58138 L
.90018 .58998 L
.9015 .59652 L
.90221 .59917 L
.90288 .60106 L
.90408 .60302 L
.90521 .6032 L
.90622 .60196 L
.90732 .59915 L
.90852 .59434 L
.90979 .58731 L
.91206 .56988 L
.91452 .54437 L
.91717 .51009 L
.92195 .43352 L
.93283 .2275 L
.93774 .14164 L
.94044 .10146 L
.94297 .06963 L
.94442 .0544 L
.94598 .04055 L
.94728 .03121 L
.94802 .02681 L
.94871 .02332 L
.94941 .02034 L
.95006 .01817 L
.95074 .01643 L
.95148 .01524 L
.95279 .01482 L
.95402 .01644 L
.95518 .01972 L
.95645 .02528 L
.95779 .03323 L
.95903 .04262 L
.96126 .06383 L
.96366 .09255 L
.97413 .26914 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006_ooool2o`0002_ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00008oooool2
o`0000Cooooo00?o0000ooooooooool00oooool3o`0002Cooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol0000Tooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000:_ooool3
o`0000Oooooo000Iooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool0000Rooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool08_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003ooooo
ooooo`06ooooo`006Oooool01?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00007ooooo`Go00008oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003oooooooooo`06ooooo`00
6Oooool01?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002Cooooo00Co
0000oooooooooooo00001oooool4o`0002?ooooo00Co0000oooooooooooo00002?ooool3o`0002_o
oooo00?o0000ooooooooool01_ooool001Wooooo00Co0000oooooooooooo0000:Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000002Cooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`0Tooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Zoooo
o`03o`000?oooooooooo00Kooooo000Iooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002;ooooo00Co0000oooooooooooo0000
2Oooool2o`0002Cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Sooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Yooooo`;o00002?ooool0
01[ooooo0_l0000[ooooo`;o00002Oooool3o`0002Cooooo0_l0000;ooooo`03o`000?oooooooooo
02?ooooo0_l0000:ooooo`;o00009?ooool2o`0000Wooooo0ol0000[ooooo`03o`000?oooooooooo
00Kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooo
oooo00002ol00001ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00`00003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00`00003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool00oooool1o`00007o
oooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00`00003o
ooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00<00000ooooooooool0<?ooool00`00003o
ooooooooo`0_ooooo`0300000?oooooooooo033ooooo00<00000ooooooooool00oooool1o`00007o
oooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0ooooool7ooooo`7o
00000Oooool000gooooo00Co0000oooooooooooo00001?ooool3o`0001Kooooo0_l00?lGooooo`;o
003o5oooool2o`00oaSooooo00?o003oooooooooool05_ooool2o`00oaOooooo0_l00?lHooooo`03
o`00oooooooooooo01Kooooo0_l00?lGooooo`;o003o5oooool2o`00o`[ooooo0_l00001ooooo`00
3Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Gooooo00?o003oooooool0
0?l05oooool2o`00oaOooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Gooooo`;o
003o5oooool2o`00oaOooooo0_l00?lGooooo`03o`00oooooooo003o01Oooooo0_l00?lGooooo`03
o`00o`000?oooooo00[ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo01Gooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Gooooo`03
o`00oooooooo003o01Kooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Gooooo`;o
003o5oooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Kooooo00?o003oooooool0
0?l05oooool00ol00?l0003oooooo`0:ooooo`7o00000Oooool000kooooo0_l00005ooooo`03o`00
0?oooooooooo01Gooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Gooooo`03o`00
oooooooo003o01Kooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Fooooo`04o`00
ooooooooooooo`00oaKooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0Fooooo`03
o`00oooooooo003o01Kooooo00Co003oooooooooool0003o2_ooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo01Gooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lE
ooooo`04o`00ooooooooooooo`00oaKooooo00?o003oooooool00?l05_ooool01?l00?oooooooooo
ool00?lEooooo`04o`00ooooooooooooo`00oaKooooo00?o003oooooool00?l05_ooool00ol00?oo
ooooo`00o`0Fooooo`04o`00ooooooooooooo`00oaGooooo00Co003oooooooooool0003o2_ooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo01Gooooo00Co003ooooooooooooo003o5Oooool0
1?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaKooooo00?o003oooooool00?l0
5_ooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaKooooo00?o003ooooo
ool00?l05_ooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaGooooo00@0
003oooooooooool0003o2_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo01Gooooo00Co
003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00
oaGooooo00Go003oooooooooooooooooo`00o`0Eooooo`04o`00ooooooooooooo`00oaGooooo00Co
003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lFooooo`04o`00ooooooooooooo`00
oaGooooo00Co003ooooooooooooo003o5Oooool010000?ooooooooooo`000?l:ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool05?ooool01Ol00?oooooooooooooooooo003o01Gooooo00Co
003ooooooooooooo003o5Oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooo
ooooooooo`00o`0Eooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Ooo
ool01?l00?ooooooooooool00?lEooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oo
oooooooooooooooo003o01Gooooo00@0003oooooooooool0003o2_ooool1o`00007ooooo000Eoooo
o`;o00005Oooool01Ol00?oooooooooooooooooo003o01Gooooo00Co003ooooooooooooo003o5Ooo
ool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Eooooo`04
o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool0
0?lEooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Go
oooo00@0003oooooooooool0003o2Oooool2o`00007ooooo000Eooooo`03o`000?oooooooooo01Co
oooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05Oooool0
1Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00
ooooooooooooooooool00?l05Oooool01?l00?ooooooooooool00?lEooooo`04o`00oooooooooooo
o`00oaGooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l0
5Oooool010000?ooooooooooo`000?l:ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Booooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo
003o01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`04o`00oooooooo
ooooo`00oaGooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool0
0?l05?ooool01Ol00?oooooooooooooooooo003o01Gooooo00@0003oooooooooool0003o2_ooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool01Ol0
0?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Gooooo
00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol0
0?oooooooooooooooooo003o01Gooooo00D0003ooooooooooooooooo0000o`09ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo003o01Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00Go
003oooooooooooooooooo`00o`0Dooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool01@000?ooooooooooooooool0003o00Wooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`0Dooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Booooo`05o`00ooooooooooooooooool00?l05?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool01oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo01;ooooo00Go003oooooooooooooooooo`00o`0Dooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00<0003oooooooooool00_ooool00`000?ooooooooooo`07ooooo`7o00000Oooool001Gooooo
0_l0000Eooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Booooo`05o`00ooooooooooooooooool00?l05?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03
0000oooooooooooo00;ooooo00<0003oooooooooool01_ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo017ooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`07ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo01;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04Oooool00`000?ooooooooooo`03ooooo`030000oooo
oooooooo00Kooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`030000oooooooo
oooo00?ooooo00<0003oooooooooool01_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
01Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`06ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo00Ko
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`030000oooooooooooo00Cooooo
00<0003oooooooooool01_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo01?ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo013ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00<0
003oooooooooool01?ooool00`000?ooooooooooo`06ooooo`7o00000Oooool001Gooooo0_l0000D
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool01Oooool2o`00007ooooo000Eoooo
o`03o`000?oooooooooo01?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00oooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`06oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00`000?ooooooooooo`04ooooo`03
0000oooooooooooo00Kooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`030000
oooooooooooo00Cooooo00<0003oooooooooool01_ooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo01?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00<0003oooooooooool01?ooool00`000?ooooooooooo`06ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03oooool00`000?ooooooooooo`04ooooo`030000oooooooo
oooo00Kooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`030000oooooooooooo
00Cooooo00<0003oooooooooool01_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo01?o
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oo
oooo00<0003oooooooooool01?ooool00`000?ooooooooooo`06ooooo`7o00000Oooool001Gooooo
0_l0000Dooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0?ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool01Oooool2o`00007ooooo
000Eooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00oooooo00<0003oooooooooool01?ooool00`000?oooooooooo
o`06ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool00`000?ooooooooooo`05
ooooo`030000oooooooooooo00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0Coooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?oooo
o`030000oooooooooooo00Gooooo00<0003oooooooooool01Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo01;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0@ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00kooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`05ooooo`7o
00000Oooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`00
0?oooooooooo01;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00kooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`05ooooo`7o0000
0Oooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03_ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00Go
oooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`00000;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03_ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00Go
oooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`00000;ooooo`03o`000?oooooooooo00;o
oooo0ol0000Booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0>ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool01?ooool2o`00007o
oooo00001Ooooooo0000oooooooooooo000000Oooooo1?l00005ooooo`03o`000?oooooooooo01;o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00<0003oooooooooool01_ooool00`000?ooooooooooo`05ooooo`7o00000Oooool00005oooo
ool0003oooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00<0003oooooooooool01_ooool00`000?ooooooooooo`05ooooo`7o00000Oooool000;ooooo
0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`030000oooooooooooo00Kooooo
00<0003oooooooooool01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo01;ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00<0
003oooooooooool01_ooool00`000?ooooooooooo`05ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool04_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03Oooool00`000?ooooooooooo`06ooooo`030000oooooooooooo00Gooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`030000oooooooooooo00Kooooo00<0003ooooo
ooooool01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo01;ooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`030000oooooooooooo00gooooo00<0003ooooooooo
ool01_ooool00`000?ooooooooooo`05ooooo`7o00000Oooool001Gooooo0_l0000Cooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00`000?ooooooooooo`0=ooooo`030000
oooooooooooo00Kooooo00<0003oooooooooool01?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo01;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`030000oooo
oooooooo00gooooo00<0003oooooooooool01_ooool00`000?ooooooooooo`05ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Kooooo00<0003oooooooooool03Oooool00`000?ooooooooooo`06ooooo`030000oooooooo
oooo00Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo
00Kooooo00<0003oooooooooool01Oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo01;o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`030000oooooooooooo00co
oooo00<0003oooooooooool01oooool00`000?ooooooooooo`05ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool04Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo
00<0003oooooooooool03?ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01oooool00`000?ooooooooooo`0<ooooo`030000oooooooooooo00Oooooo00<0
003oooooooooool01Oooool1o`00007ooooo000Eooooo`;o00004_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`07
ooooo`030000oooooooooooo00Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`0Aoooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00`000?ooooooooooo`0<oooo
o`030000oooooooooooo00Oooooo00<0003oooooooooool01Oooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo017ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
0000oooooooooooo00cooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`04ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Oooooo00<0003oooooooooool03?ooool00`000?ooooooooooo`08ooooo`030000
oooooooooooo00Cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0Aooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool02?ooool00`000?ooooooooooo`0;ooooo`030000oooo
oooooooo00Sooooo00<0003oooooooooool01?ooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo017ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`030000oooooooo
oooo00_ooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`04ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00<0003oooooooooool02oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo
00Cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00So
oooo00<0003oooooooooool01?ooool1o`00007ooooo000Eooooo`;o00004_ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00<0003oooooooooool02oooool00`000?oooooo
ooooo`08ooooo`030000oooooooooooo00?ooooo0_l00001ooooo`005Oooool00ol0003ooooooooo
o`0Aooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00`000?oooooooooo
o`0;ooooo`030000oooooooooooo00Sooooo00<0003oooooooooool01?ooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`030000oooooooooooo00_ooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`04
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Sooooo00<0003oooooooooool02oooool00`000?ooooooooooo`08oooo
o`030000oooooooooooo00Cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0@ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00`000?ooooooooooo`0;ooooo`03
0000oooooooooooo00Sooooo00<0003oooooooooool01?ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo013ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`030000
oooooooooooo00_ooooo00<0003oooooooooool02?ooool00`000?ooooooooooo`04ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00<0003oooooooooool02oooool00`000?ooooooooooo`08ooooo`030000oooo
oooooooo00Cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00`000?ooooooooooo`0;ooooo`030000oooooooo
oooo00Sooooo00<0003oooooooooool01?ooool1o`00007ooooo000Eooooo`;o00004Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00<0003oooooooooool02oooool00`00
0?ooooooooooo`08ooooo`030000oooooooooooo00?ooooo0_l00001ooooo`005Oooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool01?ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`04ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool04?ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0@
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool00oooool1o`00007ooooo000=oooo
o`?o00001Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool00oooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00?ooooo0Ol00001ooooo`00
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`03ooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?oo
ool00ol00000000000000003ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`02ooooo`;o00000Oooool000kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool04?ooool1
o`00007ooooo000=ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool04?ooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo013o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool04?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0@ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo013ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool04?ooool1o`00007ooooo000Eooooo`;o00001?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00oooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool04?ooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00_ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0@ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo013ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool04?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Co
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0@ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo013ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool04?ooool1o`00007ooooo000Eooooo`;o00001Oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00oooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool04?ooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo00Cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0@ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo013ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`04ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`030000oooo
oooooooo00Oooooo00<0003oooooooooool04Oooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00cooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0Aooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
017ooooo0Ol00001ooooo`005Oooool2o`0000Gooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00<0003oooooooooool01oooool00`000?oo
ooooooooo`0@ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool01?ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00`000?oooooo
ooooo`07ooooo`030000oooooooooooo017ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0<ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool04Oooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0A
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00`000?ooooooooooo`07oooo
o`030000oooooooooooo017ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`04ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03
0000oooooooooooo00Oooooo00<0003oooooooooool04Oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0Aooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Kooooo00?o003oooooooooool03Oooool00`000?ooooooooooo`07ooooo`030000oooo
oooooooo017ooooo0Ol00001ooooo`005Oooool2o`0000Kooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00<0003oooooooooool01oooool0
0`000?ooooooooooo`0@ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00`00
0?ooooooooooo`06ooooo`030000oooooooooooo017ooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0>ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool04Oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00kooooo00<0003oooooooooool01_ooool00`000?oooooo
ooooo`0Aooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00`000?oooooooooo
o`06ooooo`030000oooooooooooo017ooooo0Ol00001ooooo`0000Coooooo`000?l0003o00001?oo
ool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`030000oooo
oooooooo00Kooooo00<0003oooooooooool04Oooool1o`00007ooooo0002ooooo`03o`000?oooooo
oooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00<0
003oooooooooool01_ooool00`000?ooooooooooo`0Aooooo`7o00000Oooool000;ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00<0003o
ooooooooool01_ooool00`000?ooooooooooo`0Aooooo`7o00000Oooool000;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`?o00001_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool00`000?ooooooooooo`05oooo
o`030000oooooooooooo017ooooo0_l00001ooooo`000_ooool00ol0003oooooooooo`07ooooo`Co
00001Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0>ooooo`030000oooooooooooo00Gooooo00<0003ooooooooo
ool04_ooool1o`00007ooooo00000ooooooo0000o`000009ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03_ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo01;ooooo
0Ol00001ooooo`000_ooool00ol0003oooooooooo`07ooooo`Go00001?ooool00ol0003ooooooooo
o`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?oooooooooo
o`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0>ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool04_ooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05
ooooo`03o`00oooooooooooo00kooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0B
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00`000?ooooooooooo`05oooo
o`030000oooooooooooo01;ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`06ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
0000oooooooooooo00Gooooo00<0003oooooooooool04_ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00oooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0Booooo`7o0000
0Oooool001Gooooo0_l00007ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_oo
ool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0@ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool04Ooo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo013ooooo00<0003oooooooooool01?ooool0
0`000?ooooooooooo`0Booooo`7o00000Oooool001Gooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00`00
0?ooooooooooo`03ooooo`030000oooooooooooo01?ooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0@ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool04oooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo013ooooo00<0003oooooooooool00oooool00`000?oooooo
ooooo`0Cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00`000?oooooooooo
o`03ooooo`030000oooooooooooo01?ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`07
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0@
ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool04oooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo013ooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0Coooo
o`7o00000Oooool001Gooooo0_l00008ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0@ooooo`030000oooooooooooo00?ooooo00<0003ooooooooo
ool04_ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
4?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo013ooooo00<0003oooooooooool0
0oooool00`000?ooooooooooo`0Cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?oo
ool00`000?ooooooooooo`03ooooo`030000oooooooooooo01?ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0@ooooo`030000oooooooooooo00?ooooo00<0003oooooooooool04oooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00<0003oooooooooool00oooool00`00
0?ooooooooooo`0Cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00oooool00ol00?oo
ooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo01?ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Booooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Booooo`030000oooooooooooo00;ooooo00<0003oooooooooool04oooool1o`00007ooooo
000Eooooo`;o00002?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l0
5?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool00?l05?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00`000?oo
ooooooooo`02ooooo`030000oooooooooooo01;ooooo0_l00001ooooo`005Oooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00Go003oooooooooooooooooo`00o`0Dooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo01;ooooo00Go003oooooooooooooooooo`00o`0Dooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`030000oooooooooooo
00;ooooo00<0003oooooooooool04oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Oo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04_ooool01Ol00?oooooooooooooooooo003o01Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool04_ooool01Ol00?oooooooooooooooooo003o01Cooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00<0003oooooooooool00_ooool0
0`000?ooooooooooo`0Cooooo`7o00000Oooool001Gooooo00?o0000ooooooooool01oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00Go003oooooooooooooooooo`00o`0D
ooooo`05o`00ooooooooooooooooool00?l05?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`05o`00oooo
ooooooooooooool00?l05?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Booooo`05o`00ooooooooooooooooool0
0?l05?ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo01?ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oo
oooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
oooo01;ooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l0
5Oooool01?l00?ooooooooooool00?lEooooo`05o`00ooooooooooooooooool00?l05?ooool01@00
0?ooooooooooooooool0003o01Kooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`08oooo
o`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go
003oooooooooooooooooo`00o`0Dooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
4_ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Doooo
o`05o`00ooooooooooooooooool00?l05Oooool01?l00?ooooooooooool00?lEooooo`05o`00oooo
ooooooooooooool00?l05?ooool01@000?ooooooooooooooool0003o01Kooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oo
oooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Eooooo`05o`00oooooooo
ooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooooooo
ooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05Oooool01?l00?ooooooooooool00?lE
ooooo`05o`00ooooooooooooooooool00?l05?ooool01@000?ooooooooooooooool0003o01Kooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`08ooooo`05o`00ooooooooooooooooool00?l0
5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Eoooo
o`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go
003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05Oooool01?l00?oo
ooooooooool00?lEooooo`05o`00ooooooooooooooooool00?l05?ooool01@000?oooooooooooooo
ool0003o01Kooooo0Ol00001ooooo`005Oooool2o`0000Wooooo00Go003oooooooooooooooooo`00
o`0Dooooo`04o`00ooooooooooooo`00oaGooooo00Go003oooooooooooooooooo`00o`0Eooooo`04
o`00ooooooooooooo`00oaGooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00oooooooo
ooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Gooooo00Co003ooooooooooooo
003o5Oooool01Ol00?oooooooooooooooooo003o01Cooooo00D0003ooooooooooooooooo0000o`0E
ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool02?ooool01?l00?ooooooooooool00?lE
ooooo`04o`00ooooooooooooo`00oaGooooo00Go003oooooooooooooooooo`00o`0Eooooo`04o`00
ooooooooooooo`00oaGooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00oooooooooooo
ooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Gooooo00Co003ooooooooooooo003o
5Oooool01Ol00?oooooooooooooooooo003o01Cooooo00D0003ooooooooooooooooo0000o`0Foooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool02?ooool01?l00?ooooooooooool00?lEoooo
o`04o`00ooooooooooooo`00oaKooooo00Co003ooooooooooooo003o5Oooool01?l00?oooooooooo
ool00?lEooooo`04o`00ooooooooooooo`00oaGooooo00Go003oooooooooooooooooo`00o`0Eoooo
o`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool01Ol00?oooooooooo
oooooooo003o01Cooooo00@0003oooooooooool0003o5oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00Sooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lFoooo
o`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool01?l00?oooooooooo
ool00?lEooooo`04o`00ooooooooooooo`00oaKooooo00Co003ooooooooooooo003o5Oooool01?l0
0?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaGooooo00@0003oooooooooool0003o
5oooool1o`00007ooooo000Eooooo`03o`000?oooooooooo00Sooooo00Co003ooooooooooooo003o
5_ooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Kooooo00Co003ooooooooooooo
003o5Oooool01?l00?ooooooooooool00?lFooooo`03o`00oooooooo003o01Kooooo00Co003ooooo
oooooooo003o5Oooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaKooooo
00<0003oooooo`000?l05oooool1o`00007ooooo000<ooooo`Go00001?ooool00ol0003ooooooooo
o`08ooooo`04o`00ooooooooooooo`00oaKooooo00?o003oooooool00?l05_ooool00ol00?oooooo
o`00o`0Fooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5_ooool00ol0
0?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Kooooo00Co003ooooooooooooo003o5_ooool0
0ol00?ooooooo`00o`0Fooooo`030000ooooool0003o01Oooooo0Ol00001ooooo`003Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Wooooo00?o003oooooool00?l05_ooool0
0ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l05oooool0
0ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l05oooool0
0ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Kooooo00?o003oooooo`000?l05oooool1
o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool2o`00
oaOooooo00?o003oooooool00?l05oooool2o`00oaOooooo0_l00?lGooooo`;o003o5oooool00ol0
0?ooooooo`00o`0Gooooo`;o003o5oooool2o`00oaOooooo0_l00?lGooooo`?o003o5oooool1o`00
007ooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o00000000000000002Oooool2o`00oaSo
oooo00?o003oooooooooool05_ooool2o`00oaOooooo0_l00?lGooooo`;o003o6?ooool00ol00?oo
ooooooooo`0Fooooo`;o003o5oooool2o`00oaOooooo0_l00?lHooooo`03o`00oooooooooooo01Go
oooo0_l00001ooooo`003?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0ooooool7ooooo`7o00000Oooool000cooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0oooool1o`00007ooooo000Eoooooooo00002ol00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.10967, -0.207711, \
0.00395642, 0.0128031}}],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](t) == sin(20\ \[Pi]\ t) + 1\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled continuous-time waveform", "Subsubsection"],

Cell[BoxData[
    \(\(sampleRate = 1000;\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(signal\  = \ 
        Table[f1[t], {t, 0, 1, 1/\((sampleRate - 1)\)}]\  // \ N;\)\), "\n", 
    \(\(ListPlot[signal, \ PlotStyle \[Rule] Blue];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.0147151 0.294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(200)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(400)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(600)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(800)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(1.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02476 .30902 m
.02571 .32752 L
.02667 .34594 L
.02762 .36422 L
.02857 .38228 L
.02952 .40005 L
.03048 .41746 L
.03143 .43444 L
.03238 .45093 L
.03333 .46685 L
.03429 .48215 L
.03524 .49677 L
.03619 .51064 L
.03714 .52372 L
.0381 .53595 L
.03905 .54728 L
.04 .55766 L
.04095 .56707 L
.0419 .57545 L
.04286 .58278 L
.04381 .58903 L
.04476 .59417 L
.04571 .59818 L
.04667 .60105 L
.04762 .60277 L
.04857 .60332 L
.04952 .60271 L
.05048 .60094 L
.05143 .59801 L
.05238 .59394 L
.05333 .58874 L
.05429 .58244 L
.05524 .57506 L
.05619 .56662 L
.05714 .55717 L
.0581 .54673 L
.05905 .53536 L
.06 .52308 L
.06095 .50997 L
.0619 .49606 L
.06286 .4814 L
.06381 .46607 L
.06476 .45012 L
.06571 .4336 L
.06667 .4166 L
.06762 .39917 L
.06857 .38138 L
.06952 .36331 L
.07048 .34502 L
.07143 .32659 L
Mistroke
.07238 .30809 L
.07333 .2896 L
.07429 .27118 L
.07524 .25291 L
.07619 .23486 L
.07714 .21711 L
.0781 .19971 L
.07905 .18276 L
.08 .1663 L
.08095 .1504 L
.0819 .13513 L
.08286 .12055 L
.08381 .10672 L
.08476 .09368 L
.08571 .0815 L
.08667 .07022 L
.08762 .05988 L
.08857 .05052 L
.08952 .04219 L
.09048 .03491 L
.09143 .02872 L
.09238 .02364 L
.09333 .01968 L
.09429 .01687 L
.09524 .01521 L
.09619 .01472 L
.09714 .01539 L
.0981 .01722 L
.09905 .0202 L
.1 .02433 L
.10095 .02958 L
.1019 .03594 L
.10286 .04337 L
.10381 .05186 L
.10476 .06137 L
.10571 .07185 L
.10667 .08327 L
.10762 .09559 L
.10857 .10874 L
.10952 .12269 L
.11048 .13738 L
.11143 .15275 L
.11238 .16873 L
.11333 .18527 L
.11429 .2023 L
.11524 .21975 L
.11619 .23755 L
.11714 .25564 L
.1181 .27393 L
.11905 .29237 L
Mistroke
.12 .31087 L
.12095 .32936 L
.1219 .34778 L
.12286 .36604 L
.12381 .38407 L
.12476 .40181 L
.12571 .41918 L
.12667 .43611 L
.12762 .45255 L
.12857 .46841 L
.12952 .48365 L
.13048 .49819 L
.13143 .51199 L
.13238 .52498 L
.13333 .53712 L
.13429 .54836 L
.13524 .55865 L
.13619 .56795 L
.13714 .57623 L
.1381 .58346 L
.13905 .58959 L
.14 .59462 L
.14095 .59852 L
.1419 .60128 L
.14286 .60287 L
.14381 .60331 L
.14476 .60258 L
.14571 .60069 L
.14667 .59765 L
.14762 .59347 L
.14857 .58816 L
.14952 .58175 L
.15048 .57426 L
.15143 .56572 L
.15238 .55617 L
.15333 .54564 L
.15429 .53417 L
.15524 .52181 L
.15619 .50861 L
.15714 .49462 L
.1581 .4799 L
.15905 .4645 L
.16 .44849 L
.16095 .43192 L
.1619 .41487 L
.16286 .39741 L
.16381 .37959 L
.16476 .36149 L
.16571 .34318 L
.16667 .32474 L
Mistroke
.16762 .30624 L
.16857 .28775 L
.16952 .26934 L
.17048 .25109 L
.17143 .23307 L
.17238 .21535 L
.17333 .198 L
.17429 .18109 L
.17524 .16468 L
.17619 .14885 L
.17714 .13364 L
.1781 .11914 L
.17905 .10538 L
.18 .09243 L
.18095 .08033 L
.1819 .06914 L
.18286 .0589 L
.18381 .04964 L
.18476 .04142 L
.18571 .03425 L
.18667 .02816 L
.18762 .02319 L
.18857 .01935 L
.18952 .01665 L
.19048 .01511 L
.19143 .01473 L
.19238 .01552 L
.19333 .01746 L
.19429 .02056 L
.19524 .0248 L
.19619 .03017 L
.19714 .03663 L
.1981 .04418 L
.19905 .05277 L
.2 .06237 L
.20095 .07295 L
.2019 .08446 L
.20286 .09686 L
.20381 .1101 L
.20476 .12413 L
.20571 .13889 L
.20667 .15432 L
.20762 .17036 L
.20857 .18695 L
.20952 .20402 L
.21048 .22151 L
.21143 .23935 L
.21238 .25746 L
.21333 .27577 L
.21429 .29422 L
Mistroke
.21524 .31272 L
.21619 .33121 L
.21714 .34961 L
.2181 .36785 L
.21905 .38586 L
.22 .40356 L
.22095 .42089 L
.2219 .43778 L
.22286 .45416 L
.22381 .46996 L
.22476 .48513 L
.22571 .49961 L
.22667 .51332 L
.22762 .52623 L
.22857 .53829 L
.22952 .54943 L
.23048 .55962 L
.23143 .56883 L
.23238 .577 L
.23333 .58412 L
.23429 .59015 L
.23524 .59506 L
.23619 .59885 L
.23714 .60149 L
.2381 .60297 L
.23905 .60329 L
.24 .60245 L
.24095 .60044 L
.2419 .59729 L
.24286 .59299 L
.24381 .58757 L
.24476 .58105 L
.24571 .57345 L
.24667 .56481 L
.24762 .55516 L
.24857 .54453 L
.24952 .53297 L
.25048 .52053 L
.25143 .50725 L
.25238 .49318 L
.25333 .47839 L
.25429 .46293 L
.25524 .44686 L
.25619 .43024 L
.25714 .41315 L
.2581 .39564 L
.25905 .37779 L
.26 .35967 L
.26095 .34134 L
.2619 .32289 L
Mistroke
.26286 .30439 L
.26381 .2859 L
.26476 .26751 L
.26571 .24928 L
.26667 .23128 L
.26762 .2136 L
.26857 .19629 L
.26952 .17942 L
.27048 .16307 L
.27143 .1473 L
.27238 .13216 L
.27333 .11772 L
.27429 .10405 L
.27524 .09118 L
.27619 .07917 L
.27714 .06807 L
.2781 .05793 L
.27905 .04877 L
.28 .04065 L
.28095 .03359 L
.2819 .02762 L
.28286 .02276 L
.28381 .01903 L
.28476 .01645 L
.28571 .01502 L
.28667 .01476 L
.28762 .01566 L
.28857 .01772 L
.28952 .02094 L
.29048 .02529 L
.29143 .03076 L
.29238 .03734 L
.29333 .04499 L
.29429 .05368 L
.29524 .06339 L
.29619 .07406 L
.29714 .08566 L
.2981 .09815 L
.29905 .11147 L
.3 .12557 L
.30095 .1404 L
.3019 .1559 L
.30286 .172 L
.30381 .18864 L
.30476 .20576 L
.30571 .22328 L
.30667 .24115 L
.30762 .25928 L
.30857 .27761 L
.30952 .29606 L
Mistroke
.31048 .31457 L
.31143 .33305 L
.31238 .35144 L
.31333 .36966 L
.31429 .38764 L
.31524 .40531 L
.31619 .4226 L
.31714 .43944 L
.3181 .45577 L
.31905 .47151 L
.32 .48661 L
.32095 .50101 L
.3219 .51465 L
.32286 .52748 L
.32381 .53944 L
.32476 .55049 L
.32571 .56059 L
.32667 .56969 L
.32762 .57776 L
.32857 .58477 L
.32952 .59069 L
.33048 .59549 L
.33143 .59916 L
.33238 .60169 L
.33333 .60305 L
.33429 .60326 L
.33524 .6023 L
.33619 .60018 L
.33714 .59691 L
.3381 .5925 L
.33905 .58697 L
.34 .58034 L
.34095 .57264 L
.3419 .56389 L
.34286 .55414 L
.34381 .54342 L
.34476 .53177 L
.34571 .51924 L
.34667 .50587 L
.34762 .49174 L
.34857 .47687 L
.34952 .46135 L
.35048 .44522 L
.35143 .42855 L
.35238 .41141 L
.35333 .39387 L
.35429 .37599 L
.35524 .35784 L
.35619 .3395 L
.35714 .32105 L
Mistroke
.3581 .30254 L
.35905 .28406 L
.36 .26568 L
.36095 .24747 L
.3619 .2295 L
.36286 .21185 L
.36381 .19458 L
.36476 .17776 L
.36571 .16147 L
.36667 .14575 L
.36762 .13068 L
.36857 .11632 L
.36952 .10272 L
.37048 .08994 L
.37143 .07802 L
.37238 .06701 L
.37333 .05697 L
.37429 .04791 L
.37524 .0399 L
.37619 .03294 L
.37714 .02708 L
.3781 .02233 L
.37905 .01872 L
.38 .01625 L
.38095 .01494 L
.3819 .0148 L
.38286 .01581 L
.38381 .01799 L
.38476 .02132 L
.38571 .02579 L
.38667 .03137 L
.38762 .03806 L
.38857 .04581 L
.38952 .05461 L
.39048 .06441 L
.39143 .07518 L
.39238 .08687 L
.39333 .09945 L
.39429 .11285 L
.39524 .12703 L
.39619 .14192 L
.39714 .15748 L
.3981 .17364 L
.39905 .19033 L
.4 .20749 L
.40095 .22505 L
.4019 .24295 L
.40286 .26111 L
.40381 .27945 L
.40476 .29791 L
Mistroke
.40571 .31642 L
.40667 .3349 L
.40762 .35327 L
.40857 .37147 L
.40952 .38943 L
.41048 .40706 L
.41143 .42431 L
.41238 .4411 L
.41333 .45737 L
.41429 .47305 L
.41524 .48809 L
.41619 .50241 L
.41714 .51597 L
.4181 .52871 L
.41905 .54059 L
.42 .55155 L
.42095 .56155 L
.4219 .57055 L
.42286 .57851 L
.42381 .58541 L
.42476 .59122 L
.42571 .59591 L
.42667 .59947 L
.42762 .60188 L
.42857 .60313 L
.42952 .60321 L
.43048 .60214 L
.43143 .5999 L
.43238 .59652 L
.43333 .59199 L
.43429 .58635 L
.43524 .57962 L
.43619 .57181 L
.43714 .56296 L
.4381 .55311 L
.43905 .54229 L
.44 .53055 L
.44095 .51794 L
.4419 .5045 L
.44286 .49028 L
.44381 .47535 L
.44476 .45976 L
.44571 .44357 L
.44667 .42686 L
.44762 .40967 L
.44857 .39209 L
.44952 .37418 L
.45048 .35602 L
.45143 .33766 L
.45238 .3192 L
Mistroke
.45333 .30069 L
.45429 .28221 L
.45524 .26385 L
.45619 .24566 L
.45714 .22772 L
.4581 .2101 L
.45905 .19288 L
.46 .17611 L
.46095 .15987 L
.4619 .14422 L
.46286 .12922 L
.46381 .11493 L
.46476 .10141 L
.46571 .08871 L
.46667 .07688 L
.46762 .06597 L
.46857 .05602 L
.46952 .04707 L
.47048 .03915 L
.47143 .03231 L
.47238 .02655 L
.47333 .02192 L
.47429 .01842 L
.47524 .01607 L
.47619 .01488 L
.47714 .01485 L
.4781 .01598 L
.47905 .01827 L
.48 .02172 L
.48095 .0263 L
.4819 .03199 L
.48286 .03878 L
.48381 .04665 L
.48476 .05554 L
.48571 .06544 L
.48667 .07631 L
.48762 .08809 L
.48857 .10075 L
.48952 .11423 L
.49048 .12848 L
.49143 .14345 L
.49238 .15907 L
.49333 .17528 L
.49429 .19203 L
.49524 .20923 L
.49619 .22683 L
.49714 .24475 L
.4981 .26293 L
.49905 .28129 L
.5 .29976 L
Mistroke
.50095 .31827 L
.5019 .33674 L
.50286 .3551 L
.50381 .37328 L
.50476 .3912 L
.50571 .4088 L
.50667 .42601 L
.50762 .44275 L
.50857 .45896 L
.50952 .47458 L
.51048 .48955 L
.51143 .5038 L
.51238 .51728 L
.51333 .52994 L
.51429 .54173 L
.51524 .55259 L
.51619 .56249 L
.51714 .57139 L
.5181 .57925 L
.51905 .58604 L
.52 .59174 L
.52095 .59632 L
.5219 .59976 L
.52286 .60205 L
.52381 .60319 L
.52476 .60316 L
.52571 .60197 L
.52667 .59962 L
.52762 .59612 L
.52857 .59148 L
.52952 .58573 L
.53048 .57888 L
.53143 .57097 L
.53238 .56202 L
.53333 .55207 L
.53429 .54116 L
.53524 .52933 L
.53619 .51663 L
.53714 .50311 L
.5381 .48882 L
.53905 .47382 L
.54 .45817 L
.54095 .44193 L
.5419 .42516 L
.54286 .40793 L
.54381 .39032 L
.54476 .37238 L
.54571 .35419 L
.54667 .33582 L
.54762 .31735 L
Mistroke
.54857 .29884 L
.54952 .28037 L
.55048 .26202 L
.55143 .24385 L
.55238 .22594 L
.55333 .20836 L
.55429 .19118 L
.55524 .17446 L
.55619 .15827 L
.55714 .14269 L
.5581 .12775 L
.55905 .11354 L
.56 .1001 L
.56095 .08748 L
.5619 .07574 L
.56286 .06493 L
.56381 .05507 L
.56476 .04623 L
.56571 .03842 L
.56667 .03168 L
.56762 .02604 L
.56857 .02152 L
.56952 .01813 L
.57048 .0159 L
.57143 .01482 L
.57238 .01491 L
.57333 .01616 L
.57429 .01857 L
.57524 .02212 L
.57619 .02681 L
.57714 .03262 L
.5781 .03952 L
.57905 .04749 L
.58 .05649 L
.58095 .06649 L
.5819 .07745 L
.58286 .08932 L
.58381 .10206 L
.58476 .11562 L
.58571 .12995 L
.58667 .14498 L
.58762 .16067 L
.58857 .17693 L
.58952 .19373 L
.59048 .21097 L
.59143 .22861 L
.59238 .24656 L
.59333 .26476 L
.59429 .28314 L
.59524 .30161 L
Mistroke
.59619 .32012 L
.59714 .33858 L
.5981 .35693 L
.59905 .37509 L
.6 .39298 L
.60095 .41054 L
.6019 .42771 L
.60286 .4444 L
.60381 .46055 L
.60476 .47611 L
.60571 .49101 L
.60667 .50519 L
.60762 .51859 L
.60857 .53116 L
.60952 .54285 L
.61048 .55362 L
.61143 .56343 L
.61238 .57222 L
.61333 .57998 L
.61429 .58666 L
.61524 .59225 L
.61619 .59671 L
.61714 .60004 L
.6181 .60222 L
.61905 .60324 L
.62 .60309 L
.62095 .60178 L
.6219 .59932 L
.62286 .5957 L
.62381 .59096 L
.62476 .58509 L
.62571 .57814 L
.62667 .57012 L
.62762 .56107 L
.62857 .55102 L
.62952 .54002 L
.63048 .5281 L
.63143 .51531 L
.63238 .50171 L
.63333 .48735 L
.63429 .47228 L
.63524 .45657 L
.63619 .44027 L
.63714 .42346 L
.6381 .40619 L
.63905 .38854 L
.64 .37057 L
.64095 .35236 L
.6419 .33398 L
.64286 .3155 L
Mistroke
.64381 .29699 L
.64476 .27853 L
.64571 .26019 L
.64667 .24205 L
.64762 .22417 L
.64857 .20662 L
.64952 .18948 L
.65048 .17282 L
.65143 .15669 L
.65238 .14116 L
.65333 .1263 L
.65429 .11216 L
.65524 .0988 L
.65619 .08627 L
.65714 .07462 L
.6581 .0639 L
.65905 .05414 L
.66 .0454 L
.66095 .0377 L
.6619 .03107 L
.66286 .02554 L
.66381 .02113 L
.66476 .01786 L
.66571 .01574 L
.66667 .01478 L
.66762 .01498 L
.66857 .01635 L
.66952 .01887 L
.67048 .02254 L
.67143 .02735 L
.67238 .03326 L
.67333 .04027 L
.67429 .04834 L
.67524 .05744 L
.67619 .06754 L
.67714 .07859 L
.6781 .09056 L
.67905 .10338 L
.68 .11702 L
.68095 .13142 L
.6819 .14652 L
.68286 .16227 L
.68381 .17859 L
.68476 .19543 L
.68571 .21272 L
.68667 .23039 L
.68762 .24837 L
.68857 .26659 L
.68952 .28498 L
.69048 .30346 L
Mistroke
.69143 .32197 L
.69238 .34042 L
.69333 .35875 L
.69429 .37689 L
.69524 .39475 L
.69619 .41228 L
.69714 .4294 L
.6981 .44604 L
.69905 .46214 L
.7 .47763 L
.70095 .49246 L
.7019 .50656 L
.70286 .51988 L
.70381 .53237 L
.70476 .54397 L
.70571 .55465 L
.70667 .56435 L
.70762 .57305 L
.70857 .58069 L
.70952 .58727 L
.71048 .59275 L
.71143 .5971 L
.71238 .60031 L
.71333 .60237 L
.71429 .60328 L
.71524 .60301 L
.71619 .60159 L
.71714 .59901 L
.7181 .59528 L
.71905 .59042 L
.72 .58445 L
.72095 .57738 L
.7219 .56926 L
.72286 .56011 L
.72381 .54996 L
.72476 .53886 L
.72571 .52686 L
.72667 .51399 L
.72762 .50031 L
.72857 .48587 L
.72952 .47074 L
.73048 .45496 L
.73143 .43861 L
.73238 .42175 L
.73333 .40444 L
.73429 .38675 L
.73524 .36876 L
.73619 .35053 L
.73714 .33213 L
.7381 .31364 L
Mistroke
.73905 .29514 L
.74 .27669 L
.74095 .25837 L
.7419 .24025 L
.74286 .2224 L
.74381 .20489 L
.74476 .18779 L
.74571 .17118 L
.74667 .15511 L
.74762 .13964 L
.74857 .12485 L
.74952 .11079 L
.75048 .09751 L
.75143 .08506 L
.75238 .0735 L
.75333 .06288 L
.75429 .05322 L
.75524 .04458 L
.75619 .03698 L
.75714 .03046 L
.7581 .02504 L
.75905 .02075 L
.76 .01759 L
.76095 .01559 L
.7619 .01474 L
.76286 .01506 L
.76381 .01655 L
.76476 .01919 L
.76571 .02297 L
.76667 .02789 L
.76762 .03392 L
.76857 .04103 L
.76952 .04921 L
.77048 .05841 L
.77143 .0686 L
.77238 .07975 L
.77333 .0918 L
.77429 .10471 L
.77524 .11843 L
.77619 .1329 L
.77714 .14807 L
.7781 .16387 L
.77905 .18025 L
.78 .19714 L
.78095 .21447 L
.7819 .23218 L
.78286 .25018 L
.78381 .26842 L
.78476 .28683 L
.78571 .30532 L
Mistroke
.78667 .32382 L
.78762 .34226 L
.78857 .36058 L
.78952 .37869 L
.79048 .39652 L
.79143 .41401 L
.79238 .43108 L
.79333 .44767 L
.79429 .46372 L
.79524 .47915 L
.79619 .4939 L
.79714 .50793 L
.7981 .52117 L
.79905 .53357 L
.8 .54508 L
.80095 .55566 L
.8019 .56527 L
.80286 .57386 L
.80381 .5814 L
.80476 .58787 L
.80571 .59323 L
.80667 .59747 L
.80762 .60057 L
.80857 .60252 L
.80952 .6033 L
.81048 .60292 L
.81143 .60138 L
.81238 .59869 L
.81333 .59484 L
.81429 .58987 L
.81524 .58379 L
.81619 .57662 L
.81714 .56839 L
.8181 .55914 L
.81905 .54889 L
.82 .5377 L
.82095 .52561 L
.8219 .51266 L
.82286 .4989 L
.82381 .48439 L
.82476 .46919 L
.82571 .45335 L
.82667 .43695 L
.82762 .42004 L
.82857 .40269 L
.82952 .38496 L
.83048 .36694 L
.83143 .34869 L
.83238 .33029 L
.83333 .31179 L
Mistroke
.83429 .29329 L
.83524 .27485 L
.83619 .25655 L
.83714 .23845 L
.8381 .22063 L
.83905 .20316 L
.84 .18611 L
.84095 .16955 L
.8419 .15353 L
.84286 .13813 L
.84381 .12341 L
.84476 .10942 L
.84571 .09622 L
.84667 .08387 L
.84762 .0724 L
.84857 .06187 L
.84952 .05231 L
.85048 .04377 L
.85143 .03628 L
.85238 .02987 L
.85333 .02456 L
.85429 .02038 L
.85524 .01734 L
.85619 .01545 L
.85714 .01472 L
.8581 .01516 L
.85905 .01676 L
.86 .01951 L
.86095 .02341 L
.8619 .02844 L
.86286 .03458 L
.86381 .0418 L
.86476 .05008 L
.86571 .05939 L
.86667 .06968 L
.86762 .08091 L
.86857 .09305 L
.86952 .10605 L
.87048 .11984 L
.87143 .13439 L
.87238 .14962 L
.87333 .16549 L
.87429 .18192 L
.87524 .19886 L
.87619 .21623 L
.87714 .23396 L
.8781 .252 L
.87905 .27026 L
.88 .28867 L
.88095 .30717 L
Mistroke
.8819 .32567 L
.88286 .3441 L
.88381 .3624 L
.88476 .38048 L
.88571 .39829 L
.88667 .41574 L
.88762 .43277 L
.88857 .4493 L
.88952 .46529 L
.89048 .48065 L
.89143 .49534 L
.89238 .50929 L
.89333 .52245 L
.89429 .53476 L
.89524 .54618 L
.89619 .55667 L
.89714 .56617 L
.8981 .57466 L
.89905 .5821 L
.9 .58845 L
.90095 .59371 L
.9019 .59783 L
.90286 .60082 L
.90381 .60265 L
.90476 .60332 L
.90571 .60282 L
.90667 .60116 L
.90762 .59835 L
.90857 .5944 L
.90952 .58931 L
.91048 .58312 L
.91143 .57584 L
.91238 .56751 L
.91333 .55816 L
.91429 .54782 L
.91524 .53653 L
.91619 .52435 L
.91714 .51132 L
.9181 .49748 L
.91905 .4829 L
.92 .46763 L
.92095 .45174 L
.9219 .43528 L
.92286 .41832 L
.92381 .40093 L
.92476 .38317 L
.92571 .36513 L
.92667 .34686 L
.92762 .32844 L
.92857 .30994 L
Mistroke
.92952 .29144 L
.93048 .27301 L
.93143 .25473 L
.93238 .23665 L
.93333 .21887 L
.93429 .20144 L
.93524 .18443 L
.93619 .16792 L
.93714 .15196 L
.9381 .13663 L
.93905 .12198 L
.94 .10807 L
.94095 .09495 L
.9419 .08268 L
.94286 .0713 L
.94381 .06087 L
.94476 .05141 L
.94571 .04298 L
.94667 .03559 L
.94762 .02929 L
.94857 .0241 L
.94952 .02003 L
.95048 .0171 L
.95143 .01533 L
.95238 .01472 L
.95333 .01527 L
.95429 .01698 L
.95524 .01985 L
.95619 .02386 L
.95714 .02901 L
.9581 .03525 L
.95905 .04258 L
.96 .05097 L
.96095 .06037 L
.9619 .07076 L
.96286 .08209 L
.96381 .09432 L
.96476 .10739 L
.96571 .12127 L
.96667 .13588 L
.96762 .15118 L
.96857 .16711 L
.96952 .18359 L
.97048 .20057 L
.97143 .21798 L
.97238 .23576 L
.97333 .25382 L
.97429 .27209 L
.97524 .29052 L
.97619 .30902 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`006_ooool2o`0002Oooooo1Ol00003ooooo`;o00001?ooool2o`0002Co
oooo0ol00003ooooo`;o00001?ooool2o`0002;ooooo0ol00004ooooo`;o00001?ooool2o`0002?o
oooo0ol00004ooooo`;o00001?ooool2o`00023ooooo0ol00004ooooo`;o00001?ooool2o`0000Co
oooo0_l00003ooooo`006Oooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Tooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
000Iooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`00027ooooo1Ol00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Qooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool001Wooooo00Co0000oooooooooooo0000:Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Pooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0002;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00008?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`006Oooool01?l0003ooooooooo
ool0000Vooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`00027ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`006Oooool01?l0003oooooooooool0000Vooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002?o
oooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
8Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Oooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool001[ooooo0_l0000Xooooo`?o0000
1?ooool2o`0000Cooooo0_l0000Uooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000
8oooool2o`0000Cooooo0_l00004ooooo`;o00008oooool3o`0000Cooooo0_l00004ooooo`;o0000
8Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`005Oooool00ol000000000
0000003o00000080000000?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00<00000ooooooooool0;_ooool0
0`00003oooooooooo`0_ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo0?oooooo0_ooool00ol0003oooooooooo`04ooooo`003Oooool01?l0003oooooooooool00004
oooooaWo000000?o003oo`000?l000005Ol00002o`00oaOo000000?o003oo`000?l000005_l00000
0ol00?oo0000o`00000Fo`000003o`00ool0003o000001Go00000_l00?lGo`000003o`00ool0003o
000001Ko000000?o003oo`000?l000005_l000000ol00?oo0000o`00000Eo`0000;o003o3?l00006
ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo01Gooooo0_l00?lG
ooooo`;o003o5oooool2o`00oaKooooo0ol00?lFooooo`;o003o5oooool2o`00oaOooooo0_l00?lF
ooooo`?o003o5_ooool2o`00oaOooooo0_l00?l;ooooo`03o`000?oooooooooo00Cooooo000=oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05Oooool2o`00oaOooooo0_l00?lF
ooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0F
ooooo`;o003o5_ooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Kooooo0_l00?lG
ooooo`;o003o2oooool00ol0003oooooooooo`04ooooo`003Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo01Gooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0E
ooooo`03o`00oooooooo003o01Kooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00o`0E
ooooo`04o`00ooooooooooooo`00oaGooooo00?o003oooooool00?l05_ooool00ol00?ooooooo`00
o`0Fooooo`03o`00oooooooo003o01Gooooo00?o003oooooool00?l02oooool00ol0003ooooooooo
o`04ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooo`00o`0E
ooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool00ol00?oooooo
o`00o`0Fooooo`03o`00oooooooo003o01Gooooo00Co003ooooooooooooo003o5Oooool00ol00?oo
ooooo`00o`0Fooooo`03o`00oooooooo003o01Gooooo00Co003ooooooooooooo003o5Oooool01?l0
0?ooooooooooool00?l:ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo
01Gooooo00?o003oooooool00?l05Oooool01?l00?ooooooooooool00?lEooooo`04o`00oooooooo
ooooo`00oaGooooo00?o003oooooool00?l05Oooool01?l00?ooooooooooool00?lEooooo`04o`00
ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool00ol00?ooooooo`00o`0Eoooo
o`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o2_ooool00ol0003ooooooooo
o`04ooooo`005Oooool00ol0003oooooooooo`0Dooooo`04o`00ooooooooooooo`00oaGooooo00Co
003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00
oaCooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lEooooo`04o`00oooo
ooooooooo`00oaCooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lEoooo
o`04o`00ooooooooooooo`00o`[ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000oooo
ooooool05?ooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaGooooo00Co
003ooooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooo
oooo003o5Oooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaCooooo00Go
003oooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooo
oooo003o2_ooool00ol0003oooooooooo`04ooooo`005Oooool2o`0001Gooooo00Co003ooooooooo
oooo003o5Oooool01?l00?ooooooooooool00?lEooooo`04o`00ooooooooooooo`00oaCooooo00Go
003oooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooo
oooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00
o`0Dooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o2Oooool2o`0000Ko
oooo000Eooooo`03o`000?oooooooooo01Cooooo00Co003ooooooooooooo003o5Oooool01?l00?oo
ooooooooool00?lDooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooo
oooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00oaCo
oooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05?ooool0
1Ol00?oooooooooooooooooo003o01Cooooo00Co003ooooooooooooo003o2_ooool00ol0003ooooo
ooooo`04ooooo`005Oooool00ol0003oooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l0
5?ooool01?l00?ooooooooooool00?lDooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol0
0?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`04o`00oooo
ooooooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00oooooooooooooooo
ool00?l05?ooool01Ol00?oooooooooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00
o`0:ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo01Cooooo00Go003o
ooooooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooo
oooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00oooooooooooo
ooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003o
ooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooo
oooooooooooo003o01?ooooo00Go003oooooooooooooooooo`00o`0:ooooo`03o`000?oooooooooo
00Cooooo000Eooooo`03o`000?oooooooooo01Cooooo00Go003oooooooooooooooooo`00o`0Coooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo
003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l0
4oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00Go003ooooooooooooo
ooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l04oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo01Cooooo00Go003ooooooooo
ooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol0
0?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00oooo
ooooooooooooool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Cooooo
000Eooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooo
oooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00oooooooooooooooo
ool00?l04oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03
o`000?oooooooooo01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo
00Cooooo000Eooooo`;o00005?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Ko
oooo0_l00006ooooo`005Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool01oooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003ooooooooo
o`0Cooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool00ol0003ooooooooo
o`04ooooo`005Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01oooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`0Coooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`04oooo
o`005Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool01oooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`0Cooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`04ooooo`005Ooo
ool2o`0001Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`05ooooo`;o00001_oo
ool001Gooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
oooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo
oooo00Kooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool04oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01?ooool001Go
oooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Ko
oooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool04_ooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01?ooool001Gooooo00?o
0000ooooooooool04_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o
0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000oooo
ooooool04_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool01?ooool001Gooooo0_l0000Cooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooooooo
ool01Oooool2o`0000Kooooo000Eooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0
3_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oo
oooooooo01;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo000Eooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo
01;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`0000Goooooo`000?ooooooooooo`00000;oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01?ooool00005ooooool0003ooooooooo
ool000002oooool00ol0003oooooooooo`02ooooo`;o00004oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00?ooooo0ol00006ooooo`0000Goooooo`000?ooooooooooo`000007oooo
o`Co00001Oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`0000Goooooo`000?ooooooooooo`000007oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Gooooo00?o0000ooooooooool01?ooool000;ooooo0_l00008ooooo`Go
00001?ooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`0Aooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`04ooooo`005Ooo
ool00ol0003oooooooooo`0Aooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`04ooooo`005Oooool2o`00
01;ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`04ooooo`;o00001_ooool001Go
oooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Go
oooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool04Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool01?ooool001Gooooo00?o
0000ooooooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o
0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000oooo
ooooool04Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o0000oooo
ooooool01?ooool001Gooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Gooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0
4Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool0
1?ooool001Gooooo0_l0000Booooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01?oo
ool2o`0000Kooooo000Eooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo
017ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo000Eooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo017ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
000Eooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo017ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000Eoooo
o`03o`000?oooooooooo013ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo000Eooooo`;o00004Oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00?ooooo0_l00006ooooo`005Oooool00ol0003oooooooooo`0@ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`04ooooo`005Ooo
ool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`04ooooo`005Oooool00ol0
003oooooooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003ooooo
ooooo`0@ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`005Oooool2o`00017ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`03ooooo`;o00001_ooool001Gooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000oooo
ooooool04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool01?ooool001Gooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0
4?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
1?ooool000gooooo0ol00005ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00?ooooo00?o0000ooooooooool01?ooool000kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0@ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool00oooool00ol0
003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00Co003ooooooooooooooooo0ol00006oooo
o`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo000=ooooo`;o0000
1_ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
4?ooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0@ooooo`03o`000?oo
oooooooo00Cooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo000Eooooo`;o00001?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00oooooo0_l00006ooooo`005Oooool00ol0003ooooooooo
o`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool04?ooool00ol0003ooooooooo
o`04ooooo`005Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool04?ooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`04oooo
o`005Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool04?ooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`04ooooo`005Ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04Ooo
ool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool04Oooool00ol0003oooooooooo`04ooooo`005Oooool2o`00
00Gooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`;o00001_ooool001Go
oooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo017o
oooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool01?ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool01?ooool001Gooooo00?o
0000ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo017ooooo00?o
0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000oooo
ooooool01?ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool02oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo017ooooo00?o0000oooo
ooooool01?ooool001Gooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00_ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo017ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0
1?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
3?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo017ooooo00?o0000ooooooooool0
1?ooool001Gooooo0_l00005ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04?oo
ool2o`0000Kooooo000Eooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo
00Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo
00Cooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo00Gooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo
000Eooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0<ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0Aooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo00Gooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo000Eoooo
o`;o00001_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo013ooooo0_l00006oooo
o`005Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool04_ooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`005Ooo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04_oo
ool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo00gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`005Oooool00ol0
003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool04_ooool00ol0
003oooooooooo`04ooooo`0000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool04_ooool00ol0003oooooooooo`04ooooo`000_ooool00ol0003oooooooooo`07ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`000_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool04?ooool3o`0000Kooooo0002ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`000_ooool00ol0003ooooooooo
o`07ooooo`Co00001Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00gooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool04_ooool00ol0003oooooooooo`04ooooo`0000?oooooo`000?l000002Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00Cooooo0002ooooo`03o`000?oooooooooo
00Oooooo1Ol00004ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0=ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0Booooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00Co
oooo000Eooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0Booooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo00Kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o
003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Booooo`03o`000?oooooooooo00Cooooo000E
ooooo`;o00001oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo0_l00006
ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool04_ooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`06ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool04oooool00ol0003oooooooooo`04ooooo`00
5Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
4oooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00kooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool04oooool00ol0003oooooooooo`04ooooo`005Oooool0
0ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool03oooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04oooool0
0ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04oooool00ol0003oooooooooo`04ooooo`005Oooool2o`0000Oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool03oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`;o00001_ooool001Gooooo
00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01?ooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo
00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool01_ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool03oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooooooo
o`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000
ooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o0000
ooooooooool01?ooool001Gooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooooooo01?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo013ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003ooooooooo
ool04?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o0000oooooooo
ool01?ooool001Gooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo01?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool01ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool01?oo
ool001Gooooo0_l00008ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04oooool2
o`0000Kooooo000Eooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol0
0?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0D
ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo00Oooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l04oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool0
1Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?oooooooooo
o`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo017ooooo00Go003oooooooooooooooooo`00o`0Fooooo`03o`00
0?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooo
oooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o
01?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003o
ooooooooooooooooo`00o`0Fooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooo
oooo00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Aooooo`05o`00oooooooo
ooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oo
oooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go
003oooooooooooooooooo`00o`0Fooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oo
oooooooo00Oooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool0
0?l05?ooool01Ol00?oooooooooooooooooo003o01?ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooo
oooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool04Oooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooo
ooooooooo`00o`0Fooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo00Oo
oooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05?ooool0
1Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Cooooo`05o`00
ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooo
ooooooooooooo`00o`0Cooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooo
oooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Fooooo`03o`000?oooooooooo00Co
oooo000Eooooo`03o`000?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`0Dooooo`05
o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Co003o
oooooooooooo003o5?ooool01Ol00?oooooooooooooooooo003o01Cooooo00Go003ooooooooooooo
ooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05?ooool01?l00?ooooooooooool00?lD
ooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Kooooo
00?o0000ooooooooool01?ooool001Gooooo0_l00009ooooo`04o`00ooooooooooooo`00oaCooooo
00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05?ooool01?l0
0?ooooooooooool00?lDooooo`05o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooo
oooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`04o`00ooooooooooooo`00
oaCooooo00Go003oooooooooooooooooo`00o`0Dooooo`05o`00ooooooooooooooooool00?l05Ooo
ool2o`0000Kooooo000Eooooo`03o`000?oooooooooo00Sooooo00Co003ooooooooooooo003o5?oo
ool01Ol00?oooooooooooooooooo003o01Cooooo00Go003oooooooooooooooooo`00o`0Dooooo`04
o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5?ooool01Ol00?oooooooooooooo
oooo003o01Cooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lDooooo`05
o`00ooooooooooooooooool00?l05?ooool01Ol00?oooooooooooooooooo003o01Kooooo00?o0000
ooooooooool01?ooool001Gooooo00?o0000ooooooooool02?ooool01?l00?ooooooooooool00?lE
ooooo`04o`00ooooooooooooo`00oaCooooo00Co003ooooooooooooo003o5Oooool01?l00?oooooo
ooooool00?lEooooo`04o`00ooooooooooooo`00oaCooooo00Go003oooooooooooooooooo`00o`0D
ooooo`04o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool01?l00?oooooo
ooooool00?lDooooo`04o`00ooooooooooooo`00oaOooooo00?o0000ooooooooool01?ooool001Go
oooo00?o0000ooooooooool02?ooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o
01Gooooo00Co003ooooooooooooo003o5Oooool01?l00?ooooooooooool00?lEooooo`04o`00oooo
ooooooooo`00oaGooooo00?o003oooooool00?l05Oooool01?l00?ooooooooooool00?lEooooo`04
o`00ooooooooooooo`00oaGooooo00Co003ooooooooooooo003o5Oooool00ol00?ooooooo`00o`0G
ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo00Sooooo00Co003ooooo
oooooooo003o5Oooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Gooooo00Co003o
oooooooooooo003o5Oooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Kooooo00?o
003oooooool00?l05Oooool01?l00?ooooooooooool00?lEooooo`03o`00oooooooo003o01Kooooo
00?o003oooooool00?l05oooool00ol0003oooooooooo`04ooooo`003?ooool5o`0000Cooooo00?o
0000ooooooooool02?ooool00ol00?ooooooo`00o`0Fooooo`03o`00oooooooo003o01Kooooo00?o
003oooooool00?l05_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo00?o
003oooooool00?l05_ooool00ol00?ooooooo`00o`0Eooooo`03o`00oooooooo003o01Kooooo00?o
003oooooool00?l05_ooool00ol00?ooooooo`00o`0Gooooo`03o`000?oooooooooo00Cooooo000=
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02Oooool2o`00oaKooooo00?o
003oooooool00?l05_ooool00ol00?ooooooo`00o`0Fooooo`;o003o5oooool2o`00oaKooooo00?o
003oooooool00?l05_ooool2o`00oaOooooo0_l00?lFooooo`03o`00oooooooo003o01Kooooo00?o
003oooooool00?l05oooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`04
ooooo`;o00002_ooool2o`00oaOooooo0_l00?lFooooo`;o003o5oooool2o`00oaOooooo0_l00?lG
ooooo`03o`00oooooooooooo01Gooooo0_l00?lGooooo`;o003o5oooool2o`00oaKooooo0_l00?lF
ooooo`?o00001_ooool000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
o`;ooooo00?o0000ooooooooool01?ooool000cooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`04ooooo`003?ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`003Oooool3o`0000Goooooool00006o`0000Kooooo003oooooob7ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-110.84, -0.2321, 4.03943, \
0.0130719}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete spectrum: Fast Fourier Transform (FFT)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ Fourier[signal];\)\), "\n", 
    \(\(g1 = 
        DiscreteListPlot[FourierRearrange[Abs[fft], sampleRate], Red, 
          PlotRange \[Rule] All, \ Frame \[Rule] True];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499523 0.000953334 0.0147151 0.000588604 [
[.11819 -0.0125 -12 -9 ]
[.11819 -0.0125 12 0 ]
[.30886 -0.0125 -12 -9 ]
[.30886 -0.0125 12 0 ]
[.49952 -0.0125 -3 -9 ]
[.49952 -0.0125 3 0 ]
[.69019 -0.0125 -9 -9 ]
[.69019 -0.0125 9 0 ]
[.88086 -0.0125 -9 -9 ]
[.88086 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -24 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11819 0 m
.11819 .00625 L
s
[(-400)] .11819 -0.0125 0 1 Mshowa
.30886 0 m
.30886 .00625 L
s
[(-200)] .30886 -0.0125 0 1 Mshowa
.49952 0 m
.49952 .00625 L
s
[(0)] .49952 -0.0125 0 1 Mshowa
.69019 0 m
.69019 .00625 L
s
[(200)] .69019 -0.0125 0 1 Mshowa
.88086 0 m
.88086 .00625 L
s
[(400)] .88086 -0.0125 0 1 Mshowa
.125 Mabswid
.16586 0 m
.16586 .00375 L
s
.21352 0 m
.21352 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.40419 0 m
.40419 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.59486 0 m
.59486 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.78552 0 m
.78552 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.07052 0 m
.07052 .00375 L
s
.02286 0 m
.02286 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(200)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(400)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(600)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(800)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1000)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11819 .61178 m
.11819 .61803 L
s
.30886 .61178 m
.30886 .61803 L
s
.49952 .61178 m
.49952 .61803 L
s
.69019 .61178 m
.69019 .61803 L
s
.88086 .61178 m
.88086 .61803 L
s
.125 Mabswid
.16586 .61428 m
.16586 .61803 L
s
.21352 .61428 m
.21352 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.40419 .61428 m
.40419 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.59486 .61428 m
.59486 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.78552 .61428 m
.78552 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.07052 .61428 m
.07052 .61803 L
s
.02286 .61428 m
.02286 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01473 L
s
.02476 .01472 m
.02476 .01473 L
s
.02572 .01472 m
.02572 .01473 L
s
.02667 .01472 m
.02667 .01473 L
s
.02762 .01472 m
.02762 .01473 L
s
.02858 .01472 m
.02858 .01473 L
s
.02953 .01472 m
.02953 .01473 L
s
.03048 .01472 m
.03048 .01473 L
s
.03144 .01472 m
.03144 .01473 L
s
.03239 .01472 m
.03239 .01473 L
s
.03334 .01472 m
.03334 .01473 L
s
.0343 .01472 m
.0343 .01473 L
s
.03525 .01472 m
.03525 .01473 L
s
.0362 .01472 m
.0362 .01473 L
s
.03716 .01472 m
.03716 .01473 L
s
.03811 .01472 m
.03811 .01473 L
s
.03906 .01472 m
.03906 .01473 L
s
.04002 .01472 m
.04002 .01473 L
s
.04097 .01472 m
.04097 .01473 L
s
.04192 .01472 m
.04192 .01473 L
s
.04288 .01472 m
.04288 .01473 L
s
.04383 .01472 m
.04383 .01473 L
s
.04478 .01472 m
.04478 .01473 L
s
.04574 .01472 m
.04574 .01473 L
s
.04669 .01472 m
.04669 .01473 L
s
.04764 .01472 m
.04764 .01473 L
s
.0486 .01472 m
.0486 .01473 L
s
.04955 .01472 m
.04955 .01473 L
s
.0505 .01472 m
.0505 .01473 L
s
.05146 .01472 m
.05146 .01473 L
s
.05241 .01472 m
.05241 .01473 L
s
.05336 .01472 m
.05336 .01473 L
s
.05432 .01472 m
.05432 .01473 L
s
.05527 .01472 m
.05527 .01473 L
s
.05622 .01472 m
.05622 .01473 L
s
.05718 .01472 m
.05718 .01473 L
s
.05813 .01472 m
.05813 .01473 L
s
.05908 .01472 m
.05908 .01473 L
s
.06004 .01472 m
.06004 .01473 L
s
.06099 .01472 m
.06099 .01473 L
s
.06194 .01472 m
.06194 .01473 L
s
.0629 .01472 m
.0629 .01473 L
s
.06385 .01472 m
.06385 .01473 L
s
.0648 .01472 m
.0648 .01473 L
s
.06576 .01472 m
.06576 .01473 L
s
.06671 .01472 m
.06671 .01473 L
s
.06766 .01472 m
.06766 .01473 L
s
.06862 .01472 m
.06862 .01473 L
s
.06957 .01472 m
.06957 .01473 L
s
.07052 .01472 m
.07052 .01473 L
s
.07148 .01472 m
.07148 .01473 L
s
.07243 .01472 m
.07243 .01473 L
s
.07338 .01472 m
.07338 .01473 L
s
.07434 .01472 m
.07434 .01473 L
s
.07529 .01472 m
.07529 .01473 L
s
.07624 .01472 m
.07624 .01473 L
s
.0772 .01472 m
.0772 .01473 L
s
.07815 .01472 m
.07815 .01473 L
s
.0791 .01472 m
.0791 .01473 L
s
.08006 .01472 m
.08006 .01473 L
s
.08101 .01472 m
.08101 .01473 L
s
.08196 .01472 m
.08196 .01473 L
s
.08292 .01472 m
.08292 .01473 L
s
.08387 .01472 m
.08387 .01473 L
s
.08482 .01472 m
.08482 .01473 L
s
.08578 .01472 m
.08578 .01473 L
s
.08673 .01472 m
.08673 .01473 L
s
.08768 .01472 m
.08768 .01473 L
s
.08864 .01472 m
.08864 .01473 L
s
.08959 .01472 m
.08959 .01473 L
s
.09054 .01472 m
.09054 .01473 L
s
.0915 .01472 m
.0915 .01473 L
s
.09245 .01472 m
.09245 .01473 L
s
.0934 .01472 m
.0934 .01473 L
s
.09436 .01472 m
.09436 .01473 L
s
.09531 .01472 m
.09531 .01473 L
s
.09626 .01472 m
.09626 .01473 L
s
.09722 .01472 m
.09722 .01473 L
s
.09817 .01472 m
.09817 .01473 L
s
.09912 .01472 m
.09912 .01473 L
s
.10008 .01472 m
.10008 .01473 L
s
.10103 .01472 m
.10103 .01473 L
s
.10198 .01472 m
.10198 .01473 L
s
.10294 .01472 m
.10294 .01473 L
s
.10389 .01472 m
.10389 .01473 L
s
.10484 .01472 m
.10484 .01473 L
s
.1058 .01472 m
.1058 .01473 L
s
.10675 .01472 m
.10675 .01473 L
s
.1077 .01472 m
.1077 .01473 L
s
.10866 .01472 m
.10866 .01473 L
s
.10961 .01472 m
.10961 .01473 L
s
.11056 .01472 m
.11056 .01473 L
s
.11152 .01472 m
.11152 .01473 L
s
.11247 .01472 m
.11247 .01473 L
s
.11342 .01472 m
.11342 .01473 L
s
.11438 .01472 m
.11438 .01473 L
s
.11533 .01472 m
.11533 .01473 L
s
.11628 .01472 m
.11628 .01473 L
s
.11724 .01472 m
.11724 .01473 L
s
.11819 .01472 m
.11819 .01473 L
s
.11914 .01472 m
.11914 .01473 L
s
.1201 .01472 m
.1201 .01473 L
s
.12105 .01472 m
.12105 .01473 L
s
.122 .01472 m
.122 .01473 L
s
.12296 .01472 m
.12296 .01473 L
s
.12391 .01472 m
.12391 .01473 L
s
.12486 .01472 m
.12486 .01473 L
s
.12582 .01472 m
.12582 .01473 L
s
.12677 .01472 m
.12677 .01473 L
s
.12772 .01472 m
.12772 .01473 L
s
.12868 .01472 m
.12868 .01473 L
s
.12963 .01472 m
.12963 .01473 L
s
.13058 .01472 m
.13058 .01473 L
s
.13154 .01472 m
.13154 .01473 L
s
.13249 .01472 m
.13249 .01473 L
s
.13344 .01472 m
.13344 .01473 L
s
.1344 .01472 m
.1344 .01473 L
s
.13535 .01472 m
.13535 .01473 L
s
.1363 .01472 m
.1363 .01473 L
s
.13726 .01472 m
.13726 .01474 L
s
.13821 .01472 m
.13821 .01474 L
s
.13916 .01472 m
.13916 .01474 L
s
.14012 .01472 m
.14012 .01474 L
s
.14107 .01472 m
.14107 .01474 L
s
.14202 .01472 m
.14202 .01474 L
s
.14298 .01472 m
.14298 .01474 L
s
.14393 .01472 m
.14393 .01474 L
s
.14488 .01472 m
.14488 .01474 L
s
.14584 .01472 m
.14584 .01474 L
s
.14679 .01472 m
.14679 .01474 L
s
.14774 .01472 m
.14774 .01474 L
s
.1487 .01472 m
.1487 .01474 L
s
.14965 .01472 m
.14965 .01474 L
s
.1506 .01472 m
.1506 .01474 L
s
.15156 .01472 m
.15156 .01474 L
s
.15251 .01472 m
.15251 .01474 L
s
.15346 .01472 m
.15346 .01474 L
s
.15442 .01472 m
.15442 .01474 L
s
.15537 .01472 m
.15537 .01474 L
s
.15632 .01472 m
.15632 .01474 L
s
.15728 .01472 m
.15728 .01474 L
s
.15823 .01472 m
.15823 .01474 L
s
.15918 .01472 m
.15918 .01474 L
s
.16014 .01472 m
.16014 .01474 L
s
.16109 .01472 m
.16109 .01474 L
s
.16204 .01472 m
.16204 .01474 L
s
.163 .01472 m
.163 .01474 L
s
.16395 .01472 m
.16395 .01474 L
s
.1649 .01472 m
.1649 .01474 L
s
.16586 .01472 m
.16586 .01474 L
s
.16681 .01472 m
.16681 .01474 L
s
.16776 .01472 m
.16776 .01474 L
s
.16872 .01472 m
.16872 .01474 L
s
.16967 .01472 m
.16967 .01474 L
s
.17062 .01472 m
.17062 .01474 L
s
.17158 .01472 m
.17158 .01474 L
s
.17253 .01472 m
.17253 .01474 L
s
.17348 .01472 m
.17348 .01474 L
s
.17444 .01472 m
.17444 .01474 L
s
.17539 .01472 m
.17539 .01474 L
s
.17634 .01472 m
.17634 .01474 L
s
.1773 .01472 m
.1773 .01474 L
s
.17825 .01472 m
.17825 .01474 L
s
.1792 .01472 m
.1792 .01474 L
s
.18016 .01472 m
.18016 .01474 L
s
.18111 .01472 m
.18111 .01474 L
s
.18206 .01472 m
.18206 .01474 L
s
.18302 .01472 m
.18302 .01474 L
s
.18397 .01472 m
.18397 .01474 L
s
.18492 .01472 m
.18492 .01474 L
s
.18588 .01472 m
.18588 .01474 L
s
.18683 .01472 m
.18683 .01474 L
s
.18778 .01472 m
.18778 .01474 L
s
.18874 .01472 m
.18874 .01474 L
s
.18969 .01472 m
.18969 .01474 L
s
.19064 .01472 m
.19064 .01474 L
s
.1916 .01472 m
.1916 .01474 L
s
.19255 .01472 m
.19255 .01474 L
s
.1935 .01472 m
.1935 .01474 L
s
.19446 .01472 m
.19446 .01474 L
s
.19541 .01472 m
.19541 .01474 L
s
.19636 .01472 m
.19636 .01474 L
s
.19732 .01472 m
.19732 .01474 L
s
.19827 .01472 m
.19827 .01474 L
s
.19922 .01472 m
.19922 .01474 L
s
.20018 .01472 m
.20018 .01474 L
s
.20113 .01472 m
.20113 .01474 L
s
.20208 .01472 m
.20208 .01474 L
s
.20304 .01472 m
.20304 .01474 L
s
.20399 .01472 m
.20399 .01474 L
s
.20494 .01472 m
.20494 .01474 L
s
.2059 .01472 m
.2059 .01474 L
s
.20685 .01472 m
.20685 .01474 L
s
.2078 .01472 m
.2078 .01474 L
s
.20876 .01472 m
.20876 .01474 L
s
.20971 .01472 m
.20971 .01474 L
s
.21066 .01472 m
.21066 .01474 L
s
.21162 .01472 m
.21162 .01474 L
s
.21257 .01472 m
.21257 .01474 L
s
.21352 .01472 m
.21352 .01474 L
s
.21448 .01472 m
.21448 .01474 L
s
.21543 .01472 m
.21543 .01474 L
s
.21638 .01472 m
.21638 .01474 L
s
.21734 .01472 m
.21734 .01474 L
s
.21829 .01472 m
.21829 .01474 L
s
.21924 .01472 m
.21924 .01474 L
s
.2202 .01472 m
.2202 .01474 L
s
.22115 .01472 m
.22115 .01474 L
s
.2221 .01472 m
.2221 .01474 L
s
.22306 .01472 m
.22306 .01474 L
s
.22401 .01472 m
.22401 .01474 L
s
.22496 .01472 m
.22496 .01474 L
s
.22592 .01472 m
.22592 .01474 L
s
.22687 .01472 m
.22687 .01474 L
s
.22782 .01472 m
.22782 .01474 L
s
.22878 .01472 m
.22878 .01474 L
s
.22973 .01472 m
.22973 .01474 L
s
.23068 .01472 m
.23068 .01474 L
s
.23164 .01472 m
.23164 .01474 L
s
.23259 .01472 m
.23259 .01474 L
s
.23354 .01472 m
.23354 .01474 L
s
.2345 .01472 m
.2345 .01474 L
s
.23545 .01472 m
.23545 .01474 L
s
.2364 .01472 m
.2364 .01474 L
s
.23736 .01472 m
.23736 .01474 L
s
.23831 .01472 m
.23831 .01474 L
s
.23926 .01472 m
.23926 .01474 L
s
.24022 .01472 m
.24022 .01474 L
s
.24117 .01472 m
.24117 .01474 L
s
.24212 .01472 m
.24212 .01474 L
s
.24308 .01472 m
.24308 .01474 L
s
.24403 .01472 m
.24403 .01474 L
s
.24498 .01472 m
.24498 .01474 L
s
.24594 .01472 m
.24594 .01474 L
s
.24689 .01472 m
.24689 .01474 L
s
.24784 .01472 m
.24784 .01474 L
s
.2488 .01472 m
.2488 .01474 L
s
.24975 .01472 m
.24975 .01474 L
s
.2507 .01472 m
.2507 .01474 L
s
.25166 .01472 m
.25166 .01474 L
s
.25261 .01472 m
.25261 .01474 L
s
.25356 .01472 m
.25356 .01474 L
s
.25452 .01472 m
.25452 .01474 L
s
.25547 .01472 m
.25547 .01474 L
s
.25642 .01472 m
.25642 .01474 L
s
.25738 .01472 m
.25738 .01474 L
s
.25833 .01472 m
.25833 .01474 L
s
.25928 .01472 m
.25928 .01474 L
s
.26024 .01472 m
.26024 .01474 L
s
.26119 .01472 m
.26119 .01474 L
s
.26214 .01472 m
.26214 .01474 L
s
.2631 .01472 m
.2631 .01474 L
s
.26405 .01472 m
.26405 .01474 L
s
.265 .01472 m
.265 .01474 L
s
.26596 .01472 m
.26596 .01474 L
s
.26691 .01472 m
.26691 .01474 L
s
.26786 .01472 m
.26786 .01474 L
s
.26882 .01472 m
.26882 .01474 L
s
.26977 .01472 m
.26977 .01474 L
s
.27072 .01472 m
.27072 .01474 L
s
.27168 .01472 m
.27168 .01474 L
s
.27263 .01472 m
.27263 .01474 L
s
.27358 .01472 m
.27358 .01474 L
s
.27454 .01472 m
.27454 .01474 L
s
.27549 .01472 m
.27549 .01474 L
s
.27644 .01472 m
.27644 .01474 L
s
.2774 .01472 m
.2774 .01474 L
s
.27835 .01472 m
.27835 .01474 L
s
.2793 .01472 m
.2793 .01474 L
s
.28026 .01472 m
.28026 .01474 L
s
.28121 .01472 m
.28121 .01474 L
s
.28216 .01472 m
.28216 .01474 L
s
.28312 .01472 m
.28312 .01474 L
s
.28407 .01472 m
.28407 .01474 L
s
.28502 .01472 m
.28502 .01474 L
s
.28598 .01472 m
.28598 .01474 L
s
.28693 .01472 m
.28693 .01474 L
s
.28788 .01472 m
.28788 .01474 L
s
.28884 .01472 m
.28884 .01474 L
s
.28979 .01472 m
.28979 .01474 L
s
.29074 .01472 m
.29074 .01474 L
s
.2917 .01472 m
.2917 .01474 L
s
.29265 .01472 m
.29265 .01474 L
s
.2936 .01472 m
.2936 .01474 L
s
.29456 .01472 m
.29456 .01474 L
s
.29551 .01472 m
.29551 .01474 L
s
.29646 .01472 m
.29646 .01474 L
s
.29742 .01472 m
.29742 .01475 L
s
.29837 .01472 m
.29837 .01475 L
s
.29932 .01472 m
.29932 .01475 L
s
.30028 .01472 m
.30028 .01475 L
s
.30123 .01472 m
.30123 .01475 L
s
.30218 .01472 m
.30218 .01475 L
s
.30314 .01472 m
.30314 .01475 L
s
.30409 .01472 m
.30409 .01475 L
s
.30504 .01472 m
.30504 .01475 L
s
.306 .01472 m
.306 .01475 L
s
.30695 .01472 m
.30695 .01475 L
s
.3079 .01472 m
.3079 .01475 L
s
.30886 .01472 m
.30886 .01475 L
s
.30981 .01472 m
.30981 .01475 L
s
.31076 .01472 m
.31076 .01475 L
s
.31172 .01472 m
.31172 .01475 L
s
.31267 .01472 m
.31267 .01475 L
s
.31362 .01472 m
.31362 .01475 L
s
.31458 .01472 m
.31458 .01475 L
s
.31553 .01472 m
.31553 .01475 L
s
.31648 .01472 m
.31648 .01475 L
s
.31744 .01472 m
.31744 .01475 L
s
.31839 .01472 m
.31839 .01475 L
s
.31934 .01472 m
.31934 .01475 L
s
.3203 .01472 m
.3203 .01475 L
s
.32125 .01472 m
.32125 .01475 L
s
.3222 .01472 m
.3222 .01475 L
s
.32316 .01472 m
.32316 .01475 L
s
.32411 .01472 m
.32411 .01475 L
s
.32506 .01472 m
.32506 .01475 L
s
.32602 .01472 m
.32602 .01475 L
s
.32697 .01472 m
.32697 .01475 L
s
.32792 .01472 m
.32792 .01475 L
s
.32888 .01472 m
.32888 .01475 L
s
.32983 .01472 m
.32983 .01475 L
s
.33078 .01472 m
.33078 .01475 L
s
.33174 .01472 m
.33174 .01475 L
s
.33269 .01472 m
.33269 .01475 L
s
.33364 .01472 m
.33364 .01475 L
s
.3346 .01472 m
.3346 .01475 L
s
.33555 .01472 m
.33555 .01475 L
s
.3365 .01472 m
.3365 .01475 L
s
.33746 .01472 m
.33746 .01475 L
s
.33841 .01472 m
.33841 .01475 L
s
.33936 .01472 m
.33936 .01475 L
s
.34032 .01472 m
.34032 .01475 L
s
.34127 .01472 m
.34127 .01475 L
s
.34222 .01472 m
.34222 .01475 L
s
.34318 .01472 m
.34318 .01475 L
s
.34413 .01472 m
.34413 .01475 L
s
.34508 .01472 m
.34508 .01475 L
s
.34604 .01472 m
.34604 .01475 L
s
.34699 .01472 m
.34699 .01475 L
s
.34794 .01472 m
.34794 .01475 L
s
.3489 .01472 m
.3489 .01475 L
s
.34985 .01472 m
.34985 .01475 L
s
.3508 .01472 m
.3508 .01475 L
s
.35176 .01472 m
.35176 .01475 L
s
.35271 .01472 m
.35271 .01476 L
s
.35366 .01472 m
.35366 .01476 L
s
.35462 .01472 m
.35462 .01476 L
s
.35557 .01472 m
.35557 .01476 L
s
.35652 .01472 m
.35652 .01476 L
s
.35748 .01472 m
.35748 .01476 L
s
.35843 .01472 m
.35843 .01476 L
s
.35938 .01472 m
.35938 .01476 L
s
.36034 .01472 m
.36034 .01476 L
s
.36129 .01472 m
.36129 .01476 L
s
.36224 .01472 m
.36224 .01476 L
s
.3632 .01472 m
.3632 .01476 L
s
.36415 .01472 m
.36415 .01476 L
s
.3651 .01472 m
.3651 .01476 L
s
.36606 .01472 m
.36606 .01476 L
s
.36701 .01472 m
.36701 .01476 L
s
.36796 .01472 m
.36796 .01476 L
s
.36892 .01472 m
.36892 .01476 L
s
.36987 .01472 m
.36987 .01476 L
s
.37082 .01472 m
.37082 .01476 L
s
.37178 .01472 m
.37178 .01476 L
s
.37273 .01472 m
.37273 .01476 L
s
.37368 .01472 m
.37368 .01476 L
s
.37464 .01472 m
.37464 .01476 L
s
.37559 .01472 m
.37559 .01476 L
s
.37654 .01472 m
.37654 .01476 L
s
.3775 .01472 m
.3775 .01476 L
s
.37845 .01472 m
.37845 .01476 L
s
.3794 .01472 m
.3794 .01476 L
s
.38036 .01472 m
.38036 .01476 L
s
.38131 .01472 m
.38131 .01476 L
s
.38226 .01472 m
.38226 .01476 L
s
.38322 .01472 m
.38322 .01476 L
s
.38417 .01472 m
.38417 .01477 L
s
.38512 .01472 m
.38512 .01477 L
s
.38608 .01472 m
.38608 .01477 L
s
.38703 .01472 m
.38703 .01477 L
s
.38798 .01472 m
.38798 .01477 L
s
.38894 .01472 m
.38894 .01477 L
s
.38989 .01472 m
.38989 .01477 L
s
.39084 .01472 m
.39084 .01477 L
s
.3918 .01472 m
.3918 .01477 L
s
.39275 .01472 m
.39275 .01477 L
s
.3937 .01472 m
.3937 .01477 L
s
.39466 .01472 m
.39466 .01477 L
s
.39561 .01472 m
.39561 .01477 L
s
.39656 .01472 m
.39656 .01477 L
s
.39752 .01472 m
.39752 .01477 L
s
.39847 .01472 m
.39847 .01477 L
s
.39942 .01472 m
.39942 .01477 L
s
.40038 .01472 m
.40038 .01477 L
s
.40133 .01472 m
.40133 .01477 L
s
.40228 .01472 m
.40228 .01477 L
s
.40324 .01472 m
.40324 .01477 L
s
.40419 .01472 m
.40419 .01478 L
s
.40514 .01472 m
.40514 .01478 L
s
.4061 .01472 m
.4061 .01478 L
s
.40705 .01472 m
.40705 .01478 L
s
.408 .01472 m
.408 .01478 L
s
.40896 .01472 m
.40896 .01478 L
s
.40991 .01472 m
.40991 .01478 L
s
.41086 .01472 m
.41086 .01478 L
s
.41182 .01472 m
.41182 .01478 L
s
.41277 .01472 m
.41277 .01478 L
s
.41372 .01472 m
.41372 .01478 L
s
.41468 .01472 m
.41468 .01478 L
s
.41563 .01472 m
.41563 .01478 L
s
.41658 .01472 m
.41658 .01478 L
s
.41754 .01472 m
.41754 .01479 L
s
.41849 .01472 m
.41849 .01479 L
s
.41944 .01472 m
.41944 .01479 L
s
.4204 .01472 m
.4204 .01479 L
s
.42135 .01472 m
.42135 .01479 L
s
.4223 .01472 m
.4223 .01479 L
s
.42326 .01472 m
.42326 .01479 L
s
.42421 .01472 m
.42421 .01479 L
s
.42516 .01472 m
.42516 .01479 L
s
.42612 .01472 m
.42612 .01479 L
s
.42707 .01472 m
.42707 .01479 L
s
.42802 .01472 m
.42802 .0148 L
s
.42898 .01472 m
.42898 .0148 L
s
.42993 .01472 m
.42993 .0148 L
s
.43088 .01472 m
.43088 .0148 L
s
.43184 .01472 m
.43184 .0148 L
s
.43279 .01472 m
.43279 .0148 L
s
.43374 .01472 m
.43374 .0148 L
s
.4347 .01472 m
.4347 .0148 L
s
.43565 .01472 m
.43565 .01481 L
s
.4366 .01472 m
.4366 .01481 L
s
.43756 .01472 m
.43756 .01481 L
s
.43851 .01472 m
.43851 .01481 L
s
.43946 .01472 m
.43946 .01481 L
s
.44042 .01472 m
.44042 .01481 L
s
.44137 .01472 m
.44137 .01481 L
s
.44232 .01472 m
.44232 .01482 L
s
.44328 .01472 m
.44328 .01482 L
s
.44423 .01472 m
.44423 .01482 L
s
.44518 .01472 m
.44518 .01482 L
s
.44614 .01472 m
.44614 .01482 L
s
.44709 .01472 m
.44709 .01483 L
s
.44804 .01472 m
.44804 .01483 L
s
.449 .01472 m
.449 .01483 L
s
.44995 .01472 m
.44995 .01483 L
s
.4509 .01472 m
.4509 .01484 L
s
.45186 .01472 m
.45186 .01484 L
s
.45281 .01472 m
.45281 .01484 L
s
.45376 .01472 m
.45376 .01484 L
s
.45472 .01472 m
.45472 .01485 L
s
.45567 .01472 m
.45567 .01485 L
s
.45662 .01472 m
.45662 .01485 L
s
.45758 .01472 m
.45758 .01486 L
s
.45853 .01472 m
.45853 .01486 L
s
.45948 .01472 m
.45948 .01486 L
s
.46044 .01472 m
.46044 .01487 L
s
.46139 .01472 m
.46139 .01487 L
s
.46234 .01472 m
.46234 .01488 L
s
.4633 .01472 m
.4633 .01488 L
s
.46425 .01472 m
.46425 .01489 L
s
.4652 .01472 m
.4652 .01489 L
s
.46616 .01472 m
.46616 .0149 L
s
.46711 .01472 m
.46711 .01491 L
s
.46806 .01472 m
.46806 .01491 L
s
.46902 .01472 m
.46902 .01492 L
s
.46997 .01472 m
.46997 .01493 L
s
.47092 .01472 m
.47092 .01494 L
s
.47188 .01472 m
.47188 .01495 L
s
.47283 .01472 m
.47283 .01496 L
s
.47378 .01472 m
.47378 .01497 L
s
.47474 .01472 m
.47474 .01498 L
s
.47569 .01472 m
.47569 .015 L
s
.47664 .01472 m
.47664 .01501 L
s
.4776 .01472 m
.4776 .01503 L
s
.47855 .01472 m
.47855 .01505 L
s
.4795 .01472 m
.4795 .01508 L
s
.48046 .01472 m
.48046 .01511 L
s
.48141 .01472 m
.48141 .01514 L
s
.48236 .01472 m
.48236 .01519 L
s
.48332 .01472 m
.48332 .01525 L
s
.48427 .01472 m
.48427 .01532 L
s
.48522 .01472 m
.48522 .01542 L
s
.48618 .01472 m
.48618 .01558 L
s
.48713 .01472 m
.48713 .01583 L
s
.48808 .01472 m
.48808 .01633 L
s
.48904 .01472 m
.48904 .01783 L
s
.48999 .01472 m
.48999 .30882 L
s
.49094 .01472 m
.49094 .01748 L
s
.4919 .01472 m
.4919 .01602 L
s
.49285 .01472 m
.49285 .01552 L
s
.4938 .01472 m
.4938 .01527 L
s
.49476 .01472 m
.49476 .01511 L
s
.49571 .01472 m
.49571 .01499 L
s
.49666 .01472 m
.49666 .01491 L
s
.49762 .01472 m
.49762 .01484 L
s
.49857 .01472 m
.49857 .01477 L
s
.49952 .01472 m
.49952 .60332 L
s
.50048 .01472 m
.50048 .01477 L
s
.50143 .01472 m
.50143 .01484 L
s
.50238 .01472 m
.50238 .01491 L
s
.50334 .01472 m
.50334 .01499 L
s
.50429 .01472 m
.50429 .01511 L
s
.50524 .01472 m
.50524 .01527 L
s
.5062 .01472 m
.5062 .01552 L
s
.50715 .01472 m
.50715 .01602 L
s
.5081 .01472 m
.5081 .01748 L
s
.50906 .01472 m
.50906 .30882 L
s
.51001 .01472 m
.51001 .01783 L
s
.51096 .01472 m
.51096 .01633 L
s
.51192 .01472 m
.51192 .01583 L
s
.51287 .01472 m
.51287 .01558 L
s
.51382 .01472 m
.51382 .01542 L
s
.51478 .01472 m
.51478 .01532 L
s
.51573 .01472 m
.51573 .01525 L
s
.51668 .01472 m
.51668 .01519 L
s
.51764 .01472 m
.51764 .01514 L
s
.51859 .01472 m
.51859 .01511 L
s
.51954 .01472 m
.51954 .01508 L
s
.5205 .01472 m
.5205 .01505 L
s
.52145 .01472 m
.52145 .01503 L
s
.5224 .01472 m
.5224 .01501 L
s
.52336 .01472 m
.52336 .015 L
s
.52431 .01472 m
.52431 .01498 L
s
.52526 .01472 m
.52526 .01497 L
s
.52622 .01472 m
.52622 .01496 L
s
.52717 .01472 m
.52717 .01495 L
s
.52812 .01472 m
.52812 .01494 L
s
.52908 .01472 m
.52908 .01493 L
s
.53003 .01472 m
.53003 .01492 L
s
.53098 .01472 m
.53098 .01491 L
s
.53194 .01472 m
.53194 .01491 L
s
.53289 .01472 m
.53289 .0149 L
s
.53384 .01472 m
.53384 .01489 L
s
.5348 .01472 m
.5348 .01489 L
s
.53575 .01472 m
.53575 .01488 L
s
.5367 .01472 m
.5367 .01488 L
s
.53766 .01472 m
.53766 .01487 L
s
.53861 .01472 m
.53861 .01487 L
s
.53956 .01472 m
.53956 .01486 L
s
.54052 .01472 m
.54052 .01486 L
s
.54147 .01472 m
.54147 .01486 L
s
.54242 .01472 m
.54242 .01485 L
s
.54338 .01472 m
.54338 .01485 L
s
.54433 .01472 m
.54433 .01485 L
s
.54528 .01472 m
.54528 .01484 L
s
.54624 .01472 m
.54624 .01484 L
s
.54719 .01472 m
.54719 .01484 L
s
.54814 .01472 m
.54814 .01484 L
s
.5491 .01472 m
.5491 .01483 L
s
.55005 .01472 m
.55005 .01483 L
s
.551 .01472 m
.551 .01483 L
s
.55196 .01472 m
.55196 .01483 L
s
.55291 .01472 m
.55291 .01482 L
s
.55386 .01472 m
.55386 .01482 L
s
.55482 .01472 m
.55482 .01482 L
s
.55577 .01472 m
.55577 .01482 L
s
.55672 .01472 m
.55672 .01482 L
s
.55768 .01472 m
.55768 .01481 L
s
.55863 .01472 m
.55863 .01481 L
s
.55958 .01472 m
.55958 .01481 L
s
.56054 .01472 m
.56054 .01481 L
s
.56149 .01472 m
.56149 .01481 L
s
.56244 .01472 m
.56244 .01481 L
s
.5634 .01472 m
.5634 .01481 L
s
.56435 .01472 m
.56435 .0148 L
s
.5653 .01472 m
.5653 .0148 L
s
.56626 .01472 m
.56626 .0148 L
s
.56721 .01472 m
.56721 .0148 L
s
.56816 .01472 m
.56816 .0148 L
s
.56912 .01472 m
.56912 .0148 L
s
.57007 .01472 m
.57007 .0148 L
s
.57102 .01472 m
.57102 .0148 L
s
.57198 .01472 m
.57198 .01479 L
s
.57293 .01472 m
.57293 .01479 L
s
.57388 .01472 m
.57388 .01479 L
s
.57484 .01472 m
.57484 .01479 L
s
.57579 .01472 m
.57579 .01479 L
s
.57674 .01472 m
.57674 .01479 L
s
.5777 .01472 m
.5777 .01479 L
s
.57865 .01472 m
.57865 .01479 L
s
.5796 .01472 m
.5796 .01479 L
s
.58056 .01472 m
.58056 .01479 L
s
.58151 .01472 m
.58151 .01479 L
s
.58246 .01472 m
.58246 .01478 L
s
.58342 .01472 m
.58342 .01478 L
s
.58437 .01472 m
.58437 .01478 L
s
.58532 .01472 m
.58532 .01478 L
s
.58628 .01472 m
.58628 .01478 L
s
.58723 .01472 m
.58723 .01478 L
s
.58818 .01472 m
.58818 .01478 L
s
.58914 .01472 m
.58914 .01478 L
s
.59009 .01472 m
.59009 .01478 L
s
.59104 .01472 m
.59104 .01478 L
s
.592 .01472 m
.592 .01478 L
s
.59295 .01472 m
.59295 .01478 L
s
.5939 .01472 m
.5939 .01478 L
s
.59486 .01472 m
.59486 .01478 L
s
.59581 .01472 m
.59581 .01477 L
s
.59676 .01472 m
.59676 .01477 L
s
.59772 .01472 m
.59772 .01477 L
s
.59867 .01472 m
.59867 .01477 L
s
.59962 .01472 m
.59962 .01477 L
s
.60058 .01472 m
.60058 .01477 L
s
.60153 .01472 m
.60153 .01477 L
s
.60248 .01472 m
.60248 .01477 L
s
.60344 .01472 m
.60344 .01477 L
s
.60439 .01472 m
.60439 .01477 L
s
.60534 .01472 m
.60534 .01477 L
s
.6063 .01472 m
.6063 .01477 L
s
.60725 .01472 m
.60725 .01477 L
s
.6082 .01472 m
.6082 .01477 L
s
.60916 .01472 m
.60916 .01477 L
s
.61011 .01472 m
.61011 .01477 L
s
.61106 .01472 m
.61106 .01477 L
s
.61202 .01472 m
.61202 .01477 L
s
.61297 .01472 m
.61297 .01477 L
s
.61392 .01472 m
.61392 .01477 L
s
.61488 .01472 m
.61488 .01477 L
s
.61583 .01472 m
.61583 .01476 L
s
.61678 .01472 m
.61678 .01476 L
s
.61774 .01472 m
.61774 .01476 L
s
.61869 .01472 m
.61869 .01476 L
s
.61964 .01472 m
.61964 .01476 L
s
.6206 .01472 m
.6206 .01476 L
s
.62155 .01472 m
.62155 .01476 L
s
.6225 .01472 m
.6225 .01476 L
s
.62346 .01472 m
.62346 .01476 L
s
.62441 .01472 m
.62441 .01476 L
s
.62536 .01472 m
.62536 .01476 L
s
.62632 .01472 m
.62632 .01476 L
s
.62727 .01472 m
.62727 .01476 L
s
.62822 .01472 m
.62822 .01476 L
s
.62918 .01472 m
.62918 .01476 L
s
.63013 .01472 m
.63013 .01476 L
s
.63108 .01472 m
.63108 .01476 L
s
.63204 .01472 m
.63204 .01476 L
s
.63299 .01472 m
.63299 .01476 L
s
.63394 .01472 m
.63394 .01476 L
s
.6349 .01472 m
.6349 .01476 L
s
.63585 .01472 m
.63585 .01476 L
s
.6368 .01472 m
.6368 .01476 L
s
.63776 .01472 m
.63776 .01476 L
s
.63871 .01472 m
.63871 .01476 L
s
.63966 .01472 m
.63966 .01476 L
s
.64062 .01472 m
.64062 .01476 L
s
.64157 .01472 m
.64157 .01476 L
s
.64252 .01472 m
.64252 .01476 L
s
.64348 .01472 m
.64348 .01476 L
s
.64443 .01472 m
.64443 .01476 L
s
.64538 .01472 m
.64538 .01476 L
s
.64634 .01472 m
.64634 .01476 L
s
.64729 .01472 m
.64729 .01475 L
s
.64824 .01472 m
.64824 .01475 L
s
.6492 .01472 m
.6492 .01475 L
s
.65015 .01472 m
.65015 .01475 L
s
.6511 .01472 m
.6511 .01475 L
s
.65206 .01472 m
.65206 .01475 L
s
.65301 .01472 m
.65301 .01475 L
s
.65396 .01472 m
.65396 .01475 L
s
.65492 .01472 m
.65492 .01475 L
s
.65587 .01472 m
.65587 .01475 L
s
.65682 .01472 m
.65682 .01475 L
s
.65778 .01472 m
.65778 .01475 L
s
.65873 .01472 m
.65873 .01475 L
s
.65968 .01472 m
.65968 .01475 L
s
.66064 .01472 m
.66064 .01475 L
s
.66159 .01472 m
.66159 .01475 L
s
.66254 .01472 m
.66254 .01475 L
s
.6635 .01472 m
.6635 .01475 L
s
.66445 .01472 m
.66445 .01475 L
s
.6654 .01472 m
.6654 .01475 L
s
.66636 .01472 m
.66636 .01475 L
s
.66731 .01472 m
.66731 .01475 L
s
.66826 .01472 m
.66826 .01475 L
s
.66922 .01472 m
.66922 .01475 L
s
.67017 .01472 m
.67017 .01475 L
s
.67112 .01472 m
.67112 .01475 L
s
.67208 .01472 m
.67208 .01475 L
s
.67303 .01472 m
.67303 .01475 L
s
.67398 .01472 m
.67398 .01475 L
s
.67494 .01472 m
.67494 .01475 L
s
.67589 .01472 m
.67589 .01475 L
s
.67684 .01472 m
.67684 .01475 L
s
.6778 .01472 m
.6778 .01475 L
s
.67875 .01472 m
.67875 .01475 L
s
.6797 .01472 m
.6797 .01475 L
s
.68066 .01472 m
.68066 .01475 L
s
.68161 .01472 m
.68161 .01475 L
s
.68256 .01472 m
.68256 .01475 L
s
.68352 .01472 m
.68352 .01475 L
s
.68447 .01472 m
.68447 .01475 L
s
.68542 .01472 m
.68542 .01475 L
s
.68638 .01472 m
.68638 .01475 L
s
.68733 .01472 m
.68733 .01475 L
s
.68828 .01472 m
.68828 .01475 L
s
.68924 .01472 m
.68924 .01475 L
s
.69019 .01472 m
.69019 .01475 L
s
.69114 .01472 m
.69114 .01475 L
s
.6921 .01472 m
.6921 .01475 L
s
.69305 .01472 m
.69305 .01475 L
s
.694 .01472 m
.694 .01475 L
s
.69496 .01472 m
.69496 .01475 L
s
.69591 .01472 m
.69591 .01475 L
s
.69686 .01472 m
.69686 .01475 L
s
.69782 .01472 m
.69782 .01475 L
s
.69877 .01472 m
.69877 .01475 L
s
.69972 .01472 m
.69972 .01475 L
s
.70068 .01472 m
.70068 .01475 L
s
.70163 .01472 m
.70163 .01475 L
s
.70258 .01472 m
.70258 .01474 L
s
.70354 .01472 m
.70354 .01474 L
s
.70449 .01472 m
.70449 .01474 L
s
.70544 .01472 m
.70544 .01474 L
s
.7064 .01472 m
.7064 .01474 L
s
.70735 .01472 m
.70735 .01474 L
s
.7083 .01472 m
.7083 .01474 L
s
.70926 .01472 m
.70926 .01474 L
s
.71021 .01472 m
.71021 .01474 L
s
.71116 .01472 m
.71116 .01474 L
s
.71212 .01472 m
.71212 .01474 L
s
.71307 .01472 m
.71307 .01474 L
s
.71402 .01472 m
.71402 .01474 L
s
.71498 .01472 m
.71498 .01474 L
s
.71593 .01472 m
.71593 .01474 L
s
.71688 .01472 m
.71688 .01474 L
s
.71784 .01472 m
.71784 .01474 L
s
.71879 .01472 m
.71879 .01474 L
s
.71974 .01472 m
.71974 .01474 L
s
.7207 .01472 m
.7207 .01474 L
s
.72165 .01472 m
.72165 .01474 L
s
.7226 .01472 m
.7226 .01474 L
s
.72356 .01472 m
.72356 .01474 L
s
.72451 .01472 m
.72451 .01474 L
s
.72546 .01472 m
.72546 .01474 L
s
.72642 .01472 m
.72642 .01474 L
s
.72737 .01472 m
.72737 .01474 L
s
.72832 .01472 m
.72832 .01474 L
s
.72928 .01472 m
.72928 .01474 L
s
.73023 .01472 m
.73023 .01474 L
s
.73118 .01472 m
.73118 .01474 L
s
.73214 .01472 m
.73214 .01474 L
s
.73309 .01472 m
.73309 .01474 L
s
.73404 .01472 m
.73404 .01474 L
s
.735 .01472 m
.735 .01474 L
s
.73595 .01472 m
.73595 .01474 L
s
.7369 .01472 m
.7369 .01474 L
s
.73786 .01472 m
.73786 .01474 L
s
.73881 .01472 m
.73881 .01474 L
s
.73976 .01472 m
.73976 .01474 L
s
.74072 .01472 m
.74072 .01474 L
s
.74167 .01472 m
.74167 .01474 L
s
.74262 .01472 m
.74262 .01474 L
s
.74358 .01472 m
.74358 .01474 L
s
.74453 .01472 m
.74453 .01474 L
s
.74548 .01472 m
.74548 .01474 L
s
.74644 .01472 m
.74644 .01474 L
s
.74739 .01472 m
.74739 .01474 L
s
.74834 .01472 m
.74834 .01474 L
s
.7493 .01472 m
.7493 .01474 L
s
.75025 .01472 m
.75025 .01474 L
s
.7512 .01472 m
.7512 .01474 L
s
.75216 .01472 m
.75216 .01474 L
s
.75311 .01472 m
.75311 .01474 L
s
.75406 .01472 m
.75406 .01474 L
s
.75502 .01472 m
.75502 .01474 L
s
.75597 .01472 m
.75597 .01474 L
s
.75692 .01472 m
.75692 .01474 L
s
.75788 .01472 m
.75788 .01474 L
s
.75883 .01472 m
.75883 .01474 L
s
.75978 .01472 m
.75978 .01474 L
s
.76074 .01472 m
.76074 .01474 L
s
.76169 .01472 m
.76169 .01474 L
s
.76264 .01472 m
.76264 .01474 L
s
.7636 .01472 m
.7636 .01474 L
s
.76455 .01472 m
.76455 .01474 L
s
.7655 .01472 m
.7655 .01474 L
s
.76646 .01472 m
.76646 .01474 L
s
.76741 .01472 m
.76741 .01474 L
s
.76836 .01472 m
.76836 .01474 L
s
.76932 .01472 m
.76932 .01474 L
s
.77027 .01472 m
.77027 .01474 L
s
.77122 .01472 m
.77122 .01474 L
s
.77218 .01472 m
.77218 .01474 L
s
.77313 .01472 m
.77313 .01474 L
s
.77408 .01472 m
.77408 .01474 L
s
.77504 .01472 m
.77504 .01474 L
s
.77599 .01472 m
.77599 .01474 L
s
.77694 .01472 m
.77694 .01474 L
s
.7779 .01472 m
.7779 .01474 L
s
.77885 .01472 m
.77885 .01474 L
s
.7798 .01472 m
.7798 .01474 L
s
.78076 .01472 m
.78076 .01474 L
s
.78171 .01472 m
.78171 .01474 L
s
.78266 .01472 m
.78266 .01474 L
s
.78362 .01472 m
.78362 .01474 L
s
.78457 .01472 m
.78457 .01474 L
s
.78552 .01472 m
.78552 .01474 L
s
.78648 .01472 m
.78648 .01474 L
s
.78743 .01472 m
.78743 .01474 L
s
.78838 .01472 m
.78838 .01474 L
s
.78934 .01472 m
.78934 .01474 L
s
.79029 .01472 m
.79029 .01474 L
s
.79124 .01472 m
.79124 .01474 L
s
.7922 .01472 m
.7922 .01474 L
s
.79315 .01472 m
.79315 .01474 L
s
.7941 .01472 m
.7941 .01474 L
s
.79506 .01472 m
.79506 .01474 L
s
.79601 .01472 m
.79601 .01474 L
s
.79696 .01472 m
.79696 .01474 L
s
.79792 .01472 m
.79792 .01474 L
s
.79887 .01472 m
.79887 .01474 L
s
.79982 .01472 m
.79982 .01474 L
s
.80078 .01472 m
.80078 .01474 L
s
.80173 .01472 m
.80173 .01474 L
s
.80268 .01472 m
.80268 .01474 L
s
.80364 .01472 m
.80364 .01474 L
s
.80459 .01472 m
.80459 .01474 L
s
.80554 .01472 m
.80554 .01474 L
s
.8065 .01472 m
.8065 .01474 L
s
.80745 .01472 m
.80745 .01474 L
s
.8084 .01472 m
.8084 .01474 L
s
.80936 .01472 m
.80936 .01474 L
s
.81031 .01472 m
.81031 .01474 L
s
.81126 .01472 m
.81126 .01474 L
s
.81222 .01472 m
.81222 .01474 L
s
.81317 .01472 m
.81317 .01474 L
s
.81412 .01472 m
.81412 .01474 L
s
.81508 .01472 m
.81508 .01474 L
s
.81603 .01472 m
.81603 .01474 L
s
.81698 .01472 m
.81698 .01474 L
s
.81794 .01472 m
.81794 .01474 L
s
.81889 .01472 m
.81889 .01474 L
s
.81984 .01472 m
.81984 .01474 L
s
.8208 .01472 m
.8208 .01474 L
s
.82175 .01472 m
.82175 .01474 L
s
.8227 .01472 m
.8227 .01474 L
s
.82366 .01472 m
.82366 .01474 L
s
.82461 .01472 m
.82461 .01474 L
s
.82556 .01472 m
.82556 .01474 L
s
.82652 .01472 m
.82652 .01474 L
s
.82747 .01472 m
.82747 .01474 L
s
.82842 .01472 m
.82842 .01474 L
s
.82938 .01472 m
.82938 .01474 L
s
.83033 .01472 m
.83033 .01474 L
s
.83128 .01472 m
.83128 .01474 L
s
.83224 .01472 m
.83224 .01474 L
s
.83319 .01472 m
.83319 .01474 L
s
.83414 .01472 m
.83414 .01474 L
s
.8351 .01472 m
.8351 .01474 L
s
.83605 .01472 m
.83605 .01474 L
s
.837 .01472 m
.837 .01474 L
s
.83796 .01472 m
.83796 .01474 L
s
.83891 .01472 m
.83891 .01474 L
s
.83986 .01472 m
.83986 .01474 L
s
.84082 .01472 m
.84082 .01474 L
s
.84177 .01472 m
.84177 .01474 L
s
.84272 .01472 m
.84272 .01474 L
s
.84368 .01472 m
.84368 .01474 L
s
.84463 .01472 m
.84463 .01474 L
s
.84558 .01472 m
.84558 .01474 L
s
.84654 .01472 m
.84654 .01474 L
s
.84749 .01472 m
.84749 .01474 L
s
.84844 .01472 m
.84844 .01474 L
s
.8494 .01472 m
.8494 .01474 L
s
.85035 .01472 m
.85035 .01474 L
s
.8513 .01472 m
.8513 .01474 L
s
.85226 .01472 m
.85226 .01474 L
s
.85321 .01472 m
.85321 .01474 L
s
.85416 .01472 m
.85416 .01474 L
s
.85512 .01472 m
.85512 .01474 L
s
.85607 .01472 m
.85607 .01474 L
s
.85702 .01472 m
.85702 .01474 L
s
.85798 .01472 m
.85798 .01474 L
s
.85893 .01472 m
.85893 .01474 L
s
.85988 .01472 m
.85988 .01474 L
s
.86084 .01472 m
.86084 .01474 L
s
.86179 .01472 m
.86179 .01474 L
s
.86274 .01472 m
.86274 .01473 L
s
.8637 .01472 m
.8637 .01473 L
s
.86465 .01472 m
.86465 .01473 L
s
.8656 .01472 m
.8656 .01473 L
s
.86656 .01472 m
.86656 .01473 L
s
.86751 .01472 m
.86751 .01473 L
s
.86846 .01472 m
.86846 .01473 L
s
.86942 .01472 m
.86942 .01473 L
s
.87037 .01472 m
.87037 .01473 L
s
.87132 .01472 m
.87132 .01473 L
s
.87228 .01472 m
.87228 .01473 L
s
.87323 .01472 m
.87323 .01473 L
s
.87418 .01472 m
.87418 .01473 L
s
.87514 .01472 m
.87514 .01473 L
s
.87609 .01472 m
.87609 .01473 L
s
.87704 .01472 m
.87704 .01473 L
s
.878 .01472 m
.878 .01473 L
s
.87895 .01472 m
.87895 .01473 L
s
.8799 .01472 m
.8799 .01473 L
s
.88086 .01472 m
.88086 .01473 L
s
.88181 .01472 m
.88181 .01473 L
s
.88276 .01472 m
.88276 .01473 L
s
.88372 .01472 m
.88372 .01473 L
s
.88467 .01472 m
.88467 .01473 L
s
.88562 .01472 m
.88562 .01473 L
s
.88658 .01472 m
.88658 .01473 L
s
.88753 .01472 m
.88753 .01473 L
s
.88848 .01472 m
.88848 .01473 L
s
.88944 .01472 m
.88944 .01473 L
s
.89039 .01472 m
.89039 .01473 L
s
.89134 .01472 m
.89134 .01473 L
s
.8923 .01472 m
.8923 .01473 L
s
.89325 .01472 m
.89325 .01473 L
s
.8942 .01472 m
.8942 .01473 L
s
.89516 .01472 m
.89516 .01473 L
s
.89611 .01472 m
.89611 .01473 L
s
.89706 .01472 m
.89706 .01473 L
s
.89802 .01472 m
.89802 .01473 L
s
.89897 .01472 m
.89897 .01473 L
s
.89992 .01472 m
.89992 .01473 L
s
.90088 .01472 m
.90088 .01473 L
s
.90183 .01472 m
.90183 .01473 L
s
.90278 .01472 m
.90278 .01473 L
s
.90374 .01472 m
.90374 .01473 L
s
.90469 .01472 m
.90469 .01473 L
s
.90564 .01472 m
.90564 .01473 L
s
.9066 .01472 m
.9066 .01473 L
s
.90755 .01472 m
.90755 .01473 L
s
.9085 .01472 m
.9085 .01473 L
s
.90946 .01472 m
.90946 .01473 L
s
.91041 .01472 m
.91041 .01473 L
s
.91136 .01472 m
.91136 .01473 L
s
.91232 .01472 m
.91232 .01473 L
s
.91327 .01472 m
.91327 .01473 L
s
.91422 .01472 m
.91422 .01473 L
s
.91518 .01472 m
.91518 .01473 L
s
.91613 .01472 m
.91613 .01473 L
s
.91708 .01472 m
.91708 .01473 L
s
.91804 .01472 m
.91804 .01473 L
s
.91899 .01472 m
.91899 .01473 L
s
.91994 .01472 m
.91994 .01473 L
s
.9209 .01472 m
.9209 .01473 L
s
.92185 .01472 m
.92185 .01473 L
s
.9228 .01472 m
.9228 .01473 L
s
.92376 .01472 m
.92376 .01473 L
s
.92471 .01472 m
.92471 .01473 L
s
.92566 .01472 m
.92566 .01473 L
s
.92662 .01472 m
.92662 .01473 L
s
.92757 .01472 m
.92757 .01473 L
s
.92852 .01472 m
.92852 .01473 L
s
.92948 .01472 m
.92948 .01473 L
s
.93043 .01472 m
.93043 .01473 L
s
.93138 .01472 m
.93138 .01473 L
s
.93234 .01472 m
.93234 .01473 L
s
.93329 .01472 m
.93329 .01473 L
s
.93424 .01472 m
.93424 .01473 L
s
.9352 .01472 m
.9352 .01473 L
s
.93615 .01472 m
.93615 .01473 L
s
.9371 .01472 m
.9371 .01473 L
s
.93806 .01472 m
.93806 .01473 L
s
.93901 .01472 m
.93901 .01473 L
s
.93996 .01472 m
.93996 .01473 L
s
.94092 .01472 m
.94092 .01473 L
s
.94187 .01472 m
.94187 .01473 L
s
.94282 .01472 m
.94282 .01473 L
s
.94378 .01472 m
.94378 .01473 L
s
.94473 .01472 m
.94473 .01473 L
s
.94568 .01472 m
.94568 .01473 L
s
.94664 .01472 m
.94664 .01473 L
s
.94759 .01472 m
.94759 .01473 L
s
.94854 .01472 m
.94854 .01473 L
s
.9495 .01472 m
.9495 .01473 L
s
.95045 .01472 m
.95045 .01473 L
s
.9514 .01472 m
.9514 .01473 L
s
.95236 .01472 m
.95236 .01473 L
s
.95331 .01472 m
.95331 .01473 L
s
.95426 .01472 m
.95426 .01473 L
s
.95522 .01472 m
.95522 .01473 L
s
.95617 .01472 m
.95617 .01473 L
s
.95712 .01472 m
.95712 .01473 L
s
.95808 .01472 m
.95808 .01473 L
s
.95903 .01472 m
.95903 .01473 L
s
.95998 .01472 m
.95998 .01473 L
s
.96094 .01472 m
.96094 .01473 L
s
.96189 .01472 m
.96189 .01473 L
s
.96284 .01472 m
.96284 .01473 L
s
.9638 .01472 m
.9638 .01473 L
s
.96475 .01472 m
.96475 .01473 L
s
.9657 .01472 m
.9657 .01473 L
s
.96666 .01472 m
.96666 .01473 L
s
.96761 .01472 m
.96761 .01473 L
s
.96856 .01472 m
.96856 .01473 L
s
.96952 .01472 m
.96952 .01473 L
s
.97047 .01472 m
.97047 .01473 L
s
.97142 .01472 m
.97142 .01473 L
s
.97238 .01472 m
.97238 .01473 L
s
.97333 .01472 m
.97333 .01473 L
s
.97428 .01472 m
.97428 .01473 L
s
.97524 .01472 m
.97524 .01473 L
s
.97619 .01472 m
.97619 .01473 L
s
.015 w
.02381 .01473 Mdot
.02476 .01473 Mdot
.02572 .01473 Mdot
.02667 .01473 Mdot
.02762 .01473 Mdot
.02858 .01473 Mdot
.02953 .01473 Mdot
.03048 .01473 Mdot
.03144 .01473 Mdot
.03239 .01473 Mdot
.03334 .01473 Mdot
.0343 .01473 Mdot
.03525 .01473 Mdot
.0362 .01473 Mdot
.03716 .01473 Mdot
.03811 .01473 Mdot
.03906 .01473 Mdot
.04002 .01473 Mdot
.04097 .01473 Mdot
.04192 .01473 Mdot
.04288 .01473 Mdot
.04383 .01473 Mdot
.04478 .01473 Mdot
.04574 .01473 Mdot
.04669 .01473 Mdot
.04764 .01473 Mdot
.0486 .01473 Mdot
.04955 .01473 Mdot
.0505 .01473 Mdot
.05146 .01473 Mdot
.05241 .01473 Mdot
.05336 .01473 Mdot
.05432 .01473 Mdot
.05527 .01473 Mdot
.05622 .01473 Mdot
.05718 .01473 Mdot
.05813 .01473 Mdot
.05908 .01473 Mdot
.06004 .01473 Mdot
.06099 .01473 Mdot
.06194 .01473 Mdot
.0629 .01473 Mdot
.06385 .01473 Mdot
.0648 .01473 Mdot
.06576 .01473 Mdot
.06671 .01473 Mdot
.06766 .01473 Mdot
.06862 .01473 Mdot
.06957 .01473 Mdot
.07052 .01473 Mdot
.07148 .01473 Mdot
.07243 .01473 Mdot
.07338 .01473 Mdot
.07434 .01473 Mdot
.07529 .01473 Mdot
.07624 .01473 Mdot
.0772 .01473 Mdot
.07815 .01473 Mdot
.0791 .01473 Mdot
.08006 .01473 Mdot
.08101 .01473 Mdot
.08196 .01473 Mdot
.08292 .01473 Mdot
.08387 .01473 Mdot
.08482 .01473 Mdot
.08578 .01473 Mdot
.08673 .01473 Mdot
.08768 .01473 Mdot
.08864 .01473 Mdot
.08959 .01473 Mdot
.09054 .01473 Mdot
.0915 .01473 Mdot
.09245 .01473 Mdot
.0934 .01473 Mdot
.09436 .01473 Mdot
.09531 .01473 Mdot
.09626 .01473 Mdot
.09722 .01473 Mdot
.09817 .01473 Mdot
.09912 .01473 Mdot
.10008 .01473 Mdot
.10103 .01473 Mdot
.10198 .01473 Mdot
.10294 .01473 Mdot
.10389 .01473 Mdot
.10484 .01473 Mdot
.1058 .01473 Mdot
.10675 .01473 Mdot
.1077 .01473 Mdot
.10866 .01473 Mdot
.10961 .01473 Mdot
.11056 .01473 Mdot
.11152 .01473 Mdot
.11247 .01473 Mdot
.11342 .01473 Mdot
.11438 .01473 Mdot
.11533 .01473 Mdot
.11628 .01473 Mdot
.11724 .01473 Mdot
.11819 .01473 Mdot
.11914 .01473 Mdot
.1201 .01473 Mdot
.12105 .01473 Mdot
.122 .01473 Mdot
.12296 .01473 Mdot
.12391 .01473 Mdot
.12486 .01473 Mdot
.12582 .01473 Mdot
.12677 .01473 Mdot
.12772 .01473 Mdot
.12868 .01473 Mdot
.12963 .01473 Mdot
.13058 .01473 Mdot
.13154 .01473 Mdot
.13249 .01473 Mdot
.13344 .01473 Mdot
.1344 .01473 Mdot
.13535 .01473 Mdot
.1363 .01473 Mdot
.13726 .01474 Mdot
.13821 .01474 Mdot
.13916 .01474 Mdot
.14012 .01474 Mdot
.14107 .01474 Mdot
.14202 .01474 Mdot
.14298 .01474 Mdot
.14393 .01474 Mdot
.14488 .01474 Mdot
.14584 .01474 Mdot
.14679 .01474 Mdot
.14774 .01474 Mdot
.1487 .01474 Mdot
.14965 .01474 Mdot
.1506 .01474 Mdot
.15156 .01474 Mdot
.15251 .01474 Mdot
.15346 .01474 Mdot
.15442 .01474 Mdot
.15537 .01474 Mdot
.15632 .01474 Mdot
.15728 .01474 Mdot
.15823 .01474 Mdot
.15918 .01474 Mdot
.16014 .01474 Mdot
.16109 .01474 Mdot
.16204 .01474 Mdot
.163 .01474 Mdot
.16395 .01474 Mdot
.1649 .01474 Mdot
.16586 .01474 Mdot
.16681 .01474 Mdot
.16776 .01474 Mdot
.16872 .01474 Mdot
.16967 .01474 Mdot
.17062 .01474 Mdot
.17158 .01474 Mdot
.17253 .01474 Mdot
.17348 .01474 Mdot
.17444 .01474 Mdot
.17539 .01474 Mdot
.17634 .01474 Mdot
.1773 .01474 Mdot
.17825 .01474 Mdot
.1792 .01474 Mdot
.18016 .01474 Mdot
.18111 .01474 Mdot
.18206 .01474 Mdot
.18302 .01474 Mdot
.18397 .01474 Mdot
.18492 .01474 Mdot
.18588 .01474 Mdot
.18683 .01474 Mdot
.18778 .01474 Mdot
.18874 .01474 Mdot
.18969 .01474 Mdot
.19064 .01474 Mdot
.1916 .01474 Mdot
.19255 .01474 Mdot
.1935 .01474 Mdot
.19446 .01474 Mdot
.19541 .01474 Mdot
.19636 .01474 Mdot
.19732 .01474 Mdot
.19827 .01474 Mdot
.19922 .01474 Mdot
.20018 .01474 Mdot
.20113 .01474 Mdot
.20208 .01474 Mdot
.20304 .01474 Mdot
.20399 .01474 Mdot
.20494 .01474 Mdot
.2059 .01474 Mdot
.20685 .01474 Mdot
.2078 .01474 Mdot
.20876 .01474 Mdot
.20971 .01474 Mdot
.21066 .01474 Mdot
.21162 .01474 Mdot
.21257 .01474 Mdot
.21352 .01474 Mdot
.21448 .01474 Mdot
.21543 .01474 Mdot
.21638 .01474 Mdot
.21734 .01474 Mdot
.21829 .01474 Mdot
.21924 .01474 Mdot
.2202 .01474 Mdot
.22115 .01474 Mdot
.2221 .01474 Mdot
.22306 .01474 Mdot
.22401 .01474 Mdot
.22496 .01474 Mdot
.22592 .01474 Mdot
.22687 .01474 Mdot
.22782 .01474 Mdot
.22878 .01474 Mdot
.22973 .01474 Mdot
.23068 .01474 Mdot
.23164 .01474 Mdot
.23259 .01474 Mdot
.23354 .01474 Mdot
.2345 .01474 Mdot
.23545 .01474 Mdot
.2364 .01474 Mdot
.23736 .01474 Mdot
.23831 .01474 Mdot
.23926 .01474 Mdot
.24022 .01474 Mdot
.24117 .01474 Mdot
.24212 .01474 Mdot
.24308 .01474 Mdot
.24403 .01474 Mdot
.24498 .01474 Mdot
.24594 .01474 Mdot
.24689 .01474 Mdot
.24784 .01474 Mdot
.2488 .01474 Mdot
.24975 .01474 Mdot
.2507 .01474 Mdot
.25166 .01474 Mdot
.25261 .01474 Mdot
.25356 .01474 Mdot
.25452 .01474 Mdot
.25547 .01474 Mdot
.25642 .01474 Mdot
.25738 .01474 Mdot
.25833 .01474 Mdot
.25928 .01474 Mdot
.26024 .01474 Mdot
.26119 .01474 Mdot
.26214 .01474 Mdot
.2631 .01474 Mdot
.26405 .01474 Mdot
.265 .01474 Mdot
.26596 .01474 Mdot
.26691 .01474 Mdot
.26786 .01474 Mdot
.26882 .01474 Mdot
.26977 .01474 Mdot
.27072 .01474 Mdot
.27168 .01474 Mdot
.27263 .01474 Mdot
.27358 .01474 Mdot
.27454 .01474 Mdot
.27549 .01474 Mdot
.27644 .01474 Mdot
.2774 .01474 Mdot
.27835 .01474 Mdot
.2793 .01474 Mdot
.28026 .01474 Mdot
.28121 .01474 Mdot
.28216 .01474 Mdot
.28312 .01474 Mdot
.28407 .01474 Mdot
.28502 .01474 Mdot
.28598 .01474 Mdot
.28693 .01474 Mdot
.28788 .01474 Mdot
.28884 .01474 Mdot
.28979 .01474 Mdot
.29074 .01474 Mdot
.2917 .01474 Mdot
.29265 .01474 Mdot
.2936 .01474 Mdot
.29456 .01474 Mdot
.29551 .01474 Mdot
.29646 .01474 Mdot
.29742 .01475 Mdot
.29837 .01475 Mdot
.29932 .01475 Mdot
.30028 .01475 Mdot
.30123 .01475 Mdot
.30218 .01475 Mdot
.30314 .01475 Mdot
.30409 .01475 Mdot
.30504 .01475 Mdot
.306 .01475 Mdot
.30695 .01475 Mdot
.3079 .01475 Mdot
.30886 .01475 Mdot
.30981 .01475 Mdot
.31076 .01475 Mdot
.31172 .01475 Mdot
.31267 .01475 Mdot
.31362 .01475 Mdot
.31458 .01475 Mdot
.31553 .01475 Mdot
.31648 .01475 Mdot
.31744 .01475 Mdot
.31839 .01475 Mdot
.31934 .01475 Mdot
.3203 .01475 Mdot
.32125 .01475 Mdot
.3222 .01475 Mdot
.32316 .01475 Mdot
.32411 .01475 Mdot
.32506 .01475 Mdot
.32602 .01475 Mdot
.32697 .01475 Mdot
.32792 .01475 Mdot
.32888 .01475 Mdot
.32983 .01475 Mdot
.33078 .01475 Mdot
.33174 .01475 Mdot
.33269 .01475 Mdot
.33364 .01475 Mdot
.3346 .01475 Mdot
.33555 .01475 Mdot
.3365 .01475 Mdot
.33746 .01475 Mdot
.33841 .01475 Mdot
.33936 .01475 Mdot
.34032 .01475 Mdot
.34127 .01475 Mdot
.34222 .01475 Mdot
.34318 .01475 Mdot
.34413 .01475 Mdot
.34508 .01475 Mdot
.34604 .01475 Mdot
.34699 .01475 Mdot
.34794 .01475 Mdot
.3489 .01475 Mdot
.34985 .01475 Mdot
.3508 .01475 Mdot
.35176 .01475 Mdot
.35271 .01476 Mdot
.35366 .01476 Mdot
.35462 .01476 Mdot
.35557 .01476 Mdot
.35652 .01476 Mdot
.35748 .01476 Mdot
.35843 .01476 Mdot
.35938 .01476 Mdot
.36034 .01476 Mdot
.36129 .01476 Mdot
.36224 .01476 Mdot
.3632 .01476 Mdot
.36415 .01476 Mdot
.3651 .01476 Mdot
.36606 .01476 Mdot
.36701 .01476 Mdot
.36796 .01476 Mdot
.36892 .01476 Mdot
.36987 .01476 Mdot
.37082 .01476 Mdot
.37178 .01476 Mdot
.37273 .01476 Mdot
.37368 .01476 Mdot
.37464 .01476 Mdot
.37559 .01476 Mdot
.37654 .01476 Mdot
.3775 .01476 Mdot
.37845 .01476 Mdot
.3794 .01476 Mdot
.38036 .01476 Mdot
.38131 .01476 Mdot
.38226 .01476 Mdot
.38322 .01476 Mdot
.38417 .01477 Mdot
.38512 .01477 Mdot
.38608 .01477 Mdot
.38703 .01477 Mdot
.38798 .01477 Mdot
.38894 .01477 Mdot
.38989 .01477 Mdot
.39084 .01477 Mdot
.3918 .01477 Mdot
.39275 .01477 Mdot
.3937 .01477 Mdot
.39466 .01477 Mdot
.39561 .01477 Mdot
.39656 .01477 Mdot
.39752 .01477 Mdot
.39847 .01477 Mdot
.39942 .01477 Mdot
.40038 .01477 Mdot
.40133 .01477 Mdot
.40228 .01477 Mdot
.40324 .01477 Mdot
.40419 .01478 Mdot
.40514 .01478 Mdot
.4061 .01478 Mdot
.40705 .01478 Mdot
.408 .01478 Mdot
.40896 .01478 Mdot
.40991 .01478 Mdot
.41086 .01478 Mdot
.41182 .01478 Mdot
.41277 .01478 Mdot
.41372 .01478 Mdot
.41468 .01478 Mdot
.41563 .01478 Mdot
.41658 .01478 Mdot
.41754 .01479 Mdot
.41849 .01479 Mdot
.41944 .01479 Mdot
.4204 .01479 Mdot
.42135 .01479 Mdot
.4223 .01479 Mdot
.42326 .01479 Mdot
.42421 .01479 Mdot
.42516 .01479 Mdot
.42612 .01479 Mdot
.42707 .01479 Mdot
.42802 .0148 Mdot
.42898 .0148 Mdot
.42993 .0148 Mdot
.43088 .0148 Mdot
.43184 .0148 Mdot
.43279 .0148 Mdot
.43374 .0148 Mdot
.4347 .0148 Mdot
.43565 .01481 Mdot
.4366 .01481 Mdot
.43756 .01481 Mdot
.43851 .01481 Mdot
.43946 .01481 Mdot
.44042 .01481 Mdot
.44137 .01481 Mdot
.44232 .01482 Mdot
.44328 .01482 Mdot
.44423 .01482 Mdot
.44518 .01482 Mdot
.44614 .01482 Mdot
.44709 .01483 Mdot
.44804 .01483 Mdot
.449 .01483 Mdot
.44995 .01483 Mdot
.4509 .01484 Mdot
.45186 .01484 Mdot
.45281 .01484 Mdot
.45376 .01484 Mdot
.45472 .01485 Mdot
.45567 .01485 Mdot
.45662 .01485 Mdot
.45758 .01486 Mdot
.45853 .01486 Mdot
.45948 .01486 Mdot
.46044 .01487 Mdot
.46139 .01487 Mdot
.46234 .01488 Mdot
.4633 .01488 Mdot
.46425 .01489 Mdot
.4652 .01489 Mdot
.46616 .0149 Mdot
.46711 .01491 Mdot
.46806 .01491 Mdot
.46902 .01492 Mdot
.46997 .01493 Mdot
.47092 .01494 Mdot
.47188 .01495 Mdot
.47283 .01496 Mdot
.47378 .01497 Mdot
.47474 .01498 Mdot
.47569 .015 Mdot
.47664 .01501 Mdot
.4776 .01503 Mdot
.47855 .01505 Mdot
.4795 .01508 Mdot
.48046 .01511 Mdot
.48141 .01514 Mdot
.48236 .01519 Mdot
.48332 .01525 Mdot
.48427 .01532 Mdot
.48522 .01542 Mdot
.48618 .01558 Mdot
.48713 .01583 Mdot
.48808 .01633 Mdot
.48904 .01783 Mdot
.48999 .30882 Mdot
.49094 .01748 Mdot
.4919 .01602 Mdot
.49285 .01552 Mdot
.4938 .01527 Mdot
.49476 .01511 Mdot
.49571 .01499 Mdot
.49666 .01491 Mdot
.49762 .01484 Mdot
.49857 .01477 Mdot
.49952 .60332 Mdot
.50048 .01477 Mdot
.50143 .01484 Mdot
.50238 .01491 Mdot
.50334 .01499 Mdot
.50429 .01511 Mdot
.50524 .01527 Mdot
.5062 .01552 Mdot
.50715 .01602 Mdot
.5081 .01748 Mdot
.50906 .30882 Mdot
.51001 .01783 Mdot
.51096 .01633 Mdot
.51192 .01583 Mdot
.51287 .01558 Mdot
.51382 .01542 Mdot
.51478 .01532 Mdot
.51573 .01525 Mdot
.51668 .01519 Mdot
.51764 .01514 Mdot
.51859 .01511 Mdot
.51954 .01508 Mdot
.5205 .01505 Mdot
.52145 .01503 Mdot
.5224 .01501 Mdot
.52336 .015 Mdot
.52431 .01498 Mdot
.52526 .01497 Mdot
.52622 .01496 Mdot
.52717 .01495 Mdot
.52812 .01494 Mdot
.52908 .01493 Mdot
.53003 .01492 Mdot
.53098 .01491 Mdot
.53194 .01491 Mdot
.53289 .0149 Mdot
.53384 .01489 Mdot
.5348 .01489 Mdot
.53575 .01488 Mdot
.5367 .01488 Mdot
.53766 .01487 Mdot
.53861 .01487 Mdot
.53956 .01486 Mdot
.54052 .01486 Mdot
.54147 .01486 Mdot
.54242 .01485 Mdot
.54338 .01485 Mdot
.54433 .01485 Mdot
.54528 .01484 Mdot
.54624 .01484 Mdot
.54719 .01484 Mdot
.54814 .01484 Mdot
.5491 .01483 Mdot
.55005 .01483 Mdot
.551 .01483 Mdot
.55196 .01483 Mdot
.55291 .01482 Mdot
.55386 .01482 Mdot
.55482 .01482 Mdot
.55577 .01482 Mdot
.55672 .01482 Mdot
.55768 .01481 Mdot
.55863 .01481 Mdot
.55958 .01481 Mdot
.56054 .01481 Mdot
.56149 .01481 Mdot
.56244 .01481 Mdot
.5634 .01481 Mdot
.56435 .0148 Mdot
.5653 .0148 Mdot
.56626 .0148 Mdot
.56721 .0148 Mdot
.56816 .0148 Mdot
.56912 .0148 Mdot
.57007 .0148 Mdot
.57102 .0148 Mdot
.57198 .01479 Mdot
.57293 .01479 Mdot
.57388 .01479 Mdot
.57484 .01479 Mdot
.57579 .01479 Mdot
.57674 .01479 Mdot
.5777 .01479 Mdot
.57865 .01479 Mdot
.5796 .01479 Mdot
.58056 .01479 Mdot
.58151 .01479 Mdot
.58246 .01478 Mdot
.58342 .01478 Mdot
.58437 .01478 Mdot
.58532 .01478 Mdot
.58628 .01478 Mdot
.58723 .01478 Mdot
.58818 .01478 Mdot
.58914 .01478 Mdot
.59009 .01478 Mdot
.59104 .01478 Mdot
.592 .01478 Mdot
.59295 .01478 Mdot
.5939 .01478 Mdot
.59486 .01478 Mdot
.59581 .01477 Mdot
.59676 .01477 Mdot
.59772 .01477 Mdot
.59867 .01477 Mdot
.59962 .01477 Mdot
.60058 .01477 Mdot
.60153 .01477 Mdot
.60248 .01477 Mdot
.60344 .01477 Mdot
.60439 .01477 Mdot
.60534 .01477 Mdot
.6063 .01477 Mdot
.60725 .01477 Mdot
.6082 .01477 Mdot
.60916 .01477 Mdot
.61011 .01477 Mdot
.61106 .01477 Mdot
.61202 .01477 Mdot
.61297 .01477 Mdot
.61392 .01477 Mdot
.61488 .01477 Mdot
.61583 .01476 Mdot
.61678 .01476 Mdot
.61774 .01476 Mdot
.61869 .01476 Mdot
.61964 .01476 Mdot
.6206 .01476 Mdot
.62155 .01476 Mdot
.6225 .01476 Mdot
.62346 .01476 Mdot
.62441 .01476 Mdot
.62536 .01476 Mdot
.62632 .01476 Mdot
.62727 .01476 Mdot
.62822 .01476 Mdot
.62918 .01476 Mdot
.63013 .01476 Mdot
.63108 .01476 Mdot
.63204 .01476 Mdot
.63299 .01476 Mdot
.63394 .01476 Mdot
.6349 .01476 Mdot
.63585 .01476 Mdot
.6368 .01476 Mdot
.63776 .01476 Mdot
.63871 .01476 Mdot
.63966 .01476 Mdot
.64062 .01476 Mdot
.64157 .01476 Mdot
.64252 .01476 Mdot
.64348 .01476 Mdot
.64443 .01476 Mdot
.64538 .01476 Mdot
.64634 .01476 Mdot
.64729 .01475 Mdot
.64824 .01475 Mdot
.6492 .01475 Mdot
.65015 .01475 Mdot
.6511 .01475 Mdot
.65206 .01475 Mdot
.65301 .01475 Mdot
.65396 .01475 Mdot
.65492 .01475 Mdot
.65587 .01475 Mdot
.65682 .01475 Mdot
.65778 .01475 Mdot
.65873 .01475 Mdot
.65968 .01475 Mdot
.66064 .01475 Mdot
.66159 .01475 Mdot
.66254 .01475 Mdot
.6635 .01475 Mdot
.66445 .01475 Mdot
.6654 .01475 Mdot
.66636 .01475 Mdot
.66731 .01475 Mdot
.66826 .01475 Mdot
.66922 .01475 Mdot
.67017 .01475 Mdot
.67112 .01475 Mdot
.67208 .01475 Mdot
.67303 .01475 Mdot
.67398 .01475 Mdot
.67494 .01475 Mdot
.67589 .01475 Mdot
.67684 .01475 Mdot
.6778 .01475 Mdot
.67875 .01475 Mdot
.6797 .01475 Mdot
.68066 .01475 Mdot
.68161 .01475 Mdot
.68256 .01475 Mdot
.68352 .01475 Mdot
.68447 .01475 Mdot
.68542 .01475 Mdot
.68638 .01475 Mdot
.68733 .01475 Mdot
.68828 .01475 Mdot
.68924 .01475 Mdot
.69019 .01475 Mdot
.69114 .01475 Mdot
.6921 .01475 Mdot
.69305 .01475 Mdot
.694 .01475 Mdot
.69496 .01475 Mdot
.69591 .01475 Mdot
.69686 .01475 Mdot
.69782 .01475 Mdot
.69877 .01475 Mdot
.69972 .01475 Mdot
.70068 .01475 Mdot
.70163 .01475 Mdot
.70258 .01474 Mdot
.70354 .01474 Mdot
.70449 .01474 Mdot
.70544 .01474 Mdot
.7064 .01474 Mdot
.70735 .01474 Mdot
.7083 .01474 Mdot
.70926 .01474 Mdot
.71021 .01474 Mdot
.71116 .01474 Mdot
.71212 .01474 Mdot
.71307 .01474 Mdot
.71402 .01474 Mdot
.71498 .01474 Mdot
.71593 .01474 Mdot
.71688 .01474 Mdot
.71784 .01474 Mdot
.71879 .01474 Mdot
.71974 .01474 Mdot
.7207 .01474 Mdot
.72165 .01474 Mdot
.7226 .01474 Mdot
.72356 .01474 Mdot
.72451 .01474 Mdot
.72546 .01474 Mdot
.72642 .01474 Mdot
.72737 .01474 Mdot
.72832 .01474 Mdot
.72928 .01474 Mdot
.73023 .01474 Mdot
.73118 .01474 Mdot
.73214 .01474 Mdot
.73309 .01474 Mdot
.73404 .01474 Mdot
.735 .01474 Mdot
.73595 .01474 Mdot
.7369 .01474 Mdot
.73786 .01474 Mdot
.73881 .01474 Mdot
.73976 .01474 Mdot
.74072 .01474 Mdot
.74167 .01474 Mdot
.74262 .01474 Mdot
.74358 .01474 Mdot
.74453 .01474 Mdot
.74548 .01474 Mdot
.74644 .01474 Mdot
.74739 .01474 Mdot
.74834 .01474 Mdot
.7493 .01474 Mdot
.75025 .01474 Mdot
.7512 .01474 Mdot
.75216 .01474 Mdot
.75311 .01474 Mdot
.75406 .01474 Mdot
.75502 .01474 Mdot
.75597 .01474 Mdot
.75692 .01474 Mdot
.75788 .01474 Mdot
.75883 .01474 Mdot
.75978 .01474 Mdot
.76074 .01474 Mdot
.76169 .01474 Mdot
.76264 .01474 Mdot
.7636 .01474 Mdot
.76455 .01474 Mdot
.7655 .01474 Mdot
.76646 .01474 Mdot
.76741 .01474 Mdot
.76836 .01474 Mdot
.76932 .01474 Mdot
.77027 .01474 Mdot
.77122 .01474 Mdot
.77218 .01474 Mdot
.77313 .01474 Mdot
.77408 .01474 Mdot
.77504 .01474 Mdot
.77599 .01474 Mdot
.77694 .01474 Mdot
.7779 .01474 Mdot
.77885 .01474 Mdot
.7798 .01474 Mdot
.78076 .01474 Mdot
.78171 .01474 Mdot
.78266 .01474 Mdot
.78362 .01474 Mdot
.78457 .01474 Mdot
.78552 .01474 Mdot
.78648 .01474 Mdot
.78743 .01474 Mdot
.78838 .01474 Mdot
.78934 .01474 Mdot
.79029 .01474 Mdot
.79124 .01474 Mdot
.7922 .01474 Mdot
.79315 .01474 Mdot
.7941 .01474 Mdot
.79506 .01474 Mdot
.79601 .01474 Mdot
.79696 .01474 Mdot
.79792 .01474 Mdot
.79887 .01474 Mdot
.79982 .01474 Mdot
.80078 .01474 Mdot
.80173 .01474 Mdot
.80268 .01474 Mdot
.80364 .01474 Mdot
.80459 .01474 Mdot
.80554 .01474 Mdot
.8065 .01474 Mdot
.80745 .01474 Mdot
.8084 .01474 Mdot
.80936 .01474 Mdot
.81031 .01474 Mdot
.81126 .01474 Mdot
.81222 .01474 Mdot
.81317 .01474 Mdot
.81412 .01474 Mdot
.81508 .01474 Mdot
.81603 .01474 Mdot
.81698 .01474 Mdot
.81794 .01474 Mdot
.81889 .01474 Mdot
.81984 .01474 Mdot
.8208 .01474 Mdot
.82175 .01474 Mdot
.8227 .01474 Mdot
.82366 .01474 Mdot
.82461 .01474 Mdot
.82556 .01474 Mdot
.82652 .01474 Mdot
.82747 .01474 Mdot
.82842 .01474 Mdot
.82938 .01474 Mdot
.83033 .01474 Mdot
.83128 .01474 Mdot
.83224 .01474 Mdot
.83319 .01474 Mdot
.83414 .01474 Mdot
.8351 .01474 Mdot
.83605 .01474 Mdot
.837 .01474 Mdot
.83796 .01474 Mdot
.83891 .01474 Mdot
.83986 .01474 Mdot
.84082 .01474 Mdot
.84177 .01474 Mdot
.84272 .01474 Mdot
.84368 .01474 Mdot
.84463 .01474 Mdot
.84558 .01474 Mdot
.84654 .01474 Mdot
.84749 .01474 Mdot
.84844 .01474 Mdot
.8494 .01474 Mdot
.85035 .01474 Mdot
.8513 .01474 Mdot
.85226 .01474 Mdot
.85321 .01474 Mdot
.85416 .01474 Mdot
.85512 .01474 Mdot
.85607 .01474 Mdot
.85702 .01474 Mdot
.85798 .01474 Mdot
.85893 .01474 Mdot
.85988 .01474 Mdot
.86084 .01474 Mdot
.86179 .01474 Mdot
.86274 .01473 Mdot
.8637 .01473 Mdot
.86465 .01473 Mdot
.8656 .01473 Mdot
.86656 .01473 Mdot
.86751 .01473 Mdot
.86846 .01473 Mdot
.86942 .01473 Mdot
.87037 .01473 Mdot
.87132 .01473 Mdot
.87228 .01473 Mdot
.87323 .01473 Mdot
.87418 .01473 Mdot
.87514 .01473 Mdot
.87609 .01473 Mdot
.87704 .01473 Mdot
.878 .01473 Mdot
.87895 .01473 Mdot
.8799 .01473 Mdot
.88086 .01473 Mdot
.88181 .01473 Mdot
.88276 .01473 Mdot
.88372 .01473 Mdot
.88467 .01473 Mdot
.88562 .01473 Mdot
.88658 .01473 Mdot
.88753 .01473 Mdot
.88848 .01473 Mdot
.88944 .01473 Mdot
.89039 .01473 Mdot
.89134 .01473 Mdot
.8923 .01473 Mdot
.89325 .01473 Mdot
.8942 .01473 Mdot
.89516 .01473 Mdot
.89611 .01473 Mdot
.89706 .01473 Mdot
.89802 .01473 Mdot
.89897 .01473 Mdot
.89992 .01473 Mdot
.90088 .01473 Mdot
.90183 .01473 Mdot
.90278 .01473 Mdot
.90374 .01473 Mdot
.90469 .01473 Mdot
.90564 .01473 Mdot
.9066 .01473 Mdot
.90755 .01473 Mdot
.9085 .01473 Mdot
.90946 .01473 Mdot
.91041 .01473 Mdot
.91136 .01473 Mdot
.91232 .01473 Mdot
.91327 .01473 Mdot
.91422 .01473 Mdot
.91518 .01473 Mdot
.91613 .01473 Mdot
.91708 .01473 Mdot
.91804 .01473 Mdot
.91899 .01473 Mdot
.91994 .01473 Mdot
.9209 .01473 Mdot
.92185 .01473 Mdot
.9228 .01473 Mdot
.92376 .01473 Mdot
.92471 .01473 Mdot
.92566 .01473 Mdot
.92662 .01473 Mdot
.92757 .01473 Mdot
.92852 .01473 Mdot
.92948 .01473 Mdot
.93043 .01473 Mdot
.93138 .01473 Mdot
.93234 .01473 Mdot
.93329 .01473 Mdot
.93424 .01473 Mdot
.9352 .01473 Mdot
.93615 .01473 Mdot
.9371 .01473 Mdot
.93806 .01473 Mdot
.93901 .01473 Mdot
.93996 .01473 Mdot
.94092 .01473 Mdot
.94187 .01473 Mdot
.94282 .01473 Mdot
.94378 .01473 Mdot
.94473 .01473 Mdot
.94568 .01473 Mdot
.94664 .01473 Mdot
.94759 .01473 Mdot
.94854 .01473 Mdot
.9495 .01473 Mdot
.95045 .01473 Mdot
.9514 .01473 Mdot
.95236 .01473 Mdot
.95331 .01473 Mdot
.95426 .01473 Mdot
.95522 .01473 Mdot
.95617 .01473 Mdot
.95712 .01473 Mdot
.95808 .01473 Mdot
.95903 .01473 Mdot
.95998 .01473 Mdot
.96094 .01473 Mdot
.96189 .01473 Mdot
.96284 .01473 Mdot
.9638 .01473 Mdot
.96475 .01473 Mdot
.9657 .01473 Mdot
.96666 .01473 Mdot
.96761 .01473 Mdot
.96856 .01473 Mdot
.96952 .01473 Mdot
.97047 .01473 Mdot
.97142 .01473 Mdot
.97238 .01473 Mdot
.97333 .01473 Mdot
.97428 .01473 Mdot
.97524 .01473 Mdot
.97619 .01473 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00=Oooool3o`0000?ooooo0_l00004ooooo`;o00008_ooool5o`0000?o
oooo0_l00004ooooo`;o00009_ooool2o`0002Sooooo1Ol00003ooooo`;o00001?ooool2o`0002?o
oooo0ol00003ooooo`;o00001?ooool2o`0001[ooooo000fooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo023ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Cooooo
00Co0000oooooooooooo0000:?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Gooooo`00;Oooool5o`000003oooo
ool0003o000000?o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
01_ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo1Ol00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006Oooool003?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool08_ooool01?l0003oooooooooool0000Zooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000d
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Qooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002Cooooo00Co0000oooooooooooo00009oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Qoooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Iooooo`00=Oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Qooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002Cooooo00Co0000oooooooooooo00009oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Roooo
o`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000f
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00008oooool3o`0000Cooooo0_l00004
ooooo`;o00009_ooool2o`0002Wooooo0ol00004ooooo`;o00001?ooool2o`0002Cooooo00?o0000
ooooooooool00_ooool2o`0000Cooooo0_l0000Jooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006ooooooo000000D000000Oooool001Co
oooo0_l00005ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0@000001ooooo`004oooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo0?oooooo0Oooool10000007ooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00@00000o`000?oooooooooonooo0003ooooo`7o00000@000001oooo
o`004oooool01?l0003oooooooooool00004ooooo`0400000?oooooooooooooooo_oo`001?ooool1
0000007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00@00000oooooooooooooooonooo
0004ooooo`4000000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`1jooooo`Coo`0000<0o`00ool00?oo00000_oo001mooooo`4000000Oooool001Cooooo0_l00005
ooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1l
ooooo`4000000Oooool001_ooooo00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002oooo
o`030?l00?oooooooooo07cooooo0@000001ooooo`006oooool00`00003oooooooooo`1looooo`03
0?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo000Kooooo`030000
0?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`400000
0Oooool001_ooooo00<00000o`000?ooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oo
oooooooo07_ooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00
ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`4000000Oooool001_ooooo00<00000oooo
ooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001oooo
o`006oooool00`00003oooooooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00oooooooo
ool0O?ooool10000007ooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o0000
0_ooool00`3o003oooooooooo`1looooo`4000000Oooool001_ooooo00<00000ooooooooool0O?oo
ool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001ooooo`006oooool0
0`00003oooooooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool1
0000007ooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o
003oooooooooo`1looooo`4000000Oooool001_ooooo00<00000o`000?ooool0O?ooool00`3o003o
oooo0?l00002ooooo`030?l00?oooooooooo07_ooooo0Ol000010000007ooooo000Kooooo`030000
0?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`400000
0Oooool001_ooooo00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oo
oooooooo07cooooo0@000001ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?ooool0
o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo000Kooooo`0300000?oooooooooo
07cooooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`4000000Oooool001_o
oooo00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07co
oooo0@000001ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?ooool0o`0000;ooooo
00<0o`00ooooooooool0O?ooool10000007ooooo000Kooooo`0300000?l0003ooooo07cooooo00<0
o`00ooooo`3o00000_ooool00`3o003oooooooooo`1kooooo`7o00000@000001ooooo`006oooool0
0`00003oooooooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool1
0000007ooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o
003oooooooooo`1looooo`4000000Oooool001_ooooo00<00000ooooooooool0O?ooool00`3o003o
oooo0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo
0006ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo07cooooo00<0
o`00ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`4000000Oooool000Oooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07co
oooo0@000001ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1looooo`030?l00?ooool0o`00
00;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo0009ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000
o`000?ooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07_ooooo0Ol00001
0000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0O?ooool00`3o003ooooo
0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001ooooo`001_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1loooo
o`4000000Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<00000oooooooo
ool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001ooooo`00
6oooool00`00003oooooooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0
O?ooool10000007ooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_oo
ool00`3o003oooooooooo`1looooo`4000000Oooool001_ooooo00<00000ooooooooool0O?ooool0
0`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001ooooo`006oooool00`00
003oooooooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000
007ooooo000Kooooo`0300000?l0003ooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003o
ooooooooo`1kooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`1looooo`030?l0
0?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo000Kooooo`0300000?oo
oooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`4000000Ooo
ool001_ooooo00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooo
oooo07cooooo0@000001ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?ooool0o`00
00;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo000Kooooo`0300000?oooooooooo07co
oooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`4000000Oooool001_ooooo
00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07cooooo
0@000001ooooo`006oooool00`00003o0000ooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0
o`00ooooooooool0Noooool1o`00004000000Oooool001_ooooo00<00000ooooooooool0O?ooool0
0`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001ooooo`006oooool00`00
003oooooooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000
007ooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003o
ooooooooo`1looooo`4000000Oooool001_ooooo00<00000ooooooooool0O?ooool00`3o003ooooo
0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001ooooo`006oooool00`00003ooooooooo
o`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo000K
ooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1l
ooooo`4000000Oooool001_ooooo00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002oooo
o`030?l00?oooooooooo07cooooo0@000001ooooo`006oooool00`00003o0000ooooo`1looooo`03
0?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0Noooool1o`00004000000Oooool001_ooooo
00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07cooooo
0@000001ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0
o`00ooooooooool0O?ooool10000007ooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00
ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`4000000Oooool001_ooooo00<00000oooo
ooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001oooo
o`002?ooool3o`0000?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1looooo`03
0?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo0009ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo
07cooooo0@000001ooooo`001_ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool0
0`3o003oooooooooo`1looooo`4000000Oooool000Kooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000?ooool0
O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07_ooooo0Ol000010000007ooooo
0007ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003o
ooooooooo`1looooo`4000000Oooool000Sooooo0_l00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1looooo`030?l00?ooool0o`00
00;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo0009ooooo`03o`000?oooooooooo00;o
oooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1looooo`030?l00?ooool0o`0000;o
oooo00<0o`00ooooooooool0O?ooool10000007ooooo000Kooooo`0300000?oooooooooo07cooooo
00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`4000000Oooool001_ooooo00<0
0000ooooooooool0O?ooool00`3o003ooooo0?l00002ooooo`030?l00?oooooooooo07cooooo0@00
0001ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00
ooooooooool0O?ooool10000007ooooo000Kooooo`0300000?l0003ooooo07cooooo00<0o`00oooo
o`3o00000_ooool00`3o003oooooooooo`1kooooo`7o00000@000001ooooo`006oooool00`00003o
ooooooooo`1looooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007o
oooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003ooooo
ooooo`1looooo`4000000Oooool001_ooooo00<00000ooooooooool0O?ooool00`3o003ooooo0?l0
0002ooooo`030?l00?oooooooooo07cooooo0@000001ooooo`006oooool00`00003oooooooooo`1l
ooooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo000Koooo
o`0300000?oooooooooo07cooooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1loooo
o`4000000Oooool001_ooooo00<00000ooooooooool0O?ooool00`3o003ooooo0?l00002ooooo`03
0?l00?oooooooooo07cooooo0@000001ooooo`006oooool00`00003oooooooooo`1kooooo`?oo`00
00@0o`00ool00?oo003oo`00O_ooool10000007ooooo000Kooooo`0300000?l0003ooooo07_ooooo
0ooo0000103o003oo`00ool00?oo001mooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`1kooooo`?oo`0000@0o`00ool00?oo003oo`00O_ooool10000007ooooo000Kooooo`030000
0?oooooooooo07kooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Kooooo`0300000?oo
oooooooo07kooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Kooooo`0300000?oooooo
oooo07kooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Kooooo`0300000?oooooooooo
07kooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Kooooo`0300000?oooooooooo07ko
oooo00<0o`00ooooooooool0Ooooool10000007ooooo000Kooooo`0300000?l0003ooooo07kooooo
00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool0O_oo
ool00`3o003oooooooooo`1oooooo`4000000Oooool001_ooooo00<00000ooooooooool0O_ooool0
0`3o003oooooooooo`1oooooo`4000000Oooool001_ooooo00<00000ooooooooool0O_ooool00`3o
003oooooooooo`1oooooo`4000000Oooool001_ooooo00<00000ooooooooool0O_ooool00`3o003o
ooooooooo`1oooooo`4000000Oooool001_ooooo00<00000ooooooooool0O_ooool00`3o003ooooo
ooooo`1oooooo`4000000Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<0
0000ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000Kooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oooooo0@000001ooooo`00
1_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`0300000?l0003ooooo07kooooo00<0o`00ooooooooool0O_ooool1
o`00004000000Oooool000Kooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oooooo0@00
0001ooooo`001_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oooooo
0@000001ooooo`001oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oo
oooo0@000001ooooo`002?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003ooooo
ooooo`1nooooo`030?l00?oooooooooo07oooooo0@000001ooooo`006oooool00`00003ooooooooo
o`1nooooo`030?l00?oooooooooo07oooooo0@000001ooooo`006oooool00`00003oooooooooo`1n
ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`006oooool00`00003oooooooooo`1noooo
o`030?l00?oooooooooo07oooooo0@000001ooooo`006oooool00`00003o0000ooooo`1nooooo`03
0?l00?oooooooooo07kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo07kooooo
00<0o`00ooooooooool0Ooooool10000007ooooo000Kooooo`0300000?oooooooooo07kooooo00<0
o`00ooooooooool0Ooooool10000007ooooo000Kooooo`0300000?oooooooooo07kooooo00<0o`00
ooooooooool0Ooooool10000007ooooo000Kooooo`0300000?oooooooooo07kooooo00<0o`00oooo
ooooool0Ooooool10000007ooooo000Kooooo`0300000?oooooooooo07kooooo00<0o`00oooooooo
ool0Ooooool10000007ooooo000Kooooo`0300000?oooooooooo07kooooo00<0o`00ooooooooool0
Ooooool10000007ooooo000Kooooo`0300000?l0003ooooo07kooooo00<0o`00ooooooooool0O_oo
ool1o`00004000000Oooool001_ooooo00<00000ooooooooool0O_ooool00`3o003oooooooooo`1o
ooooo`4000000Oooool001_ooooo00<00000ooooooooool0O_ooool00`3o003oooooooooo`1ooooo
o`4000000Oooool001_ooooo00<00000ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`40
00000Oooool001_ooooo00<00000ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`400000
0Oooool001_ooooo00<00000ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001_o
oooo00<00000o`000?ooool0O_ooool00`3o003oooooooooo`1nooooo`7o00000@000001ooooo`00
6oooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oooooo0@000001ooooo`006oooool0
0`00003oooooooooo`1nooooo`030?l00?oooooooooo07oooooo0@000001ooooo`006oooool00`00
003oooooooooo`1nooooo`030?l00?oooooooooo07oooooo0@000001ooooo`001oooool3o`0000Co
oooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oo
oooo0@000001ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07kooooo00<0o`00
ooooooooool0Ooooool10000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000Oooooo0ol00003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o0000ooooo`1nooooo`03
0?l00?oooooooooo07kooooo0Ol000010000007ooooo0006ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000Kooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oooooo0@000001ooooo`001ooo
ool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1nooooo`030?l00?oo
oooooooo07oooooo0@000001ooooo`006oooool00`00003oooooooooo`1nooooo`030?l00?oooooo
oooo07oooooo0@000001ooooo`006oooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo
07oooooo0@000001ooooo`006oooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oo
oooo0@000001ooooo`006oooool00`00003o0000ooooo`1nooooo`030?l00?oooooooooo07kooooo
0Ol000010000007ooooo000Kooooo`0300000?oooooooooo07kooooo00<0o`00ooooooooool0Oooo
ool10000007ooooo000Kooooo`0300000?oooooooooo07kooooo00<0o`00ooooooooool0Ooooool1
0000007ooooo000Kooooo`0300000?oooooooooo07kooooo00<0o`00ooooooooool0Ooooool10000
007ooooo000Kooooo`0300000?oooooooooo07kooooo00<0o`00ooooooooool0Ooooool10000007o
oooo000Kooooo`0300000?oooooooooo07kooooo00<0o`00ooooooooool0Ooooool10000007ooooo
000Kooooo`0300000?oooooooooo07kooooo00<0o`00ooooooooool0Ooooool10000007ooooo000K
ooooo`0300000?oooooooooo07kooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Koooo
o`0300000?l0003ooooo07kooooo00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001_o
oooo00<00000ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001_ooooo
00<00000ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001_ooooo00<0
0000ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001_ooooo00<00000
ooooooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001_ooooo00<00000oooo
ooooool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001_ooooo00<00000oooooooo
ool0O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001_ooooo00<00000ooooooooool0
O_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001_ooooo00<00000o`000?ooool0O_oo
ool00`3o003oooooooooo`1nooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`1n
ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`006oooool00`00003oooooooooo`1noooo
o`030?l00?oooooooooo07oooooo0@000001ooooo`006oooool00`00003oooooooooo`1nooooo`03
0?l00?oooooooooo07oooooo0@000001ooooo`006oooool00`00003oooooooooo`1nooooo`030?l0
0?oooooooooo07oooooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo
0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1nooooo`030?l00?oooooooooo07oooooo
0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
07kooooo00<0o`00ooooooooool0Ooooool10000007ooooo0002ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000o`000?ooool0OOooool3ool007oooooo0Ol000010000007ooooo0002
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0OOooool3ool0083o
oooo0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo01_ooooo00<00000ooooooooool0;oooool00`00003oooooooooo`0]ooooo`?oo`00<?ooool0
0`00003oooooooooo`0^ooooo`0300000?oooooooooo01cooooo0@000001ooooo`0000?oooooo`00
0?l000001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00<00000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`4000000Oooool000;ooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00001Ooooooo000000D000000Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-634.057, -116.759, 4.04022, \
6.54375}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[g1, \ PlotRange \[Rule] {{\(-20\), 20}, All}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.0147151 0.000588604 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -6 -9 ]
[.875 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -24 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-15)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-10)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(10)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(15)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(20)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(200)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(400)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(600)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(800)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1000)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .01472 m
0 .01511 L
s
.025 .01472 m
.025 .01514 L
s
.05 .01472 m
.05 .01519 L
s
.075 .01472 m
.075 .01525 L
s
.1 .01472 m
.1 .01532 L
s
.125 .01472 m
.125 .01542 L
s
.15 .01472 m
.15 .01558 L
s
.175 .01472 m
.175 .01583 L
s
.2 .01472 m
.2 .01633 L
s
.225 .01472 m
.225 .01783 L
s
.25 .01472 m
.25 .30882 L
s
.275 .01472 m
.275 .01748 L
s
.3 .01472 m
.3 .01602 L
s
.325 .01472 m
.325 .01552 L
s
.35 .01472 m
.35 .01527 L
s
.375 .01472 m
.375 .01511 L
s
.4 .01472 m
.4 .01499 L
s
.425 .01472 m
.425 .01491 L
s
.45 .01472 m
.45 .01484 L
s
.475 .01472 m
.475 .01477 L
s
.5 .01472 m
.5 .60332 L
s
.525 .01472 m
.525 .01477 L
s
.55 .01472 m
.55 .01484 L
s
.575 .01472 m
.575 .01491 L
s
.6 .01472 m
.6 .01499 L
s
.625 .01472 m
.625 .01511 L
s
.65 .01472 m
.65 .01527 L
s
.675 .01472 m
.675 .01552 L
s
.7 .01472 m
.7 .01602 L
s
.725 .01472 m
.725 .01748 L
s
.75 .01472 m
.75 .30882 L
s
.775 .01472 m
.775 .01783 L
s
.8 .01472 m
.8 .01633 L
s
.825 .01472 m
.825 .01583 L
s
.85 .01472 m
.85 .01558 L
s
.875 .01472 m
.875 .01542 L
s
.9 .01472 m
.9 .01532 L
s
.925 .01472 m
.925 .01525 L
s
.95 .01472 m
.95 .01519 L
s
.975 .01472 m
.975 .01514 L
s
1 .01472 m
1 .01511 L
s
.015 w
0 .01511 Mdot
.025 .01514 Mdot
.05 .01519 Mdot
.075 .01525 Mdot
.1 .01532 Mdot
.125 .01542 Mdot
.15 .01558 Mdot
.175 .01583 Mdot
.2 .01633 Mdot
.225 .01783 Mdot
.25 .30882 Mdot
.275 .01748 Mdot
.3 .01602 Mdot
.325 .01552 Mdot
.35 .01527 Mdot
.375 .01511 Mdot
.4 .01499 Mdot
.425 .01491 Mdot
.45 .01484 Mdot
.475 .01477 Mdot
.5 .60332 Mdot
.525 .01477 Mdot
.55 .01484 Mdot
.575 .01491 Mdot
.6 .01499 Mdot
.625 .01511 Mdot
.65 .01527 Mdot
.675 .01552 Mdot
.7 .01602 Mdot
.725 .01748 Mdot
.75 .30882 Mdot
.775 .01783 Mdot
.8 .01633 Mdot
.825 .01583 Mdot
.85 .01558 Mdot
.875 .01542 Mdot
.9 .01532 Mdot
.925 .01525 Mdot
.95 .01519 Mdot
.975 .01514 Mdot
1 .01511 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000?ooooo0ol0
000Gooooo`?o00001?ooool2o`0001[ooooo0ol0000Kooooo`;o00007?ooool3o`0001[ooooo0ol0
0004ooooo`;o00005oooool3o`0000?ooooo0ol0000Fooooo`Go00000oooool2o`0000?ooooo000i
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo000001Wo
oooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Gooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool0037ooooo1Ol00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Boooo
o`Go00001Oooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0001kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool003Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007?ooool00ol0003ooooo
ooooo`0Gooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000000_ooool1o`00007ooooo0Oooool0
03Wooooo00Co0000oooooooooooooooo1?l0000Hooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00006?ooool4o`0001[ooooo00Co0000oooooooooooo00006_ooool4o`0001_ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Gooooo`04o`000?oooooooooooooo
o`Co00005_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool003Sooooo0_l00003ooooo`03o`000?oooooooooo01Sooooo0_l00004ooooo`04o`000?oooooo
ooooo`0001Sooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000Jooooo`03o`00
0?oooooooooo01_ooooo0_l00004ooooo`04o`000?ooooooooooo`0001Kooooo0_l00003ooooo`03
o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo000iooooo`04o`000?ooooooooooooooo`Go00005oooool00ol0003oooooooooo`03
ooooo`;o00006Oooool5o`0001[ooooo0_l0000Kooooo`Go00006_ooool00ol0003oooooooooo`03
ooooo`;o00006?ooool01?l0003oooooooooooooool5o`0001Kooooo0ol00004ooooo`;o00000ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool001_ooooo00<0
0000o`000?l00000nol000000`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00`00003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`0300000?oooooooooo00Cooooo000Dooooo`;o00001Oooool00`00003oooooooooo`0Loooo
o`03o`000?oooooooooo01gooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Moooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01gooooo00<00000ooooooooool01?ooool001?ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`1Qooooo`?oo`000oooool3ool000Cooooo0ooo0003oooo
o`?oo`002_ooool3ool000?ooooo0ooo0003ooooo`?oo`001?ooool3ool006Cooooo00<00000oooo
ooooool01?ooool001?ooooo00Co0000oooooooooooo00000_ooool3ool00004o`000?oooooooooo
ooooo`?oo`000oooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000?ooooo0ooo0004
ooooo`?oo`000oooool3ool000?ooooo0ooo0005ooooo`030?l00?oooooooooo00;ooooo0ooo0003
ooooo`?oo`001?ooool3ool000?ooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004
ooooo`?oo`000oooool3ool000Gooooo00<0o`00ooooooooool00_ooool3ool000?ooooo0ooo0003
ooooo`?oo`001?ooool3ool000?ooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0003
ooooo`?oo`001Oooool00`3o003oooooooooo`02ooooo`?oo`000oooool3ool000Cooooo0ooo0003
ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`000oooool3ool000Cooooo0ooo0003
ooooo`?oo`001_ooool001?ooooo00Co0000oooooooooooo00000_ooool3ool000Cooooo0ooo0003
ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`000oooool3ool000Cooooo0ooo0003
ooooo`?oo`000oooool3ool000Gooooo00<0o`00ooooooooool00_ooool3ool000?ooooo0ooo0004
ooooo`?oo`000oooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003
ooooo`?oo`001Oooool00`3o003oooooooooo`02ooooo`?oo`000oooool3ool000?ooooo0ooo0004
ooooo`?oo`000oooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000?ooooo0ooo0005
ooooo`030?l00?oooooooooo00;ooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0003
ooooo`?oo`001?ooool3ool000?ooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0006
ooooo`004oooool01?l0003oooooooooool00002ooooo`?oo`001?ooool3ool000?ooooo0ooo0003
ooooo`?oo`001?ooool3ool000?ooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0003
ooooo`?oo`001Oooool00`3o003oooooooooo`02ooooo`?oo`000oooool3ool000Cooooo0ooo0003
ooooo`?oo`000oooool3ool001oooooo00<0o`00ooooooooool06oooool3ool000?ooooo0ooo0004
ooooo`?oo`000oooool3ool000?ooooo0ooo0005ooooo`030?l00?oooooooooo00;ooooo0ooo0003
ooooo`?oo`001?ooool3ool000?ooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0003
ooooo`?oo`001?ooool3ool000?ooooo0ooo0006ooooo`004oooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0l
ooooo`030?l00?oooooooooo03gooooo00<00000ooooooooool01?ooool001Cooooo0_l00005oooo
o`0300000?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0loooo
o`030?l00?oooooooooo03gooooo00<00000ooooooooool01?ooool001_ooooo00<00000oooooooo
ool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00oooooooo
ool0?Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0looooo`030?l0
0?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030000
0?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo03cooooo00<0o`00ooooooooool0?Ooo
ool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000ooooooooool01?oo
ool001_ooooo00<00000o`000?ooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooo
oooo03cooooo00<0o`00ooooooooool0??ooool00ol000000000ooooo`05ooooo`006oooool00`00
003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o
003oooooooooo`0mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo03co
oooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03go
oooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0??ooool00`3o003ooooo
ooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`00003ooooo
ooooo`04ooooo`006oooool00`00003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0
o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`0300000?oooooooooo00Cooooo000K
ooooo`0300000?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0l
ooooo`030?l00?oooooooooo03gooooo00<00000ooooooooool01?ooool001_ooooo00<00000oooo
ooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00oooo
ooooool0?Oooool00`00003oooooooooo`04ooooo`006oooool00`00003o0000ooooo`0looooo`03
0?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0looooo`03
o`000000003ooooo00Gooooo000Kooooo`0300000?oooooooooo03cooooo00<0o`00ooooooooool0
?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000ooooooooool0
1?ooool001_ooooo00<00000ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oo
oooooooo03cooooo00<0o`00ooooooooool0?Oooool00`00003oooooooooo`04ooooo`006oooool0
0`00003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool0
0`3o003oooooooooo`0mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo
03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo
03gooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0??ooool00`3o003o
ooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`00003o
ooooooooo`04ooooo`006oooool00`00003oooooooooo`0looooo`030?l00?oooooooooo03gooooo
00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`0300000?oooooooooo00Cooooo
000Kooooo`0300000?l0003ooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003ooooooooo
o`0looooo`030?l00?oooooooooo03cooooo00?o000000000?ooool01Oooool001_ooooo00<00000
ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00
ooooooooool0?Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0loooo
o`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0moooo
o`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo03cooooo00<0o`00oooooooo
ool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000oooooooo
ool01?ooool001_ooooo00<00000ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l0
0?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`00003oooooooooo`04ooooo`001_oo
ool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0looooo`030?l00?oo
oooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`0300000?oo
oooooooo00Cooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo03cooooo00<0o`00oooooooo
ool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000oooooooo
ool01?ooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0??ooool00`3o003oooooooooo`0moooo
o`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`00003oooooooooo`04oooo
o`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`0300000?l0003ooooo03cooooo00<0o`00ooooooooool0?Oooool0
0`3o003oooooooooo`0looooo`030?l00?oooooooooo03_ooooo0`000006ooooo`001_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003ooooo
ooooo`0looooo`030?l00?oooooooooo03gooooo00<00000ooooooooool01?ooool000Kooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00oooo
ooooool0??ooool00`3o003oooooooooo`0mooooo`0300000?oooooooooo00Cooooo0007ooooo`?o
00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo03cooooo00<0o`00oooooooo
ool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000oooooooo
ool01?ooool001_ooooo00<00000ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l0
0?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`00003oooooooooo`04ooooo`006ooo
ool00`00003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??oo
ool00`3o003oooooooooo`0mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooo
oooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooo
oooo03gooooo00<00000ooooooooool01?ooool001_ooooo00<00000o`000?ooool0??ooool00`3o
003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0??ooool00ol0
00000000ooooo`05ooooo`006oooool00`00003oooooooooo`0looooo`030?l00?oooooooooo03go
oooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003ooooo
ooooo`0looooo`030?l00?oooooooooo03gooooo00<00000ooooooooool01?ooool001_ooooo00<0
0000ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0
o`00ooooooooool0?Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0l
ooooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0m
ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo03cooooo00<0o`00oooo
ooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000oooo
ooooool01?ooool001_ooooo00<00000ooooooooool0??ooool00`3o003oooooooooo`0mooooo`03
0?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`00003oooooooooo`04ooooo`00
6oooool00`00003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0
??ooool00`3o003oooooooooo`0mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?l0
003ooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oo
oooooooo03cooooo00?o000000000?ooool01Oooool001_ooooo00<00000ooooooooool0??ooool0
0`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool0
0`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0looooo`030?l00?oooooooooo
03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`0300000?oooooooooo
00Cooooo000Kooooo`0300000?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003o
ooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000ooooooooool01?ooool001_ooooo
00<00000ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo
00<0o`00ooooooooool0?Oooool00`00003oooooooooo`04ooooo`006oooool00`00003ooooooooo
o`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003ooooooooo
o`0mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo03cooooo00<0o`00
ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000
ooooooooool01?ooool001_ooooo00<00000o`000?ooool0??ooool00`3o003oooooooooo`0moooo
o`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0??ooool00ol000000000ooooo`05oooo
o`006oooool00`00003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00oooooooo
ool0??ooool00`3o003oooooooooo`0mooooo`0300000?oooooooooo00Cooooo000Kooooo`030000
0?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l0
0?oooooooooo03gooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0??oo
ool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Ooo
ool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0looooo`030?l00?oooooo
oooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`0300000?oooooo
oooo00Cooooo0008ooooo`?o00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo
03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo
03gooooo00<00000ooooooooool01?ooool000Wooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0l
ooooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0m
ooooo`0300000?oooooooooo00Cooooo0006ooooo`Go00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0??ooool00`3o003ooooooooo
o`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`00003ooooooooo
o`04ooooo`001_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003o0000ooooo`0looooo`030?l00?oooooooooo03go
oooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0kooooo`<000001_ooool000Oooooo
00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo
03cooooo00<0o`00ooooooooool0?Oooool00`00003oooooooooo`04ooooo`002?ooool2o`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooo
oooo03gooooo00<00000ooooooooool01?ooool000Wooooo00?o0000ooooooooool00_ooool2o`00
00Cooooo0_l00005ooooo`0300000?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o
003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000ooooooooool01?ooool001_o
oooo00<00000ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03co
oooo00<0o`00ooooooooool0?Oooool00`00003oooooooooo`04ooooo`006oooool00`00003ooooo
ooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003ooooo
ooooo`0mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo03cooooo00<0
o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0
0000ooooooooool01?ooool001_ooooo00<00000o`000?ooool0??ooool00`3o003oooooooooo`0m
ooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0??ooool00ol000000000ooooo`05
ooooo`006oooool00`00003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00oooo
ooooool0??ooool00`3o003oooooooooo`0mooooo`0300000?oooooooooo00Cooooo000Kooooo`03
00000?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`03
0?l00?oooooooooo03gooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0
??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0
?Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0looooo`030?l00?oo
oooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`0300000?oo
oooooooo00Cooooo000Kooooo`0300000?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool0
0`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<00000ooooooooool01?ooool0
01_ooooo00<00000ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo
03cooooo00<0o`00ooooooooool0?Oooool00`00003oooooooooo`04ooooo`006oooool00`00003o
ooooooooo`0kooooo`?oo`00?_ooool00`3o003oooooooooo`0kooooo`?oo`00?_ooool00`00003o
ooooooooo`04ooooo`006oooool00`00003o0000ooooo`0kooooo`?oo`00?_ooool00`3o003ooooo
ooooo`0kooooo`?oo`00?Oooool00ol000000000ooooo`05ooooo`006oooool00`00003ooooooooo
o`0kooooo`?oo`00?_ooool00`3o003oooooooooo`0kooooo`?oo`00?_ooool00`00003ooooooooo
o`04ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000
ooooooooool01?ooool001_ooooo00<00000ooooooooool0O?ooool00`3o003oooooooooo`1loooo
o`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00oooooooo
ool0O?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`1looooo`030?l0
0?oooooooooo07cooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0O?oo
ool00`3o003oooooooooo`1looooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?l0003o
oooo07cooooo00<0o`00ooooooooool0Noooool00ol000000000ooooo`05ooooo`006oooool00`00
003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000ooooooooool01?ooool001_o
oooo00<00000ooooooooool0O?ooool00`3o003oooooooooo`1looooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooooooool0O?ooool00`00003ooooo
ooooo`04ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<0
0000ooooooooool01?ooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<00000
ooooooooool0O?ooool00`3o003oooooooooo`1looooo`0300000?oooooooooo00Cooooo0006oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000ooooooooool0O?ooool00`3o003oooooooooo`1looooo`030000
0?oooooooooo00Cooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0O?ooool00`3o
003oooooooooo`1looooo`0300000?oooooooooo00Cooooo0006ooooo`Co00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000?ooool0O?ooool0
0`3o003oooooooooo`1jooooo`<000001_ooool000Kooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0O?oo
ool00`3o003oooooooooo`1looooo`0300000?oooooooooo00Cooooo0007ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo07cooooo00<0o`00ooooooooool0O?ooool00`00003oooooooooo`04ooooo`002?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1looooo`030?l00?oo
oooooooo07cooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0O?ooool0
0`3o003oooooooooo`1looooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo
07cooooo00<0o`00ooooooooool0O?ooool00`00003oooooooooo`04ooooo`006oooool00`00003o
ooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000ooooooooool01?ooool001_ooooo
00<00000o`000?ooool0O?ooool00`3o003oooooooooo`1kooooo`03o`000000003ooooo00Gooooo
000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooooooool0O?ooool00`00003ooooooooo
o`04ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000
ooooooooool01?ooool001_ooooo00<00000ooooooooool0O?ooool00`3o003oooooooooo`1loooo
o`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00oooooooo
ool0O?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`1looooo`030?l0
0?oooooooooo07cooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0O?oo
ool00`3o003oooooooooo`1looooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooo
oooo07cooooo00<0o`00ooooooooool0O?ooool00`00003oooooooooo`04ooooo`006oooool00`00
003o0000ooooo`1looooo`030?l00?oooooooooo07_ooooo00?o000000000?ooool01Oooool001_o
oooo00<00000ooooooooool0O?ooool00`3o003oooooooooo`1looooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooooooool0O?ooool00`00003ooooo
ooooo`04ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<0
0000ooooooooool01?ooool001_ooooo00<00000ooooooooool0O?ooool00`3o003oooooooooo`1l
ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00oooo
ooooool0O?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`1looooo`03
0?l00?oooooooooo07cooooo00<00000ooooooooool01?ooool001_ooooo00<00000o`000?ooool0
O?ooool00`3o003oooooooooo`1kooooo`03o`000000003ooooo00Gooooo000Kooooo`0300000?oo
oooooooo07cooooo00<0o`00ooooooooool0O?ooool00`00003oooooooooo`04ooooo`006oooool0
0`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000ooooooooool01?ooool0
01_ooooo00<00000ooooooooool0O?ooool00`3o003oooooooooo`1looooo`0300000?oooooooooo
00Cooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooooooool0O?ooool00`00003o
ooooooooo`04ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003ooooo
ooooo`1looooo`030?l00?oooooooooo07cooooo00<00000ooooooooool01?ooool000Kooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000oooo
ooooool01?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1looooo`030?l00?oo
oooooooo07cooooo00<00000ooooooooool01?ooool000Oooooo0ol00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o0000ooooo`1looooo`030?l0
0?oooooooooo07[ooooo0`000006ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
07cooooo00<0o`00ooooooooool0O?ooool00`00003oooooooooo`04ooooo`001_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo07cooooo00<0o`00ooooooooool0O?ooool00`00003ooooooooo
o`04ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1l
ooooo`030?l00?oooooooooo07cooooo00<00000ooooooooool01?ooool001_ooooo00<00000oooo
ooooool0O?ooool00`3o003oooooooooo`1looooo`0300000?oooooooooo00Cooooo000Kooooo`03
00000?oooooooooo07cooooo00<0o`00ooooooooool0O?ooool00`00003oooooooooo`04ooooo`00
6oooool00`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000ooooooooool0
1?ooool001_ooooo00<00000o`000?ooool0O?ooool00`3o003oooooooooo`1kooooo`03o`000000
003ooooo00Gooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooooooool0O?ooool0
0`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?oooooooooo
07cooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0O?ooool00`3o003o
ooooooooo`1looooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo07cooooo
00<0o`00ooooooooool0O?ooool00`00003oooooooooo`04ooooo`006oooool00`00003ooooooooo
o`1looooo`030?l00?oooooooooo07cooooo00<00000ooooooooool01?ooool001_ooooo00<00000
ooooooooool0O?ooool00`3o003oooooooooo`1looooo`0300000?oooooooooo00Cooooo000Koooo
o`0300000?l0003ooooo07cooooo00<0o`00ooooooooool0Noooool00ol000000000ooooo`05oooo
o`006oooool00`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000oooooooo
ool01?ooool001_ooooo00<00000ooooooooool0O?ooool00`3o003oooooooooo`1looooo`030000
0?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooooooool0O?oo
ool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?oooooo
oooo07cooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0O?ooool00`3o
003oooooooooo`1looooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo07co
oooo00<0o`00ooooooooool0O?ooool00`00003oooooooooo`04ooooo`006oooool00`00003ooooo
ooooo`1looooo`030?l00?oooooooooo07cooooo00<00000ooooooooool01?ooool001_ooooo00<0
0000o`000?ooool0O?ooool00`3o003oooooooooo`1kooooo`03o`000000003ooooo00Gooooo000K
ooooo`0300000?oooooooooo07cooooo00<0o`00ooooooooool0O?ooool00`00003oooooooooo`04
ooooo`006oooool00`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000oooo
ooooool01?ooool001_ooooo00<00000ooooooooool0O?ooool00`3o003oooooooooo`1looooo`03
00000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo07cooooo00<0o`00ooooooooool0
O?ooool00`00003oooooooooo`04ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo
0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1looooo`030?l00?oooooooooo07cooooo
00<00000ooooooooool01?ooool000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`1looooo`030?l00?oooooooooo07cooooo00<00000ooooooooool01?ooool000;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o0000ooooo`1jooooo`?oo`00O?oo
ool3000000Kooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool0N_ooool3ool007kooooo00<00000ooooooooool01?ooool000;ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003oooooooooo`1jooooo`?oo`00O_ooool00`00003oooooooooo`04
ooooo`0000?oooooo`000?l000001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`030000
0?oooooooooo00Cooooo0002ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001?oo
ool2o`0000Goooooo`000006ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.2823, -130.329, \
0.157589, 6.69334}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example #2: sum of two sinusoids", "Subsection"],

Cell[CellGroupData[{

Cell["Continuous-time waveform", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f1[t_] := 
        Sin[2  \[Pi]\ 10  t]\  + \ 
          2  Sin[2  \[Pi]\ 30\ t];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f1[t], {t, 0, 1}, \ 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\[Florin][t] \[Equal] f1[t]\  // \ TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309032 0.11678 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07547 -12 -4.5 ]
[-0.0125 .07547 0 4.5 ]
[-0.0125 .19225 -12 -4.5 ]
[-0.0125 .19225 0 4.5 ]
[-0.0125 .30903 -6 -4.5 ]
[-0.0125 .30903 0 4.5 ]
[-0.0125 .42581 -6 -4.5 ]
[-0.0125 .42581 0 4.5 ]
[-0.0125 .54259 -6 -4.5 ]
[-0.0125 .54259 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07547 m
.00625 .07547 L
s
[(-2)] -0.0125 .07547 1 0 Mshowa
0 .19225 m
.00625 .19225 L
s
[(-1)] -0.0125 .19225 1 0 Mshowa
0 .30903 m
.00625 .30903 L
s
[(0)] -0.0125 .30903 1 0 Mshowa
0 .42581 m
.00625 .42581 L
s
[(1)] -0.0125 .42581 1 0 Mshowa
0 .54259 m
.00625 .54259 L
s
[(2)] -0.0125 .54259 1 0 Mshowa
.125 Mabswid
0 .09883 m
.00375 .09883 L
s
0 .12218 m
.00375 .12218 L
s
0 .14554 m
.00375 .14554 L
s
0 .1689 m
.00375 .1689 L
s
0 .21561 m
.00375 .21561 L
s
0 .23896 m
.00375 .23896 L
s
0 .26232 m
.00375 .26232 L
s
0 .28568 m
.00375 .28568 L
s
0 .33239 m
.00375 .33239 L
s
0 .35574 m
.00375 .35574 L
s
0 .3791 m
.00375 .3791 L
s
0 .40246 m
.00375 .40246 L
s
0 .44917 m
.00375 .44917 L
s
0 .47252 m
.00375 .47252 L
s
0 .49588 m
.00375 .49588 L
s
0 .51924 m
.00375 .51924 L
s
0 .05212 m
.00375 .05212 L
s
0 .02876 m
.00375 .02876 L
s
0 .0054 m
.00375 .0054 L
s
0 .56595 m
.00375 .56595 L
s
0 .5893 m
.00375 .5893 L
s
0 .61266 m
.00375 .61266 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07547 m
1 .07547 L
s
.99375 .19225 m
1 .19225 L
s
.99375 .30903 m
1 .30903 L
s
.99375 .42581 m
1 .42581 L
s
.99375 .54259 m
1 .54259 L
s
.125 Mabswid
.99625 .09883 m
1 .09883 L
s
.99625 .12218 m
1 .12218 L
s
.99625 .14554 m
1 .14554 L
s
.99625 .1689 m
1 .1689 L
s
.99625 .21561 m
1 .21561 L
s
.99625 .23896 m
1 .23896 L
s
.99625 .26232 m
1 .26232 L
s
.99625 .28568 m
1 .28568 L
s
.99625 .33239 m
1 .33239 L
s
.99625 .35574 m
1 .35574 L
s
.99625 .3791 m
1 .3791 L
s
.99625 .40246 m
1 .40246 L
s
.99625 .44917 m
1 .44917 L
s
.99625 .47252 m
1 .47252 L
s
.99625 .49588 m
1 .49588 L
s
.99625 .51924 m
1 .51924 L
s
.99625 .05212 m
1 .05212 L
s
.99625 .02876 m
1 .02876 L
s
.99625 .0054 m
1 .0054 L
s
.99625 .56595 m
1 .56595 L
s
.99625 .5893 m
1 .5893 L
s
.99625 .61266 m
1 .61266 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30903 m
1 .30903 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30903 m
.02605 .42667 L
.02729 .48405 L
.02846 .53006 L
.02954 .56388 L
.03072 .58926 L
.0318 .6013 L
.03279 .60285 L
.03396 .59304 L
.03506 .57314 L
.03626 .54086 L
.03756 .49636 L
.04262 .29135 L
.04385 .25081 L
.04516 .21794 L
.04591 .20476 L
.04659 .19679 L
.04728 .19275 L
.04793 .19266 L
.04919 .2028 L
.05035 .22364 L
.05162 .25783 L
.05297 .30429 L
.05552 .40849 L
.05793 .50546 L
.05898 .54085 L
.06009 .57107 L
.06131 .59349 L
.06244 .60282 L
.06367 .59961 L
.06483 .58374 L
.06609 .55256 L
.06681 .5292 L
.06746 .50449 L
.07283 .23414 L
.07402 .17473 L
.07528 .11837 L
.07645 .07524 L
.07756 .04432 L
.0788 .02233 L
.07993 .01481 L
.08118 .02032 L
.08188 .02957 L
.08253 .04176 L
.0838 .07479 L
.08517 .1213 L
.08763 .22188 L
.09032 .32956 L
.09105 .35452 L
.09183 .3777 L
Mistroke
.09251 .39448 L
.09324 .40882 L
.09406 .41987 L
.09484 .42511 L
.09559 .42528 L
.09628 .42113 L
.09695 .41327 L
.09768 .40048 L
.09845 .38276 L
.09917 .36261 L
.10198 .25833 L
.10458 .14961 L
.10584 .10218 L
.10702 .06479 L
.10825 .03567 L
.1089 .02502 L
.1096 .01766 L
.11027 .0148 L
.11099 .01635 L
.11175 .02323 L
.11245 .03439 L
.11371 .06548 L
.11442 .08862 L
.11506 .11282 L
.11982 .35047 L
.12232 .47512 L
.12369 .52999 L
.12497 .5688 L
.12612 .59166 L
.12734 .60277 L
.12804 .60279 L
.12871 .59865 L
.12995 .58048 L
.13109 .55304 L
.13214 .51992 L
.13453 .42669 L
.13678 .33248 L
.1389 .25643 L
.13996 .22752 L
.1411 .2054 L
.14237 .19326 L
.14354 .19427 L
.14473 .20718 L
.14598 .2331 L
.14664 .25111 L
.14736 .27401 L
.14864 .32066 L
.15095 .41699 L
.15345 .51561 L
.15422 .54091 L
Mistroke
.15495 .56164 L
.15566 .57823 L
.15631 .59009 L
.1576 .60252 L
.15827 .60304 L
.159 .59887 L
.15965 .59085 L
.16036 .57774 L
.16164 .54281 L
.16289 .49646 L
.16404 .44508 L
.16636 .32549 L
.16885 .19466 L
.17005 .1382 L
.17119 .09241 L
.17221 .05929 L
.17333 .03319 L
.17451 .01778 L
.17576 .01562 L
.17682 .02516 L
.178 .04696 L
.17928 .08214 L
.18065 .13059 L
.18313 .23303 L
.18537 .32288 L
.1866 .36412 L
.18776 .39467 L
.18842 .40774 L
.18913 .41803 L
.19038 .42577 L
.19165 .41994 L
.19281 .40265 L
.19403 .37352 L
.19517 .33758 L
.19776 .23543 L
.20045 .12496 L
.20177 .07904 L
.203 .04578 L
.20406 .02603 L
.2052 .01562 L
.20645 .01783 L
.20759 .03255 L
.20863 .05626 L
.20975 .09198 L
.21178 .17872 L
.21634 .41694 L
.21765 .47887 L
.21889 .52842 L
.22 .56335 L
.22121 .58941 L
Mistroke
.22245 .60228 L
.22378 .60007 L
.2249 .58574 L
.22615 .55794 L
.22729 .52294 L
.22852 .47761 L
.23075 .38516 L
.23209 .32981 L
.23355 .27548 L
.23421 .25405 L
.23493 .23419 L
.23621 .20748 L
.23685 .19887 L
.23755 .19351 L
.23883 .19455 L
.24006 .20875 L
.2412 .23256 L
.24242 .268 L
.24373 .31498 L
.24609 .4125 L
.24866 .51452 L
.24936 .53798 L
.25011 .55966 L
.25075 .57528 L
.25145 .58851 L
.25216 .59785 L
.25283 .60252 L
.25363 .6027 L
.25436 .59764 L
.255 .58909 L
.2557 .57542 L
.25644 .55653 L
.25712 .53497 L
.25961 .42888 L
.26228 .2886 L
.26487 .15699 L
.26628 .0977 L
.26698 .07366 L
.26761 .05498 L
.26874 .03017 L
.26995 .01643 L
.27127 .01708 L
.27252 .03228 L
.27322 .04648 L
.27385 .06253 L
.27528 .10786 L
.27783 .21012 L
.2793 .27178 L
.28085 .33154 L
.28228 .37695 L
Mistroke
.28298 .39439 L
.28362 .40715 L
.28477 .42197 L
.286 .42546 L
.28664 .4221 L
.28734 .41449 L
.28861 .39063 L
.28926 .37392 L
.28997 .35237 L
.29141 .30058 L
.294 .19312 L
.29643 .09823 L
.29709 .07656 L
.29779 .0567 L
.29904 .03002 L
.30021 .01676 L
.3013 .01556 L
.30249 .027 L
.30377 .05364 L
.30876 .26782 L
.31148 .41243 L
.31403 .52509 L
.31536 .56661 L
.31611 .58342 L
.31679 .59438 L
.31753 .60144 L
.31834 .60321 L
.31911 .59929 L
.31982 .59098 L
.32104 .56671 L
.32174 .54786 L
.3224 .52728 L
.32515 .42077 L
.32761 .31861 L
.32895 .26989 L
.3302 .23321 L
.33127 .21034 L
.33242 .19587 L
.33369 .19279 L
.33484 .20202 L
.33549 .2121 L
.33618 .22639 L
.33742 .26044 L
.34022 .36588 L
.34283 .47459 L
.34411 .52215 L
.34531 .55862 L
.34645 .58432 L
.34766 .60011 L
.34835 .60325 L
Mistroke
.349 .60214 L
.35022 .58934 L
.35135 .56545 L
.35238 .53394 L
.35472 .43529 L
.35955 .18348 L
.36087 .12343 L
.36229 .07128 L
.36298 .05156 L
.36363 .03659 L
.36485 .01888 L
.36592 .01479 L
.36706 .02215 L
.36804 .03745 L
.36911 .06305 L
.37026 .09903 L
.3715 .14533 L
.37375 .23893 L
.37614 .3334 L
.37734 .3719 L
.37865 .40339 L
.37978 .4199 L
.38098 .42581 L
.38212 .41997 L
.38315 .4053 L
.38797 .24693 L
.39032 .14853 L
.39247 .07228 L
.39363 .04228 L
.39474 .0234 L
.3959 .01492 L
.39717 .01996 L
.39847 .04066 L
.3992 .05881 L
.39985 .07903 L
.40234 .18274 L
.40502 .32301 L
.40792 .46972 L
.40925 .52426 L
.40997 .54882 L
.41065 .56792 L
.41185 .59194 L
.41316 .60307 L
.41446 .59827 L
.41569 .58002 L
.41679 .55346 L
.41798 .51555 L
.42047 .41734 L
.42314 .30731 L
.42444 .26173 L
Mistroke
.42568 .22735 L
.42679 .20579 L
.42801 .19363 L
.42915 .1937 L
.43037 .20608 L
.43152 .22876 L
.43257 .25753 L
.4352 .35492 L
.43798 .47101 L
.43912 .51419 L
.44035 .5533 L
.44106 .57136 L
.4417 .5846 L
.44296 .60057 L
.44424 .60217 L
.44496 .59632 L
.44563 .58657 L
.44685 .55824 L
.44815 .51453 L
.45083 .39165 L
.45378 .23442 L
.45631 .11521 L
.457 .08886 L
.45773 .06495 L
.45904 .03323 L
.46026 .01747 L
.4614 .01535 L
.46265 .02668 L
.46335 .03889 L
.46398 .05333 L
.46629 .12761 L
.46882 .23199 L
.47129 .33048 L
.47268 .37483 L
.47395 .40451 L
.47512 .42084 L
.47639 .42565 L
.47759 .41744 L
.4787 .39917 L
.47983 .37112 L
.48085 .33866 L
.48315 .24931 L
.48565 .14487 L
.48702 .09431 L
.48829 .05602 L
.48896 .0404 L
.48968 .02753 L
.49047 .01831 L
.49119 .01483 L
.49185 .01586 L
Mistroke
.49256 .02157 L
.49386 .04399 L
.49507 .07814 L
.4964 .12878 L
.4991 .26048 L
.50161 .39434 L
.50394 .50322 L
.50508 .54455 L
.50629 .57742 L
.50699 .5904 L
.50764 .59859 L
.50886 .60313 L
.51016 .59291 L
.51135 .57076 L
.51266 .53432 L
.51405 .48506 L
.51851 .30225 L
.5198 .25803 L
.52102 .22504 L
.52211 .20457 L
.52331 .19335 L
.5246 .19493 L
.52532 .20202 L
.52597 .21213 L
.52725 .24121 L
.52844 .27833 L
.53324 .47216 L
.53458 .52171 L
.53531 .54506 L
.53598 .56383 L
.53718 .58879 L
.5385 .60231 L
.53924 .60303 L
.53993 .59902 L
.54124 .57934 L
.54197 .56162 L
.54264 .54127 L
.54417 .48275 L
.54883 .2445 L
.55005 .18213 L
.55139 .12155 L
.55267 .07421 L
.55384 .04232 L
.55502 .02198 L
.55629 .01472 L
.55746 .02126 L
.55856 .03849 L
.55965 .0647 L
.56064 .09575 L
.56289 .18259 L
Mistroke
.5652 .27936 L
.56647 .32822 L
.56767 .36774 L
.56835 .38622 L
.56909 .40265 L
.57039 .42113 L
.5717 .42549 L
.57292 .41628 L
.57418 .39397 L
.57536 .36247 L
.57806 .26304 L
.58088 .14507 L
.58226 .09411 L
.58352 .05646 L
.58468 .03124 L
.58578 .01772 L
.58695 .01531 L
.58821 .027 L
.58951 .05426 L
.59016 .07351 L
.59088 .09856 L
.59334 .20899 L
.5959 .34485 L
.59833 .46703 L
.59967 .52242 L
.60038 .54667 L
.60113 .56811 L
.60183 .5836 L
.60246 .59386 L
.60369 .60318 L
.60493 .59834 L
.60606 .58197 L
.60731 .55222 L
.60862 .50982 L
.61102 .41413 L
.61325 .32129 L
.61531 .24964 L
.61647 .22033 L
.61752 .20225 L
.61867 .19286 L
.61992 .19556 L
.62111 .21029 L
.6222 .23369 L
.62338 .26826 L
.62462 .31281 L
.62684 .40426 L
.62944 .50847 L
.6307 .54972 L
.63185 .57828 L
.63292 .59577 L
Mistroke
.63394 .60301 L
.63501 .60033 L
.63617 .58531 L
.63737 .5571 L
.63863 .5145 L
.6409 .41245 L
.64564 .1657 L
.647 .10676 L
.64829 .06249 L
.64946 .03438 L
.65072 .0176 L
.65139 .01478 L
.65212 .01649 L
.65289 .02355 L
.65362 .03488 L
.65491 .06531 L
.6563 .11041 L
.65882 .21162 L
.66151 .32113 L
.66284 .36578 L
.6641 .39804 L
.66523 .41699 L
.66646 .42562 L
.66762 .42188 L
.66885 .40547 L
.66991 .38207 L
.67107 .34764 L
.67387 .23911 L
.67653 .12925 L
.67769 .08798 L
.67892 .05229 L
.67963 .03659 L
.68027 .02582 L
.68152 .01514 L
.68282 .01935 L
.68356 .02868 L
.68423 .0416 L
.68547 .07565 L
.68677 .12451 L
.69242 .41142 L
.69476 .51687 L
.69608 .56032 L
.69728 .58741 L
.69796 .59698 L
.6987 .6025 L
.69939 .60301 L
.70004 .59948 L
.70129 .58219 L
.70192 .56859 L
.70261 .5502 L
Mistroke
.70754 .36006 L
.70883 .30805 L
.71022 .25971 L
.71153 .22427 L
.71272 .20281 L
.71381 .19324 L
.71499 .1944 L
.71611 .20643 L
.71714 .22642 L
.71826 .25676 L
.71949 .29865 L
.72197 .3996 L
.72464 .50715 L
.72595 .55011 L
.72717 .57999 L
.72785 .59164 L
.72857 .59976 L
.72937 .60332 L
.73009 .60143 L
.73075 .59542 L
.73146 .58437 L
.73275 .55281 L
.73397 .51053 L
.73531 .45271 L
.73801 .31379 L
.74052 .18279 L
.74283 .08482 L
.74406 .04831 L
.74536 .02373 L
.74666 .01475 L
.7474 .01672 L
.7481 .02311 L
.74935 .04504 L
.75049 .07553 L
.75307 .17034 L
.75541 .26859 L
.75669 .31909 L
.7579 .3604 L
.75903 .39122 L
.76026 .4142 L
.76137 .42458 L
.76239 .42478 L
.76358 .41379 L
.76489 .38857 L
.76554 .37116 L
.76625 .34944 L
.76752 .30369 L
.7704 .18448 L
.77181 .12752 L
.77312 .08159 L
Mistroke
.77436 .04737 L
.77568 .02357 L
.777 .01473 L
.77775 .01691 L
.77846 .02379 L
.77968 .04654 L
.7808 .0788 L
.78203 .12529 L
.78332 .18432 L
.78568 .30706 L
.78823 .43984 L
.7894 .49279 L
.79064 .53958 L
.7917 .57025 L
.79286 .59279 L
.79356 .6003 L
.79419 .60321 L
.79492 .60189 L
.79562 .59609 L
.79685 .57552 L
.79755 .55856 L
.7982 .53982 L
.80305 .3485 L
.80421 .3029 L
.80546 .25974 L
.80664 .22727 L
.80772 .20617 L
.8087 .19518 L
.80978 .19253 L
.8109 .20036 L
.81195 .21708 L
.81317 .24725 L
.81434 .28467 L
.81652 .37031 L
.81905 .47561 L
.82028 .52141 L
.82142 .55643 L
.8225 .58169 L
.82363 .59822 L
.82477 .60332 L
.82602 .59506 L
.82729 .5718 L
.828 .55257 L
.82864 .53155 L
.83109 .42671 L
.83602 .17024 L
.83737 .11111 L
.8381 .08371 L
.83879 .06181 L
.84001 .03286 L
Mistroke
.84066 .02291 L
.84135 .01656 L
.84257 .01633 L
.84326 .02222 L
.8439 .03138 L
.84507 .05673 L
.84631 .09416 L
.85084 .27625 L
.85288 .35207 L
.85403 .38531 L
.85509 .40778 L
.85626 .42248 L
.85751 .42524 L
.85859 .41681 L
.85978 .39645 L
.86109 .36188 L
.86231 .32076 L
.86505 .20914 L
.86742 .1137 L
.86868 .07183 L
.86937 .05285 L
.87003 .03802 L
.87125 .01983 L
.87237 .01473 L
.87341 .02049 L
.87456 .03843 L
.87576 .0699 L
.87705 .11613 L
.87936 .22415 L
.88207 .36897 L
.8835 .44144 L
.88501 .50797 L
.88633 .55392 L
.88708 .5738 L
.88778 .58791 L
.88902 .60175 L
.89034 .60084 L
.89162 .5849 L
.89234 .56987 L
.89301 .55248 L
.89554 .46345 L
.89802 .35967 L
.89911 .31588 L
.90029 .27278 L
.90138 .23964 L
.90255 .21304 L
.90378 .19639 L
.90493 .19237 L
.90557 .19508 L
.90627 .20203 L
Mistroke
.90754 .2248 L
.90878 .25823 L
.90992 .29709 L
.91217 .38785 L
.91459 .48755 L
.91576 .52948 L
.91687 .56225 L
.91787 .58428 L
.91896 .59906 L
.92016 .6031 L
.92143 .59268 L
.92264 .56909 L
.92373 .53696 L
.92502 .48697 L
.92643 .42172 L
.92897 .2877 L
.93165 .15162 L
.93312 .09148 L
.93384 .06759 L
.93449 .04943 L
.93566 .02614 L
.93691 .01516 L
.93756 .01526 L
.93827 .01983 L
.93956 .03941 L
.94398 .18828 L
.9463 .2853 L
.94756 .33322 L
.94874 .37096 L
.94977 .39711 L
.95088 .41616 L
.95211 .42549 L
.95322 .42274 L
.95424 .41105 L
.95534 .3891 L
.95638 .36047 L
.95734 .32843 L
.96161 .15417 L
.96278 .10929 L
.96404 .0683 L
.96522 .03895 L
.9663 .02177 L
.96749 .01473 L
.96877 .02179 L
.96999 .04257 L
.97111 .07338 L
.97228 .11598 L
.97357 .17328 L
.97619 .30903 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005oooool2o`0002_ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00008oooool2
o`0000Cooooo00?o0000ooooooooool00oooool3o`0002Cooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol0000Uooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000:Oooool3
o`0000[ooooo000Fooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool0000Rooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool08_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003ooooo
ooooo`09ooooo`005_ooool01?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00007ooooo`Go00008oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`09ooooo`00
5_ooool01?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002Cooooo00Co
0000oooooooooooo00001oooool4o`0002Cooooo00Co0000oooooooooooo00002?ooool3o`0002[o
oooo00?o0000ooooooooool02Oooool001Kooooo00Co0000oooooooooooo0000:Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000002Cooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`0Uooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Yoooo
o`03o`000?oooooooooo00Wooooo000Fooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002;ooooo00Co0000oooooooooooo0000
2Oooool2o`0002Cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Tooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Xooooo`;o00002oooool0
01Oooooo0_l0000[ooooo`;o00002Oooool3o`0002Cooooo0_l0000;ooooo`03o`000?oooooooooo
02?ooooo0_l0000:ooooo`;o00009Oooool2o`0000Wooooo0ol0000Zooooo`03o`000?oooooooooo
00Wooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Aoooo
oooo00003Ol00003ooooo`004Oooool2o`0000Gooooo00<00000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00`00003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`0300000?oooooooooo00?ooooo0_l00003ooooo`004Oooool00ol0003ooooo
ooooo`04ooooo`0300000?oooooooooo033ooooo00?o0000ooooooooool0;oooool00`00003ooooo
ooooo`0`ooooo`0300000?oooooooooo033ooooo00<00000ooooooooool0;oooool00`00003ooooo
ooooo`04ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo0?oooooo2Ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo0_l00?l6ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooo
oooo00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01Oooool2o`00oa3ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00<0003oooooooooool01_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Cooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo0_l00?l6ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo
00Cooooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`;o003o4?ooool00ol00?ooooooooooo`04ooooo`;o003o4?ooool00`00
0?ooooooooooo`05ooooo`030000oooooooooooo00Kooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool04_ooool2o`00o`Oooooo00?o003oooooooooool03_ooool2o`00o`Ko
oooo00?o003oooooooooool03_ooool2o`00o`Kooooo0_l00?l@ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00oa3o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool2o`00o`oo
oooo0_l00?l6ooooo`;o003o4?ooool00`000?ooooooooooo`05ooooo`030000oooooooooooo00Ko
oooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool04_ooool2o`00o`Kooooo
0_l00?l@ooooo`;o003o1_ooool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool2o`00oa3ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool2o`00o`oooooo
0_l00?l6ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l@ooooo`030000oooooooooooo00Gooooo
00<0003oooooooooool01_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0001?ooooo0_l0
0?l6ooooo`;o003o4?ooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo0_l0
0?l7ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l0
0?l?ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool03_ooool2o`00o`Kooooo0_l0
0?l?ooooo`;o003o1_ooool2o`00oa3ooooo0P000?l6ooooo`030000oooooooooooo00Gooooo0_l0
0003ooooo`004Oooool00ol0003oooooooooo`0Booooo`;o003o1_ooool2o`00oa3ooooo0_l00?l6
ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool00ol00?ooooooo`00o`0?
ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05
ooooo`;o003o4?ooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00oa3ooooo0P000?l6
ooooo`80003o1oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Boooo
o`;o003o1_ooool2o`00oa3ooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?oooo
o`;o003o1_ooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6oooo
o`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6oooo
o`;o003o3oooool2o`00o`Kooooo0_l00?l@ooooo`80003o1_ooool20000o`Oooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool04_ooool2o`00o`Kooooo0_l00?l@ooooo`;o
003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo00?o003oooooool0
0?l03oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o
003o3oooool00`000?oooooo0000o`06ooooo`80003o1oooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`0Booooo`;o003o1_ooool2o`00oa3ooooo0_l00?l6ooooo`;o003o
3oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool00ol00?ooooooo`00o`0?ooooo`;o003o
1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`;o003o
3oooool00`000?oooooo0000o`06ooooo`80003o1oooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`0Booooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01_oo
ool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo00?o003oooooool00?l03ooo
ool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Ooo
ool2o`00o`oooooo00<0003oooooo`000?l01_ooool20000o`Oooooo00?o0000ooooooooool00Ooo
ool0017ooooo0_l0000Cooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo
003o00Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2
o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2
o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo0_l00?l?ooooo`030000ooooool0
003o00Kooooo0P000?l6ooooo`;o00000oooool0017ooooo00?o0000ooooooooool04_ooool2o`00
o`Kooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`06ooooo`;o003o3oooool2o`00
o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00<0003oooooo`000?l01Oooool00`00
0?oooooo0000o`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo01;o
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Ko
oooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Ko
oooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Ko
oooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00`000?oo
oooo0000o`05ooooo`030000ooooool0003o00Oooooo00?o0000ooooooooool00Oooool000Sooooo
1Ol00004ooooo`03o`000?oooooooooo01;ooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Kooooo
0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`03o`00oooooooo003o00kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`030000ooooool0003o00Gooooo
00<0003oooooo`000?l01oooool00ol0003oooooooooo`01ooooo`002Oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo01;ooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Kooooo
0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`03o`00oooooooo003o00kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l03oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo
00<0003oooooo`000?l01Oooool00`000?oooooo0000o`07ooooo`03o`000?oooooooooo007ooooo
0002ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l0
0?l6ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00kooooo00<0003oooooo`000?l01Oooool00`000?oooooo0000
o`07ooooo`03o`000?oooooooooo007ooooo000;ooooo`03o`000?oooooooooo00?ooooo0ol0000B
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?
ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`030000ooooool0003o00Gooooo00<0003o
ooooo`000?l01Oooool3o`0000?ooooo0008ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0Booooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0?ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`030000ooooool0
003o00Gooooo00<0003oooooo`000?l01oooool00ol0003oooooooooo`01ooooo`002?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool04_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?
ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00kooooo00<0003oooooo`000?l01Oooool00`000?oooooo0000o`07
ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003oooooooooo`0Boooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00`000?oooooo0000o`05oooo
o`030000ooooool0003o00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooooooo
ool04_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooo
ool00?l03oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l03_ooool00`000?oooooo0000o`05ooooo`030000ooooool0003o00Oooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool04_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`0?
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?
ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o3_ooool00`000?oooooo0000
o`05ooooo`030000ooooool0003o00Oooooo00?o0000ooooooooool00Oooool0017ooooo0_l0000B
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
o`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooo003o00oooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l>ooooo`030000ooooool0003o00Gooooo00<0003oooooo`000?l01_ooool2
o`0000?ooooo000Aooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00oooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l0
3_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00<0003o
ooooo`000?l01Oooool00`000?oooooo0000o`07ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool0
0?l4ooooo`03o`00oooooooo003o00oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o3Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00<0003oooooo`000?l0
1Oooool00`000?oooooo0000o`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oo
oooooooo017ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o3Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00<0003oooooo`000?l01Ooo
ool00`000?oooooo0000o`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo017ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l>
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o3Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00<0003oooooo`000?l01Ooo
ool00`000?oooooo0000o`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo017ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l>
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o3Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00@0003oooooooooool0003o
1?ooool00`000?oooooo0000o`07ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00004_oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o3_ooool00ol00?ooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`kooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l=ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool010000?ooooooooooo`000?l4ooooo`03
0000ooooool0003o00Kooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0Aooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l>ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o3_ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`040000oooooooooooo0000o`Cooooo00<0
003oooooo`000?l01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0A
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o3_oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`040000oooooooooooo
0000o`Cooooo00<0003oooooo`000?l01oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`0Aooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Cooooo00Co003ooooo
oooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`04
0000oooooooooooo0000o`Cooooo00<0003oooooo`000?l01oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`kooooo00@0003oooooooooool0003o1?ooool00`000?oooooo0000o`07oooo
o`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo017ooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`kooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00gooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool010000?ooooooooooo`000?l4
ooooo`030000ooooool0003o00Oooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool04Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>
ooooo`040000oooooooooooo0000o`Cooooo00<0003oooooo`000?l01oooool00ol0003ooooooooo
o`01ooooo`004Oooool2o`0001;ooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Ooo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o3_ooool010000?ooooooooooo`000?l4ooooo`040000oooooooooooo0000o`Go
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03
o`00oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`0=ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00@0003oooooooooool0003o1?ooool01000
0?ooooooooooo`000?l6ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo
017ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool0
10000?ooooooooooo`000?l4ooooo`040000oooooooooooo0000o`Kooooo00?o0000ooooooooool0
0Oooool0017ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l=ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l>ooooo`040000oooooooooooo0000o`Cooooo00@0003ooooo
ooooool0003o1_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0Aoooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_oo
ool010000?ooooooooooo`000?l4ooooo`040000oooooooooooo0000o`Kooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`0>
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00@0003oooooooooool0003o1?ooool0
10000?ooooooooooo`000?l6ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00004_ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
3_ooool010000?ooooooooooo`000?l4ooooo`040000oooooooooooo0000o`Gooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l00oooool01?l0
0?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooooooo
ool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00
o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03Oooool010000?ooooooooooo`00
0?l4ooooo`040000oooooooooooo0000o`Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o
0000ooooooooool04Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo
003o3Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o3Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l=ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`0>oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooooooo
ool00?l4ooooo`05o`00ooooooooooooooooool00?l03Oooool010000?ooooooooooo`000?l4oooo
o`040000oooooooooooo0000o`Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool04Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o3Ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o00cooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l=ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`0>ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4
ooooo`05o`00ooooooooooooooooool00?l03Oooool010000?ooooooooooo`000?l4ooooo`040000
oooooooooooo0000o`Kooooo00?o0000ooooooooool00Oooool000Wooooo0ol00005ooooo`03o`00
0?oooooooooo017ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l03Ooo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`0>
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03Oooool010000?ooooooooooo`000?l4
ooooo`040000oooooooooooo0000o`Kooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`05o`00ooooooooooooooooool00?l00ooo
ool01?l00?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`0<ooooo`05
o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l=ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l03Oooool010000?ooooooooooo`000?l4ooooo`040000oooooooooooo0000o`Kooooo00?o0000
ooooooooool00Oooool000;ooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo0ol0000:oooo
o`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooo
ooooo`00o`Kooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00Cooooo00Co003o
oooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo
00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooo
oooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Oo
oooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Kooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00@0003oooooooooool0
003o1?ooool010000?ooooooooooo`000?l4ooooo`?o00000oooool000[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l5ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooooooool0
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003ooooo
ooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo
003o1_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`Oooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1_ooool010000?oooooooooo
o`000?l4ooooo`040000oooooooooooo0000o`Kooooo00?o0000ooooooooool00Oooool000[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`;o003o1Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?oooooooooo
o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool2o`00o`Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2
o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1Oooool2o`00o`Kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6oooo
o`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`;o003o1_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Ko
oooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`05ooooo`;o003o1_ooool010000?ooooooooooo`000?l3ooooo`050000oooo
ooooooooooooo`000?l01_ooool00ol0003oooooooooo`01ooooo`002Oooool2o`0000Kooooo00?o
0000ooooooooool02_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooo`00o`Kooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l5ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol0
0?l0003oooooo`05ooooo`040000oooooooooooo0000o`?ooooo00D0003ooooooooooooooooo0000
o`06ooooo`03o`000?oooooooooo007ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`Kooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Co003ooooooooooooo003o0ooo
ool01Ol00?oooooooooooooooooo003o00Kooooo0_l00?l5ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003o0000oooo
ool01Oooool010000?ooooooooooo`000?l3ooooo`050000ooooooooooooooooo`000?l01_ooool0
0ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0:ooooo`;o003o1Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Ko
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`;o003o1Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o
1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooo
oooo003o00Kooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool00ol00?l0003oooooo`05ooooo`040000oooooooooooo0000o`?o
oooo00D0003ooooooooooooooooo0000o`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
00002_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01?l0
0?ooooooooooool00?l6ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`05ooooo`;o003o1_ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Kooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01_ooool2o`00o`Gooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`;o003o1Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00o`00
0?oooooo00Gooooo00@0003oooooooooool0003o0oooool01@000?ooooooooooooooool0003o00Go
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooo003o00Gooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l5oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l0
0?l6ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`05ooooo`;o
003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05
ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o0oooool01Ol00?oo
oooooooooooooooo003o00Kooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003o0000ooooool01Oooool0
10000?ooooooooooo`000?l3ooooo`050000ooooooooooooooooo`000?l01_ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooo003o00Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l5ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l0
1Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`?ooooo
00Go003oooooooooooooooooo`00o`06ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003o0000
ooooool01?ooool01@000?ooooooooooooooool0003o00?ooooo00D0003ooooooooooooooooo0000
o`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o003o
ooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o
1_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00Kooooo
0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Gooooo0_l00?l6ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01Oooool00ol00?l0003oooooo`04ooooo`050000oooooooooooooooo
o`000?l00oooool01@000?ooooooooooooooool0003o00Kooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool02Oooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooool00?l6ooooo`;o003o1Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l3
ooooo`05o`00ooooooooooooooooool00?l01_ooool2o`00o`Gooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00
o`000?oooooo00Cooooo00D0003ooooooooooooooooo0000o`03ooooo`050000oooooooooooooooo
o`000?l01_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`03
o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooooooo
ooooool00?l01_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool2o`00o`Kooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00o`000?oooooo00Cooooo00D0
003ooooooooooooooooo0000o`03ooooo`050000ooooooooooooooooo`000?l01_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooo003o00Gooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00
o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Gooooo0_l00?l6ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool00ol00?l0003oooooo`04ooooo`050000oooooooo
ooooooooo`000?l00oooool01@000?ooooooooooooooool0003o00Kooooo00?o0000ooooooooool0
0Oooool0017ooooo0_l0000:ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooooooo
o`00o`02ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01Oooool00ol00?l0003oooooo`04ooooo`050000ooooooooooooooooo`000?l00oooool0
1@000?ooooooooooooooool0003o00Gooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`09
ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01?l0
0?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?l0003oooooo`04ooooo`050000
ooooooooooooooooo`000?l00oooool01@000?ooooooooooooooool0003o00Kooooo00?o0000oooo
ooooool00Oooool0017ooooo00?o0000ooooooooool02Oooool00ol00?ooooooo`00o`05ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol0
0?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Gooooo00?o003o0000ooooool01?ooool01@000?oooooooooooooo
ool0003o00?ooooo00D0003ooooooooooooooooo0000o`06ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00Wooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool0
0ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01Oooool00ol00?l0003oooooo`04ooooo`050000ooooooooooooooooo`000?l00oooool01@00
0?ooooooooooooooool0003o00Kooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Co
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00o`00
0?oooooo00Cooooo00D0003ooooooooooooooooo0000o`03ooooo`050000ooooooooooooooooo`00
0?l01_ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`00
oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooo`000?l01Oooool01@00
0?ooooooooooooooool0003o00?ooooo00D0003ooooooooooooooooo0000o`06ooooo`03o`000?oo
oooooooo007ooooo000Aooooo`;o00002_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l0
1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05oooo
o`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooo
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`00ooooool0003o00Gooooo00D0003ooooooooooooooooo0000o`03ooooo`05
0000ooooooooooooooooo`000?l01Oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Wo
oooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooo`000?l01Oooool01@000?ooooooooooooooool0003o00?ooooo00D0003o
oooooooooooooooo0000o`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooo
oooo00Wooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooo`000?l01Oooool01@000?ooooooooooooooool0003o00?ooooo
00D0003ooooooooooooooooo0000o`06ooooo`03o`000?oooooooooo007ooooo000Aooooo`03o`00
0?oooooooooo00Wooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool0
0?l01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`05
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooo`000?l01Oooool01@000?ooooooooooooooool0003o
00?ooooo00D0003ooooooooooooooooo0000o`06ooooo`03o`000?oooooooooo007ooooo000Aoooo
o`03o`000?oooooooooo00Wooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol0
0?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooo`000?l01Oooool01@000?oooooooooooooo
ool0003o00?ooooo00D0003ooooooooooooooooo0000o`06ooooo`03o`000?oooooooooo007ooooo
000Aooooo`03o`000?oooooooooo00Wooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
oooo0000o`Cooooo00D0003ooooooooooooooooo0000o`03ooooo`050000ooooooooooooooooo`00
0?l01_ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000[ooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`05ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooo003o00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooo`000?l4ooooo`050000oooooooooooooooo
o`000?l00_ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00?ooooo0_l00003oooo
o`004Oooool00ol0003oooooooooo`09ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`04o`00oooooooooooo0000o`Cooooo00D0003ooooooooooooooooo0000o`02ooooo`030000
oooooooooooo00;ooooo00<0003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Ooo
ool00ol0003oooooooooo`09ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oo
oooooooooooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02oooo
o`04o`00oooooooooooo0000o`Cooooo00D0003ooooooooooooooooo0000o`02ooooo`030000oooo
oooooooo00;ooooo00<0003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`09ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooo
oooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`04o`00
oooooooooooo0000o`Cooooo00D0003ooooooooooooooooo0000o`02ooooo`030000oooooooooooo
00;ooooo00<0003oooooooooool01?ooool00ol0003oooooooooo`01ooooo`002_ooool2o`0000Go
oooo00?o0000ooooooooool02Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool0
0_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003o
ooooooooool00oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003o
ooooooooool0003o1?ooool01@000?ooooooooooooooool0003o00;ooooo00<0003oooooooooool0
0_ooool00`000?ooooooooooo`04ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool02Oooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
003o00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo
00?o003oooooool00?l01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooo`000?l4ooooo`050000oooooooo
ooooooooo`000?l00_ooool00`000?ooooooooooo`02ooooo`030000oooooooooooo00Cooooo00?o
0000ooooooooool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool7o`000003o`00ool0
003o000000;o000000Co003oo`000?l0003o003o0ol000000ol00?oo0000o`000002o`000005o`00
ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000004o`00ool0003o0000o`00
o`Co000000?o003oo`000?l000000_l000000ol00?oo0000o`00o`05o`000005o`00ool0003o0000
o`000?l00?l00_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000Co003o
o`000?l0003o003o1?l000000ol00?oo0000o`000002o`000003o`00ool0003o003o00Go000000?o
003oo`000?l000000_l000000ol00?oo0000o`00o`04o`000003o`00ool0003o000000;o000000Co
003oo`000?l0003o003o1?l000000ol00?oo0000o`000002o`000004o`00ool0003o0000o`00o`?o
000000?o003oo`000?l000000ol000000ol00?oo0000o`00o`04o`000003o`00ool0003o000000;o
000000Co003oo`000?l0003o003o1?l000000ol00?oo0000o`000002o`000004o`00ool0003o0000
o`00o`?o000000?o003oo`000?l000000ol000000ol00?oo0000o`00o`04o`000003o`00ool0003o
000000;o000000Co003oo`000?l0003o003o1?l000000ol00?oo0000o`000002o`000004o`00ool0
003o0000o`00o`Co000000?o003oo`000?l000000_l000000ol00?oo0000o`00o`04o`000003o`00
ool0003o000000;o000000Co003oo`000?l0003o003o1?l000000ol00?oo0000o`000002o`000004
o`00ool0003o00000000o`Co000000D0003oo`000?l0003o00000000o`02o`0000030000ool0003o
000000;o000000<0003oo`000?l000001Ol00003ooooo`002Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol0
0?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o
1?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo0000o`Cooooo00<0003ooooooooo
ool00_ooool00`000?oooooo0000o`0;ooooo`03o`000?oooooooooo007ooooo0009ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00oooool0
0ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003oooooooooool0003o1?oo
ool00`000?ooooooooooo`02ooooo`030000ooooool0003o00_ooooo00?o0000ooooooooool00Ooo
ool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooo`000?l4ooooo`030000oooooooooooo00;ooooo00<0003oooooo`000?l02oooool00ol0
003oooooooooo`01ooooo`002_ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00_ooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooooooo
o`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003o
ooooooooool0003o1?ooool00`000?ooooooooooo`02ooooo`030000ooooool0003o00_ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`02oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool0
0oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003oooooooooool0
003o1?ooool00`000?ooooooooooo`02ooooo`030000ooooool0003o00_ooooo00?o0000oooooooo
ool00Oooool0017ooooo0_l00005ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o0oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool0
0?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Co
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?oo
ool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo0000o`Cooooo00<0003oooooooooool0
0_ooool00`000?oooooo0000o`0:ooooo`;o00000oooool0017ooooo00?o0000ooooooooool01?oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooo`000?l4ooooo`030000oooooooooooo00;ooooo00<0003oooooo`000?l02ooo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
0000o`Cooooo00<0003oooooooooool00_ooool00`000?oooooo0000o`0;ooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool00_ooool01?l0
0?ooooooooooool00?l3ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol0
0?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool0
0ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool0
0_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooo`000?l4oooo
o`030000oooooooooooo00;ooooo00<0003oooooo`000?l02oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00
o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00
o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooo`000?l4ooooo`030000oooooooooooo00;o
oooo00<0003oooooo`000?l02oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooo
ooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Cooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00
oooooooooooo0000o`Cooooo00<0003oooooooooool00_ooool00`000?oooooo0000o`0;ooooo`03
o`000?oooooooooo007ooooo000Aooooo`03o`000?oooooooooo00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003oooooooooool0003o1?ooool00`000?oo
ooooooooo`02ooooo`030000ooooool0003o00_ooooo00?o0000ooooooooool00Oooool0017ooooo
0_l00005ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Go
oooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
oooo0000o`?ooooo00<0003oooooooooool00oooool00`000?oooooo0000o`0:ooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool0
0?l01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l0
0?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?oo
ooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooo`000?l3ooooo`030000oooooooooooo00?ooooo00<0003ooooo
o`000?l02oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003o
ooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooooooool00oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo
003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooo`000?l3ooooo`030000oooo
oooooooo00?ooooo00<0003oooooo`000?l02oooool00ol0003oooooooooo`01ooooo`004Oooool0
0ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`03ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00oooool00ol00?oo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00Co003oooooooooool0003o0oooool00`000?ooooooooooo`03
ooooo`030000ooooool0003o00_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000oooo
ooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l0
0?l5ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooo`000?l3ooooo`030000oooooooooooo00?ooooo00<0003o
ooooo`000?l02oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`04o`00oooooooooooo0000o`?ooooo00<0003oooooooooool00oooool00`000?oooooo0000o`0;
ooooo`03o`000?oooooooooo007ooooo000Aooooo`;o00001Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
0_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l0
1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05oooo
o`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooo`000?l3ooooo`030000oooooooooooo00?ooooo00<0003oooooo`000?l02_oo
ool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00
ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l6
ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`05ooooo`;o003o1Oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo0000o`?o
oooo00<0003oooooooooool00oooool00`000?oooooo0000o`0;ooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2
o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00
o`Gooooo00?o003oooooooooool00_ooool01?l00?ooooooooooo`000?l3ooooo`030000oooooooo
oooo00?ooooo00<0003oooooo`000?l02oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;o
oooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l5ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`03o`00oooo
oooooooo00;ooooo00Co003oooooooooool0003o0oooool00`000?ooooooooooo`03ooooo`030000
ooooool0003o00_ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o
003o1Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo0_l00?l5ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1_oo
ool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01Oooool2o`00o`Gooooo00?o003oooooooooool00_ooool01?l00?ooooooooooo`000?l3oooo
o`030000oooooooooooo00?ooooo00<0003oooooo`000?l02oooool00ol0003oooooooooo`01oooo
o`004Oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo
0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooo`000?l3ooooo`030000oooooooooooo00?ooooo00<0003oooooo`000?l02ooo
ool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Gooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Kooooo0_l00?l5ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03oooo
o`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`04o`00ooooooooooooo`00o`Kooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`03o`00oooooooooooo00;ooooo
00Co003oooooooooool0003o0oooool00`000?ooooooooooo`03ooooo`030000ooooool0003o00[o
oooo0_l00003ooooo`004Oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01?l00?ooooooooooool00?l6ooooo`;o003o1Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1_ooool0
1?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00ooo
ool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01?l00?ooooooooooool00?l6ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1_ooool01Ol00?oooooooooooooooooo
003o00;ooooo00D0003ooooooooooooooooo0000o`05ooooo`030000ooooool0003o00_ooooo00?o
0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Ko
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo
00?ooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`06ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooo
oooooooo003o1_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool2o`00o`Kooooo00Go003oooooooooooooooooo`00o`02ooooo`05
0000ooooooooooooooooo`000?l01_ooool20000o`_ooooo00?o0000ooooooooool00Oooool0017o
oooo00?o0000ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`05ooooo`;o003o1_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Kooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Cooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6
ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`06ooooo`;o003o
1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1_ooool2o`00
o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool2o`00o`Kooooo00Co003ooooooooooooo003o0oooool01@000?ooooooooooooooool0003o00Ko
oooo0P000?l;ooooo`03o`000?oooooooooo007ooooo0009ooooo`?o00001Oooool00ol0003ooooo
ooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_oo
ool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool0
0?l4ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Co003ooooo
oooooooo003o0oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooooooool01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1_ooool2o`00o`Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2
o`00o`Kooooo00Co003ooooooooooooo003o0oooool01@000?ooooooooooooooool0003o00Kooooo
00<0003oooooooooool02_ooool00ol0003oooooooooo`01ooooo`002_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l6ooooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool01?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Ko
oooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003o
ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o
1_ooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00D0003o
oooooooooooooooo0000o`06ooooo`030000oooooooooooo00[ooooo00?o0000ooooooooool00Ooo
ool000[ooooo00?o0000ooooooooool01?ooool3o`0000Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`04ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o
003oooooooooool00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo
003o1_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`05ooooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`04o`00ooooooooooooo`00o`Oooooo00?o003oooooooooool01?ooool01?l00?oooooo
ooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l6ooooo`03o`00oooo
oooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`?ooooo00D0003ooooo
oooooooooooo0000o`06ooooo`03o`00oooooooooooo00Sooooo0ol00003ooooo`002_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l03?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o
3Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o3_ooool01?l00?oooooooooo
ool00?l3ooooo`05o`00ooooooooooooooooool00?l03Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co
003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l3ooooo`050000oooooooooooooooo
o`000?l04oooool00ol0003oooooooooo`01ooooo`002_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o
1?ooool01Ol00?oooooooooooooooooo003o00cooooo00Go003oooooooooooooooooo`00o`03oooo
o`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooo
oooooooo003o00gooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`gooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`gooooo00Co
003ooooooooooooo003o0oooool01@000?ooooooooooooooool0003o01?ooooo00?o0000oooooooo
ool00Oooool000Wooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooo
oooooooooooo003o00cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooo
oooooooo003o0oooool01Ol00?oooooooooooooooooo003o00gooooo00Go003ooooooooooooooooo
o`00o`03ooooo`04o`00ooooooooooooo`00o`gooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o0oooool01@000?oooooooooo
ooooool0003o01?ooooo00?o0000ooooooooool00Oooool000[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4
ooooo`05o`00ooooooooooooooooool00?l03?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`05o`00oooooooooooo
ooooool00?l03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o
3Oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o3Oooool01?l0
0?ooooooooooool00?l4ooooo`040000oooooooooooo0000oa?ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co
003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`0=ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l=ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l=ooooo`04
o`00ooooooooooooo`00o`Cooooo00@0003oooooooooool0003o4oooool00ol0003oooooooooo`01
ooooo`004Oooool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`go
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`0=ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l=
ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooo
ooooool00?l4ooooo`040000oooooooooooo0000oa?ooooo00?o0000ooooooooool00Oooool0017o
oooo0_l00005ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00cooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooo
oooooooooooo003o00gooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l>oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`0=ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00
o`Gooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`040000oooo
oooooooo0000oa;ooooo0_l00003ooooo`004Oooool00ol0003oooooooooo`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooo
oooo003o00Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l03Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooo003o3Oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`go
oooo00Co003ooooooooooooo003o1?ooool010000?ooooooooooo`000?lCooooo`03o`000?oooooo
oooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o003oooooool00?l01?ooool01?l0
0?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
3Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01?ooool01?l00?oo
ooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Ooo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooo
oooo003o1Oooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00@0
003oooooooooool0003o4oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003ooooooooo
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>oooo
o`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o3Ooo
ool01?l00?ooooooooooool00?l4ooooo`040000oooooooooooo0000oa?ooooo00?o0000oooooooo
ool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=oooo
o`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o3?ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool0
0?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1Ooo
ool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00@0003ooooooooo
ool0003o4oooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1Oooool01?l00?oooooooooo
ool00?l<ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l=oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_oo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo
003o1?ooool010000?ooooooooooo`000?lCooooo`03o`000?oooooooooo007ooooo000Aooooo`;o
00001_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Gooooo00Co
003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooo
oooo003o00Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l>ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooo
ooooool00?l4ooooo`040000oooooooooooo0000oa;ooooo0_l00003ooooo`004Oooool00ol0003o
ooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1Ooo
ool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo
003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003o
ooooool00?l01?ooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l=ooooo`04o`00oooo
ooooooooo`00o`Cooooo00@0003oooooooooool0003o4oooool00ol0003oooooooooo`01ooooo`00
4Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooo
oooooooo003o1Oooool01?l00?ooooooooooool00?l=ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`kooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l>ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>oooo
o`04o`00ooooooooooooo`00o`Cooooo00@0003oooooooooool0003o4oooool00ol0003ooooooooo
o`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`kooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l>ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00@0003oooooooooool0003o4oooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`kooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l>ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00@0003oooooooooool0003o4oooool00ol0
003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`kooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l>oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00@0003oooooooooool0003o4oooool0
0ol0003oooooooooo`01ooooo`004Oooool2o`0000Kooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Ooo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o3_ooool00ol00?ooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`kooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00kooooo00Co003ooooooooooooo003o1?ooool010000?ooooooooooo`000?lBooooo`;o00000ooo
ool0017ooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l0
0?ooooooooooool00?l4ooooo`040000oooooooooooo0000oa?ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l0
0?ooooooooooool00?l4ooooo`040000oooooooooooo0000oa?ooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?oo
ooooooooool00?l4ooooo`040000oooooooooooo0000oa?ooooo00?o0000ooooooooool00Oooool0
017ooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oooooo
o`00o`05ooooo`040000oooooooooooo0000oa?ooooo00?o0000ooooooooool00Oooool0017ooooo
00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05
ooooo`030000ooooool0003o01Cooooo00?o0000ooooooooool00Oooool0017ooooo0_l00006oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00<0003oooooo`000?l0
4oooool2o`0000?ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l0
3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00ko
oooo00?o003oooooool00?l01Oooool00`000?oooooo0000o`0Dooooo`03o`000?oooooooooo007o
oooo000Aooooo`03o`000?oooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003ooooo
ool00?l01Oooool00`000?oooooo0000o`0Dooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04
o`00ooooooooooooo`00o`Gooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`go
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`030000ooooool0003o
01Cooooo00?o0000ooooooooool00Oooool000Sooooo1Ol00004ooooo`03o`000?oooooooooo00Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00
o`Gooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l03_ooool00ol00?ooooooo`00o`05ooooo`030000ooooool0003o01Cooooo00?o0000oooooooo
ool00Oooool000Wooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`06ooooo`;o
003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool0
0?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003ooooo
ool00?l01Oooool00`000?oooooo0000o`0Dooooo`03o`000?oooooooooo007ooooo000:ooooo`03
o`000?oooooooooo00Cooooo0ol00005ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l03_ooool00ol00?ooooooo`00o`06ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o
003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03
o`00oooooooo003o00Gooooo00<0003oooooo`000?l04_ooool3o`0000?ooooo000;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00kooooo00?o003oooooool00?l01_ooool2o`00o`oooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
3oooool2o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
3_ooool00ol00?ooooooo`00o`05ooooo`030000ooooool0003o01Cooooo00?o0000ooooooooool0
0Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Kooooo
0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01_ooool20000oaCooooo
00?o0000ooooooooool00Oooool000Sooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o
1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`06ooooo`80003o
5?ooool00ol0003oooooooooo`01ooooo`002Oooool3o`0000Gooooo00?o0000ooooooooool01Ooo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3ooo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03ooo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Kooooo0P000?lDooooo`03o`000?oo
oooooooo007ooooo000Aooooo`03o`000?oooooooooo00Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2
o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2
o`00o`Gooooo00?o003oooooool00?l03oooool2o`00o`Kooooo00?o003oooooool00?l03_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01_ooool2
0000oaCooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0?ooooo`;o003o1Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol0
0?ooooooo`00o`06ooooo`80003o5?ooool00ol0003oooooooooo`01ooooo`004Oooool2o`0000Ko
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oo
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Ko
oooo0P000?lCooooo`;o00000oooool0017ooooo00?o0000ooooooooool01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`80003o5?ooool00ol0003ooooo
ooooo`01ooooo`004Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool00ol00?ooooooo`00
o`0>ooooo`03o`00oooooooo003o00Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l0
0?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l0
0?l6ooooo`80003o5?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06
ooooo`;o003o1Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6
ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?
ooooo`03o`00oooooooo003o00Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6
ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6
ooooo`80003o5?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06oooo
o`;o003o1Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6oooo
o`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?oooo
o`03o`00oooooooo003o00Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6oooo
o`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6oooo
o`80003o5?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`06ooooo`03
o`00oooooooooooo00Gooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o
003o4?ooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l7ooooo`;o
003o3oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00oa3ooooo0_l00?l5ooooo`;o
003o4?ooool2o`00o`Kooooo0P000?lDooooo`03o`000?oooooooooo007ooooo000Aooooo`;o0000
1oooool00ol00?ooooooooooo`05ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o
1_ooool2o`00oa3ooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o
1oooool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o
4?ooool00ol00?ooooooooooo`04ooooo`;o003o4?ooool2o`00o`Kooooo0P000?lCooooo`;o0000
0oooool0017ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00kooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l@ooooo`;o003o1_oo
ool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Oooooo00?o003oooooooooool03_oo
ool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00oa3ooooo00?o003oooooooooool01Ooo
ool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool20000oaCooooo00?o0000ooooooooool00Ooo
ool0017ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo0_l00?l6ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool2
o`00oa3ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool2
o`00o`oooooo0_l00?l6ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00kooooo0_l00?l6ooooo`80003o5?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0
003oooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool2o`00
o`Kooooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`;o003o4?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`;o003o4?ooool00ol0
0?ooooooooooo`04ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo0_l00?l6ooooo`80003o5?ooool00ol0003oooooooooo`01ooooo`004Oooool00ol0003o
ooooooooo`0Xooooo`03o`00oooooooooooo02Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo01Oooooo00<0003oooooooooool04_ooool00ol0003o
ooooooooo`01ooooo`004Oooool00ol0003oooooooooo`3oooooo`Wooooo00?o0000ooooooooool0
0Oooool0017ooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`03ooooo`;o00000oooool0017oooooool0000=o`0000?ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0956927, -3.0427, \
0.00394232, 0.032151}}],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](t) == 
      sin(20\ \[Pi]\ t) + 2\ \(sin(60\ \[Pi]\ t)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled continuous-time waveform", "Subsubsection"],

Cell[BoxData[
    \(\(sampleRate = 1000;\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(signal\  = \ 
        Table[f1[t], {t, 0, 1, 1/\((sampleRate - 1)\)}]\  // \ N;\)\), "\n", 
    \(\(ListPlot[signal, \ PlotStyle \[Rule] Blue];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.309017 0.116774 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07547 -12 -4.5 ]
[-0.0125 .07547 0 4.5 ]
[-0.0125 .19224 -12 -4.5 ]
[-0.0125 .19224 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .42579 -6 -4.5 ]
[-0.0125 .42579 0 4.5 ]
[-0.0125 .54256 -6 -4.5 ]
[-0.0125 .54256 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(200)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(400)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(600)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(800)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07547 m
.00625 .07547 L
s
[(-2)] -0.0125 .07547 1 0 Mshowa
0 .19224 m
.00625 .19224 L
s
[(-1)] -0.0125 .19224 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .42579 m
.00625 .42579 L
s
[(1)] -0.0125 .42579 1 0 Mshowa
0 .54256 m
.00625 .54256 L
s
[(2)] -0.0125 .54256 1 0 Mshowa
.125 Mabswid
0 .09882 m
.00375 .09882 L
s
0 .12218 m
.00375 .12218 L
s
0 .14553 m
.00375 .14553 L
s
0 .16889 m
.00375 .16889 L
s
0 .2156 m
.00375 .2156 L
s
0 .23895 m
.00375 .23895 L
s
0 .26231 m
.00375 .26231 L
s
0 .28566 m
.00375 .28566 L
s
0 .33237 m
.00375 .33237 L
s
0 .35573 m
.00375 .35573 L
s
0 .37908 m
.00375 .37908 L
s
0 .40244 m
.00375 .40244 L
s
0 .44915 m
.00375 .44915 L
s
0 .4725 m
.00375 .4725 L
s
0 .49586 m
.00375 .49586 L
s
0 .51921 m
.00375 .51921 L
s
0 .05211 m
.00375 .05211 L
s
0 .02876 m
.00375 .02876 L
s
0 .0054 m
.00375 .0054 L
s
0 .56592 m
.00375 .56592 L
s
0 .58927 m
.00375 .58927 L
s
0 .61263 m
.00375 .61263 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07547 m
1 .07547 L
s
.99375 .19224 m
1 .19224 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .42579 m
1 .42579 L
s
.99375 .54256 m
1 .54256 L
s
.125 Mabswid
.99625 .09882 m
1 .09882 L
s
.99625 .12218 m
1 .12218 L
s
.99625 .14553 m
1 .14553 L
s
.99625 .16889 m
1 .16889 L
s
.99625 .2156 m
1 .2156 L
s
.99625 .23895 m
1 .23895 L
s
.99625 .26231 m
1 .26231 L
s
.99625 .28566 m
1 .28566 L
s
.99625 .33237 m
1 .33237 L
s
.99625 .35573 m
1 .35573 L
s
.99625 .37908 m
1 .37908 L
s
.99625 .40244 m
1 .40244 L
s
.99625 .44915 m
1 .44915 L
s
.99625 .4725 m
1 .4725 L
s
.99625 .49586 m
1 .49586 L
s
.99625 .51921 m
1 .51921 L
s
.99625 .05211 m
1 .05211 L
s
.99625 .02876 m
1 .02876 L
s
.99625 .0054 m
1 .0054 L
s
.99625 .56592 m
1 .56592 L
s
.99625 .58927 m
1 .58927 L
s
.99625 .61263 m
1 .61263 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02476 .30902 m
.02571 .36016 L
.02667 .40972 L
.02762 .45617 L
.02857 .49809 L
.02952 .53421 L
.03048 .56348 L
.03143 .58507 L
.03238 .59843 L
.03333 .6033 L
.03429 .59969 L
.03524 .58794 L
.03619 .56863 L
.03714 .54263 L
.0381 .51103 L
.03905 .4751 L
.04 .43625 L
.04095 .39599 L
.0419 .35588 L
.04286 .31745 L
.04381 .28213 L
.04476 .25128 L
.04571 .22604 L
.04667 .20737 L
.04762 .19596 L
.04857 .19225 L
.04952 .19635 L
.05048 .20814 L
.05143 .22716 L
.05238 .2527 L
.05333 .2838 L
.05429 .3193 L
.05524 .35786 L
.05619 .39802 L
.05714 .43824 L
.0581 .47697 L
.05905 .51272 L
.06 .54408 L
.06095 .56976 L
.0619 .58871 L
.06286 .60007 L
.06381 .60326 L
.06476 .59797 L
.06571 .58418 L
.06667 .56219 L
.06762 .53256 L
.06857 .49612 L
.06952 .45395 L
.07048 .40731 L
.07143 .35763 L
Mistroke
.07238 .30645 L
.07333 .25534 L
.07429 .2059 L
.07524 .15965 L
.07619 .11799 L
.07714 .08219 L
.0781 .05329 L
.07905 .0321 L
.08 .01915 L
.08095 .01472 L
.0819 .01874 L
.08286 .03089 L
.08381 .05055 L
.08476 .07686 L
.08571 .10871 L
.08667 .14482 L
.08762 .18378 L
.08857 .22406 L
.08952 .26412 L
.09048 .30244 L
.09143 .33756 L
.09238 .36816 L
.09333 .39309 L
.09429 .41141 L
.09524 .42244 L
.09619 .42577 L
.09714 .42127 L
.0981 .40911 L
.09905 .38975 L
.1 .3639 L
.10095 .33255 L
.1019 .29686 L
.10286 .25819 L
.10381 .21799 L
.10476 .17781 L
.10571 .13919 L
.10667 .10363 L
.10762 .07253 L
.10857 .04715 L
.10952 .02857 L
.11048 .0176 L
.11143 .01484 L
.11238 .02056 L
.11333 .03476 L
.11429 .05715 L
.11524 .08714 L
.11619 .1239 L
.11714 .16632 L
.1181 .21315 L
.11905 .26294 L
Mistroke
.12 .31416 L
.12095 .36522 L
.1219 .41453 L
.12286 .46059 L
.12381 .50198 L
.12476 .53746 L
.12571 .56599 L
.12667 .58678 L
.12762 .5993 L
.12857 .60332 L
.12952 .59888 L
.13048 .58634 L
.13143 .56632 L
.13238 .53971 L
.13333 .50761 L
.13429 .47132 L
.13524 .43226 L
.13619 .39195 L
.13714 .35194 L
.1381 .31375 L
.13905 .27883 L
.14 .24849 L
.14095 .22387 L
.1419 .2059 L
.14286 .19524 L
.14381 .1923 L
.14476 .19719 L
.14571 .20972 L
.14667 .22943 L
.14762 .25558 L
.14857 .28718 L
.14952 .32305 L
.15048 .36183 L
.15143 .40206 L
.15238 .4422 L
.15333 .48071 L
.15429 .51608 L
.15524 .54692 L
.15619 .57198 L
.15714 .5902 L
.1581 .60077 L
.15905 .60311 L
.16 .59697 L
.16095 .58235 L
.1619 .55956 L
.16286 .52921 L
.16381 .49214 L
.16476 .44946 L
.16571 .40245 L
.16667 .35255 L
Mistroke
.16762 .30131 L
.16857 .2503 L
.16952 .20111 L
.17048 .15525 L
.17143 .11413 L
.17238 .07897 L
.17333 .05081 L
.17429 .03042 L
.17524 .01833 L
.17619 .01474 L
.17714 .01959 L
.1781 .03253 L
.17905 .0529 L
.18 .07981 L
.18095 .11215 L
.1819 .14862 L
.18286 .18777 L
.18381 .2281 L
.18476 .26806 L
.18571 .30612 L
.18667 .34084 L
.18762 .37092 L
.18857 .39523 L
.18952 .41285 L
.19048 .42312 L
.19143 .42567 L
.19238 .42039 L
.19333 .40749 L
.19429 .38744 L
.19524 .361 L
.19619 .32915 L
.19714 .29311 L
.1981 .25421 L
.19905 .21395 L
.2 .17386 L
.20095 .13547 L
.2019 .10029 L
.20286 .06971 L
.20381 .04497 L
.20476 .02712 L
.20571 .01695 L
.20667 .01503 L
.20762 .0216 L
.20857 .03664 L
.20952 .05982 L
.21048 .09053 L
.21143 .1279 L
.21238 .17083 L
.21333 .21802 L
.21429 .26802 L
Mistroke
.21524 .3193 L
.21619 .37025 L
.21714 .41931 L
.2181 .46496 L
.21905 .50581 L
.22 .54064 L
.22095 .56843 L
.2219 .58841 L
.22286 .60009 L
.22381 .60325 L
.22476 .59798 L
.22571 .58466 L
.22667 .56394 L
.22762 .53672 L
.22857 .50415 L
.22952 .46751 L
.23048 .42826 L
.23143 .38791 L
.23238 .34801 L
.23333 .31009 L
.23429 .27557 L
.23524 .24575 L
.23619 .22176 L
.23714 .20449 L
.2381 .1946 L
.23905 .19244 L
.24 .19811 L
.24095 .21138 L
.2419 .23177 L
.24286 .25851 L
.24381 .29059 L
.24476 .32682 L
.24571 .36581 L
.24667 .4061 L
.24762 .44615 L
.24857 .48441 L
.24952 .51939 L
.25048 .54971 L
.25143 .57412 L
.25238 .59161 L
.25333 .60138 L
.25429 .60288 L
.25524 .59588 L
.25619 .58043 L
.25714 .55685 L
.2581 .52579 L
.25905 .48811 L
.26 .44493 L
.26095 .39757 L
.2619 .34746 L
Mistroke
.26286 .29617 L
.26381 .24527 L
.26476 .19635 L
.26571 .15091 L
.26667 .11033 L
.26762 .07583 L
.26857 .04841 L
.26952 .02884 L
.27048 .01758 L
.27143 .01485 L
.27238 .02053 L
.27333 .03424 L
.27429 .05531 L
.27524 .08282 L
.27619 .11564 L
.27714 .15244 L
.2781 .19178 L
.27905 .23214 L
.28 .27197 L
.28095 .30976 L
.2819 .34408 L
.28286 .37363 L
.28381 .3973 L
.28476 .41422 L
.28571 .42373 L
.28667 .42549 L
.28762 .41944 L
.28857 .4058 L
.28952 .38507 L
.29048 .35804 L
.29143 .32572 L
.29238 .28932 L
.29333 .25022 L
.29429 .20991 L
.29524 .16992 L
.29619 .13179 L
.29714 .09701 L
.2981 .06696 L
.29905 .04286 L
.3 .02574 L
.30095 .01638 L
.3019 .0153 L
.30286 .02272 L
.30381 .0386 L
.30476 .06256 L
.30571 .09398 L
.30667 .13197 L
.30762 .17538 L
.30857 .22292 L
.30952 .27312 L
Mistroke
.31048 .32443 L
.31143 .37527 L
.31238 .42405 L
.31333 .46928 L
.31429 .50959 L
.31524 .54375 L
.31619 .57079 L
.31714 .58996 L
.3181 .60079 L
.31905 .6031 L
.32 .597 L
.32095 .58291 L
.3219 .56149 L
.32286 .53369 L
.32381 .50064 L
.32476 .46368 L
.32571 .42425 L
.32667 .38388 L
.32762 .34411 L
.32857 .30646 L
.32952 .27235 L
.33048 .24307 L
.33143 .21972 L
.33238 .20316 L
.33333 .19403 L
.33429 .19266 L
.33524 .1991 L
.33619 .21311 L
.33714 .23417 L
.3381 .26149 L
.33905 .29405 L
.34 .33062 L
.34095 .36981 L
.3419 .41015 L
.34286 .45008 L
.34381 .48808 L
.34476 .52265 L
.34571 .55243 L
.34667 .5762 L
.34762 .59295 L
.34857 .60191 L
.34952 .60257 L
.35048 .59472 L
.35143 .57843 L
.35238 .55407 L
.35333 .5223 L
.35429 .48402 L
.35524 .44036 L
.35619 .39265 L
.35714 .34236 L
Mistroke
.3581 .29103 L
.35905 .24026 L
.36 .19162 L
.36095 .14661 L
.3619 .10658 L
.36286 .07275 L
.36381 .04609 L
.36476 .02733 L
.36571 .01693 L
.36667 .01504 L
.36762 .02155 L
.36857 .03603 L
.36952 .05779 L
.37048 .08589 L
.37143 .11916 L
.37238 .15628 L
.37333 .19579 L
.37429 .23617 L
.37524 .27587 L
.37619 .31338 L
.37714 .34727 L
.3781 .37628 L
.37905 .39931 L
.38 .41551 L
.38095 .42426 L
.3819 .42524 L
.38286 .41841 L
.38381 .40403 L
.38476 .38264 L
.38571 .35503 L
.38667 .32224 L
.38762 .28551 L
.38857 .24622 L
.38952 .20587 L
.39048 .16599 L
.39143 .12813 L
.39238 .09377 L
.39333 .06426 L
.39429 .04082 L
.39524 .02445 L
.39619 .01589 L
.39714 .01566 L
.3981 .02393 L
.39905 .04064 L
.4 .06538 L
.40095 .0975 L
.4019 .13608 L
.40286 .17997 L
.40381 .22784 L
.40476 .27823 L
Mistroke
.40571 .32956 L
.40667 .38026 L
.40762 .42876 L
.40857 .47356 L
.40952 .5133 L
.41048 .54679 L
.41143 .57307 L
.41238 .59142 L
.41333 .6014 L
.41429 .60286 L
.41524 .59594 L
.41619 .58108 L
.41714 .55898 L
.4181 .5306 L
.41905 .4971 L
.42 .45982 L
.42095 .42023 L
.4219 .37985 L
.42286 .34022 L
.42381 .30287 L
.42476 .26919 L
.42571 .24045 L
.42667 .21774 L
.42762 .20191 L
.42857 .19354 L
.42952 .19295 L
.43048 .20017 L
.43143 .21491 L
.43238 .23664 L
.43333 .26453 L
.43429 .29755 L
.43524 .33444 L
.43619 .37382 L
.43714 .41418 L
.4381 .45399 L
.43905 .49171 L
.44 .52587 L
.44095 .5551 L
.4419 .57821 L
.44286 .59421 L
.44381 .60235 L
.44476 .60217 L
.44571 .59346 L
.44667 .57635 L
.44762 .55121 L
.44857 .51875 L
.44952 .47987 L
.45048 .43575 L
.45143 .38772 L
.45238 .33725 L
Mistroke
.45333 .28591 L
.45429 .23528 L
.45524 .18694 L
.45619 .14236 L
.45714 .1029 L
.4581 .06975 L
.45905 .04385 L
.46 .02591 L
.46095 .01635 L
.4619 .01532 L
.46286 .02265 L
.46381 .03789 L
.46476 .06033 L
.46571 .089 L
.46667 .12272 L
.46762 .16015 L
.46857 .19982 L
.46952 .2402 L
.47048 .27974 L
.47143 .31695 L
.47238 .35041 L
.47333 .37887 L
.47429 .40125 L
.47524 .41673 L
.47619 .42471 L
.47714 .42491 L
.4781 .41731 L
.47905 .4022 L
.48 .38014 L
.48095 .35196 L
.4819 .31872 L
.48286 .28167 L
.48381 .24221 L
.48476 .20183 L
.48571 .16209 L
.48667 .12452 L
.48762 .09058 L
.48857 .06163 L
.48952 .03885 L
.49048 .02323 L
.49143 .01549 L
.49238 .0161 L
.49333 .02523 L
.49429 .04276 L
.49524 .06828 L
.49619 .10109 L
.49714 .14025 L
.4981 .1846 L
.49905 .2328 L
.5 .28334 L
Mistroke
.50095 .33469 L
.5019 .38524 L
.50286 .43343 L
.50381 .47778 L
.50476 .51695 L
.50571 .54976 L
.50667 .57527 L
.50762 .5928 L
.50857 .60193 L
.50952 .60254 L
.51048 .5948 L
.51143 .57918 L
.51238 .55641 L
.51333 .52746 L
.51429 .49352 L
.51524 .45594 L
.51619 .4162 L
.51714 .37583 L
.5181 .33636 L
.51905 .29931 L
.52 .26607 L
.52095 .23789 L
.5219 .21584 L
.52286 .20073 L
.52381 .19313 L
.52476 .19332 L
.52571 .20131 L
.52667 .21678 L
.52762 .23917 L
.52857 .26762 L
.52952 .30108 L
.53048 .33829 L
.53143 .37783 L
.53238 .41821 L
.53333 .45789 L
.53429 .49531 L
.53524 .52903 L
.53619 .5577 L
.53714 .58014 L
.5381 .59538 L
.53905 .60271 L
.54 .60168 L
.54095 .59212 L
.5419 .57418 L
.54286 .54828 L
.54381 .51513 L
.54476 .47568 L
.54571 .4311 L
.54667 .38275 L
.54762 .33213 L
Mistroke
.54857 .28079 L
.54952 .23032 L
.55048 .18228 L
.55143 .13816 L
.55238 .09929 L
.55333 .06682 L
.55429 .04169 L
.55524 .02457 L
.55619 .01587 L
.55714 .01568 L
.5581 .02383 L
.55905 .03983 L
.56 .06294 L
.56095 .09217 L
.5619 .12632 L
.56286 .16404 L
.56381 .20385 L
.56476 .24422 L
.56571 .28359 L
.56667 .32049 L
.56762 .3535 L
.56857 .3814 L
.56952 .40312 L
.57048 .41787 L
.57143 .42508 L
.57238 .42449 L
.57333 .41613 L
.57429 .40029 L
.57524 .37758 L
.57619 .34885 L
.57714 .31517 L
.5781 .27781 L
.57905 .23819 L
.58 .19781 L
.58095 .15821 L
.5819 .12094 L
.58286 .08744 L
.58381 .05905 L
.58476 .03695 L
.58571 .02209 L
.58667 .01517 L
.58762 .01663 L
.58857 .02661 L
.58952 .04496 L
.59048 .07124 L
.59143 .10474 L
.59238 .14448 L
.59333 .18927 L
.59429 .23777 L
.59524 .28847 L
Mistroke
.59619 .33981 L
.59714 .39019 L
.5981 .43806 L
.59905 .48195 L
.6 .52053 L
.60095 .55265 L
.6019 .5774 L
.60286 .5941 L
.60381 .60238 L
.60476 .60214 L
.60571 .59359 L
.60667 .57721 L
.60762 .55377 L
.60857 .52427 L
.60952 .4899 L
.61048 .45204 L
.61143 .41217 L
.61238 .37181 L
.61333 .33252 L
.61429 .29579 L
.61524 .26301 L
.61619 .2354 L
.61714 .214 L
.6181 .19962 L
.61905 .1928 L
.62 .19378 L
.62095 .20253 L
.6219 .21872 L
.62286 .24175 L
.62381 .27076 L
.62476 .30466 L
.62571 .34216 L
.62667 .38186 L
.62762 .42224 L
.62857 .46175 L
.62952 .49888 L
.63048 .53215 L
.63143 .56024 L
.63238 .582 L
.63333 .59648 L
.63429 .60299 L
.63524 .60111 L
.63619 .5907 L
.63714 .57194 L
.6381 .54528 L
.63905 .51145 L
.64 .47143 L
.64095 .42641 L
.6419 .37777 L
.64286 .327 L
Mistroke
.64381 .27567 L
.64476 .22538 L
.64571 .17767 L
.64667 .13402 L
.64762 .09574 L
.64857 .06396 L
.64952 .03961 L
.65048 .02332 L
.65143 .01547 L
.65238 .01613 L
.65333 .02508 L
.65429 .04183 L
.65524 .0656 L
.65619 .09538 L
.65714 .12996 L
.6581 .16795 L
.65905 .20789 L
.66 .24822 L
.66095 .28742 L
.6619 .32398 L
.66286 .35654 L
.66381 .38386 L
.66476 .40492 L
.66571 .41894 L
.66667 .42538 L
.66762 .424 L
.66857 .41487 L
.66952 .39832 L
.67048 .37496 L
.67143 .34568 L
.67238 .31157 L
.67333 .27392 L
.67429 .23416 L
.67524 .19379 L
.67619 .15435 L
.67714 .11739 L
.6781 .08435 L
.67905 .05654 L
.68 .03513 L
.68095 .02103 L
.6819 .01494 L
.68286 .01724 L
.68381 .02807 L
.68476 .04724 L
.68571 .07428 L
.68667 .10845 L
.68762 .14875 L
.68857 .19398 L
.68952 .24277 L
.69048 .2936 L
Mistroke
.69143 .34491 L
.69238 .39511 L
.69333 .44265 L
.69429 .48607 L
.69524 .52405 L
.69619 .55547 L
.69714 .57944 L
.6981 .59531 L
.69905 .60274 L
.7 .60165 L
.70095 .59229 L
.7019 .57517 L
.70286 .55108 L
.70381 .52103 L
.70476 .48625 L
.70571 .44812 L
.70667 .40813 L
.70762 .36781 L
.70857 .32871 L
.70952 .29232 L
.71048 .25999 L
.71143 .23296 L
.71238 .21224 L
.71333 .19859 L
.71429 .19254 L
.71524 .1943 L
.71619 .20382 L
.71714 .22073 L
.7181 .2444 L
.71905 .27395 L
.72 .30827 L
.72095 .34606 L
.7219 .38589 L
.72286 .42626 L
.72381 .4656 L
.72476 .5024 L
.72571 .53521 L
.72667 .56272 L
.72762 .58379 L
.72857 .5975 L
.72952 .60318 L
.73048 .60045 L
.73143 .5892 L
.73238 .56962 L
.73333 .54221 L
.73429 .50771 L
.73524 .46713 L
.73619 .42169 L
.73714 .37276 L
.7381 .32187 L
Mistroke
.73905 .27057 L
.74 .22047 L
.74095 .1731 L
.7419 .12993 L
.74286 .09225 L
.74381 .06118 L
.74476 .03761 L
.74571 .02215 L
.74667 .01515 L
.74762 .01666 L
.74857 .02642 L
.74952 .04391 L
.75048 .06833 L
.75143 .09864 L
.75238 .13362 L
.75333 .17188 L
.75429 .21193 L
.75524 .25222 L
.75619 .29122 L
.75714 .32744 L
.7581 .35953 L
.75905 .38626 L
.76 .40665 L
.76095 .41993 L
.7619 .42559 L
.76286 .42344 L
.76381 .41354 L
.76476 .39628 L
.76571 .37228 L
.76667 .34247 L
.76762 .30795 L
.76857 .27002 L
.76952 .23012 L
.77048 .18977 L
.77143 .15052 L
.77238 .11389 L
.77333 .08131 L
.77429 .0541 L
.77524 .03338 L
.77619 .02005 L
.77714 .01478 L
.7781 .01794 L
.77905 .02962 L
.78 .0496 L
.78095 .07739 L
.7819 .11222 L
.78286 .15307 L
.78381 .19872 L
.78476 .24778 L
.78571 .29874 L
Mistroke
.78667 .35001 L
.78762 .40001 L
.78857 .4472 L
.78952 .49013 L
.79048 .5275 L
.79143 .55822 L
.79238 .5814 L
.79333 .59644 L
.79429 .60301 L
.79524 .60108 L
.79619 .59092 L
.79714 .57306 L
.7981 .54832 L
.79905 .51774 L
.8 .48256 L
.80095 .44418 L
.8019 .40408 L
.80286 .36382 L
.80381 .32493 L
.80476 .28888 L
.80571 .25703 L
.80667 .23059 L
.80762 .21054 L
.80857 .19764 L
.80952 .19236 L
.81048 .19491 L
.81143 .20519 L
.81238 .2228 L
.81333 .24711 L
.81429 .27719 L
.81524 .31191 L
.81619 .34998 L
.81714 .38993 L
.8181 .43026 L
.81905 .46942 L
.82 .50588 L
.82095 .53822 L
.8219 .56514 L
.82286 .58551 L
.82381 .59844 L
.82476 .60329 L
.82571 .59971 L
.82667 .58761 L
.82762 .56722 L
.82857 .53906 L
.82952 .5039 L
.83048 .46278 L
.83143 .41693 L
.83238 .36774 L
.83333 .31673 L
Mistroke
.83429 .26548 L
.83524 .21558 L
.83619 .16857 L
.83714 .12589 L
.8381 .08883 L
.83905 .05847 L
.84 .03569 L
.84095 .02107 L
.8419 .01492 L
.84286 .01727 L
.84381 .02783 L
.84476 .04606 L
.84571 .07111 L
.84667 .10195 L
.84762 .13733 L
.84857 .17583 L
.84952 .21597 L
.85048 .2562 L
.85143 .29499 L
.85238 .33086 L
.85333 .36246 L
.85429 .3886 L
.85524 .40831 L
.85619 .42084 L
.85714 .42573 L
.8581 .42279 L
.85905 .41214 L
.86 .39417 L
.86095 .36955 L
.8619 .33921 L
.86286 .30428 L
.86381 .26609 L
.86476 .22608 L
.86571 .18577 L
.86667 .14672 L
.86762 .11043 L
.86857 .07833 L
.86952 .05172 L
.87048 .0317 L
.87143 .01916 L
.87238 .01472 L
.87333 .01873 L
.87429 .03125 L
.87524 .05204 L
.87619 .08057 L
.87714 .11605 L
.8781 .15744 L
.87905 .2035 L
.88 .25282 L
.88095 .30388 L
Mistroke
.8819 .35509 L
.88286 .40488 L
.88381 .45171 L
.88476 .49414 L
.88571 .53089 L
.88667 .56089 L
.88762 .58327 L
.88857 .59748 L
.88952 .6032 L
.89048 .60043 L
.89143 .58947 L
.89238 .57088 L
.89333 .54551 L
.89429 .51441 L
.89524 .47884 L
.89619 .44022 L
.89714 .40004 L
.8981 .35985 L
.89905 .32117 L
.9 .28548 L
.90095 .25413 L
.9019 .22829 L
.90286 .20892 L
.90381 .19676 L
.90476 .19227 L
.90571 .19559 L
.90667 .20663 L
.90762 .22495 L
.90857 .24988 L
.90952 .28047 L
.91048 .31559 L
.91143 .35391 L
.91238 .39397 L
.91333 .43425 L
.91429 .47321 L
.91524 .50932 L
.91619 .54118 L
.91714 .56748 L
.9181 .58715 L
.91905 .5993 L
.92 .60332 L
.92095 .59888 L
.9219 .58594 L
.92286 .56475 L
.92381 .53584 L
.92476 .50004 L
.92571 .45839 L
.92667 .41213 L
.92762 .36269 L
.92857 .31159 L
Mistroke
.92952 .2604 L
.93048 .21073 L
.93143 .16409 L
.93238 .12191 L
.93333 .08547 L
.93429 .05584 L
.93524 .03385 L
.93619 .02007 L
.93714 .01478 L
.9381 .01796 L
.93905 .02932 L
.94 .04827 L
.94095 .07396 L
.9419 .10531 L
.94286 .14106 L
.94381 .1798 L
.94476 .22002 L
.94571 .26017 L
.94667 .29873 L
.94762 .33423 L
.94857 .36534 L
.94952 .39088 L
.95048 .4099 L
.95143 .42168 L
.95238 .42579 L
.95333 .42207 L
.95429 .41066 L
.95524 .39199 L
.95619 .36675 L
.95714 .3359 L
.9581 .30059 L
.95905 .26215 L
.96 .22204 L
.96095 .18179 L
.9619 .14294 L
.96286 .107 L
.96381 .0754 L
.96476 .0494 L
.96571 .03009 L
.96667 .01834 L
.96762 .01473 L
.96857 .0196 L
.96952 .03296 L
.97048 .05456 L
.97143 .08382 L
.97238 .11995 L
.97333 .16186 L
.97429 .20831 L
.97524 .25787 L
.97619 .30902 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`005?ooool2o`0002Wooooo1Ol00003ooooo`;o00001?ooool2o`0002Cooooo0ol00003oooo
o`;o00001?ooool2o`0002Cooooo0ol00004ooooo`;o00001?ooool2o`0002Cooooo0ol00004oooo
o`;o00001?ooool2o`00027ooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00003oooo
o`004oooool01?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000Tooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo023ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
8_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo000Cooooo`04o`00
0?ooooooooooo`0002[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`00027ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00008_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Rooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00027ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool001?ooooo00Co0000oooooooooooo0000:oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Rooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002?o
oooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`004oooool01?l0003oooooooooool0000Xooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0002;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`004oooool01?l0003oooooooooool0000Xooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002?ooooo0_l00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Pooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool001Cooooo0_l0000Zooooo`?o00001?ooool2o`0000Co
oooo0_l0000Uooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00009Oooool2o`0000Co
oooo0_l00004ooooo`;o00009?ooool3o`0000Cooooo0_l00004ooooo`;o00008_ooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`003oooool00ol0000000000000003o000000P0
000000?o0000ooooooooool01?ooool000oooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00<00000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00`00003oooooooooo`02ooooo`;o00001_ooool000oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00<0
0000ooooooooool0<?ooool00`00003oooooooooo`0`ooooo`0300000?oooooooooo033ooooo00<0
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`3o
ooooo`Sooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool04_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo0_l00?l7ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool03_ooool2o`00o`Oooooo00?o003oooooooooool03_ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`06ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo01;o
oooo0_l00?l6ooooo`;o003o3oooool2o`00o`Oooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`;o003o1oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo0_l00?l6ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Co
oooo000?ooooo`03o`000?oooooooooo01;ooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Oooooo
00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo
0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool03_ooool2o`00o`Kooooo00?o003oooooooooool03_ooool2o`00o`Kooooo
0_l00?l@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01?ooool000oooooo00?o
0000ooooooooool04_ooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00oa3ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool2o`00o`oooooo0_l0
0?l6ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo0_l0
0?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l@ooooo`03o`00oooooooooooo00Cooooo0_l0
0?l@ooooo`;o003o1_ooool00ol00?ooooooooooo`06ooooo`03o`000?oooooooooo00Cooooo000?
ooooo`;o00004oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00oa3ooooo0_l00?l6
ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l@
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool2o`00o`Kooooo0_l00?l?
ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o4?ooool2o`00o`Kooooo0_l00?l6
ooooo`;o00001_ooool000oooooo00?o0000ooooooooool04_ooool2o`00o`Kooooo0_l00?l?oooo
o`;o003o1_ooool2o`00oa3ooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?oooo
o`;o003o1_ooool2o`00oa3ooooo0_l00?l5ooooo`;o003o4?ooool2o`00o`Kooooo0_l00?l?oooo
o`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o4?ooool2o`00o`Kooooo0_l00?l7oooo
o`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo01;ooooo0_l00?l6ooooo`;o
003o3oooool2o`00o`Kooooo0_l00?l@ooooo`;o003o1Oooool00ol00?ooooooo`00o`0?ooooo`;o
003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?ooooo`03
o`00oooooooo003o00Gooooo0_l00?l@ooooo`;o003o1_ooool2o`00o`Oooooo00?o0000oooooooo
ool01?ooool000oooooo00?o0000ooooooooool04_ooool2o`00o`Kooooo0_l00?l?ooooo`;o003o
1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o
1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?ooooo`03o`00
oooooooo003o00Gooooo0_l00?l@ooooo`;o003o1Oooool00ol00?ooooooo`00o`07ooooo`03o`00
0?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo01;ooooo0_l00?l6ooooo`;o003o3ooo
ool2o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03ooo
ool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3ooo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l5ooooo`03o`00oooo
oooo003o00Oooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool04_ooool2
o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l5ooooo`03o`00oooooooo
003o00oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`07ooooo`03o`000?oooooo
oooo00Cooooo000?ooooo`;o00004oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00
o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0?ooooo`;o003o1Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00
o`oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01_ooool2o`0000Kooooo000?ooooo`03o`000?oooooooooo01;o
oooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo00?o003oooooool00?l03_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l5ooooo`03o`00oooooooo003o00oo
oooo0_l00?l6ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Ko
oooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Oooooo00?o0000ooooooooool01?ooool000oooooo
00?o0000ooooooooool04_ooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool00ol00?oooooo
o`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`03o`00oooooooo003o00kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Oooooo
00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool04_ooool2o`00o`Gooooo00?o
003oooooool00?l03oooool2o`00o`Kooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0?ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l0
0?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`07ooooo`03o`000?oooooooooo00Cooooo0006
ooooo`Go00001?ooool00ol0003oooooooooo`0Booooo`;o003o1Oooool00ol00?ooooooo`00o`0?
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?
ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6
ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01oooool00ol0003oooooooooo`04
ooooo`001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo017ooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`03o`00oooooooo003o00kooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01oooool00ol0003oooooooooo`04ooooo`001Ol00003ooooo`03o`000?oooooooooo
00Cooooo0_l0000Booooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00
o`Kooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo0ol00006ooooo`002Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l03_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`07ooooo`03o`000?oooooooooo00Cooooo0006ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l03oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l03oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l03_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01oooool00ol0003oooooooooo`04ooooo`001_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool04Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oo
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oo
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00ko
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Oooooo00?o0000ooooooooool01?ooool000Oooooo0ol00005ooooo`03o`000?oooooooooo017o
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00ko
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`07ooooo`03o`000?oooooo
oooo00Cooooo000?ooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0
3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`07ooooo`03o`000?oooooooooo00Cooooo000?ooooo`;o00004_oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00006
ooooo`003oooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooo`00o`Cooooo00?o003o
ooooool00?l03_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l03_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003o
ooooooooo`0Aooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l0
0?ooooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`0Aooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01ooo
ool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`0Aooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01oooool00ol0003o
ooooooooo`04ooooo`003oooool00ol0003oooooooooo`0Aooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01oooool00ol0003ooooooooo
o`04ooooo`003oooool2o`0001;ooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o00001_ooool000oooooo00?o0000
ooooooooool04Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Oooooo00?o0000ooooooooool01?ooool000oooooo00?o0000
ooooooooool04Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooo003o00Oooooo00?o0000ooooooooool01?ooool000oooooo00?o
0000ooooooooool04Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l>ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o3_ooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Oooooo00?o0000ooooooooool01?ooool0
00oooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o
3_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Oooooo00?o0000oooooooo
ool01?ooool000oooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Cooooo00Co003o
oooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Oooooo
00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool04Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Cooooo00Co003o
oooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo
003o00Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Kooooo00?o0000ooooooooool01?ooool000oooooo0_l0000Booooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
o`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01?oo
ool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o
003oooooool00?l01?ooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1Oooool2o`0000Kooooo000?ooooo`03o`000?oooooooooo017o
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?oooooo
ooooool00?l3ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`03o`000?oooooooooo00Cooooo
000?ooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool0
1?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`04o`00ooooooooooooo`00o`ko
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l6ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo017ooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`05o`00oooooooo
ooooooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Kooooo00?o0000ooooooooool01?ooool0
00oooooo00?o0000ooooooooool04Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`04
o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`0=ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`gooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooooooo
ooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Kooooo00?o0000ooooooooool01?ooool000oooooo00?o0000oooooooo
ool04Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`?o
oooo00Go003oooooooooooooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`go
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`kooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool0
0?l01_ooool00ol0003oooooooooo`04ooooo`003oooool2o`0001;ooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool0
0?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o3Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o3_ooool0
1?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`0000Kooooo
000?ooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool0
1?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l3
ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0003oooooooooo`04ooooo`003oooool0
0ol0003oooooooooo`0Aooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00gooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o
00gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00
o`?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`000?oooooooooo00Cooooo000?oooo
o`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0=ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l03Oooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool0
0?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Go003o
ooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo
003o0oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o0000ooooooooool01?ooool000Oo
oooo0ol00005ooooo`03o`000?oooooooooo017ooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
3Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0=oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l3ooooo`05o`00oooo
ooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l03Ooo
ool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0003o
ooooooooo`04ooooo`002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
3Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0=oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`0=ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`?ooooo00Go
003oooooooooooooooooo`00o`06ooooo`03o`000?oooooooooo00Cooooo0005o`0000?ooooo00?o
0000ooooooooool01?ooool2o`0000_ooooo00?o003oooooooooool01?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool01?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool01?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00
oooooooooooo00Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o
00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Kooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00Gooooo00Co003ooooooooo
oooo003o0oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooooooool01?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool0
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05oooo
o`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool3o`0000Kooooo0008ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool2o`00o`Kooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l6ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oo
oooooooooooooooo003o00Gooooo00?o003oooooooooool01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1_ooool01?l00?oooooooooo
ool00?l3ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`04ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo
0_l00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`06oooo
o`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l6ooooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01_ooool00ol0003oooooooooo`04ooooo`002?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo0_l00?l6ooooo`04o`00oooooooooooo
o`00o`?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Cooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6
ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00
oooooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6oooo
o`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`;o003o1_ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool0
0?l01_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1_ooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o0000ooooooooool01?ooool000Oo
oooo0_l00006ooooo`03o`000?oooooooooo00Wooooo0_l00?l6ooooo`04o`00ooooooooooooo`00
o`?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Cooooo00Co003o
oooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`00oooo
oooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`;o
003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05
ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`06ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l6ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`06ooooo`03o`000?oooooooooo00Cooooo0008ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool2o`00o`Kooooo00Co003ooooooooooooo
003o0oooool01Ol00?oooooooooooooooooo003o00Kooooo0_l00?l5ooooo`04o`00oooooooooooo
o`00o`Cooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1_ooool01?l00?oo
ooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00
o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool2o`00o`Kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`;o
003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05
ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`06ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00Wooooo0_l0
0?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`06ooooo`;o
003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05
ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`05ooooo`;o003o1_ooool01?l00?ooooooooooool00?l3ooooo`05o`00oooooooooooooooo
ool00?l01_ooool2o`00o`Gooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooo
oooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0003oooooooooo`04ooooo`003oooool2
o`0000[ooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooooooo
o`00o`06ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`05ooooo`;o003o1_ooool01?l00?ooooooooooool00?l3ooooo`05o`00
ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Cooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o
00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`;o003o1Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o
003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05
ooooo`;o00001_ooool000oooooo00?o0000ooooooooool02Oooool00ol00?ooooooo`00o`05oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`;o003o1Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o
1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`06oooo
o`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00Wooooo00?o003oooooool0
0?l01Oooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00
oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01_ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003ooooo
ooooo`09ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o0oooool01Ol00?oo
oooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo
00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool02Oooool00ol00?ooooooo`00
o`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooo
oooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0003ooooooooo
o`04ooooo`003oooool00ol0003oooooooooo`09ooooo`03o`00oooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`05
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo
00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o0000
ooooooooool01?ooool000oooooo00?o0000ooooooooool02Oooool00ol00?ooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo
003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01_ooool00ol0003oooooooooo`04ooooo`003oooool2o`0000[ooooo00?o003oooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05
ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`05ooooo`;o00001_ooool000oooooo00?o0000ooooooooool0
2Oooool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o0000oooooooo
ool01?ooool000oooooo00?o0000ooooooooool02Oooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o
00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`06ooooo`03o`000?oooooooooo00Cooooo000?
ooooo`03o`000?oooooooooo00Wooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00
o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003ooooo
ool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Kooooo00?o0000ooooooooool01?ooool000oooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
o`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Gooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003o
oooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01_ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`09ooooo`03
o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01_ooool00ol0003oooooooooo`04ooooo`003oooool2o`0000[ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooooooo
ool00oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Co
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Ooo
ool2o`0000Kooooo000?ooooo`03o`000?oooooooooo00Wooooo00?o003oooooool00?l01?ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo
00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Co
oooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0
003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`08ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`06ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00Sooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo
003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Kooooo00?o0000ooooooooool01?ooool000oooooo00?o0000oooo
ooooool02?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o0000oooooooo
ool01?ooool000oooooo00?o0000ooooooooool02?ooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03oooo
o`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo000?ooooo`;o00002Oooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`;o00001_ooool000oooooo
00?o0000ooooooooool02?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo
00Sooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00
o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00Sooooo00Co003o
oooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo
00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Co
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo0008ooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool0
0?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol0
0?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooo
ooooool00oooool00ol0003oooooooooo`04ooooo`001oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00Sooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00
o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l3ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o
1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool00oooool00ol0003oooooooooo`04ooooo`001oooool01?l0
003oooooooooool00004ooooo`Ko000000?o003oo`000?l000000_l000001?l00?oo0000o`000?l0
0?l4o`000003o`00ool0003o000000;o000000Co003oo`000?l0003o003o1?l000000ol00?oo0000
o`000002o`000004o`00ool0003o0000o`00o`?o000000?o003oo`000?l000000_l000001?l00?oo
0000o`000?l00?l4o`000003o`00ool0003o000000;o000000Co003oo`000?l0003o003o1?l00000
0ol00?oo0000o`000002o`000004o`00ool0003o0000o`00o`?o000000?o003oo`000?l000000_l0
00001?l00?oo0000o`000?l00?l4o`000003o`00ool0003o000000;o000000Co003oo`000?l0003o
003o1?l000000ol00?oo0000o`000002o`000003o`00ool0003o003o00Co000000?o003oo`000?l0
00000_l000001?l00?oo0000o`000?l00?l4o`000003o`00ool0003o000000;o000000Co003oo`00
0?l0003o003o0ol000000ol00?oo0000o`000003o`000003o`00ool0003o003o00Co000000?o003o
o`000?l000000_l000001?l00?oo0000o`000?l00?l4o`000003o`00ool0003o000000;o000000Co
003oo`000?l0003o003o1?l000000ol00?oo0000o`000002o`000003o`00ool0003o003o00Co0000
00?o003oo`000?l000000_l000001?l00?oo0000o`000?l00?l4o`000003o`00ool0003o000000;o
000000Co003oo`000?l0003o003o0ol000000ol00?oo0000o`000002o`000004o`00ool0003o0000
o`00o`Co000000?o003oo`000?l000000_l000001?l00?oo0000o`000?l00?l4o`000003o`00ool0
003o000000;o000000Co003oo`000?l0003o003o1?l000000ol00?oo0000o`000004o`0000Kooooo
0007ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooooooo
ool00?l00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`[ooooo00?o0000ooooooooool01?ooool000Oooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Cooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Co
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o2_ooool00ol0003oooooooooo`04ooooo`001oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o
1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`0;ooooo`03o`000?oo
oooooooo00Cooooo0008ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooooooo
o`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo
oooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00
oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`0;ooooo`03o`00
0?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o
003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0
0oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00_ooooo00?o0000oooooooo
ool01?ooool000oooooo0_l00004ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00;ooooo00Co003o
oooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00
o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooo`00o`0:ooooo`;o00001_ooool000oooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo
00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo
003o00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooo
ooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003o
ooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooooooool00_ooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Cooooo000?
ooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooooooool00oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool0
0?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooo`00o`0;ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`04oooo
o`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;o
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o
00Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003ooooooooo
ool00_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Cooooo000?oooo
o`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o
1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo
003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00_ooooo00?o0000oooooooo
ool01?ooool000oooooo00?o0000ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l02oooool0
0ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l0
1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00_o
oooo00?o0000ooooooooool01?ooool000oooooo0_l00005ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo00?o003oooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`05ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00_ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l02_ooool2o`0000Kooooo
000?ooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool0
0ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oo
ooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003o
ooooooooool00_ooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Cooooo000?oooo
o`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool00ol00?oo
ooooooooo`02ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00oooool00ol0
0?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00
o`04ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oooooo
o`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo003o00_ooooo00?o0000ooooooooool01?ooool000oooooo
00?o0000ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00?o003o
ooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooool00?l02oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool0
0?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05
ooooo`03o`00oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Co003ooooo
oooooooo003o1?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooo003o00_ooooo00?o0000
ooooooooool01?ooool000oooooo00?o0000ooooooooool01?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`02ooooo`03o`00oooooooo003o00_ooooo00?o0000ooooooooool01?ooool000oooooo
0_l00005ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003o
ooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`05ooooo`03o`00oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`00oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l02_oo
ool2o`0000Kooooo000?ooooo`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`0;
ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?oo
ooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`04oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00
ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o
00_ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool00ol00?ooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l02oooool00ol0003o
ooooooooo`04ooooo`003oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003oooooool00?l01?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Go
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1Oooool00ol00?ooooooo`00o`0;ooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oo
oooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01Oooool2o`00o`Kooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooo
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo
0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l02oooool00ol0003oooooooooo`04ooooo`003oooool2
o`0000Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01Oooool2o`00o`Kooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooo
oooo003o00Gooooo00?o003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`;o003o1Oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1Ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6
ooooo`;o003o2_ooool2o`0000Kooooo000?ooooo`03o`000?oooooooooo00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Ko
oooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l0
1Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l6ooooo`;o003o2oooool00ol0003oooooooooo`04oooo
o`003oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`?o
oooo00Go003oooooooooooooooooo`00o`06ooooo`;o003o1Oooool01?l00?ooooooooooool00?l4
ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Co003ooooooooo
oooo003o0oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`;o003o2oooool00ol0003o
ooooooooo`04ooooo`003oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l5ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`06ooooo`;o003o1Oooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Kooooo
00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003ooooo
ooooool01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Kooooo0_l0
0?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Go
oooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1_ooool2o`00o`_ooooo00?o0000ooooooooool01?ooool000Oooooo0ol00005ooooo`03o`000?oo
oooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Go
oooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooooooo
o`00o`06ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l6ooooo`;o003o1Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`05ooooo`;o003o1_ooool01?l00?ooooooooooool00?l3ooooo`05o`00
ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1_ooool2o`00o`Gooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooooooo`04oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool00ol00?oooooooooo
o`0:ooooo`03o`000?oooooooooo00Cooooo0008ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l0
1Oooool2o`00o`Gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01Oooool2o`00o`Kooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooo
oooo003o00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Kooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00Go
003oooooooooooooooooo`00o`06ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01Oooool2o`00o`Gooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?oo
ooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool0
0ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo0008ooooo`03o`000?oooooooooo
00Cooooo0_l00005ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00
o`05ooooo`03o`00oooooooooooo00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01Oooool2o`00o`Kooooo00Co003ooooooooooooo003o0oooool01Ol0
0?oooooooooooooooooo003o00Kooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003oooooooooool01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`05ooooo`;o003o1_ooool01?l0
0?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?oooooooooo
o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool00ol00?oo
ooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Gooooo0_l00?l6ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooooooo
o`00o`06ooooo`03o`00oooooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l6ooooo`03o`00oooooooooooo00Sooooo0ol00006ooooo`002?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00gooooo00Co003ooooooooo
oooo003o0oooool01Ol00?oooooooooooooooooo003o00gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00gooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooo
oooo003o00gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?lCooooo`03
o`000?oooooooooo00Cooooo0008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00gooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o
00gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00gooooo00Co003ooooooooo
oooo003o0oooool01Ol00?oooooooooooooooooo003o00gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo00Cooooo0007ooooo`;o00001_oo
ool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o3Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`0=
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l3ooooo`05o`00
ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
3Oooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool01?oo
ool000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00gooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o4oooool0
0ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`04ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`05o`00
ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00gooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o3Oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooooooo
o`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o4oooool00ol0
003oooooooooo`04ooooo`003oooool2o`0000Gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooooooo
o`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l=ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l>oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`0=ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o4_ooool2o`0000Kooooo000?ooooo`03o`00
0?oooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`0=ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`gooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00oa?ooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool01?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooo
oooo003o0oooool01Ol00?oooooooooooooooooo003o00gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l03Ooo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa?ooooo00?o
0000ooooooooool01?ooool000oooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o0oooool01Ol00?oo
oooooooooooooooo003o00gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?oo
ooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l03Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l=ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool01?ooool0
00oooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`kooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l3ooooo`04
o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?lCooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l>ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooooooo003o3_ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`?ooooo00Co003ooooooooo
oooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?lCooooo`03o`000?oooooooooo00Co
oooo000?ooooo`03o`000?oooooooooo00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Ooo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`?ooooo00Co
003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooo
oooo003o00Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?lCooooo`03o`000?oooooooooo00Cooooo000?ooooo`;o00001Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo
003o0oooool01?l00?ooooooooooool00?l>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`ko
oooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l>ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00oa;ooooo0_l00006ooooo`003oooool00ol0003oooooooooo`04ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o3_ooool00ol00?ooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`kooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`04ooooo`003oooool00ol0003o
ooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o4oooool00ol0003oooooooooo`04oooo
o`003oooool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00kooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`kooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00
o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o4oooool00ol0003o
ooooooooo`04ooooo`003oooool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o3_ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo
003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool00ol0
0?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o4ooo
ool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`04ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l=oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o4oooool00ol0003oooooooooo`04ooooo`003oooool2o`0000Gooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`gooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`03o`00
oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?lBoooo
o`;o00001_ooool000oooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l0
3_ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000oooo
ooooool01?ooool000oooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000oooooooo
ool01?ooool000oooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool01?oo
ool000oooooo00?o0000ooooooooool01?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooo
oooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00oooo
ooooooooo`00o`Cooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00oa?ooooo00?o0000ooooooooool01?ooool000oooooo00?o
0000ooooooooool01?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Co
oooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o
00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l03_ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00oa?ooooo00?o0000ooooooooool01?ooool000oooooo0_l00006ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`0>ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o4_ooool2o`0000Kooooo
000?ooooo`03o`000?oooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1Oooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?lCooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo
00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00kooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00kooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00kooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0Cooooo`03o`00
0?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00Gooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo003o
1Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooo`00o`0Cooooo`03o`000?oooooooooo00Cooooo0006ooooo`Go0000
1?ooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`0>ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool0
0?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool0
0?l04oooool00ol0003oooooooooo`04ooooo`001oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00kooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`0Cooooo`03
o`000?oooooooooo00Cooooo0008ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o
1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
3_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l0
1_ooool00ol00?ooooooo`00o`0Aooooo`?o00001_ooool000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0?ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00kooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`0Cooooo`03o`000?oo
oooooooo00Cooooo0006ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0?ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l0
0?l6ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Kooooo00?o
003oooooool00?l04oooool00ol0003oooooooooo`04ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Kooooo00?o003oooooool00?l03_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00oooooo0_l00?l6ooooo`;o003o5?ooool00ol0003oooooooooo`04ooooo`001oooool3
o`0000Gooooo00?o0000ooooooooool01Oooool2o`00o`Kooooo00?o003oooooool00?l03_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l5ooooo`03o`00oooooooo
003o00oooooo0_l00?l6ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2
o`00o`Kooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2
o`00oaCooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool01Oooool2o`00
o`Kooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00oooooo0_l00?l5ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`03o`00oooooooo003o
00kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00oooooo0_l00?l6ooooo`;o003o5?ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003o
ooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool00ol00?oo
ooooo`00o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Go
oooo00?o003oooooool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l03_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oo
oooo0_l00?l6ooooo`;o003o5?ooool00ol0003oooooooooo`04ooooo`003oooool2o`0000Kooooo
0_l00?l6ooooo`03o`00oooooooo003o00kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l5ooooo`03o`00oooooooo003o00oooooo
0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00oa?ooooo
0_l00006ooooo`003oooool00ol0003oooooooooo`05ooooo`;o003o1_ooool00ol00?ooooooo`00
o`0>ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Kooooo0_l0
0?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l5ooooo`03o`00oooooooo003o00oooooo0_l0
0?l6ooooo`;o003o5?ooool00ol0003oooooooooo`04ooooo`003oooool00ol0003oooooooooo`05
ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0?
ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o3oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00oooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?l?
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l03oooool2o`00o`Gooooo00?o003o
ooooool00?l03oooool2o`00o`Kooooo0_l00?lDooooo`03o`000?oooooooooo00Cooooo000?oooo
o`03o`000?oooooooooo00Gooooo0_l00?l6ooooo`;o003o4?ooool2o`00o`Gooooo00?o003ooooo
ool00?l03oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`0?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6oooo
o`;o003o3oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00oooooo0_l00?l6oooo
o`;o003o3oooool2o`00o`Kooooo0_l00?lDooooo`03o`000?oooooooooo00Cooooo000?ooooo`03
o`000?oooooooooo00Gooooo0_l00?l6ooooo`;o003o4?ooool2o`00o`Kooooo0_l00?l?ooooo`;o
003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o4?ooool2o`00o`Gooooo00?o003oooooool0
0?l03oooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo00?o003oooooool0
0?l01Oooool2o`00oa3ooooo0_l00?l6ooooo`;o003o3oooool2o`00o`Kooooo0_l00?lDooooo`03
o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo00Gooooo0_l00?l6ooooo`;o003o
4?ooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o
4?ooool2o`00o`Gooooo0_l00?l@ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o
3oooool2o`00o`Kooooo0_l00?l@ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o
5?ooool00ol0003oooooooooo`04ooooo`003oooool2o`0000Kooooo0_l00?l6ooooo`;o003o4?oo
ool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o4?oo
ool2o`00o`Kooooo00?o003oooooooooool03_ooool2o`00o`Kooooo0_l00?l?ooooo`;o003o1_oo
ool2o`00oa3ooooo00?o003oooooooooool01?ooool2o`00oa3ooooo0_l00?l6ooooo`;o003o3ooo
ool2o`00o`Kooooo0_l00?lCooooo`;o00001_ooool000oooooo00?o0000ooooooooool01Oooool2
o`00o`Kooooo0_l00?l@ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool2
o`00o`Kooooo0_l00?l?ooooo`;o003o1_ooool2o`00oa3ooooo00?o003oooooooooool01Oooool0
0ol00?ooooooooooo`0>ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o4?ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`;o003o3oooool2
o`00o`Kooooo0_l00?lDooooo`03o`000?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo
00Gooooo0_l00?l7ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`0>ooooo`;o003o1_ooool2o`00o`oooooo0_l00?l6ooooo`;o003o4?ooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo0_l00?l6ooooo`03o`00oooooooooooo
00kooooo0_l00?l6ooooo`;o003o4?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`;o003o1_ooool2o`00
oaCooooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool01_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool2o`00o`Oo
oooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00ko
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`;o003o1oooool00ol00?oo
ooooooooo`0>ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo00kooooo0_l00?l7ooooo`03o`00oooooooooooo01;o
oooo00?o0000ooooooooool01?ooool000oooooo00?o0000ooooooooool0ooooool8ooooo`03o`00
0?oooooooooo00Cooooo000?ooooo`03o`000?oooooooooo0?oooooo2?ooool00ol0003ooooooooo
o`04ooooo`003oooool2o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`003oooooooo`0000co00001_ooool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-85.4975, -3.04649, 3.94728, \
0.0321931}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete spectrum: Fast Fourier Transform (FFT)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ Fourier[signal];\)\), "\n", 
    \(\(g1 = 
        DiscreteListPlot[FourierRearrange[Abs[fft], sampleRate], Red, 
          PlotRange \[Rule] All, \ Frame \[Rule] True];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499523 0.000953334 0.0147151 0.000589997 [
[.11819 -0.0125 -12 -9 ]
[.11819 -0.0125 12 0 ]
[.30886 -0.0125 -12 -9 ]
[.30886 -0.0125 12 0 ]
[.49952 -0.0125 -3 -9 ]
[.49952 -0.0125 3 0 ]
[.69019 -0.0125 -9 -9 ]
[.69019 -0.0125 9 0 ]
[.88086 -0.0125 -9 -9 ]
[.88086 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13271 -18 -4.5 ]
[-0.0125 .13271 0 4.5 ]
[-0.0125 .25071 -18 -4.5 ]
[-0.0125 .25071 0 4.5 ]
[-0.0125 .36871 -18 -4.5 ]
[-0.0125 .36871 0 4.5 ]
[-0.0125 .48671 -18 -4.5 ]
[-0.0125 .48671 0 4.5 ]
[-0.0125 .60471 -24 -4.5 ]
[-0.0125 .60471 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11819 0 m
.11819 .00625 L
s
[(-400)] .11819 -0.0125 0 1 Mshowa
.30886 0 m
.30886 .00625 L
s
[(-200)] .30886 -0.0125 0 1 Mshowa
.49952 0 m
.49952 .00625 L
s
[(0)] .49952 -0.0125 0 1 Mshowa
.69019 0 m
.69019 .00625 L
s
[(200)] .69019 -0.0125 0 1 Mshowa
.88086 0 m
.88086 .00625 L
s
[(400)] .88086 -0.0125 0 1 Mshowa
.125 Mabswid
.16586 0 m
.16586 .00375 L
s
.21352 0 m
.21352 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.40419 0 m
.40419 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.59486 0 m
.59486 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.78552 0 m
.78552 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.07052 0 m
.07052 .00375 L
s
.02286 0 m
.02286 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13271 m
.00625 .13271 L
s
[(200)] -0.0125 .13271 1 0 Mshowa
0 .25071 m
.00625 .25071 L
s
[(400)] -0.0125 .25071 1 0 Mshowa
0 .36871 m
.00625 .36871 L
s
[(600)] -0.0125 .36871 1 0 Mshowa
0 .48671 m
.00625 .48671 L
s
[(800)] -0.0125 .48671 1 0 Mshowa
0 .60471 m
.00625 .60471 L
s
[(1000)] -0.0125 .60471 1 0 Mshowa
.125 Mabswid
0 .04421 m
.00375 .04421 L
s
0 .07371 m
.00375 .07371 L
s
0 .10321 m
.00375 .10321 L
s
0 .16221 m
.00375 .16221 L
s
0 .19171 m
.00375 .19171 L
s
0 .22121 m
.00375 .22121 L
s
0 .28021 m
.00375 .28021 L
s
0 .30971 m
.00375 .30971 L
s
0 .33921 m
.00375 .33921 L
s
0 .39821 m
.00375 .39821 L
s
0 .42771 m
.00375 .42771 L
s
0 .45721 m
.00375 .45721 L
s
0 .51621 m
.00375 .51621 L
s
0 .54571 m
.00375 .54571 L
s
0 .57521 m
.00375 .57521 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11819 .61178 m
.11819 .61803 L
s
.30886 .61178 m
.30886 .61803 L
s
.49952 .61178 m
.49952 .61803 L
s
.69019 .61178 m
.69019 .61803 L
s
.88086 .61178 m
.88086 .61803 L
s
.125 Mabswid
.16586 .61428 m
.16586 .61803 L
s
.21352 .61428 m
.21352 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.40419 .61428 m
.40419 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.59486 .61428 m
.59486 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.78552 .61428 m
.78552 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.07052 .61428 m
.07052 .61803 L
s
.02286 .61428 m
.02286 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13271 m
1 .13271 L
s
.99375 .25071 m
1 .25071 L
s
.99375 .36871 m
1 .36871 L
s
.99375 .48671 m
1 .48671 L
s
.99375 .60471 m
1 .60471 L
s
.125 Mabswid
.99625 .04421 m
1 .04421 L
s
.99625 .07371 m
1 .07371 L
s
.99625 .10321 m
1 .10321 L
s
.99625 .16221 m
1 .16221 L
s
.99625 .19171 m
1 .19171 L
s
.99625 .22121 m
1 .22121 L
s
.99625 .28021 m
1 .28021 L
s
.99625 .30971 m
1 .30971 L
s
.99625 .33921 m
1 .33921 L
s
.99625 .39821 m
1 .39821 L
s
.99625 .42771 m
1 .42771 L
s
.99625 .45721 m
1 .45721 L
s
.99625 .51621 m
1 .51621 L
s
.99625 .54571 m
1 .54571 L
s
.99625 .57521 m
1 .57521 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01485 L
s
.02476 .01472 m
.02476 .01485 L
s
.02572 .01472 m
.02572 .01485 L
s
.02667 .01472 m
.02667 .01485 L
s
.02762 .01472 m
.02762 .01485 L
s
.02858 .01472 m
.02858 .01485 L
s
.02953 .01472 m
.02953 .01485 L
s
.03048 .01472 m
.03048 .01485 L
s
.03144 .01472 m
.03144 .01485 L
s
.03239 .01472 m
.03239 .01485 L
s
.03334 .01472 m
.03334 .01485 L
s
.0343 .01472 m
.0343 .01485 L
s
.03525 .01472 m
.03525 .01485 L
s
.0362 .01472 m
.0362 .01485 L
s
.03716 .01472 m
.03716 .01485 L
s
.03811 .01472 m
.03811 .01485 L
s
.03906 .01472 m
.03906 .01485 L
s
.04002 .01472 m
.04002 .01485 L
s
.04097 .01472 m
.04097 .01485 L
s
.04192 .01472 m
.04192 .01485 L
s
.04288 .01472 m
.04288 .01485 L
s
.04383 .01472 m
.04383 .01485 L
s
.04478 .01472 m
.04478 .01485 L
s
.04574 .01472 m
.04574 .01485 L
s
.04669 .01472 m
.04669 .01485 L
s
.04764 .01472 m
.04764 .01485 L
s
.0486 .01472 m
.0486 .01485 L
s
.04955 .01472 m
.04955 .01485 L
s
.0505 .01472 m
.0505 .01485 L
s
.05146 .01472 m
.05146 .01485 L
s
.05241 .01472 m
.05241 .01485 L
s
.05336 .01472 m
.05336 .01485 L
s
.05432 .01472 m
.05432 .01485 L
s
.05527 .01472 m
.05527 .01485 L
s
.05622 .01472 m
.05622 .01485 L
s
.05718 .01472 m
.05718 .01485 L
s
.05813 .01472 m
.05813 .01485 L
s
.05908 .01472 m
.05908 .01485 L
s
.06004 .01472 m
.06004 .01485 L
s
.06099 .01472 m
.06099 .01485 L
s
.06194 .01472 m
.06194 .01485 L
s
.0629 .01472 m
.0629 .01485 L
s
.06385 .01472 m
.06385 .01485 L
s
.0648 .01472 m
.0648 .01485 L
s
.06576 .01472 m
.06576 .01485 L
s
.06671 .01472 m
.06671 .01485 L
s
.06766 .01472 m
.06766 .01485 L
s
.06862 .01472 m
.06862 .01485 L
s
.06957 .01472 m
.06957 .01485 L
s
.07052 .01472 m
.07052 .01485 L
s
.07148 .01472 m
.07148 .01485 L
s
.07243 .01472 m
.07243 .01485 L
s
.07338 .01472 m
.07338 .01485 L
s
.07434 .01472 m
.07434 .01485 L
s
.07529 .01472 m
.07529 .01485 L
s
.07624 .01472 m
.07624 .01485 L
s
.0772 .01472 m
.0772 .01485 L
s
.07815 .01472 m
.07815 .01485 L
s
.0791 .01472 m
.0791 .01485 L
s
.08006 .01472 m
.08006 .01485 L
s
.08101 .01472 m
.08101 .01485 L
s
.08196 .01472 m
.08196 .01485 L
s
.08292 .01472 m
.08292 .01485 L
s
.08387 .01472 m
.08387 .01485 L
s
.08482 .01472 m
.08482 .01485 L
s
.08578 .01472 m
.08578 .01485 L
s
.08673 .01472 m
.08673 .01485 L
s
.08768 .01472 m
.08768 .01485 L
s
.08864 .01472 m
.08864 .01485 L
s
.08959 .01472 m
.08959 .01485 L
s
.09054 .01472 m
.09054 .01485 L
s
.0915 .01472 m
.0915 .01485 L
s
.09245 .01472 m
.09245 .01485 L
s
.0934 .01472 m
.0934 .01485 L
s
.09436 .01472 m
.09436 .01485 L
s
.09531 .01472 m
.09531 .01485 L
s
.09626 .01472 m
.09626 .01485 L
s
.09722 .01472 m
.09722 .01485 L
s
.09817 .01472 m
.09817 .01485 L
s
.09912 .01472 m
.09912 .01485 L
s
.10008 .01472 m
.10008 .01485 L
s
.10103 .01472 m
.10103 .01485 L
s
.10198 .01472 m
.10198 .01485 L
s
.10294 .01472 m
.10294 .01485 L
s
.10389 .01472 m
.10389 .01485 L
s
.10484 .01472 m
.10484 .01485 L
s
.1058 .01472 m
.1058 .01485 L
s
.10675 .01472 m
.10675 .01485 L
s
.1077 .01472 m
.1077 .01485 L
s
.10866 .01472 m
.10866 .01485 L
s
.10961 .01472 m
.10961 .01485 L
s
.11056 .01472 m
.11056 .01485 L
s
.11152 .01472 m
.11152 .01485 L
s
.11247 .01472 m
.11247 .01485 L
s
.11342 .01472 m
.11342 .01485 L
s
.11438 .01472 m
.11438 .01485 L
s
.11533 .01472 m
.11533 .01485 L
s
.11628 .01472 m
.11628 .01485 L
s
.11724 .01472 m
.11724 .01485 L
s
.11819 .01472 m
.11819 .01485 L
s
.11914 .01472 m
.11914 .01485 L
s
.1201 .01472 m
.1201 .01485 L
s
.12105 .01472 m
.12105 .01485 L
s
.122 .01472 m
.122 .01485 L
s
.12296 .01472 m
.12296 .01485 L
s
.12391 .01472 m
.12391 .01485 L
s
.12486 .01472 m
.12486 .01485 L
s
.12582 .01472 m
.12582 .01485 L
s
.12677 .01472 m
.12677 .01485 L
s
.12772 .01472 m
.12772 .01485 L
s
.12868 .01472 m
.12868 .01485 L
s
.12963 .01472 m
.12963 .01485 L
s
.13058 .01472 m
.13058 .01485 L
s
.13154 .01472 m
.13154 .01485 L
s
.13249 .01472 m
.13249 .01485 L
s
.13344 .01472 m
.13344 .01485 L
s
.1344 .01472 m
.1344 .01485 L
s
.13535 .01472 m
.13535 .01485 L
s
.1363 .01472 m
.1363 .01486 L
s
.13726 .01472 m
.13726 .01486 L
s
.13821 .01472 m
.13821 .01486 L
s
.13916 .01472 m
.13916 .01486 L
s
.14012 .01472 m
.14012 .01486 L
s
.14107 .01472 m
.14107 .01486 L
s
.14202 .01472 m
.14202 .01486 L
s
.14298 .01472 m
.14298 .01486 L
s
.14393 .01472 m
.14393 .01486 L
s
.14488 .01472 m
.14488 .01486 L
s
.14584 .01472 m
.14584 .01486 L
s
.14679 .01472 m
.14679 .01486 L
s
.14774 .01472 m
.14774 .01486 L
s
.1487 .01472 m
.1487 .01486 L
s
.14965 .01472 m
.14965 .01486 L
s
.1506 .01472 m
.1506 .01486 L
s
.15156 .01472 m
.15156 .01486 L
s
.15251 .01472 m
.15251 .01486 L
s
.15346 .01472 m
.15346 .01486 L
s
.15442 .01472 m
.15442 .01486 L
s
.15537 .01472 m
.15537 .01486 L
s
.15632 .01472 m
.15632 .01486 L
s
.15728 .01472 m
.15728 .01486 L
s
.15823 .01472 m
.15823 .01486 L
s
.15918 .01472 m
.15918 .01486 L
s
.16014 .01472 m
.16014 .01486 L
s
.16109 .01472 m
.16109 .01486 L
s
.16204 .01472 m
.16204 .01486 L
s
.163 .01472 m
.163 .01486 L
s
.16395 .01472 m
.16395 .01486 L
s
.1649 .01472 m
.1649 .01486 L
s
.16586 .01472 m
.16586 .01486 L
s
.16681 .01472 m
.16681 .01486 L
s
.16776 .01472 m
.16776 .01486 L
s
.16872 .01472 m
.16872 .01486 L
s
.16967 .01472 m
.16967 .01486 L
s
.17062 .01472 m
.17062 .01486 L
s
.17158 .01472 m
.17158 .01486 L
s
.17253 .01472 m
.17253 .01486 L
s
.17348 .01472 m
.17348 .01486 L
s
.17444 .01472 m
.17444 .01486 L
s
.17539 .01472 m
.17539 .01486 L
s
.17634 .01472 m
.17634 .01486 L
s
.1773 .01472 m
.1773 .01486 L
s
.17825 .01472 m
.17825 .01486 L
s
.1792 .01472 m
.1792 .01487 L
s
.18016 .01472 m
.18016 .01487 L
s
.18111 .01472 m
.18111 .01487 L
s
.18206 .01472 m
.18206 .01487 L
s
.18302 .01472 m
.18302 .01487 L
s
.18397 .01472 m
.18397 .01487 L
s
.18492 .01472 m
.18492 .01487 L
s
.18588 .01472 m
.18588 .01487 L
s
.18683 .01472 m
.18683 .01487 L
s
.18778 .01472 m
.18778 .01487 L
s
.18874 .01472 m
.18874 .01487 L
s
.18969 .01472 m
.18969 .01487 L
s
.19064 .01472 m
.19064 .01487 L
s
.1916 .01472 m
.1916 .01487 L
s
.19255 .01472 m
.19255 .01487 L
s
.1935 .01472 m
.1935 .01487 L
s
.19446 .01472 m
.19446 .01487 L
s
.19541 .01472 m
.19541 .01487 L
s
.19636 .01472 m
.19636 .01487 L
s
.19732 .01472 m
.19732 .01487 L
s
.19827 .01472 m
.19827 .01487 L
s
.19922 .01472 m
.19922 .01487 L
s
.20018 .01472 m
.20018 .01487 L
s
.20113 .01472 m
.20113 .01487 L
s
.20208 .01472 m
.20208 .01487 L
s
.20304 .01472 m
.20304 .01487 L
s
.20399 .01472 m
.20399 .01487 L
s
.20494 .01472 m
.20494 .01487 L
s
.2059 .01472 m
.2059 .01487 L
s
.20685 .01472 m
.20685 .01487 L
s
.2078 .01472 m
.2078 .01487 L
s
.20876 .01472 m
.20876 .01487 L
s
.20971 .01472 m
.20971 .01488 L
s
.21066 .01472 m
.21066 .01488 L
s
.21162 .01472 m
.21162 .01488 L
s
.21257 .01472 m
.21257 .01488 L
s
.21352 .01472 m
.21352 .01488 L
s
.21448 .01472 m
.21448 .01488 L
s
.21543 .01472 m
.21543 .01488 L
s
.21638 .01472 m
.21638 .01488 L
s
.21734 .01472 m
.21734 .01488 L
s
.21829 .01472 m
.21829 .01488 L
s
.21924 .01472 m
.21924 .01488 L
s
.2202 .01472 m
.2202 .01488 L
s
.22115 .01472 m
.22115 .01488 L
s
.2221 .01472 m
.2221 .01488 L
s
.22306 .01472 m
.22306 .01488 L
s
.22401 .01472 m
.22401 .01488 L
s
.22496 .01472 m
.22496 .01488 L
s
.22592 .01472 m
.22592 .01488 L
s
.22687 .01472 m
.22687 .01488 L
s
.22782 .01472 m
.22782 .01488 L
s
.22878 .01472 m
.22878 .01488 L
s
.22973 .01472 m
.22973 .01488 L
s
.23068 .01472 m
.23068 .01488 L
s
.23164 .01472 m
.23164 .01488 L
s
.23259 .01472 m
.23259 .01489 L
s
.23354 .01472 m
.23354 .01489 L
s
.2345 .01472 m
.2345 .01489 L
s
.23545 .01472 m
.23545 .01489 L
s
.2364 .01472 m
.2364 .01489 L
s
.23736 .01472 m
.23736 .01489 L
s
.23831 .01472 m
.23831 .01489 L
s
.23926 .01472 m
.23926 .01489 L
s
.24022 .01472 m
.24022 .01489 L
s
.24117 .01472 m
.24117 .01489 L
s
.24212 .01472 m
.24212 .01489 L
s
.24308 .01472 m
.24308 .01489 L
s
.24403 .01472 m
.24403 .01489 L
s
.24498 .01472 m
.24498 .01489 L
s
.24594 .01472 m
.24594 .01489 L
s
.24689 .01472 m
.24689 .01489 L
s
.24784 .01472 m
.24784 .01489 L
s
.2488 .01472 m
.2488 .01489 L
s
.24975 .01472 m
.24975 .01489 L
s
.2507 .01472 m
.2507 .01489 L
s
.25166 .01472 m
.25166 .01489 L
s
.25261 .01472 m
.25261 .0149 L
s
.25356 .01472 m
.25356 .0149 L
s
.25452 .01472 m
.25452 .0149 L
s
.25547 .01472 m
.25547 .0149 L
s
.25642 .01472 m
.25642 .0149 L
s
.25738 .01472 m
.25738 .0149 L
s
.25833 .01472 m
.25833 .0149 L
s
.25928 .01472 m
.25928 .0149 L
s
.26024 .01472 m
.26024 .0149 L
s
.26119 .01472 m
.26119 .0149 L
s
.26214 .01472 m
.26214 .0149 L
s
.2631 .01472 m
.2631 .0149 L
s
.26405 .01472 m
.26405 .0149 L
s
.265 .01472 m
.265 .0149 L
s
.26596 .01472 m
.26596 .0149 L
s
.26691 .01472 m
.26691 .0149 L
s
.26786 .01472 m
.26786 .01491 L
s
.26882 .01472 m
.26882 .01491 L
s
.26977 .01472 m
.26977 .01491 L
s
.27072 .01472 m
.27072 .01491 L
s
.27168 .01472 m
.27168 .01491 L
s
.27263 .01472 m
.27263 .01491 L
s
.27358 .01472 m
.27358 .01491 L
s
.27454 .01472 m
.27454 .01491 L
s
.27549 .01472 m
.27549 .01491 L
s
.27644 .01472 m
.27644 .01491 L
s
.2774 .01472 m
.2774 .01491 L
s
.27835 .01472 m
.27835 .01491 L
s
.2793 .01472 m
.2793 .01491 L
s
.28026 .01472 m
.28026 .01491 L
s
.28121 .01472 m
.28121 .01491 L
s
.28216 .01472 m
.28216 .01492 L
s
.28312 .01472 m
.28312 .01492 L
s
.28407 .01472 m
.28407 .01492 L
s
.28502 .01472 m
.28502 .01492 L
s
.28598 .01472 m
.28598 .01492 L
s
.28693 .01472 m
.28693 .01492 L
s
.28788 .01472 m
.28788 .01492 L
s
.28884 .01472 m
.28884 .01492 L
s
.28979 .01472 m
.28979 .01492 L
s
.29074 .01472 m
.29074 .01492 L
s
.2917 .01472 m
.2917 .01492 L
s
.29265 .01472 m
.29265 .01492 L
s
.2936 .01472 m
.2936 .01493 L
s
.29456 .01472 m
.29456 .01493 L
s
.29551 .01472 m
.29551 .01493 L
s
.29646 .01472 m
.29646 .01493 L
s
.29742 .01472 m
.29742 .01493 L
s
.29837 .01472 m
.29837 .01493 L
s
.29932 .01472 m
.29932 .01493 L
s
.30028 .01472 m
.30028 .01493 L
s
.30123 .01472 m
.30123 .01493 L
s
.30218 .01472 m
.30218 .01493 L
s
.30314 .01472 m
.30314 .01493 L
s
.30409 .01472 m
.30409 .01494 L
s
.30504 .01472 m
.30504 .01494 L
s
.306 .01472 m
.306 .01494 L
s
.30695 .01472 m
.30695 .01494 L
s
.3079 .01472 m
.3079 .01494 L
s
.30886 .01472 m
.30886 .01494 L
s
.30981 .01472 m
.30981 .01494 L
s
.31076 .01472 m
.31076 .01494 L
s
.31172 .01472 m
.31172 .01494 L
s
.31267 .01472 m
.31267 .01494 L
s
.31362 .01472 m
.31362 .01495 L
s
.31458 .01472 m
.31458 .01495 L
s
.31553 .01472 m
.31553 .01495 L
s
.31648 .01472 m
.31648 .01495 L
s
.31744 .01472 m
.31744 .01495 L
s
.31839 .01472 m
.31839 .01495 L
s
.31934 .01472 m
.31934 .01495 L
s
.3203 .01472 m
.3203 .01495 L
s
.32125 .01472 m
.32125 .01495 L
s
.3222 .01472 m
.3222 .01496 L
s
.32316 .01472 m
.32316 .01496 L
s
.32411 .01472 m
.32411 .01496 L
s
.32506 .01472 m
.32506 .01496 L
s
.32602 .01472 m
.32602 .01496 L
s
.32697 .01472 m
.32697 .01496 L
s
.32792 .01472 m
.32792 .01496 L
s
.32888 .01472 m
.32888 .01496 L
s
.32983 .01472 m
.32983 .01497 L
s
.33078 .01472 m
.33078 .01497 L
s
.33174 .01472 m
.33174 .01497 L
s
.33269 .01472 m
.33269 .01497 L
s
.33364 .01472 m
.33364 .01497 L
s
.3346 .01472 m
.3346 .01497 L
s
.33555 .01472 m
.33555 .01497 L
s
.3365 .01472 m
.3365 .01498 L
s
.33746 .01472 m
.33746 .01498 L
s
.33841 .01472 m
.33841 .01498 L
s
.33936 .01472 m
.33936 .01498 L
s
.34032 .01472 m
.34032 .01498 L
s
.34127 .01472 m
.34127 .01498 L
s
.34222 .01472 m
.34222 .01498 L
s
.34318 .01472 m
.34318 .01499 L
s
.34413 .01472 m
.34413 .01499 L
s
.34508 .01472 m
.34508 .01499 L
s
.34604 .01472 m
.34604 .01499 L
s
.34699 .01472 m
.34699 .01499 L
s
.34794 .01472 m
.34794 .01499 L
s
.3489 .01472 m
.3489 .015 L
s
.34985 .01472 m
.34985 .015 L
s
.3508 .01472 m
.3508 .015 L
s
.35176 .01472 m
.35176 .015 L
s
.35271 .01472 m
.35271 .015 L
s
.35366 .01472 m
.35366 .01501 L
s
.35462 .01472 m
.35462 .01501 L
s
.35557 .01472 m
.35557 .01501 L
s
.35652 .01472 m
.35652 .01501 L
s
.35748 .01472 m
.35748 .01501 L
s
.35843 .01472 m
.35843 .01501 L
s
.35938 .01472 m
.35938 .01502 L
s
.36034 .01472 m
.36034 .01502 L
s
.36129 .01472 m
.36129 .01502 L
s
.36224 .01472 m
.36224 .01502 L
s
.3632 .01472 m
.3632 .01503 L
s
.36415 .01472 m
.36415 .01503 L
s
.3651 .01472 m
.3651 .01503 L
s
.36606 .01472 m
.36606 .01503 L
s
.36701 .01472 m
.36701 .01503 L
s
.36796 .01472 m
.36796 .01504 L
s
.36892 .01472 m
.36892 .01504 L
s
.36987 .01472 m
.36987 .01504 L
s
.37082 .01472 m
.37082 .01504 L
s
.37178 .01472 m
.37178 .01505 L
s
.37273 .01472 m
.37273 .01505 L
s
.37368 .01472 m
.37368 .01505 L
s
.37464 .01472 m
.37464 .01505 L
s
.37559 .01472 m
.37559 .01506 L
s
.37654 .01472 m
.37654 .01506 L
s
.3775 .01472 m
.3775 .01506 L
s
.37845 .01472 m
.37845 .01507 L
s
.3794 .01472 m
.3794 .01507 L
s
.38036 .01472 m
.38036 .01507 L
s
.38131 .01472 m
.38131 .01507 L
s
.38226 .01472 m
.38226 .01508 L
s
.38322 .01472 m
.38322 .01508 L
s
.38417 .01472 m
.38417 .01508 L
s
.38512 .01472 m
.38512 .01509 L
s
.38608 .01472 m
.38608 .01509 L
s
.38703 .01472 m
.38703 .01509 L
s
.38798 .01472 m
.38798 .0151 L
s
.38894 .01472 m
.38894 .0151 L
s
.38989 .01472 m
.38989 .0151 L
s
.39084 .01472 m
.39084 .01511 L
s
.3918 .01472 m
.3918 .01511 L
s
.39275 .01472 m
.39275 .01512 L
s
.3937 .01472 m
.3937 .01512 L
s
.39466 .01472 m
.39466 .01512 L
s
.39561 .01472 m
.39561 .01513 L
s
.39656 .01472 m
.39656 .01513 L
s
.39752 .01472 m
.39752 .01514 L
s
.39847 .01472 m
.39847 .01514 L
s
.39942 .01472 m
.39942 .01515 L
s
.40038 .01472 m
.40038 .01515 L
s
.40133 .01472 m
.40133 .01516 L
s
.40228 .01472 m
.40228 .01516 L
s
.40324 .01472 m
.40324 .01517 L
s
.40419 .01472 m
.40419 .01517 L
s
.40514 .01472 m
.40514 .01518 L
s
.4061 .01472 m
.4061 .01518 L
s
.40705 .01472 m
.40705 .01519 L
s
.408 .01472 m
.408 .01519 L
s
.40896 .01472 m
.40896 .0152 L
s
.40991 .01472 m
.40991 .0152 L
s
.41086 .01472 m
.41086 .01521 L
s
.41182 .01472 m
.41182 .01522 L
s
.41277 .01472 m
.41277 .01522 L
s
.41372 .01472 m
.41372 .01523 L
s
.41468 .01472 m
.41468 .01524 L
s
.41563 .01472 m
.41563 .01524 L
s
.41658 .01472 m
.41658 .01525 L
s
.41754 .01472 m
.41754 .01526 L
s
.41849 .01472 m
.41849 .01527 L
s
.41944 .01472 m
.41944 .01528 L
s
.4204 .01472 m
.4204 .01528 L
s
.42135 .01472 m
.42135 .01529 L
s
.4223 .01472 m
.4223 .0153 L
s
.42326 .01472 m
.42326 .01531 L
s
.42421 .01472 m
.42421 .01532 L
s
.42516 .01472 m
.42516 .01533 L
s
.42612 .01472 m
.42612 .01534 L
s
.42707 .01472 m
.42707 .01535 L
s
.42802 .01472 m
.42802 .01536 L
s
.42898 .01472 m
.42898 .01537 L
s
.42993 .01472 m
.42993 .01539 L
s
.43088 .01472 m
.43088 .0154 L
s
.43184 .01472 m
.43184 .01541 L
s
.43279 .01472 m
.43279 .01543 L
s
.43374 .01472 m
.43374 .01544 L
s
.4347 .01472 m
.4347 .01545 L
s
.43565 .01472 m
.43565 .01547 L
s
.4366 .01472 m
.4366 .01549 L
s
.43756 .01472 m
.43756 .0155 L
s
.43851 .01472 m
.43851 .01552 L
s
.43946 .01472 m
.43946 .01554 L
s
.44042 .01472 m
.44042 .01556 L
s
.44137 .01472 m
.44137 .01558 L
s
.44232 .01472 m
.44232 .01561 L
s
.44328 .01472 m
.44328 .01563 L
s
.44423 .01472 m
.44423 .01566 L
s
.44518 .01472 m
.44518 .01569 L
s
.44614 .01472 m
.44614 .01571 L
s
.44709 .01472 m
.44709 .01575 L
s
.44804 .01472 m
.44804 .01578 L
s
.449 .01472 m
.449 .01582 L
s
.44995 .01472 m
.44995 .01586 L
s
.4509 .01472 m
.4509 .0159 L
s
.45186 .01472 m
.45186 .01595 L
s
.45281 .01472 m
.45281 .016 L
s
.45376 .01472 m
.45376 .01606 L
s
.45472 .01472 m
.45472 .01612 L
s
.45567 .01472 m
.45567 .01619 L
s
.45662 .01472 m
.45662 .01627 L
s
.45758 .01472 m
.45758 .01636 L
s
.45853 .01472 m
.45853 .01647 L
s
.45948 .01472 m
.45948 .01659 L
s
.46044 .01472 m
.46044 .01673 L
s
.46139 .01472 m
.46139 .0169 L
s
.46234 .01472 m
.46234 .01711 L
s
.4633 .01472 m
.4633 .01736 L
s
.46425 .01472 m
.46425 .01769 L
s
.4652 .01472 m
.4652 .01813 L
s
.46616 .01472 m
.46616 .01873 L
s
.46711 .01472 m
.46711 .01964 L
s
.46806 .01472 m
.46806 .02115 L
s
.46902 .01472 m
.46902 .02419 L
s
.46997 .01472 m
.46997 .03346 L
s
.47092 .01472 m
.47092 .60332 L
s
.47188 .01472 m
.47188 .03136 L
s
.47283 .01472 m
.47283 .02288 L
s
.47378 .01472 m
.47378 .01999 L
s
.47474 .01472 m
.47474 .01852 L
s
.47569 .01472 m
.47569 .01763 L
s
.47664 .01472 m
.47664 .01702 L
s
.4776 .01472 m
.4776 .01658 L
s
.47855 .01472 m
.47855 .01624 L
s
.4795 .01472 m
.4795 .01596 L
s
.48046 .01472 m
.48046 .01573 L
s
.48141 .01472 m
.48141 .01553 L
s
.48236 .01472 m
.48236 .01534 L
s
.48332 .01472 m
.48332 .01516 L
s
.48427 .01472 m
.48427 .01498 L
s
.48522 .01472 m
.48522 .01479 L
s
.48618 .01472 m
.48618 .01488 L
s
.48713 .01472 m
.48713 .0152 L
s
.48808 .01472 m
.48808 .01577 L
s
.48904 .01472 m
.48904 .01734 L
s
.48999 .01472 m
.48999 .30996 L
s
.49094 .01472 m
.49094 .01787 L
s
.4919 .01472 m
.4919 .01636 L
s
.49285 .01472 m
.49285 .01581 L
s
.4938 .01472 m
.4938 .01551 L
s
.49476 .01472 m
.49476 .01531 L
s
.49571 .01472 m
.49571 .01516 L
s
.49666 .01472 m
.49666 .01503 L
s
.49762 .01472 m
.49762 .01492 L
s
.49857 .01472 m
.49857 .01481 L
s
.49952 .01472 m
.49952 .01472 L
s
.50048 .01472 m
.50048 .01481 L
s
.50143 .01472 m
.50143 .01492 L
s
.50238 .01472 m
.50238 .01503 L
s
.50334 .01472 m
.50334 .01516 L
s
.50429 .01472 m
.50429 .01531 L
s
.50524 .01472 m
.50524 .01551 L
s
.5062 .01472 m
.5062 .01581 L
s
.50715 .01472 m
.50715 .01636 L
s
.5081 .01472 m
.5081 .01787 L
s
.50906 .01472 m
.50906 .30996 L
s
.51001 .01472 m
.51001 .01734 L
s
.51096 .01472 m
.51096 .01577 L
s
.51192 .01472 m
.51192 .0152 L
s
.51287 .01472 m
.51287 .01488 L
s
.51382 .01472 m
.51382 .01479 L
s
.51478 .01472 m
.51478 .01498 L
s
.51573 .01472 m
.51573 .01516 L
s
.51668 .01472 m
.51668 .01534 L
s
.51764 .01472 m
.51764 .01553 L
s
.51859 .01472 m
.51859 .01573 L
s
.51954 .01472 m
.51954 .01596 L
s
.5205 .01472 m
.5205 .01624 L
s
.52145 .01472 m
.52145 .01658 L
s
.5224 .01472 m
.5224 .01702 L
s
.52336 .01472 m
.52336 .01763 L
s
.52431 .01472 m
.52431 .01852 L
s
.52526 .01472 m
.52526 .01999 L
s
.52622 .01472 m
.52622 .02288 L
s
.52717 .01472 m
.52717 .03136 L
s
.52812 .01472 m
.52812 .60332 L
s
.52908 .01472 m
.52908 .03346 L
s
.53003 .01472 m
.53003 .02419 L
s
.53098 .01472 m
.53098 .02115 L
s
.53194 .01472 m
.53194 .01964 L
s
.53289 .01472 m
.53289 .01873 L
s
.53384 .01472 m
.53384 .01813 L
s
.5348 .01472 m
.5348 .01769 L
s
.53575 .01472 m
.53575 .01736 L
s
.5367 .01472 m
.5367 .01711 L
s
.53766 .01472 m
.53766 .0169 L
s
.53861 .01472 m
.53861 .01673 L
s
.53956 .01472 m
.53956 .01659 L
s
.54052 .01472 m
.54052 .01647 L
s
.54147 .01472 m
.54147 .01636 L
s
.54242 .01472 m
.54242 .01627 L
s
.54338 .01472 m
.54338 .01619 L
s
.54433 .01472 m
.54433 .01612 L
s
.54528 .01472 m
.54528 .01606 L
s
.54624 .01472 m
.54624 .016 L
s
.54719 .01472 m
.54719 .01595 L
s
.54814 .01472 m
.54814 .0159 L
s
.5491 .01472 m
.5491 .01586 L
s
.55005 .01472 m
.55005 .01582 L
s
.551 .01472 m
.551 .01578 L
s
.55196 .01472 m
.55196 .01575 L
s
.55291 .01472 m
.55291 .01571 L
s
.55386 .01472 m
.55386 .01569 L
s
.55482 .01472 m
.55482 .01566 L
s
.55577 .01472 m
.55577 .01563 L
s
.55672 .01472 m
.55672 .01561 L
s
.55768 .01472 m
.55768 .01558 L
s
.55863 .01472 m
.55863 .01556 L
s
.55958 .01472 m
.55958 .01554 L
s
.56054 .01472 m
.56054 .01552 L
s
.56149 .01472 m
.56149 .0155 L
s
.56244 .01472 m
.56244 .01549 L
s
.5634 .01472 m
.5634 .01547 L
s
.56435 .01472 m
.56435 .01545 L
s
.5653 .01472 m
.5653 .01544 L
s
.56626 .01472 m
.56626 .01543 L
s
.56721 .01472 m
.56721 .01541 L
s
.56816 .01472 m
.56816 .0154 L
s
.56912 .01472 m
.56912 .01539 L
s
.57007 .01472 m
.57007 .01537 L
s
.57102 .01472 m
.57102 .01536 L
s
.57198 .01472 m
.57198 .01535 L
s
.57293 .01472 m
.57293 .01534 L
s
.57388 .01472 m
.57388 .01533 L
s
.57484 .01472 m
.57484 .01532 L
s
.57579 .01472 m
.57579 .01531 L
s
.57674 .01472 m
.57674 .0153 L
s
.5777 .01472 m
.5777 .01529 L
s
.57865 .01472 m
.57865 .01528 L
s
.5796 .01472 m
.5796 .01528 L
s
.58056 .01472 m
.58056 .01527 L
s
.58151 .01472 m
.58151 .01526 L
s
.58246 .01472 m
.58246 .01525 L
s
.58342 .01472 m
.58342 .01524 L
s
.58437 .01472 m
.58437 .01524 L
s
.58532 .01472 m
.58532 .01523 L
s
.58628 .01472 m
.58628 .01522 L
s
.58723 .01472 m
.58723 .01522 L
s
.58818 .01472 m
.58818 .01521 L
s
.58914 .01472 m
.58914 .0152 L
s
.59009 .01472 m
.59009 .0152 L
s
.59104 .01472 m
.59104 .01519 L
s
.592 .01472 m
.592 .01519 L
s
.59295 .01472 m
.59295 .01518 L
s
.5939 .01472 m
.5939 .01518 L
s
.59486 .01472 m
.59486 .01517 L
s
.59581 .01472 m
.59581 .01517 L
s
.59676 .01472 m
.59676 .01516 L
s
.59772 .01472 m
.59772 .01516 L
s
.59867 .01472 m
.59867 .01515 L
s
.59962 .01472 m
.59962 .01515 L
s
.60058 .01472 m
.60058 .01514 L
s
.60153 .01472 m
.60153 .01514 L
s
.60248 .01472 m
.60248 .01513 L
s
.60344 .01472 m
.60344 .01513 L
s
.60439 .01472 m
.60439 .01512 L
s
.60534 .01472 m
.60534 .01512 L
s
.6063 .01472 m
.6063 .01512 L
s
.60725 .01472 m
.60725 .01511 L
s
.6082 .01472 m
.6082 .01511 L
s
.60916 .01472 m
.60916 .0151 L
s
.61011 .01472 m
.61011 .0151 L
s
.61106 .01472 m
.61106 .0151 L
s
.61202 .01472 m
.61202 .01509 L
s
.61297 .01472 m
.61297 .01509 L
s
.61392 .01472 m
.61392 .01509 L
s
.61488 .01472 m
.61488 .01508 L
s
.61583 .01472 m
.61583 .01508 L
s
.61678 .01472 m
.61678 .01508 L
s
.61774 .01472 m
.61774 .01507 L
s
.61869 .01472 m
.61869 .01507 L
s
.61964 .01472 m
.61964 .01507 L
s
.6206 .01472 m
.6206 .01507 L
s
.62155 .01472 m
.62155 .01506 L
s
.6225 .01472 m
.6225 .01506 L
s
.62346 .01472 m
.62346 .01506 L
s
.62441 .01472 m
.62441 .01505 L
s
.62536 .01472 m
.62536 .01505 L
s
.62632 .01472 m
.62632 .01505 L
s
.62727 .01472 m
.62727 .01505 L
s
.62822 .01472 m
.62822 .01504 L
s
.62918 .01472 m
.62918 .01504 L
s
.63013 .01472 m
.63013 .01504 L
s
.63108 .01472 m
.63108 .01504 L
s
.63204 .01472 m
.63204 .01503 L
s
.63299 .01472 m
.63299 .01503 L
s
.63394 .01472 m
.63394 .01503 L
s
.6349 .01472 m
.6349 .01503 L
s
.63585 .01472 m
.63585 .01503 L
s
.6368 .01472 m
.6368 .01502 L
s
.63776 .01472 m
.63776 .01502 L
s
.63871 .01472 m
.63871 .01502 L
s
.63966 .01472 m
.63966 .01502 L
s
.64062 .01472 m
.64062 .01501 L
s
.64157 .01472 m
.64157 .01501 L
s
.64252 .01472 m
.64252 .01501 L
s
.64348 .01472 m
.64348 .01501 L
s
.64443 .01472 m
.64443 .01501 L
s
.64538 .01472 m
.64538 .01501 L
s
.64634 .01472 m
.64634 .015 L
s
.64729 .01472 m
.64729 .015 L
s
.64824 .01472 m
.64824 .015 L
s
.6492 .01472 m
.6492 .015 L
s
.65015 .01472 m
.65015 .015 L
s
.6511 .01472 m
.6511 .01499 L
s
.65206 .01472 m
.65206 .01499 L
s
.65301 .01472 m
.65301 .01499 L
s
.65396 .01472 m
.65396 .01499 L
s
.65492 .01472 m
.65492 .01499 L
s
.65587 .01472 m
.65587 .01499 L
s
.65682 .01472 m
.65682 .01498 L
s
.65778 .01472 m
.65778 .01498 L
s
.65873 .01472 m
.65873 .01498 L
s
.65968 .01472 m
.65968 .01498 L
s
.66064 .01472 m
.66064 .01498 L
s
.66159 .01472 m
.66159 .01498 L
s
.66254 .01472 m
.66254 .01498 L
s
.6635 .01472 m
.6635 .01497 L
s
.66445 .01472 m
.66445 .01497 L
s
.6654 .01472 m
.6654 .01497 L
s
.66636 .01472 m
.66636 .01497 L
s
.66731 .01472 m
.66731 .01497 L
s
.66826 .01472 m
.66826 .01497 L
s
.66922 .01472 m
.66922 .01497 L
s
.67017 .01472 m
.67017 .01496 L
s
.67112 .01472 m
.67112 .01496 L
s
.67208 .01472 m
.67208 .01496 L
s
.67303 .01472 m
.67303 .01496 L
s
.67398 .01472 m
.67398 .01496 L
s
.67494 .01472 m
.67494 .01496 L
s
.67589 .01472 m
.67589 .01496 L
s
.67684 .01472 m
.67684 .01496 L
s
.6778 .01472 m
.6778 .01495 L
s
.67875 .01472 m
.67875 .01495 L
s
.6797 .01472 m
.6797 .01495 L
s
.68066 .01472 m
.68066 .01495 L
s
.68161 .01472 m
.68161 .01495 L
s
.68256 .01472 m
.68256 .01495 L
s
.68352 .01472 m
.68352 .01495 L
s
.68447 .01472 m
.68447 .01495 L
s
.68542 .01472 m
.68542 .01495 L
s
.68638 .01472 m
.68638 .01494 L
s
.68733 .01472 m
.68733 .01494 L
s
.68828 .01472 m
.68828 .01494 L
s
.68924 .01472 m
.68924 .01494 L
s
.69019 .01472 m
.69019 .01494 L
s
.69114 .01472 m
.69114 .01494 L
s
.6921 .01472 m
.6921 .01494 L
s
.69305 .01472 m
.69305 .01494 L
s
.694 .01472 m
.694 .01494 L
s
.69496 .01472 m
.69496 .01494 L
s
.69591 .01472 m
.69591 .01493 L
s
.69686 .01472 m
.69686 .01493 L
s
.69782 .01472 m
.69782 .01493 L
s
.69877 .01472 m
.69877 .01493 L
s
.69972 .01472 m
.69972 .01493 L
s
.70068 .01472 m
.70068 .01493 L
s
.70163 .01472 m
.70163 .01493 L
s
.70258 .01472 m
.70258 .01493 L
s
.70354 .01472 m
.70354 .01493 L
s
.70449 .01472 m
.70449 .01493 L
s
.70544 .01472 m
.70544 .01493 L
s
.7064 .01472 m
.7064 .01492 L
s
.70735 .01472 m
.70735 .01492 L
s
.7083 .01472 m
.7083 .01492 L
s
.70926 .01472 m
.70926 .01492 L
s
.71021 .01472 m
.71021 .01492 L
s
.71116 .01472 m
.71116 .01492 L
s
.71212 .01472 m
.71212 .01492 L
s
.71307 .01472 m
.71307 .01492 L
s
.71402 .01472 m
.71402 .01492 L
s
.71498 .01472 m
.71498 .01492 L
s
.71593 .01472 m
.71593 .01492 L
s
.71688 .01472 m
.71688 .01492 L
s
.71784 .01472 m
.71784 .01491 L
s
.71879 .01472 m
.71879 .01491 L
s
.71974 .01472 m
.71974 .01491 L
s
.7207 .01472 m
.7207 .01491 L
s
.72165 .01472 m
.72165 .01491 L
s
.7226 .01472 m
.7226 .01491 L
s
.72356 .01472 m
.72356 .01491 L
s
.72451 .01472 m
.72451 .01491 L
s
.72546 .01472 m
.72546 .01491 L
s
.72642 .01472 m
.72642 .01491 L
s
.72737 .01472 m
.72737 .01491 L
s
.72832 .01472 m
.72832 .01491 L
s
.72928 .01472 m
.72928 .01491 L
s
.73023 .01472 m
.73023 .01491 L
s
.73118 .01472 m
.73118 .01491 L
s
.73214 .01472 m
.73214 .0149 L
s
.73309 .01472 m
.73309 .0149 L
s
.73404 .01472 m
.73404 .0149 L
s
.735 .01472 m
.735 .0149 L
s
.73595 .01472 m
.73595 .0149 L
s
.7369 .01472 m
.7369 .0149 L
s
.73786 .01472 m
.73786 .0149 L
s
.73881 .01472 m
.73881 .0149 L
s
.73976 .01472 m
.73976 .0149 L
s
.74072 .01472 m
.74072 .0149 L
s
.74167 .01472 m
.74167 .0149 L
s
.74262 .01472 m
.74262 .0149 L
s
.74358 .01472 m
.74358 .0149 L
s
.74453 .01472 m
.74453 .0149 L
s
.74548 .01472 m
.74548 .0149 L
s
.74644 .01472 m
.74644 .0149 L
s
.74739 .01472 m
.74739 .01489 L
s
.74834 .01472 m
.74834 .01489 L
s
.7493 .01472 m
.7493 .01489 L
s
.75025 .01472 m
.75025 .01489 L
s
.7512 .01472 m
.7512 .01489 L
s
.75216 .01472 m
.75216 .01489 L
s
.75311 .01472 m
.75311 .01489 L
s
.75406 .01472 m
.75406 .01489 L
s
.75502 .01472 m
.75502 .01489 L
s
.75597 .01472 m
.75597 .01489 L
s
.75692 .01472 m
.75692 .01489 L
s
.75788 .01472 m
.75788 .01489 L
s
.75883 .01472 m
.75883 .01489 L
s
.75978 .01472 m
.75978 .01489 L
s
.76074 .01472 m
.76074 .01489 L
s
.76169 .01472 m
.76169 .01489 L
s
.76264 .01472 m
.76264 .01489 L
s
.7636 .01472 m
.7636 .01489 L
s
.76455 .01472 m
.76455 .01489 L
s
.7655 .01472 m
.7655 .01489 L
s
.76646 .01472 m
.76646 .01489 L
s
.76741 .01472 m
.76741 .01488 L
s
.76836 .01472 m
.76836 .01488 L
s
.76932 .01472 m
.76932 .01488 L
s
.77027 .01472 m
.77027 .01488 L
s
.77122 .01472 m
.77122 .01488 L
s
.77218 .01472 m
.77218 .01488 L
s
.77313 .01472 m
.77313 .01488 L
s
.77408 .01472 m
.77408 .01488 L
s
.77504 .01472 m
.77504 .01488 L
s
.77599 .01472 m
.77599 .01488 L
s
.77694 .01472 m
.77694 .01488 L
s
.7779 .01472 m
.7779 .01488 L
s
.77885 .01472 m
.77885 .01488 L
s
.7798 .01472 m
.7798 .01488 L
s
.78076 .01472 m
.78076 .01488 L
s
.78171 .01472 m
.78171 .01488 L
s
.78266 .01472 m
.78266 .01488 L
s
.78362 .01472 m
.78362 .01488 L
s
.78457 .01472 m
.78457 .01488 L
s
.78552 .01472 m
.78552 .01488 L
s
.78648 .01472 m
.78648 .01488 L
s
.78743 .01472 m
.78743 .01488 L
s
.78838 .01472 m
.78838 .01488 L
s
.78934 .01472 m
.78934 .01488 L
s
.79029 .01472 m
.79029 .01487 L
s
.79124 .01472 m
.79124 .01487 L
s
.7922 .01472 m
.7922 .01487 L
s
.79315 .01472 m
.79315 .01487 L
s
.7941 .01472 m
.7941 .01487 L
s
.79506 .01472 m
.79506 .01487 L
s
.79601 .01472 m
.79601 .01487 L
s
.79696 .01472 m
.79696 .01487 L
s
.79792 .01472 m
.79792 .01487 L
s
.79887 .01472 m
.79887 .01487 L
s
.79982 .01472 m
.79982 .01487 L
s
.80078 .01472 m
.80078 .01487 L
s
.80173 .01472 m
.80173 .01487 L
s
.80268 .01472 m
.80268 .01487 L
s
.80364 .01472 m
.80364 .01487 L
s
.80459 .01472 m
.80459 .01487 L
s
.80554 .01472 m
.80554 .01487 L
s
.8065 .01472 m
.8065 .01487 L
s
.80745 .01472 m
.80745 .01487 L
s
.8084 .01472 m
.8084 .01487 L
s
.80936 .01472 m
.80936 .01487 L
s
.81031 .01472 m
.81031 .01487 L
s
.81126 .01472 m
.81126 .01487 L
s
.81222 .01472 m
.81222 .01487 L
s
.81317 .01472 m
.81317 .01487 L
s
.81412 .01472 m
.81412 .01487 L
s
.81508 .01472 m
.81508 .01487 L
s
.81603 .01472 m
.81603 .01487 L
s
.81698 .01472 m
.81698 .01487 L
s
.81794 .01472 m
.81794 .01487 L
s
.81889 .01472 m
.81889 .01487 L
s
.81984 .01472 m
.81984 .01487 L
s
.8208 .01472 m
.8208 .01486 L
s
.82175 .01472 m
.82175 .01486 L
s
.8227 .01472 m
.8227 .01486 L
s
.82366 .01472 m
.82366 .01486 L
s
.82461 .01472 m
.82461 .01486 L
s
.82556 .01472 m
.82556 .01486 L
s
.82652 .01472 m
.82652 .01486 L
s
.82747 .01472 m
.82747 .01486 L
s
.82842 .01472 m
.82842 .01486 L
s
.82938 .01472 m
.82938 .01486 L
s
.83033 .01472 m
.83033 .01486 L
s
.83128 .01472 m
.83128 .01486 L
s
.83224 .01472 m
.83224 .01486 L
s
.83319 .01472 m
.83319 .01486 L
s
.83414 .01472 m
.83414 .01486 L
s
.8351 .01472 m
.8351 .01486 L
s
.83605 .01472 m
.83605 .01486 L
s
.837 .01472 m
.837 .01486 L
s
.83796 .01472 m
.83796 .01486 L
s
.83891 .01472 m
.83891 .01486 L
s
.83986 .01472 m
.83986 .01486 L
s
.84082 .01472 m
.84082 .01486 L
s
.84177 .01472 m
.84177 .01486 L
s
.84272 .01472 m
.84272 .01486 L
s
.84368 .01472 m
.84368 .01486 L
s
.84463 .01472 m
.84463 .01486 L
s
.84558 .01472 m
.84558 .01486 L
s
.84654 .01472 m
.84654 .01486 L
s
.84749 .01472 m
.84749 .01486 L
s
.84844 .01472 m
.84844 .01486 L
s
.8494 .01472 m
.8494 .01486 L
s
.85035 .01472 m
.85035 .01486 L
s
.8513 .01472 m
.8513 .01486 L
s
.85226 .01472 m
.85226 .01486 L
s
.85321 .01472 m
.85321 .01486 L
s
.85416 .01472 m
.85416 .01486 L
s
.85512 .01472 m
.85512 .01486 L
s
.85607 .01472 m
.85607 .01486 L
s
.85702 .01472 m
.85702 .01486 L
s
.85798 .01472 m
.85798 .01486 L
s
.85893 .01472 m
.85893 .01486 L
s
.85988 .01472 m
.85988 .01486 L
s
.86084 .01472 m
.86084 .01486 L
s
.86179 .01472 m
.86179 .01486 L
s
.86274 .01472 m
.86274 .01486 L
s
.8637 .01472 m
.8637 .01485 L
s
.86465 .01472 m
.86465 .01485 L
s
.8656 .01472 m
.8656 .01485 L
s
.86656 .01472 m
.86656 .01485 L
s
.86751 .01472 m
.86751 .01485 L
s
.86846 .01472 m
.86846 .01485 L
s
.86942 .01472 m
.86942 .01485 L
s
.87037 .01472 m
.87037 .01485 L
s
.87132 .01472 m
.87132 .01485 L
s
.87228 .01472 m
.87228 .01485 L
s
.87323 .01472 m
.87323 .01485 L
s
.87418 .01472 m
.87418 .01485 L
s
.87514 .01472 m
.87514 .01485 L
s
.87609 .01472 m
.87609 .01485 L
s
.87704 .01472 m
.87704 .01485 L
s
.878 .01472 m
.878 .01485 L
s
.87895 .01472 m
.87895 .01485 L
s
.8799 .01472 m
.8799 .01485 L
s
.88086 .01472 m
.88086 .01485 L
s
.88181 .01472 m
.88181 .01485 L
s
.88276 .01472 m
.88276 .01485 L
s
.88372 .01472 m
.88372 .01485 L
s
.88467 .01472 m
.88467 .01485 L
s
.88562 .01472 m
.88562 .01485 L
s
.88658 .01472 m
.88658 .01485 L
s
.88753 .01472 m
.88753 .01485 L
s
.88848 .01472 m
.88848 .01485 L
s
.88944 .01472 m
.88944 .01485 L
s
.89039 .01472 m
.89039 .01485 L
s
.89134 .01472 m
.89134 .01485 L
s
.8923 .01472 m
.8923 .01485 L
s
.89325 .01472 m
.89325 .01485 L
s
.8942 .01472 m
.8942 .01485 L
s
.89516 .01472 m
.89516 .01485 L
s
.89611 .01472 m
.89611 .01485 L
s
.89706 .01472 m
.89706 .01485 L
s
.89802 .01472 m
.89802 .01485 L
s
.89897 .01472 m
.89897 .01485 L
s
.89992 .01472 m
.89992 .01485 L
s
.90088 .01472 m
.90088 .01485 L
s
.90183 .01472 m
.90183 .01485 L
s
.90278 .01472 m
.90278 .01485 L
s
.90374 .01472 m
.90374 .01485 L
s
.90469 .01472 m
.90469 .01485 L
s
.90564 .01472 m
.90564 .01485 L
s
.9066 .01472 m
.9066 .01485 L
s
.90755 .01472 m
.90755 .01485 L
s
.9085 .01472 m
.9085 .01485 L
s
.90946 .01472 m
.90946 .01485 L
s
.91041 .01472 m
.91041 .01485 L
s
.91136 .01472 m
.91136 .01485 L
s
.91232 .01472 m
.91232 .01485 L
s
.91327 .01472 m
.91327 .01485 L
s
.91422 .01472 m
.91422 .01485 L
s
.91518 .01472 m
.91518 .01485 L
s
.91613 .01472 m
.91613 .01485 L
s
.91708 .01472 m
.91708 .01485 L
s
.91804 .01472 m
.91804 .01485 L
s
.91899 .01472 m
.91899 .01485 L
s
.91994 .01472 m
.91994 .01485 L
s
.9209 .01472 m
.9209 .01485 L
s
.92185 .01472 m
.92185 .01485 L
s
.9228 .01472 m
.9228 .01485 L
s
.92376 .01472 m
.92376 .01485 L
s
.92471 .01472 m
.92471 .01485 L
s
.92566 .01472 m
.92566 .01485 L
s
.92662 .01472 m
.92662 .01485 L
s
.92757 .01472 m
.92757 .01485 L
s
.92852 .01472 m
.92852 .01485 L
s
.92948 .01472 m
.92948 .01485 L
s
.93043 .01472 m
.93043 .01485 L
s
.93138 .01472 m
.93138 .01485 L
s
.93234 .01472 m
.93234 .01485 L
s
.93329 .01472 m
.93329 .01485 L
s
.93424 .01472 m
.93424 .01485 L
s
.9352 .01472 m
.9352 .01485 L
s
.93615 .01472 m
.93615 .01485 L
s
.9371 .01472 m
.9371 .01485 L
s
.93806 .01472 m
.93806 .01485 L
s
.93901 .01472 m
.93901 .01485 L
s
.93996 .01472 m
.93996 .01485 L
s
.94092 .01472 m
.94092 .01485 L
s
.94187 .01472 m
.94187 .01485 L
s
.94282 .01472 m
.94282 .01485 L
s
.94378 .01472 m
.94378 .01485 L
s
.94473 .01472 m
.94473 .01485 L
s
.94568 .01472 m
.94568 .01485 L
s
.94664 .01472 m
.94664 .01485 L
s
.94759 .01472 m
.94759 .01485 L
s
.94854 .01472 m
.94854 .01485 L
s
.9495 .01472 m
.9495 .01485 L
s
.95045 .01472 m
.95045 .01485 L
s
.9514 .01472 m
.9514 .01485 L
s
.95236 .01472 m
.95236 .01485 L
s
.95331 .01472 m
.95331 .01485 L
s
.95426 .01472 m
.95426 .01485 L
s
.95522 .01472 m
.95522 .01485 L
s
.95617 .01472 m
.95617 .01485 L
s
.95712 .01472 m
.95712 .01485 L
s
.95808 .01472 m
.95808 .01485 L
s
.95903 .01472 m
.95903 .01485 L
s
.95998 .01472 m
.95998 .01485 L
s
.96094 .01472 m
.96094 .01485 L
s
.96189 .01472 m
.96189 .01485 L
s
.96284 .01472 m
.96284 .01485 L
s
.9638 .01472 m
.9638 .01485 L
s
.96475 .01472 m
.96475 .01485 L
s
.9657 .01472 m
.9657 .01485 L
s
.96666 .01472 m
.96666 .01485 L
s
.96761 .01472 m
.96761 .01485 L
s
.96856 .01472 m
.96856 .01485 L
s
.96952 .01472 m
.96952 .01485 L
s
.97047 .01472 m
.97047 .01485 L
s
.97142 .01472 m
.97142 .01485 L
s
.97238 .01472 m
.97238 .01485 L
s
.97333 .01472 m
.97333 .01485 L
s
.97428 .01472 m
.97428 .01485 L
s
.97524 .01472 m
.97524 .01485 L
s
.97619 .01472 m
.97619 .01485 L
s
.015 w
.02381 .01485 Mdot
.02476 .01485 Mdot
.02572 .01485 Mdot
.02667 .01485 Mdot
.02762 .01485 Mdot
.02858 .01485 Mdot
.02953 .01485 Mdot
.03048 .01485 Mdot
.03144 .01485 Mdot
.03239 .01485 Mdot
.03334 .01485 Mdot
.0343 .01485 Mdot
.03525 .01485 Mdot
.0362 .01485 Mdot
.03716 .01485 Mdot
.03811 .01485 Mdot
.03906 .01485 Mdot
.04002 .01485 Mdot
.04097 .01485 Mdot
.04192 .01485 Mdot
.04288 .01485 Mdot
.04383 .01485 Mdot
.04478 .01485 Mdot
.04574 .01485 Mdot
.04669 .01485 Mdot
.04764 .01485 Mdot
.0486 .01485 Mdot
.04955 .01485 Mdot
.0505 .01485 Mdot
.05146 .01485 Mdot
.05241 .01485 Mdot
.05336 .01485 Mdot
.05432 .01485 Mdot
.05527 .01485 Mdot
.05622 .01485 Mdot
.05718 .01485 Mdot
.05813 .01485 Mdot
.05908 .01485 Mdot
.06004 .01485 Mdot
.06099 .01485 Mdot
.06194 .01485 Mdot
.0629 .01485 Mdot
.06385 .01485 Mdot
.0648 .01485 Mdot
.06576 .01485 Mdot
.06671 .01485 Mdot
.06766 .01485 Mdot
.06862 .01485 Mdot
.06957 .01485 Mdot
.07052 .01485 Mdot
.07148 .01485 Mdot
.07243 .01485 Mdot
.07338 .01485 Mdot
.07434 .01485 Mdot
.07529 .01485 Mdot
.07624 .01485 Mdot
.0772 .01485 Mdot
.07815 .01485 Mdot
.0791 .01485 Mdot
.08006 .01485 Mdot
.08101 .01485 Mdot
.08196 .01485 Mdot
.08292 .01485 Mdot
.08387 .01485 Mdot
.08482 .01485 Mdot
.08578 .01485 Mdot
.08673 .01485 Mdot
.08768 .01485 Mdot
.08864 .01485 Mdot
.08959 .01485 Mdot
.09054 .01485 Mdot
.0915 .01485 Mdot
.09245 .01485 Mdot
.0934 .01485 Mdot
.09436 .01485 Mdot
.09531 .01485 Mdot
.09626 .01485 Mdot
.09722 .01485 Mdot
.09817 .01485 Mdot
.09912 .01485 Mdot
.10008 .01485 Mdot
.10103 .01485 Mdot
.10198 .01485 Mdot
.10294 .01485 Mdot
.10389 .01485 Mdot
.10484 .01485 Mdot
.1058 .01485 Mdot
.10675 .01485 Mdot
.1077 .01485 Mdot
.10866 .01485 Mdot
.10961 .01485 Mdot
.11056 .01485 Mdot
.11152 .01485 Mdot
.11247 .01485 Mdot
.11342 .01485 Mdot
.11438 .01485 Mdot
.11533 .01485 Mdot
.11628 .01485 Mdot
.11724 .01485 Mdot
.11819 .01485 Mdot
.11914 .01485 Mdot
.1201 .01485 Mdot
.12105 .01485 Mdot
.122 .01485 Mdot
.12296 .01485 Mdot
.12391 .01485 Mdot
.12486 .01485 Mdot
.12582 .01485 Mdot
.12677 .01485 Mdot
.12772 .01485 Mdot
.12868 .01485 Mdot
.12963 .01485 Mdot
.13058 .01485 Mdot
.13154 .01485 Mdot
.13249 .01485 Mdot
.13344 .01485 Mdot
.1344 .01485 Mdot
.13535 .01485 Mdot
.1363 .01486 Mdot
.13726 .01486 Mdot
.13821 .01486 Mdot
.13916 .01486 Mdot
.14012 .01486 Mdot
.14107 .01486 Mdot
.14202 .01486 Mdot
.14298 .01486 Mdot
.14393 .01486 Mdot
.14488 .01486 Mdot
.14584 .01486 Mdot
.14679 .01486 Mdot
.14774 .01486 Mdot
.1487 .01486 Mdot
.14965 .01486 Mdot
.1506 .01486 Mdot
.15156 .01486 Mdot
.15251 .01486 Mdot
.15346 .01486 Mdot
.15442 .01486 Mdot
.15537 .01486 Mdot
.15632 .01486 Mdot
.15728 .01486 Mdot
.15823 .01486 Mdot
.15918 .01486 Mdot
.16014 .01486 Mdot
.16109 .01486 Mdot
.16204 .01486 Mdot
.163 .01486 Mdot
.16395 .01486 Mdot
.1649 .01486 Mdot
.16586 .01486 Mdot
.16681 .01486 Mdot
.16776 .01486 Mdot
.16872 .01486 Mdot
.16967 .01486 Mdot
.17062 .01486 Mdot
.17158 .01486 Mdot
.17253 .01486 Mdot
.17348 .01486 Mdot
.17444 .01486 Mdot
.17539 .01486 Mdot
.17634 .01486 Mdot
.1773 .01486 Mdot
.17825 .01486 Mdot
.1792 .01487 Mdot
.18016 .01487 Mdot
.18111 .01487 Mdot
.18206 .01487 Mdot
.18302 .01487 Mdot
.18397 .01487 Mdot
.18492 .01487 Mdot
.18588 .01487 Mdot
.18683 .01487 Mdot
.18778 .01487 Mdot
.18874 .01487 Mdot
.18969 .01487 Mdot
.19064 .01487 Mdot
.1916 .01487 Mdot
.19255 .01487 Mdot
.1935 .01487 Mdot
.19446 .01487 Mdot
.19541 .01487 Mdot
.19636 .01487 Mdot
.19732 .01487 Mdot
.19827 .01487 Mdot
.19922 .01487 Mdot
.20018 .01487 Mdot
.20113 .01487 Mdot
.20208 .01487 Mdot
.20304 .01487 Mdot
.20399 .01487 Mdot
.20494 .01487 Mdot
.2059 .01487 Mdot
.20685 .01487 Mdot
.2078 .01487 Mdot
.20876 .01487 Mdot
.20971 .01488 Mdot
.21066 .01488 Mdot
.21162 .01488 Mdot
.21257 .01488 Mdot
.21352 .01488 Mdot
.21448 .01488 Mdot
.21543 .01488 Mdot
.21638 .01488 Mdot
.21734 .01488 Mdot
.21829 .01488 Mdot
.21924 .01488 Mdot
.2202 .01488 Mdot
.22115 .01488 Mdot
.2221 .01488 Mdot
.22306 .01488 Mdot
.22401 .01488 Mdot
.22496 .01488 Mdot
.22592 .01488 Mdot
.22687 .01488 Mdot
.22782 .01488 Mdot
.22878 .01488 Mdot
.22973 .01488 Mdot
.23068 .01488 Mdot
.23164 .01488 Mdot
.23259 .01489 Mdot
.23354 .01489 Mdot
.2345 .01489 Mdot
.23545 .01489 Mdot
.2364 .01489 Mdot
.23736 .01489 Mdot
.23831 .01489 Mdot
.23926 .01489 Mdot
.24022 .01489 Mdot
.24117 .01489 Mdot
.24212 .01489 Mdot
.24308 .01489 Mdot
.24403 .01489 Mdot
.24498 .01489 Mdot
.24594 .01489 Mdot
.24689 .01489 Mdot
.24784 .01489 Mdot
.2488 .01489 Mdot
.24975 .01489 Mdot
.2507 .01489 Mdot
.25166 .01489 Mdot
.25261 .0149 Mdot
.25356 .0149 Mdot
.25452 .0149 Mdot
.25547 .0149 Mdot
.25642 .0149 Mdot
.25738 .0149 Mdot
.25833 .0149 Mdot
.25928 .0149 Mdot
.26024 .0149 Mdot
.26119 .0149 Mdot
.26214 .0149 Mdot
.2631 .0149 Mdot
.26405 .0149 Mdot
.265 .0149 Mdot
.26596 .0149 Mdot
.26691 .0149 Mdot
.26786 .01491 Mdot
.26882 .01491 Mdot
.26977 .01491 Mdot
.27072 .01491 Mdot
.27168 .01491 Mdot
.27263 .01491 Mdot
.27358 .01491 Mdot
.27454 .01491 Mdot
.27549 .01491 Mdot
.27644 .01491 Mdot
.2774 .01491 Mdot
.27835 .01491 Mdot
.2793 .01491 Mdot
.28026 .01491 Mdot
.28121 .01491 Mdot
.28216 .01492 Mdot
.28312 .01492 Mdot
.28407 .01492 Mdot
.28502 .01492 Mdot
.28598 .01492 Mdot
.28693 .01492 Mdot
.28788 .01492 Mdot
.28884 .01492 Mdot
.28979 .01492 Mdot
.29074 .01492 Mdot
.2917 .01492 Mdot
.29265 .01492 Mdot
.2936 .01493 Mdot
.29456 .01493 Mdot
.29551 .01493 Mdot
.29646 .01493 Mdot
.29742 .01493 Mdot
.29837 .01493 Mdot
.29932 .01493 Mdot
.30028 .01493 Mdot
.30123 .01493 Mdot
.30218 .01493 Mdot
.30314 .01493 Mdot
.30409 .01494 Mdot
.30504 .01494 Mdot
.306 .01494 Mdot
.30695 .01494 Mdot
.3079 .01494 Mdot
.30886 .01494 Mdot
.30981 .01494 Mdot
.31076 .01494 Mdot
.31172 .01494 Mdot
.31267 .01494 Mdot
.31362 .01495 Mdot
.31458 .01495 Mdot
.31553 .01495 Mdot
.31648 .01495 Mdot
.31744 .01495 Mdot
.31839 .01495 Mdot
.31934 .01495 Mdot
.3203 .01495 Mdot
.32125 .01495 Mdot
.3222 .01496 Mdot
.32316 .01496 Mdot
.32411 .01496 Mdot
.32506 .01496 Mdot
.32602 .01496 Mdot
.32697 .01496 Mdot
.32792 .01496 Mdot
.32888 .01496 Mdot
.32983 .01497 Mdot
.33078 .01497 Mdot
.33174 .01497 Mdot
.33269 .01497 Mdot
.33364 .01497 Mdot
.3346 .01497 Mdot
.33555 .01497 Mdot
.3365 .01498 Mdot
.33746 .01498 Mdot
.33841 .01498 Mdot
.33936 .01498 Mdot
.34032 .01498 Mdot
.34127 .01498 Mdot
.34222 .01498 Mdot
.34318 .01499 Mdot
.34413 .01499 Mdot
.34508 .01499 Mdot
.34604 .01499 Mdot
.34699 .01499 Mdot
.34794 .01499 Mdot
.3489 .015 Mdot
.34985 .015 Mdot
.3508 .015 Mdot
.35176 .015 Mdot
.35271 .015 Mdot
.35366 .01501 Mdot
.35462 .01501 Mdot
.35557 .01501 Mdot
.35652 .01501 Mdot
.35748 .01501 Mdot
.35843 .01501 Mdot
.35938 .01502 Mdot
.36034 .01502 Mdot
.36129 .01502 Mdot
.36224 .01502 Mdot
.3632 .01503 Mdot
.36415 .01503 Mdot
.3651 .01503 Mdot
.36606 .01503 Mdot
.36701 .01503 Mdot
.36796 .01504 Mdot
.36892 .01504 Mdot
.36987 .01504 Mdot
.37082 .01504 Mdot
.37178 .01505 Mdot
.37273 .01505 Mdot
.37368 .01505 Mdot
.37464 .01505 Mdot
.37559 .01506 Mdot
.37654 .01506 Mdot
.3775 .01506 Mdot
.37845 .01507 Mdot
.3794 .01507 Mdot
.38036 .01507 Mdot
.38131 .01507 Mdot
.38226 .01508 Mdot
.38322 .01508 Mdot
.38417 .01508 Mdot
.38512 .01509 Mdot
.38608 .01509 Mdot
.38703 .01509 Mdot
.38798 .0151 Mdot
.38894 .0151 Mdot
.38989 .0151 Mdot
.39084 .01511 Mdot
.3918 .01511 Mdot
.39275 .01512 Mdot
.3937 .01512 Mdot
.39466 .01512 Mdot
.39561 .01513 Mdot
.39656 .01513 Mdot
.39752 .01514 Mdot
.39847 .01514 Mdot
.39942 .01515 Mdot
.40038 .01515 Mdot
.40133 .01516 Mdot
.40228 .01516 Mdot
.40324 .01517 Mdot
.40419 .01517 Mdot
.40514 .01518 Mdot
.4061 .01518 Mdot
.40705 .01519 Mdot
.408 .01519 Mdot
.40896 .0152 Mdot
.40991 .0152 Mdot
.41086 .01521 Mdot
.41182 .01522 Mdot
.41277 .01522 Mdot
.41372 .01523 Mdot
.41468 .01524 Mdot
.41563 .01524 Mdot
.41658 .01525 Mdot
.41754 .01526 Mdot
.41849 .01527 Mdot
.41944 .01528 Mdot
.4204 .01528 Mdot
.42135 .01529 Mdot
.4223 .0153 Mdot
.42326 .01531 Mdot
.42421 .01532 Mdot
.42516 .01533 Mdot
.42612 .01534 Mdot
.42707 .01535 Mdot
.42802 .01536 Mdot
.42898 .01537 Mdot
.42993 .01539 Mdot
.43088 .0154 Mdot
.43184 .01541 Mdot
.43279 .01543 Mdot
.43374 .01544 Mdot
.4347 .01545 Mdot
.43565 .01547 Mdot
.4366 .01549 Mdot
.43756 .0155 Mdot
.43851 .01552 Mdot
.43946 .01554 Mdot
.44042 .01556 Mdot
.44137 .01558 Mdot
.44232 .01561 Mdot
.44328 .01563 Mdot
.44423 .01566 Mdot
.44518 .01569 Mdot
.44614 .01571 Mdot
.44709 .01575 Mdot
.44804 .01578 Mdot
.449 .01582 Mdot
.44995 .01586 Mdot
.4509 .0159 Mdot
.45186 .01595 Mdot
.45281 .016 Mdot
.45376 .01606 Mdot
.45472 .01612 Mdot
.45567 .01619 Mdot
.45662 .01627 Mdot
.45758 .01636 Mdot
.45853 .01647 Mdot
.45948 .01659 Mdot
.46044 .01673 Mdot
.46139 .0169 Mdot
.46234 .01711 Mdot
.4633 .01736 Mdot
.46425 .01769 Mdot
.4652 .01813 Mdot
.46616 .01873 Mdot
.46711 .01964 Mdot
.46806 .02115 Mdot
.46902 .02419 Mdot
.46997 .03346 Mdot
.47092 .60332 Mdot
.47188 .03136 Mdot
.47283 .02288 Mdot
.47378 .01999 Mdot
.47474 .01852 Mdot
.47569 .01763 Mdot
.47664 .01702 Mdot
.4776 .01658 Mdot
.47855 .01624 Mdot
.4795 .01596 Mdot
.48046 .01573 Mdot
.48141 .01553 Mdot
.48236 .01534 Mdot
.48332 .01516 Mdot
.48427 .01498 Mdot
.48522 .01479 Mdot
.48618 .01488 Mdot
.48713 .0152 Mdot
.48808 .01577 Mdot
.48904 .01734 Mdot
.48999 .30996 Mdot
.49094 .01787 Mdot
.4919 .01636 Mdot
.49285 .01581 Mdot
.4938 .01551 Mdot
.49476 .01531 Mdot
.49571 .01516 Mdot
.49666 .01503 Mdot
.49762 .01492 Mdot
.49857 .01481 Mdot
.49952 .01472 Mdot
.50048 .01481 Mdot
.50143 .01492 Mdot
.50238 .01503 Mdot
.50334 .01516 Mdot
.50429 .01531 Mdot
.50524 .01551 Mdot
.5062 .01581 Mdot
.50715 .01636 Mdot
.5081 .01787 Mdot
.50906 .30996 Mdot
.51001 .01734 Mdot
.51096 .01577 Mdot
.51192 .0152 Mdot
.51287 .01488 Mdot
.51382 .01479 Mdot
.51478 .01498 Mdot
.51573 .01516 Mdot
.51668 .01534 Mdot
.51764 .01553 Mdot
.51859 .01573 Mdot
.51954 .01596 Mdot
.5205 .01624 Mdot
.52145 .01658 Mdot
.5224 .01702 Mdot
.52336 .01763 Mdot
.52431 .01852 Mdot
.52526 .01999 Mdot
.52622 .02288 Mdot
.52717 .03136 Mdot
.52812 .60332 Mdot
.52908 .03346 Mdot
.53003 .02419 Mdot
.53098 .02115 Mdot
.53194 .01964 Mdot
.53289 .01873 Mdot
.53384 .01813 Mdot
.5348 .01769 Mdot
.53575 .01736 Mdot
.5367 .01711 Mdot
.53766 .0169 Mdot
.53861 .01673 Mdot
.53956 .01659 Mdot
.54052 .01647 Mdot
.54147 .01636 Mdot
.54242 .01627 Mdot
.54338 .01619 Mdot
.54433 .01612 Mdot
.54528 .01606 Mdot
.54624 .016 Mdot
.54719 .01595 Mdot
.54814 .0159 Mdot
.5491 .01586 Mdot
.55005 .01582 Mdot
.551 .01578 Mdot
.55196 .01575 Mdot
.55291 .01571 Mdot
.55386 .01569 Mdot
.55482 .01566 Mdot
.55577 .01563 Mdot
.55672 .01561 Mdot
.55768 .01558 Mdot
.55863 .01556 Mdot
.55958 .01554 Mdot
.56054 .01552 Mdot
.56149 .0155 Mdot
.56244 .01549 Mdot
.5634 .01547 Mdot
.56435 .01545 Mdot
.5653 .01544 Mdot
.56626 .01543 Mdot
.56721 .01541 Mdot
.56816 .0154 Mdot
.56912 .01539 Mdot
.57007 .01537 Mdot
.57102 .01536 Mdot
.57198 .01535 Mdot
.57293 .01534 Mdot
.57388 .01533 Mdot
.57484 .01532 Mdot
.57579 .01531 Mdot
.57674 .0153 Mdot
.5777 .01529 Mdot
.57865 .01528 Mdot
.5796 .01528 Mdot
.58056 .01527 Mdot
.58151 .01526 Mdot
.58246 .01525 Mdot
.58342 .01524 Mdot
.58437 .01524 Mdot
.58532 .01523 Mdot
.58628 .01522 Mdot
.58723 .01522 Mdot
.58818 .01521 Mdot
.58914 .0152 Mdot
.59009 .0152 Mdot
.59104 .01519 Mdot
.592 .01519 Mdot
.59295 .01518 Mdot
.5939 .01518 Mdot
.59486 .01517 Mdot
.59581 .01517 Mdot
.59676 .01516 Mdot
.59772 .01516 Mdot
.59867 .01515 Mdot
.59962 .01515 Mdot
.60058 .01514 Mdot
.60153 .01514 Mdot
.60248 .01513 Mdot
.60344 .01513 Mdot
.60439 .01512 Mdot
.60534 .01512 Mdot
.6063 .01512 Mdot
.60725 .01511 Mdot
.6082 .01511 Mdot
.60916 .0151 Mdot
.61011 .0151 Mdot
.61106 .0151 Mdot
.61202 .01509 Mdot
.61297 .01509 Mdot
.61392 .01509 Mdot
.61488 .01508 Mdot
.61583 .01508 Mdot
.61678 .01508 Mdot
.61774 .01507 Mdot
.61869 .01507 Mdot
.61964 .01507 Mdot
.6206 .01507 Mdot
.62155 .01506 Mdot
.6225 .01506 Mdot
.62346 .01506 Mdot
.62441 .01505 Mdot
.62536 .01505 Mdot
.62632 .01505 Mdot
.62727 .01505 Mdot
.62822 .01504 Mdot
.62918 .01504 Mdot
.63013 .01504 Mdot
.63108 .01504 Mdot
.63204 .01503 Mdot
.63299 .01503 Mdot
.63394 .01503 Mdot
.6349 .01503 Mdot
.63585 .01503 Mdot
.6368 .01502 Mdot
.63776 .01502 Mdot
.63871 .01502 Mdot
.63966 .01502 Mdot
.64062 .01501 Mdot
.64157 .01501 Mdot
.64252 .01501 Mdot
.64348 .01501 Mdot
.64443 .01501 Mdot
.64538 .01501 Mdot
.64634 .015 Mdot
.64729 .015 Mdot
.64824 .015 Mdot
.6492 .015 Mdot
.65015 .015 Mdot
.6511 .01499 Mdot
.65206 .01499 Mdot
.65301 .01499 Mdot
.65396 .01499 Mdot
.65492 .01499 Mdot
.65587 .01499 Mdot
.65682 .01498 Mdot
.65778 .01498 Mdot
.65873 .01498 Mdot
.65968 .01498 Mdot
.66064 .01498 Mdot
.66159 .01498 Mdot
.66254 .01498 Mdot
.6635 .01497 Mdot
.66445 .01497 Mdot
.6654 .01497 Mdot
.66636 .01497 Mdot
.66731 .01497 Mdot
.66826 .01497 Mdot
.66922 .01497 Mdot
.67017 .01496 Mdot
.67112 .01496 Mdot
.67208 .01496 Mdot
.67303 .01496 Mdot
.67398 .01496 Mdot
.67494 .01496 Mdot
.67589 .01496 Mdot
.67684 .01496 Mdot
.6778 .01495 Mdot
.67875 .01495 Mdot
.6797 .01495 Mdot
.68066 .01495 Mdot
.68161 .01495 Mdot
.68256 .01495 Mdot
.68352 .01495 Mdot
.68447 .01495 Mdot
.68542 .01495 Mdot
.68638 .01494 Mdot
.68733 .01494 Mdot
.68828 .01494 Mdot
.68924 .01494 Mdot
.69019 .01494 Mdot
.69114 .01494 Mdot
.6921 .01494 Mdot
.69305 .01494 Mdot
.694 .01494 Mdot
.69496 .01494 Mdot
.69591 .01493 Mdot
.69686 .01493 Mdot
.69782 .01493 Mdot
.69877 .01493 Mdot
.69972 .01493 Mdot
.70068 .01493 Mdot
.70163 .01493 Mdot
.70258 .01493 Mdot
.70354 .01493 Mdot
.70449 .01493 Mdot
.70544 .01493 Mdot
.7064 .01492 Mdot
.70735 .01492 Mdot
.7083 .01492 Mdot
.70926 .01492 Mdot
.71021 .01492 Mdot
.71116 .01492 Mdot
.71212 .01492 Mdot
.71307 .01492 Mdot
.71402 .01492 Mdot
.71498 .01492 Mdot
.71593 .01492 Mdot
.71688 .01492 Mdot
.71784 .01491 Mdot
.71879 .01491 Mdot
.71974 .01491 Mdot
.7207 .01491 Mdot
.72165 .01491 Mdot
.7226 .01491 Mdot
.72356 .01491 Mdot
.72451 .01491 Mdot
.72546 .01491 Mdot
.72642 .01491 Mdot
.72737 .01491 Mdot
.72832 .01491 Mdot
.72928 .01491 Mdot
.73023 .01491 Mdot
.73118 .01491 Mdot
.73214 .0149 Mdot
.73309 .0149 Mdot
.73404 .0149 Mdot
.735 .0149 Mdot
.73595 .0149 Mdot
.7369 .0149 Mdot
.73786 .0149 Mdot
.73881 .0149 Mdot
.73976 .0149 Mdot
.74072 .0149 Mdot
.74167 .0149 Mdot
.74262 .0149 Mdot
.74358 .0149 Mdot
.74453 .0149 Mdot
.74548 .0149 Mdot
.74644 .0149 Mdot
.74739 .01489 Mdot
.74834 .01489 Mdot
.7493 .01489 Mdot
.75025 .01489 Mdot
.7512 .01489 Mdot
.75216 .01489 Mdot
.75311 .01489 Mdot
.75406 .01489 Mdot
.75502 .01489 Mdot
.75597 .01489 Mdot
.75692 .01489 Mdot
.75788 .01489 Mdot
.75883 .01489 Mdot
.75978 .01489 Mdot
.76074 .01489 Mdot
.76169 .01489 Mdot
.76264 .01489 Mdot
.7636 .01489 Mdot
.76455 .01489 Mdot
.7655 .01489 Mdot
.76646 .01489 Mdot
.76741 .01488 Mdot
.76836 .01488 Mdot
.76932 .01488 Mdot
.77027 .01488 Mdot
.77122 .01488 Mdot
.77218 .01488 Mdot
.77313 .01488 Mdot
.77408 .01488 Mdot
.77504 .01488 Mdot
.77599 .01488 Mdot
.77694 .01488 Mdot
.7779 .01488 Mdot
.77885 .01488 Mdot
.7798 .01488 Mdot
.78076 .01488 Mdot
.78171 .01488 Mdot
.78266 .01488 Mdot
.78362 .01488 Mdot
.78457 .01488 Mdot
.78552 .01488 Mdot
.78648 .01488 Mdot
.78743 .01488 Mdot
.78838 .01488 Mdot
.78934 .01488 Mdot
.79029 .01487 Mdot
.79124 .01487 Mdot
.7922 .01487 Mdot
.79315 .01487 Mdot
.7941 .01487 Mdot
.79506 .01487 Mdot
.79601 .01487 Mdot
.79696 .01487 Mdot
.79792 .01487 Mdot
.79887 .01487 Mdot
.79982 .01487 Mdot
.80078 .01487 Mdot
.80173 .01487 Mdot
.80268 .01487 Mdot
.80364 .01487 Mdot
.80459 .01487 Mdot
.80554 .01487 Mdot
.8065 .01487 Mdot
.80745 .01487 Mdot
.8084 .01487 Mdot
.80936 .01487 Mdot
.81031 .01487 Mdot
.81126 .01487 Mdot
.81222 .01487 Mdot
.81317 .01487 Mdot
.81412 .01487 Mdot
.81508 .01487 Mdot
.81603 .01487 Mdot
.81698 .01487 Mdot
.81794 .01487 Mdot
.81889 .01487 Mdot
.81984 .01487 Mdot
.8208 .01486 Mdot
.82175 .01486 Mdot
.8227 .01486 Mdot
.82366 .01486 Mdot
.82461 .01486 Mdot
.82556 .01486 Mdot
.82652 .01486 Mdot
.82747 .01486 Mdot
.82842 .01486 Mdot
.82938 .01486 Mdot
.83033 .01486 Mdot
.83128 .01486 Mdot
.83224 .01486 Mdot
.83319 .01486 Mdot
.83414 .01486 Mdot
.8351 .01486 Mdot
.83605 .01486 Mdot
.837 .01486 Mdot
.83796 .01486 Mdot
.83891 .01486 Mdot
.83986 .01486 Mdot
.84082 .01486 Mdot
.84177 .01486 Mdot
.84272 .01486 Mdot
.84368 .01486 Mdot
.84463 .01486 Mdot
.84558 .01486 Mdot
.84654 .01486 Mdot
.84749 .01486 Mdot
.84844 .01486 Mdot
.8494 .01486 Mdot
.85035 .01486 Mdot
.8513 .01486 Mdot
.85226 .01486 Mdot
.85321 .01486 Mdot
.85416 .01486 Mdot
.85512 .01486 Mdot
.85607 .01486 Mdot
.85702 .01486 Mdot
.85798 .01486 Mdot
.85893 .01486 Mdot
.85988 .01486 Mdot
.86084 .01486 Mdot
.86179 .01486 Mdot
.86274 .01486 Mdot
.8637 .01485 Mdot
.86465 .01485 Mdot
.8656 .01485 Mdot
.86656 .01485 Mdot
.86751 .01485 Mdot
.86846 .01485 Mdot
.86942 .01485 Mdot
.87037 .01485 Mdot
.87132 .01485 Mdot
.87228 .01485 Mdot
.87323 .01485 Mdot
.87418 .01485 Mdot
.87514 .01485 Mdot
.87609 .01485 Mdot
.87704 .01485 Mdot
.878 .01485 Mdot
.87895 .01485 Mdot
.8799 .01485 Mdot
.88086 .01485 Mdot
.88181 .01485 Mdot
.88276 .01485 Mdot
.88372 .01485 Mdot
.88467 .01485 Mdot
.88562 .01485 Mdot
.88658 .01485 Mdot
.88753 .01485 Mdot
.88848 .01485 Mdot
.88944 .01485 Mdot
.89039 .01485 Mdot
.89134 .01485 Mdot
.8923 .01485 Mdot
.89325 .01485 Mdot
.8942 .01485 Mdot
.89516 .01485 Mdot
.89611 .01485 Mdot
.89706 .01485 Mdot
.89802 .01485 Mdot
.89897 .01485 Mdot
.89992 .01485 Mdot
.90088 .01485 Mdot
.90183 .01485 Mdot
.90278 .01485 Mdot
.90374 .01485 Mdot
.90469 .01485 Mdot
.90564 .01485 Mdot
.9066 .01485 Mdot
.90755 .01485 Mdot
.9085 .01485 Mdot
.90946 .01485 Mdot
.91041 .01485 Mdot
.91136 .01485 Mdot
.91232 .01485 Mdot
.91327 .01485 Mdot
.91422 .01485 Mdot
.91518 .01485 Mdot
.91613 .01485 Mdot
.91708 .01485 Mdot
.91804 .01485 Mdot
.91899 .01485 Mdot
.91994 .01485 Mdot
.9209 .01485 Mdot
.92185 .01485 Mdot
.9228 .01485 Mdot
.92376 .01485 Mdot
.92471 .01485 Mdot
.92566 .01485 Mdot
.92662 .01485 Mdot
.92757 .01485 Mdot
.92852 .01485 Mdot
.92948 .01485 Mdot
.93043 .01485 Mdot
.93138 .01485 Mdot
.93234 .01485 Mdot
.93329 .01485 Mdot
.93424 .01485 Mdot
.9352 .01485 Mdot
.93615 .01485 Mdot
.9371 .01485 Mdot
.93806 .01485 Mdot
.93901 .01485 Mdot
.93996 .01485 Mdot
.94092 .01485 Mdot
.94187 .01485 Mdot
.94282 .01485 Mdot
.94378 .01485 Mdot
.94473 .01485 Mdot
.94568 .01485 Mdot
.94664 .01485 Mdot
.94759 .01485 Mdot
.94854 .01485 Mdot
.9495 .01485 Mdot
.95045 .01485 Mdot
.9514 .01485 Mdot
.95236 .01485 Mdot
.95331 .01485 Mdot
.95426 .01485 Mdot
.95522 .01485 Mdot
.95617 .01485 Mdot
.95712 .01485 Mdot
.95808 .01485 Mdot
.95903 .01485 Mdot
.95998 .01485 Mdot
.96094 .01485 Mdot
.96189 .01485 Mdot
.96284 .01485 Mdot
.9638 .01485 Mdot
.96475 .01485 Mdot
.9657 .01485 Mdot
.96666 .01485 Mdot
.96761 .01485 Mdot
.96856 .01485 Mdot
.96952 .01485 Mdot
.97047 .01485 Mdot
.97142 .01485 Mdot
.97238 .01485 Mdot
.97333 .01485 Mdot
.97428 .01485 Mdot
.97524 .01485 Mdot
.97619 .01485 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00=Oooool3o`0000?ooooo0_l00004ooooo`;o00008_ooool5o`0000?o
oooo0_l00004ooooo`;o00009_ooool2o`0002Sooooo1Ol00003ooooo`;o00001?ooool2o`0002?o
oooo0ol00003ooooo`;o00001?ooool2o`0001[ooooo000fooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo023ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Cooooo
00Co0000oooooooooooo0000:?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Gooooo`00;Oooool5o`000003oooo
ool0003o000000?o00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
01_ooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Tooooo`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo1Ol00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00006Oooool003?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool08_ooool01?l0003oooooooooool0000Zooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000d
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Qooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002Cooooo00Co0000oooooooooooo00009oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Qoooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
000Iooooo`00=Oooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Qooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002Cooooo00Co0000oooooooooooo00009oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Roooo
o`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000f
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00008oooool3o`0000Cooooo0_l00004
ooooo`;o00009_ooool2o`0002Wooooo0ol00004ooooo`;o00001?ooool2o`0002Cooooo00?o0000
ooooooooool00_ooool2o`0000Cooooo0_l0000Jooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`006ooooooo000000D000000Oooool001_ooooo00<00000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool10000007ooooo000Dooooo`;o00001Oooool00`00003oooooooooo`0Kooooo`03
o`000?oooooooooo02oooooo00<00000ooooooooool0;_ooool00`00003oooooooooo`0_ooooo`03
o`000?oooooooooo02kooooo00<00000ooooooooool07?ooool10000007ooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool0ooooool1ooooo`4000000Oooool001?ooooo
00Co0000oooooooooooo00001?ooool01000003o0000oooooooooookool000?ooooo0Ol000010000
007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00@00000oooooooooooooooonooo0004
ooooo`4000000Oooool001?ooooo00Co0000oooooooooooo00001?ooool01000003ooooooooooooo
oookool000Cooooo0@000001ooooo`004oooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo07Cooooo1_oo0002ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo00001Ooo
001gooooo`4000000Oooool001Cooooo0_l00005ooooo`0300000?oooooooooo07Gooooo1?oo0003
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool01?oo001hooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0MOooool4ool000?ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`04ool007Sooooo0@000001ooooo`006oooool00`00003oooooooooo`1eooooo`Co
o`000oooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00Coo`00N?ooool10000007o
oooo000Kooooo`0300000?oooooooooo07Gooooo0ooo0004ooooo`030?l00?oooooooooo00;ooooo
00@0o`00oooooooooooooooo0ooo001hooooo`4000000Oooool001_ooooo00<00000o`000?ooool0
Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`1fooooo`7o00000@000001ooooo`006oooool00`00003ooooooooo
o`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1g
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1goooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`03
0?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`03
0?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l0
0?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l0
0?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oo
oooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooo
oooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooo
oooo07Oooooo0@000001ooooo`006oooool00`00003o0000ooooo`1gooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
07Kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Mooo
ool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Moooool1
0000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Moooool10000
007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Moooool10000007o
oooo000Kooooo`0300000?l0003ooooo07Oooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0M_ooool1o`0000400000
0Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooo
oooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_o
oooo00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;o
oooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool000Kooooo
1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0Moooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`1gooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0Moooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`1gooooo`4000000Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0Moooool0
0`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`1gooooo`4000000Oooool000Wooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003o0000oooo
o`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo07Kooooo0Ol000010000007ooooo0006ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;o
oooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool000Kooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07Oooooo0@000001
ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`1goooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`03
0?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`03
0?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l0
0?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l0
0?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oo
oooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooo
oooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooo
oooo07Oooooo0@000001ooooo`006oooool00`00003o0000ooooo`1gooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
07Kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Mooo
ool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Moooool1
0000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Moooool10000
007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Moooool10000007o
oooo000Kooooo`0300000?l0003ooooo07Oooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0M_ooool1o`0000400000
0Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooo
oooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool0
01_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_o
oooo00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;o
oooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_ooooo
00<00000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_ooooo00<0
0000ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000
ooooooooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000o`00
0?ooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`1fooooo`7o00000@000001ooooo`006oooool00`00003o
ooooooooo`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003ooooooooo
o`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1g
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`002?ooool3o`0000?ooooo0_l00004oooo
o`;o00001Oooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07Oooooo0@000001oooo
o`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Moooool1
0000007ooooo0006ooooo`Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000o`000?ooool0Moooool00`3o003oooooooooo`02ooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1fooooo`7o00000@00
0001ooooo`001_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00;o
oooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07Oo
oooo0@000001ooooo`001oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
07Oooooo0@000001ooooo`002?ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Moooool1
0000007ooooo0009ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00001Oooool00`00
003oooooooooo`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003o
ooooooooo`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003ooooooooo
o`1gooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003o0000ooooo`1g
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo07Kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo
07Oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oo
oooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;o
oooo00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo
00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0
o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00@0o`00oooooooo
oooooooo0ooo00001?ooooooo`00ool00?oo0004ooooo`030?l00?oooooooooo07Oooooo0@000001
ooooo`006oooool00`00003o0000ooooo`1gooooo`040?l00?ooooooooooooooo`?oo`0000Cooooo
ool00?oo003oo`001?ooool00`3o003oooooooooo`1fooooo`7o00000@000001ooooo`006oooool0
0`00003oooooooooo`1gooooo`040?l00?ooooooooooooooo`?oo`0000Coooooool00?oo003oo`00
1?ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000ooooooooool0Mooo
ool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool0
0`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool1
0000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o
003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003o
ooooooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo
000Kooooo`0300000?l0003ooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003ooooooooo
o`1fooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooo
oooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo
07Oooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_o
oooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Oo
oooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo
00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0
o`00ooooooooool03?ooool00`3o003oooooooooo`1gooooo`4000000Oooool000Oooooo0ol00004
ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<
ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`001_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1gooooo`400000
0Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00`00003o0000ooooo`1gooooo`030?l00?oooooooooo
00cooooo00<0o`00ooooooooool0M_ooool1o`00004000000Oooool000Kooooo1?l00003ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1g
ooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo0006oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003ooooooooo
o`1gooooo`4000000Oooool000Oooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0Moooool00`3o003ooooo
ooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`002?ooool2o`0000Cooooo0_l0
0004ooooo`;o00001Oooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo00<0
o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00
ooooooooool03?ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000oooo
ooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001oooo
o`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00oooooooo
ool0Moooool10000007ooooo000Kooooo`0300000?l0003ooooo07Oooooo00<0o`00ooooooooool0
3?ooool00`3o003oooooooooo`1fooooo`7o00000@000001ooooo`006oooool00`00003ooooooooo
o`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo000K
ooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1g
ooooo`4000000Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<oooo
o`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`03
0?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`030000
0?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1gooooo`400000
0Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l00?oo
oooooooo07Oooooo0@000001ooooo`006oooool00`00003o0000ooooo`1gooooo`030?l00?oooooo
oooo00cooooo00<0o`00ooooooooool0M_ooool1o`00004000000Oooool001_ooooo00<00000oooo
ooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001oooo
o`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00oooooooo
ool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool0
3?ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000ooooooooool0Mooo
ool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool0
0`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool1
0000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o
003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003o
ooooooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003o0000
ooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0M_ooool1o`0000400000
0Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l00?oo
oooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooo
oooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo
07Oooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_o
oooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Oo
oooo0@000001ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003ooooo
ooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo
0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<oooo
o`030?l00?oooooooooo07Oooooo0@000001ooooo`001_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1gooooo`4000000Ooo
ool000Oooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003o0000ooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0
M_ooool1o`00004000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1goooo
o`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo0006ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l00?oo
oooooooo07Oooooo0@000001ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool0
0`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool1
0000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o
003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003o
ooooooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo
000Kooooo`0300000?l0003ooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003ooooooooo
o`1fooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooo
oooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo
07Oooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_o
oooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Oo
oooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo
00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0
o`00ooooooooool03?ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000
ooooooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001
ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00oooo
ooooool0Moooool10000007ooooo000Kooooo`0300000?l0003ooooo07Oooooo00<0o`00oooooooo
ool03?ooool00`3o003oooooooooo`1fooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo
000Kooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003ooooooooo
o`1gooooo`4000000Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<
ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1goooo
o`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`03
00000?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1gooooo`40
00000Oooool001_ooooo00<00000ooooooooool0Moooool00`3o003oooooooooo`0<ooooo`030?l0
0?oooooooooo07Oooooo0@000001ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oo
oooooooo00cooooo00<0o`00ooooooooool0Moooool10000007ooooo000Kooooo`0300000?l0003o
oooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1fooooo`7o00000@000001
ooooo`006oooool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00oooo
ooooool0Moooool10000007ooooo000Kooooo`0300000?oooooooooo07Oooooo00<0o`00oooooooo
ool03?ooool00`3o003oooooooooo`1gooooo`4000000Oooool001_ooooo00<00000ooooooooool0
Moooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Oooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`1gooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0Mooo
ool10000007ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Cooooo0_l0
0005ooooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool03?ooool00`3o003ooooooooo
o`1gooooo`4000000Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`1fooooo`?oo`002oooool3ool007Wooooo0@000001ooooo`000_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`0300000?l0003ooooo07Kooooo0ooo000;ooooo`?oo`00N?ooool1
o`00004000000Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`1fooooo`?oo`002oooool3ool007Wooooo0@000001ooooo`000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool0;oooool00`00
003oooooooooo`0^ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool0;_ooool00`00
003oooooooooo`0Looooo`4000000Oooool00003ooooool0003o000000Cooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00<0
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<0
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool10000007ooooo0002ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`;o00001?ooool2o`0000Goooooo`0000050000007ooooo003oooooob7ooooo003oooooob7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-634.057, -115.305, 4.04022, \
6.5283}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[g1, \ PlotRange \[Rule] {{\(-40\), 40}, All}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0125 0.0147151 0.000589997 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -6 -9 ]
[.625 -0.0125 6 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -6 -9 ]
[.875 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13271 -18 -4.5 ]
[-0.0125 .13271 0 4.5 ]
[-0.0125 .25071 -18 -4.5 ]
[-0.0125 .25071 0 4.5 ]
[-0.0125 .36871 -18 -4.5 ]
[-0.0125 .36871 0 4.5 ]
[-0.0125 .48671 -18 -4.5 ]
[-0.0125 .48671 0 4.5 ]
[-0.0125 .60471 -24 -4.5 ]
[-0.0125 .60471 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-30)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-20)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-10)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(10)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(20)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(30)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(40)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13271 m
.00625 .13271 L
s
[(200)] -0.0125 .13271 1 0 Mshowa
0 .25071 m
.00625 .25071 L
s
[(400)] -0.0125 .25071 1 0 Mshowa
0 .36871 m
.00625 .36871 L
s
[(600)] -0.0125 .36871 1 0 Mshowa
0 .48671 m
.00625 .48671 L
s
[(800)] -0.0125 .48671 1 0 Mshowa
0 .60471 m
.00625 .60471 L
s
[(1000)] -0.0125 .60471 1 0 Mshowa
.125 Mabswid
0 .04421 m
.00375 .04421 L
s
0 .07371 m
.00375 .07371 L
s
0 .10321 m
.00375 .10321 L
s
0 .16221 m
.00375 .16221 L
s
0 .19171 m
.00375 .19171 L
s
0 .22121 m
.00375 .22121 L
s
0 .28021 m
.00375 .28021 L
s
0 .30971 m
.00375 .30971 L
s
0 .33921 m
.00375 .33921 L
s
0 .39821 m
.00375 .39821 L
s
0 .42771 m
.00375 .42771 L
s
0 .45721 m
.00375 .45721 L
s
0 .51621 m
.00375 .51621 L
s
0 .54571 m
.00375 .54571 L
s
0 .57521 m
.00375 .57521 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13271 m
1 .13271 L
s
.99375 .25071 m
1 .25071 L
s
.99375 .36871 m
1 .36871 L
s
.99375 .48671 m
1 .48671 L
s
.99375 .60471 m
1 .60471 L
s
.125 Mabswid
.99625 .04421 m
1 .04421 L
s
.99625 .07371 m
1 .07371 L
s
.99625 .10321 m
1 .10321 L
s
.99625 .16221 m
1 .16221 L
s
.99625 .19171 m
1 .19171 L
s
.99625 .22121 m
1 .22121 L
s
.99625 .28021 m
1 .28021 L
s
.99625 .30971 m
1 .30971 L
s
.99625 .33921 m
1 .33921 L
s
.99625 .39821 m
1 .39821 L
s
.99625 .42771 m
1 .42771 L
s
.99625 .45721 m
1 .45721 L
s
.99625 .51621 m
1 .51621 L
s
.99625 .54571 m
1 .54571 L
s
.99625 .57521 m
1 .57521 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .01472 m
0 .0169 L
s
.0125 .01472 m
.0125 .01711 L
s
.025 .01472 m
.025 .01736 L
s
.0375 .01472 m
.0375 .01769 L
s
.05 .01472 m
.05 .01813 L
s
.0625 .01472 m
.0625 .01873 L
s
.075 .01472 m
.075 .01964 L
s
.0875 .01472 m
.0875 .02115 L
s
.1 .01472 m
.1 .02419 L
s
.1125 .01472 m
.1125 .03346 L
s
.125 .01472 m
.125 .60332 L
s
.1375 .01472 m
.1375 .03136 L
s
.15 .01472 m
.15 .02288 L
s
.1625 .01472 m
.1625 .01999 L
s
.175 .01472 m
.175 .01852 L
s
.1875 .01472 m
.1875 .01763 L
s
.2 .01472 m
.2 .01702 L
s
.2125 .01472 m
.2125 .01658 L
s
.225 .01472 m
.225 .01624 L
s
.2375 .01472 m
.2375 .01596 L
s
.25 .01472 m
.25 .01573 L
s
.2625 .01472 m
.2625 .01553 L
s
.275 .01472 m
.275 .01534 L
s
.2875 .01472 m
.2875 .01516 L
s
.3 .01472 m
.3 .01498 L
s
.3125 .01472 m
.3125 .01479 L
s
.325 .01472 m
.325 .01488 L
s
.3375 .01472 m
.3375 .0152 L
s
.35 .01472 m
.35 .01577 L
s
.3625 .01472 m
.3625 .01734 L
s
.375 .01472 m
.375 .30996 L
s
.3875 .01472 m
.3875 .01787 L
s
.4 .01472 m
.4 .01636 L
s
.4125 .01472 m
.4125 .01581 L
s
.425 .01472 m
.425 .01551 L
s
.4375 .01472 m
.4375 .01531 L
s
.45 .01472 m
.45 .01516 L
s
.4625 .01472 m
.4625 .01503 L
s
.475 .01472 m
.475 .01492 L
s
.4875 .01472 m
.4875 .01481 L
s
.5 .01472 m
.5 .01472 L
s
.5125 .01472 m
.5125 .01481 L
s
.525 .01472 m
.525 .01492 L
s
.5375 .01472 m
.5375 .01503 L
s
.55 .01472 m
.55 .01516 L
s
.5625 .01472 m
.5625 .01531 L
s
.575 .01472 m
.575 .01551 L
s
.5875 .01472 m
.5875 .01581 L
s
.6 .01472 m
.6 .01636 L
s
.6125 .01472 m
.6125 .01787 L
s
.625 .01472 m
.625 .30996 L
s
.6375 .01472 m
.6375 .01734 L
s
.65 .01472 m
.65 .01577 L
s
.6625 .01472 m
.6625 .0152 L
s
.675 .01472 m
.675 .01488 L
s
.6875 .01472 m
.6875 .01479 L
s
.7 .01472 m
.7 .01498 L
s
.7125 .01472 m
.7125 .01516 L
s
.725 .01472 m
.725 .01534 L
s
.7375 .01472 m
.7375 .01553 L
s
.75 .01472 m
.75 .01573 L
s
.7625 .01472 m
.7625 .01596 L
s
.775 .01472 m
.775 .01624 L
s
.7875 .01472 m
.7875 .01658 L
s
.8 .01472 m
.8 .01702 L
s
.8125 .01472 m
.8125 .01763 L
s
.825 .01472 m
.825 .01852 L
s
.8375 .01472 m
.8375 .01999 L
s
.85 .01472 m
.85 .02288 L
s
.8625 .01472 m
.8625 .03136 L
s
.875 .01472 m
.875 .60332 L
s
.8875 .01472 m
.8875 .03346 L
s
.9 .01472 m
.9 .02419 L
s
.9125 .01472 m
.9125 .02115 L
s
.925 .01472 m
.925 .01964 L
s
.9375 .01472 m
.9375 .01873 L
s
.95 .01472 m
.95 .01813 L
s
.9625 .01472 m
.9625 .01769 L
s
.975 .01472 m
.975 .01736 L
s
.9875 .01472 m
.9875 .01711 L
s
1 .01472 m
1 .0169 L
s
.015 w
0 .0169 Mdot
.0125 .01711 Mdot
.025 .01736 Mdot
.0375 .01769 Mdot
.05 .01813 Mdot
.0625 .01873 Mdot
.075 .01964 Mdot
.0875 .02115 Mdot
.1 .02419 Mdot
.1125 .03346 Mdot
.125 .60332 Mdot
.1375 .03136 Mdot
.15 .02288 Mdot
.1625 .01999 Mdot
.175 .01852 Mdot
.1875 .01763 Mdot
.2 .01702 Mdot
.2125 .01658 Mdot
.225 .01624 Mdot
.2375 .01596 Mdot
.25 .01573 Mdot
.2625 .01553 Mdot
.275 .01534 Mdot
.2875 .01516 Mdot
.3 .01498 Mdot
.3125 .01479 Mdot
.325 .01488 Mdot
.3375 .0152 Mdot
.35 .01577 Mdot
.3625 .01734 Mdot
.375 .30996 Mdot
.3875 .01787 Mdot
.4 .01636 Mdot
.4125 .01581 Mdot
.425 .01551 Mdot
.4375 .01531 Mdot
.45 .01516 Mdot
.4625 .01503 Mdot
.475 .01492 Mdot
.4875 .01481 Mdot
.5 .01472 Mdot
.5125 .01481 Mdot
.525 .01492 Mdot
.5375 .01503 Mdot
.55 .01516 Mdot
.5625 .01531 Mdot
.575 .01551 Mdot
.5875 .01581 Mdot
.6 .01636 Mdot
.6125 .01787 Mdot
.625 .30996 Mdot
.6375 .01734 Mdot
.65 .01577 Mdot
.6625 .0152 Mdot
.675 .01488 Mdot
.6875 .01479 Mdot
.7 .01498 Mdot
.7125 .01516 Mdot
.725 .01534 Mdot
.7375 .01553 Mdot
.75 .01573 Mdot
.7625 .01596 Mdot
.775 .01624 Mdot
.7875 .01658 Mdot
.8 .01702 Mdot
.8125 .01763 Mdot
.825 .01852 Mdot
.8375 .01999 Mdot
.85 .02288 Mdot
.8625 .03136 Mdot
.875 .60332 Mdot
.8875 .03346 Mdot
.9 .02419 Mdot
.9125 .02115 Mdot
.925 .01964 Mdot
.9375 .01873 Mdot
.95 .01813 Mdot
.9625 .01769 Mdot
.975 .01736 Mdot
.9875 .01711 Mdot
1 .0169 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Fooooo`Go00000oooool2o`0001Oooooo0ol00004ooooo`;o00006?ooool2o`0001Wooooo0ol0
0004ooooo`;o00005_ooool5o`0000?ooooo0_l0000Gooooo`?o00001?ooool2o`0001Sooooo0ol0
0003ooooo`;o00000oooool003Oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0001Kooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Goooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005_ooool01?l0003oooooooooool0
000Iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0001Gooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0001Sooooo00Go0000ooooooooooooooooo`000002ooooo`7o0000
0Oooool1ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0=ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000oo
oooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005_ooool01?l0
003oooooooooool0000Iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`Go00000_ooool01?l0003oooooooooool00002oooo
o`00>Oooool2o`0000?ooooo00Co0000oooooooooooo00006?ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0001Kooooo00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0001Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
01Gooooo0_l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00002ooooo`00>oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo01?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
01Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Fooooo`04o`000?oooooo
ooooo`0001Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Eooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Iooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo000gooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000Eooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Foooo
o`;o00001?ooool01?l0003oooooooooool0000Fooooo`04o`000?ooooooooooo`0001Sooooo0_l0
0004ooooo`04o`000?ooooooooooo`0001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0001Oooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo000hooooo`?o00001?oo
ool2o`0001Oooooo0ol00004ooooo`;o00006?ooool00ol0003oooooooooo`03ooooo`;o00006?oo
ool2o`0001[ooooo00?o0000ooooooooool00oooool2o`0001Oooooo0ol00004ooooo`;o00005ooo
ool3o`0000Cooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`006oooool00`00003o0000o`00
003ko`00000300000?oooooooooo00Cooooo000Dooooo`;o00001Oooool00`00003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00`00003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`0300000?oooooooooo00Cooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`0300000?oooooooooo01gooooo00<00000
ooooooooool07Oooool00`00003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0>oooool?ool00003oooooooo003o
o`0000[oo`004?ooool6ool00003oooooooo003oo`00013oo`0000?oooooool00?oo00003Ooo000@
ooooo`Koo`0000?oooooool00?oo00004?oo00001?ooooooo`00ool00?oo000nooooo`0300000?oo
oooooooo00Cooooo000Cooooo`04o`000?ooooooooooo`0000;ooooo1_oo00000oooooooo`00ool0
000=ool000;ooooo00Coo`00ooooooooool0o`000_ooool0103o003oooooooooo`3o0003ooooo`04
0?l00?oooooooooo0?l000;ooooo00?oo`00oooooooo00003_oo00000oooooooo`00ool0000@ool0
0003oooooooo003oo`0000goo`000_ooool00`3o003oooooool0000>ool00003oooooooo003oo`00
013oo`0000?oooooool00?oo00004?oo00000oooooooo`00ool00004ool00003ooooo`3o003ooooo
00Woo`0000?oooooool00?oo00004?oo00000oooooooo`00ool0000=ool00003oooooooo003oo`00
00Coo`0000Goooooool00?oooooooooo0?l00003ooooo`040?l00?oooooooooo0?l000;ooooo00@0
o`00ooooooooool0o`000_ooool00ooo003oooooool00008ool00003oooooooo003oo`0000[oo`00
1_ooool001?ooooo00Co0000oooooooooooo00000_ooool6ool00003oooooooo003oo`0000goo`00
00Koooooool00?oo003oo`00ooooo`3o0002ooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00
ool00?oo003oo`00ooooo`0Bool00003oooooooo003oo`00013oo`0000?oooooool00?oo00003Ooo
0002ooooo`030?l00?ooooooo`0000koo`0000?oooooool00?oo00004?oo00000oooooooo`00ool0
000@ool00003oooooooo003oo`0000Coo`0000?ooooo0?l00?ooool02Ooo00000oooooooo`00ool0
000@ool00003oooooooo003oo`0000goo`0000?oooooool00?oo00002_oo0002ooooo`040?l00?oo
oooooooo0?l000;ooooo00D0o`00ooooooooool0o`00ooooo`0<ool00003oooooooo003oo`0000[o
o`001_ooool001?ooooo00Co0000oooooooooooo00000_ooool6ool00003oooooooo003oo`0000go
o`0000?oooooool00?oo00001?oo00001Oooool0o`00ooooooooool0o`0000?ooooo00D0o`00ool0
0?oo003oo`00ooooo`0Bool00004oooooooo003oo`00ool001cooooo0ooo0002ooooo`030?l00?oo
ooooo`0000Soo`00:Oooool3ool00003oooooooo003oo`0000Coo`0000?ooooo0?l00?ooool00ooo
000Mooooo`coo`0000?oooooool00?oo00002_oo0002ooooo`040?l00?oooooooooo0?l000;ooooo
00<0o`00oooooooo00003_oo00000oooooooo`00ool0000:ool000Kooooo000Dooooo`;o00001Ooo
ool00`00003oooooooooo`0Booooo`Koo`0000Kooooo0?l00?oooooooooo0?l00?ooool6ool00004
oooooooo003oo`00ool003Cooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0boooo
o`Woo`000_ooool01@3o003oooooooooo`3o003ooooo00Koo`005Oooool00`00003oooooooooo`04
ooooo`006oooool00`00003oooooooooo`0Eooooo`Koo`0000?ooooo0?l00?ooool00ooo000koooo
o`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0>?ooool3ool000;ooooo00<0o`00oooo
oooo00001Ooo000Hooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01So
oooo0ooo00000oooool0o`00ooooo`03ool003_ooooo00<0o`00ooooooooool0??ooool00`3o003o
ooooooooo`0hooooo`?oo`000_ooool00`3o003oooooool00002ool001_ooooo00<00000oooooooo
ool01?ooool001_ooooo00<00000ooooooooool06?ooool3ool00003ooooo`3o003ooooo03kooooo
00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?ooooooo`0000;oo`00
6oooool00`00003oooooooooo`04ooooo`006oooool00`00003o0000ooooo`0Looooo`030?l00?oo
oooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oo
oooooooo01cooooo00?o000000000?ooool01Oooool001_ooooo00<00000ooooooooool07?ooool0
0`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool0
0`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo
01cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo
03gooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`006oooool00`00003o
ooooooooo`0Looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003o
ooooooooo`0mooooo`030?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool001_ooooo
00<00000ooooooooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo
00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo
000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003ooooooooo
o`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool07Oooool00`00003ooooooooo
o`04ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo03gooooo00<0o`00
ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo01gooooo00<00000
ooooooooool01?ooool001_ooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`0moooo
o`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Moooo
o`0300000?oooooooooo00Cooooo000Kooooo`0300000?l0003ooooo01cooooo00<0o`00oooooooo
ool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00oooooooo
ool07?ooool00ol000000000ooooo`05ooooo`006oooool00`00003oooooooooo`0Looooo`030?l0
0?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l0
0?oooooooooo01gooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool07?oo
ool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Ooo
ool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooo
oooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooo
oooo03gooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`006oooool00`00
003oooooooooo`0Looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o
003oooooooooo`0mooooo`030?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool001_o
oooo00<00000ooooooooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03co
oooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003ooooo
ooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool07Oooool00`00003ooooo
ooooo`04ooooo`006oooool00`00003o0000ooooo`0Looooo`030?l00?oooooooooo03gooooo00<0
o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo01cooooo00?o
000000000?ooool01Oooool001_ooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`0m
ooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0M
ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00oooo
ooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00oooo
ooooool07Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0Looooo`03
0?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`03
0?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0
7?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0
?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo0006ooooo`Go00000ooo
ool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0?Ooo
ool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool07Ooo
ool00`00003oooooooooo`04ooooo`001oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Looooo`03
0?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`03
0?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool000Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00oooo
ooooool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo0009ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00<00000o`000?ooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooo
oooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Kooooo`<000001_ooool0
00Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo03gooooo
00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo01gooooo
00<00000ooooooooool01?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Loooo
o`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0moooo
o`030?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool000Oooooo0ol00004ooooo`;o
00001?ooool2o`0000Gooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`0mooooo`03
0?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Mooooo`03
00000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0
?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0
7Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oo
oooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oo
oooooooo01gooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool07?ooool0
0`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool0
0`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?l0003ooooo
01cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo
03gooooo00<0o`00ooooooooool07?ooool00ol000000000ooooo`05ooooo`006oooool00`00003o
ooooooooo`0Looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003o
ooooooooo`0mooooo`030?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool001_ooooo
00<00000ooooooooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo
00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo
000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003ooooooooo
o`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool07Oooool00`00003ooooooooo
o`04ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo03gooooo00<0o`00
ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo01gooooo00<00000
ooooooooool01?ooool001_ooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`0moooo
o`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Moooo
o`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00oooooooo
ool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00oooooooo
ool07Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0Looooo`030?l0
0?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l0
0?oooooooooo01gooooo00<00000ooooooooool01?ooool001_ooooo00<00000o`000?ooool07?oo
ool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Ooo
ool00`3o003oooooooooo`0Looooo`03o`000000003ooooo00Gooooo000Kooooo`0300000?oooooo
oooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooo
oooo03gooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`006oooool00`00
003oooooooooo`0Looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o
003oooooooooo`0mooooo`030?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool001_o
oooo00<00000ooooooooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03co
oooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003ooooo
ooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool07Oooool00`00003ooooo
ooooo`04ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo03gooooo00<0
o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo01gooooo00<0
0000ooooooooool01?ooool001_ooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`0m
ooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0M
ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?l0003ooooo01cooooo00<0o`00oooo
ooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00oooo
ooooool07?ooool00ol000000000ooooo`05ooooo`006oooool00`00003oooooooooo`0Looooo`03
0?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`03
0?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0
7?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0
?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oo
oooooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oo
oooooooo03gooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`006oooool0
0`00003oooooooooo`0Looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool0
0`3o003oooooooooo`0mooooo`030?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool0
00Sooooo0ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool07?ooool00`3o
003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o
003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo0009ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000
ooooooooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00
ooooooooool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo0006oooo
o`Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0
o`00ooooooooool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo0006
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?l0003ooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003o
ooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool06oooool3000000Ko
oooo0007ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o
003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool07Oooool00`00
003oooooooooo`04ooooo`002?ooool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0?Oooool0
0`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool07Oooool0
0`00003oooooooooo`04ooooo`002Oooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`00
00Gooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo
03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo
00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003o
ooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool07Oooool00`00003o
ooooooooo`04ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo03gooooo
00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo01gooooo
00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool07?ooool00`3o003ooooooooo
o`0mooooo`030?l00?oooooooooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003ooooooooo
o`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?l0003ooooo01cooooo00<0o`00
ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00
ooooooooool07?ooool00ol000000000ooooo`05ooooo`006oooool00`00003oooooooooo`0Loooo
o`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??ooool00`3o003oooooooooo`0moooo
o`030?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool001_ooooo00<00000oooooooo
ool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo03cooooo00<0o`00oooooooo
ool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`030000
0?oooooooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0looooo`030?l0
0?oooooooooo03gooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`006ooo
ool00`00003oooooooooo`0Looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool0??oo
ool00`3o003oooooooooo`0mooooo`030?l00?oooooooooo01gooooo00<00000ooooooooool01?oo
ool001_ooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`0mooooo`030?l00?oooooo
oooo03cooooo00<0o`00ooooooooool0?Oooool00`3o003oooooooooo`0Mooooo`0300000?oooooo
oooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0?Oooool00`3o
003oooooooooo`0looooo`030?l00?oooooooooo03gooooo00<0o`00ooooooooool07Oooool00`00
003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo03_o
oooo0ooo000mooooo`?oo`00?_ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?l0003ooooo01cooooo00<0o`00ooooooooool0>oooool3ool003gooooo
0ooo000nooooo`030?l00?oooooooooo01cooooo00?o000000000?ooool01Oooool001_ooooo00<0
0000ooooooooool07?ooool00`3o003oooooooooo`0kooooo`?oo`00?Oooool3ool003kooooo00<0
o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0L
ooooo`030?l00?oooooooooo0;cooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04
ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo0;cooooo00<0o`00oooo
ooooool07Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0Looooo`03
0?l00?oooooooooo0;cooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`00
6oooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo0;cooooo00<0o`00ooooooooool0
7Oooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oo
oooooooo0;cooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`006oooool0
0`00003o0000ooooo`0Looooo`030?l00?oooooooooo0;cooooo00<0o`00ooooooooool07?ooool0
0ol000000000ooooo`05ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo
0;cooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`006oooool00`00003o
ooooooooo`0Looooo`030?l00?oooooooooo0;cooooo00<0o`00ooooooooool07Oooool00`00003o
ooooooooo`04ooooo`006oooool00`00003oooooooooo`0Looooo`030?l00?oooooooooo0;cooooo
00<0o`00ooooooooool07Oooool00`00003oooooooooo`04ooooo`006oooool00`00003ooooooooo
o`0Looooo`030?l00?oooooooooo0;cooooo00<0o`00ooooooooool07Oooool00`00003ooooooooo
o`04ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0L
ooooo`030?l00?oooooooooo0;cooooo00<0o`00ooooooooool07Oooool00`00003oooooooooo`04
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0
_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo0006ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`2looooo`030?l00?oooooooooo
01gooooo00<00000ooooooooool01?ooool000Kooooo1?l00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003o0000ooooo`0Looooo`030?l00?oooooo
oooo0;cooooo00<0o`00ooooooooool06oooool3000000Kooooo0006ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oo
oooooooo00Cooooo0007ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0
_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo0008ooooo`;o00001?oo
ool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?oo
ool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooo
oooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooo
oooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o
003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01co
oooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?l0003ooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003ooooo
ooooo`0Looooo`03o`000000003ooooo00Gooooo000Kooooo`0300000?oooooooooo01cooooo00<0
o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000K
ooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0M
ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00oooo
ooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`03
00000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`03
00000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0
_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oo
oooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oo
oooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool0
0`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?l0003ooooo
01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Looooo`03o`000000003ooooo
00Gooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003o
ooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo
00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo
000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003ooooooooo
o`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00
ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Koooo
o`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Moooo
o`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00oooooooo
ool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`030000
0?l0003ooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Looooo`03o`00
0000003ooooo00Gooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?oo
ool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooo
oooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooo
oooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o
003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01co
oooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Co
oooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo01cooooo
00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo
0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`2loooo
o`030?l00?oooooooooo01gooooo00<00000ooooooooool01?ooool000Kooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`0Looooo`030?l00?oooooooooo0;cooooo00<0o`00ooooooooool07Ooo
ool00`00003oooooooooo`04ooooo`001oooool3o`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00004ooooo`0300000?l0003ooooo01cooooo00<0o`00ooooooooool0
_?ooool00`3o003oooooooooo`0Kooooo`<000001_ooool000Kooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`0Looooo`030?l00?oooooooooo0;cooooo00<0o`00ooooooooool07Oooool00`00
003oooooooooo`04ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo01cooooo00<0
o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo0007
ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo01cooooo00<0o`00
ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Koooo
o`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Moooo
o`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00oooooooo
ool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`030000
0?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`030000
0?oooooooooo00Cooooo000Kooooo`0300000?l0003ooooo01cooooo00<0o`00ooooooooool0_?oo
ool00`3o003oooooooooo`0Looooo`03o`000000003ooooo00Gooooo000Kooooo`0300000?oooooo
oooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooo
oooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o
003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01co
oooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003ooooo
ooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0
o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000K
ooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0M
ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00oooo
ooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`03
00000?l0003ooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Looooo`03
o`000000003ooooo00Gooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0
_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oo
oooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oo
oooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool0
0`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo
01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo
00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003o
ooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo
00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo
000Kooooo`0300000?l0003ooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003ooooooooo
o`0Looooo`03o`000000003ooooo00Gooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00
ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Koooo
o`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Moooo
o`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo01cooooo00<0o`00oooooooo
ool0_?ooool00`3o003oooooooooo`0Mooooo`0300000?oooooooooo00Cooooo000Kooooo`030000
0?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003oooooooooo`0Mooooo`030000
0?oooooooooo00Cooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`0300000?oooooooooo01cooooo00<0o`00ooooooooool0_?ooool00`3o003ooooo
ooooo`0Mooooo`0300000?oooooooooo00Cooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool07?ooool00`3o003oooooooooo`2looooo`030?l00?oooooooooo
01gooooo00<00000ooooooooool01?ooool000;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`0Kooooo`?oo`00^oooool3ool001oooooo00<00000ooooooooool01?oo
ool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o0000ooooo`0Kooooo`?o
o`00^oooool3ool001gooooo0`000006ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo01_ooooo0ooo000Nooooo`0300000?oooooooooo01gooooo00<00000
ooooooooool07Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01gooooo00<00000
ooooooooool06oooool3ool001oooooo00<00000ooooooooool01?ooool00003ooooool0003o0000
00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`030000
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00`00003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00<00000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`030000
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00<00000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`030000
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`04ooooo`000_oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooool000001_oo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-48.5647, -128.844, \
0.315178, 6.67754}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example #3: product of two sinusoids", "Subsection"],

Cell[CellGroupData[{

Cell["Continuous-time waveform", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f1[t_] := 
        Sin[2  \[Pi]\ t]\ Sin[2  \[Pi]\ 30\ t];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f1[t], {t, 0, 1}, \ 
        PlotStyle \[Rule] Blue];\)\), "\[IndentingNewLine]", 
    \(\[Florin][t] \[Equal] f1[t]\  // \ TraditionalForm\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.308952 0.294793 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01416 -12 -4.5 ]
[-0.0125 .01416 0 4.5 ]
[-0.0125 .16156 -24 -4.5 ]
[-0.0125 .16156 0 4.5 ]
[-0.0125 .30895 -6 -4.5 ]
[-0.0125 .30895 0 4.5 ]
[-0.0125 .45635 -18 -4.5 ]
[-0.0125 .45635 0 4.5 ]
[-0.0125 .60375 -6 -4.5 ]
[-0.0125 .60375 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01416 m
.00625 .01416 L
s
[(-1)] -0.0125 .01416 1 0 Mshowa
0 .16156 m
.00625 .16156 L
s
[(-0.5)] -0.0125 .16156 1 0 Mshowa
0 .30895 m
.00625 .30895 L
s
[(0)] -0.0125 .30895 1 0 Mshowa
0 .45635 m
.00625 .45635 L
s
[(0.5)] -0.0125 .45635 1 0 Mshowa
0 .60375 m
.00625 .60375 L
s
[(1)] -0.0125 .60375 1 0 Mshowa
.125 Mabswid
0 .04364 m
.00375 .04364 L
s
0 .07312 m
.00375 .07312 L
s
0 .1026 m
.00375 .1026 L
s
0 .13208 m
.00375 .13208 L
s
0 .19103 m
.00375 .19103 L
s
0 .22051 m
.00375 .22051 L
s
0 .24999 m
.00375 .24999 L
s
0 .27947 m
.00375 .27947 L
s
0 .33843 m
.00375 .33843 L
s
0 .36791 m
.00375 .36791 L
s
0 .39739 m
.00375 .39739 L
s
0 .42687 m
.00375 .42687 L
s
0 .48583 m
.00375 .48583 L
s
0 .51531 m
.00375 .51531 L
s
0 .54479 m
.00375 .54479 L
s
0 .57427 m
.00375 .57427 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01416 m
1 .01416 L
s
.99375 .16156 m
1 .16156 L
s
.99375 .30895 m
1 .30895 L
s
.99375 .45635 m
1 .45635 L
s
.99375 .60375 m
1 .60375 L
s
.125 Mabswid
.99625 .04364 m
1 .04364 L
s
.99625 .07312 m
1 .07312 L
s
.99625 .1026 m
1 .1026 L
s
.99625 .13208 m
1 .13208 L
s
.99625 .19103 m
1 .19103 L
s
.99625 .22051 m
1 .22051 L
s
.99625 .24999 m
1 .24999 L
s
.99625 .27947 m
1 .27947 L
s
.99625 .33843 m
1 .33843 L
s
.99625 .36791 m
1 .36791 L
s
.99625 .39739 m
1 .39739 L
s
.99625 .42687 m
1 .42687 L
s
.99625 .48583 m
1 .48583 L
s
.99625 .51531 m
1 .51531 L
s
.99625 .54479 m
1 .54479 L
s
.99625 .57427 m
1 .57427 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30895 m
1 .30895 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30895 m
.02499 .30948 L
.02605 .31083 L
.02729 .31325 L
.02846 .31614 L
.03056 .32171 L
.03171 .32431 L
.03279 .32603 L
.03395 .32681 L
.03524 .32606 L
.03633 .32394 L
.0375 .32008 L
.03816 .31725 L
.03887 .31363 L
.04017 .30588 L
.04262 .28893 L
.04385 .28042 L
.04518 .27226 L
.04644 .2663 L
.04759 .26289 L
.04824 .262 L
.04895 .26196 L
.04969 .263 L
.05038 .26501 L
.05159 .27101 L
.0529 .28073 L
.05786 .33784 L
.06004 .36306 L
.06128 .37428 L
.06244 .38169 L
.06371 .38559 L
.06442 .38568 L
.06507 .38437 L
.06572 .38171 L
.06643 .37728 L
.06718 .371 L
.06787 .36371 L
.07072 .32156 L
.07376 .26643 L
.07515 .24317 L
.07588 .23237 L
.07665 .22242 L
.07733 .21519 L
.07807 .20903 L
.07938 .20328 L
.08065 .20446 L
.08137 .20814 L
.08202 .21338 L
.08328 .22846 L
.08448 .24817 L
Mistroke
.08914 .35281 L
.09037 .38045 L
.0917 .4065 L
.09295 .42569 L
.0941 .43747 L
.09476 .44137 L
.09549 .44305 L
.09625 .44184 L
.09695 .43794 L
.0982 .42468 L
.0989 .41386 L
.09954 .40206 L
.10213 .33889 L
.10458 .26784 L
.1068 .20812 L
.10804 .18124 L
.10918 .16286 L
.11046 .15078 L
.1111 .14841 L
.1118 .14878 L
.11308 .15744 L
.11426 .17443 L
.1149 .18704 L
.1156 .20313 L
.11686 .23783 L
.11923 .31514 L
.12175 .39955 L
.12309 .43785 L
.12383 .45558 L
.12453 .46969 L
.12579 .48755 L
.12694 .4944 L
.12802 .49212 L
.12919 .48002 L
.13043 .45687 L
.13175 .42193 L
.13413 .33969 L
.13635 .25319 L
.13843 .17955 L
.13956 .14694 L
.14059 .12393 L
.14174 .10711 L
.14296 .1004 L
.14416 .10571 L
.14547 .12466 L
.1467 .15423 L
.14784 .19019 L
.15232 .37455 L
.15354 .42391 L
.15485 .47017 L
Mistroke
.15608 .50451 L
.15722 .52606 L
.15848 .53747 L
.15969 .5351 L
.16099 .51801 L
.16173 .50197 L
.16241 .48329 L
.1648 .39436 L
.16705 .29089 L
.16909 .19745 L
.17021 .15244 L
.17125 .11691 L
.17238 .08743 L
.17361 .06748 L
.17466 .06167 L
.17578 .06722 L
.1771 .08898 L
.17835 .12361 L
.17946 .1647 L
.18068 .21775 L
.18521 .43893 L
.18645 .48998 L
.18776 .53234 L
.18887 .55709 L
.19009 .5705 L
.19079 .57138 L
.19143 .56776 L
.19217 .55842 L
.19286 .54468 L
.1941 .50918 L
.19544 .45691 L
.20047 .20171 L
.20169 .14476 L
.203 .09392 L
.20375 .07094 L
.20444 .05446 L
.20513 .04258 L
.20578 .03586 L
.20646 .03373 L
.20718 .03687 L
.20847 .05637 L
.20927 .07668 L
.21001 .10108 L
.2114 .15856 L
.21621 .41376 L
.21753 .47802 L
.21894 .53435 L
.21962 .55571 L
.22027 .5718 L
.22148 .59028 L
Mistroke
.22267 .59282 L
.22392 .57848 L
.225 .55296 L
.22618 .51206 L
.22881 .38468 L
.23128 .24531 L
.2325 .17961 L
.23383 .11634 L
.23509 .06857 L
.23626 .03735 L
.23697 .02534 L
.23761 .01926 L
.23836 .0181 L
.23906 .02275 L
.24028 .04413 L
.24098 .0632 L
.24162 .08487 L
.24383 .18544 L
.2459 .30131 L
.24836 .43954 L
.24953 .49633 L
.2506 .54016 L
.25173 .57474 L
.25296 .59737 L
.25404 .60332 L
.25519 .5949 L
.25639 .57025 L
.25753 .53357 L
.25877 .48047 L
.2601 .41175 L
.26473 .15266 L
.26606 .09301 L
.26732 .05035 L
.26845 .02559 L
.26967 .01472 L
.27032 .01594 L
.27104 .02293 L
.27179 .03637 L
.27249 .05437 L
.27374 .09845 L
.27509 .16004 L
.28014 .44066 L
.28145 .50303 L
.28284 .55497 L
.28364 .57655 L
.28437 .59026 L
.2851 .59816 L
.28579 .60006 L
.28644 .59686 L
.28713 .58827 L
Mistroke
.28837 .56008 L
.28906 .53779 L
.2897 .5132 L
.29116 .44596 L
.2937 .30625 L
.29639 .16059 L
.2975 .11099 L
.29869 .06842 L
.3 .03732 L
.30123 .02473 L
.30251 .02939 L
.30315 .03849 L
.30385 .05338 L
.3051 .09154 L
.30625 .13863 L
.30911 .28598 L
.3117 .42568 L
.31289 .48089 L
.31417 .52967 L
.31538 .56253 L
.3165 .57985 L
.31768 .58374 L
.31899 .5707 L
.31964 .55752 L
.32034 .53879 L
.32162 .4942 L
.3266 .24582 L
.32779 .18721 L
.32905 .13275 L
.33013 .09515 L
.33132 .06523 L
.33237 .0502 L
.33351 .0466 L
.33458 .0553 L
.33556 .07324 L
.33664 .10278 L
.33781 .14542 L
.34018 .25413 L
.34271 .38027 L
.34404 .44059 L
.34545 .49387 L
.34668 .52833 L
.34739 .54209 L
.34804 .55084 L
.34919 .5562 L
.35043 .54767 L
.35163 .52605 L
.35293 .48905 L
.3553 .39462 L
.3576 .28756 L
Mistroke
.35976 .19243 L
.36108 .14447 L
.36178 .12383 L
.36252 .10601 L
.36382 .08547 L
.36502 .07979 L
.36568 .08222 L
.3664 .08916 L
.36769 .11248 L
.36847 .13294 L
.36922 .15608 L
.37062 .20741 L
.37541 .40746 L
.37672 .45235 L
.37741 .47195 L
.37814 .48912 L
.37877 .50104 L
.37947 .51047 L
.3807 .51749 L
.38196 .51186 L
.38312 .49585 L
.38375 .48285 L
.38445 .46579 L
.3857 .42802 L
.39035 .25314 L
.39169 .20712 L
.39295 .17127 L
.39425 .14356 L
.39495 .13347 L
.39569 .12642 L
.39701 .12384 L
.39826 .13299 L
.39939 .15019 L
.40061 .17738 L
.40524 .32536 L
.40646 .36535 L
.40778 .40381 L
.40892 .43121 L
.41017 .45345 L
.41135 .46595 L
.4126 .46964 L
.41375 .46437 L
.41482 .45234 L
.41589 .43433 L
.41686 .41346 L
.41903 .3557 L
.42152 .28339 L
.42386 .2244 L
.42503 .20198 L
.42629 .18495 L
Mistroke
.42701 .17887 L
.4277 .17563 L
.42898 .17625 L
.43008 .18353 L
.43125 .19756 L
.43236 .21589 L
.43337 .23591 L
.43816 .34658 L
.43946 .37224 L
.44017 .38416 L
.44084 .39372 L
.44201 .40648 L
.4433 .41392 L
.44402 .41499 L
.4447 .41399 L
.44598 .40708 L
.4467 .40058 L
.44736 .39305 L
.44886 .37161 L
.45371 .28594 L
.45504 .26572 L
.45576 .25634 L
.45644 .24885 L
.45763 .23884 L
.45894 .23298 L
.46019 .23244 L
.46137 .23626 L
.46244 .2429 L
.46359 .25299 L
.466 .28065 L
.46855 .31256 L
.47079 .33612 L
.47206 .34592 L
.47325 .3522 L
.47434 .35533 L
.47534 .35603 L
.47649 .35441 L
.47759 .35074 L
.47888 .34421 L
.48006 .33682 L
.4827 .31834 L
.4839 .31037 L
.48517 .30307 L
.48625 .29806 L
.48744 .29408 L
.4881 .29259 L
.48881 .29156 L
.4901 .29115 L
.49087 .2917 L
.4916 .29269 L
Mistroke
.49226 .29391 L
.49297 .29551 L
.49548 .30209 L
.4968 .30526 L
.49751 .30667 L
.49818 .30771 L
.49939 .30881 L
.50003 .30895 L
.50072 .30876 L
.50193 .30755 L
.50304 .30561 L
.50538 .2998 L
.50644 .29699 L
.50759 .29422 L
.50885 .29203 L
.50954 .29133 L
.51019 .29109 L
.51134 .29173 L
.51258 .29412 L
.51327 .29625 L
.51403 .29921 L
.5154 .30615 L
.51798 .32305 L
.51929 .33234 L
.5207 .34172 L
.52195 .34863 L
.52326 .35375 L
.524 .35539 L
.5248 .35605 L
.52553 .35553 L
.52621 .35405 L
.5275 .34855 L
.52823 .34397 L
.52888 .33891 L
.53379 .2833 L
.53508 .26746 L
.53648 .25238 L
.53779 .24127 L
.53899 .23466 L
.54015 .23211 L
.54142 .23405 L
.54262 .24056 L
.54373 .25055 L
.54505 .26694 L
.54625 .28528 L
.54894 .3332 L
.55122 .37281 L
.55241 .39015 L
.55368 .40418 L
.55478 .41197 L
Mistroke
.556 .41499 L
.5571 .41236 L
.55813 .40521 L
.57892 .29594 L
.58134 .36644 L
.58267 .40205 L
.58392 .43052 L
.58462 .44365 L
.58526 .45356 L
.58598 .46194 L
.58675 .46765 L
.58802 .46904 L
.58866 .46584 L
.58936 .45938 L
.59066 .43954 L
.59184 .41344 L
.59449 .33424 L
.59698 .24962 L
.59807 .21463 L
.59926 .18054 L
.60041 .15404 L
.60149 .13608 L
.60262 .12536 L
.60384 .12406 L
.60448 .12769 L
.60517 .135 L
.60644 .1569 L
.60767 .18786 L
.60881 .22361 L
.61109 .30826 L
.6135 .4005 L
.61556 .46602 L
.61673 .49299 L
.61782 .50963 L
.61911 .51747 L
.62028 .51288 L
.62093 .50554 L
.62163 .49381 L
.62291 .46315 L
.6243 .41821 L
.62577 .36071 L
.62841 .24734 L
.63069 .15895 L
.63198 .12068 L
.63315 .09579 L
.63447 .08133 L
.63513 .07979 L
.63585 .0826 L
.63716 .09955 L
.63838 .12822 L
Mistroke
.63955 .16593 L
.64081 .21583 L
.6431 .32045 L
.64514 .41432 L
.64622 .45874 L
.64739 .49919 L
.64864 .53203 L
.64982 .55057 L
.65051 .55549 L
.65116 .55592 L
.65239 .54555 L
.65353 .52314 L
.6546 .49233 L
.657 .39425 L
.66162 .16932 L
.66288 .119 L
.66358 .0962 L
.66422 .07845 L
.66536 .05617 L
.66661 .04636 L
.66778 .05169 L
.66889 .06958 L
.66989 .09564 L
.67097 .13346 L
.67563 .36372 L
.67693 .42937 L
.67832 .49158 L
.67963 .53812 L
.68083 .56749 L
.68148 .57737 L
.68218 .58321 L
.68346 .58027 L
.68418 .57084 L
.68495 .55481 L
.68568 .53434 L
.68634 .51166 L
.69106 .27682 L
.69235 .2071 L
.69373 .13947 L
.69493 .09076 L
.69623 .05148 L
.69754 .0289 L
.69878 .02477 L
.69999 .03719 L
.70111 .06257 L
.70229 .10281 L
.7036 .16049 L
.70626 .30375 L
.70855 .43093 L
.70975 .4896 L
Mistroke
.71102 .54046 L
.71213 .57341 L
.71335 .59483 L
.71445 .6 L
.71548 .59231 L
.71679 .56579 L
.71752 .54314 L
.7182 .51784 L
.72076 .39246 L
.72324 .25037 L
.72555 .12895 L
.72675 .07924 L
.72804 .04023 L
.72878 .02566 L
.72947 .01734 L
.73078 .01672 L
.73144 .02392 L
.73215 .03701 L
.73342 .07375 L
.7342 .1038 L
.73494 .13654 L
.73631 .20685 L
.73876 .34748 L
.7401 .42313 L
.74138 .4873 L
.74257 .53694 L
.74385 .57657 L
.74502 .5976 L
.74611 .6033 L
.74724 .59479 L
.7485 .56871 L
.74981 .52454 L
.75104 .47004 L
.7538 .31847 L
.75644 .17156 L
.75751 .12024 L
.75866 .07506 L
.75992 .03947 L
.76109 .02135 L
.76224 .01851 L
.76332 .02954 L
.76429 .05033 L
.76534 .0835 L
.7665 .13103 L
.76777 .19364 L
.77033 .33695 L
.77272 .46376 L
.77377 .50997 L
.77493 .55071 L
.77614 .57966 L
Mistroke
.77743 .59321 L
.77811 .59292 L
.77884 .5869 L
.78016 .5615 L
.78142 .52137 L
.78275 .46517 L
.78512 .34175 L
.78727 .22431 L
.78956 .11709 L
.79088 .07243 L
.79208 .0459 L
.79329 .03421 L
.79442 .03749 L
.79563 .05588 L
.79632 .07278 L
.79696 .09248 L
.79964 .20721 L
.80211 .33672 L
.80445 .45247 L
.80576 .5046 L
.80646 .52687 L
.80719 .54599 L
.80849 .56705 L
.8097 .5713 L
.81043 .56661 L
.81122 .5555 L
.81197 .53953 L
.81265 .52048 L
.81396 .47422 L
.81533 .41411 L
.81767 .29832 L
.82021 .17812 L
.82138 .13306 L
.82261 .09589 L
.82367 .07438 L
.82483 .06268 L
.82615 .06526 L
.82689 .07402 L
.82757 .08645 L
.82883 .1195 L
.83015 .16633 L
.8325 .26941 L
.835 .3855 L
.83622 .43623 L
.83738 .47677 L
.83842 .50539 L
.83954 .52673 L
.84061 .53689 L
.84174 .5365 L
.8427 .52721 L
Mistroke
.84376 .50802 L
.84501 .47465 L
.84615 .43578 L
.84871 .33038 L
.8511 .22973 L
.85334 .15303 L
.85444 .12655 L
.85562 .10795 L
.85693 .1004 L
.85813 .10582 L
.85932 .12223 L
.86061 .15151 L
.86197 .19243 L
.86323 .23737 L
.86549 .32481 L
.86794 .41247 L
.86906 .44469 L
.87025 .47095 L
.87127 .48597 L
.87239 .49399 L
.8737 .49178 L
.87443 .48521 L
.8751 .47601 L
.8764 .45032 L
.87764 .41778 L
.88241 .26019 L
.8837 .22153 L
.88507 .18757 L
.88637 .16439 L
.88754 .15196 L
.88826 .14862 L
.88892 .14846 L
.88965 .15146 L
.89042 .15813 L
.89172 .17682 L
.89245 .19112 L
.89314 .20653 L
.89814 .34639 L
.89952 .38145 L
.90097 .41164 L
.90222 .43 L
.90292 .437 L
.90359 .44117 L
.9048 .44272 L
.90608 .43609 L
.90716 .42423 L
.90835 .40561 L
.91102 .34914 L
.91349 .29045 L
.91465 .26507 L
Mistroke
.91591 .24119 L
.9171 .22328 L
.91819 .2115 L
.91918 .20513 L
.92027 .20292 L
.9214 .2059 L
.92246 .21326 L
.9237 .22677 L
.92488 .24359 L
.92708 .28172 L
.92947 .32478 L
.93072 .34496 L
.93205 .3627 L
.93269 .36973 L
.9334 .37604 L
.93465 .38339 L
.93591 .38583 L
.93709 .38365 L
.93825 .37769 L
.9393 .36942 L
.94166 .3438 L
.94404 .3139 L
.94657 .28561 L
.94788 .2745 L
.94863 .26965 L
.94934 .26615 L
.95057 .26251 L
.95126 .26187 L
.9519 .26212 L
.95304 .26448 L
.9541 .26859 L
.95526 .2748 L
.9565 .2828 L
.959 .30035 L
.96022 .30838 L
.96135 .3148 L
.96245 .31987 L
.9636 .32376 L
.96476 .32607 L
.96604 .32681 L
.9671 .32616 L
.96824 .32441 L
.96932 .32203 L
.9703 .31949 L
.97166 .31582 L
.97312 .31237 L
.97388 .31094 L
.97471 .30978 L
.97547 .30915 L
.97619 .30895 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`008?ooool2o`0002Wooooo0_l00004ooooo`04o`000?oooooooooooooo
o`Go00008oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;ooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo0ol0000Tooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`?o0000:?ooool3o`0000Oooooo000Oooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool0000Rooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000008_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:?oo
ool00ol0003oooooooooo`06ooooo`007oooool01?l0003oooooooooool0000Wooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00007ooooo`Go
00008Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:?ooool00ol0003ooooo
ooooo`06ooooo`007oooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0002;ooooo00Co0000oooooooooooo00001oooool4o`0002?ooooo00Co0000oooooooooooo0000
2?ooool3o`0002Wooooo00?o0000ooooooooool01_ooool001oooooo00Co0000oooooooooooo0000
9oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo000002;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00000Xooooo`03o`000?oooooooooo00Kooooo000Oooooo`04o`000?ooooooooooo`0002Oo
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000002;ooooo00Co0000
oooooooooooo00002Oooool2o`0002;ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`0Sooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Woooo
o`;o00002?ooool0023ooooo0_l0000Yooooo`;o00002Oooool3o`0002Cooooo0_l0000;ooooo`03
o`000?oooooooooo027ooooo0_l0000:ooooo`;o00009?ooool2o`0000Wooooo0ol0000Yooooo`03
o`000?oooooooooo00Kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo000Koooooooo00001Ol00001ooooo`004oooool3o`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool1o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0ooooool1ooooo`7o00000Oooool000cooooo1Ol00003ooooo`03o`000?oooooooooo
00Cooooo0_l00014ooooo`03o`00oooooooooooo0;Wooooo0_l00001ooooo`005?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03_ooooo00?o003oooooooooool01Oooool00ol00?oo
ooooooooo`1dooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0>_ooool1o`00007o
oooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool2o`00o`Kooooo
0_l00?mfooooo`03o`00oooooooooooo00Gooooo0_l00?llooooo`7o00000Oooool001?ooooo0_l0
0006ooooo`03o`000?oooooooooo03[ooooo0_l00?l6ooooo`;o003o1oooool00ol00?oooooooooo
o`1Tooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o??ooool1o`00007ooooo000D
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool2o`00o`Kooooo0_l00?l7
ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?ll
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0<_ooool00ol00?ooooooooooo`05oooo
o`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`05oooo
o`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool0<_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo03;ooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Oooooo00?o003ooooooooo
ool0I?ooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Oooooo00?o003ooooooooo
ool0<_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo03;ooooo0_l00?l6ooooo`;o003o
1_ooool2o`00o`Oooooo00?o003oooooooooool0I?ooool00ol00?ooooooooooo`05ooooo`;o003o
1_ooool2o`00o`Kooooo0_l00?ldooooo`7o00000Oooool001_ooooo0_l0000cooooo`;o003o1_oo
ool2o`00o`Kooooo0_l00?l7ooooo`03o`00oooooooooooo06Cooooo00?o003oooooooooool01Ooo
ool2o`00o`Kooooo0_l00?l6ooooo`;o003o<oooool2o`00007ooooo000Kooooo`03o`000?oooooo
oooo03;ooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Oooooo0_l00?l6ooooo`03o`00oooooooo
oooo05Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2
o`00o`Kooooo0_l00?ldooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0<_ooool2o`00
o`Kooooo0_l00?l6ooooo`;o003o1oooool2o`00o`Kooooo00?o003oooooooooool0E?ooool00ol0
0?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o=?ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo03;ooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Ko
oooo00?o003oooooool00?l01_ooool2o`00oeCooooo0_l00?l7ooooo`;o003o1_ooool2o`00o`Ko
oooo0_l00?l6ooooo`;o003o=?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo03;ooooo
0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo00?o003oooooool00?l01_ooool2o`00oeCooooo
0_l00?l7ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o=?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo02[ooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l0
0?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`;o003oE?ooool2o`00o`Oooooo0_l0
0?l5ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o003o1oooool00ol00?oooooooooo
o`0Zooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0:_ooool00ol00?ooooooooooo`05
ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?mD
ooooo`;o003o1oooool2o`00o`Gooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo0_l00?l7
ooooo`03o`00oooooooooooo02[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Zoooo
o`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo00?o003ooooo
ool00?l01_ooool2o`00oeCooooo0_l00?l7ooooo`;o003o1Oooool00ol00?ooooooo`00o`06oooo
o`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool0:_ooool1o`00007ooooo000Kooooo`;o
0000:oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`03
o`00oooooooo003o00Kooooo0_l00?mDooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o003o1oooool00ol00?ooooooooooo`0Yooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool0:_ooool00ol00?ooooooooooo`05ooooo`;o003o
1_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o
1oooool00ol00?ooooooooooo`13ooooo`03o`00oooooooooooo00Cooooo0_l00?l6ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo0_l00?l7ooooo`03o`00
oooooooooooo02[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Zooooo`;o003o1_oo
ool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`07ooooo`03o`00oooooooooooo04;ooooo0_l00?l6ooooo`;o003o1_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o003o1ooo
ool2o`00ob_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Zooooo`;o003o1Oooool0
0ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01_ooool2o`00odCooooo0_l00?l6ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o02_ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0Zooooo`;o003o1Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00
odCooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
02_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Zooooo`;o003o1Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?m4ooooo`;o003o1_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00o`Ko
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0[ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0:_ooool2o`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`06ooooo`;o003oA?ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l0:oooool1o`00007ooooo000Kooooo`;o00008oooool00ol00?oooooooooo
o`05ooooo`;o003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l0
0?m4ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01_ooool00ol00?ooooooooooo`0Qooooo`;o00000Oooool001_ooooo00?o0000
ooooooooool08_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003oA?ooool2o`00o`Kooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lS
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06oooo
o`;o003oA?ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo0_l00?lSooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool08_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003oA?ooool2o`00o`Kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lS
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool08Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06oooo
o`;o003oA?ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo0_l00?lSooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool08Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003oA?ooool2o`00o`Kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l0
0?lSooooo`7o00000Oooool001_ooooo00?o0000ooooooooool08Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`06ooooo`;o003o1_ooool2o`00ocCooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00ob?o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Qooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Ko
oooo0_l00?l6ooooo`;o003o=?ooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o8oooool1
o`00007ooooo000Kooooo`;o00008_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Gooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_oo
ool2o`00ocCooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00ob;ooooo0_l00001ooooo`00
6oooool00ol0003oooooooooo`0Qooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01_ooool2o`00ocCooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00ob?ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0Qooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01_ooool2o`00ocCooooo0_l00?l6ooooo`;o003o1_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0Sooooo`7o00000Oooool001_ooooo00?o0000ooooooooool08Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?ldooooo`;o003o
1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o02?ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00Cooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`;o003o=?ooool2o`00o`Gooooo
00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o6oooool1o`00
007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`0Iooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`Gooooo0_l00?ldooooo`;o003o1Oooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo0_l00?lKooooo`7o00000Oooool000Oooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool06Ooo
ool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5
ooooo`;o003o=?ooool2o`00o`Gooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`06ooooo`;o003o6oooool1o`00007ooooo0005o`0000;ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`02ooooo`;o00006_ooool2o`00o`Kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`;o003o=?ooool2o`00o`Gooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o6_ooool2
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Iooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Gooooo0_l00?ldooooo`;o003o1Oooool01?l00?ooooooooooool00?l5
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lKooooo`7o00000Oooool000Oooooo00Co
0000oooooooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool06Oooool2o`00o`Kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooo
oooo003o03?ooooo0_l00?l5ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01_ooool2o`00oa_ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool2o`00o`Kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o03;o
oooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Kooooo0_l00?lKooooo`7o00000Oooool000Sooooo0_l00008ooooo`Go00001?ooool0
0ol0003oooooooooo`0Iooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Yoooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l5ooooo`;o003o6oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
01Wooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo02Wooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Gooooo0_l00?lKooooo`7o00000Oooool001_ooooo00?o0000ooooooooool06Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Ooo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o
1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo02Wooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Go
oooo0_l00?lKooooo`7o00000Oooool001_ooooo00?o0000ooooooooool06Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Ooo
ool00ol00?ooooooo`00o`05ooooo`;o003o:oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool2o`00oa_ooooo
0Ol00001ooooo`006oooool2o`0001[ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Ooo
ool2o`00ob_ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`05ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?lJooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool06Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00
oooooooo003o02[ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?lKooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool06?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o02[ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?lKooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`04ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0:_ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo017ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`0Aooooo`;o003o1Oooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`03o`00oooooooo003o02[ooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1Oooool2o`00oa?ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`0Aooooo`;o003o1Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o02[ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Ooo
ool2o`00oa?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Aooooo`;o003o1Oooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o02[o
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00oa?ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0Aooooo`;o003o1Oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o02[ooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00oa?ooooo0Ol00001ooooo`006oooool2
o`0001;ooooo0_l00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooool00?l0:_ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooo003o017ooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`0Aooooo`;o003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l5ooooo`03o`00oooooooo003o02[ooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1Oooool00ol00?ooooooo`00o`0Booooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool04?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0:_ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o01;ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00
oooooooooooo01;ooooo00?o003oooooooooool03?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o01;ooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`0@ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo0_l0
0?lCooooo`03o`00oooooooooooo00cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1Oooool00ol00?ooooooo`00o`0Booooo`7o00000Oooool001_ooooo00?o0000
ooooooooool04?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`;o003o4_oo
ool00ol00?ooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1Oooool00ol00?ooooooo`00o`0Booooo`7o00000Oooool001_ooooo00?o0000
ooooooooool04?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`;o003o4_oo
ool00ol00?ooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o01;ooooo0Ol00001ooooo`006oooool2
o`00017ooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l04_ooool00ol00?ooooooo`00o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l04Ooo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo013ooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l04_ooool00ol00?ooooooo`00
o`0=ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1Oooool00ol00?ooooooo`00o`0Booooo`7o00000Oooool001_ooooo00?o0000
ooooooooool04?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o
1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooooooo
ool00?l5ooooo`03o`00oooooooo003o01;ooooo00?o003oooooool00?l03Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l3ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o4_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo013ooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooo`00o`0Booooo`03o`00oooooooo003o00gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00oa;ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`09ooooo`;o003o1Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooo
oooo003o01;ooooo00?o003oooooool00?l03Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1_ooool00ol00?ooooooooooo`09ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02Ooo
ool2o`00o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o4Oooool00ol00?ooooooo`00o`0=oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?l;oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00oa7ooooo00?o003oooooool00?l03Oooool01?l00?oooooooooo
ool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool0
0_ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?l;ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00oa7ooooo00?o003oooooool00?l03Oooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l02_ooool1o`00007o
oooo000Kooooo`;o00002Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o4?ooool01Ol00?oooooooooooooooooo003o00cooooo00Co003ooooooooooooo003o
1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o
003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00
o`09ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`05
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l@ooooo`05o`00oooooooooooooooo
ool00?l03?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l02_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00Sooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1?l00?ooooooooooool00?l@ooooo`05o`00ooooooooooooooooool00?l03?ooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooool00?l02_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Sooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo
003o1?ooool2o`00o`Cooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l03?ooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooooooo
ool00?l00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooool00?l02_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00So
oooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o1?ooool3o`00o`?ooooo0_l00?l4ooooo`05o`00ooooooooooooooooool00?l01ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Wooooo
0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool02?ooool01?l00?oooooooooo
ool00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooool00?l00_ooool00ol00?ooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l01oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003o
ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`04o`00oooooooo
ooooo`00o`Wooooo0Ol00001ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Oooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l01oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol0
0?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l02Oooool1o`00007ooooo000C
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooooooool00_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Wooooo0Ol00001ooooo`004oooool01?l0003oooooooooool0
0004ooooo`Ko00000_l00?l2o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000
o`000002o`000004o`00ool0003o0000o`00o`Co000000Go003oo`000?l0003o0000o`00o`03o`00
0005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00Co000000Go
003oo`000?l0003o0000o`00o`03o`000004o`00ool0003o0000o`00o`Co000000Go003oo`000?l0
003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002
o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o0000
00Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001?l0
0?oo0000o`000?l00002o`00o`?o000000Go003oo`000?l0003o0000o`00o`03o`000003o`00ool0
003o000000Co00000_l00?l3o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000
o`000002o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o
00?o000000?o003oo`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00;o000000?o003o
o`000?l000000_l000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000
o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000000ol00?oo0000o`000002o`000005
o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003o
o`000?l0003o0000o`00o`03o`000003o`00ool0003o000000Co00000Oooool001?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00o`?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooooooool01?ooool2o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01?ooool1o`00007ooooo000C
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool01?l00?oooooooooo
ool00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooooooo`04ooooo`;o003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`02
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`04ooooo`7o00000Ooo
ool001Cooooo0_l00005ooooo`03o`000?oooooooooo00Gooooo0_l00?l4ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Sooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`04ooooo`;o003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o
oooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Cooooo0_l00?l7oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool01Oooool2o`00o`Gooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`08ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooooooool01?ooool2o`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`05o`00
ooooooooooooooooool00?l01?ooool2o`00o`Oooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`0<ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`0:
ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool01?ooool2o`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooooooo
ool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0<oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`0:ooooo`03o`00
oooooooo003o00Cooooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo00;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00;ooooo
00Co003ooooooooooooo003o3_ooool1o`00007ooooo000Kooooo`;o00003Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l02_ooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o0_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`02ooooo`04o`00oooooooo
ooooo`00o`gooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0<ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`0:ooooo`03o`00oooooooo003o00Co
oooo00?o003oooooooooool00oooool01?l00?ooooooooooool00?l2ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool03?ooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00
o`0:ooooo`03o`00oooooooo003o00Cooooo00?o003oooooooooool00oooool01?l00?oooooooooo
ool00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o0oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l>ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool03?ooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooo`00o`0:ooooo`03o`00oooooooo003o00Cooooo00?o003ooooo
ooooool00oooool01?l00?ooooooooooool00?l2ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool03?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooo
oooo003o00Cooooo00?o003oooooool00?l01_ooool2o`00o`_ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00cooooo00?o003oooooool00?l01Oooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o00Kooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00oooool01?l0
0?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooooooo
ool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l03_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00cooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`0Jooooo`05o`00oooooooo
ooooooooool00?l00oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o0oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`0>ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool03?ooool00ol00?ooooooo`00
o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o01[ooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool01?l00?oooooooooo
ool00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00kooooo0Ol00001ooooo`006oooool2o`0000gooooo00?o003oooooool0
0?l01Oooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`0Joooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o
00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00
o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooool00?l03Oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00gooooo0_l00?l5
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o01[ooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool0
0?l03_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00gooooo0_l00?l5ooooo`04o`00
ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`04ooooo`03o`00oooooooo003o01[ooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool0
1?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o3oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00gooooo0_l00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol0
0?ooooooo`00o`0Jooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2
o`00o`oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0=ooooo`;o003o1Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`00oooooooo003o01[ooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l5ooooo`;o003o3oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo00gooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0J
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooooooo`0=
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool05?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0Jooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o5_ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo01Gooooo00?o003oooooool00?l01?ooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooo`00o`05
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l06_oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?lFooooo`7o00000Oooool001_ooooo0_l0000F
ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00Cooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o01[ooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l05Oooool2
o`00007ooooo000Kooooo`03o`000?oooooooooo01Gooooo00?o003oooooool00?l01?ooool01?l0
0?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Ooo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`06ooooo`;o003o6_ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooo`00o`0Fooooo`7o00000Oooool001_ooooo00?o0000ooooooooool05Oooool00ol00?oo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool0
0ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo0_l0
0?lJooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooo`00o`0Fooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
5Oooool2o`00o`Gooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01_ooool2
o`00oa_ooooo0_l00?l5ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooool00?l05_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01Gooooo0_l0
0?l5ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Kooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l05_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo01Gooooo0_l00?l5ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o
1?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o02[o
oooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool2o`00oaOooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0Eooooo`;o003o1_ooool00ol00?ooooooo`00o`05oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Ooo
ool00ol00?ooooooo`00o`0Zooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Go
oooo0_l00?lGooooo`7o00000Oooool001_ooooo0_l0000Fooooo`;o003o1_ooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Ooo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1Oooool00ol00?ooooooo`00o`0Zooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooo
ooooo`00o`Gooooo0_l00?lFooooo`;o00000Oooool001_ooooo00?o0000ooooooooool05Oooool2
o`00o`Kooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0:_ooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01Oooool01?l00?ooooooooooool00?l5ooooo`;o003o5oooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo01Gooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
02[ooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1Oooool2o`00oaOooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`0Eooooo`;o003o1_ooool00ol00?ooooooo`00o`05
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`0Zooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lG
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool05Oooool2o`00o`Kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo
00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l0:oooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lGooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05oooo
o`;o003o;?ooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Cooooo00Co003ooooo
oooooooo003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l07oooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00o`05ooooo`;o003o;?ooool2o`00
o`Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o1Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l07oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo01gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo0_l00?l/ooooo`;o003o1_oo
ool2o`00o`Kooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l5ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0O
ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02
ooooo`;o00007_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooool00?l01Oooool2o`00obcooooo0_l00?l6ooooo`;o003o1_ooool00ol00?oooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o01kooooo0_l00001ooooo`001oooool01?l0
003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l0
1Oooool2o`00obcooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`04ooooo`04o`00
ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06
ooooo`;o003o7oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo1?l00005
ooooo`03o`000?oooooooooo01gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`06ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool0:_ooool2o`00o`Kooooo
0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lOooooo`7o00000Oooool000Oo
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooo
oooo003o00Kooooo00?o003oooooooooool0:_ooool00ol00?ooooooooooo`05ooooo`;o003o1_oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Ooo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o7oooool1o`00007ooooo0008ooooo`;o0000
2?ooool5o`0000Cooooo00?o0000ooooooooool07Oooool2o`00o`Kooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l0
1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01_ooool00ol00?ooooooo`00o`0kooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06
ooooo`;o003o7oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01gooooo0_l00?l6oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Kooooo0_l00?llooooo`;o003o1_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`06ooooo`;o003o7oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01gooooo0_l00?l6
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo0_l00?llooooo`;o003o1_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`06ooooo`;o003o7oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01gooooo0_l0
0?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?llooooo`;o003o1_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`06ooooo`;o003o7oooool1o`00007ooooo000Kooooo`;o00007_ooool2o`00o`Kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01_ooool2o`00occooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Kooooo0_l00?lNooooo`;o00000Oooool001_ooooo00?o0000ooooooooool07Oooool2o`00o`Ko
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Ko
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01_ooool2o`00occooooo0_l00?l6ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Kooooo0_l00?lOooooo`7o00000Oooool001_ooooo00?o0000ooooooooool07_ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?llooooo`;o003o1_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`06ooooo`03o`00oooooooooooo01kooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0Uooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`06ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?llooooo`;o003o1_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`0Wooooo`7o00000Oooool001_ooooo00?o0000ooooooooool09Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`06ooooo`;o003o??ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l09oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo02Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00occooooo
0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o02Oooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`0Uooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01_ooool2o`00occooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l09oooool1o`00007ooooo000K
ooooo`;o00009_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06
ooooo`;o003o1_ooool2o`00occooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`0Vooooo`;o00000Oooool001_ooooo00?o0000oooo
ooooool09_ooool2o`00o`Gooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l7oooo
o`03o`00oooooooooooo03[ooooo00?o003oooooooooool01Oooool2o`00o`Kooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Kooooo0_l00?lWooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool09_ooool2o`00o`Gooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?m<ooooo`;o
003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00obOooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`0Vooooo`;o003o1Oooool00ol00?ooooooo`00o`06ooooo`;o003o
1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1_ooool2o`00odcooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o
9oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o003oooooooooool01?oo
ool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00odcooooo0_l00?l6ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`06ooooo`;o003o9oooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo02Kooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2
o`00odcooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2
o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
oooo02Kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo
00Cooooo00?o003oooooool00?l01_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?m<ooooo`;o003o1_ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Vooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0;Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00odco
oooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00o`Ko
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0_ooooo`7o00000Oooool001_ooooo
0_l0000^ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003oC?ooool2o`00o`Kooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00o`Kooooo
00?o003oooooool00?l0;_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo02kooooo0_l0
0?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l0
0?l6ooooo`;o003oC?ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`06ooooo`;o003o1_ooool2o`00o`Kooooo00?o003oooooool00?l0;oooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo02kooooo0_l00?l6ooooo`;o003o1_ooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o003oC?ooool2o`00o`Kooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l`
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0;_ooool2o`00o`Kooooo0_l00?l6oooo
o`;o003o1_ooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?ooooooooooo`1<oooo
o`03o`00oooooooooooo00Gooooo0_l00?l5ooooo`03o`00oooooooo003o00Kooooo0_l00?l6oooo
o`;o003o1_ooool2o`00oc3ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0^ooooo`;o
003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooo003o00Kooooo0_l00?mMooooo`;o
003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1oooool00ol00?ooooooooooo`0^ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0;_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o
1_ooool00ol00?ooooooo`00o`06ooooo`;o003oGOooool2o`00o`Kooooo0_l00?l6ooooo`;o003o
1_ooool2o`00o`Oooooo00?o003oooooooooool0;_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo02kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooo
oooo003o00Kooooo0_l00?mMooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o1_oo
ool2o`00o`Oooooo00?o003oooooooooool0;_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo02kooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooooooo
003o00Kooooo0_l00?mMooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o1_ooool2
o`00o`Oooooo00?o003oooooooooool0;_ooool1o`00007ooooo000Kooooo`;o0000=oooool2o`00
o`Kooooo0_l00?l6ooooo`;o003o1oooool2o`00oegooooo00?o003oooooooooool01Oooool2o`00
o`Kooooo0_l00?l6ooooo`;o003o=oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo03Ko
oooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool0G?ooool00ol00?oo
ooooooooo`05ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?lhooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0=_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1oooool00ol00?oooooo
ooooo`1Looooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003o1_ooool2o`00ocSooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`0fooooo`;o003o1_ooool2o`00o`Oooooo00?o
003oooooooooool0K?ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o>?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo03Kooooo0_l00?l6ooooo`;o003o1oooool00ol00?ooooooooooo`1/
ooooo`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool0=_ooool1o`00007ooooo000Coooo
o`?o00001Oooool00ol0003oooooooooo`0nooooo`;o003o1oooool00ol00?ooooooooooo`1/oooo
o`;o003o1_ooool2o`00o`Oooooo00?o003oooooooooool0=_ooool1o`00007ooooo000Dooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool2o`00o`Oooooo00?o003ooooooooo
ool0K?ooool00ol00?ooooooooooo`05ooooo`;o003o@?ooool1o`00007ooooo000Dooooo`03o`00
0?oooooooooo00Cooooo0_l00010ooooo`03o`00oooooooooooo07cooooo00?o003oooooooooool0
?_ooool2o`00007ooooo000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
ool1ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`03
ooooo`7o00000Oooool001?ooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`005?ooool00ol0003oooooooooo`04oooooooo00001Ol00001ooooo`00oooooolQooooo`00oooo
oolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.135193, -1.23051, \
0.00404426, 0.0130657}}],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](
        t) == \(sin(2\ \[Pi]\ t)\)\ \(sin(60\ \[Pi]\ t)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled continuous-time waveform", "Subsubsection"],

Cell[BoxData[
    \(\(sampleRate = 1000;\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(signal\  = \ 
        Table[f1[t], {t, 0, 1, 1/\((sampleRate - 1)\)}]\  // \ N;\)\), "\n", 
    \(\(ListPlot[signal, \ PlotStyle \[Rule] Blue];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.309501 0.295212 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01429 -12 -4.5 ]
[-0.0125 .01429 0 4.5 ]
[-0.0125 .16189 -24 -4.5 ]
[-0.0125 .16189 0 4.5 ]
[-0.0125 .3095 -6 -4.5 ]
[-0.0125 .3095 0 4.5 ]
[-0.0125 .45711 -18 -4.5 ]
[-0.0125 .45711 0 4.5 ]
[-0.0125 .60471 -6 -4.5 ]
[-0.0125 .60471 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(200)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(400)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(600)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(800)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01429 m
.00625 .01429 L
s
[(-1)] -0.0125 .01429 1 0 Mshowa
0 .16189 m
.00625 .16189 L
s
[(-0.5)] -0.0125 .16189 1 0 Mshowa
0 .3095 m
.00625 .3095 L
s
[(0)] -0.0125 .3095 1 0 Mshowa
0 .45711 m
.00625 .45711 L
s
[(0.5)] -0.0125 .45711 1 0 Mshowa
0 .60471 m
.00625 .60471 L
s
[(1)] -0.0125 .60471 1 0 Mshowa
.125 Mabswid
0 .04381 m
.00375 .04381 L
s
0 .07333 m
.00375 .07333 L
s
0 .10285 m
.00375 .10285 L
s
0 .13237 m
.00375 .13237 L
s
0 .19142 m
.00375 .19142 L
s
0 .22094 m
.00375 .22094 L
s
0 .25046 m
.00375 .25046 L
s
0 .27998 m
.00375 .27998 L
s
0 .33902 m
.00375 .33902 L
s
0 .36854 m
.00375 .36854 L
s
0 .39806 m
.00375 .39806 L
s
0 .42759 m
.00375 .42759 L
s
0 .48663 m
.00375 .48663 L
s
0 .51615 m
.00375 .51615 L
s
0 .54567 m
.00375 .54567 L
s
0 .57519 m
.00375 .57519 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01429 m
1 .01429 L
s
.99375 .16189 m
1 .16189 L
s
.99375 .3095 m
1 .3095 L
s
.99375 .45711 m
1 .45711 L
s
.99375 .60471 m
1 .60471 L
s
.125 Mabswid
.99625 .04381 m
1 .04381 L
s
.99625 .07333 m
1 .07333 L
s
.99625 .10285 m
1 .10285 L
s
.99625 .13237 m
1 .13237 L
s
.99625 .19142 m
1 .19142 L
s
.99625 .22094 m
1 .22094 L
s
.99625 .25046 m
1 .25046 L
s
.99625 .27998 m
1 .27998 L
s
.99625 .33902 m
1 .33902 L
s
.99625 .36854 m
1 .36854 L
s
.99625 .39806 m
1 .39806 L
s
.99625 .42759 m
1 .42759 L
s
.99625 .48663 m
1 .48663 L
s
.99625 .51615 m
1 .51615 L
s
.99625 .54567 m
1 .54567 L
s
.99625 .57519 m
1 .57519 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .3095 m
1 .3095 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02476 .3095 m
.02571 .30985 L
.02667 .31087 L
.02762 .31249 L
.02857 .31459 L
.02952 .31702 L
.03048 .31958 L
.03143 .32209 L
.03238 .32432 L
.03333 .32607 L
.03429 .32714 L
.03524 .32736 L
.03619 .32662 L
.03714 .32482 L
.0381 .32195 L
.03905 .31802 L
.04 .31313 L
.04095 .30742 L
.0419 .3011 L
.04286 .2944 L
.04381 .28762 L
.04476 .28105 L
.04571 .27503 L
.04667 .26987 L
.04762 .26586 L
.04857 .26327 L
.04952 .26234 L
.05048 .26321 L
.05143 .26598 L
.05238 .27067 L
.05333 .27721 L
.05429 .28545 L
.05524 .29517 L
.05619 .30606 L
.05714 .31775 L
.0581 .32982 L
.05905 .34182 L
.06 .35326 L
.06095 .36367 L
.0619 .37257 L
.06286 .37956 L
.06381 .38426 L
.06476 .38639 L
.06571 .38573 L
.06667 .38219 L
.06762 .37578 L
.06857 .36662 L
.06952 .35494 L
.07048 .34107 L
.07143 .32547 L
Mistroke
.07238 .30864 L
.07333 .29118 L
.07429 .27373 L
.07524 .25693 L
.07619 .24145 L
.07714 .22792 L
.0781 .2169 L
.07905 .2089 L
.08 .20432 L
.08095 .20345 L
.0819 .20643 L
.08286 .21329 L
.08381 .22387 L
.08476 .23792 L
.08571 .25501 L
.08667 .27461 L
.08762 .29605 L
.08857 .31861 L
.08952 .34147 L
.09048 .36381 L
.09143 .38479 L
.09238 .4036 L
.09333 .41949 L
.09429 .43179 L
.09524 .43998 L
.09619 .44363 L
.09714 .44252 L
.0981 .43655 L
.09905 .42582 L
.1 .41063 L
.10095 .39142 L
.1019 .3688 L
.10286 .34352 L
.10381 .31644 L
.10476 .28851 L
.10571 .26073 L
.10667 .23412 L
.10762 .20967 L
.10857 .18831 L
.10952 .17089 L
.11048 .15812 L
.11143 .15055 L
.11238 .14857 L
.11333 .15236 L
.11429 .16188 L
.11524 .17691 L
.11619 .19699 L
.11714 .2215 L
.1181 .24962 L
.11905 .2804 L
Mistroke
.12 .31278 L
.12095 .3456 L
.1219 .37768 L
.12286 .40786 L
.12381 .43501 L
.12476 .45809 L
.12571 .4762 L
.12667 .48862 L
.12762 .49479 L
.12857 .49441 L
.12952 .48737 L
.13048 .47384 L
.13143 .4542 L
.13238 .42907 L
.13333 .39928 L
.13429 .36583 L
.13524 .32988 L
.13619 .2927 L
.13714 .25559 L
.1381 .21991 L
.13905 .18695 L
.14 .15794 L
.14095 .13398 L
.1419 .116 L
.14286 .10473 L
.14381 .10065 L
.14476 .104 L
.14571 .11476 L
.14667 .13263 L
.14762 .15705 L
.14857 .18722 L
.14952 .22214 L
.15048 .26059 L
.15143 .30123 L
.15238 .34264 L
.15333 .38333 L
.15429 .42182 L
.15524 .45673 L
.15619 .48674 L
.15714 .51073 L
.1581 .52777 L
.15905 .53719 L
.16 .53855 L
.16095 .53174 L
.1619 .51692 L
.16286 .49452 L
.16381 .4653 L
.16476 .43022 L
.16571 .39049 L
.16667 .34749 L
Mistroke
.16762 .30274 L
.16857 .25781 L
.16952 .21433 L
.17048 .17386 L
.17143 .13788 L
.17238 .10772 L
.17333 .08451 L
.17429 .06914 L
.17524 .06223 L
.17619 .06409 L
.17714 .07473 L
.1781 .09384 L
.17905 .1208 L
.18 .1547 L
.18095 .19439 L
.1819 .2385 L
.18286 .28546 L
.18381 .33363 L
.18476 .38128 L
.18571 .42672 L
.18667 .46829 L
.18762 .50448 L
.18857 .53396 L
.18952 .55563 L
.19048 .56867 L
.19143 .57254 L
.19238 .56706 L
.19333 .55235 L
.19429 .5289 L
.19524 .49747 L
.19619 .45916 L
.19714 .41528 L
.1981 .36737 L
.19905 .31713 L
.2 .26633 L
.20095 .21679 L
.2019 .17028 L
.20286 .12849 L
.20381 .09293 L
.20476 .06491 L
.20571 .04546 L
.20667 .03532 L
.20762 .0349 L
.20857 .04427 L
.20952 .06313 L
.21048 .09085 L
.21143 .12649 L
.21238 .16881 L
.21333 .21632 L
.21429 .26735 L
Mistroke
.21524 .3201 L
.21619 .37268 L
.21714 .42323 L
.2181 .46992 L
.21905 .51108 L
.22 .54521 L
.22095 .57107 L
.2219 .58772 L
.22286 .59451 L
.22381 .59119 L
.22476 .57782 L
.22571 .55486 L
.22667 .52309 L
.22762 .48363 L
.22857 .43785 L
.22952 .38737 L
.23048 .33397 L
.23143 .27957 L
.23238 .22608 L
.23333 .17543 L
.23429 .12942 L
.23524 .08971 L
.23619 .05772 L
.23714 .03463 L
.2381 .02126 L
.23905 .01812 L
.24 .02534 L
.24095 .04268 L
.2419 .06954 L
.24286 .10498 L
.24381 .14776 L
.24476 .19635 L
.24571 .24905 L
.24667 .30396 L
.24762 .35915 L
.24857 .41264 L
.24952 .46252 L
.25048 .50702 L
.25143 .54454 L
.25238 .57374 L
.25333 .59357 L
.25429 .60332 L
.25524 .60263 L
.25619 .59152 L
.25714 .57038 L
.2581 .53996 L
.25905 .50133 L
.26 .45588 L
.26095 .40521 L
.2619 .35114 L
Mistroke
.26286 .29558 L
.26381 .24052 L
.26476 .18791 L
.26571 .13964 L
.26667 .09741 L
.26762 .06273 L
.26857 .03684 L
.26952 .02064 L
.27048 .01472 L
.27143 .01927 L
.27238 .03412 L
.27333 .05875 L
.27429 .09226 L
.27524 .13345 L
.27619 .18086 L
.27714 .23278 L
.2781 .28736 L
.27905 .34265 L
.28 .3967 L
.28095 .44757 L
.2819 .49346 L
.28286 .53274 L
.28381 .56403 L
.28476 .58623 L
.28571 .59856 L
.28667 .60061 L
.28762 .59231 L
.28857 .574 L
.28952 .54633 L
.29048 .51032 L
.29143 .46727 L
.29238 .41872 L
.29333 .36641 L
.29429 .31223 L
.29524 .25808 L
.29619 .20592 L
.29714 .15757 L
.2981 .11476 L
.29905 .07899 L
.3 .0515 L
.30095 .03326 L
.3019 .02488 L
.30286 .02663 L
.30381 .03841 L
.30476 .05976 L
.30571 .0899 L
.30667 .12771 L
.30762 .17184 L
.30857 .22068 L
.30952 .27247 L
Mistroke
.31048 .32538 L
.31143 .3775 L
.31238 .42699 L
.31333 .4721 L
.31429 .51125 L
.31524 .54307 L
.31619 .56646 L
.31714 .58063 L
.3181 .58512 L
.31905 .57981 L
.32 .56495 L
.32095 .5411 L
.3219 .50916 L
.32286 .4703 L
.32381 .42595 L
.32476 .37771 L
.32571 .32732 L
.32667 .27657 L
.32762 .22727 L
.32857 .18118 L
.32952 .1399 L
.33048 .10488 L
.33143 .07732 L
.33238 .05816 L
.33333 .04803 L
.33429 .04723 L
.33524 .05573 L
.33619 .07317 L
.33714 .09887 L
.3381 .13186 L
.33905 .17092 L
.34 .21462 L
.34095 .26137 L
.3419 .3095 L
.34286 .35728 L
.34381 .40301 L
.34476 .4451 L
.34571 .48205 L
.34667 .51262 L
.34762 .53575 L
.34857 .55068 L
.34952 .55695 L
.35048 .5544 L
.35143 .5432 L
.35238 .52382 L
.35333 .497 L
.35429 .46378 L
.35524 .42538 L
.35619 .38321 L
.35714 .33881 L
Mistroke
.3581 .29377 L
.35905 .24969 L
.36 .20815 L
.36095 .17058 L
.3619 .13829 L
.36286 .11238 L
.36381 .09369 L
.36476 .08283 L
.36571 .08011 L
.36667 .08553 L
.36762 .09883 L
.36857 .11945 L
.36952 .14658 L
.37048 .17919 L
.37143 .21606 L
.37238 .25584 L
.37333 .29707 L
.37429 .33828 L
.37524 .378 L
.37619 .41484 L
.37714 .44753 L
.3781 .47494 L
.37905 .49617 L
.38 .51054 L
.38095 .51761 L
.3819 .51723 L
.38286 .50951 L
.38381 .4948 L
.38476 .47373 L
.38571 .44712 L
.38667 .41599 L
.38762 .38151 L
.38857 .34495 L
.38952 .30764 L
.39048 .27091 L
.39143 .23606 L
.39238 .2043 L
.39333 .17673 L
.39429 .15425 L
.39524 .13761 L
.39619 .12729 L
.39714 .12357 L
.3981 .12649 L
.39905 .13584 L
.4 .15119 L
.40095 .17189 L
.4019 .19712 L
.40286 .22592 L
.40381 .2572 L
.40476 .2898 L
Mistroke
.40571 .32254 L
.40667 .35426 L
.40762 .38383 L
.40857 .41026 L
.40952 .43265 L
.41048 .45027 L
.41143 .46259 L
.41238 .46926 L
.41333 .47015 L
.41429 .46535 L
.41524 .45512 L
.41619 .43994 L
.41714 .42046 L
.4181 .39744 L
.41905 .37178 L
.42 .34446 L
.42095 .31648 L
.4219 .28885 L
.42286 .26256 L
.42381 .23851 L
.42476 .2175 L
.42571 .20024 L
.42667 .18724 L
.42762 .17887 L
.42857 .17532 L
.42952 .17661 L
.43048 .18257 L
.43143 .19288 L
.43238 .20705 L
.43333 .22449 L
.43429 .24448 L
.43524 .26624 L
.43619 .28895 L
.43714 .31176 L
.4381 .33386 L
.43905 .35446 L
.44 .37288 L
.44095 .38851 L
.4419 .40087 L
.44286 .40962 L
.44381 .41455 L
.44476 .41559 L
.44571 .41284 L
.44667 .40651 L
.44762 .39694 L
.44857 .3846 L
.44952 .37002 L
.45048 .3538 L
.45143 .33659 L
.45238 .31905 L
Mistroke
.45333 .30183 L
.45429 .28555 L
.45524 .27075 L
.45619 .25793 L
.45714 .24747 L
.4581 .23966 L
.45905 .23468 L
.46 .23259 L
.46095 .23334 L
.4619 .23678 L
.46286 .24267 L
.46381 .25067 L
.46476 .26038 L
.46571 .27136 L
.46667 .28314 L
.46762 .29523 L
.46857 .30717 L
.46952 .31851 L
.47048 .32886 L
.47143 .33787 L
.47238 .34529 L
.47333 .35092 L
.47429 .35465 L
.47524 .35646 L
.47619 .35641 L
.47714 .35463 L
.4781 .3513 L
.47905 .34668 L
.48 .34105 L
.48095 .33471 L
.4819 .328 L
.48286 .32122 L
.48381 .31468 L
.48476 .30864 L
.48571 .30331 L
.48667 .29889 L
.48762 .29548 L
.48857 .29314 L
.48952 .29188 L
.49048 .29164 L
.49143 .2923 L
.49238 .29373 L
.49333 .29575 L
.49429 .29814 L
.49524 .30071 L
.49619 .30323 L
.49714 .30551 L
.4981 .30739 L
.49905 .30872 L
.5 .30941 L
Mistroke
.50095 .30941 L
.5019 .30872 L
.50286 .30739 L
.50381 .30551 L
.50476 .30323 L
.50571 .30071 L
.50667 .29814 L
.50762 .29575 L
.50857 .29373 L
.50952 .2923 L
.51048 .29164 L
.51143 .29188 L
.51238 .29314 L
.51333 .29548 L
.51429 .29889 L
.51524 .30331 L
.51619 .30864 L
.51714 .31468 L
.5181 .32122 L
.51905 .328 L
.52 .33471 L
.52095 .34105 L
.5219 .34668 L
.52286 .3513 L
.52381 .35463 L
.52476 .35641 L
.52571 .35646 L
.52667 .35465 L
.52762 .35092 L
.52857 .34529 L
.52952 .33787 L
.53048 .32886 L
.53143 .31851 L
.53238 .30717 L
.53333 .29523 L
.53429 .28314 L
.53524 .27136 L
.53619 .26038 L
.53714 .25067 L
.5381 .24267 L
.53905 .23678 L
.54 .23334 L
.54095 .23259 L
.5419 .23468 L
.54286 .23966 L
.54381 .24747 L
.54476 .25793 L
.54571 .27075 L
.54667 .28555 L
.54762 .30183 L
Mistroke
.54857 .31905 L
.54952 .33659 L
.55048 .3538 L
.55143 .37002 L
.55238 .3846 L
.55333 .39694 L
.55429 .40651 L
.55524 .41284 L
.55619 .41559 L
.55714 .41455 L
.5581 .40962 L
.55905 .40087 L
.56 .38851 L
.56095 .37288 L
.5619 .35446 L
.56286 .33386 L
.56381 .31176 L
.56476 .28895 L
.56571 .26624 L
.56667 .24448 L
.56762 .22449 L
.56857 .20705 L
.56952 .19288 L
.57048 .18257 L
.57143 .17661 L
.57238 .17532 L
.57333 .17887 L
.57429 .18724 L
.57524 .20024 L
.57619 .2175 L
.57714 .23851 L
.5781 .26256 L
.57905 .28885 L
.58 .31648 L
.58095 .34446 L
.5819 .37178 L
.58286 .39744 L
.58381 .42046 L
.58476 .43994 L
.58571 .45512 L
.58667 .46535 L
.58762 .47015 L
.58857 .46926 L
.58952 .46259 L
.59048 .45027 L
.59143 .43265 L
.59238 .41026 L
.59333 .38383 L
.59429 .35426 L
.59524 .32254 L
Mistroke
.59619 .2898 L
.59714 .2572 L
.5981 .22592 L
.59905 .19712 L
.6 .17189 L
.60095 .15119 L
.6019 .13584 L
.60286 .12649 L
.60381 .12357 L
.60476 .12729 L
.60571 .13761 L
.60667 .15425 L
.60762 .17673 L
.60857 .2043 L
.60952 .23606 L
.61048 .27091 L
.61143 .30764 L
.61238 .34495 L
.61333 .38151 L
.61429 .41599 L
.61524 .44712 L
.61619 .47373 L
.61714 .4948 L
.6181 .50951 L
.61905 .51723 L
.62 .51761 L
.62095 .51054 L
.6219 .49617 L
.62286 .47494 L
.62381 .44753 L
.62476 .41484 L
.62571 .378 L
.62667 .33828 L
.62762 .29707 L
.62857 .25584 L
.62952 .21606 L
.63048 .17919 L
.63143 .14658 L
.63238 .11945 L
.63333 .09883 L
.63429 .08553 L
.63524 .08011 L
.63619 .08283 L
.63714 .09369 L
.6381 .11238 L
.63905 .13829 L
.64 .17058 L
.64095 .20815 L
.6419 .24969 L
.64286 .29377 L
Mistroke
.64381 .33881 L
.64476 .38321 L
.64571 .42538 L
.64667 .46378 L
.64762 .497 L
.64857 .52382 L
.64952 .5432 L
.65048 .5544 L
.65143 .55695 L
.65238 .55068 L
.65333 .53575 L
.65429 .51262 L
.65524 .48205 L
.65619 .4451 L
.65714 .40301 L
.6581 .35728 L
.65905 .3095 L
.66 .26137 L
.66095 .21462 L
.6619 .17092 L
.66286 .13186 L
.66381 .09887 L
.66476 .07317 L
.66571 .05573 L
.66667 .04723 L
.66762 .04803 L
.66857 .05816 L
.66952 .07732 L
.67048 .10488 L
.67143 .1399 L
.67238 .18118 L
.67333 .22727 L
.67429 .27657 L
.67524 .32732 L
.67619 .37771 L
.67714 .42595 L
.6781 .4703 L
.67905 .50916 L
.68 .5411 L
.68095 .56495 L
.6819 .57981 L
.68286 .58512 L
.68381 .58063 L
.68476 .56646 L
.68571 .54307 L
.68667 .51125 L
.68762 .4721 L
.68857 .42699 L
.68952 .3775 L
.69048 .32538 L
Mistroke
.69143 .27247 L
.69238 .22068 L
.69333 .17184 L
.69429 .12771 L
.69524 .0899 L
.69619 .05976 L
.69714 .03841 L
.6981 .02663 L
.69905 .02488 L
.7 .03326 L
.70095 .0515 L
.7019 .07899 L
.70286 .11476 L
.70381 .15757 L
.70476 .20592 L
.70571 .25808 L
.70667 .31223 L
.70762 .36641 L
.70857 .41872 L
.70952 .46727 L
.71048 .51032 L
.71143 .54633 L
.71238 .574 L
.71333 .59231 L
.71429 .60061 L
.71524 .59856 L
.71619 .58623 L
.71714 .56403 L
.7181 .53274 L
.71905 .49346 L
.72 .44757 L
.72095 .3967 L
.7219 .34265 L
.72286 .28736 L
.72381 .23278 L
.72476 .18086 L
.72571 .13345 L
.72667 .09226 L
.72762 .05875 L
.72857 .03412 L
.72952 .01927 L
.73048 .01472 L
.73143 .02064 L
.73238 .03684 L
.73333 .06273 L
.73429 .09741 L
.73524 .13964 L
.73619 .18791 L
.73714 .24052 L
.7381 .29558 L
Mistroke
.73905 .35114 L
.74 .40521 L
.74095 .45588 L
.7419 .50133 L
.74286 .53996 L
.74381 .57038 L
.74476 .59152 L
.74571 .60263 L
.74667 .60332 L
.74762 .59357 L
.74857 .57374 L
.74952 .54454 L
.75048 .50702 L
.75143 .46252 L
.75238 .41264 L
.75333 .35915 L
.75429 .30396 L
.75524 .24905 L
.75619 .19635 L
.75714 .14776 L
.7581 .10498 L
.75905 .06954 L
.76 .04268 L
.76095 .02534 L
.7619 .01812 L
.76286 .02126 L
.76381 .03463 L
.76476 .05772 L
.76571 .08971 L
.76667 .12942 L
.76762 .17543 L
.76857 .22608 L
.76952 .27957 L
.77048 .33397 L
.77143 .38737 L
.77238 .43785 L
.77333 .48363 L
.77429 .52309 L
.77524 .55486 L
.77619 .57782 L
.77714 .59119 L
.7781 .59451 L
.77905 .58772 L
.78 .57107 L
.78095 .54521 L
.7819 .51108 L
.78286 .46992 L
.78381 .42323 L
.78476 .37268 L
.78571 .3201 L
Mistroke
.78667 .26735 L
.78762 .21632 L
.78857 .16881 L
.78952 .12649 L
.79048 .09085 L
.79143 .06313 L
.79238 .04427 L
.79333 .0349 L
.79429 .03532 L
.79524 .04546 L
.79619 .06491 L
.79714 .09293 L
.7981 .12849 L
.79905 .17028 L
.8 .21679 L
.80095 .26633 L
.8019 .31713 L
.80286 .36737 L
.80381 .41528 L
.80476 .45916 L
.80571 .49747 L
.80667 .5289 L
.80762 .55235 L
.80857 .56706 L
.80952 .57254 L
.81048 .56867 L
.81143 .55563 L
.81238 .53396 L
.81333 .50448 L
.81429 .46829 L
.81524 .42672 L
.81619 .38128 L
.81714 .33363 L
.8181 .28546 L
.81905 .2385 L
.82 .19439 L
.82095 .1547 L
.8219 .1208 L
.82286 .09384 L
.82381 .07473 L
.82476 .06409 L
.82571 .06223 L
.82667 .06914 L
.82762 .08451 L
.82857 .10772 L
.82952 .13788 L
.83048 .17386 L
.83143 .21433 L
.83238 .25781 L
.83333 .30274 L
Mistroke
.83429 .34749 L
.83524 .39049 L
.83619 .43022 L
.83714 .4653 L
.8381 .49452 L
.83905 .51692 L
.84 .53174 L
.84095 .53855 L
.8419 .53719 L
.84286 .52777 L
.84381 .51073 L
.84476 .48674 L
.84571 .45673 L
.84667 .42182 L
.84762 .38333 L
.84857 .34264 L
.84952 .30123 L
.85048 .26059 L
.85143 .22214 L
.85238 .18722 L
.85333 .15705 L
.85429 .13263 L
.85524 .11476 L
.85619 .104 L
.85714 .10065 L
.8581 .10473 L
.85905 .116 L
.86 .13398 L
.86095 .15794 L
.8619 .18695 L
.86286 .21991 L
.86381 .25559 L
.86476 .2927 L
.86571 .32988 L
.86667 .36583 L
.86762 .39928 L
.86857 .42907 L
.86952 .4542 L
.87048 .47384 L
.87143 .48737 L
.87238 .49441 L
.87333 .49479 L
.87429 .48862 L
.87524 .4762 L
.87619 .45809 L
.87714 .43501 L
.8781 .40786 L
.87905 .37768 L
.88 .3456 L
.88095 .31278 L
Mistroke
.8819 .2804 L
.88286 .24962 L
.88381 .2215 L
.88476 .19699 L
.88571 .17691 L
.88667 .16188 L
.88762 .15236 L
.88857 .14857 L
.88952 .15055 L
.89048 .15812 L
.89143 .17089 L
.89238 .18831 L
.89333 .20967 L
.89429 .23412 L
.89524 .26073 L
.89619 .28851 L
.89714 .31644 L
.8981 .34352 L
.89905 .3688 L
.9 .39142 L
.90095 .41063 L
.9019 .42582 L
.90286 .43655 L
.90381 .44252 L
.90476 .44363 L
.90571 .43998 L
.90667 .43179 L
.90762 .41949 L
.90857 .4036 L
.90952 .38479 L
.91048 .36381 L
.91143 .34147 L
.91238 .31861 L
.91333 .29605 L
.91429 .27461 L
.91524 .25501 L
.91619 .23792 L
.91714 .22387 L
.9181 .21329 L
.91905 .20643 L
.92 .20345 L
.92095 .20432 L
.9219 .2089 L
.92286 .2169 L
.92381 .22792 L
.92476 .24145 L
.92571 .25693 L
.92667 .27373 L
.92762 .29118 L
.92857 .30864 L
Mistroke
.92952 .32547 L
.93048 .34107 L
.93143 .35494 L
.93238 .36662 L
.93333 .37578 L
.93429 .38219 L
.93524 .38573 L
.93619 .38639 L
.93714 .38426 L
.9381 .37956 L
.93905 .37257 L
.94 .36367 L
.94095 .35326 L
.9419 .34182 L
.94286 .32982 L
.94381 .31775 L
.94476 .30606 L
.94571 .29517 L
.94667 .28545 L
.94762 .27721 L
.94857 .27067 L
.94952 .26598 L
.95048 .26321 L
.95143 .26234 L
.95238 .26327 L
.95333 .26586 L
.95429 .26987 L
.95524 .27503 L
.95619 .28105 L
.95714 .28762 L
.9581 .2944 L
.95905 .3011 L
.96 .30742 L
.96095 .31313 L
.9619 .31802 L
.96286 .32195 L
.96381 .32482 L
.96476 .32662 L
.96571 .32736 L
.96667 .32714 L
.96762 .32607 L
.96857 .32432 L
.96952 .32209 L
.97048 .31958 L
.97143 .31702 L
.97238 .31459 L
.97333 .31249 L
.97429 .31087 L
.97524 .30985 L
.97619 .3095 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0002Kooooo1Ol0
0003ooooo`;o00001?ooool2o`0002;ooooo0ol00003ooooo`;o00001?ooool2o`0002;ooooo0ol0
0004ooooo`;o00001?ooool2o`00027ooooo0ol00004ooooo`;o00001?ooool2o`0001oooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`007oooool01?l0003oooooooooool0
000Vooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00007oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Oooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo000Oooooo`04o`000?ooooooooooo`0002Oooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Oooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool001oooooo
00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Pooooo`Co00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo0ol00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`007oooool01?l0003oooooooooool0000Uooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00007oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`007oooool01?l0003ooooo
ooooool0000Uooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`00027ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00007oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Nooooo`;o00001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool0023ooooo0_l0000Wooooo`?o00001?ooool2o`0000Cooooo0_l0000Sooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`;o00008oooool2o`0000Cooooo0_l00004ooooo`;o00008Oooool3
o`0000Cooooo0_l00004ooooo`;o00008?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`006oooool00ol0000000000000003k00000003o`000?oooooooooo00Cooooo000Coooo
o`?o00001Oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00<00000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo000Dooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00`00003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00<00000ooooooooool0;_ooool00`00003oooooooooo`0]ooooo`03
00000?oooooooooo02kooooo00<00000ooooooooool00oooool00ol0003oooooooooo`04ooooo`00
3?ooool5o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3kooooo`03o`00
0?oooooooooo00Cooooo000Dooooo`03o`000?oooooooooo00Cooooo0_l00012ooooo`03o`00oooo
oooooooo07;ooooo00?o003oooooooooool0@?ooool3o`0000Kooooo000Dooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>Oooool00ol00?ooooooooooo`05ooooo`;o003oLoooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03[ooooo00?o0000ooooooooool01?ooool0
01?ooooo0_l00006ooooo`03o`000?oooooooooo03Wooooo00?o003oooooooooool01Oooool2o`00
o`Kooooo00?o003oooooooooool0H_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Gooooo00?o003oooooooooool0>_ooool00ol0003oooooooooo`04ooooo`005?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0_l00?l6ooooo`;o003o1_ooool2o`00of?o
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03[o
oooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool0>Oooool2o`00o`Kooooo
0_l00?l6ooooo`;o003oHoooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00oc_ooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool0<Oooool00ol00?oooooooooo
o`05ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?mSooooo`03o`00oooooooooooo00Gooooo0_l0
0?l6ooooo`;o003o1_ooool00ol00?ooooooooooo`0booooo`03o`000?oooooooooo00Cooooo000K
ooooo`03o`000?oooooooooo037ooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l6
ooooo`;o003oHoooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Kooooo00?o003o
ooooooooool0<_ooool00ol0003oooooooooo`04ooooo`006oooool2o`0003;ooooo0_l00?l6oooo
o`;o003o1_ooool2o`00o`Kooooo0_l00?mSooooo`03o`00oooooooooooo00Gooooo0_l00?l6oooo
o`;o003o1_ooool2o`00oc;ooooo0_l00006ooooo`006oooool00ol0003oooooooooo`0aooooo`;o
003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00oe?ooooo00?o003ooooooooo
ool01Oooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00oc?ooooo00?o0000oooooooo
ool01?ooool001_ooooo00?o0000ooooooooool0<Oooool2o`00o`Kooooo0_l00?l6ooooo`;o003o
1_ooool2o`00o`Kooooo0_l00?mCooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00oc?ooooo00?o0000ooooooooool0
1?ooool001_ooooo00?o0000ooooooooool0<Oooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_oo
ool2o`00o`Kooooo0_l00?mCooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00oc?ooooo00?o0000ooooooooool01?oo
ool001_ooooo00?o0000ooooooooool0<Oooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_ooool2
o`00o`Kooooo0_l00?mCooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lcooooo`03o`000?oooooo
oooo00Cooooo000Kooooo`03o`000?oooooooooo02Wooooo00?o003oooooooooool01Oooool2o`00
o`Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?mCooooo`03o`00oooooooooooo
00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Kooooo0_l00?l6ooooo`03o`00oooooooooooo02[ooooo00?o0000ooooooooool01?ooool001_o
oooo00?o0000ooooooooool0:Oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00o`Ko
oooo0_l00?l6ooooo`;o003o1_ooool2o`00oe;ooooo0_l00?l6ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool00ol00?oo
ooooooooo`0Zooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo02Wooooo
0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00oe;ooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01_ooool2o`00o`Kooooo0_l00?l[ooooo`03o`000?oooooooooo00Cooooo
000Kooooo`;o0000:_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo0_l0
0?l6ooooo`;o003oD_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00ob[ooooo0_l0
0006ooooo`006oooool00ol0003oooooooooo`0Yooooo`;o003o1_ooool2o`00o`Gooooo00?o003o
ooooool00?l01_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1oooool00ol00?ooooooooooo`11
ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06
ooooo`;o003o:oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0Yoooo
o`;o003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o@oooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00ob_ooooo00?o0000oooo
ooooool01?ooool001_ooooo00?o0000ooooooooool0:Oooool2o`00o`Gooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o
003o1_ooool2o`00od?ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00Kooooo0_l00?l[ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`00
0?oooooooooo02Wooooo0_l00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?m3ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o
:oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0Yooooo`;o003o1Ooo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_oo
ool2o`00o`Kooooo0_l00?l6ooooo`;o003o@_ooool2o`00o`Kooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`06ooooo`;o003o:oooool00ol0003oooooooooo`04ooooo`006oooool0
0ol0003oooooooooo`0Xooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2
o`00o`Kooooo0_l00?m2ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Kooooo0_l00?l[ooooo`03o`000?oooooooooo00Cooooo000Kooooo`;o00008_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00
o`Kooooo0_l00?m2ooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Kooooo0_l00?l6ooooo`03o`00oooooooooooo027ooooo0_l00006ooooo`006oooool00ol0003o
ooooooooo`0Qooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`06ooooo`;o003o1_ooool2o`00od;ooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o003o8oooool00ol0003o
ooooooooo`04ooooo`006oooool00ol0003oooooooooo`0Qooooo`03o`00oooooooooooo00Cooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00od;ooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01_ooool2o`00ob?ooooo00?o0000ooooooooool01?ooool001_ooooo00?o
0000ooooooooool08Oooool2o`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l5ooooo`;o003o1_ooool2o`00od;ooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00ob?ooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool08Oooool2o`00o`Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o00Go
oooo0_l00?m2ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lSooooo`03o`000?oooooooooo00Co
oooo000Kooooo`03o`000?oooooooooo027ooooo0_l00?l5ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`05ooooo`;o003o1_ooool00ol0
0?ooooooooooo`0booooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00
ob?ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool08Oooool2o`00o`Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Gooooo0_l00?l6ooooo`;o003o<oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Kooooo0_l00?lSooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooo
oooo023ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00o`Kooooo0_l00?lcoooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00ob?ooooo00?o0000oooo
ooooool01?ooool001_ooooo0_l0000Qooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo
0_l00?l6ooooo`;o003o<_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00ob;ooooo
0_l00006ooooo`006oooool00ol0003oooooooooo`0Pooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo0_l00?l6ooooo`;o003o<_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2
o`00ob?ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool08?ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o1_ooool2o`00oc;ooooo0_l00?l6ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00Kooooo0_l00?lSooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`00
0?oooooooooo023ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00o`Kooooo0_l0
0?lbooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o8oooool00ol0003ooooooooo
o`04ooooo`006oooool00ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00o`Kooooo0_l00?lbooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooo
oooo01[ooooo00?o0000ooooooooool01?ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00005ooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool01?ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o1_ooool2o`00oc;ooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo00?o003o
ooooooooool06_ooool00ol0003oooooooooo`04ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Iooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00
o`06ooooo`;o003o<_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Cooooo00?o003oooooool00?l01_ooool2o`00oa_ooooo00?o0000ooooooooool01?ooool000Go
00000_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l0000Joooo
o`;o003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o
00Kooooo0_l00?lbooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool00ol00?ooooooo`00o`06ooooo`;o003o6Oooool3o`0000Kooooo0007ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l5ooooo`;o003o<_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooool00?l01_ooool2o`00oa_ooooo00?o0000ooooooooool01?oo
ool000Oooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool06?oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Ooo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1Oooool2o`00oc;ooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Kooooo0_l00?lKooooo`03o`000?oo
oooooooo00Cooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Hooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o<_ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01_oo
ool2o`00oa_ooooo00?o0000ooooooooool01?ooool000Sooooo0_l00008ooooo`Go00001?ooool0
0ol0003oooooooooo`0Hooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o1_ooool2o`00ob?ooooo
00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooool00?l01_ooool2o`00oa_ooooo00?o0000ooooooooool01?oo
ool001_ooooo00?o0000ooooooooool06?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00o`Kooooo
0_l00?lSooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Kooooo0_l00?lKooooo`03o`000?oo
oooooooo00Cooooo000Kooooo`03o`000?oooooooooo01Sooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo
0_l00?l6ooooo`;o003o8oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`06ooooo`;o003o
6oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0Hooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l5ooooo`03o`00oooooooo003o00Gooooo0_l00?lRooooo`;o003o1_ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`0Kooooo`03o`000?oooooooooo00Cooooo000Kooooo`;o0000
6Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o8_ooool2
o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l06_ooool2o`0000Kooooo000Koooo
o`03o`000?oooooooooo01Sooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1Oooool2o`00ob;ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00Cooooo00Co003ooooooooooooo003o1Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`0Kooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo01Sooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00ob;ooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o01_ooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool04Oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?lRoooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`06ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000
ooooooooool04Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Gooooo0_l00?lRooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01_ooool2o`00oa?ooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool04Oooool2o`00o`Gooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00ob;ooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool00ol00?oo
ooooo`00o`06ooooo`;o003o4oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003ooooo
ooooo`0Aooooo`;o003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l5ooooo`;o003o8_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Cooooo00Co
003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l4ooooo`03o`00oooooooo003o00Kooooo0_l00?lCooooo`03o`000?oooooooooo
00Cooooo000Kooooo`;o00004_ooool2o`00o`Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0Qooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l01_ooool2
o`00oa;ooooo0_l00006ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?oo
ooooo`00o`0Qooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01?ooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o4oooool00ol0003ooooo
ooooo`04ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0Q
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool0
0?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o4oooool00ol0003oooooooooo`04oooo
o`006oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o
003o4oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo
0_l00?lCooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo013ooooo00?o
003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?lCooooo`03o`00oooooooooooo00Cooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`0Cooooo`03o`000?oo
oooooooo00Cooooo000Kooooo`03o`000?oooooooooo013ooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l5ooooo`;o003o4oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l04oooool00ol0003oooooooooo`04
ooooo`006oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo003o00Gooooo00Co003ooooo
oooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`;o003o4_ooool2o`00o`Kooooo00?o003oooooool00?l01?ooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooo003o01?ooooo00?o0000ooooooooool01?ooool0
01_ooooo00?o0000ooooooooool04?ooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1Oooool2o`00oa;ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l04oooool00ol0003oooooooooo`04
ooooo`006oooool2o`00017ooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Gooooo0_l00?lBooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01?ooool0
1?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa7ooooo0_l00006ooooo`006oooool0
0ol0003oooooooooo`0@ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooool00?l04_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa;ooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool04?ooool00ol00?ooooooo`00
o`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa7o
oooo00?o003oooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?lBooooo`03o`000?oooooooooo00Cooooo000Koooo
o`03o`000?oooooooooo00Wooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oa7ooooo00?o
003oooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00[ooooo00?o0000oooooooo
ool01?ooool001_ooooo00?o0000ooooooooool02Oooool2o`00o`Gooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?lA
ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o2oooool00ol0003ooooo
ooooo`04ooooo`006oooool00ol0003oooooooooo`09ooooo`;o003o1Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o4Oooool00ol00?ooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00
o`0;ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00Sooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?lAooooo`03o`00oooooooo003o00Co
oooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`03o`00oooooooo003o00_ooooo00?o0000ooooooooool01?ooool0
01_ooooo0_l00009ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
4?ooool01?l00?ooooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo
003o00[ooooo0_l00006ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo003o
00Gooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o4?ooool01?l00?ooooooooooool00?l4ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l02oooool00ol0003oooooooooo`04
ooooo`006oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo003o00Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00oa3ooooo00Co003ooooooooooooo003o1?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`[ooooo00?o0000ooooooooool01?oo
ool001_ooooo00?o0000ooooooooool02?ooool00ol00?ooooooo`00o`04ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooooooo00;ooooo0_l00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l:ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00Sooooo00Co
003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool3
o`00o`?ooooo0_l00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l:ooooo`03o`000?oooooooooo00Cooooo000Dooooo`;o
00001Oooool00ol0003oooooooooo`08ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool00?l00_ooool00ol00?oooooo
o`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o2_ooool00ol0003oooooooooo`04ooooo`004oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Oooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`08o`00ooooooooooooo`00oooooooo003oooooool00?l4ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
2_ooool00ol0003oooooooooo`04ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Oooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00?o003o0_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o2_ooool00ol0003oooooooooo`04
ooooo`004oooool01?l0003oooooooooool00004ooooo`Ko00000_l00?l2o`000005o`00ool0003o
0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o
0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o
003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l0
0ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`00
0005o`00ool0003o0000o`000?l00?l01?l000001?l00?oo0000o`000?l00?l4o`000005o`00ool0
003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0
003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0
003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l0
0?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03
o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o0000
00Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0003o0000o`000?l00?l00ol000001Ol0
0?oo0000o`000?l0003o003o00?o000000Go003oo`000?l0003o0000o`00o`03o`000005o`00ool0
003o0000o`000?l00?l00ol000001Ol00?oo0000o`000?l0003o003o00?o000000?o003oo`000?l0
00000_l000001?l00?oo0000o`000?l00?l3o`0000;o003o1_l00006ooooo`004oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00Co003ooooooooooooo003o0oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`02ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Kooooo00?o0000ooooooooool01?ooool001?ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00Gooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooool00?l01oooool00ol0003oooooooooo`04ooooo`005?ooool2
o`0000Gooooo00?o0000ooooooooool01Oooool2o`00o`Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l8oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Oooooo00?o0000oooooooo
ool01?ooool001_ooooo00?o0000ooooooooool01Oooool2o`00o`Cooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l8ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00Cooooo00Co003ooooooooooooo003o1?ooool2o`00o`Sooooo00?o0000ooooooooool01?ooool0
01_ooooo00?o0000ooooooooool02oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o2?ooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03o`00
0?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo00_ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o2Oooool00ol00?ooooooo`00o`04
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l>ooooo`03
o`000?oooooooooo00Cooooo000Kooooo`;o00003Oooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l3
ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3Oooool2o`0000Kooooo000Kooooo`03
o`000?oooooooooo00cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l9ooooo`03o`00oooooooo003o00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`kooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000oooo
ooooool03?ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o2_ooool00ol00?oooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o3_ooool0
0ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooo003o
00Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l5ooooo`;o003o2_ooool00ol00?ooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`kooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000oooooooo
ool03?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l5ooooo`;o003o2oooool00ol00?ooooooooooo`03ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o0000ooooooooool01?ooool001_ooooo
00?o0000ooooooooool03?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o2oooool00ol00?ooooooooooo`03oooo
o`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`kooooo00?o0000ooooooooool0
1?ooool001_ooooo00?o0000ooooooooool03?ooool00ol00?ooooooo`00o`05ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o6?ooool01?l00?ooooooooooool00?l4oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooo
ooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003o
ooooool00?l03oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0<oooo
o`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oaWooooo00?o
003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
1?ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`03o`00oooooooo003o00oooooo00?o0000ooooooooool01?ooool001_ooooo0_l0
000=ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00oaWo
oooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l01?ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool00ol00?ooooooo`00o`0>ooooo`;o00001_ooool001_ooooo00?o0000oooooooo
ool03?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?lI
ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`04ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l5ooooo`;o003o3oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0=
ooooo`;o003o1Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o6Oooool00ol00?oooooo
o`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oo
ooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00o`oo
oooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool03Oooool2o`00o`Gooooo
00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00oaWooooo00?o003oooooool00?l01?ooool01?l00?oo
ooooooooool00?l4ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool0
0?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o3oooool00ol0003oooooooooo`04oooo
o`006oooool00ol0003oooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool0
0?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03
o`00oooooooo003o01Wooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l01?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l5ooooo`;o003o3oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003ooooo
ooooo`0Dooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1Oooool00ol00?ooooooo`00o`0Iooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o5_ooool00ol0003oooooooooo`04ooooo`006ooo
ool00ol0003oooooooooo`0Dooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00oa[ooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`04ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00oaKooooo00?o0000ooooooooool01?ooool001_ooooo0_l0000E
ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1Oooool2o`00oa[ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`04
ooooo`04o`00ooooooooooooo`00o`Cooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l01?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`0Foooo
o`;o00001_ooool001_ooooo00?o0000ooooooooool05?ooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?lJooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`04ooooo`05
o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooool00?l05oooool00ol0003oooooooooo`04ooooo`006oooool0
0ol0003oooooooooo`0Dooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00oa[ooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?oo
ool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o01Oooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool05?ooool00ol00?ooooooo`00
o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo0_l0
0?lJooooo`;o003o1_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co
003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooo
ooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooo003o01Oooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool0
5?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Gooooo0_l00?lKooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00?o003oooooool0
0?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Co
oooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`0Gooooo`03o`000?oooooooooo
00Cooooo000Kooooo`03o`000?oooooooooo01Cooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo01Wooooo
00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4oooo
o`03o`00oooooooo003o01Oooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000oooooooo
ool05?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co
003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00obWooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00
ooooooooooooo`00o`Cooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4oooo
o`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00
oaOooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool05?ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooo
oooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`03o`00oooooooo003o02Wooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o
003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooooooooooo
o`00o`Cooooo00?o003oooooool00?l01_ooool2o`00oaOooooo00?o0000ooooooooool01?ooool0
01_ooooo0_l0000Fooooo`;o003o1Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool00ol00?oooooo
o`00o`0Yooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Kooooo0_l00?lFooooo`;o00001_oo
ool001_ooooo00?o0000ooooooooool05Oooool2o`00o`Gooooo00?o003oooooool00?l01Oooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003o
oooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Go
oooo0_l00?lZooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oo
ooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o00Kooooo0_l00?lGooooo`03o`00
0?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo01Gooooo0_l00?l5ooooo`03o`00oooo
oooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool0
0?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oo
ooooooooool00?l5ooooo`;o003o:_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`06ooooo`;o
003o5oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0Eooooo`03o`00
oooooooooooo00Cooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`03
o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?lZooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Kooooo0_l00?lGooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooo
oooo01Gooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`04o`00oooooooo
ooooo`00o`Cooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00ob[ooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooooooo003o
00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Fooooo`03o`000?oooooooooo
00Cooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003o
ooooooooo`0Looooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo
003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o:_ooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`0Ooooo
o`03o`000?oooooooooo00Cooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo01cooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00Co003ooooooooooooo003o1?oo
ool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooo
oooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo0_l0
0?lZooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o01oooooo00?o0000ooooooooool01?ooool000Oooooo00Co0000
oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o00007Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?oooooooooo
ool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l0
0?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o
1Oooool2o`00ob[ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l07Oooool3o`0000Kooooo0007ooooo`04o`000?oo
ooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?oooooo
ooooool00?l5ooooo`;o003o:_ooool2o`00o`Kooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o01oooooo00?o0000ooooooooool01?ooool000Oooooo
00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000ooooooooool07?ooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`04o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool0
1?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?l6ooooo`;o003o
:oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1_ooool2o`00oaoooooo00?o0000ooooooooool01?ooool000Oooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo0_l00?l5ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4
ooooo`04o`00ooooooooooooo`00o`Gooooo0_l00?l6ooooo`;o003o:oooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00oaoooooo00?o
0000ooooooooool01?ooool000Sooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`0M
ooooo`;o003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo
00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l5ooooo`;o003o>_ooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lOooooo`03o`000?oooooooooo
00Cooooo000Kooooo`03o`000?oooooooooo01gooooo0_l00?l5ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04o`00ooooooooooooo`00
o`Cooooo00Co003ooooooooooooo003o1?ooool01?l00?ooooooooooool00?l4ooooo`04o`00oooo
ooooooooo`00o`Gooooo0_l00?ljooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1_ooool2o`00oaoooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool07Ooo
ool2o`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00
ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1Oooool2o`00oc[ooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o7oooool00ol0003oooooooooo`04oooo
o`006oooool00ol0003oooooooooo`0Mooooo`;o003o1Oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`04
o`00ooooooooooooo`00o`Cooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`06
ooooo`;o003o>_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lO
ooooo`03o`000?oooooooooo00Cooooo000Kooooo`;o00007_ooool2o`00o`Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool01?l00?ooooooooooool00?l4ooooo`04o`00ooooooooooooo`00o`Cooooo00?o
003oooooool00?l01_ooool2o`00oc[ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`06ooooo`;o003o7_ooool2o`0000Kooooo000Kooooo`03o`000?oooooooooo01gooooo0_l00?l5
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo0_l00?ljooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003o
ooooool00?l01_ooool2o`00oaoooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000oooo
ooooool07Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?ljoooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05oooo
o`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`0Noooo
o`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o
003o>_ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool0
0?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o02Oooooo00?o0000oooooooo
ool01?ooool001_ooooo00?o0000ooooooooool09Oooool2o`00o`Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00oc_ooooo0_l00?l5ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00
oooooooo003o02Oooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool09Ooo
ool2o`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o1_oo
ool2o`00oc_ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooo
oooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00obOooooo00?o0000ooooooooool01?oo
ool001_ooooo00?o0000ooooooooool09Oooool2o`00o`Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00oc_ooooo00?o003oooooooooool01?ooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool0
0ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2
o`00obOooooo00?o0000ooooooooool01?ooool001_ooooo0_l0000Vooooo`;o003o1Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o003o>oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`06ooooo`;o003o9_ooool2o`0000Kooooo000Kooooo`03o`000?oooooooooo02Go
oooo0_l00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oo
ooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01_ooool2o`00o`Ko
oooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o9oooool00ol0003o
ooooooooo`04ooooo`006oooool00ol0003oooooooooo`0Uooooo`;o003o1_ooool2o`00o`Gooooo
00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo
00?o003oooooool00?l01_ooool2o`00od[ooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?lWooooo`03o`000?oooooooooo00Cooooo
000Kooooo`03o`000?oooooooooo02Gooooo0_l00?l6ooooo`;o003o1Oooool00ol00?ooooooo`00
o`06ooooo`;o003o1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l0
0?m:ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00
o`06ooooo`;o003o9oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0U
ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1Oooool00ol00?ooooooo`00o`06
ooooo`;o003o1_ooool2o`00od[ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05
ooooo`03o`00oooooooo003o00Kooooo0_l00?lWooooo`03o`000?oooooooooo00Cooooo000Koooo
o`03o`000?oooooooooo02Gooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l5oooo
o`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o003oBoooool2o`00o`Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003ooooo
ool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo02Kooooo00?o0000oooo
ooooool01?ooool001_ooooo00?o0000ooooooooool09Oooool00ol00?ooooooooooo`05ooooo`;o
003o1_ooool2o`00o`Kooooo0_l00?l5ooooo`03o`00oooooooo003o00Kooooo0_l00?l6ooooo`;o
003oBoooool2o`00o`Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`03
o`00oooooooooooo02Kooooo00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool0
;Oooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1Oooool00ol00?ooooooo`00o`06ooooo`;o003o
1_ooool2o`00od_ooooo0_l00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l0
1Oooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Kooooo0_l00?l_ooooo`03o`00
0?oooooooooo00Cooooo000Kooooo`;o0000;_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1Ooo
ool00ol00?ooooooo`00o`06ooooo`;o003o1_ooool2o`00od_ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Ooo
ool00ol00?ooooooo`00o`06ooooo`;o003o;_ooool2o`0000Kooooo000Kooooo`03o`000?oooooo
oooo02gooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_ooool2
o`00od_ooooo00?o003oooooooooool01?ooool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo
003o00Gooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`06ooooo`;o003o;oooool0
0ol0003oooooooooo`04ooooo`006oooool00ol0003oooooooooo`0]ooooo`;o003o1_ooool2o`00
o`Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?m;ooooo`03o`00oooooooooooo
00Gooooo0_l00?l5ooooo`03o`00oooooooo003o00Gooooo00?o003oooooool00?l01Oooool00ol0
0?ooooooo`00o`06ooooo`;o003o;oooool00ol0003oooooooooo`04ooooo`006oooool00ol0003o
ooooooooo`0]ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00oe_o
oooo0_l00?l5ooooo`03o`00oooooooo003o00Kooooo0_l00?l5ooooo`03o`00oooooooo003o00Ko
oooo0_l00?l_ooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oooooooooo02gooooo
0_l00?l6ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003oFoooool2o`00o`Kooooo
0_l00?l6ooooo`;o003o1Oooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo02kooooo
00?o0000ooooooooool01?ooool001_ooooo00?o0000ooooooooool0;Oooool2o`00o`Kooooo0_l0
0?l6ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?mKooooo`;o003o1_ooool2o`00o`Kooooo0_l0
0?l5ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool0;_ooool00ol0003ooooooooo
o`04ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`00oooooooooooo00Gooooo0_l00?l6
ooooo`;o003o1_ooool2o`00o`Kooooo0_l00?mKooooo`;o003o1_ooool2o`00o`Kooooo0_l00?l6
ooooo`;o003o1_ooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00Cooooo000Koooo
o`;o0000=_ooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00oe_ooooo0_l00?l6oooo
o`;o003o1_ooool2o`00o`Kooooo0_l00?lfooooo`;o00001_ooool001_ooooo00?o0000oooooooo
ool0=Oooool2o`00o`Kooooo0_l00?l6ooooo`;o003o1_ooool2o`00oe_ooooo00?o003ooooooooo
ool01Oooool00ol00?ooooooooooo`05ooooo`;o003o1_ooool2o`00ocOooooo00?o0000oooooooo
ool01?ooool001_ooooo00?o0000ooooooooool0=Oooool2o`00o`Kooooo0_l00?l6ooooo`;o003o
1_ooool2o`00oe_ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`;o003o
1_ooool00ol00?ooooooooooo`0fooooo`03o`000?oooooooooo00Cooooo000Kooooo`03o`000?oo
oooooooo03Gooooo00?o003oooooooooool01Oooool2o`00o`Kooooo0_l00?l6ooooo`03o`00oooo
oooooooo05[ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Gooooo00?o003oooooooooool0=_ooool00ol0003oooooooooo`04ooooo`006oooool0
0ol0003oooooooooo`0eooooo`03o`00oooooooooooo00Gooooo0_l00?l6ooooo`;o003oJoooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0=_ooool0
0ol0003oooooooooo`04ooooo`004oooool3o`0000Gooooo00?o0000ooooooooool0=Oooool00ol0
0?ooooooooooo`05ooooo`;o003o1_ooool2o`00of_ooooo00?o003oooooooooool01Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo03Kooooo00?o0000ooooooooool01?ooool001Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0mooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool0J_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03ko
oooo00?o0000ooooooooool01?ooool001Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0mooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0J_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo03kooooo00?o0000ooooooooool01?ooool001Cooooo00?o
0000ooooooooool01?ooool2o`000?[ooooo0ol00006ooooo`005?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool001?ooooo0_l00006oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool001Cooooo00?o0000oooooooo
ool01?ooooooo`0000Kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-137.394, -1.25585, 4.136, \
0.0133431}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete spectrum: Fast Fourier Transform (FFT)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ Fourier[signal];\)\), "\n", 
    \(\(g1 = 
        DiscreteListPlot[FourierRearrange[Abs[fft], sampleRate], Red, 
          PlotRange \[Rule] All, \ Frame \[Rule] True];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499523 0.000953334 0.0147151 0.00232388 [
[.11819 -0.0125 -12 -9 ]
[.11819 -0.0125 12 0 ]
[.30886 -0.0125 -12 -9 ]
[.30886 -0.0125 12 0 ]
[.49952 -0.0125 -3 -9 ]
[.49952 -0.0125 3 0 ]
[.69019 -0.0125 -9 -9 ]
[.69019 -0.0125 9 0 ]
[.88086 -0.0125 -9 -9 ]
[.88086 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13091 -12 -4.5 ]
[-0.0125 .13091 0 4.5 ]
[-0.0125 .2471 -18 -4.5 ]
[-0.0125 .2471 0 4.5 ]
[-0.0125 .3633 -18 -4.5 ]
[-0.0125 .3633 0 4.5 ]
[-0.0125 .47949 -18 -4.5 ]
[-0.0125 .47949 0 4.5 ]
[-0.0125 .59568 -18 -4.5 ]
[-0.0125 .59568 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11819 0 m
.11819 .00625 L
s
[(-400)] .11819 -0.0125 0 1 Mshowa
.30886 0 m
.30886 .00625 L
s
[(-200)] .30886 -0.0125 0 1 Mshowa
.49952 0 m
.49952 .00625 L
s
[(0)] .49952 -0.0125 0 1 Mshowa
.69019 0 m
.69019 .00625 L
s
[(200)] .69019 -0.0125 0 1 Mshowa
.88086 0 m
.88086 .00625 L
s
[(400)] .88086 -0.0125 0 1 Mshowa
.125 Mabswid
.16586 0 m
.16586 .00375 L
s
.21352 0 m
.21352 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.40419 0 m
.40419 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.59486 0 m
.59486 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.78552 0 m
.78552 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.07052 0 m
.07052 .00375 L
s
.02286 0 m
.02286 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13091 m
.00625 .13091 L
s
[(50)] -0.0125 .13091 1 0 Mshowa
0 .2471 m
.00625 .2471 L
s
[(100)] -0.0125 .2471 1 0 Mshowa
0 .3633 m
.00625 .3633 L
s
[(150)] -0.0125 .3633 1 0 Mshowa
0 .47949 m
.00625 .47949 L
s
[(200)] -0.0125 .47949 1 0 Mshowa
0 .59568 m
.00625 .59568 L
s
[(250)] -0.0125 .59568 1 0 Mshowa
.125 Mabswid
0 .03795 m
.00375 .03795 L
s
0 .06119 m
.00375 .06119 L
s
0 .08443 m
.00375 .08443 L
s
0 .10767 m
.00375 .10767 L
s
0 .15415 m
.00375 .15415 L
s
0 .17739 m
.00375 .17739 L
s
0 .20063 m
.00375 .20063 L
s
0 .22386 m
.00375 .22386 L
s
0 .27034 m
.00375 .27034 L
s
0 .29358 m
.00375 .29358 L
s
0 .31682 m
.00375 .31682 L
s
0 .34006 m
.00375 .34006 L
s
0 .38654 m
.00375 .38654 L
s
0 .40977 m
.00375 .40977 L
s
0 .43301 m
.00375 .43301 L
s
0 .45625 m
.00375 .45625 L
s
0 .50273 m
.00375 .50273 L
s
0 .52597 m
.00375 .52597 L
s
0 .54921 m
.00375 .54921 L
s
0 .57245 m
.00375 .57245 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11819 .61178 m
.11819 .61803 L
s
.30886 .61178 m
.30886 .61803 L
s
.49952 .61178 m
.49952 .61803 L
s
.69019 .61178 m
.69019 .61803 L
s
.88086 .61178 m
.88086 .61803 L
s
.125 Mabswid
.16586 .61428 m
.16586 .61803 L
s
.21352 .61428 m
.21352 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.40419 .61428 m
.40419 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.59486 .61428 m
.59486 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.78552 .61428 m
.78552 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.07052 .61428 m
.07052 .61803 L
s
.02286 .61428 m
.02286 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13091 m
1 .13091 L
s
.99375 .2471 m
1 .2471 L
s
.99375 .3633 m
1 .3633 L
s
.99375 .47949 m
1 .47949 L
s
.99375 .59568 m
1 .59568 L
s
.125 Mabswid
.99625 .03795 m
1 .03795 L
s
.99625 .06119 m
1 .06119 L
s
.99625 .08443 m
1 .08443 L
s
.99625 .10767 m
1 .10767 L
s
.99625 .15415 m
1 .15415 L
s
.99625 .17739 m
1 .17739 L
s
.99625 .20063 m
1 .20063 L
s
.99625 .22386 m
1 .22386 L
s
.99625 .27034 m
1 .27034 L
s
.99625 .29358 m
1 .29358 L
s
.99625 .31682 m
1 .31682 L
s
.99625 .34006 m
1 .34006 L
s
.99625 .38654 m
1 .38654 L
s
.99625 .40977 m
1 .40977 L
s
.99625 .43301 m
1 .43301 L
s
.99625 .45625 m
1 .45625 L
s
.99625 .50273 m
1 .50273 L
s
.99625 .52597 m
1 .52597 L
s
.99625 .54921 m
1 .54921 L
s
.99625 .57245 m
1 .57245 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01472 L
s
.02476 .01472 m
.02476 .01472 L
s
.02572 .01472 m
.02572 .01472 L
s
.02667 .01472 m
.02667 .01472 L
s
.02762 .01472 m
.02762 .01472 L
s
.02858 .01472 m
.02858 .01472 L
s
.02953 .01472 m
.02953 .01472 L
s
.03048 .01472 m
.03048 .01472 L
s
.03144 .01472 m
.03144 .01472 L
s
.03239 .01472 m
.03239 .01472 L
s
.03334 .01472 m
.03334 .01472 L
s
.0343 .01472 m
.0343 .01472 L
s
.03525 .01472 m
.03525 .01472 L
s
.0362 .01472 m
.0362 .01472 L
s
.03716 .01472 m
.03716 .01472 L
s
.03811 .01472 m
.03811 .01472 L
s
.03906 .01472 m
.03906 .01472 L
s
.04002 .01472 m
.04002 .01472 L
s
.04097 .01472 m
.04097 .01472 L
s
.04192 .01472 m
.04192 .01472 L
s
.04288 .01472 m
.04288 .01472 L
s
.04383 .01472 m
.04383 .01472 L
s
.04478 .01472 m
.04478 .01472 L
s
.04574 .01472 m
.04574 .01472 L
s
.04669 .01472 m
.04669 .01472 L
s
.04764 .01472 m
.04764 .01472 L
s
.0486 .01472 m
.0486 .01472 L
s
.04955 .01472 m
.04955 .01472 L
s
.0505 .01472 m
.0505 .01472 L
s
.05146 .01472 m
.05146 .01472 L
s
.05241 .01472 m
.05241 .01472 L
s
.05336 .01472 m
.05336 .01472 L
s
.05432 .01472 m
.05432 .01472 L
s
.05527 .01472 m
.05527 .01472 L
s
.05622 .01472 m
.05622 .01472 L
s
.05718 .01472 m
.05718 .01472 L
s
.05813 .01472 m
.05813 .01472 L
s
.05908 .01472 m
.05908 .01472 L
s
.06004 .01472 m
.06004 .01472 L
s
.06099 .01472 m
.06099 .01472 L
s
.06194 .01472 m
.06194 .01472 L
s
.0629 .01472 m
.0629 .01472 L
s
.06385 .01472 m
.06385 .01472 L
s
.0648 .01472 m
.0648 .01472 L
s
.06576 .01472 m
.06576 .01472 L
s
.06671 .01472 m
.06671 .01472 L
s
.06766 .01472 m
.06766 .01472 L
s
.06862 .01472 m
.06862 .01472 L
s
.06957 .01472 m
.06957 .01472 L
s
.07052 .01472 m
.07052 .01472 L
s
.07148 .01472 m
.07148 .01472 L
s
.07243 .01472 m
.07243 .01472 L
s
.07338 .01472 m
.07338 .01472 L
s
.07434 .01472 m
.07434 .01472 L
s
.07529 .01472 m
.07529 .01472 L
s
.07624 .01472 m
.07624 .01472 L
s
.0772 .01472 m
.0772 .01472 L
s
.07815 .01472 m
.07815 .01472 L
s
.0791 .01472 m
.0791 .01472 L
s
.08006 .01472 m
.08006 .01472 L
s
.08101 .01472 m
.08101 .01472 L
s
.08196 .01472 m
.08196 .01472 L
s
.08292 .01472 m
.08292 .01472 L
s
.08387 .01472 m
.08387 .01472 L
s
.08482 .01472 m
.08482 .01472 L
s
.08578 .01472 m
.08578 .01472 L
s
.08673 .01472 m
.08673 .01472 L
s
.08768 .01472 m
.08768 .01472 L
s
.08864 .01472 m
.08864 .01472 L
s
.08959 .01472 m
.08959 .01472 L
s
.09054 .01472 m
.09054 .01472 L
s
.0915 .01472 m
.0915 .01472 L
s
.09245 .01472 m
.09245 .01472 L
s
.0934 .01472 m
.0934 .01472 L
s
.09436 .01472 m
.09436 .01472 L
s
.09531 .01472 m
.09531 .01472 L
s
.09626 .01472 m
.09626 .01472 L
s
.09722 .01472 m
.09722 .01472 L
s
.09817 .01472 m
.09817 .01472 L
s
.09912 .01472 m
.09912 .01472 L
s
.10008 .01472 m
.10008 .01472 L
s
.10103 .01472 m
.10103 .01472 L
s
.10198 .01472 m
.10198 .01472 L
s
.10294 .01472 m
.10294 .01472 L
s
.10389 .01472 m
.10389 .01472 L
s
.10484 .01472 m
.10484 .01472 L
s
.1058 .01472 m
.1058 .01472 L
s
.10675 .01472 m
.10675 .01472 L
s
.1077 .01472 m
.1077 .01472 L
s
.10866 .01472 m
.10866 .01472 L
s
.10961 .01472 m
.10961 .01472 L
s
.11056 .01472 m
.11056 .01472 L
s
.11152 .01472 m
.11152 .01472 L
s
.11247 .01472 m
.11247 .01472 L
s
.11342 .01472 m
.11342 .01472 L
s
.11438 .01472 m
.11438 .01472 L
s
.11533 .01472 m
.11533 .01472 L
s
.11628 .01472 m
.11628 .01472 L
s
.11724 .01472 m
.11724 .01472 L
s
.11819 .01472 m
.11819 .01472 L
s
.11914 .01472 m
.11914 .01472 L
s
.1201 .01472 m
.1201 .01472 L
s
.12105 .01472 m
.12105 .01472 L
s
.122 .01472 m
.122 .01472 L
s
.12296 .01472 m
.12296 .01472 L
s
.12391 .01472 m
.12391 .01472 L
s
.12486 .01472 m
.12486 .01472 L
s
.12582 .01472 m
.12582 .01472 L
s
.12677 .01472 m
.12677 .01472 L
s
.12772 .01472 m
.12772 .01472 L
s
.12868 .01472 m
.12868 .01472 L
s
.12963 .01472 m
.12963 .01472 L
s
.13058 .01472 m
.13058 .01472 L
s
.13154 .01472 m
.13154 .01472 L
s
.13249 .01472 m
.13249 .01472 L
s
.13344 .01472 m
.13344 .01472 L
s
.1344 .01472 m
.1344 .01472 L
s
.13535 .01472 m
.13535 .01472 L
s
.1363 .01472 m
.1363 .01472 L
s
.13726 .01472 m
.13726 .01472 L
s
.13821 .01472 m
.13821 .01472 L
s
.13916 .01472 m
.13916 .01472 L
s
.14012 .01472 m
.14012 .01472 L
s
.14107 .01472 m
.14107 .01472 L
s
.14202 .01472 m
.14202 .01472 L
s
.14298 .01472 m
.14298 .01472 L
s
.14393 .01472 m
.14393 .01472 L
s
.14488 .01472 m
.14488 .01472 L
s
.14584 .01472 m
.14584 .01472 L
s
.14679 .01472 m
.14679 .01472 L
s
.14774 .01472 m
.14774 .01472 L
s
.1487 .01472 m
.1487 .01472 L
s
.14965 .01472 m
.14965 .01472 L
s
.1506 .01472 m
.1506 .01472 L
s
.15156 .01472 m
.15156 .01472 L
s
.15251 .01472 m
.15251 .01472 L
s
.15346 .01472 m
.15346 .01472 L
s
.15442 .01472 m
.15442 .01472 L
s
.15537 .01472 m
.15537 .01472 L
s
.15632 .01472 m
.15632 .01472 L
s
.15728 .01472 m
.15728 .01472 L
s
.15823 .01472 m
.15823 .01472 L
s
.15918 .01472 m
.15918 .01472 L
s
.16014 .01472 m
.16014 .01472 L
s
.16109 .01472 m
.16109 .01472 L
s
.16204 .01472 m
.16204 .01472 L
s
.163 .01472 m
.163 .01472 L
s
.16395 .01472 m
.16395 .01472 L
s
.1649 .01472 m
.1649 .01472 L
s
.16586 .01472 m
.16586 .01472 L
s
.16681 .01472 m
.16681 .01472 L
s
.16776 .01472 m
.16776 .01472 L
s
.16872 .01472 m
.16872 .01472 L
s
.16967 .01472 m
.16967 .01472 L
s
.17062 .01472 m
.17062 .01472 L
s
.17158 .01472 m
.17158 .01472 L
s
.17253 .01472 m
.17253 .01472 L
s
.17348 .01472 m
.17348 .01472 L
s
.17444 .01472 m
.17444 .01472 L
s
.17539 .01472 m
.17539 .01472 L
s
.17634 .01472 m
.17634 .01472 L
s
.1773 .01472 m
.1773 .01472 L
s
.17825 .01472 m
.17825 .01472 L
s
.1792 .01472 m
.1792 .01472 L
s
.18016 .01472 m
.18016 .01472 L
s
.18111 .01472 m
.18111 .01472 L
s
.18206 .01472 m
.18206 .01472 L
s
.18302 .01472 m
.18302 .01472 L
s
.18397 .01472 m
.18397 .01472 L
s
.18492 .01472 m
.18492 .01472 L
s
.18588 .01472 m
.18588 .01472 L
s
.18683 .01472 m
.18683 .01472 L
s
.18778 .01472 m
.18778 .01472 L
s
.18874 .01472 m
.18874 .01472 L
s
.18969 .01472 m
.18969 .01472 L
s
.19064 .01472 m
.19064 .01472 L
s
.1916 .01472 m
.1916 .01472 L
s
.19255 .01472 m
.19255 .01472 L
s
.1935 .01472 m
.1935 .01472 L
s
.19446 .01472 m
.19446 .01472 L
s
.19541 .01472 m
.19541 .01472 L
s
.19636 .01472 m
.19636 .01472 L
s
.19732 .01472 m
.19732 .01472 L
s
.19827 .01472 m
.19827 .01472 L
s
.19922 .01472 m
.19922 .01472 L
s
.20018 .01472 m
.20018 .01472 L
s
.20113 .01472 m
.20113 .01472 L
s
.20208 .01472 m
.20208 .01472 L
s
.20304 .01472 m
.20304 .01472 L
s
.20399 .01472 m
.20399 .01472 L
s
.20494 .01472 m
.20494 .01472 L
s
.2059 .01472 m
.2059 .01472 L
s
.20685 .01472 m
.20685 .01472 L
s
.2078 .01472 m
.2078 .01472 L
s
.20876 .01472 m
.20876 .01472 L
s
.20971 .01472 m
.20971 .01472 L
s
.21066 .01472 m
.21066 .01472 L
s
.21162 .01472 m
.21162 .01472 L
s
.21257 .01472 m
.21257 .01472 L
s
.21352 .01472 m
.21352 .01472 L
s
.21448 .01472 m
.21448 .01472 L
s
.21543 .01472 m
.21543 .01472 L
s
.21638 .01472 m
.21638 .01472 L
s
.21734 .01472 m
.21734 .01472 L
s
.21829 .01472 m
.21829 .01472 L
s
.21924 .01472 m
.21924 .01472 L
s
.2202 .01472 m
.2202 .01472 L
s
.22115 .01472 m
.22115 .01472 L
s
.2221 .01472 m
.2221 .01472 L
s
.22306 .01472 m
.22306 .01472 L
s
.22401 .01472 m
.22401 .01472 L
s
.22496 .01472 m
.22496 .01472 L
s
.22592 .01472 m
.22592 .01472 L
s
.22687 .01472 m
.22687 .01472 L
s
.22782 .01472 m
.22782 .01472 L
s
.22878 .01472 m
.22878 .01472 L
s
.22973 .01472 m
.22973 .01472 L
s
.23068 .01472 m
.23068 .01472 L
s
.23164 .01472 m
.23164 .01472 L
s
.23259 .01472 m
.23259 .01472 L
s
.23354 .01472 m
.23354 .01472 L
s
.2345 .01472 m
.2345 .01472 L
s
.23545 .01472 m
.23545 .01472 L
s
.2364 .01472 m
.2364 .01472 L
s
.23736 .01472 m
.23736 .01472 L
s
.23831 .01472 m
.23831 .01472 L
s
.23926 .01472 m
.23926 .01472 L
s
.24022 .01472 m
.24022 .01472 L
s
.24117 .01472 m
.24117 .01472 L
s
.24212 .01472 m
.24212 .01472 L
s
.24308 .01472 m
.24308 .01472 L
s
.24403 .01472 m
.24403 .01472 L
s
.24498 .01472 m
.24498 .01472 L
s
.24594 .01472 m
.24594 .01472 L
s
.24689 .01472 m
.24689 .01472 L
s
.24784 .01472 m
.24784 .01472 L
s
.2488 .01472 m
.2488 .01472 L
s
.24975 .01472 m
.24975 .01472 L
s
.2507 .01472 m
.2507 .01472 L
s
.25166 .01472 m
.25166 .01472 L
s
.25261 .01472 m
.25261 .01472 L
s
.25356 .01472 m
.25356 .01472 L
s
.25452 .01472 m
.25452 .01472 L
s
.25547 .01472 m
.25547 .01472 L
s
.25642 .01472 m
.25642 .01472 L
s
.25738 .01472 m
.25738 .01472 L
s
.25833 .01472 m
.25833 .01472 L
s
.25928 .01472 m
.25928 .01472 L
s
.26024 .01472 m
.26024 .01472 L
s
.26119 .01472 m
.26119 .01472 L
s
.26214 .01472 m
.26214 .01472 L
s
.2631 .01472 m
.2631 .01472 L
s
.26405 .01472 m
.26405 .01472 L
s
.265 .01472 m
.265 .01472 L
s
.26596 .01472 m
.26596 .01472 L
s
.26691 .01472 m
.26691 .01472 L
s
.26786 .01472 m
.26786 .01472 L
s
.26882 .01472 m
.26882 .01472 L
s
.26977 .01472 m
.26977 .01472 L
s
.27072 .01472 m
.27072 .01472 L
s
.27168 .01472 m
.27168 .01472 L
s
.27263 .01472 m
.27263 .01472 L
s
.27358 .01472 m
.27358 .01472 L
s
.27454 .01472 m
.27454 .01472 L
s
.27549 .01472 m
.27549 .01472 L
s
.27644 .01472 m
.27644 .01472 L
s
.2774 .01472 m
.2774 .01472 L
s
.27835 .01472 m
.27835 .01472 L
s
.2793 .01472 m
.2793 .01472 L
s
.28026 .01472 m
.28026 .01472 L
s
.28121 .01472 m
.28121 .01472 L
s
.28216 .01472 m
.28216 .01472 L
s
.28312 .01472 m
.28312 .01472 L
s
.28407 .01472 m
.28407 .01472 L
s
.28502 .01472 m
.28502 .01472 L
s
.28598 .01472 m
.28598 .01472 L
s
.28693 .01472 m
.28693 .01472 L
s
.28788 .01472 m
.28788 .01472 L
s
.28884 .01472 m
.28884 .01472 L
s
.28979 .01472 m
.28979 .01472 L
s
.29074 .01472 m
.29074 .01472 L
s
.2917 .01472 m
.2917 .01472 L
s
.29265 .01472 m
.29265 .01472 L
s
.2936 .01472 m
.2936 .01472 L
s
.29456 .01472 m
.29456 .01472 L
s
.29551 .01472 m
.29551 .01472 L
s
.29646 .01472 m
.29646 .01472 L
s
.29742 .01472 m
.29742 .01472 L
s
.29837 .01472 m
.29837 .01472 L
s
.29932 .01472 m
.29932 .01472 L
s
.30028 .01472 m
.30028 .01472 L
s
.30123 .01472 m
.30123 .01472 L
s
.30218 .01472 m
.30218 .01472 L
s
.30314 .01472 m
.30314 .01472 L
s
.30409 .01472 m
.30409 .01472 L
s
.30504 .01472 m
.30504 .01472 L
s
.306 .01472 m
.306 .01472 L
s
.30695 .01472 m
.30695 .01472 L
s
.3079 .01472 m
.3079 .01472 L
s
.30886 .01472 m
.30886 .01472 L
s
.30981 .01472 m
.30981 .01472 L
s
.31076 .01472 m
.31076 .01472 L
s
.31172 .01472 m
.31172 .01472 L
s
.31267 .01472 m
.31267 .01472 L
s
.31362 .01472 m
.31362 .01472 L
s
.31458 .01472 m
.31458 .01472 L
s
.31553 .01472 m
.31553 .01472 L
s
.31648 .01472 m
.31648 .01472 L
s
.31744 .01472 m
.31744 .01472 L
s
.31839 .01472 m
.31839 .01472 L
s
.31934 .01472 m
.31934 .01472 L
s
.3203 .01472 m
.3203 .01472 L
s
.32125 .01472 m
.32125 .01472 L
s
.3222 .01472 m
.3222 .01472 L
s
.32316 .01472 m
.32316 .01472 L
s
.32411 .01472 m
.32411 .01472 L
s
.32506 .01472 m
.32506 .01472 L
s
.32602 .01472 m
.32602 .01472 L
s
.32697 .01472 m
.32697 .01472 L
s
.32792 .01472 m
.32792 .01472 L
s
.32888 .01472 m
.32888 .01472 L
s
.32983 .01472 m
.32983 .01472 L
s
.33078 .01472 m
.33078 .01472 L
s
.33174 .01472 m
.33174 .01472 L
s
.33269 .01472 m
.33269 .01472 L
s
.33364 .01472 m
.33364 .01472 L
s
.3346 .01472 m
.3346 .01472 L
s
.33555 .01472 m
.33555 .01472 L
s
.3365 .01472 m
.3365 .01472 L
s
.33746 .01472 m
.33746 .01472 L
s
.33841 .01472 m
.33841 .01472 L
s
.33936 .01472 m
.33936 .01472 L
s
.34032 .01472 m
.34032 .01472 L
s
.34127 .01472 m
.34127 .01472 L
s
.34222 .01472 m
.34222 .01472 L
s
.34318 .01472 m
.34318 .01472 L
s
.34413 .01472 m
.34413 .01472 L
s
.34508 .01472 m
.34508 .01472 L
s
.34604 .01472 m
.34604 .01472 L
s
.34699 .01472 m
.34699 .01472 L
s
.34794 .01472 m
.34794 .01472 L
s
.3489 .01472 m
.3489 .01472 L
s
.34985 .01472 m
.34985 .01472 L
s
.3508 .01472 m
.3508 .01472 L
s
.35176 .01472 m
.35176 .01472 L
s
.35271 .01472 m
.35271 .01472 L
s
.35366 .01472 m
.35366 .01472 L
s
.35462 .01472 m
.35462 .01472 L
s
.35557 .01472 m
.35557 .01472 L
s
.35652 .01472 m
.35652 .01472 L
s
.35748 .01472 m
.35748 .01472 L
s
.35843 .01472 m
.35843 .01472 L
s
.35938 .01472 m
.35938 .01472 L
s
.36034 .01472 m
.36034 .01472 L
s
.36129 .01472 m
.36129 .01472 L
s
.36224 .01472 m
.36224 .01472 L
s
.3632 .01472 m
.3632 .01472 L
s
.36415 .01472 m
.36415 .01472 L
s
.3651 .01472 m
.3651 .01472 L
s
.36606 .01472 m
.36606 .01472 L
s
.36701 .01472 m
.36701 .01472 L
s
.36796 .01472 m
.36796 .01472 L
s
.36892 .01472 m
.36892 .01472 L
s
.36987 .01472 m
.36987 .01472 L
s
.37082 .01472 m
.37082 .01472 L
s
.37178 .01472 m
.37178 .01472 L
s
.37273 .01472 m
.37273 .01472 L
s
.37368 .01472 m
.37368 .01472 L
s
.37464 .01472 m
.37464 .01472 L
s
.37559 .01472 m
.37559 .01472 L
s
.37654 .01472 m
.37654 .01472 L
s
.3775 .01472 m
.3775 .01472 L
s
.37845 .01472 m
.37845 .01472 L
s
.3794 .01472 m
.3794 .01472 L
s
.38036 .01472 m
.38036 .01472 L
s
.38131 .01472 m
.38131 .01473 L
s
.38226 .01472 m
.38226 .01473 L
s
.38322 .01472 m
.38322 .01473 L
s
.38417 .01472 m
.38417 .01473 L
s
.38512 .01472 m
.38512 .01473 L
s
.38608 .01472 m
.38608 .01473 L
s
.38703 .01472 m
.38703 .01473 L
s
.38798 .01472 m
.38798 .01473 L
s
.38894 .01472 m
.38894 .01473 L
s
.38989 .01472 m
.38989 .01473 L
s
.39084 .01472 m
.39084 .01473 L
s
.3918 .01472 m
.3918 .01473 L
s
.39275 .01472 m
.39275 .01473 L
s
.3937 .01472 m
.3937 .01473 L
s
.39466 .01472 m
.39466 .01473 L
s
.39561 .01472 m
.39561 .01473 L
s
.39656 .01472 m
.39656 .01473 L
s
.39752 .01472 m
.39752 .01473 L
s
.39847 .01472 m
.39847 .01473 L
s
.39942 .01472 m
.39942 .01473 L
s
.40038 .01472 m
.40038 .01473 L
s
.40133 .01472 m
.40133 .01473 L
s
.40228 .01472 m
.40228 .01473 L
s
.40324 .01472 m
.40324 .01473 L
s
.40419 .01472 m
.40419 .01473 L
s
.40514 .01472 m
.40514 .01473 L
s
.4061 .01472 m
.4061 .01473 L
s
.40705 .01472 m
.40705 .01473 L
s
.408 .01472 m
.408 .01473 L
s
.40896 .01472 m
.40896 .01473 L
s
.40991 .01472 m
.40991 .01473 L
s
.41086 .01472 m
.41086 .01473 L
s
.41182 .01472 m
.41182 .01474 L
s
.41277 .01472 m
.41277 .01474 L
s
.41372 .01472 m
.41372 .01474 L
s
.41468 .01472 m
.41468 .01474 L
s
.41563 .01472 m
.41563 .01474 L
s
.41658 .01472 m
.41658 .01474 L
s
.41754 .01472 m
.41754 .01474 L
s
.41849 .01472 m
.41849 .01474 L
s
.41944 .01472 m
.41944 .01474 L
s
.4204 .01472 m
.4204 .01474 L
s
.42135 .01472 m
.42135 .01474 L
s
.4223 .01472 m
.4223 .01474 L
s
.42326 .01472 m
.42326 .01474 L
s
.42421 .01472 m
.42421 .01475 L
s
.42516 .01472 m
.42516 .01475 L
s
.42612 .01472 m
.42612 .01475 L
s
.42707 .01472 m
.42707 .01475 L
s
.42802 .01472 m
.42802 .01475 L
s
.42898 .01472 m
.42898 .01475 L
s
.42993 .01472 m
.42993 .01475 L
s
.43088 .01472 m
.43088 .01475 L
s
.43184 .01472 m
.43184 .01476 L
s
.43279 .01472 m
.43279 .01476 L
s
.43374 .01472 m
.43374 .01476 L
s
.4347 .01472 m
.4347 .01476 L
s
.43565 .01472 m
.43565 .01476 L
s
.4366 .01472 m
.4366 .01477 L
s
.43756 .01472 m
.43756 .01477 L
s
.43851 .01472 m
.43851 .01477 L
s
.43946 .01472 m
.43946 .01477 L
s
.44042 .01472 m
.44042 .01478 L
s
.44137 .01472 m
.44137 .01478 L
s
.44232 .01472 m
.44232 .01478 L
s
.44328 .01472 m
.44328 .01479 L
s
.44423 .01472 m
.44423 .01479 L
s
.44518 .01472 m
.44518 .0148 L
s
.44614 .01472 m
.44614 .0148 L
s
.44709 .01472 m
.44709 .01481 L
s
.44804 .01472 m
.44804 .01482 L
s
.449 .01472 m
.449 .01482 L
s
.44995 .01472 m
.44995 .01483 L
s
.4509 .01472 m
.4509 .01484 L
s
.45186 .01472 m
.45186 .01485 L
s
.45281 .01472 m
.45281 .01486 L
s
.45376 .01472 m
.45376 .01488 L
s
.45472 .01472 m
.45472 .0149 L
s
.45567 .01472 m
.45567 .01492 L
s
.45662 .01472 m
.45662 .01494 L
s
.45758 .01472 m
.45758 .01497 L
s
.45853 .01472 m
.45853 .015 L
s
.45948 .01472 m
.45948 .01505 L
s
.46044 .01472 m
.46044 .0151 L
s
.46139 .01472 m
.46139 .01518 L
s
.46234 .01472 m
.46234 .01528 L
s
.4633 .01472 m
.4633 .01541 L
s
.46425 .01472 m
.46425 .01561 L
s
.4652 .01472 m
.4652 .01591 L
s
.46616 .01472 m
.46616 .01642 L
s
.46711 .01472 m
.46711 .01738 L
s
.46806 .01472 m
.46806 .01961 L
s
.46902 .01472 m
.46902 .02761 L
s
.46997 .01472 m
.46997 .60332 L
s
.47092 .01472 m
.47092 .04953 L
s
.47188 .01472 m
.47188 .58601 L
s
.47283 .01472 m
.47283 .02513 L
s
.47378 .01472 m
.47378 .01854 L
s
.47474 .01472 m
.47474 .01669 L
s
.47569 .01472 m
.47569 .0159 L
s
.47664 .01472 m
.47664 .01549 L
s
.4776 .01472 m
.4776 .01526 L
s
.47855 .01472 m
.47855 .01511 L
s
.4795 .01472 m
.4795 .01501 L
s
.48046 .01472 m
.48046 .01494 L
s
.48141 .01472 m
.48141 .01489 L
s
.48236 .01472 m
.48236 .01485 L
s
.48332 .01472 m
.48332 .01482 L
s
.48427 .01472 m
.48427 .0148 L
s
.48522 .01472 m
.48522 .01478 L
s
.48618 .01472 m
.48618 .01477 L
s
.48713 .01472 m
.48713 .01476 L
s
.48808 .01472 m
.48808 .01475 L
s
.48904 .01472 m
.48904 .01474 L
s
.48999 .01472 m
.48999 .01474 L
s
.49094 .01472 m
.49094 .01473 L
s
.4919 .01472 m
.4919 .01473 L
s
.49285 .01472 m
.49285 .01472 L
s
.4938 .01472 m
.4938 .01472 L
s
.49476 .01472 m
.49476 .01472 L
s
.49571 .01472 m
.49571 .01472 L
s
.49666 .01472 m
.49666 .01472 L
s
.49762 .01472 m
.49762 .01472 L
s
.49857 .01472 m
.49857 .01472 L
s
.49952 .01472 m
.49952 .01472 L
s
.50048 .01472 m
.50048 .01472 L
s
.50143 .01472 m
.50143 .01472 L
s
.50238 .01472 m
.50238 .01472 L
s
.50334 .01472 m
.50334 .01472 L
s
.50429 .01472 m
.50429 .01472 L
s
.50524 .01472 m
.50524 .01472 L
s
.5062 .01472 m
.5062 .01472 L
s
.50715 .01472 m
.50715 .01473 L
s
.5081 .01472 m
.5081 .01473 L
s
.50906 .01472 m
.50906 .01474 L
s
.51001 .01472 m
.51001 .01474 L
s
.51096 .01472 m
.51096 .01475 L
s
.51192 .01472 m
.51192 .01476 L
s
.51287 .01472 m
.51287 .01477 L
s
.51382 .01472 m
.51382 .01478 L
s
.51478 .01472 m
.51478 .0148 L
s
.51573 .01472 m
.51573 .01482 L
s
.51668 .01472 m
.51668 .01485 L
s
.51764 .01472 m
.51764 .01489 L
s
.51859 .01472 m
.51859 .01494 L
s
.51954 .01472 m
.51954 .01501 L
s
.5205 .01472 m
.5205 .01511 L
s
.52145 .01472 m
.52145 .01526 L
s
.5224 .01472 m
.5224 .01549 L
s
.52336 .01472 m
.52336 .0159 L
s
.52431 .01472 m
.52431 .01669 L
s
.52526 .01472 m
.52526 .01854 L
s
.52622 .01472 m
.52622 .02513 L
s
.52717 .01472 m
.52717 .58601 L
s
.52812 .01472 m
.52812 .04953 L
s
.52908 .01472 m
.52908 .60332 L
s
.53003 .01472 m
.53003 .02761 L
s
.53098 .01472 m
.53098 .01961 L
s
.53194 .01472 m
.53194 .01738 L
s
.53289 .01472 m
.53289 .01642 L
s
.53384 .01472 m
.53384 .01591 L
s
.5348 .01472 m
.5348 .01561 L
s
.53575 .01472 m
.53575 .01541 L
s
.5367 .01472 m
.5367 .01528 L
s
.53766 .01472 m
.53766 .01518 L
s
.53861 .01472 m
.53861 .0151 L
s
.53956 .01472 m
.53956 .01505 L
s
.54052 .01472 m
.54052 .015 L
s
.54147 .01472 m
.54147 .01497 L
s
.54242 .01472 m
.54242 .01494 L
s
.54338 .01472 m
.54338 .01492 L
s
.54433 .01472 m
.54433 .0149 L
s
.54528 .01472 m
.54528 .01488 L
s
.54624 .01472 m
.54624 .01486 L
s
.54719 .01472 m
.54719 .01485 L
s
.54814 .01472 m
.54814 .01484 L
s
.5491 .01472 m
.5491 .01483 L
s
.55005 .01472 m
.55005 .01482 L
s
.551 .01472 m
.551 .01482 L
s
.55196 .01472 m
.55196 .01481 L
s
.55291 .01472 m
.55291 .0148 L
s
.55386 .01472 m
.55386 .0148 L
s
.55482 .01472 m
.55482 .01479 L
s
.55577 .01472 m
.55577 .01479 L
s
.55672 .01472 m
.55672 .01478 L
s
.55768 .01472 m
.55768 .01478 L
s
.55863 .01472 m
.55863 .01478 L
s
.55958 .01472 m
.55958 .01477 L
s
.56054 .01472 m
.56054 .01477 L
s
.56149 .01472 m
.56149 .01477 L
s
.56244 .01472 m
.56244 .01477 L
s
.5634 .01472 m
.5634 .01476 L
s
.56435 .01472 m
.56435 .01476 L
s
.5653 .01472 m
.5653 .01476 L
s
.56626 .01472 m
.56626 .01476 L
s
.56721 .01472 m
.56721 .01476 L
s
.56816 .01472 m
.56816 .01475 L
s
.56912 .01472 m
.56912 .01475 L
s
.57007 .01472 m
.57007 .01475 L
s
.57102 .01472 m
.57102 .01475 L
s
.57198 .01472 m
.57198 .01475 L
s
.57293 .01472 m
.57293 .01475 L
s
.57388 .01472 m
.57388 .01475 L
s
.57484 .01472 m
.57484 .01475 L
s
.57579 .01472 m
.57579 .01474 L
s
.57674 .01472 m
.57674 .01474 L
s
.5777 .01472 m
.5777 .01474 L
s
.57865 .01472 m
.57865 .01474 L
s
.5796 .01472 m
.5796 .01474 L
s
.58056 .01472 m
.58056 .01474 L
s
.58151 .01472 m
.58151 .01474 L
s
.58246 .01472 m
.58246 .01474 L
s
.58342 .01472 m
.58342 .01474 L
s
.58437 .01472 m
.58437 .01474 L
s
.58532 .01472 m
.58532 .01474 L
s
.58628 .01472 m
.58628 .01474 L
s
.58723 .01472 m
.58723 .01474 L
s
.58818 .01472 m
.58818 .01473 L
s
.58914 .01472 m
.58914 .01473 L
s
.59009 .01472 m
.59009 .01473 L
s
.59104 .01472 m
.59104 .01473 L
s
.592 .01472 m
.592 .01473 L
s
.59295 .01472 m
.59295 .01473 L
s
.5939 .01472 m
.5939 .01473 L
s
.59486 .01472 m
.59486 .01473 L
s
.59581 .01472 m
.59581 .01473 L
s
.59676 .01472 m
.59676 .01473 L
s
.59772 .01472 m
.59772 .01473 L
s
.59867 .01472 m
.59867 .01473 L
s
.59962 .01472 m
.59962 .01473 L
s
.60058 .01472 m
.60058 .01473 L
s
.60153 .01472 m
.60153 .01473 L
s
.60248 .01472 m
.60248 .01473 L
s
.60344 .01472 m
.60344 .01473 L
s
.60439 .01472 m
.60439 .01473 L
s
.60534 .01472 m
.60534 .01473 L
s
.6063 .01472 m
.6063 .01473 L
s
.60725 .01472 m
.60725 .01473 L
s
.6082 .01472 m
.6082 .01473 L
s
.60916 .01472 m
.60916 .01473 L
s
.61011 .01472 m
.61011 .01473 L
s
.61106 .01472 m
.61106 .01473 L
s
.61202 .01472 m
.61202 .01473 L
s
.61297 .01472 m
.61297 .01473 L
s
.61392 .01472 m
.61392 .01473 L
s
.61488 .01472 m
.61488 .01473 L
s
.61583 .01472 m
.61583 .01473 L
s
.61678 .01472 m
.61678 .01473 L
s
.61774 .01472 m
.61774 .01473 L
s
.61869 .01472 m
.61869 .01472 L
s
.61964 .01472 m
.61964 .01472 L
s
.6206 .01472 m
.6206 .01472 L
s
.62155 .01472 m
.62155 .01472 L
s
.6225 .01472 m
.6225 .01472 L
s
.62346 .01472 m
.62346 .01472 L
s
.62441 .01472 m
.62441 .01472 L
s
.62536 .01472 m
.62536 .01472 L
s
.62632 .01472 m
.62632 .01472 L
s
.62727 .01472 m
.62727 .01472 L
s
.62822 .01472 m
.62822 .01472 L
s
.62918 .01472 m
.62918 .01472 L
s
.63013 .01472 m
.63013 .01472 L
s
.63108 .01472 m
.63108 .01472 L
s
.63204 .01472 m
.63204 .01472 L
s
.63299 .01472 m
.63299 .01472 L
s
.63394 .01472 m
.63394 .01472 L
s
.6349 .01472 m
.6349 .01472 L
s
.63585 .01472 m
.63585 .01472 L
s
.6368 .01472 m
.6368 .01472 L
s
.63776 .01472 m
.63776 .01472 L
s
.63871 .01472 m
.63871 .01472 L
s
.63966 .01472 m
.63966 .01472 L
s
.64062 .01472 m
.64062 .01472 L
s
.64157 .01472 m
.64157 .01472 L
s
.64252 .01472 m
.64252 .01472 L
s
.64348 .01472 m
.64348 .01472 L
s
.64443 .01472 m
.64443 .01472 L
s
.64538 .01472 m
.64538 .01472 L
s
.64634 .01472 m
.64634 .01472 L
s
.64729 .01472 m
.64729 .01472 L
s
.64824 .01472 m
.64824 .01472 L
s
.6492 .01472 m
.6492 .01472 L
s
.65015 .01472 m
.65015 .01472 L
s
.6511 .01472 m
.6511 .01472 L
s
.65206 .01472 m
.65206 .01472 L
s
.65301 .01472 m
.65301 .01472 L
s
.65396 .01472 m
.65396 .01472 L
s
.65492 .01472 m
.65492 .01472 L
s
.65587 .01472 m
.65587 .01472 L
s
.65682 .01472 m
.65682 .01472 L
s
.65778 .01472 m
.65778 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.65968 .01472 m
.65968 .01472 L
s
.66064 .01472 m
.66064 .01472 L
s
.66159 .01472 m
.66159 .01472 L
s
.66254 .01472 m
.66254 .01472 L
s
.6635 .01472 m
.6635 .01472 L
s
.66445 .01472 m
.66445 .01472 L
s
.6654 .01472 m
.6654 .01472 L
s
.66636 .01472 m
.66636 .01472 L
s
.66731 .01472 m
.66731 .01472 L
s
.66826 .01472 m
.66826 .01472 L
s
.66922 .01472 m
.66922 .01472 L
s
.67017 .01472 m
.67017 .01472 L
s
.67112 .01472 m
.67112 .01472 L
s
.67208 .01472 m
.67208 .01472 L
s
.67303 .01472 m
.67303 .01472 L
s
.67398 .01472 m
.67398 .01472 L
s
.67494 .01472 m
.67494 .01472 L
s
.67589 .01472 m
.67589 .01472 L
s
.67684 .01472 m
.67684 .01472 L
s
.6778 .01472 m
.6778 .01472 L
s
.67875 .01472 m
.67875 .01472 L
s
.6797 .01472 m
.6797 .01472 L
s
.68066 .01472 m
.68066 .01472 L
s
.68161 .01472 m
.68161 .01472 L
s
.68256 .01472 m
.68256 .01472 L
s
.68352 .01472 m
.68352 .01472 L
s
.68447 .01472 m
.68447 .01472 L
s
.68542 .01472 m
.68542 .01472 L
s
.68638 .01472 m
.68638 .01472 L
s
.68733 .01472 m
.68733 .01472 L
s
.68828 .01472 m
.68828 .01472 L
s
.68924 .01472 m
.68924 .01472 L
s
.69019 .01472 m
.69019 .01472 L
s
.69114 .01472 m
.69114 .01472 L
s
.6921 .01472 m
.6921 .01472 L
s
.69305 .01472 m
.69305 .01472 L
s
.694 .01472 m
.694 .01472 L
s
.69496 .01472 m
.69496 .01472 L
s
.69591 .01472 m
.69591 .01472 L
s
.69686 .01472 m
.69686 .01472 L
s
.69782 .01472 m
.69782 .01472 L
s
.69877 .01472 m
.69877 .01472 L
s
.69972 .01472 m
.69972 .01472 L
s
.70068 .01472 m
.70068 .01472 L
s
.70163 .01472 m
.70163 .01472 L
s
.70258 .01472 m
.70258 .01472 L
s
.70354 .01472 m
.70354 .01472 L
s
.70449 .01472 m
.70449 .01472 L
s
.70544 .01472 m
.70544 .01472 L
s
.7064 .01472 m
.7064 .01472 L
s
.70735 .01472 m
.70735 .01472 L
s
.7083 .01472 m
.7083 .01472 L
s
.70926 .01472 m
.70926 .01472 L
s
.71021 .01472 m
.71021 .01472 L
s
.71116 .01472 m
.71116 .01472 L
s
.71212 .01472 m
.71212 .01472 L
s
.71307 .01472 m
.71307 .01472 L
s
.71402 .01472 m
.71402 .01472 L
s
.71498 .01472 m
.71498 .01472 L
s
.71593 .01472 m
.71593 .01472 L
s
.71688 .01472 m
.71688 .01472 L
s
.71784 .01472 m
.71784 .01472 L
s
.71879 .01472 m
.71879 .01472 L
s
.71974 .01472 m
.71974 .01472 L
s
.7207 .01472 m
.7207 .01472 L
s
.72165 .01472 m
.72165 .01472 L
s
.7226 .01472 m
.7226 .01472 L
s
.72356 .01472 m
.72356 .01472 L
s
.72451 .01472 m
.72451 .01472 L
s
.72546 .01472 m
.72546 .01472 L
s
.72642 .01472 m
.72642 .01472 L
s
.72737 .01472 m
.72737 .01472 L
s
.72832 .01472 m
.72832 .01472 L
s
.72928 .01472 m
.72928 .01472 L
s
.73023 .01472 m
.73023 .01472 L
s
.73118 .01472 m
.73118 .01472 L
s
.73214 .01472 m
.73214 .01472 L
s
.73309 .01472 m
.73309 .01472 L
s
.73404 .01472 m
.73404 .01472 L
s
.735 .01472 m
.735 .01472 L
s
.73595 .01472 m
.73595 .01472 L
s
.7369 .01472 m
.7369 .01472 L
s
.73786 .01472 m
.73786 .01472 L
s
.73881 .01472 m
.73881 .01472 L
s
.73976 .01472 m
.73976 .01472 L
s
.74072 .01472 m
.74072 .01472 L
s
.74167 .01472 m
.74167 .01472 L
s
.74262 .01472 m
.74262 .01472 L
s
.74358 .01472 m
.74358 .01472 L
s
.74453 .01472 m
.74453 .01472 L
s
.74548 .01472 m
.74548 .01472 L
s
.74644 .01472 m
.74644 .01472 L
s
.74739 .01472 m
.74739 .01472 L
s
.74834 .01472 m
.74834 .01472 L
s
.7493 .01472 m
.7493 .01472 L
s
.75025 .01472 m
.75025 .01472 L
s
.7512 .01472 m
.7512 .01472 L
s
.75216 .01472 m
.75216 .01472 L
s
.75311 .01472 m
.75311 .01472 L
s
.75406 .01472 m
.75406 .01472 L
s
.75502 .01472 m
.75502 .01472 L
s
.75597 .01472 m
.75597 .01472 L
s
.75692 .01472 m
.75692 .01472 L
s
.75788 .01472 m
.75788 .01472 L
s
.75883 .01472 m
.75883 .01472 L
s
.75978 .01472 m
.75978 .01472 L
s
.76074 .01472 m
.76074 .01472 L
s
.76169 .01472 m
.76169 .01472 L
s
.76264 .01472 m
.76264 .01472 L
s
.7636 .01472 m
.7636 .01472 L
s
.76455 .01472 m
.76455 .01472 L
s
.7655 .01472 m
.7655 .01472 L
s
.76646 .01472 m
.76646 .01472 L
s
.76741 .01472 m
.76741 .01472 L
s
.76836 .01472 m
.76836 .01472 L
s
.76932 .01472 m
.76932 .01472 L
s
.77027 .01472 m
.77027 .01472 L
s
.77122 .01472 m
.77122 .01472 L
s
.77218 .01472 m
.77218 .01472 L
s
.77313 .01472 m
.77313 .01472 L
s
.77408 .01472 m
.77408 .01472 L
s
.77504 .01472 m
.77504 .01472 L
s
.77599 .01472 m
.77599 .01472 L
s
.77694 .01472 m
.77694 .01472 L
s
.7779 .01472 m
.7779 .01472 L
s
.77885 .01472 m
.77885 .01472 L
s
.7798 .01472 m
.7798 .01472 L
s
.78076 .01472 m
.78076 .01472 L
s
.78171 .01472 m
.78171 .01472 L
s
.78266 .01472 m
.78266 .01472 L
s
.78362 .01472 m
.78362 .01472 L
s
.78457 .01472 m
.78457 .01472 L
s
.78552 .01472 m
.78552 .01472 L
s
.78648 .01472 m
.78648 .01472 L
s
.78743 .01472 m
.78743 .01472 L
s
.78838 .01472 m
.78838 .01472 L
s
.78934 .01472 m
.78934 .01472 L
s
.79029 .01472 m
.79029 .01472 L
s
.79124 .01472 m
.79124 .01472 L
s
.7922 .01472 m
.7922 .01472 L
s
.79315 .01472 m
.79315 .01472 L
s
.7941 .01472 m
.7941 .01472 L
s
.79506 .01472 m
.79506 .01472 L
s
.79601 .01472 m
.79601 .01472 L
s
.79696 .01472 m
.79696 .01472 L
s
.79792 .01472 m
.79792 .01472 L
s
.79887 .01472 m
.79887 .01472 L
s
.79982 .01472 m
.79982 .01472 L
s
.80078 .01472 m
.80078 .01472 L
s
.80173 .01472 m
.80173 .01472 L
s
.80268 .01472 m
.80268 .01472 L
s
.80364 .01472 m
.80364 .01472 L
s
.80459 .01472 m
.80459 .01472 L
s
.80554 .01472 m
.80554 .01472 L
s
.8065 .01472 m
.8065 .01472 L
s
.80745 .01472 m
.80745 .01472 L
s
.8084 .01472 m
.8084 .01472 L
s
.80936 .01472 m
.80936 .01472 L
s
.81031 .01472 m
.81031 .01472 L
s
.81126 .01472 m
.81126 .01472 L
s
.81222 .01472 m
.81222 .01472 L
s
.81317 .01472 m
.81317 .01472 L
s
.81412 .01472 m
.81412 .01472 L
s
.81508 .01472 m
.81508 .01472 L
s
.81603 .01472 m
.81603 .01472 L
s
.81698 .01472 m
.81698 .01472 L
s
.81794 .01472 m
.81794 .01472 L
s
.81889 .01472 m
.81889 .01472 L
s
.81984 .01472 m
.81984 .01472 L
s
.8208 .01472 m
.8208 .01472 L
s
.82175 .01472 m
.82175 .01472 L
s
.8227 .01472 m
.8227 .01472 L
s
.82366 .01472 m
.82366 .01472 L
s
.82461 .01472 m
.82461 .01472 L
s
.82556 .01472 m
.82556 .01472 L
s
.82652 .01472 m
.82652 .01472 L
s
.82747 .01472 m
.82747 .01472 L
s
.82842 .01472 m
.82842 .01472 L
s
.82938 .01472 m
.82938 .01472 L
s
.83033 .01472 m
.83033 .01472 L
s
.83128 .01472 m
.83128 .01472 L
s
.83224 .01472 m
.83224 .01472 L
s
.83319 .01472 m
.83319 .01472 L
s
.83414 .01472 m
.83414 .01472 L
s
.8351 .01472 m
.8351 .01472 L
s
.83605 .01472 m
.83605 .01472 L
s
.837 .01472 m
.837 .01472 L
s
.83796 .01472 m
.83796 .01472 L
s
.83891 .01472 m
.83891 .01472 L
s
.83986 .01472 m
.83986 .01472 L
s
.84082 .01472 m
.84082 .01472 L
s
.84177 .01472 m
.84177 .01472 L
s
.84272 .01472 m
.84272 .01472 L
s
.84368 .01472 m
.84368 .01472 L
s
.84463 .01472 m
.84463 .01472 L
s
.84558 .01472 m
.84558 .01472 L
s
.84654 .01472 m
.84654 .01472 L
s
.84749 .01472 m
.84749 .01472 L
s
.84844 .01472 m
.84844 .01472 L
s
.8494 .01472 m
.8494 .01472 L
s
.85035 .01472 m
.85035 .01472 L
s
.8513 .01472 m
.8513 .01472 L
s
.85226 .01472 m
.85226 .01472 L
s
.85321 .01472 m
.85321 .01472 L
s
.85416 .01472 m
.85416 .01472 L
s
.85512 .01472 m
.85512 .01472 L
s
.85607 .01472 m
.85607 .01472 L
s
.85702 .01472 m
.85702 .01472 L
s
.85798 .01472 m
.85798 .01472 L
s
.85893 .01472 m
.85893 .01472 L
s
.85988 .01472 m
.85988 .01472 L
s
.86084 .01472 m
.86084 .01472 L
s
.86179 .01472 m
.86179 .01472 L
s
.86274 .01472 m
.86274 .01472 L
s
.8637 .01472 m
.8637 .01472 L
s
.86465 .01472 m
.86465 .01472 L
s
.8656 .01472 m
.8656 .01472 L
s
.86656 .01472 m
.86656 .01472 L
s
.86751 .01472 m
.86751 .01472 L
s
.86846 .01472 m
.86846 .01472 L
s
.86942 .01472 m
.86942 .01472 L
s
.87037 .01472 m
.87037 .01472 L
s
.87132 .01472 m
.87132 .01472 L
s
.87228 .01472 m
.87228 .01472 L
s
.87323 .01472 m
.87323 .01472 L
s
.87418 .01472 m
.87418 .01472 L
s
.87514 .01472 m
.87514 .01472 L
s
.87609 .01472 m
.87609 .01472 L
s
.87704 .01472 m
.87704 .01472 L
s
.878 .01472 m
.878 .01472 L
s
.87895 .01472 m
.87895 .01472 L
s
.8799 .01472 m
.8799 .01472 L
s
.88086 .01472 m
.88086 .01472 L
s
.88181 .01472 m
.88181 .01472 L
s
.88276 .01472 m
.88276 .01472 L
s
.88372 .01472 m
.88372 .01472 L
s
.88467 .01472 m
.88467 .01472 L
s
.88562 .01472 m
.88562 .01472 L
s
.88658 .01472 m
.88658 .01472 L
s
.88753 .01472 m
.88753 .01472 L
s
.88848 .01472 m
.88848 .01472 L
s
.88944 .01472 m
.88944 .01472 L
s
.89039 .01472 m
.89039 .01472 L
s
.89134 .01472 m
.89134 .01472 L
s
.8923 .01472 m
.8923 .01472 L
s
.89325 .01472 m
.89325 .01472 L
s
.8942 .01472 m
.8942 .01472 L
s
.89516 .01472 m
.89516 .01472 L
s
.89611 .01472 m
.89611 .01472 L
s
.89706 .01472 m
.89706 .01472 L
s
.89802 .01472 m
.89802 .01472 L
s
.89897 .01472 m
.89897 .01472 L
s
.89992 .01472 m
.89992 .01472 L
s
.90088 .01472 m
.90088 .01472 L
s
.90183 .01472 m
.90183 .01472 L
s
.90278 .01472 m
.90278 .01472 L
s
.90374 .01472 m
.90374 .01472 L
s
.90469 .01472 m
.90469 .01472 L
s
.90564 .01472 m
.90564 .01472 L
s
.9066 .01472 m
.9066 .01472 L
s
.90755 .01472 m
.90755 .01472 L
s
.9085 .01472 m
.9085 .01472 L
s
.90946 .01472 m
.90946 .01472 L
s
.91041 .01472 m
.91041 .01472 L
s
.91136 .01472 m
.91136 .01472 L
s
.91232 .01472 m
.91232 .01472 L
s
.91327 .01472 m
.91327 .01472 L
s
.91422 .01472 m
.91422 .01472 L
s
.91518 .01472 m
.91518 .01472 L
s
.91613 .01472 m
.91613 .01472 L
s
.91708 .01472 m
.91708 .01472 L
s
.91804 .01472 m
.91804 .01472 L
s
.91899 .01472 m
.91899 .01472 L
s
.91994 .01472 m
.91994 .01472 L
s
.9209 .01472 m
.9209 .01472 L
s
.92185 .01472 m
.92185 .01472 L
s
.9228 .01472 m
.9228 .01472 L
s
.92376 .01472 m
.92376 .01472 L
s
.92471 .01472 m
.92471 .01472 L
s
.92566 .01472 m
.92566 .01472 L
s
.92662 .01472 m
.92662 .01472 L
s
.92757 .01472 m
.92757 .01472 L
s
.92852 .01472 m
.92852 .01472 L
s
.92948 .01472 m
.92948 .01472 L
s
.93043 .01472 m
.93043 .01472 L
s
.93138 .01472 m
.93138 .01472 L
s
.93234 .01472 m
.93234 .01472 L
s
.93329 .01472 m
.93329 .01472 L
s
.93424 .01472 m
.93424 .01472 L
s
.9352 .01472 m
.9352 .01472 L
s
.93615 .01472 m
.93615 .01472 L
s
.9371 .01472 m
.9371 .01472 L
s
.93806 .01472 m
.93806 .01472 L
s
.93901 .01472 m
.93901 .01472 L
s
.93996 .01472 m
.93996 .01472 L
s
.94092 .01472 m
.94092 .01472 L
s
.94187 .01472 m
.94187 .01472 L
s
.94282 .01472 m
.94282 .01472 L
s
.94378 .01472 m
.94378 .01472 L
s
.94473 .01472 m
.94473 .01472 L
s
.94568 .01472 m
.94568 .01472 L
s
.94664 .01472 m
.94664 .01472 L
s
.94759 .01472 m
.94759 .01472 L
s
.94854 .01472 m
.94854 .01472 L
s
.9495 .01472 m
.9495 .01472 L
s
.95045 .01472 m
.95045 .01472 L
s
.9514 .01472 m
.9514 .01472 L
s
.95236 .01472 m
.95236 .01472 L
s
.95331 .01472 m
.95331 .01472 L
s
.95426 .01472 m
.95426 .01472 L
s
.95522 .01472 m
.95522 .01472 L
s
.95617 .01472 m
.95617 .01472 L
s
.95712 .01472 m
.95712 .01472 L
s
.95808 .01472 m
.95808 .01472 L
s
.95903 .01472 m
.95903 .01472 L
s
.95998 .01472 m
.95998 .01472 L
s
.96094 .01472 m
.96094 .01472 L
s
.96189 .01472 m
.96189 .01472 L
s
.96284 .01472 m
.96284 .01472 L
s
.9638 .01472 m
.9638 .01472 L
s
.96475 .01472 m
.96475 .01472 L
s
.9657 .01472 m
.9657 .01472 L
s
.96666 .01472 m
.96666 .01472 L
s
.96761 .01472 m
.96761 .01472 L
s
.96856 .01472 m
.96856 .01472 L
s
.96952 .01472 m
.96952 .01472 L
s
.97047 .01472 m
.97047 .01472 L
s
.97142 .01472 m
.97142 .01472 L
s
.97238 .01472 m
.97238 .01472 L
s
.97333 .01472 m
.97333 .01472 L
s
.97428 .01472 m
.97428 .01472 L
s
.97524 .01472 m
.97524 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01472 Mdot
.02476 .01472 Mdot
.02572 .01472 Mdot
.02667 .01472 Mdot
.02762 .01472 Mdot
.02858 .01472 Mdot
.02953 .01472 Mdot
.03048 .01472 Mdot
.03144 .01472 Mdot
.03239 .01472 Mdot
.03334 .01472 Mdot
.0343 .01472 Mdot
.03525 .01472 Mdot
.0362 .01472 Mdot
.03716 .01472 Mdot
.03811 .01472 Mdot
.03906 .01472 Mdot
.04002 .01472 Mdot
.04097 .01472 Mdot
.04192 .01472 Mdot
.04288 .01472 Mdot
.04383 .01472 Mdot
.04478 .01472 Mdot
.04574 .01472 Mdot
.04669 .01472 Mdot
.04764 .01472 Mdot
.0486 .01472 Mdot
.04955 .01472 Mdot
.0505 .01472 Mdot
.05146 .01472 Mdot
.05241 .01472 Mdot
.05336 .01472 Mdot
.05432 .01472 Mdot
.05527 .01472 Mdot
.05622 .01472 Mdot
.05718 .01472 Mdot
.05813 .01472 Mdot
.05908 .01472 Mdot
.06004 .01472 Mdot
.06099 .01472 Mdot
.06194 .01472 Mdot
.0629 .01472 Mdot
.06385 .01472 Mdot
.0648 .01472 Mdot
.06576 .01472 Mdot
.06671 .01472 Mdot
.06766 .01472 Mdot
.06862 .01472 Mdot
.06957 .01472 Mdot
.07052 .01472 Mdot
.07148 .01472 Mdot
.07243 .01472 Mdot
.07338 .01472 Mdot
.07434 .01472 Mdot
.07529 .01472 Mdot
.07624 .01472 Mdot
.0772 .01472 Mdot
.07815 .01472 Mdot
.0791 .01472 Mdot
.08006 .01472 Mdot
.08101 .01472 Mdot
.08196 .01472 Mdot
.08292 .01472 Mdot
.08387 .01472 Mdot
.08482 .01472 Mdot
.08578 .01472 Mdot
.08673 .01472 Mdot
.08768 .01472 Mdot
.08864 .01472 Mdot
.08959 .01472 Mdot
.09054 .01472 Mdot
.0915 .01472 Mdot
.09245 .01472 Mdot
.0934 .01472 Mdot
.09436 .01472 Mdot
.09531 .01472 Mdot
.09626 .01472 Mdot
.09722 .01472 Mdot
.09817 .01472 Mdot
.09912 .01472 Mdot
.10008 .01472 Mdot
.10103 .01472 Mdot
.10198 .01472 Mdot
.10294 .01472 Mdot
.10389 .01472 Mdot
.10484 .01472 Mdot
.1058 .01472 Mdot
.10675 .01472 Mdot
.1077 .01472 Mdot
.10866 .01472 Mdot
.10961 .01472 Mdot
.11056 .01472 Mdot
.11152 .01472 Mdot
.11247 .01472 Mdot
.11342 .01472 Mdot
.11438 .01472 Mdot
.11533 .01472 Mdot
.11628 .01472 Mdot
.11724 .01472 Mdot
.11819 .01472 Mdot
.11914 .01472 Mdot
.1201 .01472 Mdot
.12105 .01472 Mdot
.122 .01472 Mdot
.12296 .01472 Mdot
.12391 .01472 Mdot
.12486 .01472 Mdot
.12582 .01472 Mdot
.12677 .01472 Mdot
.12772 .01472 Mdot
.12868 .01472 Mdot
.12963 .01472 Mdot
.13058 .01472 Mdot
.13154 .01472 Mdot
.13249 .01472 Mdot
.13344 .01472 Mdot
.1344 .01472 Mdot
.13535 .01472 Mdot
.1363 .01472 Mdot
.13726 .01472 Mdot
.13821 .01472 Mdot
.13916 .01472 Mdot
.14012 .01472 Mdot
.14107 .01472 Mdot
.14202 .01472 Mdot
.14298 .01472 Mdot
.14393 .01472 Mdot
.14488 .01472 Mdot
.14584 .01472 Mdot
.14679 .01472 Mdot
.14774 .01472 Mdot
.1487 .01472 Mdot
.14965 .01472 Mdot
.1506 .01472 Mdot
.15156 .01472 Mdot
.15251 .01472 Mdot
.15346 .01472 Mdot
.15442 .01472 Mdot
.15537 .01472 Mdot
.15632 .01472 Mdot
.15728 .01472 Mdot
.15823 .01472 Mdot
.15918 .01472 Mdot
.16014 .01472 Mdot
.16109 .01472 Mdot
.16204 .01472 Mdot
.163 .01472 Mdot
.16395 .01472 Mdot
.1649 .01472 Mdot
.16586 .01472 Mdot
.16681 .01472 Mdot
.16776 .01472 Mdot
.16872 .01472 Mdot
.16967 .01472 Mdot
.17062 .01472 Mdot
.17158 .01472 Mdot
.17253 .01472 Mdot
.17348 .01472 Mdot
.17444 .01472 Mdot
.17539 .01472 Mdot
.17634 .01472 Mdot
.1773 .01472 Mdot
.17825 .01472 Mdot
.1792 .01472 Mdot
.18016 .01472 Mdot
.18111 .01472 Mdot
.18206 .01472 Mdot
.18302 .01472 Mdot
.18397 .01472 Mdot
.18492 .01472 Mdot
.18588 .01472 Mdot
.18683 .01472 Mdot
.18778 .01472 Mdot
.18874 .01472 Mdot
.18969 .01472 Mdot
.19064 .01472 Mdot
.1916 .01472 Mdot
.19255 .01472 Mdot
.1935 .01472 Mdot
.19446 .01472 Mdot
.19541 .01472 Mdot
.19636 .01472 Mdot
.19732 .01472 Mdot
.19827 .01472 Mdot
.19922 .01472 Mdot
.20018 .01472 Mdot
.20113 .01472 Mdot
.20208 .01472 Mdot
.20304 .01472 Mdot
.20399 .01472 Mdot
.20494 .01472 Mdot
.2059 .01472 Mdot
.20685 .01472 Mdot
.2078 .01472 Mdot
.20876 .01472 Mdot
.20971 .01472 Mdot
.21066 .01472 Mdot
.21162 .01472 Mdot
.21257 .01472 Mdot
.21352 .01472 Mdot
.21448 .01472 Mdot
.21543 .01472 Mdot
.21638 .01472 Mdot
.21734 .01472 Mdot
.21829 .01472 Mdot
.21924 .01472 Mdot
.2202 .01472 Mdot
.22115 .01472 Mdot
.2221 .01472 Mdot
.22306 .01472 Mdot
.22401 .01472 Mdot
.22496 .01472 Mdot
.22592 .01472 Mdot
.22687 .01472 Mdot
.22782 .01472 Mdot
.22878 .01472 Mdot
.22973 .01472 Mdot
.23068 .01472 Mdot
.23164 .01472 Mdot
.23259 .01472 Mdot
.23354 .01472 Mdot
.2345 .01472 Mdot
.23545 .01472 Mdot
.2364 .01472 Mdot
.23736 .01472 Mdot
.23831 .01472 Mdot
.23926 .01472 Mdot
.24022 .01472 Mdot
.24117 .01472 Mdot
.24212 .01472 Mdot
.24308 .01472 Mdot
.24403 .01472 Mdot
.24498 .01472 Mdot
.24594 .01472 Mdot
.24689 .01472 Mdot
.24784 .01472 Mdot
.2488 .01472 Mdot
.24975 .01472 Mdot
.2507 .01472 Mdot
.25166 .01472 Mdot
.25261 .01472 Mdot
.25356 .01472 Mdot
.25452 .01472 Mdot
.25547 .01472 Mdot
.25642 .01472 Mdot
.25738 .01472 Mdot
.25833 .01472 Mdot
.25928 .01472 Mdot
.26024 .01472 Mdot
.26119 .01472 Mdot
.26214 .01472 Mdot
.2631 .01472 Mdot
.26405 .01472 Mdot
.265 .01472 Mdot
.26596 .01472 Mdot
.26691 .01472 Mdot
.26786 .01472 Mdot
.26882 .01472 Mdot
.26977 .01472 Mdot
.27072 .01472 Mdot
.27168 .01472 Mdot
.27263 .01472 Mdot
.27358 .01472 Mdot
.27454 .01472 Mdot
.27549 .01472 Mdot
.27644 .01472 Mdot
.2774 .01472 Mdot
.27835 .01472 Mdot
.2793 .01472 Mdot
.28026 .01472 Mdot
.28121 .01472 Mdot
.28216 .01472 Mdot
.28312 .01472 Mdot
.28407 .01472 Mdot
.28502 .01472 Mdot
.28598 .01472 Mdot
.28693 .01472 Mdot
.28788 .01472 Mdot
.28884 .01472 Mdot
.28979 .01472 Mdot
.29074 .01472 Mdot
.2917 .01472 Mdot
.29265 .01472 Mdot
.2936 .01472 Mdot
.29456 .01472 Mdot
.29551 .01472 Mdot
.29646 .01472 Mdot
.29742 .01472 Mdot
.29837 .01472 Mdot
.29932 .01472 Mdot
.30028 .01472 Mdot
.30123 .01472 Mdot
.30218 .01472 Mdot
.30314 .01472 Mdot
.30409 .01472 Mdot
.30504 .01472 Mdot
.306 .01472 Mdot
.30695 .01472 Mdot
.3079 .01472 Mdot
.30886 .01472 Mdot
.30981 .01472 Mdot
.31076 .01472 Mdot
.31172 .01472 Mdot
.31267 .01472 Mdot
.31362 .01472 Mdot
.31458 .01472 Mdot
.31553 .01472 Mdot
.31648 .01472 Mdot
.31744 .01472 Mdot
.31839 .01472 Mdot
.31934 .01472 Mdot
.3203 .01472 Mdot
.32125 .01472 Mdot
.3222 .01472 Mdot
.32316 .01472 Mdot
.32411 .01472 Mdot
.32506 .01472 Mdot
.32602 .01472 Mdot
.32697 .01472 Mdot
.32792 .01472 Mdot
.32888 .01472 Mdot
.32983 .01472 Mdot
.33078 .01472 Mdot
.33174 .01472 Mdot
.33269 .01472 Mdot
.33364 .01472 Mdot
.3346 .01472 Mdot
.33555 .01472 Mdot
.3365 .01472 Mdot
.33746 .01472 Mdot
.33841 .01472 Mdot
.33936 .01472 Mdot
.34032 .01472 Mdot
.34127 .01472 Mdot
.34222 .01472 Mdot
.34318 .01472 Mdot
.34413 .01472 Mdot
.34508 .01472 Mdot
.34604 .01472 Mdot
.34699 .01472 Mdot
.34794 .01472 Mdot
.3489 .01472 Mdot
.34985 .01472 Mdot
.3508 .01472 Mdot
.35176 .01472 Mdot
.35271 .01472 Mdot
.35366 .01472 Mdot
.35462 .01472 Mdot
.35557 .01472 Mdot
.35652 .01472 Mdot
.35748 .01472 Mdot
.35843 .01472 Mdot
.35938 .01472 Mdot
.36034 .01472 Mdot
.36129 .01472 Mdot
.36224 .01472 Mdot
.3632 .01472 Mdot
.36415 .01472 Mdot
.3651 .01472 Mdot
.36606 .01472 Mdot
.36701 .01472 Mdot
.36796 .01472 Mdot
.36892 .01472 Mdot
.36987 .01472 Mdot
.37082 .01472 Mdot
.37178 .01472 Mdot
.37273 .01472 Mdot
.37368 .01472 Mdot
.37464 .01472 Mdot
.37559 .01472 Mdot
.37654 .01472 Mdot
.3775 .01472 Mdot
.37845 .01472 Mdot
.3794 .01472 Mdot
.38036 .01472 Mdot
.38131 .01473 Mdot
.38226 .01473 Mdot
.38322 .01473 Mdot
.38417 .01473 Mdot
.38512 .01473 Mdot
.38608 .01473 Mdot
.38703 .01473 Mdot
.38798 .01473 Mdot
.38894 .01473 Mdot
.38989 .01473 Mdot
.39084 .01473 Mdot
.3918 .01473 Mdot
.39275 .01473 Mdot
.3937 .01473 Mdot
.39466 .01473 Mdot
.39561 .01473 Mdot
.39656 .01473 Mdot
.39752 .01473 Mdot
.39847 .01473 Mdot
.39942 .01473 Mdot
.40038 .01473 Mdot
.40133 .01473 Mdot
.40228 .01473 Mdot
.40324 .01473 Mdot
.40419 .01473 Mdot
.40514 .01473 Mdot
.4061 .01473 Mdot
.40705 .01473 Mdot
.408 .01473 Mdot
.40896 .01473 Mdot
.40991 .01473 Mdot
.41086 .01473 Mdot
.41182 .01474 Mdot
.41277 .01474 Mdot
.41372 .01474 Mdot
.41468 .01474 Mdot
.41563 .01474 Mdot
.41658 .01474 Mdot
.41754 .01474 Mdot
.41849 .01474 Mdot
.41944 .01474 Mdot
.4204 .01474 Mdot
.42135 .01474 Mdot
.4223 .01474 Mdot
.42326 .01474 Mdot
.42421 .01475 Mdot
.42516 .01475 Mdot
.42612 .01475 Mdot
.42707 .01475 Mdot
.42802 .01475 Mdot
.42898 .01475 Mdot
.42993 .01475 Mdot
.43088 .01475 Mdot
.43184 .01476 Mdot
.43279 .01476 Mdot
.43374 .01476 Mdot
.4347 .01476 Mdot
.43565 .01476 Mdot
.4366 .01477 Mdot
.43756 .01477 Mdot
.43851 .01477 Mdot
.43946 .01477 Mdot
.44042 .01478 Mdot
.44137 .01478 Mdot
.44232 .01478 Mdot
.44328 .01479 Mdot
.44423 .01479 Mdot
.44518 .0148 Mdot
.44614 .0148 Mdot
.44709 .01481 Mdot
.44804 .01482 Mdot
.449 .01482 Mdot
.44995 .01483 Mdot
.4509 .01484 Mdot
.45186 .01485 Mdot
.45281 .01486 Mdot
.45376 .01488 Mdot
.45472 .0149 Mdot
.45567 .01492 Mdot
.45662 .01494 Mdot
.45758 .01497 Mdot
.45853 .015 Mdot
.45948 .01505 Mdot
.46044 .0151 Mdot
.46139 .01518 Mdot
.46234 .01528 Mdot
.4633 .01541 Mdot
.46425 .01561 Mdot
.4652 .01591 Mdot
.46616 .01642 Mdot
.46711 .01738 Mdot
.46806 .01961 Mdot
.46902 .02761 Mdot
.46997 .60332 Mdot
.47092 .04953 Mdot
.47188 .58601 Mdot
.47283 .02513 Mdot
.47378 .01854 Mdot
.47474 .01669 Mdot
.47569 .0159 Mdot
.47664 .01549 Mdot
.4776 .01526 Mdot
.47855 .01511 Mdot
.4795 .01501 Mdot
.48046 .01494 Mdot
.48141 .01489 Mdot
.48236 .01485 Mdot
.48332 .01482 Mdot
.48427 .0148 Mdot
.48522 .01478 Mdot
.48618 .01477 Mdot
.48713 .01476 Mdot
.48808 .01475 Mdot
.48904 .01474 Mdot
.48999 .01474 Mdot
.49094 .01473 Mdot
.4919 .01473 Mdot
.49285 .01472 Mdot
.4938 .01472 Mdot
.49476 .01472 Mdot
.49571 .01472 Mdot
.49666 .01472 Mdot
.49762 .01472 Mdot
.49857 .01472 Mdot
.49952 .01472 Mdot
.50048 .01472 Mdot
.50143 .01472 Mdot
.50238 .01472 Mdot
.50334 .01472 Mdot
.50429 .01472 Mdot
.50524 .01472 Mdot
.5062 .01472 Mdot
.50715 .01473 Mdot
.5081 .01473 Mdot
.50906 .01474 Mdot
.51001 .01474 Mdot
.51096 .01475 Mdot
.51192 .01476 Mdot
.51287 .01477 Mdot
.51382 .01478 Mdot
.51478 .0148 Mdot
.51573 .01482 Mdot
.51668 .01485 Mdot
.51764 .01489 Mdot
.51859 .01494 Mdot
.51954 .01501 Mdot
.5205 .01511 Mdot
.52145 .01526 Mdot
.5224 .01549 Mdot
.52336 .0159 Mdot
.52431 .01669 Mdot
.52526 .01854 Mdot
.52622 .02513 Mdot
.52717 .58601 Mdot
.52812 .04953 Mdot
.52908 .60332 Mdot
.53003 .02761 Mdot
.53098 .01961 Mdot
.53194 .01738 Mdot
.53289 .01642 Mdot
.53384 .01591 Mdot
.5348 .01561 Mdot
.53575 .01541 Mdot
.5367 .01528 Mdot
.53766 .01518 Mdot
.53861 .0151 Mdot
.53956 .01505 Mdot
.54052 .015 Mdot
.54147 .01497 Mdot
.54242 .01494 Mdot
.54338 .01492 Mdot
.54433 .0149 Mdot
.54528 .01488 Mdot
.54624 .01486 Mdot
.54719 .01485 Mdot
.54814 .01484 Mdot
.5491 .01483 Mdot
.55005 .01482 Mdot
.551 .01482 Mdot
.55196 .01481 Mdot
.55291 .0148 Mdot
.55386 .0148 Mdot
.55482 .01479 Mdot
.55577 .01479 Mdot
.55672 .01478 Mdot
.55768 .01478 Mdot
.55863 .01478 Mdot
.55958 .01477 Mdot
.56054 .01477 Mdot
.56149 .01477 Mdot
.56244 .01477 Mdot
.5634 .01476 Mdot
.56435 .01476 Mdot
.5653 .01476 Mdot
.56626 .01476 Mdot
.56721 .01476 Mdot
.56816 .01475 Mdot
.56912 .01475 Mdot
.57007 .01475 Mdot
.57102 .01475 Mdot
.57198 .01475 Mdot
.57293 .01475 Mdot
.57388 .01475 Mdot
.57484 .01475 Mdot
.57579 .01474 Mdot
.57674 .01474 Mdot
.5777 .01474 Mdot
.57865 .01474 Mdot
.5796 .01474 Mdot
.58056 .01474 Mdot
.58151 .01474 Mdot
.58246 .01474 Mdot
.58342 .01474 Mdot
.58437 .01474 Mdot
.58532 .01474 Mdot
.58628 .01474 Mdot
.58723 .01474 Mdot
.58818 .01473 Mdot
.58914 .01473 Mdot
.59009 .01473 Mdot
.59104 .01473 Mdot
.592 .01473 Mdot
.59295 .01473 Mdot
.5939 .01473 Mdot
.59486 .01473 Mdot
.59581 .01473 Mdot
.59676 .01473 Mdot
.59772 .01473 Mdot
.59867 .01473 Mdot
.59962 .01473 Mdot
.60058 .01473 Mdot
.60153 .01473 Mdot
.60248 .01473 Mdot
.60344 .01473 Mdot
.60439 .01473 Mdot
.60534 .01473 Mdot
.6063 .01473 Mdot
.60725 .01473 Mdot
.6082 .01473 Mdot
.60916 .01473 Mdot
.61011 .01473 Mdot
.61106 .01473 Mdot
.61202 .01473 Mdot
.61297 .01473 Mdot
.61392 .01473 Mdot
.61488 .01473 Mdot
.61583 .01473 Mdot
.61678 .01473 Mdot
.61774 .01473 Mdot
.61869 .01472 Mdot
.61964 .01472 Mdot
.6206 .01472 Mdot
.62155 .01472 Mdot
.6225 .01472 Mdot
.62346 .01472 Mdot
.62441 .01472 Mdot
.62536 .01472 Mdot
.62632 .01472 Mdot
.62727 .01472 Mdot
.62822 .01472 Mdot
.62918 .01472 Mdot
.63013 .01472 Mdot
.63108 .01472 Mdot
.63204 .01472 Mdot
.63299 .01472 Mdot
.63394 .01472 Mdot
.6349 .01472 Mdot
.63585 .01472 Mdot
.6368 .01472 Mdot
.63776 .01472 Mdot
.63871 .01472 Mdot
.63966 .01472 Mdot
.64062 .01472 Mdot
.64157 .01472 Mdot
.64252 .01472 Mdot
.64348 .01472 Mdot
.64443 .01472 Mdot
.64538 .01472 Mdot
.64634 .01472 Mdot
.64729 .01472 Mdot
.64824 .01472 Mdot
.6492 .01472 Mdot
.65015 .01472 Mdot
.6511 .01472 Mdot
.65206 .01472 Mdot
.65301 .01472 Mdot
.65396 .01472 Mdot
.65492 .01472 Mdot
.65587 .01472 Mdot
.65682 .01472 Mdot
.65778 .01472 Mdot
.65873 .01472 Mdot
.65968 .01472 Mdot
.66064 .01472 Mdot
.66159 .01472 Mdot
.66254 .01472 Mdot
.6635 .01472 Mdot
.66445 .01472 Mdot
.6654 .01472 Mdot
.66636 .01472 Mdot
.66731 .01472 Mdot
.66826 .01472 Mdot
.66922 .01472 Mdot
.67017 .01472 Mdot
.67112 .01472 Mdot
.67208 .01472 Mdot
.67303 .01472 Mdot
.67398 .01472 Mdot
.67494 .01472 Mdot
.67589 .01472 Mdot
.67684 .01472 Mdot
.6778 .01472 Mdot
.67875 .01472 Mdot
.6797 .01472 Mdot
.68066 .01472 Mdot
.68161 .01472 Mdot
.68256 .01472 Mdot
.68352 .01472 Mdot
.68447 .01472 Mdot
.68542 .01472 Mdot
.68638 .01472 Mdot
.68733 .01472 Mdot
.68828 .01472 Mdot
.68924 .01472 Mdot
.69019 .01472 Mdot
.69114 .01472 Mdot
.6921 .01472 Mdot
.69305 .01472 Mdot
.694 .01472 Mdot
.69496 .01472 Mdot
.69591 .01472 Mdot
.69686 .01472 Mdot
.69782 .01472 Mdot
.69877 .01472 Mdot
.69972 .01472 Mdot
.70068 .01472 Mdot
.70163 .01472 Mdot
.70258 .01472 Mdot
.70354 .01472 Mdot
.70449 .01472 Mdot
.70544 .01472 Mdot
.7064 .01472 Mdot
.70735 .01472 Mdot
.7083 .01472 Mdot
.70926 .01472 Mdot
.71021 .01472 Mdot
.71116 .01472 Mdot
.71212 .01472 Mdot
.71307 .01472 Mdot
.71402 .01472 Mdot
.71498 .01472 Mdot
.71593 .01472 Mdot
.71688 .01472 Mdot
.71784 .01472 Mdot
.71879 .01472 Mdot
.71974 .01472 Mdot
.7207 .01472 Mdot
.72165 .01472 Mdot
.7226 .01472 Mdot
.72356 .01472 Mdot
.72451 .01472 Mdot
.72546 .01472 Mdot
.72642 .01472 Mdot
.72737 .01472 Mdot
.72832 .01472 Mdot
.72928 .01472 Mdot
.73023 .01472 Mdot
.73118 .01472 Mdot
.73214 .01472 Mdot
.73309 .01472 Mdot
.73404 .01472 Mdot
.735 .01472 Mdot
.73595 .01472 Mdot
.7369 .01472 Mdot
.73786 .01472 Mdot
.73881 .01472 Mdot
.73976 .01472 Mdot
.74072 .01472 Mdot
.74167 .01472 Mdot
.74262 .01472 Mdot
.74358 .01472 Mdot
.74453 .01472 Mdot
.74548 .01472 Mdot
.74644 .01472 Mdot
.74739 .01472 Mdot
.74834 .01472 Mdot
.7493 .01472 Mdot
.75025 .01472 Mdot
.7512 .01472 Mdot
.75216 .01472 Mdot
.75311 .01472 Mdot
.75406 .01472 Mdot
.75502 .01472 Mdot
.75597 .01472 Mdot
.75692 .01472 Mdot
.75788 .01472 Mdot
.75883 .01472 Mdot
.75978 .01472 Mdot
.76074 .01472 Mdot
.76169 .01472 Mdot
.76264 .01472 Mdot
.7636 .01472 Mdot
.76455 .01472 Mdot
.7655 .01472 Mdot
.76646 .01472 Mdot
.76741 .01472 Mdot
.76836 .01472 Mdot
.76932 .01472 Mdot
.77027 .01472 Mdot
.77122 .01472 Mdot
.77218 .01472 Mdot
.77313 .01472 Mdot
.77408 .01472 Mdot
.77504 .01472 Mdot
.77599 .01472 Mdot
.77694 .01472 Mdot
.7779 .01472 Mdot
.77885 .01472 Mdot
.7798 .01472 Mdot
.78076 .01472 Mdot
.78171 .01472 Mdot
.78266 .01472 Mdot
.78362 .01472 Mdot
.78457 .01472 Mdot
.78552 .01472 Mdot
.78648 .01472 Mdot
.78743 .01472 Mdot
.78838 .01472 Mdot
.78934 .01472 Mdot
.79029 .01472 Mdot
.79124 .01472 Mdot
.7922 .01472 Mdot
.79315 .01472 Mdot
.7941 .01472 Mdot
.79506 .01472 Mdot
.79601 .01472 Mdot
.79696 .01472 Mdot
.79792 .01472 Mdot
.79887 .01472 Mdot
.79982 .01472 Mdot
.80078 .01472 Mdot
.80173 .01472 Mdot
.80268 .01472 Mdot
.80364 .01472 Mdot
.80459 .01472 Mdot
.80554 .01472 Mdot
.8065 .01472 Mdot
.80745 .01472 Mdot
.8084 .01472 Mdot
.80936 .01472 Mdot
.81031 .01472 Mdot
.81126 .01472 Mdot
.81222 .01472 Mdot
.81317 .01472 Mdot
.81412 .01472 Mdot
.81508 .01472 Mdot
.81603 .01472 Mdot
.81698 .01472 Mdot
.81794 .01472 Mdot
.81889 .01472 Mdot
.81984 .01472 Mdot
.8208 .01472 Mdot
.82175 .01472 Mdot
.8227 .01472 Mdot
.82366 .01472 Mdot
.82461 .01472 Mdot
.82556 .01472 Mdot
.82652 .01472 Mdot
.82747 .01472 Mdot
.82842 .01472 Mdot
.82938 .01472 Mdot
.83033 .01472 Mdot
.83128 .01472 Mdot
.83224 .01472 Mdot
.83319 .01472 Mdot
.83414 .01472 Mdot
.8351 .01472 Mdot
.83605 .01472 Mdot
.837 .01472 Mdot
.83796 .01472 Mdot
.83891 .01472 Mdot
.83986 .01472 Mdot
.84082 .01472 Mdot
.84177 .01472 Mdot
.84272 .01472 Mdot
.84368 .01472 Mdot
.84463 .01472 Mdot
.84558 .01472 Mdot
.84654 .01472 Mdot
.84749 .01472 Mdot
.84844 .01472 Mdot
.8494 .01472 Mdot
.85035 .01472 Mdot
.8513 .01472 Mdot
.85226 .01472 Mdot
.85321 .01472 Mdot
.85416 .01472 Mdot
.85512 .01472 Mdot
.85607 .01472 Mdot
.85702 .01472 Mdot
.85798 .01472 Mdot
.85893 .01472 Mdot
.85988 .01472 Mdot
.86084 .01472 Mdot
.86179 .01472 Mdot
.86274 .01472 Mdot
.8637 .01472 Mdot
.86465 .01472 Mdot
.8656 .01472 Mdot
.86656 .01472 Mdot
.86751 .01472 Mdot
.86846 .01472 Mdot
.86942 .01472 Mdot
.87037 .01472 Mdot
.87132 .01472 Mdot
.87228 .01472 Mdot
.87323 .01472 Mdot
.87418 .01472 Mdot
.87514 .01472 Mdot
.87609 .01472 Mdot
.87704 .01472 Mdot
.878 .01472 Mdot
.87895 .01472 Mdot
.8799 .01472 Mdot
.88086 .01472 Mdot
.88181 .01472 Mdot
.88276 .01472 Mdot
.88372 .01472 Mdot
.88467 .01472 Mdot
.88562 .01472 Mdot
.88658 .01472 Mdot
.88753 .01472 Mdot
.88848 .01472 Mdot
.88944 .01472 Mdot
.89039 .01472 Mdot
.89134 .01472 Mdot
.8923 .01472 Mdot
.89325 .01472 Mdot
.8942 .01472 Mdot
.89516 .01472 Mdot
.89611 .01472 Mdot
.89706 .01472 Mdot
.89802 .01472 Mdot
.89897 .01472 Mdot
.89992 .01472 Mdot
.90088 .01472 Mdot
.90183 .01472 Mdot
.90278 .01472 Mdot
.90374 .01472 Mdot
.90469 .01472 Mdot
.90564 .01472 Mdot
.9066 .01472 Mdot
.90755 .01472 Mdot
.9085 .01472 Mdot
.90946 .01472 Mdot
.91041 .01472 Mdot
.91136 .01472 Mdot
.91232 .01472 Mdot
.91327 .01472 Mdot
.91422 .01472 Mdot
.91518 .01472 Mdot
.91613 .01472 Mdot
.91708 .01472 Mdot
.91804 .01472 Mdot
.91899 .01472 Mdot
.91994 .01472 Mdot
.9209 .01472 Mdot
.92185 .01472 Mdot
.9228 .01472 Mdot
.92376 .01472 Mdot
.92471 .01472 Mdot
.92566 .01472 Mdot
.92662 .01472 Mdot
.92757 .01472 Mdot
.92852 .01472 Mdot
.92948 .01472 Mdot
.93043 .01472 Mdot
.93138 .01472 Mdot
.93234 .01472 Mdot
.93329 .01472 Mdot
.93424 .01472 Mdot
.9352 .01472 Mdot
.93615 .01472 Mdot
.9371 .01472 Mdot
.93806 .01472 Mdot
.93901 .01472 Mdot
.93996 .01472 Mdot
.94092 .01472 Mdot
.94187 .01472 Mdot
.94282 .01472 Mdot
.94378 .01472 Mdot
.94473 .01472 Mdot
.94568 .01472 Mdot
.94664 .01472 Mdot
.94759 .01472 Mdot
.94854 .01472 Mdot
.9495 .01472 Mdot
.95045 .01472 Mdot
.9514 .01472 Mdot
.95236 .01472 Mdot
.95331 .01472 Mdot
.95426 .01472 Mdot
.95522 .01472 Mdot
.95617 .01472 Mdot
.95712 .01472 Mdot
.95808 .01472 Mdot
.95903 .01472 Mdot
.95998 .01472 Mdot
.96094 .01472 Mdot
.96189 .01472 Mdot
.96284 .01472 Mdot
.9638 .01472 Mdot
.96475 .01472 Mdot
.9657 .01472 Mdot
.96666 .01472 Mdot
.96761 .01472 Mdot
.96856 .01472 Mdot
.96952 .01472 Mdot
.97047 .01472 Mdot
.97142 .01472 Mdot
.97238 .01472 Mdot
.97333 .01472 Mdot
.97428 .01472 Mdot
.97524 .01472 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool3o`0000?ooooo0_l00004ooooo`;o00008oooool5o`0000?ooooo0_l00004oooo
o`;o00009oooool2o`0002Wooooo1Ol00003ooooo`;o00001?ooool2o`0002Gooooo0ol00003oooo
o`;o00001?ooool2o`0001[ooooo000aooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Gooooo00Co0000oooooooo
oooo0000:Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00009Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0Gooooo`00:?ooool5o`000003ooooool0003o000000?o
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001cooooo1Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Uooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0002;ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00006Oooool002kooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08ooo
ool01?l0003oooooooooool0000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000_ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Rooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Gooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Iooooo`00<?oo
ool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Rooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Gooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Tooooo`;o00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000aooooo`03o`000?oo
oooooooo00;ooooo0_l00004ooooo`;o00009?ooool3o`0000Cooooo0_l00004ooooo`;o00009ooo
ool2o`0002[ooooo0ol00004ooooo`;o00001?ooool2o`0002Kooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l0000Jooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`005Ooooooo000000/000000Oooool001Gooooo00<00000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool1
0000007ooooo000>ooooo`;o00001Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo
033ooooo00<00000ooooooooool0;oooool00`00003oooooooooo`0`ooooo`03o`000?oooooooooo
033ooooo00<00000ooooooooool07?ooool10000007ooooo000=ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool00_oooomcool000Oooooo2ooo0007ooooogCoo`001?ooool10000
007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000?ooool00_ooooooool0
007oo`000oooool1o`00004000000Oooool000gooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`02ooooooooo`000Ooo0004ooooo`4000000Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`1booooo`goo`001Oooool=ool007Gooooo0@000001oooo
o`003Oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07Sooooo1?oo000;oooo
o`Coo`00Noooool10000007ooooo000>ooooo`;o00001Oooool00`00003oooooooooo`1hooooo`Co
o`002oooool4ool007_ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1hooooo`?oo`00
3Oooool3ool007_ooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1jooooo`030?l00?oo
oooooooo00cooooo00<0o`00ooooooooool0NOooool1o`00004000000Oooool001Gooooo00<00000
ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001
ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00oooo
ooooool0N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07Sooooo0ooo000=ooooo`?o
o`00Noooool10000007ooooo000Eooooo`0300000?oooooooooo07Sooooo0ooo000=ooooo`?oo`00
Noooool10000007ooooo000Eooooo`0300000?oooooooooo07Sooooo0ooo000=ooooo`?oo`00Nooo
ool10000007ooooo000Eooooo`0300000?l0003ooooo07[ooooo00<0o`00ooooooooool03?ooool0
0`3o003oooooooooo`1iooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1joooo
o`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`03
00000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`40
00000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l0
0?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oo
oooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo
07[ooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1jooooo`030?l00?oooooooooo00co
oooo00<0o`00ooooooooool0NOooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0
N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool0
0`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o
003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007o
oooo000Eooooo`0300000?l0003ooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003ooooo
ooooo`1iooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oo
oooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool0
00Oooooo0ol00004ooooo`;o00001Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo
00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo0006ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07[ooooo00<0o`00
ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool000[ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo07[ooooo00<0o`00
ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool000[ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?l0003ooooo07[ooooo00<0o`00
ooooooooool03?ooool00`3o003oooooooooo`1iooooo`7o00000@000001ooooo`001_ooool4o`00
00?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1jooooo`030?l00?oooooo
oooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo0006ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1jooooo`030?l00?oooooo
oooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo0006ooooo`Go00000oooool2o`00
00Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo
07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00co
oooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[ooooo
00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<0
0000o`000?ooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Wooooo0Ol0
00010000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool0
0`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o
003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007o
oooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003ooooo
ooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003ooooooooo
o`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1j
ooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0NOooool1o`00004000000Oooool0
01Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo
07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00co
oooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[ooooo
00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<0
0000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00
ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?l0003ooooo07[ooooo00<0o`00oooo
ooooool03?ooool00`3o003oooooooooo`1iooooo`7o00000@000001ooooo`005Oooool00`00003o
ooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007o
oooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003ooooo
ooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003ooooooooo
o`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1j
ooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eoooo
o`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1joooo
o`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`03
0?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1jooooo`030?l0
0?oooooooooo00cooooo00<0o`00ooooooooool0NOooool1o`00004000000Oooool001Gooooo00<0
0000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00
ooooooooool0N_ooool10000007ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2
o`0000Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooo
oooo07[ooooo0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1jooooo`030?l00?oo
oooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo0002ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`400000
0Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000o`000?ooool0N_ooool00`3o003oooooooooo`0<ooooo`03
0?l00?oooooooooo07Wooooo0Ol000010000007ooooo0002ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool00003
ooooool0003o000000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1j
ooooo`4000000Oooool000;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005oooo
o`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1joooo
o`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`03
0?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l0
0?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?l0
003ooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1iooooo`7o00000@00
0001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00
ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00oooo
ooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0
N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?oo
ool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000o`000?ooool0N_ooool0
0`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Wooooo0Ol000010000007ooooo000Eoooo
o`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1joooo
o`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`03
0?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l0
0?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooo
oooo07[ooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1jooooo`030?l00?oooooooooo
00cooooo00<0o`00ooooooooool0NOooool1o`00004000000Oooool001Gooooo00<00000oooooooo
ool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0
N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?oo
ool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool0
0`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00
003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000
007ooooo000Eooooo`0300000?l0003ooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003o
ooooooooo`1iooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l0
0?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooo
oooo07[ooooo0@000001ooooo`0000Coooooo`000?l0003o00000oooool3o`0000Cooooo0_l00005
ooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1j
ooooo`4000000Oooool000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`1jooooo`030?l00?oo
oooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo0002ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Ooo
ool000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00<00000o`000?ooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oo
oooooooo07Wooooo0Ol000010000007ooooo0002ooooo`04o`000?ooooooooooooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool0
3?ooool00`3o003oooooooooo`1jooooo`4000000Oooool00003ooooool0003o000000?ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07[ooooo
00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool000;ooooo00Co
0000oooooooooooooooo1Ol00003ooooo`;o00001Oooool00`00003oooooooooo`1jooooo`030?l0
0?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooo
oooo07[ooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1jooooo`030?l00?oooooooooo
00cooooo00<0o`00ooooooooool0NOooool1o`00004000000Oooool001Gooooo00<00000oooooooo
ool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0
N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?oo
ool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool0
0`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00
003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000
007ooooo000Eooooo`0300000?l0003ooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003o
ooooooooo`1iooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l0
0?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oo
oooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooo
oooo07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo
00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[o
oooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo
00<00000o`000?ooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07Wooooo
0Ol000010000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?oo
ool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool0
0`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00
003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000
007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003o
ooooooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003ooooo
ooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003o0000oooo
o`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0NOooool1o`00004000000Ooo
ool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooo
oooo07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo
00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[o
oooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool000Go0000
0oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool0
3?ooool00`3o003oooooooooo`1jooooo`4000000Oooool00005ooooool0003oooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001oooo
o`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003o0000ooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00
ooooooooool0NOooool1o`00004000000Oooool000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003ooooooooo
o`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo0000
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003o
ooooooooo`1jooooo`4000000Oooool00005o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0N_ooool0
0`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`0000Coooooo`00
0?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo07[ooooo00<0o`00
ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000oooo
ooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001oooo
o`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00oooooooo
ool0N_ooool10000007ooooo000Eooooo`0300000?l0003ooooo07[ooooo00<0o`00ooooooooool0
3?ooool00`3o003oooooooooo`1iooooo`7o00000@000001ooooo`005Oooool00`00003ooooooooo
o`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000E
ooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1j
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<oooo
o`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`03
0?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`030000
0?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`400000
0Oooool001Gooooo00<00000o`000?ooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oo
oooooooo07Wooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00
ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000oooo
ooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001oooo
o`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00oooooooo
ool0N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool0
3?ooool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_oo
ool00`3o003oooooooooo`0<ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool0
0`00003o0000ooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00ooooooooool0NOooool1
o`00004000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<oooo
o`030?l00?oooooooooo07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`03
0?l00?oooooooooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`030000
0?oooooooooo07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`400000
0Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l00?oo
oooooooo07[ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooo
oooo00cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000Eooooo`0300000?l0003ooooo
07[ooooo00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1iooooo`7o00000@000001oooo
o`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00cooooo00<0o`00oooooooo
ool0N_ooool10000007ooooo000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool0
3?ooool00`3o003oooooooooo`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0NOoo
ool3ool000_ooooo0ooo001looooo`4000000Oooool000Go00000_ooool3o`0000Cooooo0_l00005
ooooo`0300000?oooooooooo07Wooooo0ooo000;ooooo`?oo`00O?ooool10000007ooooo00001ooo
oooo0000oooooooooooo0000ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00<00000ooooooooool0NOooool3ool000_ooooo0ooo001looooo`400000
0Oooool000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00<00000o`000?ooool0N_ooool00`3o003oooooooooo`0<ooooo`030?l0
0?oooooooooo07Wooooo0Ol000010000007ooooo0003ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo07[ooooo
00<0o`00ooooooooool03?ooool00`3o003oooooooooo`1jooooo`4000000Oooool00006o`000?oo
ooooooooooooool0003ooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool0N?ooool3ool000gooooo0ooo001kooooo`4000000Oooool00007o`000?oooooooooooooo
ool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0N?oo
ool3ool000gooooo0ooo001kooooo`4000000Oooool00004ooooool0003o0000o`0000;ooooo1Ol0
0003ooooo`;o00001Oooool00`00003oooooooooo`1hooooo`?oo`003Oooool3ool007_ooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`03ooooo`4000000Oooool001Goooooo`00000;0000
007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-608.193, -26.6989, 3.95006, \
1.62045}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[g1, \ PlotRange \[Rule] {{0, 40}, All}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.025 0.0147151 0.00232388 [
[.125 -0.0125 -3 -9 ]
[.125 -0.0125 3 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.625 -0.0125 -6 -9 ]
[.625 -0.0125 6 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -6 -9 ]
[.875 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13091 -12 -4.5 ]
[-0.0125 .13091 0 4.5 ]
[-0.0125 .2471 -18 -4.5 ]
[-0.0125 .2471 0 4.5 ]
[-0.0125 .3633 -18 -4.5 ]
[-0.0125 .3633 0 4.5 ]
[-0.0125 .47949 -18 -4.5 ]
[-0.0125 .47949 0 4.5 ]
[-0.0125 .59568 -18 -4.5 ]
[-0.0125 .59568 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(10)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(15)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(20)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(30)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(35)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(40)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13091 m
.00625 .13091 L
s
[(50)] -0.0125 .13091 1 0 Mshowa
0 .2471 m
.00625 .2471 L
s
[(100)] -0.0125 .2471 1 0 Mshowa
0 .3633 m
.00625 .3633 L
s
[(150)] -0.0125 .3633 1 0 Mshowa
0 .47949 m
.00625 .47949 L
s
[(200)] -0.0125 .47949 1 0 Mshowa
0 .59568 m
.00625 .59568 L
s
[(250)] -0.0125 .59568 1 0 Mshowa
.125 Mabswid
0 .03795 m
.00375 .03795 L
s
0 .06119 m
.00375 .06119 L
s
0 .08443 m
.00375 .08443 L
s
0 .10767 m
.00375 .10767 L
s
0 .15415 m
.00375 .15415 L
s
0 .17739 m
.00375 .17739 L
s
0 .20063 m
.00375 .20063 L
s
0 .22386 m
.00375 .22386 L
s
0 .27034 m
.00375 .27034 L
s
0 .29358 m
.00375 .29358 L
s
0 .31682 m
.00375 .31682 L
s
0 .34006 m
.00375 .34006 L
s
0 .38654 m
.00375 .38654 L
s
0 .40977 m
.00375 .40977 L
s
0 .43301 m
.00375 .43301 L
s
0 .45625 m
.00375 .45625 L
s
0 .50273 m
.00375 .50273 L
s
0 .52597 m
.00375 .52597 L
s
0 .54921 m
.00375 .54921 L
s
0 .57245 m
.00375 .57245 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13091 m
1 .13091 L
s
.99375 .2471 m
1 .2471 L
s
.99375 .3633 m
1 .3633 L
s
.99375 .47949 m
1 .47949 L
s
.99375 .59568 m
1 .59568 L
s
.125 Mabswid
.99625 .03795 m
1 .03795 L
s
.99625 .06119 m
1 .06119 L
s
.99625 .08443 m
1 .08443 L
s
.99625 .10767 m
1 .10767 L
s
.99625 .15415 m
1 .15415 L
s
.99625 .17739 m
1 .17739 L
s
.99625 .20063 m
1 .20063 L
s
.99625 .22386 m
1 .22386 L
s
.99625 .27034 m
1 .27034 L
s
.99625 .29358 m
1 .29358 L
s
.99625 .31682 m
1 .31682 L
s
.99625 .34006 m
1 .34006 L
s
.99625 .38654 m
1 .38654 L
s
.99625 .40977 m
1 .40977 L
s
.99625 .43301 m
1 .43301 L
s
.99625 .45625 m
1 .45625 L
s
.99625 .50273 m
1 .50273 L
s
.99625 .52597 m
1 .52597 L
s
.99625 .54921 m
1 .54921 L
s
.99625 .57245 m
1 .57245 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .01472 m
0 .01472 L
s
.025 .01472 m
.025 .01472 L
s
.05 .01472 m
.05 .01472 L
s
.075 .01472 m
.075 .01472 L
s
.1 .01472 m
.1 .01472 L
s
.125 .01472 m
.125 .01472 L
s
.15 .01472 m
.15 .01472 L
s
.175 .01472 m
.175 .01472 L
s
.2 .01472 m
.2 .01473 L
s
.225 .01472 m
.225 .01473 L
s
.25 .01472 m
.25 .01474 L
s
.275 .01472 m
.275 .01474 L
s
.3 .01472 m
.3 .01475 L
s
.325 .01472 m
.325 .01476 L
s
.35 .01472 m
.35 .01477 L
s
.375 .01472 m
.375 .01478 L
s
.4 .01472 m
.4 .0148 L
s
.425 .01472 m
.425 .01482 L
s
.45 .01472 m
.45 .01485 L
s
.475 .01472 m
.475 .01489 L
s
.5 .01472 m
.5 .01494 L
s
.525 .01472 m
.525 .01501 L
s
.55 .01472 m
.55 .01511 L
s
.575 .01472 m
.575 .01526 L
s
.6 .01472 m
.6 .01549 L
s
.625 .01472 m
.625 .0159 L
s
.65 .01472 m
.65 .01669 L
s
.675 .01472 m
.675 .01854 L
s
.7 .01472 m
.7 .02513 L
s
.725 .01472 m
.725 .58601 L
s
.75 .01472 m
.75 .04953 L
s
.775 .01472 m
.775 .60332 L
s
.8 .01472 m
.8 .02761 L
s
.825 .01472 m
.825 .01961 L
s
.85 .01472 m
.85 .01738 L
s
.875 .01472 m
.875 .01642 L
s
.9 .01472 m
.9 .01591 L
s
.925 .01472 m
.925 .01561 L
s
.95 .01472 m
.95 .01541 L
s
.975 .01472 m
.975 .01528 L
s
1 .01472 m
1 .01518 L
s
.015 w
0 .01472 Mdot
.025 .01472 Mdot
.05 .01472 Mdot
.075 .01472 Mdot
.1 .01472 Mdot
.125 .01472 Mdot
.15 .01472 Mdot
.175 .01472 Mdot
.2 .01473 Mdot
.225 .01473 Mdot
.25 .01474 Mdot
.275 .01474 Mdot
.3 .01475 Mdot
.325 .01476 Mdot
.35 .01477 Mdot
.375 .01478 Mdot
.4 .0148 Mdot
.425 .01482 Mdot
.45 .01485 Mdot
.475 .01489 Mdot
.5 .01494 Mdot
.525 .01501 Mdot
.55 .01511 Mdot
.575 .01526 Mdot
.6 .01549 Mdot
.625 .0159 Mdot
.65 .01669 Mdot
.675 .01854 Mdot
.7 .02513 Mdot
.725 .58601 Mdot
.75 .04953 Mdot
.775 .60332 Mdot
.8 .02761 Mdot
.825 .01961 Mdot
.85 .01738 Mdot
.875 .01642 Mdot
.9 .01591 Mdot
.925 .01561 Mdot
.95 .01541 Mdot
.975 .01528 Mdot
1 .01518 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00<oooool3o`0001_ooooo0ol00004ooooo`;o0000
5oooool3o`0000?ooooo0ol0000Gooooo`Go00000oooool2o`0001Kooooo1Ol00002ooooo`?o0000
6?ooool3o`0000Cooooo0_l0000Gooooo`?o00000oooool3o`0001Wooooo0ol00003ooooo`;o0000
0oooool003;ooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00005oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool05Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0001Gooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000?ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000000;o
oooo0Ol00001ooooo`7ooooo000fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo1Ol00002
ooooo`04o`000?ooooooooooo`0000;ooooo000fooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool05oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo0_l00003ooooo`04o`00
0?ooooooooooo`0001Oooooo0_l00006ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`00<_ooool4o`0001cooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Gooooo`04o`000?ooooooooooooooo`Co00005ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00005Oooool01_l0003o
oooooooooooooooo0000ooooo`Co00006oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooool000000ol0000Hooooo`03o`000?oooooo000000?ooooo00Co
0000oooooooooooo00000_ooool003;ooooo00?o0000ooooooooool07?ooool2o`0000Cooooo00Co
0000oooooooooooo00005_ooool2o`0000?ooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00005Oooool01ol0003ooooooooooooooooo
0000ooooool000006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00005Oooool01ol0003ooooooooooooooooo0000ooooool000007?ooool2o`0000?ooooo00Co0000
oooooooooooo00000_ooool003;ooooo1Ol0000Kooooo`03o`000?oooooooooo00?ooooo0_l0000H
ooooo`04o`000?ooooooooooooooo`Go00005oooool3o`0000Cooooo0_l0000Gooooo`?o00000_oo
ool5o`0001Oooooo0ol00004ooooo`;o00005oooool3o`0000;ooooo1Ol0000Iooooo`03o`000?oo
oooooooo00;ooooo0_l00003ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`005Oooool00`00003o0000o`00003oo`0000;o000000<00000ooooooooool01?oo
ool000kooooo0_l00005ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0`00003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool01?ooool0
00gooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Mooooo`0300000?oooooo
oooo01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01kooooo00<00000ooooooooool01?ooool000gooooo00Co0000oooooooooooo00000_ooool3
ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3
ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3
ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3
ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3
ool000Cooooo0ooo0014ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3
ool000Kooooo000=ooooo`04o`000?ooooooooooo`0000;ooooo0ooo00001?l0003ooooooooooooo
ool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?oo
ool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?oo
ool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?oo
ool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?oo
ool3ool000?ooooo0ooo0004ooooo`?oo`001Oooool00`3o003oooooooooo`03ooooo`030?l00?oo
oooooooo00Cooooo00<0o`00ooooooooool00oooool00`3o003oooooooooo`04ooooo`030?l00?oo
oooooooo00;ooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000ooo
ool3ool000Cooooo0ooo0003ooooo`?oo`001_ooool000gooooo00Co0000oooooooooooo00000_oo
ool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000ooo
ool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000ooo
ool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000ooo
ool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000?ooooo0ooo0004ooooo`?oo`000ooo
ool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool000Gooooo00<0o`00ooooooooool00ooo
ool00`3o003oooooooooo`04ooooo`030?l00?oooooooooo00?ooooo00<0o`00ooooooooool01?oo
ool00`3o003oooooooooo`02ooooo`?oo`000oooool3ool000Cooooo0ooo0003ooooo`?oo`001?oo
ool3ool000?ooooo0ooo0004ooooo`?oo`000oooool3ool000Kooooo000=ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool0Y?ooool3ool000Cooooo0ooo0003ooooo`?oo`001Ooo
ool00`3o003oooooooooo`04ooooo`030?l00?oooooooooo00?ooooo00<0o`00ooooooooool00_oo
ool3ool000Cooooo0ooo0003ooooo`?oo`001?ooool3ool001oooooo00<00000ooooooooool01?oo
ool000kooooo0_l00005ooooo`0300000?oooooooooo0;7ooooo0ooo0005ooooo`030?l00?oooooo
oooo00Cooooo00<0o`00ooooooooool00oooool00`3o003oooooooooo`02ooooo`?oo`00<oooool0
0`00003oooooooooo`04ooooo`005Oooool00`00003oooooooooo`2aooooo`?oo`001Oooool00`3o
003oooooooooo`04ooooo`030?l00?oooooooooo00?ooooo00<0o`00ooooooooool00_ooool3ool0
03?ooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003o
ooooooooo`04ooooo`030?l00?oooooooooo00?ooooo00<0o`00ooooooooool0>?ooool00`00003o
ooooooooo`04ooooo`005Oooool00`00003o0000ooooo`2iooooo`030?l00?oooooooooo00Cooooo
00<0o`00ooooooooool00oooool00`3o003oooooooooo`0gooooo`03o`000000003ooooo00Gooooo
000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool01?ooool00`3o003ooooooooo
o`03ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000
ooooooooool0^Oooool00`3o003oooooooooo`02ooooo`?oo`001Oooool00`3o003oooooooooo`0h
ooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00oooo
ooooool00_ooool3ool000Gooooo00<0o`00ooooooooool0>?ooool00`00003oooooooooo`04oooo
o`005Oooool00`00003oooooooooo`2iooooo`030?l00?oooooooooo00;ooooo0ooo0005ooooo`03
0?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0
^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool0
1?ooool001Gooooo00<00000o`000?ooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oo
oooooooo03Oooooo00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0^Oooool0
0`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool0
01Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo
03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003o
ooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo
00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo
00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003ooooooooo
o`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000
o`000?ooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Oooooo00?o0000
00000?ooool01Oooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:oooo
o`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooooooo
ool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000oooooooo
ool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l0
0?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Ooo
ool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?oo
ool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooo
oooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0^Oooool00`3o
003oooooooooo`0:ooooo`030?l00?oooooooooo03Oooooo00?o000000000?ooool01Oooool001Go
oooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03So
oooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003ooooo
ooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool000Oooooo0ol0
0004ooooo`;o00001Oooool00`00003oooooooooo`2iooooo`030?l00?oooooooooo00[ooooo00<0
o`00ooooooooool0>?ooool00`00003oooooooooo`04ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`2iooooo`030?l0
0?oooooooooo00[ooooo00<0o`00ooooooooool0>?ooool00`00003oooooooooo`04ooooo`002_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0
^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool0
1?ooool000[ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`030000
0?l0003ooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0fooooo`<00000
1_ooool000Kooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool0
1?ooool000Kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`030000
0?oooooooooo00Cooooo0006ooooo`Go00000oooool2o`0000Gooooo00<00000ooooooooool0^Ooo
ool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?oo
ool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooo
oooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o
003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Go
oooo00<00000o`000?ooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Oo
oooo00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0^Oooool00`3o003ooooo
ooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<0
0000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<0
0000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:
ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooo
ooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000oooo
ooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`03
0?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0
^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Oooooo00?o000000000?ooool0
1Oooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oo
oooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool0
0`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool0
01Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo
03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003o
ooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo
00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo
00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0^Oooool00`3o003ooooooooo
o`0:ooooo`030?l00?oooooooooo03Oooooo00?o000000000?ooool01Oooool001Gooooo00<00000
ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000
ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:oooo
o`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooooooo
ool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000oooooooo
ool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l0
0?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Ooo
ool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?oo
ool001Gooooo00<00000o`000?ooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooo
oooo03Oooooo00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0^Oooool00`3o
003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Go
oooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03So
oooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003ooooo
ooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool00004ooooool0
003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`2iooooo`030?l0
0?oooooooooo00[ooooo00<0o`00ooooooooool0>?ooool00`00003oooooooooo`04ooooo`000_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`2iooooo`030?l00?oooooooooo00[ooooo00<0o`00oooooooo
ool0>?ooool00`00003oooooooooo`04ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o0000ooooo`2ioooo
o`030?l00?oooooooooo00[ooooo00<0o`00ooooooooool0=_ooool3000000Kooooo0002ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0h
ooooo`0300000?oooooooooo00Cooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo0;Wooooo00<0
o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo0000
0ooooooo0000o`000004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`2iooooo`030?l00?oooooooooo00[ooooo00<0o`00ooooooooool0
>?ooool00`00003oooooooooo`04ooooo`000_ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0000Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oo
oooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool0
0`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool0
01Gooooo00<00000o`000?ooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo
03Oooooo00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0^Oooool00`3o003o
ooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo
00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo
00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003ooooooooo
o`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000
ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000
ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:oooo
o`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?oo
ool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Oooooo00?o000000000?oo
ool01Oooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l0
0?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Ooo
ool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?oo
ool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooo
oooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o
003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Go
oooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03So
oooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0^Oooool00`3o003ooooo
ooooo`0:ooooo`030?l00?oooooooooo03Oooooo00?o000000000?ooool01Oooool001Gooooo00<0
0000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<0
0000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:
ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooo
ooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000oooo
ooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`03
0?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0
^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool0
1?ooool001Gooooo00<00000o`000?ooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oo
oooooooo03Oooooo00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0^Oooool0
0`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool0
01Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo
03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003o
ooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool00004oooo
ool0003o0000o`0000?ooooo0ol00004ooooo`;o00001Oooool00`00003oooooooooo`2iooooo`03
0?l00?oooooooooo00[ooooo00<0o`00ooooooooool0>?ooool00`00003oooooooooo`04ooooo`00
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o
003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo0002ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?l0003ooooo
0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0fooooo`<000001_ooool000;o
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo
03Sooooo00<00000ooooooooool01?ooool000;ooooo00Co0000oooooooooooooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:
ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool00003ooooool0003o0000
00?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooo
oooo00Cooooo0002ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Gooooo00<00000
ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000
ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:oooo
o`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?oo
ool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Oooooo00?o000000000?oo
ool01Oooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l0
0?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Ooo
ool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?oo
ool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooo
oooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o
003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Go
oooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03So
oooo00<00000ooooooooool01?ooool001Gooooo00<00000o`000?ooool0^Oooool00`3o003ooooo
ooooo`0:ooooo`030?l00?oooooooooo03Oooooo00?o000000000?ooool01Oooool001Gooooo00<0
0000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<0
0000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:
ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooo
ooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000oooo
ooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`03
0?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0
^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool0
1?ooool001Gooooo00<00000o`000?ooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oo
oooooooo03Oooooo00?o000000000?ooool01Oooool001Gooooo00<00000ooooooooool0^Oooool0
0`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool0
01Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo
03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003o
ooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo
00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo
00<00000ooooooooool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003ooooooooo
o`0:ooooo`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000
o`000?ooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Oooooo00?o0000
00000?ooool01Oooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:oooo
o`030?l00?oooooooooo03Sooooo00<00000ooooooooool01?ooool001Gooooo00<00000oooooooo
ool0^Oooool00`3o003oooooooooo`0:ooooo`030?l00?oooooooooo03Sooooo00<00000oooooooo
ool01?ooool001Gooooo00<00000ooooooooool0^Oooool00`3o003oooooooooo`0:ooooo`030?l0
0?oooooooooo03Sooooo00<00000ooooooooool01?ooool000Go00000oooool2o`0000Cooooo0_l0
0005ooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003ooooooooo
o`0hooooo`0300000?oooooooooo00Cooooo00001Ooooooo0000oooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo0;Wo
oooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Co
oooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`0300000?l0003ooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o
003oooooooooo`0fooooo`<000001_ooool000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`2i
ooooo`030?l00?oooooooooo00[ooooo00<0o`00ooooooooool0>?ooool00`00003oooooooooo`04
ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`2iooooo`030?l00?oooooooooo00[ooooo
00<0o`00ooooooooool0>?ooool00`00003oooooooooo`04ooooo`0000Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`2iooooo`030?l00?oooooooooo00[ooooo00<0o`00ooooooooool0>?ooool00`00
003oooooooooo`04ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005oooo
o`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hoooo
o`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00oooooooo
ool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo000Eooooo`030000
0?l0003ooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0gooooo`03o`00
0000003ooooo00Gooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_oo
ool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooo
oooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooo
oooo00Cooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o
003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo0;Wo
oooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Co
oooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003ooooo
ooooo`0hooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0
o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo000E
ooooo`0300000?l0003ooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0g
ooooo`03o`000000003ooooo00Gooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00oooo
ooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo000Eooooo`03
00000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`03
00000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool0
2_ooool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oo
oooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oo
oooooooo00Cooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool0
0`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?l0003ooooo
0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0gooooo`03o`000000003ooooo
00Gooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003o
ooooooooo`0hooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo0;Wooooo
00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo
000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003ooooooooo
o`0hooooo`0300000?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00
ooooooooool02_ooool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo000Eoooo
o`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hoooo
o`0300000?oooooooooo00Cooooo000Eooooo`0300000?l0003ooooo0;Wooooo00<0o`00oooooooo
ool02_ooool00`3o003oooooooooo`0gooooo`03o`000000003ooooo00Gooooo000Eooooo`030000
0?oooooooooo0;Wooooo00<0o`00ooooooooool02_ooool00`3o003oooooooooo`0hooooo`030000
0?oooooooooo00Cooooo000Eooooo`0300000?oooooooooo0;Wooooo00<0o`00ooooooooool02_oo
ool00`3o003oooooooooo`0hooooo`0300000?oooooooooo00Cooooo0005o`0000;ooooo0ol00004
ooooo`;o00001Oooool00`00003oooooooooo`2hooooo`?oo`002oooool00`3o003oooooooooo`0h
ooooo`0300000?oooooooooo00Cooooo00001ooooooo0000oooooooooooo0000ooooool000000ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0
^?ooool3ool000_ooooo00<0o`00ooooooooool0>?ooool00`00003oooooooooo`04ooooo`000_oo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00`00003oooooooooo`2hooooo`?oo`002oooool00`3o003oooooooooo`0hooooo`030000
0?oooooooooo00Cooooo0003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`0300000?l0003ooooo0<Kooooo00<0o`00ooooooooool0
=_ooool3000000Kooooo00001_l0003ooooooooooooooooo0000ooooo`Co00000oooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo0<Gooooo0ooo000iooooo`0300000?oooooooooo
00Cooooo00001ol0003ooooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo0<Gooooo0ooo000iooooo`0300000?oooooooooo00Cooooo0000
1?oooooo0000o`000?l00002ooooo`Go00000oooool2o`0000Gooooo00<00000ooooooooool0aOoo
ool3ool003Wooooo00<00000ooooooooool01?ooool001Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0`00003oooooooooo`04ooooo`005Ooooooo000000H000001_ooool00?oooooo8Oooool00?oooooo
8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.27209, -30.0642, \
0.153994, 1.65665}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Does this make sense?", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Florin][t]\  \[Equal] \((f1[t]\  // TrigReduce)\)\  // \ 
      TraditionalForm\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\[Florin](t) == 
      1\/2\ \((cos(58\ \[Pi]\ t) - cos(62\ \[Pi]\ t))\)\)], "Output"]
}, Open  ]],

Cell["\<\
Note that the expression 'sin(2\[Pi] t) sin(60\[Pi] t)' can also be \
expressed as '1/2 [(cos(58\[Pi] t)-cos(62\[Pi] t)]'. Thus two frequencies are \
present in the signal 29Hz and 31Hz.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example #4: square wave", "Subsection"],

Cell[CellGroupData[{

Cell["Continuous-time waveform", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Pulse1[t_] := 
        UnitStep[t] - UnitStep[t - 1/20] - 1/2;\)\), "\[IndentingNewLine]", 
    \(\(fnc1\  = \ 
        PeriodicSignal[
          Pulse1, {0, 1/10}, {t, 0, 1}];\)\), "\[IndentingNewLine]", 
    \(\(Plot[fnc1, {t, 0, 1}, PlotPoints \[Rule] 100, \ 
        PlotStyle \[Rule] Blue];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07358 -24 -4.5 ]
[-0.0125 .07358 0 4.5 ]
[-0.0125 .1913 -24 -4.5 ]
[-0.0125 .1913 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .42674 -18 -4.5 ]
[-0.0125 .42674 0 4.5 ]
[-0.0125 .54446 -18 -4.5 ]
[-0.0125 .54446 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07358 m
.00625 .07358 L
s
[(-0.4)] -0.0125 .07358 1 0 Mshowa
0 .1913 m
.00625 .1913 L
s
[(-0.2)] -0.0125 .1913 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .42674 m
.00625 .42674 L
s
[(0.2)] -0.0125 .42674 1 0 Mshowa
0 .54446 m
.00625 .54446 L
s
[(0.4)] -0.0125 .54446 1 0 Mshowa
.125 Mabswid
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .16187 m
.00375 .16187 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .45617 m
.00375 .45617 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .04415 m
.00375 .04415 L
s
0 .01472 m
.00375 .01472 L
s
0 .57389 m
.00375 .57389 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07358 m
1 .07358 L
s
.99375 .1913 m
1 .1913 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .42674 m
1 .42674 L
s
.99375 .54446 m
1 .54446 L
s
.125 Mabswid
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .04415 m
1 .04415 L
s
.99625 .01472 m
1 .01472 L
s
.99625 .57389 m
1 .57389 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .60332 m
.03318 .60332 L
.04339 .60332 L
.05298 .60332 L
.06221 .60332 L
.06695 .60332 L
.06832 .60332 L
.06961 .60332 L
.07077 .60332 L
.07109 .60332 L
.07126 .60332 L
.07143 .60332 L
.07171 .01472 L
.07203 .01472 L
.08143 .01472 L
.09142 .01472 L
.10105 .01472 L
.11031 .01472 L
.11508 .01472 L
.11645 .01472 L
.11774 .01472 L
.11831 .01472 L
.11862 .01472 L
.1189 .01472 L
.11922 .60332 L
.11938 .60332 L
.11956 .60332 L
.12016 .60332 L
.13019 .60332 L
.13985 .60332 L
.14914 .60332 L
.15384 .60332 L
.15903 .60332 L
.16139 .60332 L
.16394 .60332 L
.16511 .60332 L
.16575 .60332 L
.16606 .60332 L
.16634 .60332 L
.1666 .60332 L
.16685 .01472 L
.16711 .01472 L
.16739 .01472 L
.16855 .01472 L
.17846 .01472 L
.18802 .01472 L
.1972 .01472 L
.20231 .01472 L
.20698 .01472 L
.20929 .01472 L
Mistroke
.21181 .01472 L
.21296 .01472 L
.21359 .01472 L
.2139 .01472 L
.21419 .01472 L
.21446 .60332 L
.21474 .60332 L
.21535 .60332 L
.21639 .60332 L
.22561 .60332 L
.23542 .60332 L
.24487 .60332 L
.24968 .60332 L
.25491 .60332 L
.25735 .60332 L
.25868 .60332 L
.25994 .60332 L
.261 .60332 L
.26129 .60332 L
.2616 .60332 L
.26186 .60332 L
.26214 .01472 L
.26247 .01472 L
.26276 .01472 L
.26341 .01472 L
.26458 .01472 L
.27429 .01472 L
.28362 .01472 L
.29356 .01472 L
.2985 .01472 L
.30312 .01472 L
.3054 .01472 L
.30756 .01472 L
.30875 .01472 L
.30908 .01472 L
.30925 .01472 L
.30942 .01472 L
.30972 .60332 L
.30988 .60332 L
.31005 .60332 L
.31232 .60332 L
.32228 .60332 L
.33188 .60332 L
.34111 .60332 L
.34626 .60332 L
.35094 .60332 L
.35327 .60332 L
.3545 .60332 L
.3558 .60332 L
.35635 .60332 L
Mistroke
.35665 .60332 L
.35694 .60332 L
.3571 .60332 L
.35728 .01472 L
.35758 .01472 L
.35819 .01472 L
.3604 .01472 L
.37025 .01472 L
.37974 .01472 L
.38983 .01472 L
.39489 .01472 L
.39955 .01472 L
.4019 .01472 L
.40305 .01472 L
.4041 .01472 L
.40437 .01472 L
.40466 .01472 L
.40494 .60332 L
.4052 .60332 L
.40639 .60332 L
.4089 .60332 L
.41842 .60332 L
.42758 .60332 L
.43733 .60332 L
.44671 .60332 L
.44923 .60332 L
.45046 .60332 L
.45157 .60332 L
.45187 .60332 L
.45218 .60332 L
.45248 .01472 L
.45276 .01472 L
.45402 .01472 L
.45669 .01472 L
.46625 .01472 L
.47544 .01472 L
.48522 .01472 L
.49464 .01472 L
.4971 .01472 L
.49839 .01472 L
.49911 .01472 L
.49946 .01472 L
.49978 .01472 L
.50009 .60332 L
.50024 .60332 L
.50041 .60332 L
.5011 .60332 L
.50231 .60332 L
.50465 .60332 L
.51447 .60332 L
Mistroke
.52392 .60332 L
.53396 .60332 L
.53899 .60332 L
.5412 .60332 L
.54364 .60332 L
.54476 .60332 L
.54597 .60332 L
.54656 .60332 L
.54711 .60332 L
.54735 .60332 L
.54761 .60332 L
.54789 .01472 L
.54816 .01472 L
.55295 .01472 L
.56303 .01472 L
.57274 .01472 L
.58208 .01472 L
.58681 .01472 L
.58932 .01472 L
.59202 .01472 L
.59334 .01472 L
.594 .01472 L
.5946 .01472 L
.59489 .01472 L
.59515 .01472 L
.59543 .60332 L
.59573 .60332 L
.59696 .60332 L
.60159 .60332 L
.61096 .60332 L
.62093 .60332 L
.63053 .60332 L
.63537 .60332 L
.63977 .60332 L
.64094 .60332 L
.64156 .60332 L
.64221 .60332 L
.64249 .60332 L
.64279 .60332 L
.64296 .01472 L
.64311 .01472 L
.64341 .01472 L
.64452 .01472 L
.6496 .01472 L
.65924 .01472 L
.6685 .01472 L
.67837 .01472 L
.68293 .01472 L
.68533 .01472 L
.68786 .01472 L
Mistroke
.68915 .01472 L
.68951 .01472 L
.68989 .01472 L
.69007 .01472 L
.69025 .01472 L
.6904 .01472 L
.69057 .60332 L
.69087 .60332 L
.6912 .60332 L
.69187 .60332 L
.69306 .60332 L
.69795 .60332 L
.70771 .60332 L
.7171 .60332 L
.72708 .60332 L
.73206 .60332 L
.73449 .60332 L
.7367 .60332 L
.73723 .60332 L
.73753 .60332 L
.7378 .60332 L
.7381 .01472 L
.73826 .01472 L
.73842 .01472 L
.739 .01472 L
.74117 .01472 L
.74594 .01472 L
.75596 .01472 L
.76561 .01472 L
.77489 .01472 L
.77958 .01472 L
.78207 .01472 L
.78339 .01472 L
.7841 .01472 L
.78477 .01472 L
.78536 .01472 L
.78553 .01472 L
.78569 .01472 L
.78599 .60332 L
.78615 .60332 L
.78632 .60332 L
.78663 .60332 L
.78732 .60332 L
.78967 .60332 L
.79427 .60332 L
.80345 .60332 L
.81322 .60332 L
.82262 .60332 L
.8274 .60332 L
.82992 .60332 L
Mistroke
.83131 .60332 L
.83199 .60332 L
.83261 .60332 L
.83293 .60332 L
.83323 .60332 L
.83353 .01472 L
.8337 .01472 L
.83387 .01472 L
.83523 .01472 L
.83761 .01472 L
.84224 .01472 L
.85227 .01472 L
.86193 .01472 L
.87123 .01472 L
.87602 .01472 L
.87844 .01472 L
.87911 .01472 L
.87982 .01472 L
.88015 .01472 L
.8805 .01472 L
.88079 .01472 L
.88096 .60332 L
.88111 .60332 L
.89058 .60332 L
.90064 .60332 L
.91034 .60332 L
.91966 .60332 L
.92448 .60332 L
.92691 .60332 L
.92758 .60332 L
.92795 .60332 L
.92813 .60332 L
.92829 .60332 L
.92845 .60332 L
.92862 .01472 L
.9288 .01472 L
.92897 .01472 L
.92959 .01472 L
.93931 .01472 L
.94867 .01472 L
.95863 .01472 L
.96822 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0002Wooooo0_l00004ooooo`04o`00
0?ooooooooooooooo`Go00008oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0002;o
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Tooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`?o0000:?ooool3o`0000Oooooo000Oooooo`04o`000?ooooooooooo`0002Oo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Rooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000008_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool00000:?ooool00ol0003oooooooooo`06ooooo`007oooool01?l0003oooooooooool0000W
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool08_ooool01?l0003ooooooooo
ool00007ooooo`Go00008Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000008_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:?oo
ool00ol0003oooooooooo`06ooooo`007oooool01?l0003oooooooooool0000Wooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0002;ooooo00Co0000oooooooooooo00001oooool4o`0002?ooooo00Co0000
oooooooooooo00002?ooool3o`0002Wooooo00?o0000ooooooooool01_ooool001oooooo00Co0000
oooooooooooo00009oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00008_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002;ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00000Xooooo`03o`000?oooooooooo00Kooooo000Oooooo`04o`000?oo
ooooooooo`0002Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
02;ooooo00Co0000oooooooooooo00002Oooool2o`0002;ooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`00000Wooooo`;o00002?ooool0023ooooo0_l0000Yooooo`;o00002Oooool3o`0002Cooooo
0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0000:ooooo`;o00009?ooool2o`0000Wooooo
0ol0000Yooooo`03o`000?oooooooooo00Kooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo000Kooooo`0300000?l0003o00000?oo00000Ol000010000007ooooo
000Kooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00`00003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`0300000?oooooooooo00?ooooo0@000001ooooo`006oooool00`00003oooooooooo`03
ooooo`0300000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00`00003oooooooooo`0^
ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool0;_ooool00`00003oooooooooo`03
ooooo`4000000Oooool001_ooooo00<00000ooooooooool0/?ooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0Foooo
o`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o0000ooooo`0?ooooo``0
003o00?o003o0000ooooool02_ooool00ol00?l0003o0000o`050000o`Co003o00<0003ooooooooo
ool02_ooool80000o`Co003o00<0003oooooooooool02_ooool80000o`Co003o00<0003ooooooooo
ool02Oooool00ol00?l0003o0000o`080000o`;o003o00<0003oooooooooool02Oooool00ol00?l0
003o0000o`060000o`?o003o00<0003oooooooooool02_ooool00ol00?l0003o0000o`060000o`?o
003o00<0003oooooooooool02Oooool2o`00o`P0003o0ol00?l00`000?ooooooooooo`09ooooo`;o
003o20000?l2o`00o`030000oooooooooooo00[ooooo3@000?l4ooooo`7o00000@000001ooooo`00
6oooool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00
003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o0000oooo
o`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooo
oooo00oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo
00oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool03oooool10000007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`?o00001?ooool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001
ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00<00000
ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool000Go00000_ooool01?l0
003oooooooooool00007ooooo`Go00001?ooool00`00003o0000ooooo`0?ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00kooooo0Ol000010000007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00001Oooool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@00
0001ooooo`001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Gooooo00<0
0000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool000Oooooo00Co0000
oooooooooooo00002Oooool2o`0000Gooooo00<00000ooooooooool03oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`0?ooooo`4000000Oooool000Sooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00<00000
ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000oooooooo
ool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool0
3oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000o`000?ooool03ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`0>ooooo`7o00000@000001ooooo`006oooool00`00003oooooooooo`0?
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00oooooo0@000001ooooo`006oooool00`00003o0000ooooo`0?ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
3oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03ooo
ool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool1
0000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool10000
007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool10000007o
oooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool10000007ooooo
000Kooooo`0300000?l0003ooooo00oooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03_ooool1o`00004000000Ooo
ool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_o
oooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo
00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool000Sooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00`00003oooooooooo`0?ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00oooooo0@000001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`40
00000Oooool000Go00000_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Co
oooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool000Oooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`0300000?l0003ooooo00oo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool03_ooool1o`00004000000Oooool000Oooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00<00000ooooooooool03oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`0?ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?
ooooo`4000000Oooool000Sooooo0_l00009ooooo`?o00001Oooool00`00003oooooooooo`0?oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00oooooo0@000001ooooo`006oooool00`00003o0000ooooo`0?ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
3oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03ooo
ool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool1
0000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool10000
007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool10000007o
oooo000Kooooo`0300000?l0003ooooo00oooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03_ooool1o`0000400000
0Oooool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_o
oooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo
00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000
ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000o`00
0?ooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`0>ooooo`7o00000@000001ooooo`006oooool00`00003o
ooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00oooooo0@000001ooooo`005?ooool2o`0000Gooooo00<00000oooo
ooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001?ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001oooo
o`004oooool01?l0003oooooooooool00004oooooa80000000<0003o0000000000002P0000000`00
0?l0000000000009000000030000o`000000000000T0000000<0003o0000000000002P0000000`00
0?l0000000000009000000030000o`000000000000X0000000<0003o0000000000002@0000000`00
0?l0000000000009000000030000o`000000000000X0000000<0003o0000000000002@0000000`00
0?l0000000000009000000030000o`000000000000X0000000<0003o0000000000002@0000000`00
0?l0000000000009000000030000o`000000000000X0000000<0003o0000000000002@0000000`00
0?l0000000000009000000030000o`000000000000X0000000<0003o00000000000040000001oooo
o`004oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00oooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool03oooool10000007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001?ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001oooo
o`005?ooool2o`0000Gooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`40
00000Oooool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`400000
0Oooool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool0
01_ooooo00<00000o`000?ooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0>ooooo`7o00000@000001oooo
o`006oooool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`00
6oooool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00
003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o0000
ooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00kooooo0Ol000010000007ooooo000Kooooo`0300000?oo
oooooooo00oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooo
oooo00oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo
00oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00[ooooo00<0003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0
003oooooooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003o
ooooooooool03oooool10000007ooooo000Kooooo`0300000?l0003ooooo00oooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool03_ooool1o`00004000000Oooool001_ooooo00<00000ooooooooool03oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool03oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool03oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooooooo
o`0?ooooo`4000000Oooool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?
ooooo`4000000Oooool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool0
0`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`001oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool03ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`0?ooooo`4000000Oooool000Oooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03ooo
ool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00ooo
ool00`00003o0000ooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00kooooo0Ol000010000007ooooo0007
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`030000
0?oooooooooo00oooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool03oooool10000007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooooooo00oo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[o
oooo00<0003oooooooooool03oooool10000007ooooo0008ooooo`;o00002Oooool3o`0000Gooooo
00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<0
0000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0
003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000
ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003o
ooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000oooo
ooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_ooooo00<00000o`000?oo
ool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`0>ooooo`7o00000@000001ooooo`006oooool00`00003ooooo
ooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09
ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:
ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09oooo
o`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00oooooo0@000001ooooo`006oooool00`00003oooooooooo`0?ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00oooooo0@000001ooooo`006oooool00`00003o0000ooooo`0?ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooo
ooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooo
ooooool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003ooooooooo
ool03oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
3oooool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_oo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03ooo
ool10000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool1
0000007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool10000
007ooooo000Kooooo`0300000?oooooooooo00oooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03oooool10000007o
oooo000Kooooo`0300000?l0003ooooo00oooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool03_ooool1o`0000400000
0Oooool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_o
oooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool000Sooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`0300000?oooooooooo00oooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool03oooool10000007ooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool00oooool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo
00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo
0@000001ooooo`001oooool01?l0003oooooooooool00007ooooo`Go00001?ooool00`00003o0000
ooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00kooooo0Ol000010000007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0?ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00oooooo0@000001ooooo`001oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Gooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`03
0000oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`40
00000Oooool000Oooooo00Co0000oooooooooooo00002Oooool2o`0000Gooooo00<00000oooooooo
ool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wooooo00<0003ooooooooo
ool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool000Sooooo0_l0000;ooooo`03o`00
0?oooooooooo00?ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000
oooooooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`400000
0Oooool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooo
oooooooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Ooo
ool001_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooo
oooo00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool0
01_ooooo00<00000ooooooooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo
00Wooooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0?ooooo`4000000Oooool001_o
oooo00<00000o`000?ooool03oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00Wo
oooo00<0003oooooooooool02_ooool00`000?ooooooooooo`0>ooooo`7o00000@000001ooooo`00
6oooool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool0
2Oooool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006ooo
ool00`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Ooo
ool00`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool0
0`00003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool0
0`000?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00
003oooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`00
0?ooooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o
ooooooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oo
ooooooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003ooooo
ooooo`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooo
ooooo`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003ooooooooo
o`0?ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00Wooooo00<0003oooooooooool02Oooool00`000?oooooooooo
o`0:ooooo`030000oooooooooooo00oooooo0@000001ooooo`006oooool00`00003o0000ooooo`03
ooooo`X0003o0_l00?l00`000?ooooooooooo`0:ooooo`T0003o0ol00?l00`000?ooooooooooo`09
ooooo`03o`00o`000?l0003o00L0003o0ol00?l00`000?ooooooooooo`09ooooo`03o`00o`000?l0
003o00L0003o0_l00?l00`000?ooooooooooo`0:ooooo`03o`00o`000?l0003o00P0003o00?o003o
0000ooooool02oooool00ol00?l0003o0000o`070000o`;o003o00<0003oooooooooool02Oooool2
o`00o`T0003o0_l00?l00`000?ooooooooooo`09ooooo`;o003o20000?l2o`00o`030000oooooooo
oooo00[ooooo0_l00?l90000o`03o`00o`000?oooooo00[ooooo00?o003o0000o`000?l020000?l2
o`00o`030000oooooooooooo00kooooo0Ol000010000007ooooo000Kooooo`0300000?oooooooooo
0?oooooo0Oooool10000007ooooo000Kooooo`0300000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0@000001ooooo`00
6ooooooo000000D000000Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.135193, -0.618986, \
0.00404426, 0.00654375}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled continuous-time waveform", "Subsubsection"],

Cell[BoxData[
    \(\(sampleRate = 1000;\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(signal\  = \ 
        Table[fnc1\  /. \ t \[Rule] ti, {ti, 0, 1, 
              1/\((sampleRate - 1)\)}]\  // \ N;\)\), "\n", 
    \(\(ListPlot[signal, PlotStyle \[Rule] Blue];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.309017 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .07358 -24 -4.5 ]
[-0.0125 .07358 0 4.5 ]
[-0.0125 .1913 -24 -4.5 ]
[-0.0125 .1913 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .42674 -18 -4.5 ]
[-0.0125 .42674 0 4.5 ]
[-0.0125 .54446 -18 -4.5 ]
[-0.0125 .54446 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(200)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(400)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(600)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(800)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07358 m
.00625 .07358 L
s
[(-0.4)] -0.0125 .07358 1 0 Mshowa
0 .1913 m
.00625 .1913 L
s
[(-0.2)] -0.0125 .1913 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .42674 m
.00625 .42674 L
s
[(0.2)] -0.0125 .42674 1 0 Mshowa
0 .54446 m
.00625 .54446 L
s
[(0.4)] -0.0125 .54446 1 0 Mshowa
.125 Mabswid
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .16187 m
.00375 .16187 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .45617 m
.00375 .45617 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .04415 m
.00375 .04415 L
s
0 .01472 m
.00375 .01472 L
s
0 .57389 m
.00375 .57389 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07358 m
1 .07358 L
s
.99375 .1913 m
1 .1913 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .42674 m
1 .42674 L
s
.99375 .54446 m
1 .54446 L
s
.125 Mabswid
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .04415 m
1 .04415 L
s
.99625 .01472 m
1 .01472 L
s
.99625 .57389 m
1 .57389 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02476 .60332 m
.02571 .60332 L
.02667 .60332 L
.02762 .60332 L
.02857 .60332 L
.02952 .60332 L
.03048 .60332 L
.03143 .60332 L
.03238 .60332 L
.03333 .60332 L
.03429 .60332 L
.03524 .60332 L
.03619 .60332 L
.03714 .60332 L
.0381 .60332 L
.03905 .60332 L
.04 .60332 L
.04095 .60332 L
.0419 .60332 L
.04286 .60332 L
.04381 .60332 L
.04476 .60332 L
.04571 .60332 L
.04667 .60332 L
.04762 .60332 L
.04857 .60332 L
.04952 .60332 L
.05048 .60332 L
.05143 .60332 L
.05238 .60332 L
.05333 .60332 L
.05429 .60332 L
.05524 .60332 L
.05619 .60332 L
.05714 .60332 L
.0581 .60332 L
.05905 .60332 L
.06 .60332 L
.06095 .60332 L
.0619 .60332 L
.06286 .60332 L
.06381 .60332 L
.06476 .60332 L
.06571 .60332 L
.06667 .60332 L
.06762 .60332 L
.06857 .60332 L
.06952 .60332 L
.07048 .60332 L
.07143 .60332 L
Mistroke
.07238 .01472 L
.07333 .01472 L
.07429 .01472 L
.07524 .01472 L
.07619 .01472 L
.07714 .01472 L
.0781 .01472 L
.07905 .01472 L
.08 .01472 L
.08095 .01472 L
.0819 .01472 L
.08286 .01472 L
.08381 .01472 L
.08476 .01472 L
.08571 .01472 L
.08667 .01472 L
.08762 .01472 L
.08857 .01472 L
.08952 .01472 L
.09048 .01472 L
.09143 .01472 L
.09238 .01472 L
.09333 .01472 L
.09429 .01472 L
.09524 .01472 L
.09619 .01472 L
.09714 .01472 L
.0981 .01472 L
.09905 .01472 L
.1 .01472 L
.10095 .01472 L
.1019 .01472 L
.10286 .01472 L
.10381 .01472 L
.10476 .01472 L
.10571 .01472 L
.10667 .01472 L
.10762 .01472 L
.10857 .01472 L
.10952 .01472 L
.11048 .01472 L
.11143 .01472 L
.11238 .01472 L
.11333 .01472 L
.11429 .01472 L
.11524 .01472 L
.11619 .01472 L
.11714 .01472 L
.1181 .01472 L
.11905 .01472 L
Mistroke
.12 .60332 L
.12095 .60332 L
.1219 .60332 L
.12286 .60332 L
.12381 .60332 L
.12476 .60332 L
.12571 .60332 L
.12667 .60332 L
.12762 .60332 L
.12857 .60332 L
.12952 .60332 L
.13048 .60332 L
.13143 .60332 L
.13238 .60332 L
.13333 .60332 L
.13429 .60332 L
.13524 .60332 L
.13619 .60332 L
.13714 .60332 L
.1381 .60332 L
.13905 .60332 L
.14 .60332 L
.14095 .60332 L
.1419 .60332 L
.14286 .60332 L
.14381 .60332 L
.14476 .60332 L
.14571 .60332 L
.14667 .60332 L
.14762 .60332 L
.14857 .60332 L
.14952 .60332 L
.15048 .60332 L
.15143 .60332 L
.15238 .60332 L
.15333 .60332 L
.15429 .60332 L
.15524 .60332 L
.15619 .60332 L
.15714 .60332 L
.1581 .60332 L
.15905 .60332 L
.16 .60332 L
.16095 .60332 L
.1619 .60332 L
.16286 .60332 L
.16381 .60332 L
.16476 .60332 L
.16571 .60332 L
.16667 .60332 L
Mistroke
.16762 .01472 L
.16857 .01472 L
.16952 .01472 L
.17048 .01472 L
.17143 .01472 L
.17238 .01472 L
.17333 .01472 L
.17429 .01472 L
.17524 .01472 L
.17619 .01472 L
.17714 .01472 L
.1781 .01472 L
.17905 .01472 L
.18 .01472 L
.18095 .01472 L
.1819 .01472 L
.18286 .01472 L
.18381 .01472 L
.18476 .01472 L
.18571 .01472 L
.18667 .01472 L
.18762 .01472 L
.18857 .01472 L
.18952 .01472 L
.19048 .01472 L
.19143 .01472 L
.19238 .01472 L
.19333 .01472 L
.19429 .01472 L
.19524 .01472 L
.19619 .01472 L
.19714 .01472 L
.1981 .01472 L
.19905 .01472 L
.2 .01472 L
.20095 .01472 L
.2019 .01472 L
.20286 .01472 L
.20381 .01472 L
.20476 .01472 L
.20571 .01472 L
.20667 .01472 L
.20762 .01472 L
.20857 .01472 L
.20952 .01472 L
.21048 .01472 L
.21143 .01472 L
.21238 .01472 L
.21333 .01472 L
.21429 .01472 L
Mistroke
.21524 .60332 L
.21619 .60332 L
.21714 .60332 L
.2181 .60332 L
.21905 .60332 L
.22 .60332 L
.22095 .60332 L
.2219 .60332 L
.22286 .60332 L
.22381 .60332 L
.22476 .60332 L
.22571 .60332 L
.22667 .60332 L
.22762 .60332 L
.22857 .60332 L
.22952 .60332 L
.23048 .60332 L
.23143 .60332 L
.23238 .60332 L
.23333 .60332 L
.23429 .60332 L
.23524 .60332 L
.23619 .60332 L
.23714 .60332 L
.2381 .60332 L
.23905 .60332 L
.24 .60332 L
.24095 .60332 L
.2419 .60332 L
.24286 .60332 L
.24381 .60332 L
.24476 .60332 L
.24571 .60332 L
.24667 .60332 L
.24762 .60332 L
.24857 .60332 L
.24952 .60332 L
.25048 .60332 L
.25143 .60332 L
.25238 .60332 L
.25333 .60332 L
.25429 .60332 L
.25524 .60332 L
.25619 .60332 L
.25714 .60332 L
.2581 .60332 L
.25905 .60332 L
.26 .60332 L
.26095 .60332 L
.2619 .60332 L
Mistroke
.26286 .01472 L
.26381 .01472 L
.26476 .01472 L
.26571 .01472 L
.26667 .01472 L
.26762 .01472 L
.26857 .01472 L
.26952 .01472 L
.27048 .01472 L
.27143 .01472 L
.27238 .01472 L
.27333 .01472 L
.27429 .01472 L
.27524 .01472 L
.27619 .01472 L
.27714 .01472 L
.2781 .01472 L
.27905 .01472 L
.28 .01472 L
.28095 .01472 L
.2819 .01472 L
.28286 .01472 L
.28381 .01472 L
.28476 .01472 L
.28571 .01472 L
.28667 .01472 L
.28762 .01472 L
.28857 .01472 L
.28952 .01472 L
.29048 .01472 L
.29143 .01472 L
.29238 .01472 L
.29333 .01472 L
.29429 .01472 L
.29524 .01472 L
.29619 .01472 L
.29714 .01472 L
.2981 .01472 L
.29905 .01472 L
.3 .01472 L
.30095 .01472 L
.3019 .01472 L
.30286 .01472 L
.30381 .01472 L
.30476 .01472 L
.30571 .01472 L
.30667 .01472 L
.30762 .01472 L
.30857 .01472 L
.30952 .01472 L
Mistroke
.31048 .60332 L
.31143 .60332 L
.31238 .60332 L
.31333 .60332 L
.31429 .60332 L
.31524 .60332 L
.31619 .60332 L
.31714 .60332 L
.3181 .60332 L
.31905 .60332 L
.32 .60332 L
.32095 .60332 L
.3219 .60332 L
.32286 .60332 L
.32381 .60332 L
.32476 .60332 L
.32571 .60332 L
.32667 .60332 L
.32762 .60332 L
.32857 .60332 L
.32952 .60332 L
.33048 .60332 L
.33143 .60332 L
.33238 .60332 L
.33333 .60332 L
.33429 .60332 L
.33524 .60332 L
.33619 .60332 L
.33714 .60332 L
.3381 .60332 L
.33905 .60332 L
.34 .60332 L
.34095 .60332 L
.3419 .60332 L
.34286 .60332 L
.34381 .60332 L
.34476 .60332 L
.34571 .60332 L
.34667 .60332 L
.34762 .60332 L
.34857 .60332 L
.34952 .60332 L
.35048 .60332 L
.35143 .60332 L
.35238 .60332 L
.35333 .60332 L
.35429 .60332 L
.35524 .60332 L
.35619 .60332 L
.35714 .60332 L
Mistroke
.3581 .01472 L
.35905 .01472 L
.36 .01472 L
.36095 .01472 L
.3619 .01472 L
.36286 .01472 L
.36381 .01472 L
.36476 .01472 L
.36571 .01472 L
.36667 .01472 L
.36762 .01472 L
.36857 .01472 L
.36952 .01472 L
.37048 .01472 L
.37143 .01472 L
.37238 .01472 L
.37333 .01472 L
.37429 .01472 L
.37524 .01472 L
.37619 .01472 L
.37714 .01472 L
.3781 .01472 L
.37905 .01472 L
.38 .01472 L
.38095 .01472 L
.3819 .01472 L
.38286 .01472 L
.38381 .01472 L
.38476 .01472 L
.38571 .01472 L
.38667 .01472 L
.38762 .01472 L
.38857 .01472 L
.38952 .01472 L
.39048 .01472 L
.39143 .01472 L
.39238 .01472 L
.39333 .01472 L
.39429 .01472 L
.39524 .01472 L
.39619 .01472 L
.39714 .01472 L
.3981 .01472 L
.39905 .01472 L
.4 .01472 L
.40095 .01472 L
.4019 .01472 L
.40286 .01472 L
.40381 .01472 L
.40476 .01472 L
Mistroke
.40571 .60332 L
.40667 .60332 L
.40762 .60332 L
.40857 .60332 L
.40952 .60332 L
.41048 .60332 L
.41143 .60332 L
.41238 .60332 L
.41333 .60332 L
.41429 .60332 L
.41524 .60332 L
.41619 .60332 L
.41714 .60332 L
.4181 .60332 L
.41905 .60332 L
.42 .60332 L
.42095 .60332 L
.4219 .60332 L
.42286 .60332 L
.42381 .60332 L
.42476 .60332 L
.42571 .60332 L
.42667 .60332 L
.42762 .60332 L
.42857 .60332 L
.42952 .60332 L
.43048 .60332 L
.43143 .60332 L
.43238 .60332 L
.43333 .60332 L
.43429 .60332 L
.43524 .60332 L
.43619 .60332 L
.43714 .60332 L
.4381 .60332 L
.43905 .60332 L
.44 .60332 L
.44095 .60332 L
.4419 .60332 L
.44286 .60332 L
.44381 .60332 L
.44476 .60332 L
.44571 .60332 L
.44667 .60332 L
.44762 .60332 L
.44857 .60332 L
.44952 .60332 L
.45048 .60332 L
.45143 .60332 L
.45238 .60332 L
Mistroke
.45333 .01472 L
.45429 .01472 L
.45524 .01472 L
.45619 .01472 L
.45714 .01472 L
.4581 .01472 L
.45905 .01472 L
.46 .01472 L
.46095 .01472 L
.4619 .01472 L
.46286 .01472 L
.46381 .01472 L
.46476 .01472 L
.46571 .01472 L
.46667 .01472 L
.46762 .01472 L
.46857 .01472 L
.46952 .01472 L
.47048 .01472 L
.47143 .01472 L
.47238 .01472 L
.47333 .01472 L
.47429 .01472 L
.47524 .01472 L
.47619 .01472 L
.47714 .01472 L
.4781 .01472 L
.47905 .01472 L
.48 .01472 L
.48095 .01472 L
.4819 .01472 L
.48286 .01472 L
.48381 .01472 L
.48476 .01472 L
.48571 .01472 L
.48667 .01472 L
.48762 .01472 L
.48857 .01472 L
.48952 .01472 L
.49048 .01472 L
.49143 .01472 L
.49238 .01472 L
.49333 .01472 L
.49429 .01472 L
.49524 .01472 L
.49619 .01472 L
.49714 .01472 L
.4981 .01472 L
.49905 .01472 L
.5 .01472 L
Mistroke
.50095 .60332 L
.5019 .60332 L
.50286 .60332 L
.50381 .60332 L
.50476 .60332 L
.50571 .60332 L
.50667 .60332 L
.50762 .60332 L
.50857 .60332 L
.50952 .60332 L
.51048 .60332 L
.51143 .60332 L
.51238 .60332 L
.51333 .60332 L
.51429 .60332 L
.51524 .60332 L
.51619 .60332 L
.51714 .60332 L
.5181 .60332 L
.51905 .60332 L
.52 .60332 L
.52095 .60332 L
.5219 .60332 L
.52286 .60332 L
.52381 .60332 L
.52476 .60332 L
.52571 .60332 L
.52667 .60332 L
.52762 .60332 L
.52857 .60332 L
.52952 .60332 L
.53048 .60332 L
.53143 .60332 L
.53238 .60332 L
.53333 .60332 L
.53429 .60332 L
.53524 .60332 L
.53619 .60332 L
.53714 .60332 L
.5381 .60332 L
.53905 .60332 L
.54 .60332 L
.54095 .60332 L
.5419 .60332 L
.54286 .60332 L
.54381 .60332 L
.54476 .60332 L
.54571 .60332 L
.54667 .60332 L
.54762 .60332 L
Mistroke
.54857 .01472 L
.54952 .01472 L
.55048 .01472 L
.55143 .01472 L
.55238 .01472 L
.55333 .01472 L
.55429 .01472 L
.55524 .01472 L
.55619 .01472 L
.55714 .01472 L
.5581 .01472 L
.55905 .01472 L
.56 .01472 L
.56095 .01472 L
.5619 .01472 L
.56286 .01472 L
.56381 .01472 L
.56476 .01472 L
.56571 .01472 L
.56667 .01472 L
.56762 .01472 L
.56857 .01472 L
.56952 .01472 L
.57048 .01472 L
.57143 .01472 L
.57238 .01472 L
.57333 .01472 L
.57429 .01472 L
.57524 .01472 L
.57619 .01472 L
.57714 .01472 L
.5781 .01472 L
.57905 .01472 L
.58 .01472 L
.58095 .01472 L
.5819 .01472 L
.58286 .01472 L
.58381 .01472 L
.58476 .01472 L
.58571 .01472 L
.58667 .01472 L
.58762 .01472 L
.58857 .01472 L
.58952 .01472 L
.59048 .01472 L
.59143 .01472 L
.59238 .01472 L
.59333 .01472 L
.59429 .01472 L
.59524 .01472 L
Mistroke
.59619 .60332 L
.59714 .60332 L
.5981 .60332 L
.59905 .60332 L
.6 .60332 L
.60095 .60332 L
.6019 .60332 L
.60286 .60332 L
.60381 .60332 L
.60476 .60332 L
.60571 .60332 L
.60667 .60332 L
.60762 .60332 L
.60857 .60332 L
.60952 .60332 L
.61048 .60332 L
.61143 .60332 L
.61238 .60332 L
.61333 .60332 L
.61429 .60332 L
.61524 .60332 L
.61619 .60332 L
.61714 .60332 L
.6181 .60332 L
.61905 .60332 L
.62 .60332 L
.62095 .60332 L
.6219 .60332 L
.62286 .60332 L
.62381 .60332 L
.62476 .60332 L
.62571 .60332 L
.62667 .60332 L
.62762 .60332 L
.62857 .60332 L
.62952 .60332 L
.63048 .60332 L
.63143 .60332 L
.63238 .60332 L
.63333 .60332 L
.63429 .60332 L
.63524 .60332 L
.63619 .60332 L
.63714 .60332 L
.6381 .60332 L
.63905 .60332 L
.64 .60332 L
.64095 .60332 L
.6419 .60332 L
.64286 .60332 L
Mistroke
.64381 .01472 L
.64476 .01472 L
.64571 .01472 L
.64667 .01472 L
.64762 .01472 L
.64857 .01472 L
.64952 .01472 L
.65048 .01472 L
.65143 .01472 L
.65238 .01472 L
.65333 .01472 L
.65429 .01472 L
.65524 .01472 L
.65619 .01472 L
.65714 .01472 L
.6581 .01472 L
.65905 .01472 L
.66 .01472 L
.66095 .01472 L
.6619 .01472 L
.66286 .01472 L
.66381 .01472 L
.66476 .01472 L
.66571 .01472 L
.66667 .01472 L
.66762 .01472 L
.66857 .01472 L
.66952 .01472 L
.67048 .01472 L
.67143 .01472 L
.67238 .01472 L
.67333 .01472 L
.67429 .01472 L
.67524 .01472 L
.67619 .01472 L
.67714 .01472 L
.6781 .01472 L
.67905 .01472 L
.68 .01472 L
.68095 .01472 L
.6819 .01472 L
.68286 .01472 L
.68381 .01472 L
.68476 .01472 L
.68571 .01472 L
.68667 .01472 L
.68762 .01472 L
.68857 .01472 L
.68952 .01472 L
.69048 .01472 L
Mistroke
.69143 .60332 L
.69238 .60332 L
.69333 .60332 L
.69429 .60332 L
.69524 .60332 L
.69619 .60332 L
.69714 .60332 L
.6981 .60332 L
.69905 .60332 L
.7 .60332 L
.70095 .60332 L
.7019 .60332 L
.70286 .60332 L
.70381 .60332 L
.70476 .60332 L
.70571 .60332 L
.70667 .60332 L
.70762 .60332 L
.70857 .60332 L
.70952 .60332 L
.71048 .60332 L
.71143 .60332 L
.71238 .60332 L
.71333 .60332 L
.71429 .60332 L
.71524 .60332 L
.71619 .60332 L
.71714 .60332 L
.7181 .60332 L
.71905 .60332 L
.72 .60332 L
.72095 .60332 L
.7219 .60332 L
.72286 .60332 L
.72381 .60332 L
.72476 .60332 L
.72571 .60332 L
.72667 .60332 L
.72762 .60332 L
.72857 .60332 L
.72952 .60332 L
.73048 .60332 L
.73143 .60332 L
.73238 .60332 L
.73333 .60332 L
.73429 .60332 L
.73524 .60332 L
.73619 .60332 L
.73714 .60332 L
.7381 .60332 L
Mistroke
.73905 .01472 L
.74 .01472 L
.74095 .01472 L
.7419 .01472 L
.74286 .01472 L
.74381 .01472 L
.74476 .01472 L
.74571 .01472 L
.74667 .01472 L
.74762 .01472 L
.74857 .01472 L
.74952 .01472 L
.75048 .01472 L
.75143 .01472 L
.75238 .01472 L
.75333 .01472 L
.75429 .01472 L
.75524 .01472 L
.75619 .01472 L
.75714 .01472 L
.7581 .01472 L
.75905 .01472 L
.76 .01472 L
.76095 .01472 L
.7619 .01472 L
.76286 .01472 L
.76381 .01472 L
.76476 .01472 L
.76571 .01472 L
.76667 .01472 L
.76762 .01472 L
.76857 .01472 L
.76952 .01472 L
.77048 .01472 L
.77143 .01472 L
.77238 .01472 L
.77333 .01472 L
.77429 .01472 L
.77524 .01472 L
.77619 .01472 L
.77714 .01472 L
.7781 .01472 L
.77905 .01472 L
.78 .01472 L
.78095 .01472 L
.7819 .01472 L
.78286 .01472 L
.78381 .01472 L
.78476 .01472 L
.78571 .01472 L
Mistroke
.78667 .60332 L
.78762 .60332 L
.78857 .60332 L
.78952 .60332 L
.79048 .60332 L
.79143 .60332 L
.79238 .60332 L
.79333 .60332 L
.79429 .60332 L
.79524 .60332 L
.79619 .60332 L
.79714 .60332 L
.7981 .60332 L
.79905 .60332 L
.8 .60332 L
.80095 .60332 L
.8019 .60332 L
.80286 .60332 L
.80381 .60332 L
.80476 .60332 L
.80571 .60332 L
.80667 .60332 L
.80762 .60332 L
.80857 .60332 L
.80952 .60332 L
.81048 .60332 L
.81143 .60332 L
.81238 .60332 L
.81333 .60332 L
.81429 .60332 L
.81524 .60332 L
.81619 .60332 L
.81714 .60332 L
.8181 .60332 L
.81905 .60332 L
.82 .60332 L
.82095 .60332 L
.8219 .60332 L
.82286 .60332 L
.82381 .60332 L
.82476 .60332 L
.82571 .60332 L
.82667 .60332 L
.82762 .60332 L
.82857 .60332 L
.82952 .60332 L
.83048 .60332 L
.83143 .60332 L
.83238 .60332 L
.83333 .60332 L
Mistroke
.83429 .01472 L
.83524 .01472 L
.83619 .01472 L
.83714 .01472 L
.8381 .01472 L
.83905 .01472 L
.84 .01472 L
.84095 .01472 L
.8419 .01472 L
.84286 .01472 L
.84381 .01472 L
.84476 .01472 L
.84571 .01472 L
.84667 .01472 L
.84762 .01472 L
.84857 .01472 L
.84952 .01472 L
.85048 .01472 L
.85143 .01472 L
.85238 .01472 L
.85333 .01472 L
.85429 .01472 L
.85524 .01472 L
.85619 .01472 L
.85714 .01472 L
.8581 .01472 L
.85905 .01472 L
.86 .01472 L
.86095 .01472 L
.8619 .01472 L
.86286 .01472 L
.86381 .01472 L
.86476 .01472 L
.86571 .01472 L
.86667 .01472 L
.86762 .01472 L
.86857 .01472 L
.86952 .01472 L
.87048 .01472 L
.87143 .01472 L
.87238 .01472 L
.87333 .01472 L
.87429 .01472 L
.87524 .01472 L
.87619 .01472 L
.87714 .01472 L
.8781 .01472 L
.87905 .01472 L
.88 .01472 L
.88095 .01472 L
Mistroke
.8819 .60332 L
.88286 .60332 L
.88381 .60332 L
.88476 .60332 L
.88571 .60332 L
.88667 .60332 L
.88762 .60332 L
.88857 .60332 L
.88952 .60332 L
.89048 .60332 L
.89143 .60332 L
.89238 .60332 L
.89333 .60332 L
.89429 .60332 L
.89524 .60332 L
.89619 .60332 L
.89714 .60332 L
.8981 .60332 L
.89905 .60332 L
.9 .60332 L
.90095 .60332 L
.9019 .60332 L
.90286 .60332 L
.90381 .60332 L
.90476 .60332 L
.90571 .60332 L
.90667 .60332 L
.90762 .60332 L
.90857 .60332 L
.90952 .60332 L
.91048 .60332 L
.91143 .60332 L
.91238 .60332 L
.91333 .60332 L
.91429 .60332 L
.91524 .60332 L
.91619 .60332 L
.91714 .60332 L
.9181 .60332 L
.91905 .60332 L
.92 .60332 L
.92095 .60332 L
.9219 .60332 L
.92286 .60332 L
.92381 .60332 L
.92476 .60332 L
.92571 .60332 L
.92667 .60332 L
.92762 .60332 L
.92857 .60332 L
Mistroke
.92952 .01472 L
.93048 .01472 L
.93143 .01472 L
.93238 .01472 L
.93333 .01472 L
.93429 .01472 L
.93524 .01472 L
.93619 .01472 L
.93714 .01472 L
.9381 .01472 L
.93905 .01472 L
.94 .01472 L
.94095 .01472 L
.9419 .01472 L
.94286 .01472 L
.94381 .01472 L
.94476 .01472 L
.94571 .01472 L
.94667 .01472 L
.94762 .01472 L
.94857 .01472 L
.94952 .01472 L
.95048 .01472 L
.95143 .01472 L
.95238 .01472 L
.95333 .01472 L
.95429 .01472 L
.95524 .01472 L
.95619 .01472 L
.95714 .01472 L
.9581 .01472 L
.95905 .01472 L
.96 .01472 L
.96095 .01472 L
.9619 .01472 L
.96286 .01472 L
.96381 .01472 L
.96476 .01472 L
.96571 .01472 L
.96667 .01472 L
.96762 .01472 L
.96857 .01472 L
.96952 .01472 L
.97048 .01472 L
.97143 .01472 L
.97238 .01472 L
.97333 .01472 L
.97429 .01472 L
.97524 .01472 L
.97619 .30902 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`008?ooool2o`0002Kooooo1Ol0
0003ooooo`;o00001?ooool2o`0002;ooooo0ol00003ooooo`;o00001?ooool2o`0002;ooooo0ol0
0004ooooo`;o00001?ooool2o`00027ooooo0ol00004ooooo`;o00001?ooool2o`0001oooooo0ol0
0004ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`007oooool01?l0003oooooooooool0
000Vooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00007oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Oooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo000Oooooo`04o`000?ooooooooooo`0002Oooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo
1Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Oooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool001oooooo
00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Pooooo`Co00000oooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo0ol00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`007oooool01?l0003oooooooooool0000Uooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00007oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`007oooool01?l0003ooooo
ooooool0000Uooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`00027ooooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00007oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Nooooo`;o00001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool0023ooooo0_l0000Wooooo`?o00001?ooool2o`0000Cooooo0_l0000Sooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`;o00008oooool2o`0000Cooooo0_l00004ooooo`;o00008Oooool3
o`0000Cooooo0_l00004ooooo`;o00008?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`006ooooooo000000Kooooo000Kooooo`0300000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?o
oooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool0noooool00`00003ooooo
ooooo`04ooooo`006oooool00`00003o0000ooooo`0?ooooo`go003o2oooool=o`00o`_ooooo3Ol0
0?l<ooooo`co003o3?ooool=o`00o`_ooooo3Ol00?l;ooooo`go003o2oooool=o`00o`_ooooo3Ol0
0?l<ooooo`co003o1Oooool00ol000000000ooooo`05ooooo`006oooool00`00003oooooooooo`0?
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00`00003oooooooooo`04
ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooo
ooooool01?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00`00003oooooooooo`04ooooo`00
6oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
1?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool01?ooool00`00003oooooooooo`04ooooo`006oooool0
0`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool0
0`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool01?ooool00`00003oooooooooo`04ooooo`006oooool00`00003o
0000ooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00000
0000ooooo`05ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool01?ooool00`00003oooooooooo`04ooooo`006oooool00`00003ooooooooo
o`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00`00003ooooooooo
o`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003o
ooooooooool01?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00`00003oooooooooo`04oooo
o`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00<00000oooooooo
ool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Cooooo00<00000oooooooo
ool01?ooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03
00000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03
00000?oooooooooo00Cooooo0005o`0000;ooooo00Co0000oooooooooooo00001oooool5o`0000Co
oooo00<00000o`000?ooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00;o
oooo0`000006ooooo`001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
00Gooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
00Cooooo00<00000ooooooooool01?ooool000Oooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`000005ooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo0007ooooo`04o`000?ooooooooooo`00
00Wooooo0_l00005ooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo0008ooooo`;o00002oooool00ol0003o
ooooooooo`03ooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`04ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo
000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`04ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo000Koooo
o`0300000?l0003ooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03oooo
o`03o`000000003ooooo00Gooooo000Kooooo`0300000?oooooooooo00oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo000Kooooo`030000
0?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`030000
0?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooo
oooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`0300000?oooooo
oooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?l0003ooooo00oooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`03ooooo`03o`000000003ooooo00Gooooo000Kooooo`0300000?oooooooooo00oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo000K
ooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04
ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo000Kooooo`03
00000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`03
00000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oo
oooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04ooooo`0300000?oo
oooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`04ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?l0003ooooo
00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02ooooo`03o`000000003ooooo
00Gooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo
000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo0008oooo
o`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00<00000ooooooooool03oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00?ooooo00<00000ooooooooool01?ooool0
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oo
oooooooo00Cooooo0005o`0000;ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`04ooooo`0300000?l0003ooooo00oooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool01?l00?oooooooooo
ooooool3000000Kooooo0007ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool0
0oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
0oooool00`00003oooooooooo`04ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001?ooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool00oooool00`00003oooooooooo`04ooooo`001oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00`00003oooooooooo`0?oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool00oooool00`00003oooooooooo`04oooo
o`002?ooool2o`0000Wooooo0ol00005ooooo`0300000?oooooooooo00oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`030000
0?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`030000
0?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooo
oooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooo
oooo00Cooooo000Kooooo`0300000?l0003ooooo00oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`02ooooo`03o`000000003ooooo00Gooooo000Kooooo`0300000?oooooooooo00oo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo000K
ooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03
ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`03
00000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`03
00000?oooooooooo00Cooooo000Kooooo`0300000?l0003ooooo00oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`02ooooo`03o`000000003ooooo00Gooooo000Kooooo`0300000?oo
oooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oo
oooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo
00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo
00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo
000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Koooo
o`0300000?l0003ooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02oooo
o`03o`000000003ooooo00Gooooo000Kooooo`0300000?oooooooooo00oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`030000
0?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`030000
0?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooo
oooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`03ooooo`0300000?oooooo
oooo00Cooooo000Dooooo`;o00001Oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool00oooool00`00003oooooooooo`04ooooo`004oooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo4P0000000ol00?l000000000000900000003o`00o`000000000000T0000000?o003o0000
000000002@0000000ol00?l000000000000900000003o`00o`000000000000T0000000?o003o0000
000000002P0000000ol00?l000000000000800000003o`00o`000000000000X0000000?o003o0000
000000002@0000000ol00?l000000000000900000003o`00o`000000000000T0000000?o003o0000
000000002@0000000ol00?l000000000000900000003o`00o`000000000000T0000000?o003o0000
000000002@0000000ol00?l000000000000900000003o`00o`000000000000T0000000?o003o0000
000000002P0000000ol00?l000000000000900000003o`00o`000000000000@000001_ooool001?o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
013ooooo00<00000ooooooooool01?ooool001?ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?ooool001?o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
013ooooo00<00000ooooooooool01?ooool001Cooooo0_l00005ooooo`0300000?oooooooooo00oo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool04?ooool00`00003oooooooooo`04ooooo`006oooool00`00003ooooo
ooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?ooool001_ooooo00<0
0000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`0300000?oooooooooo00Cooooo000K
ooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool00`00003oooooooooo`04
ooooo`006oooool00`00003o0000ooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00oooooo00?o00000000
0?ooool01Oooool001_ooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`03
00000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
4?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo013ooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool03oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0@ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo
00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool04?ooool00`00003oooooooooo`04ooooo`006oooool00`00003o
ooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?ooool001_ooooo
00<00000o`000?ooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0?ooooo`03o`000000003ooooo00Gooooo
000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool00`00003ooooooooo
o`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000
ooooooooool01?ooool001_ooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@oooo
o`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool04?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00
oooooooooooo013ooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool03ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0@ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooo
oooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Sooooo00?o003oooooooooool04?ooool00`00003oooooooooo`04ooooo`006oooool00`00
003o0000ooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00oooooo00?o000000000?ooool01Oooool001_o
oooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`0300000?oooooooooo00Co
oooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool00`00003ooooo
ooooo`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<0
0000ooooooooool01?ooool001_ooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@
ooooo`0300000?oooooooooo00Cooooo0008ooooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000Cooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`0300000?oooooo
oooo00Cooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?oo
ool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`0300000?l0
003ooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool03_ooool3000000Kooooo0007ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`0?ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo013ooooo00<00000ooooooooool01?ooool000Oooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00<00000ooooooooool03oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0@ooooo`0300000?oooooooooo00Cooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`0300000?oooooooooo00oooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003ooooooooo
ool04?ooool00`00003oooooooooo`04ooooo`002?ooool2o`0000Wooooo0ol00005ooooo`030000
0?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool04?ooool00`00003oooooooooo`04ooooo`006ooo
ool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?oo
ool001_ooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`0300000?oooooo
oooo00Cooooo000Kooooo`0300000?l0003ooooo00oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03oooool00ol0
00000000ooooo`05ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013o
oooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool03oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oooooo
ooooo`0@ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o
003oooooooooool04?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?ooool001_ooooo00<00000oooo
ooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02?ooool00ol00?ooooooooooo`0@ooooo`0300000?oooooooooo00Cooooo000Kooooo`03
00000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool00`00003oooooooooo`04ooooo`00
6oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool0
1?ooool001_ooooo00<00000o`000?ooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0?ooooo`03o`000000
003ooooo00Gooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool0
0`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo
013ooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool03oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?oo
ooooooooo`0@ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo
00?o003oooooooooool04?ooool00`00003oooooooooo`04ooooo`006oooool00`00003ooooooooo
o`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?ooool001_ooooo00<00000
ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`0300000?oooooooooo00Cooooo000Koooo
o`0300000?l0003ooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Sooooo00?o003oooooooooool03oooool00ol000000000ooooo`05oooo
o`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000oooooooo
ool01?ooool001_ooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`030000
0?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04?oo
ool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo013ooooo00<00000ooooooooool01?ooool000Sooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0ol00004ooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool00`00
003oooooooooo`04ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
00?ooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`0300000?oooooooooo
00Cooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00004ooooo`0300000?oooooooooo
00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool04?ooool00`00003oooooooooo`04ooooo`001oooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo00<00000o`000?ooool03oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0>ooooo`<000001_ooool000Oooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`000005ooooo`0300000?oooooooooo00oooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool04?ooool0
0`00003oooooooooo`04ooooo`001oooool01?l0003oooooooooool00009ooooo`;o00001Oooool0
0`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?ooool0
00Sooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool03oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0
0?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0@ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00So
oooo00?o003oooooooooool04?ooool00`00003oooooooooo`04ooooo`006oooool00`00003ooooo
ooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?ooool001_ooooo00<0
0000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`0300000?oooooooooo00Cooooo000K
ooooo`0300000?l0003ooooo00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03oooool00ol000000000ooooo`05
ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000oooo
ooooool01?ooool001_ooooo00<00000ooooooooool03oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0@ooooo`03
00000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo00oooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
4?ooool00`00003oooooooooo`04ooooo`006oooool00`00003oooooooooo`0?ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo013ooooo00<00000ooooooooool01?ooool001_ooooo00<00000ooooooooool03oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02?ooool0
0ol00?ooooooooooo`0@ooooo`0300000?oooooooooo00Cooooo000Kooooo`0300000?oooooooooo
00oooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool04?ooool00`00003oooooooooo`04ooooo`006oooool00`00003o
ooooooooo`0?ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo013ooooo00<00000ooooooooool01?ooool001_ooooo
00<00000o`000?ooool00oooool=o`00o`_ooooo3Ol00?l;ooooo`go003o2oooool=o`00o`cooooo
3Ol00?l;ooooo`go003o2oooool=o`00o`_ooooo3Ol00?l;ooooo`go003o3?ooool<o`00oa7ooooo
00?o000000000?ooool01Oooool001_ooooo00<00000ooooooooool0noooool00`00003ooooooooo
o`04ooooo`006oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo02gooooo00<00000
ooooooooool0;Oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo02gooooo00<00000
ooooooooool0;_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo000Koooo
o`0300000?oooooooooo00?ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`0300000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool001_oooooo`000006ooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-137.394, -0.632785, 4.136, \
0.00669218}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete spectrum: Fast Fourier Transform (FFT)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ Fourier[signal];\)\), "\n", 
    \(\(g1 = 
        DiscreteListPlot[FourierRearrange[Abs[fft], sampleRate], Red, 
          PlotRange \[Rule] All, \ Frame \[Rule] True];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499523 0.000953334 0.0147151 0.00184894 [
[.11819 -0.0125 -12 -9 ]
[.11819 -0.0125 12 0 ]
[.30886 -0.0125 -12 -9 ]
[.30886 -0.0125 12 0 ]
[.49952 -0.0125 -3 -9 ]
[.49952 -0.0125 3 0 ]
[.69019 -0.0125 -9 -9 ]
[.69019 -0.0125 9 0 ]
[.88086 -0.0125 -9 -9 ]
[.88086 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .10716 -12 -4.5 ]
[-0.0125 .10716 0 4.5 ]
[-0.0125 .19961 -18 -4.5 ]
[-0.0125 .19961 0 4.5 ]
[-0.0125 .29206 -18 -4.5 ]
[-0.0125 .29206 0 4.5 ]
[-0.0125 .3845 -18 -4.5 ]
[-0.0125 .3845 0 4.5 ]
[-0.0125 .47695 -18 -4.5 ]
[-0.0125 .47695 0 4.5 ]
[-0.0125 .5694 -18 -4.5 ]
[-0.0125 .5694 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11819 0 m
.11819 .00625 L
s
[(-400)] .11819 -0.0125 0 1 Mshowa
.30886 0 m
.30886 .00625 L
s
[(-200)] .30886 -0.0125 0 1 Mshowa
.49952 0 m
.49952 .00625 L
s
[(0)] .49952 -0.0125 0 1 Mshowa
.69019 0 m
.69019 .00625 L
s
[(200)] .69019 -0.0125 0 1 Mshowa
.88086 0 m
.88086 .00625 L
s
[(400)] .88086 -0.0125 0 1 Mshowa
.125 Mabswid
.16586 0 m
.16586 .00375 L
s
.21352 0 m
.21352 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.40419 0 m
.40419 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.59486 0 m
.59486 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.78552 0 m
.78552 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.07052 0 m
.07052 .00375 L
s
.02286 0 m
.02286 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .10716 m
.00625 .10716 L
s
[(50)] -0.0125 .10716 1 0 Mshowa
0 .19961 m
.00625 .19961 L
s
[(100)] -0.0125 .19961 1 0 Mshowa
0 .29206 m
.00625 .29206 L
s
[(150)] -0.0125 .29206 1 0 Mshowa
0 .3845 m
.00625 .3845 L
s
[(200)] -0.0125 .3845 1 0 Mshowa
0 .47695 m
.00625 .47695 L
s
[(250)] -0.0125 .47695 1 0 Mshowa
0 .5694 m
.00625 .5694 L
s
[(300)] -0.0125 .5694 1 0 Mshowa
.125 Mabswid
0 .0332 m
.00375 .0332 L
s
0 .05169 m
.00375 .05169 L
s
0 .07018 m
.00375 .07018 L
s
0 .08867 m
.00375 .08867 L
s
0 .12565 m
.00375 .12565 L
s
0 .14414 m
.00375 .14414 L
s
0 .16263 m
.00375 .16263 L
s
0 .18112 m
.00375 .18112 L
s
0 .2181 m
.00375 .2181 L
s
0 .23659 m
.00375 .23659 L
s
0 .25508 m
.00375 .25508 L
s
0 .27357 m
.00375 .27357 L
s
0 .31055 m
.00375 .31055 L
s
0 .32903 m
.00375 .32903 L
s
0 .34752 m
.00375 .34752 L
s
0 .36601 m
.00375 .36601 L
s
0 .40299 m
.00375 .40299 L
s
0 .42148 m
.00375 .42148 L
s
0 .43997 m
.00375 .43997 L
s
0 .45846 m
.00375 .45846 L
s
0 .49544 m
.00375 .49544 L
s
0 .51393 m
.00375 .51393 L
s
0 .53242 m
.00375 .53242 L
s
0 .55091 m
.00375 .55091 L
s
0 .58789 m
.00375 .58789 L
s
0 .60638 m
.00375 .60638 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11819 .61178 m
.11819 .61803 L
s
.30886 .61178 m
.30886 .61803 L
s
.49952 .61178 m
.49952 .61803 L
s
.69019 .61178 m
.69019 .61803 L
s
.88086 .61178 m
.88086 .61803 L
s
.125 Mabswid
.16586 .61428 m
.16586 .61803 L
s
.21352 .61428 m
.21352 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.40419 .61428 m
.40419 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.59486 .61428 m
.59486 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.78552 .61428 m
.78552 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.07052 .61428 m
.07052 .61803 L
s
.02286 .61428 m
.02286 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .10716 m
1 .10716 L
s
.99375 .19961 m
1 .19961 L
s
.99375 .29206 m
1 .29206 L
s
.99375 .3845 m
1 .3845 L
s
.99375 .47695 m
1 .47695 L
s
.99375 .5694 m
1 .5694 L
s
.125 Mabswid
.99625 .0332 m
1 .0332 L
s
.99625 .05169 m
1 .05169 L
s
.99625 .07018 m
1 .07018 L
s
.99625 .08867 m
1 .08867 L
s
.99625 .12565 m
1 .12565 L
s
.99625 .14414 m
1 .14414 L
s
.99625 .16263 m
1 .16263 L
s
.99625 .18112 m
1 .18112 L
s
.99625 .2181 m
1 .2181 L
s
.99625 .23659 m
1 .23659 L
s
.99625 .25508 m
1 .25508 L
s
.99625 .27357 m
1 .27357 L
s
.99625 .31055 m
1 .31055 L
s
.99625 .32903 m
1 .32903 L
s
.99625 .34752 m
1 .34752 L
s
.99625 .36601 m
1 .36601 L
s
.99625 .40299 m
1 .40299 L
s
.99625 .42148 m
1 .42148 L
s
.99625 .43997 m
1 .43997 L
s
.99625 .45846 m
1 .45846 L
s
.99625 .49544 m
1 .49544 L
s
.99625 .51393 m
1 .51393 L
s
.99625 .53242 m
1 .53242 L
s
.99625 .55091 m
1 .55091 L
s
.99625 .58789 m
1 .58789 L
s
.99625 .60638 m
1 .60638 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01564 L
s
.02476 .01472 m
.02476 .01564 L
s
.02572 .01472 m
.02572 .01564 L
s
.02667 .01472 m
.02667 .01564 L
s
.02762 .01472 m
.02762 .01564 L
s
.02858 .01472 m
.02858 .01564 L
s
.02953 .01472 m
.02953 .01564 L
s
.03048 .01472 m
.03048 .01564 L
s
.03144 .01472 m
.03144 .01564 L
s
.03239 .01472 m
.03239 .03229 L
s
.03334 .01472 m
.03334 .01564 L
s
.0343 .01472 m
.0343 .01564 L
s
.03525 .01472 m
.03525 .01564 L
s
.0362 .01472 m
.0362 .01564 L
s
.03716 .01472 m
.03716 .01564 L
s
.03811 .01472 m
.03811 .01564 L
s
.03906 .01472 m
.03906 .01564 L
s
.04002 .01472 m
.04002 .01564 L
s
.04097 .01472 m
.04097 .01564 L
s
.04192 .01472 m
.04192 .01564 L
s
.04288 .01472 m
.04288 .01564 L
s
.04383 .01472 m
.04383 .01564 L
s
.04478 .01472 m
.04478 .01564 L
s
.04574 .01472 m
.04574 .01564 L
s
.04669 .01472 m
.04669 .01564 L
s
.04764 .01472 m
.04764 .01564 L
s
.0486 .01472 m
.0486 .01564 L
s
.04955 .01472 m
.04955 .01564 L
s
.0505 .01472 m
.0505 .01564 L
s
.05146 .01472 m
.05146 .03237 L
s
.05241 .01472 m
.05241 .01564 L
s
.05336 .01472 m
.05336 .01564 L
s
.05432 .01472 m
.05432 .01564 L
s
.05527 .01472 m
.05527 .01564 L
s
.05622 .01472 m
.05622 .01564 L
s
.05718 .01472 m
.05718 .01564 L
s
.05813 .01472 m
.05813 .01564 L
s
.05908 .01472 m
.05908 .01564 L
s
.06004 .01472 m
.06004 .01564 L
s
.06099 .01472 m
.06099 .01564 L
s
.06194 .01472 m
.06194 .01564 L
s
.0629 .01472 m
.0629 .01564 L
s
.06385 .01472 m
.06385 .01564 L
s
.0648 .01472 m
.0648 .01564 L
s
.06576 .01472 m
.06576 .01564 L
s
.06671 .01472 m
.06671 .01564 L
s
.06766 .01472 m
.06766 .01564 L
s
.06862 .01472 m
.06862 .01564 L
s
.06957 .01472 m
.06957 .01564 L
s
.07052 .01472 m
.07052 .03252 L
s
.07148 .01472 m
.07148 .01564 L
s
.07243 .01472 m
.07243 .01564 L
s
.07338 .01472 m
.07338 .01564 L
s
.07434 .01472 m
.07434 .01564 L
s
.07529 .01472 m
.07529 .01564 L
s
.07624 .01472 m
.07624 .01564 L
s
.0772 .01472 m
.0772 .01564 L
s
.07815 .01472 m
.07815 .01564 L
s
.0791 .01472 m
.0791 .01564 L
s
.08006 .01472 m
.08006 .01564 L
s
.08101 .01472 m
.08101 .01564 L
s
.08196 .01472 m
.08196 .01564 L
s
.08292 .01472 m
.08292 .01564 L
s
.08387 .01472 m
.08387 .01564 L
s
.08482 .01472 m
.08482 .01564 L
s
.08578 .01472 m
.08578 .01564 L
s
.08673 .01472 m
.08673 .01564 L
s
.08768 .01472 m
.08768 .01564 L
s
.08864 .01472 m
.08864 .01564 L
s
.08959 .01472 m
.08959 .03276 L
s
.09054 .01472 m
.09054 .01564 L
s
.0915 .01472 m
.0915 .01564 L
s
.09245 .01472 m
.09245 .01564 L
s
.0934 .01472 m
.0934 .01564 L
s
.09436 .01472 m
.09436 .01564 L
s
.09531 .01472 m
.09531 .01564 L
s
.09626 .01472 m
.09626 .01564 L
s
.09722 .01472 m
.09722 .01564 L
s
.09817 .01472 m
.09817 .01564 L
s
.09912 .01472 m
.09912 .01564 L
s
.10008 .01472 m
.10008 .01564 L
s
.10103 .01472 m
.10103 .01564 L
s
.10198 .01472 m
.10198 .01564 L
s
.10294 .01472 m
.10294 .01564 L
s
.10389 .01472 m
.10389 .01564 L
s
.10484 .01472 m
.10484 .01564 L
s
.1058 .01472 m
.1058 .01564 L
s
.10675 .01472 m
.10675 .01564 L
s
.1077 .01472 m
.1077 .01564 L
s
.10866 .01472 m
.10866 .03308 L
s
.10961 .01472 m
.10961 .01564 L
s
.11056 .01472 m
.11056 .01564 L
s
.11152 .01472 m
.11152 .01564 L
s
.11247 .01472 m
.11247 .01564 L
s
.11342 .01472 m
.11342 .01564 L
s
.11438 .01472 m
.11438 .01564 L
s
.11533 .01472 m
.11533 .01564 L
s
.11628 .01472 m
.11628 .01564 L
s
.11724 .01472 m
.11724 .01564 L
s
.11819 .01472 m
.11819 .01564 L
s
.11914 .01472 m
.11914 .01564 L
s
.1201 .01472 m
.1201 .01564 L
s
.12105 .01472 m
.12105 .01564 L
s
.122 .01472 m
.122 .01564 L
s
.12296 .01472 m
.12296 .01564 L
s
.12391 .01472 m
.12391 .01564 L
s
.12486 .01472 m
.12486 .01564 L
s
.12582 .01472 m
.12582 .01564 L
s
.12677 .01472 m
.12677 .01564 L
s
.12772 .01472 m
.12772 .0335 L
s
.12868 .01472 m
.12868 .01564 L
s
.12963 .01472 m
.12963 .01564 L
s
.13058 .01472 m
.13058 .01564 L
s
.13154 .01472 m
.13154 .01564 L
s
.13249 .01472 m
.13249 .01564 L
s
.13344 .01472 m
.13344 .01564 L
s
.1344 .01472 m
.1344 .01564 L
s
.13535 .01472 m
.13535 .01564 L
s
.1363 .01472 m
.1363 .01564 L
s
.13726 .01472 m
.13726 .01564 L
s
.13821 .01472 m
.13821 .01564 L
s
.13916 .01472 m
.13916 .01564 L
s
.14012 .01472 m
.14012 .01564 L
s
.14107 .01472 m
.14107 .01564 L
s
.14202 .01472 m
.14202 .01564 L
s
.14298 .01472 m
.14298 .01564 L
s
.14393 .01472 m
.14393 .01564 L
s
.14488 .01472 m
.14488 .01564 L
s
.14584 .01472 m
.14584 .01564 L
s
.14679 .01472 m
.14679 .03402 L
s
.14774 .01472 m
.14774 .01564 L
s
.1487 .01472 m
.1487 .01564 L
s
.14965 .01472 m
.14965 .01564 L
s
.1506 .01472 m
.1506 .01564 L
s
.15156 .01472 m
.15156 .01564 L
s
.15251 .01472 m
.15251 .01564 L
s
.15346 .01472 m
.15346 .01564 L
s
.15442 .01472 m
.15442 .01564 L
s
.15537 .01472 m
.15537 .01564 L
s
.15632 .01472 m
.15632 .01564 L
s
.15728 .01472 m
.15728 .01564 L
s
.15823 .01472 m
.15823 .01564 L
s
.15918 .01472 m
.15918 .01564 L
s
.16014 .01472 m
.16014 .01564 L
s
.16109 .01472 m
.16109 .01564 L
s
.16204 .01472 m
.16204 .01564 L
s
.163 .01472 m
.163 .01564 L
s
.16395 .01472 m
.16395 .01564 L
s
.1649 .01472 m
.1649 .01564 L
s
.16586 .01472 m
.16586 .03465 L
s
.16681 .01472 m
.16681 .01564 L
s
.16776 .01472 m
.16776 .01564 L
s
.16872 .01472 m
.16872 .01564 L
s
.16967 .01472 m
.16967 .01564 L
s
.17062 .01472 m
.17062 .01564 L
s
.17158 .01472 m
.17158 .01564 L
s
.17253 .01472 m
.17253 .01564 L
s
.17348 .01472 m
.17348 .01564 L
s
.17444 .01472 m
.17444 .01564 L
s
.17539 .01472 m
.17539 .01564 L
s
.17634 .01472 m
.17634 .01564 L
s
.1773 .01472 m
.1773 .01564 L
s
.17825 .01472 m
.17825 .01564 L
s
.1792 .01472 m
.1792 .01564 L
s
.18016 .01472 m
.18016 .01564 L
s
.18111 .01472 m
.18111 .01564 L
s
.18206 .01472 m
.18206 .01564 L
s
.18302 .01472 m
.18302 .01564 L
s
.18397 .01472 m
.18397 .01564 L
s
.18492 .01472 m
.18492 .03541 L
s
.18588 .01472 m
.18588 .01564 L
s
.18683 .01472 m
.18683 .01564 L
s
.18778 .01472 m
.18778 .01564 L
s
.18874 .01472 m
.18874 .01564 L
s
.18969 .01472 m
.18969 .01564 L
s
.19064 .01472 m
.19064 .01564 L
s
.1916 .01472 m
.1916 .01564 L
s
.19255 .01472 m
.19255 .01564 L
s
.1935 .01472 m
.1935 .01564 L
s
.19446 .01472 m
.19446 .01564 L
s
.19541 .01472 m
.19541 .01564 L
s
.19636 .01472 m
.19636 .01564 L
s
.19732 .01472 m
.19732 .01564 L
s
.19827 .01472 m
.19827 .01564 L
s
.19922 .01472 m
.19922 .01564 L
s
.20018 .01472 m
.20018 .01564 L
s
.20113 .01472 m
.20113 .01564 L
s
.20208 .01472 m
.20208 .01564 L
s
.20304 .01472 m
.20304 .01564 L
s
.20399 .01472 m
.20399 .03631 L
s
.20494 .01472 m
.20494 .01564 L
s
.2059 .01472 m
.2059 .01564 L
s
.20685 .01472 m
.20685 .01564 L
s
.2078 .01472 m
.2078 .01564 L
s
.20876 .01472 m
.20876 .01564 L
s
.20971 .01472 m
.20971 .01564 L
s
.21066 .01472 m
.21066 .01564 L
s
.21162 .01472 m
.21162 .01564 L
s
.21257 .01472 m
.21257 .01564 L
s
.21352 .01472 m
.21352 .01564 L
s
.21448 .01472 m
.21448 .01564 L
s
.21543 .01472 m
.21543 .01564 L
s
.21638 .01472 m
.21638 .01564 L
s
.21734 .01472 m
.21734 .01564 L
s
.21829 .01472 m
.21829 .01564 L
s
.21924 .01472 m
.21924 .01564 L
s
.2202 .01472 m
.2202 .01564 L
s
.22115 .01472 m
.22115 .01564 L
s
.2221 .01472 m
.2221 .01564 L
s
.22306 .01472 m
.22306 .03739 L
s
.22401 .01472 m
.22401 .01564 L
s
.22496 .01472 m
.22496 .01564 L
s
.22592 .01472 m
.22592 .01564 L
s
.22687 .01472 m
.22687 .01564 L
s
.22782 .01472 m
.22782 .01564 L
s
.22878 .01472 m
.22878 .01564 L
s
.22973 .01472 m
.22973 .01564 L
s
.23068 .01472 m
.23068 .01564 L
s
.23164 .01472 m
.23164 .01564 L
s
.23259 .01472 m
.23259 .01564 L
s
.23354 .01472 m
.23354 .01564 L
s
.2345 .01472 m
.2345 .01564 L
s
.23545 .01472 m
.23545 .01564 L
s
.2364 .01472 m
.2364 .01564 L
s
.23736 .01472 m
.23736 .01564 L
s
.23831 .01472 m
.23831 .01564 L
s
.23926 .01472 m
.23926 .01564 L
s
.24022 .01472 m
.24022 .01564 L
s
.24117 .01472 m
.24117 .01564 L
s
.24212 .01472 m
.24212 .03868 L
s
.24308 .01472 m
.24308 .01564 L
s
.24403 .01472 m
.24403 .01564 L
s
.24498 .01472 m
.24498 .01564 L
s
.24594 .01472 m
.24594 .01564 L
s
.24689 .01472 m
.24689 .01564 L
s
.24784 .01472 m
.24784 .01564 L
s
.2488 .01472 m
.2488 .01564 L
s
.24975 .01472 m
.24975 .01564 L
s
.2507 .01472 m
.2507 .01564 L
s
.25166 .01472 m
.25166 .01564 L
s
.25261 .01472 m
.25261 .01564 L
s
.25356 .01472 m
.25356 .01564 L
s
.25452 .01472 m
.25452 .01564 L
s
.25547 .01472 m
.25547 .01564 L
s
.25642 .01472 m
.25642 .01564 L
s
.25738 .01472 m
.25738 .01564 L
s
.25833 .01472 m
.25833 .01564 L
s
.25928 .01472 m
.25928 .01564 L
s
.26024 .01472 m
.26024 .01564 L
s
.26119 .01472 m
.26119 .04022 L
s
.26214 .01472 m
.26214 .01564 L
s
.2631 .01472 m
.2631 .01564 L
s
.26405 .01472 m
.26405 .01564 L
s
.265 .01472 m
.265 .01564 L
s
.26596 .01472 m
.26596 .01564 L
s
.26691 .01472 m
.26691 .01564 L
s
.26786 .01472 m
.26786 .01564 L
s
.26882 .01472 m
.26882 .01564 L
s
.26977 .01472 m
.26977 .01564 L
s
.27072 .01472 m
.27072 .01564 L
s
.27168 .01472 m
.27168 .01564 L
s
.27263 .01472 m
.27263 .01564 L
s
.27358 .01472 m
.27358 .01564 L
s
.27454 .01472 m
.27454 .01564 L
s
.27549 .01472 m
.27549 .01564 L
s
.27644 .01472 m
.27644 .01564 L
s
.2774 .01472 m
.2774 .01564 L
s
.27835 .01472 m
.27835 .01564 L
s
.2793 .01472 m
.2793 .01564 L
s
.28026 .01472 m
.28026 .04207 L
s
.28121 .01472 m
.28121 .01564 L
s
.28216 .01472 m
.28216 .01564 L
s
.28312 .01472 m
.28312 .01564 L
s
.28407 .01472 m
.28407 .01564 L
s
.28502 .01472 m
.28502 .01564 L
s
.28598 .01472 m
.28598 .01564 L
s
.28693 .01472 m
.28693 .01564 L
s
.28788 .01472 m
.28788 .01564 L
s
.28884 .01472 m
.28884 .01564 L
s
.28979 .01472 m
.28979 .01564 L
s
.29074 .01472 m
.29074 .01564 L
s
.2917 .01472 m
.2917 .01564 L
s
.29265 .01472 m
.29265 .01564 L
s
.2936 .01472 m
.2936 .01564 L
s
.29456 .01472 m
.29456 .01564 L
s
.29551 .01472 m
.29551 .01564 L
s
.29646 .01472 m
.29646 .01564 L
s
.29742 .01472 m
.29742 .01564 L
s
.29837 .01472 m
.29837 .01564 L
s
.29932 .01472 m
.29932 .04432 L
s
.30028 .01472 m
.30028 .01564 L
s
.30123 .01472 m
.30123 .01564 L
s
.30218 .01472 m
.30218 .01564 L
s
.30314 .01472 m
.30314 .01564 L
s
.30409 .01472 m
.30409 .01564 L
s
.30504 .01472 m
.30504 .01564 L
s
.306 .01472 m
.306 .01564 L
s
.30695 .01472 m
.30695 .01564 L
s
.3079 .01472 m
.3079 .01564 L
s
.30886 .01472 m
.30886 .01564 L
s
.30981 .01472 m
.30981 .01564 L
s
.31076 .01472 m
.31076 .01564 L
s
.31172 .01472 m
.31172 .01564 L
s
.31267 .01472 m
.31267 .01564 L
s
.31362 .01472 m
.31362 .01564 L
s
.31458 .01472 m
.31458 .01564 L
s
.31553 .01472 m
.31553 .01564 L
s
.31648 .01472 m
.31648 .01564 L
s
.31744 .01472 m
.31744 .01564 L
s
.31839 .01472 m
.31839 .0471 L
s
.31934 .01472 m
.31934 .01564 L
s
.3203 .01472 m
.3203 .01564 L
s
.32125 .01472 m
.32125 .01564 L
s
.3222 .01472 m
.3222 .01564 L
s
.32316 .01472 m
.32316 .01564 L
s
.32411 .01472 m
.32411 .01564 L
s
.32506 .01472 m
.32506 .01564 L
s
.32602 .01472 m
.32602 .01564 L
s
.32697 .01472 m
.32697 .01564 L
s
.32792 .01472 m
.32792 .01564 L
s
.32888 .01472 m
.32888 .01564 L
s
.32983 .01472 m
.32983 .01564 L
s
.33078 .01472 m
.33078 .01564 L
s
.33174 .01472 m
.33174 .01564 L
s
.33269 .01472 m
.33269 .01564 L
s
.33364 .01472 m
.33364 .01564 L
s
.3346 .01472 m
.3346 .01564 L
s
.33555 .01472 m
.33555 .01564 L
s
.3365 .01472 m
.3365 .01564 L
s
.33746 .01472 m
.33746 .05058 L
s
.33841 .01472 m
.33841 .01564 L
s
.33936 .01472 m
.33936 .01564 L
s
.34032 .01472 m
.34032 .01564 L
s
.34127 .01472 m
.34127 .01564 L
s
.34222 .01472 m
.34222 .01564 L
s
.34318 .01472 m
.34318 .01564 L
s
.34413 .01472 m
.34413 .01564 L
s
.34508 .01472 m
.34508 .01564 L
s
.34604 .01472 m
.34604 .01564 L
s
.34699 .01472 m
.34699 .01564 L
s
.34794 .01472 m
.34794 .01564 L
s
.3489 .01472 m
.3489 .01564 L
s
.34985 .01472 m
.34985 .01564 L
s
.3508 .01472 m
.3508 .01564 L
s
.35176 .01472 m
.35176 .01564 L
s
.35271 .01472 m
.35271 .01564 L
s
.35366 .01472 m
.35366 .01564 L
s
.35462 .01472 m
.35462 .01564 L
s
.35557 .01472 m
.35557 .01564 L
s
.35652 .01472 m
.35652 .05503 L
s
.35748 .01472 m
.35748 .01564 L
s
.35843 .01472 m
.35843 .01564 L
s
.35938 .01472 m
.35938 .01564 L
s
.36034 .01472 m
.36034 .01564 L
s
.36129 .01472 m
.36129 .01564 L
s
.36224 .01472 m
.36224 .01564 L
s
.3632 .01472 m
.3632 .01564 L
s
.36415 .01472 m
.36415 .01564 L
s
.3651 .01472 m
.3651 .01564 L
s
.36606 .01472 m
.36606 .01564 L
s
.36701 .01472 m
.36701 .01564 L
s
.36796 .01472 m
.36796 .01564 L
s
.36892 .01472 m
.36892 .01564 L
s
.36987 .01472 m
.36987 .01564 L
s
.37082 .01472 m
.37082 .01564 L
s
.37178 .01472 m
.37178 .01564 L
s
.37273 .01472 m
.37273 .01564 L
s
.37368 .01472 m
.37368 .01564 L
s
.37464 .01472 m
.37464 .01564 L
s
.37559 .01472 m
.37559 .06091 L
s
.37654 .01472 m
.37654 .01564 L
s
.3775 .01472 m
.3775 .01564 L
s
.37845 .01472 m
.37845 .01564 L
s
.3794 .01472 m
.3794 .01564 L
s
.38036 .01472 m
.38036 .01564 L
s
.38131 .01472 m
.38131 .01564 L
s
.38226 .01472 m
.38226 .01564 L
s
.38322 .01472 m
.38322 .01564 L
s
.38417 .01472 m
.38417 .01564 L
s
.38512 .01472 m
.38512 .01564 L
s
.38608 .01472 m
.38608 .01564 L
s
.38703 .01472 m
.38703 .01564 L
s
.38798 .01472 m
.38798 .01564 L
s
.38894 .01472 m
.38894 .01564 L
s
.38989 .01472 m
.38989 .01564 L
s
.39084 .01472 m
.39084 .01564 L
s
.3918 .01472 m
.3918 .01564 L
s
.39275 .01472 m
.39275 .01564 L
s
.3937 .01472 m
.3937 .01564 L
s
.39466 .01472 m
.39466 .06899 L
s
.39561 .01472 m
.39561 .01564 L
s
.39656 .01472 m
.39656 .01564 L
s
.39752 .01472 m
.39752 .01564 L
s
.39847 .01472 m
.39847 .01564 L
s
.39942 .01472 m
.39942 .01564 L
s
.40038 .01472 m
.40038 .01564 L
s
.40133 .01472 m
.40133 .01564 L
s
.40228 .01472 m
.40228 .01564 L
s
.40324 .01472 m
.40324 .01564 L
s
.40419 .01472 m
.40419 .01564 L
s
.40514 .01472 m
.40514 .01564 L
s
.4061 .01472 m
.4061 .01564 L
s
.40705 .01472 m
.40705 .01564 L
s
.408 .01472 m
.408 .01564 L
s
.40896 .01472 m
.40896 .01564 L
s
.40991 .01472 m
.40991 .01564 L
s
.41086 .01472 m
.41086 .01564 L
s
.41182 .01472 m
.41182 .01564 L
s
.41277 .01472 m
.41277 .01564 L
s
.41372 .01472 m
.41372 .08074 L
s
.41468 .01472 m
.41468 .01564 L
s
.41563 .01472 m
.41563 .01564 L
s
.41658 .01472 m
.41658 .01564 L
s
.41754 .01472 m
.41754 .01564 L
s
.41849 .01472 m
.41849 .01564 L
s
.41944 .01472 m
.41944 .01564 L
s
.4204 .01472 m
.4204 .01564 L
s
.42135 .01472 m
.42135 .01564 L
s
.4223 .01472 m
.4223 .01564 L
s
.42326 .01472 m
.42326 .01564 L
s
.42421 .01472 m
.42421 .01564 L
s
.42516 .01472 m
.42516 .01564 L
s
.42612 .01472 m
.42612 .01564 L
s
.42707 .01472 m
.42707 .01564 L
s
.42802 .01472 m
.42802 .01564 L
s
.42898 .01472 m
.42898 .01564 L
s
.42993 .01472 m
.42993 .01564 L
s
.43088 .01472 m
.43088 .01564 L
s
.43184 .01472 m
.43184 .01564 L
s
.43279 .01472 m
.43279 .09928 L
s
.43374 .01472 m
.43374 .01564 L
s
.4347 .01472 m
.4347 .01564 L
s
.43565 .01472 m
.43565 .01564 L
s
.4366 .01472 m
.4366 .01564 L
s
.43756 .01472 m
.43756 .01564 L
s
.43851 .01472 m
.43851 .01564 L
s
.43946 .01472 m
.43946 .01564 L
s
.44042 .01472 m
.44042 .01564 L
s
.44137 .01472 m
.44137 .01564 L
s
.44232 .01472 m
.44232 .01564 L
s
.44328 .01472 m
.44328 .01564 L
s
.44423 .01472 m
.44423 .01564 L
s
.44518 .01472 m
.44518 .01564 L
s
.44614 .01472 m
.44614 .01564 L
s
.44709 .01472 m
.44709 .01564 L
s
.44804 .01472 m
.44804 .01564 L
s
.449 .01472 m
.449 .01564 L
s
.44995 .01472 m
.44995 .01564 L
s
.4509 .01472 m
.4509 .01564 L
s
.45186 .01472 m
.45186 .13277 L
s
.45281 .01472 m
.45281 .01564 L
s
.45376 .01472 m
.45376 .01564 L
s
.45472 .01472 m
.45472 .01564 L
s
.45567 .01472 m
.45567 .01564 L
s
.45662 .01472 m
.45662 .01564 L
s
.45758 .01472 m
.45758 .01564 L
s
.45853 .01472 m
.45853 .01564 L
s
.45948 .01472 m
.45948 .01564 L
s
.46044 .01472 m
.46044 .01564 L
s
.46139 .01472 m
.46139 .01564 L
s
.46234 .01472 m
.46234 .01564 L
s
.4633 .01472 m
.4633 .01564 L
s
.46425 .01472 m
.46425 .01564 L
s
.4652 .01472 m
.4652 .01564 L
s
.46616 .01472 m
.46616 .01564 L
s
.46711 .01472 m
.46711 .01564 L
s
.46806 .01472 m
.46806 .01564 L
s
.46902 .01472 m
.46902 .01564 L
s
.46997 .01472 m
.46997 .01564 L
s
.47092 .01472 m
.47092 .2111 L
s
.47188 .01472 m
.47188 .01564 L
s
.47283 .01472 m
.47283 .01564 L
s
.47378 .01472 m
.47378 .01564 L
s
.47474 .01472 m
.47474 .01564 L
s
.47569 .01472 m
.47569 .01564 L
s
.47664 .01472 m
.47664 .01564 L
s
.4776 .01472 m
.4776 .01564 L
s
.47855 .01472 m
.47855 .01564 L
s
.4795 .01472 m
.4795 .01564 L
s
.48046 .01472 m
.48046 .01564 L
s
.48141 .01472 m
.48141 .01564 L
s
.48236 .01472 m
.48236 .01564 L
s
.48332 .01472 m
.48332 .01564 L
s
.48427 .01472 m
.48427 .01564 L
s
.48522 .01472 m
.48522 .01564 L
s
.48618 .01472 m
.48618 .01564 L
s
.48713 .01472 m
.48713 .01564 L
s
.48808 .01472 m
.48808 .01564 L
s
.48904 .01472 m
.48904 .01564 L
s
.48999 .01472 m
.48999 .60332 L
s
.49094 .01472 m
.49094 .01564 L
s
.4919 .01472 m
.4919 .01564 L
s
.49285 .01472 m
.49285 .01564 L
s
.4938 .01472 m
.4938 .01564 L
s
.49476 .01472 m
.49476 .01564 L
s
.49571 .01472 m
.49571 .01564 L
s
.49666 .01472 m
.49666 .01564 L
s
.49762 .01472 m
.49762 .01564 L
s
.49857 .01472 m
.49857 .01564 L
s
.49952 .01472 m
.49952 .01564 L
s
.50048 .01472 m
.50048 .01564 L
s
.50143 .01472 m
.50143 .01564 L
s
.50238 .01472 m
.50238 .01564 L
s
.50334 .01472 m
.50334 .01564 L
s
.50429 .01472 m
.50429 .01564 L
s
.50524 .01472 m
.50524 .01564 L
s
.5062 .01472 m
.5062 .01564 L
s
.50715 .01472 m
.50715 .01564 L
s
.5081 .01472 m
.5081 .01564 L
s
.50906 .01472 m
.50906 .60332 L
s
.51001 .01472 m
.51001 .01564 L
s
.51096 .01472 m
.51096 .01564 L
s
.51192 .01472 m
.51192 .01564 L
s
.51287 .01472 m
.51287 .01564 L
s
.51382 .01472 m
.51382 .01564 L
s
.51478 .01472 m
.51478 .01564 L
s
.51573 .01472 m
.51573 .01564 L
s
.51668 .01472 m
.51668 .01564 L
s
.51764 .01472 m
.51764 .01564 L
s
.51859 .01472 m
.51859 .01564 L
s
.51954 .01472 m
.51954 .01564 L
s
.5205 .01472 m
.5205 .01564 L
s
.52145 .01472 m
.52145 .01564 L
s
.5224 .01472 m
.5224 .01564 L
s
.52336 .01472 m
.52336 .01564 L
s
.52431 .01472 m
.52431 .01564 L
s
.52526 .01472 m
.52526 .01564 L
s
.52622 .01472 m
.52622 .01564 L
s
.52717 .01472 m
.52717 .01564 L
s
.52812 .01472 m
.52812 .2111 L
s
.52908 .01472 m
.52908 .01564 L
s
.53003 .01472 m
.53003 .01564 L
s
.53098 .01472 m
.53098 .01564 L
s
.53194 .01472 m
.53194 .01564 L
s
.53289 .01472 m
.53289 .01564 L
s
.53384 .01472 m
.53384 .01564 L
s
.5348 .01472 m
.5348 .01564 L
s
.53575 .01472 m
.53575 .01564 L
s
.5367 .01472 m
.5367 .01564 L
s
.53766 .01472 m
.53766 .01564 L
s
.53861 .01472 m
.53861 .01564 L
s
.53956 .01472 m
.53956 .01564 L
s
.54052 .01472 m
.54052 .01564 L
s
.54147 .01472 m
.54147 .01564 L
s
.54242 .01472 m
.54242 .01564 L
s
.54338 .01472 m
.54338 .01564 L
s
.54433 .01472 m
.54433 .01564 L
s
.54528 .01472 m
.54528 .01564 L
s
.54624 .01472 m
.54624 .01564 L
s
.54719 .01472 m
.54719 .13277 L
s
.54814 .01472 m
.54814 .01564 L
s
.5491 .01472 m
.5491 .01564 L
s
.55005 .01472 m
.55005 .01564 L
s
.551 .01472 m
.551 .01564 L
s
.55196 .01472 m
.55196 .01564 L
s
.55291 .01472 m
.55291 .01564 L
s
.55386 .01472 m
.55386 .01564 L
s
.55482 .01472 m
.55482 .01564 L
s
.55577 .01472 m
.55577 .01564 L
s
.55672 .01472 m
.55672 .01564 L
s
.55768 .01472 m
.55768 .01564 L
s
.55863 .01472 m
.55863 .01564 L
s
.55958 .01472 m
.55958 .01564 L
s
.56054 .01472 m
.56054 .01564 L
s
.56149 .01472 m
.56149 .01564 L
s
.56244 .01472 m
.56244 .01564 L
s
.5634 .01472 m
.5634 .01564 L
s
.56435 .01472 m
.56435 .01564 L
s
.5653 .01472 m
.5653 .01564 L
s
.56626 .01472 m
.56626 .09928 L
s
.56721 .01472 m
.56721 .01564 L
s
.56816 .01472 m
.56816 .01564 L
s
.56912 .01472 m
.56912 .01564 L
s
.57007 .01472 m
.57007 .01564 L
s
.57102 .01472 m
.57102 .01564 L
s
.57198 .01472 m
.57198 .01564 L
s
.57293 .01472 m
.57293 .01564 L
s
.57388 .01472 m
.57388 .01564 L
s
.57484 .01472 m
.57484 .01564 L
s
.57579 .01472 m
.57579 .01564 L
s
.57674 .01472 m
.57674 .01564 L
s
.5777 .01472 m
.5777 .01564 L
s
.57865 .01472 m
.57865 .01564 L
s
.5796 .01472 m
.5796 .01564 L
s
.58056 .01472 m
.58056 .01564 L
s
.58151 .01472 m
.58151 .01564 L
s
.58246 .01472 m
.58246 .01564 L
s
.58342 .01472 m
.58342 .01564 L
s
.58437 .01472 m
.58437 .01564 L
s
.58532 .01472 m
.58532 .08074 L
s
.58628 .01472 m
.58628 .01564 L
s
.58723 .01472 m
.58723 .01564 L
s
.58818 .01472 m
.58818 .01564 L
s
.58914 .01472 m
.58914 .01564 L
s
.59009 .01472 m
.59009 .01564 L
s
.59104 .01472 m
.59104 .01564 L
s
.592 .01472 m
.592 .01564 L
s
.59295 .01472 m
.59295 .01564 L
s
.5939 .01472 m
.5939 .01564 L
s
.59486 .01472 m
.59486 .01564 L
s
.59581 .01472 m
.59581 .01564 L
s
.59676 .01472 m
.59676 .01564 L
s
.59772 .01472 m
.59772 .01564 L
s
.59867 .01472 m
.59867 .01564 L
s
.59962 .01472 m
.59962 .01564 L
s
.60058 .01472 m
.60058 .01564 L
s
.60153 .01472 m
.60153 .01564 L
s
.60248 .01472 m
.60248 .01564 L
s
.60344 .01472 m
.60344 .01564 L
s
.60439 .01472 m
.60439 .06899 L
s
.60534 .01472 m
.60534 .01564 L
s
.6063 .01472 m
.6063 .01564 L
s
.60725 .01472 m
.60725 .01564 L
s
.6082 .01472 m
.6082 .01564 L
s
.60916 .01472 m
.60916 .01564 L
s
.61011 .01472 m
.61011 .01564 L
s
.61106 .01472 m
.61106 .01564 L
s
.61202 .01472 m
.61202 .01564 L
s
.61297 .01472 m
.61297 .01564 L
s
.61392 .01472 m
.61392 .01564 L
s
.61488 .01472 m
.61488 .01564 L
s
.61583 .01472 m
.61583 .01564 L
s
.61678 .01472 m
.61678 .01564 L
s
.61774 .01472 m
.61774 .01564 L
s
.61869 .01472 m
.61869 .01564 L
s
.61964 .01472 m
.61964 .01564 L
s
.6206 .01472 m
.6206 .01564 L
s
.62155 .01472 m
.62155 .01564 L
s
.6225 .01472 m
.6225 .01564 L
s
.62346 .01472 m
.62346 .06091 L
s
.62441 .01472 m
.62441 .01564 L
s
.62536 .01472 m
.62536 .01564 L
s
.62632 .01472 m
.62632 .01564 L
s
.62727 .01472 m
.62727 .01564 L
s
.62822 .01472 m
.62822 .01564 L
s
.62918 .01472 m
.62918 .01564 L
s
.63013 .01472 m
.63013 .01564 L
s
.63108 .01472 m
.63108 .01564 L
s
.63204 .01472 m
.63204 .01564 L
s
.63299 .01472 m
.63299 .01564 L
s
.63394 .01472 m
.63394 .01564 L
s
.6349 .01472 m
.6349 .01564 L
s
.63585 .01472 m
.63585 .01564 L
s
.6368 .01472 m
.6368 .01564 L
s
.63776 .01472 m
.63776 .01564 L
s
.63871 .01472 m
.63871 .01564 L
s
.63966 .01472 m
.63966 .01564 L
s
.64062 .01472 m
.64062 .01564 L
s
.64157 .01472 m
.64157 .01564 L
s
.64252 .01472 m
.64252 .05503 L
s
.64348 .01472 m
.64348 .01564 L
s
.64443 .01472 m
.64443 .01564 L
s
.64538 .01472 m
.64538 .01564 L
s
.64634 .01472 m
.64634 .01564 L
s
.64729 .01472 m
.64729 .01564 L
s
.64824 .01472 m
.64824 .01564 L
s
.6492 .01472 m
.6492 .01564 L
s
.65015 .01472 m
.65015 .01564 L
s
.6511 .01472 m
.6511 .01564 L
s
.65206 .01472 m
.65206 .01564 L
s
.65301 .01472 m
.65301 .01564 L
s
.65396 .01472 m
.65396 .01564 L
s
.65492 .01472 m
.65492 .01564 L
s
.65587 .01472 m
.65587 .01564 L
s
.65682 .01472 m
.65682 .01564 L
s
.65778 .01472 m
.65778 .01564 L
s
.65873 .01472 m
.65873 .01564 L
s
.65968 .01472 m
.65968 .01564 L
s
.66064 .01472 m
.66064 .01564 L
s
.66159 .01472 m
.66159 .05058 L
s
.66254 .01472 m
.66254 .01564 L
s
.6635 .01472 m
.6635 .01564 L
s
.66445 .01472 m
.66445 .01564 L
s
.6654 .01472 m
.6654 .01564 L
s
.66636 .01472 m
.66636 .01564 L
s
.66731 .01472 m
.66731 .01564 L
s
.66826 .01472 m
.66826 .01564 L
s
.66922 .01472 m
.66922 .01564 L
s
.67017 .01472 m
.67017 .01564 L
s
.67112 .01472 m
.67112 .01564 L
s
.67208 .01472 m
.67208 .01564 L
s
.67303 .01472 m
.67303 .01564 L
s
.67398 .01472 m
.67398 .01564 L
s
.67494 .01472 m
.67494 .01564 L
s
.67589 .01472 m
.67589 .01564 L
s
.67684 .01472 m
.67684 .01564 L
s
.6778 .01472 m
.6778 .01564 L
s
.67875 .01472 m
.67875 .01564 L
s
.6797 .01472 m
.6797 .01564 L
s
.68066 .01472 m
.68066 .0471 L
s
.68161 .01472 m
.68161 .01564 L
s
.68256 .01472 m
.68256 .01564 L
s
.68352 .01472 m
.68352 .01564 L
s
.68447 .01472 m
.68447 .01564 L
s
.68542 .01472 m
.68542 .01564 L
s
.68638 .01472 m
.68638 .01564 L
s
.68733 .01472 m
.68733 .01564 L
s
.68828 .01472 m
.68828 .01564 L
s
.68924 .01472 m
.68924 .01564 L
s
.69019 .01472 m
.69019 .01564 L
s
.69114 .01472 m
.69114 .01564 L
s
.6921 .01472 m
.6921 .01564 L
s
.69305 .01472 m
.69305 .01564 L
s
.694 .01472 m
.694 .01564 L
s
.69496 .01472 m
.69496 .01564 L
s
.69591 .01472 m
.69591 .01564 L
s
.69686 .01472 m
.69686 .01564 L
s
.69782 .01472 m
.69782 .01564 L
s
.69877 .01472 m
.69877 .01564 L
s
.69972 .01472 m
.69972 .04432 L
s
.70068 .01472 m
.70068 .01564 L
s
.70163 .01472 m
.70163 .01564 L
s
.70258 .01472 m
.70258 .01564 L
s
.70354 .01472 m
.70354 .01564 L
s
.70449 .01472 m
.70449 .01564 L
s
.70544 .01472 m
.70544 .01564 L
s
.7064 .01472 m
.7064 .01564 L
s
.70735 .01472 m
.70735 .01564 L
s
.7083 .01472 m
.7083 .01564 L
s
.70926 .01472 m
.70926 .01564 L
s
.71021 .01472 m
.71021 .01564 L
s
.71116 .01472 m
.71116 .01564 L
s
.71212 .01472 m
.71212 .01564 L
s
.71307 .01472 m
.71307 .01564 L
s
.71402 .01472 m
.71402 .01564 L
s
.71498 .01472 m
.71498 .01564 L
s
.71593 .01472 m
.71593 .01564 L
s
.71688 .01472 m
.71688 .01564 L
s
.71784 .01472 m
.71784 .01564 L
s
.71879 .01472 m
.71879 .04207 L
s
.71974 .01472 m
.71974 .01564 L
s
.7207 .01472 m
.7207 .01564 L
s
.72165 .01472 m
.72165 .01564 L
s
.7226 .01472 m
.7226 .01564 L
s
.72356 .01472 m
.72356 .01564 L
s
.72451 .01472 m
.72451 .01564 L
s
.72546 .01472 m
.72546 .01564 L
s
.72642 .01472 m
.72642 .01564 L
s
.72737 .01472 m
.72737 .01564 L
s
.72832 .01472 m
.72832 .01564 L
s
.72928 .01472 m
.72928 .01564 L
s
.73023 .01472 m
.73023 .01564 L
s
.73118 .01472 m
.73118 .01564 L
s
.73214 .01472 m
.73214 .01564 L
s
.73309 .01472 m
.73309 .01564 L
s
.73404 .01472 m
.73404 .01564 L
s
.735 .01472 m
.735 .01564 L
s
.73595 .01472 m
.73595 .01564 L
s
.7369 .01472 m
.7369 .01564 L
s
.73786 .01472 m
.73786 .04022 L
s
.73881 .01472 m
.73881 .01564 L
s
.73976 .01472 m
.73976 .01564 L
s
.74072 .01472 m
.74072 .01564 L
s
.74167 .01472 m
.74167 .01564 L
s
.74262 .01472 m
.74262 .01564 L
s
.74358 .01472 m
.74358 .01564 L
s
.74453 .01472 m
.74453 .01564 L
s
.74548 .01472 m
.74548 .01564 L
s
.74644 .01472 m
.74644 .01564 L
s
.74739 .01472 m
.74739 .01564 L
s
.74834 .01472 m
.74834 .01564 L
s
.7493 .01472 m
.7493 .01564 L
s
.75025 .01472 m
.75025 .01564 L
s
.7512 .01472 m
.7512 .01564 L
s
.75216 .01472 m
.75216 .01564 L
s
.75311 .01472 m
.75311 .01564 L
s
.75406 .01472 m
.75406 .01564 L
s
.75502 .01472 m
.75502 .01564 L
s
.75597 .01472 m
.75597 .01564 L
s
.75692 .01472 m
.75692 .03868 L
s
.75788 .01472 m
.75788 .01564 L
s
.75883 .01472 m
.75883 .01564 L
s
.75978 .01472 m
.75978 .01564 L
s
.76074 .01472 m
.76074 .01564 L
s
.76169 .01472 m
.76169 .01564 L
s
.76264 .01472 m
.76264 .01564 L
s
.7636 .01472 m
.7636 .01564 L
s
.76455 .01472 m
.76455 .01564 L
s
.7655 .01472 m
.7655 .01564 L
s
.76646 .01472 m
.76646 .01564 L
s
.76741 .01472 m
.76741 .01564 L
s
.76836 .01472 m
.76836 .01564 L
s
.76932 .01472 m
.76932 .01564 L
s
.77027 .01472 m
.77027 .01564 L
s
.77122 .01472 m
.77122 .01564 L
s
.77218 .01472 m
.77218 .01564 L
s
.77313 .01472 m
.77313 .01564 L
s
.77408 .01472 m
.77408 .01564 L
s
.77504 .01472 m
.77504 .01564 L
s
.77599 .01472 m
.77599 .03739 L
s
.77694 .01472 m
.77694 .01564 L
s
.7779 .01472 m
.7779 .01564 L
s
.77885 .01472 m
.77885 .01564 L
s
.7798 .01472 m
.7798 .01564 L
s
.78076 .01472 m
.78076 .01564 L
s
.78171 .01472 m
.78171 .01564 L
s
.78266 .01472 m
.78266 .01564 L
s
.78362 .01472 m
.78362 .01564 L
s
.78457 .01472 m
.78457 .01564 L
s
.78552 .01472 m
.78552 .01564 L
s
.78648 .01472 m
.78648 .01564 L
s
.78743 .01472 m
.78743 .01564 L
s
.78838 .01472 m
.78838 .01564 L
s
.78934 .01472 m
.78934 .01564 L
s
.79029 .01472 m
.79029 .01564 L
s
.79124 .01472 m
.79124 .01564 L
s
.7922 .01472 m
.7922 .01564 L
s
.79315 .01472 m
.79315 .01564 L
s
.7941 .01472 m
.7941 .01564 L
s
.79506 .01472 m
.79506 .03631 L
s
.79601 .01472 m
.79601 .01564 L
s
.79696 .01472 m
.79696 .01564 L
s
.79792 .01472 m
.79792 .01564 L
s
.79887 .01472 m
.79887 .01564 L
s
.79982 .01472 m
.79982 .01564 L
s
.80078 .01472 m
.80078 .01564 L
s
.80173 .01472 m
.80173 .01564 L
s
.80268 .01472 m
.80268 .01564 L
s
.80364 .01472 m
.80364 .01564 L
s
.80459 .01472 m
.80459 .01564 L
s
.80554 .01472 m
.80554 .01564 L
s
.8065 .01472 m
.8065 .01564 L
s
.80745 .01472 m
.80745 .01564 L
s
.8084 .01472 m
.8084 .01564 L
s
.80936 .01472 m
.80936 .01564 L
s
.81031 .01472 m
.81031 .01564 L
s
.81126 .01472 m
.81126 .01564 L
s
.81222 .01472 m
.81222 .01564 L
s
.81317 .01472 m
.81317 .01564 L
s
.81412 .01472 m
.81412 .03541 L
s
.81508 .01472 m
.81508 .01564 L
s
.81603 .01472 m
.81603 .01564 L
s
.81698 .01472 m
.81698 .01564 L
s
.81794 .01472 m
.81794 .01564 L
s
.81889 .01472 m
.81889 .01564 L
s
.81984 .01472 m
.81984 .01564 L
s
.8208 .01472 m
.8208 .01564 L
s
.82175 .01472 m
.82175 .01564 L
s
.8227 .01472 m
.8227 .01564 L
s
.82366 .01472 m
.82366 .01564 L
s
.82461 .01472 m
.82461 .01564 L
s
.82556 .01472 m
.82556 .01564 L
s
.82652 .01472 m
.82652 .01564 L
s
.82747 .01472 m
.82747 .01564 L
s
.82842 .01472 m
.82842 .01564 L
s
.82938 .01472 m
.82938 .01564 L
s
.83033 .01472 m
.83033 .01564 L
s
.83128 .01472 m
.83128 .01564 L
s
.83224 .01472 m
.83224 .01564 L
s
.83319 .01472 m
.83319 .03465 L
s
.83414 .01472 m
.83414 .01564 L
s
.8351 .01472 m
.8351 .01564 L
s
.83605 .01472 m
.83605 .01564 L
s
.837 .01472 m
.837 .01564 L
s
.83796 .01472 m
.83796 .01564 L
s
.83891 .01472 m
.83891 .01564 L
s
.83986 .01472 m
.83986 .01564 L
s
.84082 .01472 m
.84082 .01564 L
s
.84177 .01472 m
.84177 .01564 L
s
.84272 .01472 m
.84272 .01564 L
s
.84368 .01472 m
.84368 .01564 L
s
.84463 .01472 m
.84463 .01564 L
s
.84558 .01472 m
.84558 .01564 L
s
.84654 .01472 m
.84654 .01564 L
s
.84749 .01472 m
.84749 .01564 L
s
.84844 .01472 m
.84844 .01564 L
s
.8494 .01472 m
.8494 .01564 L
s
.85035 .01472 m
.85035 .01564 L
s
.8513 .01472 m
.8513 .01564 L
s
.85226 .01472 m
.85226 .03402 L
s
.85321 .01472 m
.85321 .01564 L
s
.85416 .01472 m
.85416 .01564 L
s
.85512 .01472 m
.85512 .01564 L
s
.85607 .01472 m
.85607 .01564 L
s
.85702 .01472 m
.85702 .01564 L
s
.85798 .01472 m
.85798 .01564 L
s
.85893 .01472 m
.85893 .01564 L
s
.85988 .01472 m
.85988 .01564 L
s
.86084 .01472 m
.86084 .01564 L
s
.86179 .01472 m
.86179 .01564 L
s
.86274 .01472 m
.86274 .01564 L
s
.8637 .01472 m
.8637 .01564 L
s
.86465 .01472 m
.86465 .01564 L
s
.8656 .01472 m
.8656 .01564 L
s
.86656 .01472 m
.86656 .01564 L
s
.86751 .01472 m
.86751 .01564 L
s
.86846 .01472 m
.86846 .01564 L
s
.86942 .01472 m
.86942 .01564 L
s
.87037 .01472 m
.87037 .01564 L
s
.87132 .01472 m
.87132 .0335 L
s
.87228 .01472 m
.87228 .01564 L
s
.87323 .01472 m
.87323 .01564 L
s
.87418 .01472 m
.87418 .01564 L
s
.87514 .01472 m
.87514 .01564 L
s
.87609 .01472 m
.87609 .01564 L
s
.87704 .01472 m
.87704 .01564 L
s
.878 .01472 m
.878 .01564 L
s
.87895 .01472 m
.87895 .01564 L
s
.8799 .01472 m
.8799 .01564 L
s
.88086 .01472 m
.88086 .01564 L
s
.88181 .01472 m
.88181 .01564 L
s
.88276 .01472 m
.88276 .01564 L
s
.88372 .01472 m
.88372 .01564 L
s
.88467 .01472 m
.88467 .01564 L
s
.88562 .01472 m
.88562 .01564 L
s
.88658 .01472 m
.88658 .01564 L
s
.88753 .01472 m
.88753 .01564 L
s
.88848 .01472 m
.88848 .01564 L
s
.88944 .01472 m
.88944 .01564 L
s
.89039 .01472 m
.89039 .03308 L
s
.89134 .01472 m
.89134 .01564 L
s
.8923 .01472 m
.8923 .01564 L
s
.89325 .01472 m
.89325 .01564 L
s
.8942 .01472 m
.8942 .01564 L
s
.89516 .01472 m
.89516 .01564 L
s
.89611 .01472 m
.89611 .01564 L
s
.89706 .01472 m
.89706 .01564 L
s
.89802 .01472 m
.89802 .01564 L
s
.89897 .01472 m
.89897 .01564 L
s
.89992 .01472 m
.89992 .01564 L
s
.90088 .01472 m
.90088 .01564 L
s
.90183 .01472 m
.90183 .01564 L
s
.90278 .01472 m
.90278 .01564 L
s
.90374 .01472 m
.90374 .01564 L
s
.90469 .01472 m
.90469 .01564 L
s
.90564 .01472 m
.90564 .01564 L
s
.9066 .01472 m
.9066 .01564 L
s
.90755 .01472 m
.90755 .01564 L
s
.9085 .01472 m
.9085 .01564 L
s
.90946 .01472 m
.90946 .03276 L
s
.91041 .01472 m
.91041 .01564 L
s
.91136 .01472 m
.91136 .01564 L
s
.91232 .01472 m
.91232 .01564 L
s
.91327 .01472 m
.91327 .01564 L
s
.91422 .01472 m
.91422 .01564 L
s
.91518 .01472 m
.91518 .01564 L
s
.91613 .01472 m
.91613 .01564 L
s
.91708 .01472 m
.91708 .01564 L
s
.91804 .01472 m
.91804 .01564 L
s
.91899 .01472 m
.91899 .01564 L
s
.91994 .01472 m
.91994 .01564 L
s
.9209 .01472 m
.9209 .01564 L
s
.92185 .01472 m
.92185 .01564 L
s
.9228 .01472 m
.9228 .01564 L
s
.92376 .01472 m
.92376 .01564 L
s
.92471 .01472 m
.92471 .01564 L
s
.92566 .01472 m
.92566 .01564 L
s
.92662 .01472 m
.92662 .01564 L
s
.92757 .01472 m
.92757 .01564 L
s
.92852 .01472 m
.92852 .03252 L
s
.92948 .01472 m
.92948 .01564 L
s
.93043 .01472 m
.93043 .01564 L
s
.93138 .01472 m
.93138 .01564 L
s
.93234 .01472 m
.93234 .01564 L
s
.93329 .01472 m
.93329 .01564 L
s
.93424 .01472 m
.93424 .01564 L
s
.9352 .01472 m
.9352 .01564 L
s
.93615 .01472 m
.93615 .01564 L
s
.9371 .01472 m
.9371 .01564 L
s
.93806 .01472 m
.93806 .01564 L
s
.93901 .01472 m
.93901 .01564 L
s
.93996 .01472 m
.93996 .01564 L
s
.94092 .01472 m
.94092 .01564 L
s
.94187 .01472 m
.94187 .01564 L
s
.94282 .01472 m
.94282 .01564 L
s
.94378 .01472 m
.94378 .01564 L
s
.94473 .01472 m
.94473 .01564 L
s
.94568 .01472 m
.94568 .01564 L
s
.94664 .01472 m
.94664 .01564 L
s
.94759 .01472 m
.94759 .03237 L
s
.94854 .01472 m
.94854 .01564 L
s
.9495 .01472 m
.9495 .01564 L
s
.95045 .01472 m
.95045 .01564 L
s
.9514 .01472 m
.9514 .01564 L
s
.95236 .01472 m
.95236 .01564 L
s
.95331 .01472 m
.95331 .01564 L
s
.95426 .01472 m
.95426 .01564 L
s
.95522 .01472 m
.95522 .01564 L
s
.95617 .01472 m
.95617 .01564 L
s
.95712 .01472 m
.95712 .01564 L
s
.95808 .01472 m
.95808 .01564 L
s
.95903 .01472 m
.95903 .01564 L
s
.95998 .01472 m
.95998 .01564 L
s
.96094 .01472 m
.96094 .01564 L
s
.96189 .01472 m
.96189 .01564 L
s
.96284 .01472 m
.96284 .01564 L
s
.9638 .01472 m
.9638 .01564 L
s
.96475 .01472 m
.96475 .01564 L
s
.9657 .01472 m
.9657 .01564 L
s
.96666 .01472 m
.96666 .03229 L
s
.96761 .01472 m
.96761 .01564 L
s
.96856 .01472 m
.96856 .01564 L
s
.96952 .01472 m
.96952 .01564 L
s
.97047 .01472 m
.97047 .01564 L
s
.97142 .01472 m
.97142 .01564 L
s
.97238 .01472 m
.97238 .01564 L
s
.97333 .01472 m
.97333 .01564 L
s
.97428 .01472 m
.97428 .01564 L
s
.97524 .01472 m
.97524 .01564 L
s
.97619 .01472 m
.97619 .01564 L
s
.015 w
.02381 .01564 Mdot
.02476 .01564 Mdot
.02572 .01564 Mdot
.02667 .01564 Mdot
.02762 .01564 Mdot
.02858 .01564 Mdot
.02953 .01564 Mdot
.03048 .01564 Mdot
.03144 .01564 Mdot
.03239 .03229 Mdot
.03334 .01564 Mdot
.0343 .01564 Mdot
.03525 .01564 Mdot
.0362 .01564 Mdot
.03716 .01564 Mdot
.03811 .01564 Mdot
.03906 .01564 Mdot
.04002 .01564 Mdot
.04097 .01564 Mdot
.04192 .01564 Mdot
.04288 .01564 Mdot
.04383 .01564 Mdot
.04478 .01564 Mdot
.04574 .01564 Mdot
.04669 .01564 Mdot
.04764 .01564 Mdot
.0486 .01564 Mdot
.04955 .01564 Mdot
.0505 .01564 Mdot
.05146 .03237 Mdot
.05241 .01564 Mdot
.05336 .01564 Mdot
.05432 .01564 Mdot
.05527 .01564 Mdot
.05622 .01564 Mdot
.05718 .01564 Mdot
.05813 .01564 Mdot
.05908 .01564 Mdot
.06004 .01564 Mdot
.06099 .01564 Mdot
.06194 .01564 Mdot
.0629 .01564 Mdot
.06385 .01564 Mdot
.0648 .01564 Mdot
.06576 .01564 Mdot
.06671 .01564 Mdot
.06766 .01564 Mdot
.06862 .01564 Mdot
.06957 .01564 Mdot
.07052 .03252 Mdot
.07148 .01564 Mdot
.07243 .01564 Mdot
.07338 .01564 Mdot
.07434 .01564 Mdot
.07529 .01564 Mdot
.07624 .01564 Mdot
.0772 .01564 Mdot
.07815 .01564 Mdot
.0791 .01564 Mdot
.08006 .01564 Mdot
.08101 .01564 Mdot
.08196 .01564 Mdot
.08292 .01564 Mdot
.08387 .01564 Mdot
.08482 .01564 Mdot
.08578 .01564 Mdot
.08673 .01564 Mdot
.08768 .01564 Mdot
.08864 .01564 Mdot
.08959 .03276 Mdot
.09054 .01564 Mdot
.0915 .01564 Mdot
.09245 .01564 Mdot
.0934 .01564 Mdot
.09436 .01564 Mdot
.09531 .01564 Mdot
.09626 .01564 Mdot
.09722 .01564 Mdot
.09817 .01564 Mdot
.09912 .01564 Mdot
.10008 .01564 Mdot
.10103 .01564 Mdot
.10198 .01564 Mdot
.10294 .01564 Mdot
.10389 .01564 Mdot
.10484 .01564 Mdot
.1058 .01564 Mdot
.10675 .01564 Mdot
.1077 .01564 Mdot
.10866 .03308 Mdot
.10961 .01564 Mdot
.11056 .01564 Mdot
.11152 .01564 Mdot
.11247 .01564 Mdot
.11342 .01564 Mdot
.11438 .01564 Mdot
.11533 .01564 Mdot
.11628 .01564 Mdot
.11724 .01564 Mdot
.11819 .01564 Mdot
.11914 .01564 Mdot
.1201 .01564 Mdot
.12105 .01564 Mdot
.122 .01564 Mdot
.12296 .01564 Mdot
.12391 .01564 Mdot
.12486 .01564 Mdot
.12582 .01564 Mdot
.12677 .01564 Mdot
.12772 .0335 Mdot
.12868 .01564 Mdot
.12963 .01564 Mdot
.13058 .01564 Mdot
.13154 .01564 Mdot
.13249 .01564 Mdot
.13344 .01564 Mdot
.1344 .01564 Mdot
.13535 .01564 Mdot
.1363 .01564 Mdot
.13726 .01564 Mdot
.13821 .01564 Mdot
.13916 .01564 Mdot
.14012 .01564 Mdot
.14107 .01564 Mdot
.14202 .01564 Mdot
.14298 .01564 Mdot
.14393 .01564 Mdot
.14488 .01564 Mdot
.14584 .01564 Mdot
.14679 .03402 Mdot
.14774 .01564 Mdot
.1487 .01564 Mdot
.14965 .01564 Mdot
.1506 .01564 Mdot
.15156 .01564 Mdot
.15251 .01564 Mdot
.15346 .01564 Mdot
.15442 .01564 Mdot
.15537 .01564 Mdot
.15632 .01564 Mdot
.15728 .01564 Mdot
.15823 .01564 Mdot
.15918 .01564 Mdot
.16014 .01564 Mdot
.16109 .01564 Mdot
.16204 .01564 Mdot
.163 .01564 Mdot
.16395 .01564 Mdot
.1649 .01564 Mdot
.16586 .03465 Mdot
.16681 .01564 Mdot
.16776 .01564 Mdot
.16872 .01564 Mdot
.16967 .01564 Mdot
.17062 .01564 Mdot
.17158 .01564 Mdot
.17253 .01564 Mdot
.17348 .01564 Mdot
.17444 .01564 Mdot
.17539 .01564 Mdot
.17634 .01564 Mdot
.1773 .01564 Mdot
.17825 .01564 Mdot
.1792 .01564 Mdot
.18016 .01564 Mdot
.18111 .01564 Mdot
.18206 .01564 Mdot
.18302 .01564 Mdot
.18397 .01564 Mdot
.18492 .03541 Mdot
.18588 .01564 Mdot
.18683 .01564 Mdot
.18778 .01564 Mdot
.18874 .01564 Mdot
.18969 .01564 Mdot
.19064 .01564 Mdot
.1916 .01564 Mdot
.19255 .01564 Mdot
.1935 .01564 Mdot
.19446 .01564 Mdot
.19541 .01564 Mdot
.19636 .01564 Mdot
.19732 .01564 Mdot
.19827 .01564 Mdot
.19922 .01564 Mdot
.20018 .01564 Mdot
.20113 .01564 Mdot
.20208 .01564 Mdot
.20304 .01564 Mdot
.20399 .03631 Mdot
.20494 .01564 Mdot
.2059 .01564 Mdot
.20685 .01564 Mdot
.2078 .01564 Mdot
.20876 .01564 Mdot
.20971 .01564 Mdot
.21066 .01564 Mdot
.21162 .01564 Mdot
.21257 .01564 Mdot
.21352 .01564 Mdot
.21448 .01564 Mdot
.21543 .01564 Mdot
.21638 .01564 Mdot
.21734 .01564 Mdot
.21829 .01564 Mdot
.21924 .01564 Mdot
.2202 .01564 Mdot
.22115 .01564 Mdot
.2221 .01564 Mdot
.22306 .03739 Mdot
.22401 .01564 Mdot
.22496 .01564 Mdot
.22592 .01564 Mdot
.22687 .01564 Mdot
.22782 .01564 Mdot
.22878 .01564 Mdot
.22973 .01564 Mdot
.23068 .01564 Mdot
.23164 .01564 Mdot
.23259 .01564 Mdot
.23354 .01564 Mdot
.2345 .01564 Mdot
.23545 .01564 Mdot
.2364 .01564 Mdot
.23736 .01564 Mdot
.23831 .01564 Mdot
.23926 .01564 Mdot
.24022 .01564 Mdot
.24117 .01564 Mdot
.24212 .03868 Mdot
.24308 .01564 Mdot
.24403 .01564 Mdot
.24498 .01564 Mdot
.24594 .01564 Mdot
.24689 .01564 Mdot
.24784 .01564 Mdot
.2488 .01564 Mdot
.24975 .01564 Mdot
.2507 .01564 Mdot
.25166 .01564 Mdot
.25261 .01564 Mdot
.25356 .01564 Mdot
.25452 .01564 Mdot
.25547 .01564 Mdot
.25642 .01564 Mdot
.25738 .01564 Mdot
.25833 .01564 Mdot
.25928 .01564 Mdot
.26024 .01564 Mdot
.26119 .04022 Mdot
.26214 .01564 Mdot
.2631 .01564 Mdot
.26405 .01564 Mdot
.265 .01564 Mdot
.26596 .01564 Mdot
.26691 .01564 Mdot
.26786 .01564 Mdot
.26882 .01564 Mdot
.26977 .01564 Mdot
.27072 .01564 Mdot
.27168 .01564 Mdot
.27263 .01564 Mdot
.27358 .01564 Mdot
.27454 .01564 Mdot
.27549 .01564 Mdot
.27644 .01564 Mdot
.2774 .01564 Mdot
.27835 .01564 Mdot
.2793 .01564 Mdot
.28026 .04207 Mdot
.28121 .01564 Mdot
.28216 .01564 Mdot
.28312 .01564 Mdot
.28407 .01564 Mdot
.28502 .01564 Mdot
.28598 .01564 Mdot
.28693 .01564 Mdot
.28788 .01564 Mdot
.28884 .01564 Mdot
.28979 .01564 Mdot
.29074 .01564 Mdot
.2917 .01564 Mdot
.29265 .01564 Mdot
.2936 .01564 Mdot
.29456 .01564 Mdot
.29551 .01564 Mdot
.29646 .01564 Mdot
.29742 .01564 Mdot
.29837 .01564 Mdot
.29932 .04432 Mdot
.30028 .01564 Mdot
.30123 .01564 Mdot
.30218 .01564 Mdot
.30314 .01564 Mdot
.30409 .01564 Mdot
.30504 .01564 Mdot
.306 .01564 Mdot
.30695 .01564 Mdot
.3079 .01564 Mdot
.30886 .01564 Mdot
.30981 .01564 Mdot
.31076 .01564 Mdot
.31172 .01564 Mdot
.31267 .01564 Mdot
.31362 .01564 Mdot
.31458 .01564 Mdot
.31553 .01564 Mdot
.31648 .01564 Mdot
.31744 .01564 Mdot
.31839 .0471 Mdot
.31934 .01564 Mdot
.3203 .01564 Mdot
.32125 .01564 Mdot
.3222 .01564 Mdot
.32316 .01564 Mdot
.32411 .01564 Mdot
.32506 .01564 Mdot
.32602 .01564 Mdot
.32697 .01564 Mdot
.32792 .01564 Mdot
.32888 .01564 Mdot
.32983 .01564 Mdot
.33078 .01564 Mdot
.33174 .01564 Mdot
.33269 .01564 Mdot
.33364 .01564 Mdot
.3346 .01564 Mdot
.33555 .01564 Mdot
.3365 .01564 Mdot
.33746 .05058 Mdot
.33841 .01564 Mdot
.33936 .01564 Mdot
.34032 .01564 Mdot
.34127 .01564 Mdot
.34222 .01564 Mdot
.34318 .01564 Mdot
.34413 .01564 Mdot
.34508 .01564 Mdot
.34604 .01564 Mdot
.34699 .01564 Mdot
.34794 .01564 Mdot
.3489 .01564 Mdot
.34985 .01564 Mdot
.3508 .01564 Mdot
.35176 .01564 Mdot
.35271 .01564 Mdot
.35366 .01564 Mdot
.35462 .01564 Mdot
.35557 .01564 Mdot
.35652 .05503 Mdot
.35748 .01564 Mdot
.35843 .01564 Mdot
.35938 .01564 Mdot
.36034 .01564 Mdot
.36129 .01564 Mdot
.36224 .01564 Mdot
.3632 .01564 Mdot
.36415 .01564 Mdot
.3651 .01564 Mdot
.36606 .01564 Mdot
.36701 .01564 Mdot
.36796 .01564 Mdot
.36892 .01564 Mdot
.36987 .01564 Mdot
.37082 .01564 Mdot
.37178 .01564 Mdot
.37273 .01564 Mdot
.37368 .01564 Mdot
.37464 .01564 Mdot
.37559 .06091 Mdot
.37654 .01564 Mdot
.3775 .01564 Mdot
.37845 .01564 Mdot
.3794 .01564 Mdot
.38036 .01564 Mdot
.38131 .01564 Mdot
.38226 .01564 Mdot
.38322 .01564 Mdot
.38417 .01564 Mdot
.38512 .01564 Mdot
.38608 .01564 Mdot
.38703 .01564 Mdot
.38798 .01564 Mdot
.38894 .01564 Mdot
.38989 .01564 Mdot
.39084 .01564 Mdot
.3918 .01564 Mdot
.39275 .01564 Mdot
.3937 .01564 Mdot
.39466 .06899 Mdot
.39561 .01564 Mdot
.39656 .01564 Mdot
.39752 .01564 Mdot
.39847 .01564 Mdot
.39942 .01564 Mdot
.40038 .01564 Mdot
.40133 .01564 Mdot
.40228 .01564 Mdot
.40324 .01564 Mdot
.40419 .01564 Mdot
.40514 .01564 Mdot
.4061 .01564 Mdot
.40705 .01564 Mdot
.408 .01564 Mdot
.40896 .01564 Mdot
.40991 .01564 Mdot
.41086 .01564 Mdot
.41182 .01564 Mdot
.41277 .01564 Mdot
.41372 .08074 Mdot
.41468 .01564 Mdot
.41563 .01564 Mdot
.41658 .01564 Mdot
.41754 .01564 Mdot
.41849 .01564 Mdot
.41944 .01564 Mdot
.4204 .01564 Mdot
.42135 .01564 Mdot
.4223 .01564 Mdot
.42326 .01564 Mdot
.42421 .01564 Mdot
.42516 .01564 Mdot
.42612 .01564 Mdot
.42707 .01564 Mdot
.42802 .01564 Mdot
.42898 .01564 Mdot
.42993 .01564 Mdot
.43088 .01564 Mdot
.43184 .01564 Mdot
.43279 .09928 Mdot
.43374 .01564 Mdot
.4347 .01564 Mdot
.43565 .01564 Mdot
.4366 .01564 Mdot
.43756 .01564 Mdot
.43851 .01564 Mdot
.43946 .01564 Mdot
.44042 .01564 Mdot
.44137 .01564 Mdot
.44232 .01564 Mdot
.44328 .01564 Mdot
.44423 .01564 Mdot
.44518 .01564 Mdot
.44614 .01564 Mdot
.44709 .01564 Mdot
.44804 .01564 Mdot
.449 .01564 Mdot
.44995 .01564 Mdot
.4509 .01564 Mdot
.45186 .13277 Mdot
.45281 .01564 Mdot
.45376 .01564 Mdot
.45472 .01564 Mdot
.45567 .01564 Mdot
.45662 .01564 Mdot
.45758 .01564 Mdot
.45853 .01564 Mdot
.45948 .01564 Mdot
.46044 .01564 Mdot
.46139 .01564 Mdot
.46234 .01564 Mdot
.4633 .01564 Mdot
.46425 .01564 Mdot
.4652 .01564 Mdot
.46616 .01564 Mdot
.46711 .01564 Mdot
.46806 .01564 Mdot
.46902 .01564 Mdot
.46997 .01564 Mdot
.47092 .2111 Mdot
.47188 .01564 Mdot
.47283 .01564 Mdot
.47378 .01564 Mdot
.47474 .01564 Mdot
.47569 .01564 Mdot
.47664 .01564 Mdot
.4776 .01564 Mdot
.47855 .01564 Mdot
.4795 .01564 Mdot
.48046 .01564 Mdot
.48141 .01564 Mdot
.48236 .01564 Mdot
.48332 .01564 Mdot
.48427 .01564 Mdot
.48522 .01564 Mdot
.48618 .01564 Mdot
.48713 .01564 Mdot
.48808 .01564 Mdot
.48904 .01564 Mdot
.48999 .60332 Mdot
.49094 .01564 Mdot
.4919 .01564 Mdot
.49285 .01564 Mdot
.4938 .01564 Mdot
.49476 .01564 Mdot
.49571 .01564 Mdot
.49666 .01564 Mdot
.49762 .01564 Mdot
.49857 .01564 Mdot
.49952 .01564 Mdot
.50048 .01564 Mdot
.50143 .01564 Mdot
.50238 .01564 Mdot
.50334 .01564 Mdot
.50429 .01564 Mdot
.50524 .01564 Mdot
.5062 .01564 Mdot
.50715 .01564 Mdot
.5081 .01564 Mdot
.50906 .60332 Mdot
.51001 .01564 Mdot
.51096 .01564 Mdot
.51192 .01564 Mdot
.51287 .01564 Mdot
.51382 .01564 Mdot
.51478 .01564 Mdot
.51573 .01564 Mdot
.51668 .01564 Mdot
.51764 .01564 Mdot
.51859 .01564 Mdot
.51954 .01564 Mdot
.5205 .01564 Mdot
.52145 .01564 Mdot
.5224 .01564 Mdot
.52336 .01564 Mdot
.52431 .01564 Mdot
.52526 .01564 Mdot
.52622 .01564 Mdot
.52717 .01564 Mdot
.52812 .2111 Mdot
.52908 .01564 Mdot
.53003 .01564 Mdot
.53098 .01564 Mdot
.53194 .01564 Mdot
.53289 .01564 Mdot
.53384 .01564 Mdot
.5348 .01564 Mdot
.53575 .01564 Mdot
.5367 .01564 Mdot
.53766 .01564 Mdot
.53861 .01564 Mdot
.53956 .01564 Mdot
.54052 .01564 Mdot
.54147 .01564 Mdot
.54242 .01564 Mdot
.54338 .01564 Mdot
.54433 .01564 Mdot
.54528 .01564 Mdot
.54624 .01564 Mdot
.54719 .13277 Mdot
.54814 .01564 Mdot
.5491 .01564 Mdot
.55005 .01564 Mdot
.551 .01564 Mdot
.55196 .01564 Mdot
.55291 .01564 Mdot
.55386 .01564 Mdot
.55482 .01564 Mdot
.55577 .01564 Mdot
.55672 .01564 Mdot
.55768 .01564 Mdot
.55863 .01564 Mdot
.55958 .01564 Mdot
.56054 .01564 Mdot
.56149 .01564 Mdot
.56244 .01564 Mdot
.5634 .01564 Mdot
.56435 .01564 Mdot
.5653 .01564 Mdot
.56626 .09928 Mdot
.56721 .01564 Mdot
.56816 .01564 Mdot
.56912 .01564 Mdot
.57007 .01564 Mdot
.57102 .01564 Mdot
.57198 .01564 Mdot
.57293 .01564 Mdot
.57388 .01564 Mdot
.57484 .01564 Mdot
.57579 .01564 Mdot
.57674 .01564 Mdot
.5777 .01564 Mdot
.57865 .01564 Mdot
.5796 .01564 Mdot
.58056 .01564 Mdot
.58151 .01564 Mdot
.58246 .01564 Mdot
.58342 .01564 Mdot
.58437 .01564 Mdot
.58532 .08074 Mdot
.58628 .01564 Mdot
.58723 .01564 Mdot
.58818 .01564 Mdot
.58914 .01564 Mdot
.59009 .01564 Mdot
.59104 .01564 Mdot
.592 .01564 Mdot
.59295 .01564 Mdot
.5939 .01564 Mdot
.59486 .01564 Mdot
.59581 .01564 Mdot
.59676 .01564 Mdot
.59772 .01564 Mdot
.59867 .01564 Mdot
.59962 .01564 Mdot
.60058 .01564 Mdot
.60153 .01564 Mdot
.60248 .01564 Mdot
.60344 .01564 Mdot
.60439 .06899 Mdot
.60534 .01564 Mdot
.6063 .01564 Mdot
.60725 .01564 Mdot
.6082 .01564 Mdot
.60916 .01564 Mdot
.61011 .01564 Mdot
.61106 .01564 Mdot
.61202 .01564 Mdot
.61297 .01564 Mdot
.61392 .01564 Mdot
.61488 .01564 Mdot
.61583 .01564 Mdot
.61678 .01564 Mdot
.61774 .01564 Mdot
.61869 .01564 Mdot
.61964 .01564 Mdot
.6206 .01564 Mdot
.62155 .01564 Mdot
.6225 .01564 Mdot
.62346 .06091 Mdot
.62441 .01564 Mdot
.62536 .01564 Mdot
.62632 .01564 Mdot
.62727 .01564 Mdot
.62822 .01564 Mdot
.62918 .01564 Mdot
.63013 .01564 Mdot
.63108 .01564 Mdot
.63204 .01564 Mdot
.63299 .01564 Mdot
.63394 .01564 Mdot
.6349 .01564 Mdot
.63585 .01564 Mdot
.6368 .01564 Mdot
.63776 .01564 Mdot
.63871 .01564 Mdot
.63966 .01564 Mdot
.64062 .01564 Mdot
.64157 .01564 Mdot
.64252 .05503 Mdot
.64348 .01564 Mdot
.64443 .01564 Mdot
.64538 .01564 Mdot
.64634 .01564 Mdot
.64729 .01564 Mdot
.64824 .01564 Mdot
.6492 .01564 Mdot
.65015 .01564 Mdot
.6511 .01564 Mdot
.65206 .01564 Mdot
.65301 .01564 Mdot
.65396 .01564 Mdot
.65492 .01564 Mdot
.65587 .01564 Mdot
.65682 .01564 Mdot
.65778 .01564 Mdot
.65873 .01564 Mdot
.65968 .01564 Mdot
.66064 .01564 Mdot
.66159 .05058 Mdot
.66254 .01564 Mdot
.6635 .01564 Mdot
.66445 .01564 Mdot
.6654 .01564 Mdot
.66636 .01564 Mdot
.66731 .01564 Mdot
.66826 .01564 Mdot
.66922 .01564 Mdot
.67017 .01564 Mdot
.67112 .01564 Mdot
.67208 .01564 Mdot
.67303 .01564 Mdot
.67398 .01564 Mdot
.67494 .01564 Mdot
.67589 .01564 Mdot
.67684 .01564 Mdot
.6778 .01564 Mdot
.67875 .01564 Mdot
.6797 .01564 Mdot
.68066 .0471 Mdot
.68161 .01564 Mdot
.68256 .01564 Mdot
.68352 .01564 Mdot
.68447 .01564 Mdot
.68542 .01564 Mdot
.68638 .01564 Mdot
.68733 .01564 Mdot
.68828 .01564 Mdot
.68924 .01564 Mdot
.69019 .01564 Mdot
.69114 .01564 Mdot
.6921 .01564 Mdot
.69305 .01564 Mdot
.694 .01564 Mdot
.69496 .01564 Mdot
.69591 .01564 Mdot
.69686 .01564 Mdot
.69782 .01564 Mdot
.69877 .01564 Mdot
.69972 .04432 Mdot
.70068 .01564 Mdot
.70163 .01564 Mdot
.70258 .01564 Mdot
.70354 .01564 Mdot
.70449 .01564 Mdot
.70544 .01564 Mdot
.7064 .01564 Mdot
.70735 .01564 Mdot
.7083 .01564 Mdot
.70926 .01564 Mdot
.71021 .01564 Mdot
.71116 .01564 Mdot
.71212 .01564 Mdot
.71307 .01564 Mdot
.71402 .01564 Mdot
.71498 .01564 Mdot
.71593 .01564 Mdot
.71688 .01564 Mdot
.71784 .01564 Mdot
.71879 .04207 Mdot
.71974 .01564 Mdot
.7207 .01564 Mdot
.72165 .01564 Mdot
.7226 .01564 Mdot
.72356 .01564 Mdot
.72451 .01564 Mdot
.72546 .01564 Mdot
.72642 .01564 Mdot
.72737 .01564 Mdot
.72832 .01564 Mdot
.72928 .01564 Mdot
.73023 .01564 Mdot
.73118 .01564 Mdot
.73214 .01564 Mdot
.73309 .01564 Mdot
.73404 .01564 Mdot
.735 .01564 Mdot
.73595 .01564 Mdot
.7369 .01564 Mdot
.73786 .04022 Mdot
.73881 .01564 Mdot
.73976 .01564 Mdot
.74072 .01564 Mdot
.74167 .01564 Mdot
.74262 .01564 Mdot
.74358 .01564 Mdot
.74453 .01564 Mdot
.74548 .01564 Mdot
.74644 .01564 Mdot
.74739 .01564 Mdot
.74834 .01564 Mdot
.7493 .01564 Mdot
.75025 .01564 Mdot
.7512 .01564 Mdot
.75216 .01564 Mdot
.75311 .01564 Mdot
.75406 .01564 Mdot
.75502 .01564 Mdot
.75597 .01564 Mdot
.75692 .03868 Mdot
.75788 .01564 Mdot
.75883 .01564 Mdot
.75978 .01564 Mdot
.76074 .01564 Mdot
.76169 .01564 Mdot
.76264 .01564 Mdot
.7636 .01564 Mdot
.76455 .01564 Mdot
.7655 .01564 Mdot
.76646 .01564 Mdot
.76741 .01564 Mdot
.76836 .01564 Mdot
.76932 .01564 Mdot
.77027 .01564 Mdot
.77122 .01564 Mdot
.77218 .01564 Mdot
.77313 .01564 Mdot
.77408 .01564 Mdot
.77504 .01564 Mdot
.77599 .03739 Mdot
.77694 .01564 Mdot
.7779 .01564 Mdot
.77885 .01564 Mdot
.7798 .01564 Mdot
.78076 .01564 Mdot
.78171 .01564 Mdot
.78266 .01564 Mdot
.78362 .01564 Mdot
.78457 .01564 Mdot
.78552 .01564 Mdot
.78648 .01564 Mdot
.78743 .01564 Mdot
.78838 .01564 Mdot
.78934 .01564 Mdot
.79029 .01564 Mdot
.79124 .01564 Mdot
.7922 .01564 Mdot
.79315 .01564 Mdot
.7941 .01564 Mdot
.79506 .03631 Mdot
.79601 .01564 Mdot
.79696 .01564 Mdot
.79792 .01564 Mdot
.79887 .01564 Mdot
.79982 .01564 Mdot
.80078 .01564 Mdot
.80173 .01564 Mdot
.80268 .01564 Mdot
.80364 .01564 Mdot
.80459 .01564 Mdot
.80554 .01564 Mdot
.8065 .01564 Mdot
.80745 .01564 Mdot
.8084 .01564 Mdot
.80936 .01564 Mdot
.81031 .01564 Mdot
.81126 .01564 Mdot
.81222 .01564 Mdot
.81317 .01564 Mdot
.81412 .03541 Mdot
.81508 .01564 Mdot
.81603 .01564 Mdot
.81698 .01564 Mdot
.81794 .01564 Mdot
.81889 .01564 Mdot
.81984 .01564 Mdot
.8208 .01564 Mdot
.82175 .01564 Mdot
.8227 .01564 Mdot
.82366 .01564 Mdot
.82461 .01564 Mdot
.82556 .01564 Mdot
.82652 .01564 Mdot
.82747 .01564 Mdot
.82842 .01564 Mdot
.82938 .01564 Mdot
.83033 .01564 Mdot
.83128 .01564 Mdot
.83224 .01564 Mdot
.83319 .03465 Mdot
.83414 .01564 Mdot
.8351 .01564 Mdot
.83605 .01564 Mdot
.837 .01564 Mdot
.83796 .01564 Mdot
.83891 .01564 Mdot
.83986 .01564 Mdot
.84082 .01564 Mdot
.84177 .01564 Mdot
.84272 .01564 Mdot
.84368 .01564 Mdot
.84463 .01564 Mdot
.84558 .01564 Mdot
.84654 .01564 Mdot
.84749 .01564 Mdot
.84844 .01564 Mdot
.8494 .01564 Mdot
.85035 .01564 Mdot
.8513 .01564 Mdot
.85226 .03402 Mdot
.85321 .01564 Mdot
.85416 .01564 Mdot
.85512 .01564 Mdot
.85607 .01564 Mdot
.85702 .01564 Mdot
.85798 .01564 Mdot
.85893 .01564 Mdot
.85988 .01564 Mdot
.86084 .01564 Mdot
.86179 .01564 Mdot
.86274 .01564 Mdot
.8637 .01564 Mdot
.86465 .01564 Mdot
.8656 .01564 Mdot
.86656 .01564 Mdot
.86751 .01564 Mdot
.86846 .01564 Mdot
.86942 .01564 Mdot
.87037 .01564 Mdot
.87132 .0335 Mdot
.87228 .01564 Mdot
.87323 .01564 Mdot
.87418 .01564 Mdot
.87514 .01564 Mdot
.87609 .01564 Mdot
.87704 .01564 Mdot
.878 .01564 Mdot
.87895 .01564 Mdot
.8799 .01564 Mdot
.88086 .01564 Mdot
.88181 .01564 Mdot
.88276 .01564 Mdot
.88372 .01564 Mdot
.88467 .01564 Mdot
.88562 .01564 Mdot
.88658 .01564 Mdot
.88753 .01564 Mdot
.88848 .01564 Mdot
.88944 .01564 Mdot
.89039 .03308 Mdot
.89134 .01564 Mdot
.8923 .01564 Mdot
.89325 .01564 Mdot
.8942 .01564 Mdot
.89516 .01564 Mdot
.89611 .01564 Mdot
.89706 .01564 Mdot
.89802 .01564 Mdot
.89897 .01564 Mdot
.89992 .01564 Mdot
.90088 .01564 Mdot
.90183 .01564 Mdot
.90278 .01564 Mdot
.90374 .01564 Mdot
.90469 .01564 Mdot
.90564 .01564 Mdot
.9066 .01564 Mdot
.90755 .01564 Mdot
.9085 .01564 Mdot
.90946 .03276 Mdot
.91041 .01564 Mdot
.91136 .01564 Mdot
.91232 .01564 Mdot
.91327 .01564 Mdot
.91422 .01564 Mdot
.91518 .01564 Mdot
.91613 .01564 Mdot
.91708 .01564 Mdot
.91804 .01564 Mdot
.91899 .01564 Mdot
.91994 .01564 Mdot
.9209 .01564 Mdot
.92185 .01564 Mdot
.9228 .01564 Mdot
.92376 .01564 Mdot
.92471 .01564 Mdot
.92566 .01564 Mdot
.92662 .01564 Mdot
.92757 .01564 Mdot
.92852 .03252 Mdot
.92948 .01564 Mdot
.93043 .01564 Mdot
.93138 .01564 Mdot
.93234 .01564 Mdot
.93329 .01564 Mdot
.93424 .01564 Mdot
.9352 .01564 Mdot
.93615 .01564 Mdot
.9371 .01564 Mdot
.93806 .01564 Mdot
.93901 .01564 Mdot
.93996 .01564 Mdot
.94092 .01564 Mdot
.94187 .01564 Mdot
.94282 .01564 Mdot
.94378 .01564 Mdot
.94473 .01564 Mdot
.94568 .01564 Mdot
.94664 .01564 Mdot
.94759 .03237 Mdot
.94854 .01564 Mdot
.9495 .01564 Mdot
.95045 .01564 Mdot
.9514 .01564 Mdot
.95236 .01564 Mdot
.95331 .01564 Mdot
.95426 .01564 Mdot
.95522 .01564 Mdot
.95617 .01564 Mdot
.95712 .01564 Mdot
.95808 .01564 Mdot
.95903 .01564 Mdot
.95998 .01564 Mdot
.96094 .01564 Mdot
.96189 .01564 Mdot
.96284 .01564 Mdot
.9638 .01564 Mdot
.96475 .01564 Mdot
.9657 .01564 Mdot
.96666 .03229 Mdot
.96761 .01564 Mdot
.96856 .01564 Mdot
.96952 .01564 Mdot
.97047 .01564 Mdot
.97142 .01564 Mdot
.97238 .01564 Mdot
.97333 .01564 Mdot
.97428 .01564 Mdot
.97524 .01564 Mdot
.97619 .01564 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool3o`0000?ooooo0_l00004ooooo`;o00008oooool5o`0000?ooooo0_l00004oooo
o`;o00009oooool2o`0002Wooooo1Ol00003ooooo`;o00001?ooool2o`0002Gooooo0ol00003oooo
o`;o00001?ooool2o`0001[ooooo000aooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Gooooo00Co0000oooooooo
oooo0000:Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00009Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0Gooooo`00:?ooool5o`000003ooooool0003o000000?o
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001cooooo1Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Uooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0002;ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00006Oooool002kooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08ooo
ool01?l0003oooooooooool0000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000_ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Rooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Gooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Iooooo`00<?oo
ool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Rooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Gooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Tooooo`;o00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000aooooo`03o`000?oo
oooooooo00;ooooo0_l00004ooooo`;o00009?ooool3o`0000Cooooo0_l00004ooooo`;o00009ooo
ool2o`0002[ooooo0ol00004ooooo`;o00001?ooool2o`0002Kooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l0000Jooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`005Ooooooo000000/000000Oooool001Gooooo00<00000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool1
0000007ooooo000>ooooo`;o00001Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo
033ooooo00<00000ooooooooool0;oooool00`00003oooooooooo`0`ooooo`03o`000?oooooooooo
033ooooo00<00000ooooooooool07?ooool10000007ooooo000=ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool0ooooool7ooooo`4000000Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00`00003o0000ooooo`02ooooool0o`000@3o0003ooooo`7o00000@000001oooo
o`003Oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00;oooooo`3o00010?l0
00Cooooo0@000001ooooo`003Oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
00;oooooo`3o00010?l000Cooooo0@000001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo00Gooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`03oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00?ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00?ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00oooool00`3o003oooooooooo`05oooo
o`4000000Oooool000kooooo0_l00005ooooo`0300000?oooooooooo00Cooooo0`3o0002ooooo`<0
o`000_ooool30?l000;ooooo0`3o0002ooooo`<0o`000_ooool30?l000Cooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00?ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00?ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool0103o003oooooooooooooool30?l000;ooooo0`3o0002ooooo`<0o`000_ooool30?l0
00;ooooo0`3o0002ooooo`<0o`001oooool10000007ooooo000Eooooo`0300000?l0003ooooo00Co
oooo0`3o0002ooooo`<0o`000_ooool30?l000;ooooo0`3o0002ooooo`<0o`000_ooool30?l000;o
oooo0`3o0002ooooo`<0o`000_ooool30?l000?ooooo0`3o0002ooooo`<0o`000oooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`03ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`03ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`030?l000?ooooo0`3o0002ooooo`<0o`000_ooool30?l000;ooooo0`3o0002ooooo`<0
o`000_ooool30?l000;ooooo0`3o0002ooooo`<0o`000_ooool30?l000;ooooo0`3o0006ooooo`7o
00000@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`<0o`000_ooool30?l000;ooooo
0`3o0002ooooo`<0o`000_ooool30?l000;ooooo0`3o0002ooooo`<0o`000_ooool30?l000;ooooo
0`3o0003ooooo`<0o`000_ooool30?l000;ooooo0`3o0002ooooo`<0o`000oooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00?ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00?ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00`3o0002ooooo`<0o`00
0_ooool30?l000?ooooo0`3o0002ooooo`<0o`000_ooool30?l000;ooooo0`3o0002ooooo`<0o`00
0_ooool30?l000;ooooo0`3o0002ooooo`<0o`000_ooool30?l000;ooooo0`3o0007ooooo`400000
0Oooool001Gooooo00<00000ooooooooool08_ooool30?l000;ooooo0`3o0002ooooo`<0o`000ooo
ool30?l000;ooooo0`3o0002ooooo`<0o`000_ooool30?l000;ooooo0`3o0002ooooo`<0o`000ooo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00ooo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00ooo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00<0o`000_ooool30?l000;ooooo0`3o
0002ooooo`<0o`000_ooool30?l000?ooooo0`3o0002ooooo`<0o`000_ooool30?l000;ooooo0`3o
000Uooooo`4000000Oooool001Gooooo00<00000ooooooooool0??ooool30?l000;ooooo0`3o0002
ooooo`<0o`000_ooool30?l000;ooooo0`3o0003ooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool00oooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool00oooool00`3o003oooooooooo`030?l000;ooooo0`3o0002ooooo`<0o`000_ooool3
0?l000;ooooo0`3o000oooooo`4000000Oooool001Gooooo00<00000ooooooooool0A_ooool30?l0
00;ooooo0`3o0002ooooo`<0o`000_ooool30?l000?ooooo00<0o`00ooooooooool00oooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00@0o`00oooooooooooooooo0`3o0002
ooooo`<0o`000_ooool30?l000;ooooo0`3o0019ooooo`4000000Oooool001Gooooo00<00000o`00
0?ooool0D?ooool30?l000;ooooo0`3o0002ooooo`<0o`001?ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`040?l00?ooooooooooooooo`<0o`000_ooool30?l000;ooooo0`3o001Booooo`7o00000@000001
ooooo`005Oooool00`00003oooooooooo`1Eooooo`<0o`000_ooool30?l000Cooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool0103o003oooooooooooooool30?l000;ooooo0`3o001Hooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0F_ooool30?l000;ooooo0`3o0004ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool0103o003oooooooooooooool30?l000;ooooo0`3o001M
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0Goooool30?l000Cooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`040?l00?ooooooooooooooo`<0o`00H_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo05oooooo0`3o0002ooooo`<0o`001?ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool0103o
003oooooooooooooool30?l000;ooooo0`3o001Rooooo`4000000Oooool001Gooooo00<00000o`00
0?ooool0I?ooool30?l000Cooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00@0o`00oooooooooooooooo0`3o001Vooooo`7o00000@000001
ooooo`005Oooool00`00003oooooooooo`1Tooooo`<0o`001?ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool0103o003oooooooooooooool3
0?l006Oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1Yooooo`<0o`001?ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`040?l00?ooooooooooooooo`<0o`00K?ooool10000007ooooo000Eoooo
o`0300000?oooooooooo06Wooooo0`3o0004ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00@0o`00oooo
oooooooooooo0`3o001/ooooo`4000000Oooool001Gooooo00<00000ooooooooool0JOooool30?l0
00Cooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool0103o003oooooooooooooool30?l006cooooo0@000001
ooooo`005Oooool00`00003o0000ooooo`1`ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool0Koooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0L?ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo073ooooo0@000001ooooo`001oooool3o`0000Cooooo
0_l00005ooooo`0300000?oooooooooo06kooooo0`3o0004ooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool00_ooool0103o003oooooooooooooool30?l0077ooooo0@000001ooooo`00
1_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`1^ooooo`<0o`001?ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
00;ooooo00@0o`00oooooooooooooooo0`3o001aooooo`4000000Oooool000[ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo06kooooo0`3o0004
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool0103o003ooooooooooooo
ool30?l0077ooooo0@000001ooooo`002_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00<00000o`000?ooool0MOooool00`3o003oooooooooo`02ooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool0M?ooool1o`00004000000Oooool000Kooooo1?l00003
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0MOooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0MOooool10000007ooooo0006
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`1eooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`1eooooo`4000000Oooool000Kooooo1Ol00003ooooo`;o00001Oooool00`00003oooooooooo`1e
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1e
ooooo`4000000Oooool001Gooooo00<00000o`000?ooool0MOooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0M?ooool1o`00004000000Oooool001Go
oooo00<00000ooooooooool0MOooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;o
oooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;o
oooo00<0o`00ooooooooool0MOooool10000007ooooo000Eooooo`0300000?oooooooooo07?ooooo
0`3o0004ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`02ooooo`040?l00?ooooooooooooooo`<0o`00M_ooool10000007ooooo000Eooooo`030000
0?oooooooooo07?ooooo0`3o0004ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`02ooooo`040?l00?ooooooooooooooo`<0o`00M_ooool10000007o
oooo000Eooooo`0300000?oooooooooo07?ooooo0`3o0004ooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`040?l00?ooooooooooooooo`<0
o`00M_ooool10000007ooooo000Eooooo`0300000?l0003ooooo07[ooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
NOooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`1jooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1j
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`02oooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1joooo
o`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003oooooooooo`02ooooo`03
0?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1jooooo`40
00000Oooool001Gooooo00<00000o`000?ooool0N_ooool00`3o003oooooooooo`02ooooo`030?l0
0?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1iooooo`7o0000
0@000001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00;ooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07[ooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07[ooooo0@000001
ooooo`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07[ooooo0@000001oooo
o`005Oooool00`00003oooooooooo`1jooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`00
5Oooool00`00003o0000ooooo`1jooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07Wooooo0Ol000010000007ooooo
000Eooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0N_ooool10000007ooooo000E
ooooo`0300000?oooooooooo07[ooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0N_ooool10000007ooooo00001?oo
oooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0N_ooool0
0`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`1jooooo`4000000Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0N_oo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`1jooooo`4000000Oooool000;ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000?ooool0
N_ooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`1iooooo`7o00000@000001ooooo`000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`1jooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`000_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00
003oooooooooo`1jooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`02ooooo`030?l00?oooooooooo07[ooooo0@000001ooooo`0000?oooooo`000?l0
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool0N?ooool30?l000Cooooo00<0o`00ooooooooool00_ooool0103o003ooooooooooooo
ool30?l007_ooooo0@000001ooooo`000_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2
o`0000Gooooo00<00000ooooooooool0N?ooool30?l000Cooooo00<0o`00ooooooooool00_ooool0
103o003oooooooooooooool30?l007_ooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1h
ooooo`<0o`001?ooool00`3o003oooooooooo`02ooooo`040?l00?ooooooooooooooo`<0o`00N_oo
ool1o`00004000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1ooooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`03
00000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`40
00000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l0
0?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1oooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001Gooooo00<00000
ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001
ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0
Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Ooo
ool00`00003o0000ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0O_oo
ool1o`00004000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1ooooo
o`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`03
00000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`40
00000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l0
0?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1oooooo`030?l00?oo
oooooooo00;ooooo00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001Gooooo00<00000
ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001
ooooo`0000Coooooo`000?l0003o00000oooool3o`0000Cooooo0_l00005ooooo`0300000?oooooo
oooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool0
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0
o`00ooooooooool0Ooooool10000007ooooo0002ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo07oooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000;ooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<0
0000o`000?ooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol0
00010000007ooooo0002ooooo`04o`000?ooooooooooooooo`Co00000oooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`1oooooo`4000000Oooool00003ooooool0003o000000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool0
0_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000;ooooo00Co0000oooooooooooooooo
1Ol00003ooooo`;o00001Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000
o`000?ooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol00001
0000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo
000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`1oooooo`4000000Oooool001Gooooo00<00000o`000?ooool0Ooooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo07kooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo
07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Go
oooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oo
oooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?l0003ooooo07oooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`1nooooo`7o00000@000001ooooo`005Oooool0
0`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool1
0000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo
000Eooooo`0300000?l0003ooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`1nooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooo
oooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo
07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000Go
00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo07oooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool00005ooooool0003oooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001
ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003o0000ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0
o`00ooooooooool0O_ooool1o`00004000000Oooool000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003ooooo
ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo
00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`1oooooo`4000000Oooool00005o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0Oooo
ool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`0000Cooooo
o`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo07oooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000
o`000?ooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol00001
0000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo
000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`1oooooo`4000000Oooool001Gooooo00<00000o`000?ooool0Ooooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo07kooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo
07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Go
oooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oo
oooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo
00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0
o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000
o`000?ooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol00001
0000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o
003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo
000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooooooo
o`1oooooo`4000000Oooool001Gooooo00<00000o`000?ooool0Ooooool00`3o003oooooooooo`02
ooooo`030?l00?oooooooooo07kooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo
07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool000Go
00000_ooool3o`0000Cooooo0_l00005ooooo`0300000?oooooooooo07oooooo00<0o`00oooooooo
ool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool00007ooooool0003oooooooooool0
003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool1
0000007ooooo0002ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`1oooooo`4000000Oooool000?ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`000?ooool0Ooooool0
0`3o003oooooooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol000010000007ooooo00001_l0
003ooooooooooooooooo0000ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`400000
0Oooool00007o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo
07oooooo0@000001ooooo`0000Coooooo`000?l0003o00000_ooool5o`0000?ooooo0_l00005oooo
o`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1ooooo
o`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`03
0?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1oooooo`030?l0
0?oooooooooo00;ooooo00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001Gooooo00<0
0000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`00
5Oooool00`00003o0000ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0
O_ooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1o
ooooo`030?l00?oooooooooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eoooo
o`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1ooooo
o`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`03
0?l00?oooooooooo07oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1oooooo`030?l0
0?oooooooooo00;ooooo00<0o`00ooooooooool0O_ooool1o`00004000000Oooool001Gooooo00<0
0000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00
ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Oooool001Gooooo00<00000o`000?oo
ool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol000010000007o
oooo000Eooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`1oooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool00`3o003ooooooooo
o`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`0000Coooooo`000?l0003o00001?oo
ool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_oo
ool00`3o003oooooooooo`1oooooo`4000000Oooool00005o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooooooo07oooooo0@000001ooooo`00
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_ooool00`00003o0000ooooo`1oooooo`030?l00?oooooooooo00;ooooo00<0o`00oooo
ooooool0O_ooool1o`00004000000Oooool000;ooooo0_l00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1oooooo`030?l00?oooooo
oooo00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo0004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Ooo
ool00005o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`03
0?l00?oooooooooo07oooooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Co
oooo0_l00005ooooo`0300000?oooooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003o
ooooooooo`1oooooo`4000000Oooool001Gooooo00<00000o`000?ooool0Ooooool00`3o003ooooo
ooooo`02ooooo`030?l00?oooooooooo07kooooo0Ol000010000007ooooo000Eooooo`0300000?oo
oooooooo07oooooo00<0o`00ooooooooool00_ooool00`3o003oooooooooo`1oooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0Ooooool00`3o003oooooooooo`02ooooo`030?l00?oooooo
oooo07oooooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`030?l00?oooooooooo
00;ooooo00<0o`00ooooooooool0Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07ko
oooo0`3o0002ooooo`<0o`00P?ooool10000007ooooo000Eooooo`0300000?l0003ooooo07kooooo
0`3o0002ooooo`<0o`00Ooooool1o`00004000000Oooool001Gooooo00<00000ooooooooool0O_oo
ool30?l000;ooooo0`3o0020ooooo`4000000Oooool001Gooooo00<00000ooooooooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool1
0000007ooooo000Eooooool000002`000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-608.193, -33.5571, 3.95006, \
2.0367}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example #5: single pulse", "Subsection"],

Cell[CellGroupData[{

Cell["Continuous-time waveform", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f1[t_] := 
        UnitStep[t - 9/20] - 
          UnitStep[t - 11/20];\)\), "\[IndentingNewLine]", 
    \(\(Plot[f1[t], {t, 0, 1}, PlotPoints \[Rule] 100, \ 
        PlotStyle \[Rule] Blue];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.4)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.6)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.8)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.03318 .01472 L
.04339 .01472 L
.05298 .01472 L
.06221 .01472 L
.07203 .01472 L
.08148 .01472 L
.09153 .01472 L
.10121 .01472 L
.11052 .01472 L
.12043 .01472 L
.12997 .01472 L
.13914 .01472 L
.14891 .01472 L
.15831 .01472 L
.1683 .01472 L
.17793 .01472 L
.18719 .01472 L
.19704 .01472 L
.20653 .01472 L
.21661 .01472 L
.22632 .01472 L
.23566 .01472 L
.2456 .01472 L
.25518 .01472 L
.26438 .01472 L
.27418 .01472 L
.28361 .01472 L
.29364 .01472 L
.3033 .01472 L
.31259 .01472 L
.32248 .01472 L
.332 .01472 L
.34115 .01472 L
.3509 .01472 L
.36028 .01472 L
.37025 .01472 L
.37985 .01472 L
.38909 .01472 L
.39893 .01472 L
.40839 .01472 L
.41845 .01472 L
.42814 .01472 L
.43747 .01472 L
.44219 .01472 L
.44739 .01472 L
.44977 .01472 L
.45108 .01472 L
.45173 .01472 L
.45204 .01472 L
Mistroke
.45232 .01472 L
.45261 .60332 L
.45288 .60332 L
.45348 .60332 L
.45474 .60332 L
.45694 .60332 L
.4663 .60332 L
.47625 .60332 L
.48584 .60332 L
.49506 .60332 L
.50487 .60332 L
.51431 .60332 L
.52435 .60332 L
.53403 .60332 L
.53845 .60332 L
.54097 .60332 L
.54333 .60332 L
.54564 .60332 L
.54628 .60332 L
.54694 .60332 L
.54722 .60332 L
.54751 .60332 L
.54768 .01472 L
.54783 .01472 L
.54813 .01472 L
.55323 .01472 L
.56293 .01472 L
.57227 .01472 L
.5822 .01472 L
.59177 .01472 L
.60097 .01472 L
.61076 .01472 L
.62018 .01472 L
.6302 .01472 L
.63985 .01472 L
.64914 .01472 L
.65902 .01472 L
.66853 .01472 L
.67767 .01472 L
.68741 .01472 L
.69678 .01472 L
.70675 .01472 L
.71635 .01472 L
.72558 .01472 L
.7354 .01472 L
.74486 .01472 L
.75491 .01472 L
.7646 .01472 L
.77391 .01472 L
.78382 .01472 L
Mistroke
.79337 .01472 L
.80255 .01472 L
.81232 .01472 L
.82172 .01472 L
.83172 .01472 L
.84135 .01472 L
.85062 .01472 L
.86047 .01472 L
.86996 .01472 L
.88005 .01472 L
.88977 .01472 L
.89912 .01472 L
.90906 .01472 L
.91864 .01472 L
.92785 .01472 L
.93766 .01472 L
.94709 .01472 L
.95712 .01472 L
.96679 .01472 L
.97609 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006_ooool2o`0002_ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00008oooool2
o`0000Cooooo00?o0000ooooooooool00oooool3o`0002Cooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo0ol0000Tooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000:_ooool3
o`0000Oooooo000Iooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool0000Rooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool08_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003ooooo
ooooo`06ooooo`006Oooool01?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00007ooooo`Go00008oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003oooooooooo`06ooooo`00
6Oooool01?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool08Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002Cooooo00Co
0000oooooooooooo00001oooool4o`0002?ooooo00Co0000oooooooooooo00002?ooool3o`0002_o
oooo00?o0000ooooooooool01_ooool001Wooooo00Co0000oooooooooooo0000:Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000008_ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000002Cooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`0Tooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Zoooo
o`03o`000?oooooooooo00Kooooo000Iooooo`04o`000?ooooooooooo`0002Wooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002;ooooo00Co0000oooooooooooo0000
2Oooool2o`0002Cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`0Sooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Yooooo`;o00002?ooool0
01[ooooo0_l0000[ooooo`;o00002Oooool3o`0002Cooooo0_l0000;ooooo`03o`000?oooooooooo
02?ooooo0_l0000:ooooo`;o00009?ooool2o`0000Wooooo0ol0000[ooooo`03o`000?oooooooooo
00Kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooo
oooo00002ol00001ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00`00003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00`00003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool00oooool1o`00007o
oooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00`00003o
ooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00<00000ooooooooool0<?ooool00`00003o
ooooooooo`0_ooooo`0300000?oooooooooo033ooooo00<00000ooooooooool00oooool1o`00007o
oooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0ooooool7ooooo`7o
00000Oooool000gooooo00Co0000oooooooooooo00001?ooool3o`0000?oooooL_l00?l00`000?oo
ooooooooo`0Fooooog80003o00?o003oooooooooool00_ooool2o`00007ooooo000=ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`03
0000oooooooooooo07Gooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o
00000Oooool000kooooo0_l00005ooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool0
5_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOoo
ool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`00
0?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?oo
ooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool2o`0007Kooooo
00<0003oooooooooool05_ooool00`000?ooooooooooo`1dooooo`;o00000Oooool001Gooooo00?o
0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003o
ooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003ooooo
ooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0
MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_oo
ool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo0_l0001fooooo`030000oooooooo
oooo01Kooooo00<0003oooooooooool0M?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo
07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Go
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo
00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0
003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003ooooo
ooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003ooooooooo
ool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo0_l0001fooooo`030000
oooooooooooo01Kooooo00<0003oooooooooool0M?ooool2o`00007ooooo000Eooooo`03o`000?oo
oooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooo
oooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo
01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Go
oooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo
0Ol00001ooooo`000_ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`00
0?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o0000
0Oooool00005ooooool0003oooooooooool000002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o
00000Oooool00005ooooool0003oooooooooool000002Oooool00ol0003oooooooooo`04ooooo`?o
0000MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Cooooo0_l00001ooooo`00
00Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`00
00Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00
007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1e
ooooo`7o00000Oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`1eoooo
o`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000
oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooo
oooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`;o0000M_ooool0
0`000?ooooooooooo`0Fooooo`030000oooooooooooo07Cooooo0_l00001ooooo`005Oooool00ol0
003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?oo
ooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?oooooo
ooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1e
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Foooo
o`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03
0000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`;o0000
M_ooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Cooooo0_l00001ooooo`005Ooo
ool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool0
0`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`00
0?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?oooooo
ooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?oooooooooo
o`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool2o`0007Kooooo00<0003o
ooooooooool05_ooool00`000?ooooooooooo`1dooooo`;o00000Oooool001Gooooo00?o0000oooo
ooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003ooooooooo
ool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool0
5_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOoo
ool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1
o`00007ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0
003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00
007ooooo00001Ooooooo0000oooooooooooo000000[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00
007ooooo00001Ooooooo0000oooooooooooo000000Oooooo1Ol00004ooooo`03o`00000000000000
07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1dooooo`;o00000Oooool00005
ooooool0003oooooooooool000001oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool0
0005ooooool0003oooooooooool000002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool0
0005ooooool0003oooooooooool000002Oooool2o`0000Gooooo00?o0000ooooooooool0MOooool0
0`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`000_ooool2o`00
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo
01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Go
oooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0
003oooooooooool0MOooool1o`00007ooooo000Eooooo`;o0000M_ooool00`000?ooooooooooo`0F
ooooo`030000oooooooooooo07Cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1eoooo
o`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000
oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooo
oooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo
07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Ko
oooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`;o0000M_ooool00`000?oooooo
ooooo`0Fooooo`030000oooooooooooo07Cooooo0_l00001ooooo`005Oooool00ol0003ooooooooo
o`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1e
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Foooo
o`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`03
0000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooo
oooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooo
oooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`;o0000M_ooool00`00
0?ooooooooooo`0Fooooo`030000oooooooooooo07Cooooo0_l00001ooooo`005Oooool00ol0003o
ooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?oooooo
ooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?oooooooooo
o`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1e
ooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo0002oooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1eoooo
o`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo00001Ooooooo
0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool0
0005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol0
0001ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool00ol0000000000000
001eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0M?ooool2o`00007ooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo0000
1Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo0002
ooooo`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0F
ooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eoooo
o`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000
oooooooooooo07Gooooo0Ol00001ooooo`005Oooool2o`0007Kooooo00<0003oooooooooool05_oo
ool00`000?ooooooooooo`1dooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0MOooool0
0`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?oo
ooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?oooooo
ooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1e
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Foooo
o`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool2o`0007Kooooo00<0003ooooooooo
ool05_ooool00`000?ooooooooooo`1dooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0
MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool0
0`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`00
0?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?oooooo
ooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?oooooooooo
o`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool2o`0007Kooooo00<0003o
ooooooooool05_ooool00`000?ooooooooooo`1dooooo`;o00000Oooool001Gooooo00?o0000oooo
ooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003ooooooooo
ool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool0
5_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOoo
ool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`000_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0MOooool0
0`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`0000Goooooo`00
0?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo0000
1Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o0000
0Oooool00005ooooool0003oooooooooool000002?ooool3o`0000Gooooo00?o0000000000000000
MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Cooooo0_l00001ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007o
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eoooo
o`7o00000Oooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`1eooooo`03
0000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooo
oooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000oooooooo
oooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool001Go
oooo0_l0001fooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0M?ooool2o`00007o
oooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?oooooo
ooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?oooooooooo
o`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1e
ooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?ooooooooooo`1eoooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`03
0000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eooooo`030000
oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`;o0000M_oo
ool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Cooooo0_l00001ooooo`005Oooool0
0ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`00
0?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?oo
ooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_ooool00`000?oooooooooo
o`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool00`000?ooooooooooo`0F
ooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1eoooo
o`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00007ooooo000Eooooo`;o
0000M_ooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Cooooo0_l00001ooooo`00
5Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0
MOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Gooooo00<0003oooooooooool05_oo
ool00`000?ooooooooooo`1eooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0MOooool0
0`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1eooooo`030000oooooooooooo01Kooooo00<0003oooooooooool0MOooool1o`00
007ooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`1eooooo`030000oooooooooooo01Ko
oooo00<0003oooooooooool0MOooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0MOooool00`000?ooooooooooo`0Fooooo`030000oooooooooooo07Gooooo
0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo00<0
003oooooooooool05_ooool00`000?ooooooooooo`1eooooo`7o00000Oooool000kooooo00?o0000
ooooooooool01?ooool00ol0000000000000001eooooo`03o`00o`000?l0003o01<0003o0ol00?l0
0`000?ooooooooooo`1dooooo`;o00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooo`Oooooo0Ol00001ooooo`003Oooool2o`0000Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool00oooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0oooool1o`00007ooooo000Eoooooooo00002ol00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.10966, -0.103856, \
0.00395636, 0.00640152}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sampled continuous-time waveform\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(sampleRate = 1000;\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(signal\  = \ 
        Table[f1[t]\ , {t, 0, 1, 1/\((sampleRate - 1)\)}]\  // \ 
          N;\)\), "\n", 
    \(\(ListPlot[signal, \ PlotStyle \[Rule] Blue];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000952381 0.0147151 0.588604 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -12 -9 ]
[.97619 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(200)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(400)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(600)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(800)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.4)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.6)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.8)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02476 .01472 m
.02571 .01472 L
.02667 .01472 L
.02762 .01472 L
.02857 .01472 L
.02952 .01472 L
.03048 .01472 L
.03143 .01472 L
.03238 .01472 L
.03333 .01472 L
.03429 .01472 L
.03524 .01472 L
.03619 .01472 L
.03714 .01472 L
.0381 .01472 L
.03905 .01472 L
.04 .01472 L
.04095 .01472 L
.0419 .01472 L
.04286 .01472 L
.04381 .01472 L
.04476 .01472 L
.04571 .01472 L
.04667 .01472 L
.04762 .01472 L
.04857 .01472 L
.04952 .01472 L
.05048 .01472 L
.05143 .01472 L
.05238 .01472 L
.05333 .01472 L
.05429 .01472 L
.05524 .01472 L
.05619 .01472 L
.05714 .01472 L
.0581 .01472 L
.05905 .01472 L
.06 .01472 L
.06095 .01472 L
.0619 .01472 L
.06286 .01472 L
.06381 .01472 L
.06476 .01472 L
.06571 .01472 L
.06667 .01472 L
.06762 .01472 L
.06857 .01472 L
.06952 .01472 L
.07048 .01472 L
.07143 .01472 L
Mistroke
.07238 .01472 L
.07333 .01472 L
.07429 .01472 L
.07524 .01472 L
.07619 .01472 L
.07714 .01472 L
.0781 .01472 L
.07905 .01472 L
.08 .01472 L
.08095 .01472 L
.0819 .01472 L
.08286 .01472 L
.08381 .01472 L
.08476 .01472 L
.08571 .01472 L
.08667 .01472 L
.08762 .01472 L
.08857 .01472 L
.08952 .01472 L
.09048 .01472 L
.09143 .01472 L
.09238 .01472 L
.09333 .01472 L
.09429 .01472 L
.09524 .01472 L
.09619 .01472 L
.09714 .01472 L
.0981 .01472 L
.09905 .01472 L
.1 .01472 L
.10095 .01472 L
.1019 .01472 L
.10286 .01472 L
.10381 .01472 L
.10476 .01472 L
.10571 .01472 L
.10667 .01472 L
.10762 .01472 L
.10857 .01472 L
.10952 .01472 L
.11048 .01472 L
.11143 .01472 L
.11238 .01472 L
.11333 .01472 L
.11429 .01472 L
.11524 .01472 L
.11619 .01472 L
.11714 .01472 L
.1181 .01472 L
.11905 .01472 L
Mistroke
.12 .01472 L
.12095 .01472 L
.1219 .01472 L
.12286 .01472 L
.12381 .01472 L
.12476 .01472 L
.12571 .01472 L
.12667 .01472 L
.12762 .01472 L
.12857 .01472 L
.12952 .01472 L
.13048 .01472 L
.13143 .01472 L
.13238 .01472 L
.13333 .01472 L
.13429 .01472 L
.13524 .01472 L
.13619 .01472 L
.13714 .01472 L
.1381 .01472 L
.13905 .01472 L
.14 .01472 L
.14095 .01472 L
.1419 .01472 L
.14286 .01472 L
.14381 .01472 L
.14476 .01472 L
.14571 .01472 L
.14667 .01472 L
.14762 .01472 L
.14857 .01472 L
.14952 .01472 L
.15048 .01472 L
.15143 .01472 L
.15238 .01472 L
.15333 .01472 L
.15429 .01472 L
.15524 .01472 L
.15619 .01472 L
.15714 .01472 L
.1581 .01472 L
.15905 .01472 L
.16 .01472 L
.16095 .01472 L
.1619 .01472 L
.16286 .01472 L
.16381 .01472 L
.16476 .01472 L
.16571 .01472 L
.16667 .01472 L
Mistroke
.16762 .01472 L
.16857 .01472 L
.16952 .01472 L
.17048 .01472 L
.17143 .01472 L
.17238 .01472 L
.17333 .01472 L
.17429 .01472 L
.17524 .01472 L
.17619 .01472 L
.17714 .01472 L
.1781 .01472 L
.17905 .01472 L
.18 .01472 L
.18095 .01472 L
.1819 .01472 L
.18286 .01472 L
.18381 .01472 L
.18476 .01472 L
.18571 .01472 L
.18667 .01472 L
.18762 .01472 L
.18857 .01472 L
.18952 .01472 L
.19048 .01472 L
.19143 .01472 L
.19238 .01472 L
.19333 .01472 L
.19429 .01472 L
.19524 .01472 L
.19619 .01472 L
.19714 .01472 L
.1981 .01472 L
.19905 .01472 L
.2 .01472 L
.20095 .01472 L
.2019 .01472 L
.20286 .01472 L
.20381 .01472 L
.20476 .01472 L
.20571 .01472 L
.20667 .01472 L
.20762 .01472 L
.20857 .01472 L
.20952 .01472 L
.21048 .01472 L
.21143 .01472 L
.21238 .01472 L
.21333 .01472 L
.21429 .01472 L
Mistroke
.21524 .01472 L
.21619 .01472 L
.21714 .01472 L
.2181 .01472 L
.21905 .01472 L
.22 .01472 L
.22095 .01472 L
.2219 .01472 L
.22286 .01472 L
.22381 .01472 L
.22476 .01472 L
.22571 .01472 L
.22667 .01472 L
.22762 .01472 L
.22857 .01472 L
.22952 .01472 L
.23048 .01472 L
.23143 .01472 L
.23238 .01472 L
.23333 .01472 L
.23429 .01472 L
.23524 .01472 L
.23619 .01472 L
.23714 .01472 L
.2381 .01472 L
.23905 .01472 L
.24 .01472 L
.24095 .01472 L
.2419 .01472 L
.24286 .01472 L
.24381 .01472 L
.24476 .01472 L
.24571 .01472 L
.24667 .01472 L
.24762 .01472 L
.24857 .01472 L
.24952 .01472 L
.25048 .01472 L
.25143 .01472 L
.25238 .01472 L
.25333 .01472 L
.25429 .01472 L
.25524 .01472 L
.25619 .01472 L
.25714 .01472 L
.2581 .01472 L
.25905 .01472 L
.26 .01472 L
.26095 .01472 L
.2619 .01472 L
Mistroke
.26286 .01472 L
.26381 .01472 L
.26476 .01472 L
.26571 .01472 L
.26667 .01472 L
.26762 .01472 L
.26857 .01472 L
.26952 .01472 L
.27048 .01472 L
.27143 .01472 L
.27238 .01472 L
.27333 .01472 L
.27429 .01472 L
.27524 .01472 L
.27619 .01472 L
.27714 .01472 L
.2781 .01472 L
.27905 .01472 L
.28 .01472 L
.28095 .01472 L
.2819 .01472 L
.28286 .01472 L
.28381 .01472 L
.28476 .01472 L
.28571 .01472 L
.28667 .01472 L
.28762 .01472 L
.28857 .01472 L
.28952 .01472 L
.29048 .01472 L
.29143 .01472 L
.29238 .01472 L
.29333 .01472 L
.29429 .01472 L
.29524 .01472 L
.29619 .01472 L
.29714 .01472 L
.2981 .01472 L
.29905 .01472 L
.3 .01472 L
.30095 .01472 L
.3019 .01472 L
.30286 .01472 L
.30381 .01472 L
.30476 .01472 L
.30571 .01472 L
.30667 .01472 L
.30762 .01472 L
.30857 .01472 L
.30952 .01472 L
Mistroke
.31048 .01472 L
.31143 .01472 L
.31238 .01472 L
.31333 .01472 L
.31429 .01472 L
.31524 .01472 L
.31619 .01472 L
.31714 .01472 L
.3181 .01472 L
.31905 .01472 L
.32 .01472 L
.32095 .01472 L
.3219 .01472 L
.32286 .01472 L
.32381 .01472 L
.32476 .01472 L
.32571 .01472 L
.32667 .01472 L
.32762 .01472 L
.32857 .01472 L
.32952 .01472 L
.33048 .01472 L
.33143 .01472 L
.33238 .01472 L
.33333 .01472 L
.33429 .01472 L
.33524 .01472 L
.33619 .01472 L
.33714 .01472 L
.3381 .01472 L
.33905 .01472 L
.34 .01472 L
.34095 .01472 L
.3419 .01472 L
.34286 .01472 L
.34381 .01472 L
.34476 .01472 L
.34571 .01472 L
.34667 .01472 L
.34762 .01472 L
.34857 .01472 L
.34952 .01472 L
.35048 .01472 L
.35143 .01472 L
.35238 .01472 L
.35333 .01472 L
.35429 .01472 L
.35524 .01472 L
.35619 .01472 L
.35714 .01472 L
Mistroke
.3581 .01472 L
.35905 .01472 L
.36 .01472 L
.36095 .01472 L
.3619 .01472 L
.36286 .01472 L
.36381 .01472 L
.36476 .01472 L
.36571 .01472 L
.36667 .01472 L
.36762 .01472 L
.36857 .01472 L
.36952 .01472 L
.37048 .01472 L
.37143 .01472 L
.37238 .01472 L
.37333 .01472 L
.37429 .01472 L
.37524 .01472 L
.37619 .01472 L
.37714 .01472 L
.3781 .01472 L
.37905 .01472 L
.38 .01472 L
.38095 .01472 L
.3819 .01472 L
.38286 .01472 L
.38381 .01472 L
.38476 .01472 L
.38571 .01472 L
.38667 .01472 L
.38762 .01472 L
.38857 .01472 L
.38952 .01472 L
.39048 .01472 L
.39143 .01472 L
.39238 .01472 L
.39333 .01472 L
.39429 .01472 L
.39524 .01472 L
.39619 .01472 L
.39714 .01472 L
.3981 .01472 L
.39905 .01472 L
.4 .01472 L
.40095 .01472 L
.4019 .01472 L
.40286 .01472 L
.40381 .01472 L
.40476 .01472 L
Mistroke
.40571 .01472 L
.40667 .01472 L
.40762 .01472 L
.40857 .01472 L
.40952 .01472 L
.41048 .01472 L
.41143 .01472 L
.41238 .01472 L
.41333 .01472 L
.41429 .01472 L
.41524 .01472 L
.41619 .01472 L
.41714 .01472 L
.4181 .01472 L
.41905 .01472 L
.42 .01472 L
.42095 .01472 L
.4219 .01472 L
.42286 .01472 L
.42381 .01472 L
.42476 .01472 L
.42571 .01472 L
.42667 .01472 L
.42762 .01472 L
.42857 .01472 L
.42952 .01472 L
.43048 .01472 L
.43143 .01472 L
.43238 .01472 L
.43333 .01472 L
.43429 .01472 L
.43524 .01472 L
.43619 .01472 L
.43714 .01472 L
.4381 .01472 L
.43905 .01472 L
.44 .01472 L
.44095 .01472 L
.4419 .01472 L
.44286 .01472 L
.44381 .01472 L
.44476 .01472 L
.44571 .01472 L
.44667 .01472 L
.44762 .01472 L
.44857 .01472 L
.44952 .01472 L
.45048 .01472 L
.45143 .01472 L
.45238 .01472 L
Mistroke
.45333 .60332 L
.45429 .60332 L
.45524 .60332 L
.45619 .60332 L
.45714 .60332 L
.4581 .60332 L
.45905 .60332 L
.46 .60332 L
.46095 .60332 L
.4619 .60332 L
.46286 .60332 L
.46381 .60332 L
.46476 .60332 L
.46571 .60332 L
.46667 .60332 L
.46762 .60332 L
.46857 .60332 L
.46952 .60332 L
.47048 .60332 L
.47143 .60332 L
.47238 .60332 L
.47333 .60332 L
.47429 .60332 L
.47524 .60332 L
.47619 .60332 L
.47714 .60332 L
.4781 .60332 L
.47905 .60332 L
.48 .60332 L
.48095 .60332 L
.4819 .60332 L
.48286 .60332 L
.48381 .60332 L
.48476 .60332 L
.48571 .60332 L
.48667 .60332 L
.48762 .60332 L
.48857 .60332 L
.48952 .60332 L
.49048 .60332 L
.49143 .60332 L
.49238 .60332 L
.49333 .60332 L
.49429 .60332 L
.49524 .60332 L
.49619 .60332 L
.49714 .60332 L
.4981 .60332 L
.49905 .60332 L
.5 .60332 L
Mistroke
.50095 .60332 L
.5019 .60332 L
.50286 .60332 L
.50381 .60332 L
.50476 .60332 L
.50571 .60332 L
.50667 .60332 L
.50762 .60332 L
.50857 .60332 L
.50952 .60332 L
.51048 .60332 L
.51143 .60332 L
.51238 .60332 L
.51333 .60332 L
.51429 .60332 L
.51524 .60332 L
.51619 .60332 L
.51714 .60332 L
.5181 .60332 L
.51905 .60332 L
.52 .60332 L
.52095 .60332 L
.5219 .60332 L
.52286 .60332 L
.52381 .60332 L
.52476 .60332 L
.52571 .60332 L
.52667 .60332 L
.52762 .60332 L
.52857 .60332 L
.52952 .60332 L
.53048 .60332 L
.53143 .60332 L
.53238 .60332 L
.53333 .60332 L
.53429 .60332 L
.53524 .60332 L
.53619 .60332 L
.53714 .60332 L
.5381 .60332 L
.53905 .60332 L
.54 .60332 L
.54095 .60332 L
.5419 .60332 L
.54286 .60332 L
.54381 .60332 L
.54476 .60332 L
.54571 .60332 L
.54667 .60332 L
.54762 .60332 L
Mistroke
.54857 .01472 L
.54952 .01472 L
.55048 .01472 L
.55143 .01472 L
.55238 .01472 L
.55333 .01472 L
.55429 .01472 L
.55524 .01472 L
.55619 .01472 L
.55714 .01472 L
.5581 .01472 L
.55905 .01472 L
.56 .01472 L
.56095 .01472 L
.5619 .01472 L
.56286 .01472 L
.56381 .01472 L
.56476 .01472 L
.56571 .01472 L
.56667 .01472 L
.56762 .01472 L
.56857 .01472 L
.56952 .01472 L
.57048 .01472 L
.57143 .01472 L
.57238 .01472 L
.57333 .01472 L
.57429 .01472 L
.57524 .01472 L
.57619 .01472 L
.57714 .01472 L
.5781 .01472 L
.57905 .01472 L
.58 .01472 L
.58095 .01472 L
.5819 .01472 L
.58286 .01472 L
.58381 .01472 L
.58476 .01472 L
.58571 .01472 L
.58667 .01472 L
.58762 .01472 L
.58857 .01472 L
.58952 .01472 L
.59048 .01472 L
.59143 .01472 L
.59238 .01472 L
.59333 .01472 L
.59429 .01472 L
.59524 .01472 L
Mistroke
.59619 .01472 L
.59714 .01472 L
.5981 .01472 L
.59905 .01472 L
.6 .01472 L
.60095 .01472 L
.6019 .01472 L
.60286 .01472 L
.60381 .01472 L
.60476 .01472 L
.60571 .01472 L
.60667 .01472 L
.60762 .01472 L
.60857 .01472 L
.60952 .01472 L
.61048 .01472 L
.61143 .01472 L
.61238 .01472 L
.61333 .01472 L
.61429 .01472 L
.61524 .01472 L
.61619 .01472 L
.61714 .01472 L
.6181 .01472 L
.61905 .01472 L
.62 .01472 L
.62095 .01472 L
.6219 .01472 L
.62286 .01472 L
.62381 .01472 L
.62476 .01472 L
.62571 .01472 L
.62667 .01472 L
.62762 .01472 L
.62857 .01472 L
.62952 .01472 L
.63048 .01472 L
.63143 .01472 L
.63238 .01472 L
.63333 .01472 L
.63429 .01472 L
.63524 .01472 L
.63619 .01472 L
.63714 .01472 L
.6381 .01472 L
.63905 .01472 L
.64 .01472 L
.64095 .01472 L
.6419 .01472 L
.64286 .01472 L
Mistroke
.64381 .01472 L
.64476 .01472 L
.64571 .01472 L
.64667 .01472 L
.64762 .01472 L
.64857 .01472 L
.64952 .01472 L
.65048 .01472 L
.65143 .01472 L
.65238 .01472 L
.65333 .01472 L
.65429 .01472 L
.65524 .01472 L
.65619 .01472 L
.65714 .01472 L
.6581 .01472 L
.65905 .01472 L
.66 .01472 L
.66095 .01472 L
.6619 .01472 L
.66286 .01472 L
.66381 .01472 L
.66476 .01472 L
.66571 .01472 L
.66667 .01472 L
.66762 .01472 L
.66857 .01472 L
.66952 .01472 L
.67048 .01472 L
.67143 .01472 L
.67238 .01472 L
.67333 .01472 L
.67429 .01472 L
.67524 .01472 L
.67619 .01472 L
.67714 .01472 L
.6781 .01472 L
.67905 .01472 L
.68 .01472 L
.68095 .01472 L
.6819 .01472 L
.68286 .01472 L
.68381 .01472 L
.68476 .01472 L
.68571 .01472 L
.68667 .01472 L
.68762 .01472 L
.68857 .01472 L
.68952 .01472 L
.69048 .01472 L
Mistroke
.69143 .01472 L
.69238 .01472 L
.69333 .01472 L
.69429 .01472 L
.69524 .01472 L
.69619 .01472 L
.69714 .01472 L
.6981 .01472 L
.69905 .01472 L
.7 .01472 L
.70095 .01472 L
.7019 .01472 L
.70286 .01472 L
.70381 .01472 L
.70476 .01472 L
.70571 .01472 L
.70667 .01472 L
.70762 .01472 L
.70857 .01472 L
.70952 .01472 L
.71048 .01472 L
.71143 .01472 L
.71238 .01472 L
.71333 .01472 L
.71429 .01472 L
.71524 .01472 L
.71619 .01472 L
.71714 .01472 L
.7181 .01472 L
.71905 .01472 L
.72 .01472 L
.72095 .01472 L
.7219 .01472 L
.72286 .01472 L
.72381 .01472 L
.72476 .01472 L
.72571 .01472 L
.72667 .01472 L
.72762 .01472 L
.72857 .01472 L
.72952 .01472 L
.73048 .01472 L
.73143 .01472 L
.73238 .01472 L
.73333 .01472 L
.73429 .01472 L
.73524 .01472 L
.73619 .01472 L
.73714 .01472 L
.7381 .01472 L
Mistroke
.73905 .01472 L
.74 .01472 L
.74095 .01472 L
.7419 .01472 L
.74286 .01472 L
.74381 .01472 L
.74476 .01472 L
.74571 .01472 L
.74667 .01472 L
.74762 .01472 L
.74857 .01472 L
.74952 .01472 L
.75048 .01472 L
.75143 .01472 L
.75238 .01472 L
.75333 .01472 L
.75429 .01472 L
.75524 .01472 L
.75619 .01472 L
.75714 .01472 L
.7581 .01472 L
.75905 .01472 L
.76 .01472 L
.76095 .01472 L
.7619 .01472 L
.76286 .01472 L
.76381 .01472 L
.76476 .01472 L
.76571 .01472 L
.76667 .01472 L
.76762 .01472 L
.76857 .01472 L
.76952 .01472 L
.77048 .01472 L
.77143 .01472 L
.77238 .01472 L
.77333 .01472 L
.77429 .01472 L
.77524 .01472 L
.77619 .01472 L
.77714 .01472 L
.7781 .01472 L
.77905 .01472 L
.78 .01472 L
.78095 .01472 L
.7819 .01472 L
.78286 .01472 L
.78381 .01472 L
.78476 .01472 L
.78571 .01472 L
Mistroke
.78667 .01472 L
.78762 .01472 L
.78857 .01472 L
.78952 .01472 L
.79048 .01472 L
.79143 .01472 L
.79238 .01472 L
.79333 .01472 L
.79429 .01472 L
.79524 .01472 L
.79619 .01472 L
.79714 .01472 L
.7981 .01472 L
.79905 .01472 L
.8 .01472 L
.80095 .01472 L
.8019 .01472 L
.80286 .01472 L
.80381 .01472 L
.80476 .01472 L
.80571 .01472 L
.80667 .01472 L
.80762 .01472 L
.80857 .01472 L
.80952 .01472 L
.81048 .01472 L
.81143 .01472 L
.81238 .01472 L
.81333 .01472 L
.81429 .01472 L
.81524 .01472 L
.81619 .01472 L
.81714 .01472 L
.8181 .01472 L
.81905 .01472 L
.82 .01472 L
.82095 .01472 L
.8219 .01472 L
.82286 .01472 L
.82381 .01472 L
.82476 .01472 L
.82571 .01472 L
.82667 .01472 L
.82762 .01472 L
.82857 .01472 L
.82952 .01472 L
.83048 .01472 L
.83143 .01472 L
.83238 .01472 L
.83333 .01472 L
Mistroke
.83429 .01472 L
.83524 .01472 L
.83619 .01472 L
.83714 .01472 L
.8381 .01472 L
.83905 .01472 L
.84 .01472 L
.84095 .01472 L
.8419 .01472 L
.84286 .01472 L
.84381 .01472 L
.84476 .01472 L
.84571 .01472 L
.84667 .01472 L
.84762 .01472 L
.84857 .01472 L
.84952 .01472 L
.85048 .01472 L
.85143 .01472 L
.85238 .01472 L
.85333 .01472 L
.85429 .01472 L
.85524 .01472 L
.85619 .01472 L
.85714 .01472 L
.8581 .01472 L
.85905 .01472 L
.86 .01472 L
.86095 .01472 L
.8619 .01472 L
.86286 .01472 L
.86381 .01472 L
.86476 .01472 L
.86571 .01472 L
.86667 .01472 L
.86762 .01472 L
.86857 .01472 L
.86952 .01472 L
.87048 .01472 L
.87143 .01472 L
.87238 .01472 L
.87333 .01472 L
.87429 .01472 L
.87524 .01472 L
.87619 .01472 L
.87714 .01472 L
.8781 .01472 L
.87905 .01472 L
.88 .01472 L
.88095 .01472 L
Mistroke
.8819 .01472 L
.88286 .01472 L
.88381 .01472 L
.88476 .01472 L
.88571 .01472 L
.88667 .01472 L
.88762 .01472 L
.88857 .01472 L
.88952 .01472 L
.89048 .01472 L
.89143 .01472 L
.89238 .01472 L
.89333 .01472 L
.89429 .01472 L
.89524 .01472 L
.89619 .01472 L
.89714 .01472 L
.8981 .01472 L
.89905 .01472 L
.9 .01472 L
.90095 .01472 L
.9019 .01472 L
.90286 .01472 L
.90381 .01472 L
.90476 .01472 L
.90571 .01472 L
.90667 .01472 L
.90762 .01472 L
.90857 .01472 L
.90952 .01472 L
.91048 .01472 L
.91143 .01472 L
.91238 .01472 L
.91333 .01472 L
.91429 .01472 L
.91524 .01472 L
.91619 .01472 L
.91714 .01472 L
.9181 .01472 L
.91905 .01472 L
.92 .01472 L
.92095 .01472 L
.9219 .01472 L
.92286 .01472 L
.92381 .01472 L
.92476 .01472 L
.92571 .01472 L
.92667 .01472 L
.92762 .01472 L
.92857 .01472 L
Mistroke
.92952 .01472 L
.93048 .01472 L
.93143 .01472 L
.93238 .01472 L
.93333 .01472 L
.93429 .01472 L
.93524 .01472 L
.93619 .01472 L
.93714 .01472 L
.9381 .01472 L
.93905 .01472 L
.94 .01472 L
.94095 .01472 L
.9419 .01472 L
.94286 .01472 L
.94381 .01472 L
.94476 .01472 L
.94571 .01472 L
.94667 .01472 L
.94762 .01472 L
.94857 .01472 L
.94952 .01472 L
.95048 .01472 L
.95143 .01472 L
.95238 .01472 L
.95333 .01472 L
.95429 .01472 L
.95524 .01472 L
.95619 .01472 L
.95714 .01472 L
.9581 .01472 L
.95905 .01472 L
.96 .01472 L
.96095 .01472 L
.9619 .01472 L
.96286 .01472 L
.96381 .01472 L
.96476 .01472 L
.96571 .01472 L
.96667 .01472 L
.96762 .01472 L
.96857 .01472 L
.96952 .01472 L
.97048 .01472 L
.97143 .01472 L
.97238 .01472 L
.97333 .01472 L
.97429 .01472 L
.97524 .01472 L
.97619 .01472 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`006_ooool2o`0002Oooooo1Ol00003ooooo`;o00001?ooool2o`0002Co
oooo0ol00003ooooo`;o00001?ooool2o`0002;ooooo0ol00004ooooo`;o00001?ooool2o`0002?o
oooo0ol00004ooooo`;o00001?ooool2o`00023ooooo0ol00004ooooo`;o00001?ooool2o`0000Co
oooo0_l00003ooooo`006Oooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Tooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
000Iooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`00027ooooo1Ol00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Qooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00023ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool001Wooooo00Co0000oooooooooooo0000:Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Pooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0002;ooooo0ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00008?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`006Oooool01?l0003ooooooooo
ool0000Vooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`00027ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`006Oooool01?l0003oooooooooool0000Vooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002?o
oooo0_l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00008Oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
8Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Oooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool001[ooooo0_l0000Xooooo`?o0000
1?ooool2o`0000Cooooo0_l0000Uooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o0000
8oooool2o`0000Cooooo0_l00004ooooo`;o00008oooool3o`0000Cooooo0_l00004ooooo`;o0000
8Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`005Oooool00ol000000000
0000003o00000080000000?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool00ooo
ool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool00oooool0
0`00003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00<00000ooooooooool0;_ooool0
0`00003oooooooooo`0_ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo0?oooooo0_ooool00ol0003oooooooooo`04ooooo`003Oooool01?l0003oooooooooool00004
ooooo`Ko0000L?l00?lHo`00077o003o1_l00006ooooo`003Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1c
ooooo`03o`000?oooooooooo00Cooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0L_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo00?o0000
ooooooooool01?ooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1b
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04
ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000oooooooo
ool0L_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo00?o0000oooooooo
ool01?ooool001Gooooo00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0L_oo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?oo
ool001Gooooo0_l0001cooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0L_ooool2
o`0000Kooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07;o
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Co
oooo000Eooooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o
003oooooooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000E
ooooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1c
ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03
o`000?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1cooooo`03
o`000?oooooooooo00Cooooo000Eooooo`;o0000Loooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo07;ooooo0_l00006ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooo
oooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool0
0ol0003oooooooooo`1booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool0
0ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo
01Kooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003o
ooooooooo`1booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003o
ooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Kooooo
00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003ooooooooo
o`1booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003ooooooooo
o`04ooooo`005Oooool2o`0007?ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1b
ooooo`;o00001_ooool001Gooooo00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000oooooooo
ool0L_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo00?o0000oooooooo
ool01?ooool001Gooooo00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Fooooo`03o`00
oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0L_oo
ool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?oo
ool000;ooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003ooooooooo
o`1booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003ooooooooo
o`04ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo
00?o0000ooooooooool01?ooool00005ooooool0003oooooooooool000002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`1cooooo`03o`000?oooooooooo00Cooooo00001Ooooooo0000oooooooooooo000000[ooooo
00?o0000ooooooooool00oooool2o`0007?ooooo00?o003oooooooooool05_ooool00ol00?oooooo
ooooo`1aooooo`?o00001_ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool00005ooooool0003oooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0L_ooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool000;o
oooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Ko
oooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003ooooo
ooooo`1booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003ooooo
ooooo`04ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1b
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04
ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool2o`0007?ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`1booooo`;o00001_ooool001Gooooo00?o0000ooooooooool0
L_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool0
1?ooool001Gooooo00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooo
oooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0L_ooool0
0ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool0
01Gooooo00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0L_ooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo
00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo07?ooooo
00?o0000ooooooooool01?ooool001Gooooo0_l0001cooooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool0L_ooool2o`0000Kooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o003o
ooooooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eoooo
o`03o`000?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1coooo
o`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`00
0?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`00
0?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool05_oo
ool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooo
oooo07;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooo
oooo00Cooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol0
0?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`;o0000Loooool00ol00?oo
ooooooooo`0Fooooo`03o`00oooooooooooo07;ooooo0_l00006ooooo`005Oooool00ol0003ooooo
ooooo`1booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003ooooo
ooooo`04ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1b
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04
ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool0Loooool00ol0003oooooooooo`04ooooo`000_ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool3o`0000Cooooo00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`0Fooooo`03
o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool00005ooooool0003oooooooooool0
00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo00001Ooooooo0000
oooooooooooo000000Oooooo1Ol00004ooooo`03o`000?oooooooooo07;ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo00001Ooooooo0000
oooooooooooo000000Oooooo00Co0000oooooooooooo00001Oooool2o`0007?ooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`1aooooo`?o00001_ooool00005ooooool0003ooooooooo
ool000002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo07;ooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo00001Ooooooo
0000oooooooooooo000000Wooooo0_l00005ooooo`03o`000?oooooooooo07;ooooo00?o003ooooo
ooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo0002ooooo`;o
00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07;ooooo00?o003ooooooooo
ool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`00
0?oooooooooo07;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`00
0?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07;ooooo00?o003oooooooooool05_oo
ool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooo
oooo07;ooooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`1cooooo`03o`000?oooooo
oooo00Cooooo000Eooooo`;o0000Loooool00ol00?ooooooooooo`0Fooooo`03o`00oooooooooooo
07;ooooo0_l00006ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Ko
oooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003ooooo
ooooo`1booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003ooooo
ooooo`04ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Kooooo00?o
003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1b
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04
ooooo`005Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Kooooo00?o003ooooo
ooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1booooo`03
o`00oooooooooooo01Kooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`00
5Oooool00ol0003oooooooooo`1booooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0
Loooool00ol0003oooooooooo`04ooooo`005Oooool2o`0007Cooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`1booooo`;o00001_ooool001Gooooo00?o0000ooooooooool0Loooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool0
01Gooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0Loooool00ol00?oo
ooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo
00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo
00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0Loooool00ol00?oooooooooo
o`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000
ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000
ooooooooool01?ooool001Gooooo0_l0001dooooo`03o`00oooooooooooo01Gooooo00?o003ooooo
ooooool0L_ooool2o`0000Kooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o003ooooooooo
ool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`00
0?oooooooooo07?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`00
0?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool05Ooo
ool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooo
oooo07?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooo
oooo00Cooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool05Oooool00ol0
0?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo0002ooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Go
oooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`0000Goooooo`000?oooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1coooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04oooo
o`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool2
o`0007Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1aooooo`?o00001_ooool0
0005ooooool0003oooooooooool000001oooool4o`0000Gooooo00?o0000ooooooooool0Loooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool0
0005ooooool0003oooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo07?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooo
oooo00Cooooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Loooool0
0ol0003oooooooooo`04ooooo`000_ooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo
07?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo
00Cooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07?ooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo
000Eooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`;o0000M?ooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo07;ooooo0_l00006ooooo`005Oooool00ol0003oooooooooo`1coooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04oooo
o`005Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003ooooooooo
ool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1cooooo`03o`00
oooooooooooo01Gooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Ooo
ool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Looo
ool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0
003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Loooool00ol0
003oooooooooo`04ooooo`005Oooool2o`0007Cooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`1booooo`;o00001_ooool001Gooooo00?o0000ooooooooool0Loooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o
0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o
0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0E
ooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000oooo
ooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000oooo
ooooool01?ooool001Gooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0
Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool0
1?ooool001Gooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooo
oooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo0_l0001dooooo`03o`00oooooooo
oooo01Gooooo00?o003oooooooooool0L_ooool2o`0000Kooooo000Eooooo`03o`000?oooooooooo
07?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo
00Cooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07?ooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo
000Eooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool05Oooool00ol00?oooooooooo
o`1cooooo`03o`000?oooooooooo00Cooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00001Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool0Loooool00ol0003oooooooooo`04ooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1cooooo`03o`00oooo
oooooooo01Gooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`0000Gooooo
o`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Loooool00ol0003ooooo
ooooo`04ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`?o00001Oooool2o`0007Cooooo
00?o003oooooooooool05Oooool00ol00?ooooooooooo`1aooooo`?o00001_ooool00005ooooool0
003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000oooooooo
ool01?ooool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo
07?ooooo00?o0000ooooooooool01?ooool000;ooooo0_l00009ooooo`?o00001Oooool00ol0003o
ooooooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Loooool00ol0003o
ooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003ooooooooo
o`1cooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Loooool00ol0003ooooooooo
o`04ooooo`005Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool2o`0007Cooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`1booooo`;o00001_ooool001Gooooo00?o0000oooooooo
ool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000oooooooo
ool01?ooool001Gooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00
oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0Looo
ool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?oo
ool001Gooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0Loooool00ol0
0?ooooooooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Go
oooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07?o
oooo00?o0000ooooooooool01?ooool001Gooooo00?o0000ooooooooool0Loooool00ol00?oooooo
ooooo`0Eooooo`03o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool001Gooooo0_l0
001dooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0L_ooool2o`0000Kooooo000E
ooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1c
ooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o003ooooo
ooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03
o`000?oooooooooo07?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03
o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool0
5Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oo
oooooooo07?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oo
oooooooo00Cooooo000Eooooo`03o`000?oooooooooo07?ooooo00?o003oooooooooool05Oooool0
0ol00?ooooooooooo`1cooooo`03o`000?oooooooooo00Cooooo000Eooooo`03o`000?oooooooooo
07?ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`1cooooo`03o`000?oooooooooo
00Cooooo000Eooooo`;o0000M?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo07;o
oooo0_l00006ooooo`005Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003ooooooooo
o`1cooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Loooool00ol0003ooooooooo
o`04ooooo`005Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool0Loooool00ol0003oooooooooo`04ooooo`005Oooool00ol0003oooooooooo`1coooo
o`03o`00oooooooooooo01Gooooo00?o003oooooooooool0Loooool00ol0003oooooooooo`04oooo
o`003Oooool3o`0000Gooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`0Eooooo`03
o`00oooooooooooo07?ooooo00?o0000ooooooooool01?ooool000kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1cooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool0
Loooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`04ooooo`;o0000M?oo
oolIo`00og?ooooo0ol00006ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo0_ooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo0_ooool00ol0003oooooooooo`04ooooo`003Oooool2o`0000Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003ooooo
ooooo`04oooooooo00001_l00006ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-110.84, -0.11605, 4.03943, \
0.00653594}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete spectrum: Fast Fourier Transform (FFT)", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fft\  = \ Fourier[signal];\)\), "\n", 
    \(\(g1 = 
        DiscreteListPlot[FourierRearrange[Abs[fft], sampleRate], Red, 
          PlotRange \[Rule] All, \ Frame \[Rule] True];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499523 0.000953334 0.0147151 0.00588604 [
[.11819 -0.0125 -12 -9 ]
[.11819 -0.0125 12 0 ]
[.30886 -0.0125 -12 -9 ]
[.30886 -0.0125 12 0 ]
[.49952 -0.0125 -3 -9 ]
[.49952 -0.0125 3 0 ]
[.69019 -0.0125 -9 -9 ]
[.69019 -0.0125 9 0 ]
[.88086 -0.0125 -9 -9 ]
[.88086 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -12 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -12 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -12 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11819 0 m
.11819 .00625 L
s
[(-400)] .11819 -0.0125 0 1 Mshowa
.30886 0 m
.30886 .00625 L
s
[(-200)] .30886 -0.0125 0 1 Mshowa
.49952 0 m
.49952 .00625 L
s
[(0)] .49952 -0.0125 0 1 Mshowa
.69019 0 m
.69019 .00625 L
s
[(200)] .69019 -0.0125 0 1 Mshowa
.88086 0 m
.88086 .00625 L
s
[(400)] .88086 -0.0125 0 1 Mshowa
.125 Mabswid
.16586 0 m
.16586 .00375 L
s
.21352 0 m
.21352 .00375 L
s
.26119 0 m
.26119 .00375 L
s
.35652 0 m
.35652 .00375 L
s
.40419 0 m
.40419 .00375 L
s
.45186 0 m
.45186 .00375 L
s
.54719 0 m
.54719 .00375 L
s
.59486 0 m
.59486 .00375 L
s
.64252 0 m
.64252 .00375 L
s
.73786 0 m
.73786 .00375 L
s
.78552 0 m
.78552 .00375 L
s
.83319 0 m
.83319 .00375 L
s
.07052 0 m
.07052 .00375 L
s
.02286 0 m
.02286 .00375 L
s
.92852 0 m
.92852 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(20)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(40)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(60)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(80)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(100)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11819 .61178 m
.11819 .61803 L
s
.30886 .61178 m
.30886 .61803 L
s
.49952 .61178 m
.49952 .61803 L
s
.69019 .61178 m
.69019 .61803 L
s
.88086 .61178 m
.88086 .61803 L
s
.125 Mabswid
.16586 .61428 m
.16586 .61803 L
s
.21352 .61428 m
.21352 .61803 L
s
.26119 .61428 m
.26119 .61803 L
s
.35652 .61428 m
.35652 .61803 L
s
.40419 .61428 m
.40419 .61803 L
s
.45186 .61428 m
.45186 .61803 L
s
.54719 .61428 m
.54719 .61803 L
s
.59486 .61428 m
.59486 .61803 L
s
.64252 .61428 m
.64252 .61803 L
s
.73786 .61428 m
.73786 .61803 L
s
.78552 .61428 m
.78552 .61803 L
s
.83319 .61428 m
.83319 .61803 L
s
.07052 .61428 m
.07052 .61803 L
s
.02286 .61428 m
.02286 .61803 L
s
.92852 .61428 m
.92852 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02381 .01653 L
s
.02476 .01472 m
.02476 .01817 L
s
.02572 .01472 m
.02572 .01948 L
s
.02667 .01472 m
.02667 .02031 L
s
.02762 .01472 m
.02762 .0206 L
s
.02858 .01472 m
.02858 .02031 L
s
.02953 .01472 m
.02953 .01948 L
s
.03048 .01472 m
.03048 .01818 L
s
.03144 .01472 m
.03144 .01653 L
s
.03239 .01472 m
.03239 .01472 L
s
.03334 .01472 m
.03334 .01654 L
s
.0343 .01472 m
.0343 .01818 L
s
.03525 .01472 m
.03525 .01948 L
s
.0362 .01472 m
.0362 .02032 L
s
.03716 .01472 m
.03716 .02061 L
s
.03811 .01472 m
.03811 .02032 L
s
.03906 .01472 m
.03906 .01948 L
s
.04002 .01472 m
.04002 .01818 L
s
.04097 .01472 m
.04097 .01654 L
s
.04192 .01472 m
.04192 .01472 L
s
.04288 .01472 m
.04288 .01654 L
s
.04383 .01472 m
.04383 .01818 L
s
.04478 .01472 m
.04478 .01949 L
s
.04574 .01472 m
.04574 .02033 L
s
.04669 .01472 m
.04669 .02062 L
s
.04764 .01472 m
.04764 .02033 L
s
.0486 .01472 m
.0486 .01949 L
s
.04955 .01472 m
.04955 .01819 L
s
.0505 .01472 m
.0505 .01654 L
s
.05146 .01472 m
.05146 .01472 L
s
.05241 .01472 m
.05241 .01654 L
s
.05336 .01472 m
.05336 .01819 L
s
.05432 .01472 m
.05432 .0195 L
s
.05527 .01472 m
.05527 .02035 L
s
.05622 .01472 m
.05622 .02064 L
s
.05718 .01472 m
.05718 .02035 L
s
.05813 .01472 m
.05813 .01951 L
s
.05908 .01472 m
.05908 .0182 L
s
.06004 .01472 m
.06004 .01655 L
s
.06099 .01472 m
.06099 .01472 L
s
.06194 .01472 m
.06194 .01655 L
s
.0629 .01472 m
.0629 .01821 L
s
.06385 .01472 m
.06385 .01952 L
s
.0648 .01472 m
.0648 .02037 L
s
.06576 .01472 m
.06576 .02066 L
s
.06671 .01472 m
.06671 .02037 L
s
.06766 .01472 m
.06766 .01953 L
s
.06862 .01472 m
.06862 .01821 L
s
.06957 .01472 m
.06957 .01656 L
s
.07052 .01472 m
.07052 .01472 L
s
.07148 .01472 m
.07148 .01656 L
s
.07243 .01472 m
.07243 .01822 L
s
.07338 .01472 m
.07338 .01954 L
s
.07434 .01472 m
.07434 .02039 L
s
.07529 .01472 m
.07529 .02069 L
s
.07624 .01472 m
.07624 .0204 L
s
.0772 .01472 m
.0772 .01955 L
s
.07815 .01472 m
.07815 .01823 L
s
.0791 .01472 m
.0791 .01657 L
s
.08006 .01472 m
.08006 .01472 L
s
.08101 .01472 m
.08101 .01657 L
s
.08196 .01472 m
.08196 .01824 L
s
.08292 .01472 m
.08292 .01957 L
s
.08387 .01472 m
.08387 .02043 L
s
.08482 .01472 m
.08482 .02073 L
s
.08578 .01472 m
.08578 .02044 L
s
.08673 .01472 m
.08673 .01958 L
s
.08768 .01472 m
.08768 .01826 L
s
.08864 .01472 m
.08864 .01658 L
s
.08959 .01472 m
.08959 .01472 L
s
.09054 .01472 m
.09054 .01658 L
s
.0915 .01472 m
.0915 .01827 L
s
.09245 .01472 m
.09245 .01961 L
s
.0934 .01472 m
.0934 .02047 L
s
.09436 .01472 m
.09436 .02077 L
s
.09531 .01472 m
.09531 .02048 L
s
.09626 .01472 m
.09626 .01962 L
s
.09722 .01472 m
.09722 .01828 L
s
.09817 .01472 m
.09817 .01659 L
s
.09912 .01472 m
.09912 .01472 L
s
.10008 .01472 m
.10008 .01659 L
s
.10103 .01472 m
.10103 .01829 L
s
.10198 .01472 m
.10198 .01964 L
s
.10294 .01472 m
.10294 .02051 L
s
.10389 .01472 m
.10389 .02082 L
s
.10484 .01472 m
.10484 .02052 L
s
.1058 .01472 m
.1058 .01966 L
s
.10675 .01472 m
.10675 .01831 L
s
.1077 .01472 m
.1077 .01661 L
s
.10866 .01472 m
.10866 .01472 L
s
.10961 .01472 m
.10961 .01661 L
s
.11056 .01472 m
.11056 .01832 L
s
.11152 .01472 m
.11152 .01969 L
s
.11247 .01472 m
.11247 .02057 L
s
.11342 .01472 m
.11342 .02087 L
s
.11438 .01472 m
.11438 .02058 L
s
.11533 .01472 m
.11533 .01971 L
s
.11628 .01472 m
.11628 .01835 L
s
.11724 .01472 m
.11724 .01663 L
s
.11819 .01472 m
.11819 .01472 L
s
.11914 .01472 m
.11914 .01663 L
s
.1201 .01472 m
.1201 .01836 L
s
.12105 .01472 m
.12105 .01974 L
s
.122 .01472 m
.122 .02063 L
s
.12296 .01472 m
.12296 .02094 L
s
.12391 .01472 m
.12391 .02064 L
s
.12486 .01472 m
.12486 .01976 L
s
.12582 .01472 m
.12582 .01838 L
s
.12677 .01472 m
.12677 .01665 L
s
.12772 .01472 m
.12772 .01472 L
s
.12868 .01472 m
.12868 .01665 L
s
.12963 .01472 m
.12963 .0184 L
s
.13058 .01472 m
.13058 .01979 L
s
.13154 .01472 m
.13154 .02069 L
s
.13249 .01472 m
.13249 .02101 L
s
.13344 .01472 m
.13344 .02071 L
s
.1344 .01472 m
.1344 .01982 L
s
.13535 .01472 m
.13535 .01843 L
s
.1363 .01472 m
.1363 .01667 L
s
.13726 .01472 m
.13726 .01472 L
s
.13821 .01472 m
.13821 .01667 L
s
.13916 .01472 m
.13916 .01845 L
s
.14012 .01472 m
.14012 .01986 L
s
.14107 .01472 m
.14107 .02077 L
s
.14202 .01472 m
.14202 .02109 L
s
.14298 .01472 m
.14298 .02078 L
s
.14393 .01472 m
.14393 .01988 L
s
.14488 .01472 m
.14488 .01847 L
s
.14584 .01472 m
.14584 .01669 L
s
.14679 .01472 m
.14679 .01472 L
s
.14774 .01472 m
.14774 .0167 L
s
.1487 .01472 m
.1487 .0185 L
s
.14965 .01472 m
.14965 .01993 L
s
.1506 .01472 m
.1506 .02085 L
s
.15156 .01472 m
.15156 .02117 L
s
.15251 .01472 m
.15251 .02087 L
s
.15346 .01472 m
.15346 .01995 L
s
.15442 .01472 m
.15442 .01853 L
s
.15537 .01472 m
.15537 .01672 L
s
.15632 .01472 m
.15632 .01472 L
s
.15728 .01472 m
.15728 .01673 L
s
.15823 .01472 m
.15823 .01855 L
s
.15918 .01472 m
.15918 .02 L
s
.16014 .01472 m
.16014 .02094 L
s
.16109 .01472 m
.16109 .02127 L
s
.16204 .01472 m
.16204 .02096 L
s
.163 .01472 m
.163 .02003 L
s
.16395 .01472 m
.16395 .01859 L
s
.1649 .01472 m
.1649 .01675 L
s
.16586 .01472 m
.16586 .01472 L
s
.16681 .01472 m
.16681 .01676 L
s
.16776 .01472 m
.16776 .01861 L
s
.16872 .01472 m
.16872 .02009 L
s
.16967 .01472 m
.16967 .02104 L
s
.17062 .01472 m
.17062 .02138 L
s
.17158 .01472 m
.17158 .02106 L
s
.17253 .01472 m
.17253 .02012 L
s
.17348 .01472 m
.17348 .01865 L
s
.17444 .01472 m
.17444 .01679 L
s
.17539 .01472 m
.17539 .01472 L
s
.17634 .01472 m
.17634 .01679 L
s
.1773 .01472 m
.1773 .01868 L
s
.17825 .01472 m
.17825 .02018 L
s
.1792 .01472 m
.1792 .02115 L
s
.18016 .01472 m
.18016 .02149 L
s
.18111 .01472 m
.18111 .02117 L
s
.18206 .01472 m
.18206 .02022 L
s
.18302 .01472 m
.18302 .01872 L
s
.18397 .01472 m
.18397 .01682 L
s
.18492 .01472 m
.18492 .01472 L
s
.18588 .01472 m
.18588 .01683 L
s
.18683 .01472 m
.18683 .01875 L
s
.18778 .01472 m
.18778 .02028 L
s
.18874 .01472 m
.18874 .02127 L
s
.18969 .01472 m
.18969 .02162 L
s
.19064 .01472 m
.19064 .02129 L
s
.1916 .01472 m
.1916 .02032 L
s
.19255 .01472 m
.19255 .0188 L
s
.1935 .01472 m
.1935 .01687 L
s
.19446 .01472 m
.19446 .01472 L
s
.19541 .01472 m
.19541 .01687 L
s
.19636 .01472 m
.19636 .01883 L
s
.19732 .01472 m
.19732 .02039 L
s
.19827 .01472 m
.19827 .0214 L
s
.19922 .01472 m
.19922 .02176 L
s
.20018 .01472 m
.20018 .02143 L
s
.20113 .01472 m
.20113 .02044 L
s
.20208 .01472 m
.20208 .01888 L
s
.20304 .01472 m
.20304 .01691 L
s
.20399 .01472 m
.20399 .01472 L
s
.20494 .01472 m
.20494 .01692 L
s
.2059 .01472 m
.2059 .01892 L
s
.20685 .01472 m
.20685 .02051 L
s
.2078 .01472 m
.2078 .02154 L
s
.20876 .01472 m
.20876 .02191 L
s
.20971 .01472 m
.20971 .02157 L
s
.21066 .01472 m
.21066 .02056 L
s
.21162 .01472 m
.21162 .01897 L
s
.21257 .01472 m
.21257 .01696 L
s
.21352 .01472 m
.21352 .01472 L
s
.21448 .01472 m
.21448 .01697 L
s
.21543 .01472 m
.21543 .01901 L
s
.21638 .01472 m
.21638 .02064 L
s
.21734 .01472 m
.21734 .0217 L
s
.21829 .01472 m
.21829 .02208 L
s
.21924 .01472 m
.21924 .02173 L
s
.2202 .01472 m
.2202 .0207 L
s
.22115 .01472 m
.22115 .01907 L
s
.2221 .01472 m
.2221 .01701 L
s
.22306 .01472 m
.22306 .01472 L
s
.22401 .01472 m
.22401 .01702 L
s
.22496 .01472 m
.22496 .01912 L
s
.22592 .01472 m
.22592 .02079 L
s
.22687 .01472 m
.22687 .02187 L
s
.22782 .01472 m
.22782 .02226 L
s
.22878 .01472 m
.22878 .02191 L
s
.22973 .01472 m
.22973 .02085 L
s
.23068 .01472 m
.23068 .01918 L
s
.23164 .01472 m
.23164 .01707 L
s
.23259 .01472 m
.23259 .01472 L
s
.23354 .01472 m
.23354 .01708 L
s
.2345 .01472 m
.2345 .01923 L
s
.23545 .01472 m
.23545 .02094 L
s
.2364 .01472 m
.2364 .02206 L
s
.23736 .01472 m
.23736 .02246 L
s
.23831 .01472 m
.23831 .0221 L
s
.23926 .01472 m
.23926 .02101 L
s
.24022 .01472 m
.24022 .0193 L
s
.24117 .01472 m
.24117 .01713 L
s
.24212 .01472 m
.24212 .01472 L
s
.24308 .01472 m
.24308 .01715 L
s
.24403 .01472 m
.24403 .01935 L
s
.24498 .01472 m
.24498 .02112 L
s
.24594 .01472 m
.24594 .02226 L
s
.24689 .01472 m
.24689 .02267 L
s
.24784 .01472 m
.24784 .02231 L
s
.2488 .01472 m
.2488 .02119 L
s
.24975 .01472 m
.24975 .01943 L
s
.2507 .01472 m
.2507 .0172 L
s
.25166 .01472 m
.25166 .01472 L
s
.25261 .01472 m
.25261 .01722 L
s
.25356 .01472 m
.25356 .01949 L
s
.25452 .01472 m
.25452 .02131 L
s
.25547 .01472 m
.25547 .02249 L
s
.25642 .01472 m
.25642 .02291 L
s
.25738 .01472 m
.25738 .02253 L
s
.25833 .01472 m
.25833 .02139 L
s
.25928 .01472 m
.25928 .01958 L
s
.26024 .01472 m
.26024 .01728 L
s
.26119 .01472 m
.26119 .01472 L
s
.26214 .01472 m
.26214 .0173 L
s
.2631 .01472 m
.2631 .01964 L
s
.26405 .01472 m
.26405 .02151 L
s
.265 .01472 m
.265 .02273 L
s
.26596 .01472 m
.26596 .02317 L
s
.26691 .01472 m
.26691 .02279 L
s
.26786 .01472 m
.26786 .0216 L
s
.26882 .01472 m
.26882 .01974 L
s
.26977 .01472 m
.26977 .01736 L
s
.27072 .01472 m
.27072 .01472 L
s
.27168 .01472 m
.27168 .01738 L
s
.27263 .01472 m
.27263 .0198 L
s
.27358 .01472 m
.27358 .02174 L
s
.27454 .01472 m
.27454 .023 L
s
.27549 .01472 m
.27549 .02346 L
s
.27644 .01472 m
.27644 .02306 L
s
.2774 .01472 m
.2774 .02184 L
s
.27835 .01472 m
.27835 .01991 L
s
.2793 .01472 m
.2793 .01746 L
s
.28026 .01472 m
.28026 .01472 L
s
.28121 .01472 m
.28121 .01748 L
s
.28216 .01472 m
.28216 .01998 L
s
.28312 .01472 m
.28312 .02199 L
s
.28407 .01472 m
.28407 .0233 L
s
.28502 .01472 m
.28502 .02378 L
s
.28598 .01472 m
.28598 .02337 L
s
.28693 .01472 m
.28693 .0221 L
s
.28788 .01472 m
.28788 .0201 L
s
.28884 .01472 m
.28884 .01756 L
s
.28979 .01472 m
.28979 .01472 L
s
.29074 .01472 m
.29074 .01758 L
s
.2917 .01472 m
.2917 .02018 L
s
.29265 .01472 m
.29265 .02227 L
s
.2936 .01472 m
.2936 .02363 L
s
.29456 .01472 m
.29456 .02413 L
s
.29551 .01472 m
.29551 .0237 L
s
.29646 .01472 m
.29646 .02239 L
s
.29742 .01472 m
.29742 .02031 L
s
.29837 .01472 m
.29837 .01767 L
s
.29932 .01472 m
.29932 .01472 L
s
.30028 .01472 m
.30028 .01769 L
s
.30123 .01472 m
.30123 .02041 L
s
.30218 .01472 m
.30218 .02258 L
s
.30314 .01472 m
.30314 .024 L
s
.30409 .01472 m
.30409 .02452 L
s
.30504 .01472 m
.30504 .02408 L
s
.306 .01472 m
.306 .02271 L
s
.30695 .01472 m
.30695 .02055 L
s
.3079 .01472 m
.3079 .0178 L
s
.30886 .01472 m
.30886 .01472 L
s
.30981 .01472 m
.30981 .01782 L
s
.31076 .01472 m
.31076 .02065 L
s
.31172 .01472 m
.31172 .02292 L
s
.31267 .01472 m
.31267 .02441 L
s
.31362 .01472 m
.31362 .02495 L
s
.31458 .01472 m
.31458 .02449 L
s
.31553 .01472 m
.31553 .02307 L
s
.31648 .01472 m
.31648 .02081 L
s
.31744 .01472 m
.31744 .01794 L
s
.31839 .01472 m
.31839 .01472 L
s
.31934 .01472 m
.31934 .01797 L
s
.3203 .01472 m
.3203 .02093 L
s
.32125 .01472 m
.32125 .02331 L
s
.3222 .01472 m
.3222 .02486 L
s
.32316 .01472 m
.32316 .02544 L
s
.32411 .01472 m
.32411 .02496 L
s
.32506 .01472 m
.32506 .02347 L
s
.32602 .01472 m
.32602 .02111 L
s
.32697 .01472 m
.32697 .01809 L
s
.32792 .01472 m
.32792 .01472 L
s
.32888 .01472 m
.32888 .01813 L
s
.32983 .01472 m
.32983 .02124 L
s
.33078 .01472 m
.33078 .02374 L
s
.33174 .01472 m
.33174 .02537 L
s
.33269 .01472 m
.33269 .02598 L
s
.33364 .01472 m
.33364 .02548 L
s
.3346 .01472 m
.3346 .02392 L
s
.33555 .01472 m
.33555 .02144 L
s
.3365 .01472 m
.3365 .01827 L
s
.33746 .01472 m
.33746 .01472 L
s
.33841 .01472 m
.33841 .01831 L
s
.33936 .01472 m
.33936 .02158 L
s
.34032 .01472 m
.34032 .02422 L
s
.34127 .01472 m
.34127 .02595 L
s
.34222 .01472 m
.34222 .0266 L
s
.34318 .01472 m
.34318 .02608 L
s
.34413 .01472 m
.34413 .02443 L
s
.34508 .01472 m
.34508 .02182 L
s
.34604 .01472 m
.34604 .01847 L
s
.34699 .01472 m
.34699 .01472 L
s
.34794 .01472 m
.34794 .01851 L
s
.3489 .01472 m
.3489 .02198 L
s
.34985 .01472 m
.34985 .02477 L
s
.3508 .01472 m
.3508 .02661 L
s
.35176 .01472 m
.35176 .02729 L
s
.35271 .01472 m
.35271 .02675 L
s
.35366 .01472 m
.35366 .02501 L
s
.35462 .01472 m
.35462 .02224 L
s
.35557 .01472 m
.35557 .0187 L
s
.35652 .01472 m
.35652 .01472 L
s
.35748 .01472 m
.35748 .01875 L
s
.35843 .01472 m
.35843 .02243 L
s
.35938 .01472 m
.35938 .0254 L
s
.36034 .01472 m
.36034 .02736 L
s
.36129 .01472 m
.36129 .02809 L
s
.36224 .01472 m
.36224 .02752 L
s
.3632 .01472 m
.3632 .02568 L
s
.36415 .01472 m
.36415 .02273 L
s
.3651 .01472 m
.3651 .01896 L
s
.36606 .01472 m
.36606 .01472 L
s
.36701 .01472 m
.36701 .01902 L
s
.36796 .01472 m
.36796 .02295 L
s
.36892 .01472 m
.36892 .02613 L
s
.36987 .01472 m
.36987 .02822 L
s
.37082 .01472 m
.37082 .02902 L
s
.37178 .01472 m
.37178 .02841 L
s
.37273 .01472 m
.37273 .02645 L
s
.37368 .01472 m
.37368 .0233 L
s
.37464 .01472 m
.37464 .01926 L
s
.37559 .01472 m
.37559 .01472 L
s
.37654 .01472 m
.37654 .01933 L
s
.3775 .01472 m
.3775 .02356 L
s
.37845 .01472 m
.37845 .02697 L
s
.3794 .01472 m
.3794 .02923 L
s
.38036 .01472 m
.38036 .0301 L
s
.38131 .01472 m
.38131 .02946 L
s
.38226 .01472 m
.38226 .02735 L
s
.38322 .01472 m
.38322 .02397 L
s
.38417 .01472 m
.38417 .01962 L
s
.38512 .01472 m
.38512 .01472 L
s
.38608 .01472 m
.38608 .0197 L
s
.38703 .01472 m
.38703 .02427 L
s
.38798 .01472 m
.38798 .02797 L
s
.38894 .01472 m
.38894 .03042 L
s
.38989 .01472 m
.38989 .03137 L
s
.39084 .01472 m
.39084 .03068 L
s
.3918 .01472 m
.3918 .02841 L
s
.39275 .01472 m
.39275 .02475 L
s
.3937 .01472 m
.3937 .02004 L
s
.39466 .01472 m
.39466 .01472 L
s
.39561 .01472 m
.39561 .02013 L
s
.39656 .01472 m
.39656 .02511 L
s
.39752 .01472 m
.39752 .02915 L
s
.39847 .01472 m
.39847 .03184 L
s
.39942 .01472 m
.39942 .03289 L
s
.40038 .01472 m
.40038 .03216 L
s
.40133 .01472 m
.40133 .02969 L
s
.40228 .01472 m
.40228 .0257 L
s
.40324 .01472 m
.40324 .02054 L
s
.40419 .01472 m
.40419 .01472 L
s
.40514 .01472 m
.40514 .02066 L
s
.4061 .01472 m
.4061 .02613 L
s
.40705 .01472 m
.40705 .03059 L
s
.408 .01472 m
.408 .03356 L
s
.40896 .01472 m
.40896 .03473 L
s
.40991 .01472 m
.40991 .03395 L
s
.41086 .01472 m
.41086 .03125 L
s
.41182 .01472 m
.41182 .02685 L
s
.41277 .01472 m
.41277 .02116 L
s
.41372 .01472 m
.41372 .01472 L
s
.41468 .01472 m
.41468 .02131 L
s
.41563 .01472 m
.41563 .02739 L
s
.41658 .01472 m
.41658 .03236 L
s
.41754 .01472 m
.41754 .03569 L
s
.41849 .01472 m
.41849 .03702 L
s
.41944 .01472 m
.41944 .03618 L
s
.4204 .01472 m
.4204 .03319 L
s
.42135 .01472 m
.42135 .02829 L
s
.4223 .01472 m
.4223 .02194 L
s
.42326 .01472 m
.42326 .01472 L
s
.42421 .01472 m
.42421 .02212 L
s
.42516 .01472 m
.42516 .02898 L
s
.42612 .01472 m
.42612 .03459 L
s
.42707 .01472 m
.42707 .03839 L
s
.42802 .01472 m
.42802 .03993 L
s
.42898 .01472 m
.42898 .03901 L
s
.42993 .01472 m
.42993 .03566 L
s
.43088 .01472 m
.43088 .03014 L
s
.43184 .01472 m
.43184 .02294 L
s
.43279 .01472 m
.43279 .01472 L
s
.43374 .01472 m
.43374 .02317 L
s
.4347 .01472 m
.4347 .03103 L
s
.43565 .01472 m
.43565 .03751 L
s
.4366 .01472 m
.4366 .04191 L
s
.43756 .01472 m
.43756 .04374 L
s
.43851 .01472 m
.43851 .04275 L
s
.43946 .01472 m
.43946 .03893 L
s
.44042 .01472 m
.44042 .03259 L
s
.44137 .01472 m
.44137 .02426 L
s
.44232 .01472 m
.44232 .01472 L
s
.44328 .01472 m
.44328 .02458 L
s
.44423 .01472 m
.44423 .03381 L
s
.44518 .01472 m
.44518 .04145 L
s
.44614 .01472 m
.44614 .0467 L
s
.44709 .01472 m
.44709 .04895 L
s
.44804 .01472 m
.44804 .04787 L
s
.449 .01472 m
.449 .04345 L
s
.44995 .01472 m
.44995 .03599 L
s
.4509 .01472 m
.4509 .02612 L
s
.45186 .01472 m
.45186 .01472 L
s
.45281 .01472 m
.45281 .02658 L
s
.45376 .01472 m
.45376 .03775 L
s
.45472 .01472 m
.45472 .04708 L
s
.45567 .01472 m
.45567 .05359 L
s
.45662 .01472 m
.45662 .05649 L
s
.45758 .01472 m
.45758 .05534 L
s
.45853 .01472 m
.45853 .05007 L
s
.45948 .01472 m
.45948 .04101 L
s
.46044 .01472 m
.46044 .02888 L
s
.46139 .01472 m
.46139 .01472 L
s
.46234 .01472 m
.46234 .0296 L
s
.4633 .01472 m
.4633 .04376 L
s
.46425 .01472 m
.46425 .05577 L
s
.4652 .01472 m
.4652 .06432 L
s
.46616 .01472 m
.46616 .06835 L
s
.46711 .01472 m
.46711 .06722 L
s
.46806 .01472 m
.46806 .06073 L
s
.46902 .01472 m
.46902 .04919 L
s
.46997 .01472 m
.46997 .03342 L
s
.47092 .01472 m
.47092 .01472 L
s
.47188 .01472 m
.47188 .03471 L
s
.47283 .01472 m
.47283 .0541 L
s
.47378 .01472 m
.47378 .07092 L
s
.47474 .01472 m
.47474 .08333 L
s
.47569 .01472 m
.47569 .08974 L
s
.47664 .01472 m
.47664 .08903 L
s
.4776 .01472 m
.4776 .08068 L
s
.47855 .01472 m
.47855 .06481 L
s
.4795 .01472 m
.4795 .04231 L
s
.48046 .01472 m
.48046 .01472 L
s
.48141 .01472 m
.48141 .04521 L
s
.48236 .01472 m
.48236 .07593 L
s
.48332 .01472 m
.48332 .10392 L
s
.48427 .01472 m
.48427 .12613 L
s
.48522 .01472 m
.48522 .13967 L
s
.48618 .01472 m
.48618 .14203 L
s
.48713 .01472 m
.48713 .13134 L
s
.48808 .01472 m
.48808 .10651 L
s
.48904 .01472 m
.48904 .06736 L
s
.48999 .01472 m
.48999 .01472 L
s
.49094 .01472 m
.49094 .07905 L
s
.4919 .01472 m
.4919 .15239 L
s
.49285 .01472 m
.49285 .23127 L
s
.4938 .01472 m
.4938 .31171 L
s
.49476 .01472 m
.49476 .38945 L
s
.49571 .01472 m
.49571 .4602 L
s
.49666 .01472 m
.49666 .51998 L
s
.49762 .01472 m
.49762 .56535 L
s
.49857 .01472 m
.49857 .59369 L
s
.49952 .01472 m
.49952 .60332 L
s
.50048 .01472 m
.50048 .59369 L
s
.50143 .01472 m
.50143 .56535 L
s
.50238 .01472 m
.50238 .51998 L
s
.50334 .01472 m
.50334 .4602 L
s
.50429 .01472 m
.50429 .38945 L
s
.50524 .01472 m
.50524 .31171 L
s
.5062 .01472 m
.5062 .23127 L
s
.50715 .01472 m
.50715 .15239 L
s
.5081 .01472 m
.5081 .07905 L
s
.50906 .01472 m
.50906 .01472 L
s
.51001 .01472 m
.51001 .06736 L
s
.51096 .01472 m
.51096 .10651 L
s
.51192 .01472 m
.51192 .13134 L
s
.51287 .01472 m
.51287 .14203 L
s
.51382 .01472 m
.51382 .13967 L
s
.51478 .01472 m
.51478 .12613 L
s
.51573 .01472 m
.51573 .10392 L
s
.51668 .01472 m
.51668 .07593 L
s
.51764 .01472 m
.51764 .04521 L
s
.51859 .01472 m
.51859 .01472 L
s
.51954 .01472 m
.51954 .04231 L
s
.5205 .01472 m
.5205 .06481 L
s
.52145 .01472 m
.52145 .08068 L
s
.5224 .01472 m
.5224 .08903 L
s
.52336 .01472 m
.52336 .08974 L
s
.52431 .01472 m
.52431 .08333 L
s
.52526 .01472 m
.52526 .07092 L
s
.52622 .01472 m
.52622 .0541 L
s
.52717 .01472 m
.52717 .03471 L
s
.52812 .01472 m
.52812 .01472 L
s
.52908 .01472 m
.52908 .03342 L
s
.53003 .01472 m
.53003 .04919 L
s
.53098 .01472 m
.53098 .06073 L
s
.53194 .01472 m
.53194 .06722 L
s
.53289 .01472 m
.53289 .06835 L
s
.53384 .01472 m
.53384 .06432 L
s
.5348 .01472 m
.5348 .05577 L
s
.53575 .01472 m
.53575 .04376 L
s
.5367 .01472 m
.5367 .0296 L
s
.53766 .01472 m
.53766 .01472 L
s
.53861 .01472 m
.53861 .02888 L
s
.53956 .01472 m
.53956 .04101 L
s
.54052 .01472 m
.54052 .05007 L
s
.54147 .01472 m
.54147 .05534 L
s
.54242 .01472 m
.54242 .05649 L
s
.54338 .01472 m
.54338 .05359 L
s
.54433 .01472 m
.54433 .04708 L
s
.54528 .01472 m
.54528 .03775 L
s
.54624 .01472 m
.54624 .02658 L
s
.54719 .01472 m
.54719 .01472 L
s
.54814 .01472 m
.54814 .02612 L
s
.5491 .01472 m
.5491 .03599 L
s
.55005 .01472 m
.55005 .04345 L
s
.551 .01472 m
.551 .04787 L
s
.55196 .01472 m
.55196 .04895 L
s
.55291 .01472 m
.55291 .0467 L
s
.55386 .01472 m
.55386 .04145 L
s
.55482 .01472 m
.55482 .03381 L
s
.55577 .01472 m
.55577 .02458 L
s
.55672 .01472 m
.55672 .01472 L
s
.55768 .01472 m
.55768 .02426 L
s
.55863 .01472 m
.55863 .03259 L
s
.55958 .01472 m
.55958 .03893 L
s
.56054 .01472 m
.56054 .04275 L
s
.56149 .01472 m
.56149 .04374 L
s
.56244 .01472 m
.56244 .04191 L
s
.5634 .01472 m
.5634 .03751 L
s
.56435 .01472 m
.56435 .03103 L
s
.5653 .01472 m
.5653 .02317 L
s
.56626 .01472 m
.56626 .01472 L
s
.56721 .01472 m
.56721 .02294 L
s
.56816 .01472 m
.56816 .03014 L
s
.56912 .01472 m
.56912 .03566 L
s
.57007 .01472 m
.57007 .03901 L
s
.57102 .01472 m
.57102 .03993 L
s
.57198 .01472 m
.57198 .03839 L
s
.57293 .01472 m
.57293 .03459 L
s
.57388 .01472 m
.57388 .02898 L
s
.57484 .01472 m
.57484 .02212 L
s
.57579 .01472 m
.57579 .01472 L
s
.57674 .01472 m
.57674 .02194 L
s
.5777 .01472 m
.5777 .02829 L
s
.57865 .01472 m
.57865 .03319 L
s
.5796 .01472 m
.5796 .03618 L
s
.58056 .01472 m
.58056 .03702 L
s
.58151 .01472 m
.58151 .03569 L
s
.58246 .01472 m
.58246 .03236 L
s
.58342 .01472 m
.58342 .02739 L
s
.58437 .01472 m
.58437 .02131 L
s
.58532 .01472 m
.58532 .01472 L
s
.58628 .01472 m
.58628 .02116 L
s
.58723 .01472 m
.58723 .02685 L
s
.58818 .01472 m
.58818 .03125 L
s
.58914 .01472 m
.58914 .03395 L
s
.59009 .01472 m
.59009 .03473 L
s
.59104 .01472 m
.59104 .03356 L
s
.592 .01472 m
.592 .03059 L
s
.59295 .01472 m
.59295 .02613 L
s
.5939 .01472 m
.5939 .02066 L
s
.59486 .01472 m
.59486 .01472 L
s
.59581 .01472 m
.59581 .02054 L
s
.59676 .01472 m
.59676 .0257 L
s
.59772 .01472 m
.59772 .02969 L
s
.59867 .01472 m
.59867 .03216 L
s
.59962 .01472 m
.59962 .03289 L
s
.60058 .01472 m
.60058 .03184 L
s
.60153 .01472 m
.60153 .02915 L
s
.60248 .01472 m
.60248 .02511 L
s
.60344 .01472 m
.60344 .02013 L
s
.60439 .01472 m
.60439 .01472 L
s
.60534 .01472 m
.60534 .02004 L
s
.6063 .01472 m
.6063 .02475 L
s
.60725 .01472 m
.60725 .02841 L
s
.6082 .01472 m
.6082 .03068 L
s
.60916 .01472 m
.60916 .03137 L
s
.61011 .01472 m
.61011 .03042 L
s
.61106 .01472 m
.61106 .02797 L
s
.61202 .01472 m
.61202 .02427 L
s
.61297 .01472 m
.61297 .0197 L
s
.61392 .01472 m
.61392 .01472 L
s
.61488 .01472 m
.61488 .01962 L
s
.61583 .01472 m
.61583 .02397 L
s
.61678 .01472 m
.61678 .02735 L
s
.61774 .01472 m
.61774 .02946 L
s
.61869 .01472 m
.61869 .0301 L
s
.61964 .01472 m
.61964 .02923 L
s
.6206 .01472 m
.6206 .02697 L
s
.62155 .01472 m
.62155 .02356 L
s
.6225 .01472 m
.6225 .01933 L
s
.62346 .01472 m
.62346 .01472 L
s
.62441 .01472 m
.62441 .01926 L
s
.62536 .01472 m
.62536 .0233 L
s
.62632 .01472 m
.62632 .02645 L
s
.62727 .01472 m
.62727 .02841 L
s
.62822 .01472 m
.62822 .02902 L
s
.62918 .01472 m
.62918 .02822 L
s
.63013 .01472 m
.63013 .02613 L
s
.63108 .01472 m
.63108 .02295 L
s
.63204 .01472 m
.63204 .01902 L
s
.63299 .01472 m
.63299 .01472 L
s
.63394 .01472 m
.63394 .01896 L
s
.6349 .01472 m
.6349 .02273 L
s
.63585 .01472 m
.63585 .02568 L
s
.6368 .01472 m
.6368 .02752 L
s
.63776 .01472 m
.63776 .02809 L
s
.63871 .01472 m
.63871 .02736 L
s
.63966 .01472 m
.63966 .0254 L
s
.64062 .01472 m
.64062 .02243 L
s
.64157 .01472 m
.64157 .01875 L
s
.64252 .01472 m
.64252 .01472 L
s
.64348 .01472 m
.64348 .0187 L
s
.64443 .01472 m
.64443 .02224 L
s
.64538 .01472 m
.64538 .02501 L
s
.64634 .01472 m
.64634 .02675 L
s
.64729 .01472 m
.64729 .02729 L
s
.64824 .01472 m
.64824 .02661 L
s
.6492 .01472 m
.6492 .02477 L
s
.65015 .01472 m
.65015 .02198 L
s
.6511 .01472 m
.6511 .01851 L
s
.65206 .01472 m
.65206 .01472 L
s
.65301 .01472 m
.65301 .01847 L
s
.65396 .01472 m
.65396 .02182 L
s
.65492 .01472 m
.65492 .02443 L
s
.65587 .01472 m
.65587 .02608 L
s
.65682 .01472 m
.65682 .0266 L
s
.65778 .01472 m
.65778 .02595 L
s
.65873 .01472 m
.65873 .02422 L
s
.65968 .01472 m
.65968 .02158 L
s
.66064 .01472 m
.66064 .01831 L
s
.66159 .01472 m
.66159 .01472 L
s
.66254 .01472 m
.66254 .01827 L
s
.6635 .01472 m
.6635 .02144 L
s
.66445 .01472 m
.66445 .02392 L
s
.6654 .01472 m
.6654 .02548 L
s
.66636 .01472 m
.66636 .02598 L
s
.66731 .01472 m
.66731 .02537 L
s
.66826 .01472 m
.66826 .02374 L
s
.66922 .01472 m
.66922 .02124 L
s
.67017 .01472 m
.67017 .01813 L
s
.67112 .01472 m
.67112 .01472 L
s
.67208 .01472 m
.67208 .01809 L
s
.67303 .01472 m
.67303 .02111 L
s
.67398 .01472 m
.67398 .02347 L
s
.67494 .01472 m
.67494 .02496 L
s
.67589 .01472 m
.67589 .02544 L
s
.67684 .01472 m
.67684 .02486 L
s
.6778 .01472 m
.6778 .02331 L
s
.67875 .01472 m
.67875 .02093 L
s
.6797 .01472 m
.6797 .01797 L
s
.68066 .01472 m
.68066 .01472 L
s
.68161 .01472 m
.68161 .01794 L
s
.68256 .01472 m
.68256 .02081 L
s
.68352 .01472 m
.68352 .02307 L
s
.68447 .01472 m
.68447 .02449 L
s
.68542 .01472 m
.68542 .02495 L
s
.68638 .01472 m
.68638 .02441 L
s
.68733 .01472 m
.68733 .02292 L
s
.68828 .01472 m
.68828 .02065 L
s
.68924 .01472 m
.68924 .01782 L
s
.69019 .01472 m
.69019 .01472 L
s
.69114 .01472 m
.69114 .0178 L
s
.6921 .01472 m
.6921 .02055 L
s
.69305 .01472 m
.69305 .02271 L
s
.694 .01472 m
.694 .02408 L
s
.69496 .01472 m
.69496 .02452 L
s
.69591 .01472 m
.69591 .024 L
s
.69686 .01472 m
.69686 .02258 L
s
.69782 .01472 m
.69782 .02041 L
s
.69877 .01472 m
.69877 .01769 L
s
.69972 .01472 m
.69972 .01472 L
s
.70068 .01472 m
.70068 .01767 L
s
.70163 .01472 m
.70163 .02031 L
s
.70258 .01472 m
.70258 .02239 L
s
.70354 .01472 m
.70354 .0237 L
s
.70449 .01472 m
.70449 .02413 L
s
.70544 .01472 m
.70544 .02363 L
s
.7064 .01472 m
.7064 .02227 L
s
.70735 .01472 m
.70735 .02018 L
s
.7083 .01472 m
.7083 .01758 L
s
.70926 .01472 m
.70926 .01472 L
s
.71021 .01472 m
.71021 .01756 L
s
.71116 .01472 m
.71116 .0201 L
s
.71212 .01472 m
.71212 .0221 L
s
.71307 .01472 m
.71307 .02337 L
s
.71402 .01472 m
.71402 .02378 L
s
.71498 .01472 m
.71498 .0233 L
s
.71593 .01472 m
.71593 .02199 L
s
.71688 .01472 m
.71688 .01998 L
s
.71784 .01472 m
.71784 .01748 L
s
.71879 .01472 m
.71879 .01472 L
s
.71974 .01472 m
.71974 .01746 L
s
.7207 .01472 m
.7207 .01991 L
s
.72165 .01472 m
.72165 .02184 L
s
.7226 .01472 m
.7226 .02306 L
s
.72356 .01472 m
.72356 .02346 L
s
.72451 .01472 m
.72451 .023 L
s
.72546 .01472 m
.72546 .02174 L
s
.72642 .01472 m
.72642 .0198 L
s
.72737 .01472 m
.72737 .01738 L
s
.72832 .01472 m
.72832 .01472 L
s
.72928 .01472 m
.72928 .01736 L
s
.73023 .01472 m
.73023 .01974 L
s
.73118 .01472 m
.73118 .0216 L
s
.73214 .01472 m
.73214 .02279 L
s
.73309 .01472 m
.73309 .02317 L
s
.73404 .01472 m
.73404 .02273 L
s
.735 .01472 m
.735 .02151 L
s
.73595 .01472 m
.73595 .01964 L
s
.7369 .01472 m
.7369 .0173 L
s
.73786 .01472 m
.73786 .01472 L
s
.73881 .01472 m
.73881 .01728 L
s
.73976 .01472 m
.73976 .01958 L
s
.74072 .01472 m
.74072 .02139 L
s
.74167 .01472 m
.74167 .02253 L
s
.74262 .01472 m
.74262 .02291 L
s
.74358 .01472 m
.74358 .02249 L
s
.74453 .01472 m
.74453 .02131 L
s
.74548 .01472 m
.74548 .01949 L
s
.74644 .01472 m
.74644 .01722 L
s
.74739 .01472 m
.74739 .01472 L
s
.74834 .01472 m
.74834 .0172 L
s
.7493 .01472 m
.7493 .01943 L
s
.75025 .01472 m
.75025 .02119 L
s
.7512 .01472 m
.7512 .02231 L
s
.75216 .01472 m
.75216 .02267 L
s
.75311 .01472 m
.75311 .02226 L
s
.75406 .01472 m
.75406 .02112 L
s
.75502 .01472 m
.75502 .01935 L
s
.75597 .01472 m
.75597 .01715 L
s
.75692 .01472 m
.75692 .01472 L
s
.75788 .01472 m
.75788 .01713 L
s
.75883 .01472 m
.75883 .0193 L
s
.75978 .01472 m
.75978 .02101 L
s
.76074 .01472 m
.76074 .0221 L
s
.76169 .01472 m
.76169 .02246 L
s
.76264 .01472 m
.76264 .02206 L
s
.7636 .01472 m
.7636 .02094 L
s
.76455 .01472 m
.76455 .01923 L
s
.7655 .01472 m
.7655 .01708 L
s
.76646 .01472 m
.76646 .01472 L
s
.76741 .01472 m
.76741 .01707 L
s
.76836 .01472 m
.76836 .01918 L
s
.76932 .01472 m
.76932 .02085 L
s
.77027 .01472 m
.77027 .02191 L
s
.77122 .01472 m
.77122 .02226 L
s
.77218 .01472 m
.77218 .02187 L
s
.77313 .01472 m
.77313 .02079 L
s
.77408 .01472 m
.77408 .01912 L
s
.77504 .01472 m
.77504 .01702 L
s
.77599 .01472 m
.77599 .01472 L
s
.77694 .01472 m
.77694 .01701 L
s
.7779 .01472 m
.7779 .01907 L
s
.77885 .01472 m
.77885 .0207 L
s
.7798 .01472 m
.7798 .02173 L
s
.78076 .01472 m
.78076 .02208 L
s
.78171 .01472 m
.78171 .0217 L
s
.78266 .01472 m
.78266 .02064 L
s
.78362 .01472 m
.78362 .01901 L
s
.78457 .01472 m
.78457 .01697 L
s
.78552 .01472 m
.78552 .01472 L
s
.78648 .01472 m
.78648 .01696 L
s
.78743 .01472 m
.78743 .01897 L
s
.78838 .01472 m
.78838 .02056 L
s
.78934 .01472 m
.78934 .02157 L
s
.79029 .01472 m
.79029 .02191 L
s
.79124 .01472 m
.79124 .02154 L
s
.7922 .01472 m
.7922 .02051 L
s
.79315 .01472 m
.79315 .01892 L
s
.7941 .01472 m
.7941 .01692 L
s
.79506 .01472 m
.79506 .01472 L
s
.79601 .01472 m
.79601 .01691 L
s
.79696 .01472 m
.79696 .01888 L
s
.79792 .01472 m
.79792 .02044 L
s
.79887 .01472 m
.79887 .02143 L
s
.79982 .01472 m
.79982 .02176 L
s
.80078 .01472 m
.80078 .0214 L
s
.80173 .01472 m
.80173 .02039 L
s
.80268 .01472 m
.80268 .01883 L
s
.80364 .01472 m
.80364 .01687 L
s
.80459 .01472 m
.80459 .01472 L
s
.80554 .01472 m
.80554 .01687 L
s
.8065 .01472 m
.8065 .0188 L
s
.80745 .01472 m
.80745 .02032 L
s
.8084 .01472 m
.8084 .02129 L
s
.80936 .01472 m
.80936 .02162 L
s
.81031 .01472 m
.81031 .02127 L
s
.81126 .01472 m
.81126 .02028 L
s
.81222 .01472 m
.81222 .01875 L
s
.81317 .01472 m
.81317 .01683 L
s
.81412 .01472 m
.81412 .01472 L
s
.81508 .01472 m
.81508 .01682 L
s
.81603 .01472 m
.81603 .01872 L
s
.81698 .01472 m
.81698 .02022 L
s
.81794 .01472 m
.81794 .02117 L
s
.81889 .01472 m
.81889 .02149 L
s
.81984 .01472 m
.81984 .02115 L
s
.8208 .01472 m
.8208 .02018 L
s
.82175 .01472 m
.82175 .01868 L
s
.8227 .01472 m
.8227 .01679 L
s
.82366 .01472 m
.82366 .01472 L
s
.82461 .01472 m
.82461 .01679 L
s
.82556 .01472 m
.82556 .01865 L
s
.82652 .01472 m
.82652 .02012 L
s
.82747 .01472 m
.82747 .02106 L
s
.82842 .01472 m
.82842 .02138 L
s
.82938 .01472 m
.82938 .02104 L
s
.83033 .01472 m
.83033 .02009 L
s
.83128 .01472 m
.83128 .01861 L
s
.83224 .01472 m
.83224 .01676 L
s
.83319 .01472 m
.83319 .01472 L
s
.83414 .01472 m
.83414 .01675 L
s
.8351 .01472 m
.8351 .01859 L
s
.83605 .01472 m
.83605 .02003 L
s
.837 .01472 m
.837 .02096 L
s
.83796 .01472 m
.83796 .02127 L
s
.83891 .01472 m
.83891 .02094 L
s
.83986 .01472 m
.83986 .02 L
s
.84082 .01472 m
.84082 .01855 L
s
.84177 .01472 m
.84177 .01673 L
s
.84272 .01472 m
.84272 .01472 L
s
.84368 .01472 m
.84368 .01672 L
s
.84463 .01472 m
.84463 .01853 L
s
.84558 .01472 m
.84558 .01995 L
s
.84654 .01472 m
.84654 .02087 L
s
.84749 .01472 m
.84749 .02117 L
s
.84844 .01472 m
.84844 .02085 L
s
.8494 .01472 m
.8494 .01993 L
s
.85035 .01472 m
.85035 .0185 L
s
.8513 .01472 m
.8513 .0167 L
s
.85226 .01472 m
.85226 .01472 L
s
.85321 .01472 m
.85321 .01669 L
s
.85416 .01472 m
.85416 .01847 L
s
.85512 .01472 m
.85512 .01988 L
s
.85607 .01472 m
.85607 .02078 L
s
.85702 .01472 m
.85702 .02109 L
s
.85798 .01472 m
.85798 .02077 L
s
.85893 .01472 m
.85893 .01986 L
s
.85988 .01472 m
.85988 .01845 L
s
.86084 .01472 m
.86084 .01667 L
s
.86179 .01472 m
.86179 .01472 L
s
.86274 .01472 m
.86274 .01667 L
s
.8637 .01472 m
.8637 .01843 L
s
.86465 .01472 m
.86465 .01982 L
s
.8656 .01472 m
.8656 .02071 L
s
.86656 .01472 m
.86656 .02101 L
s
.86751 .01472 m
.86751 .02069 L
s
.86846 .01472 m
.86846 .01979 L
s
.86942 .01472 m
.86942 .0184 L
s
.87037 .01472 m
.87037 .01665 L
s
.87132 .01472 m
.87132 .01472 L
s
.87228 .01472 m
.87228 .01665 L
s
.87323 .01472 m
.87323 .01838 L
s
.87418 .01472 m
.87418 .01976 L
s
.87514 .01472 m
.87514 .02064 L
s
.87609 .01472 m
.87609 .02094 L
s
.87704 .01472 m
.87704 .02063 L
s
.878 .01472 m
.878 .01974 L
s
.87895 .01472 m
.87895 .01836 L
s
.8799 .01472 m
.8799 .01663 L
s
.88086 .01472 m
.88086 .01472 L
s
.88181 .01472 m
.88181 .01663 L
s
.88276 .01472 m
.88276 .01835 L
s
.88372 .01472 m
.88372 .01971 L
s
.88467 .01472 m
.88467 .02058 L
s
.88562 .01472 m
.88562 .02087 L
s
.88658 .01472 m
.88658 .02057 L
s
.88753 .01472 m
.88753 .01969 L
s
.88848 .01472 m
.88848 .01832 L
s
.88944 .01472 m
.88944 .01661 L
s
.89039 .01472 m
.89039 .01472 L
s
.89134 .01472 m
.89134 .01661 L
s
.8923 .01472 m
.8923 .01831 L
s
.89325 .01472 m
.89325 .01966 L
s
.8942 .01472 m
.8942 .02052 L
s
.89516 .01472 m
.89516 .02082 L
s
.89611 .01472 m
.89611 .02051 L
s
.89706 .01472 m
.89706 .01964 L
s
.89802 .01472 m
.89802 .01829 L
s
.89897 .01472 m
.89897 .01659 L
s
.89992 .01472 m
.89992 .01472 L
s
.90088 .01472 m
.90088 .01659 L
s
.90183 .01472 m
.90183 .01828 L
s
.90278 .01472 m
.90278 .01962 L
s
.90374 .01472 m
.90374 .02048 L
s
.90469 .01472 m
.90469 .02077 L
s
.90564 .01472 m
.90564 .02047 L
s
.9066 .01472 m
.9066 .01961 L
s
.90755 .01472 m
.90755 .01827 L
s
.9085 .01472 m
.9085 .01658 L
s
.90946 .01472 m
.90946 .01472 L
s
.91041 .01472 m
.91041 .01658 L
s
.91136 .01472 m
.91136 .01826 L
s
.91232 .01472 m
.91232 .01958 L
s
.91327 .01472 m
.91327 .02044 L
s
.91422 .01472 m
.91422 .02073 L
s
.91518 .01472 m
.91518 .02043 L
s
.91613 .01472 m
.91613 .01957 L
s
.91708 .01472 m
.91708 .01824 L
s
.91804 .01472 m
.91804 .01657 L
s
.91899 .01472 m
.91899 .01472 L
s
.91994 .01472 m
.91994 .01657 L
s
.9209 .01472 m
.9209 .01823 L
s
.92185 .01472 m
.92185 .01955 L
s
.9228 .01472 m
.9228 .0204 L
s
.92376 .01472 m
.92376 .02069 L
s
.92471 .01472 m
.92471 .02039 L
s
.92566 .01472 m
.92566 .01954 L
s
.92662 .01472 m
.92662 .01822 L
s
.92757 .01472 m
.92757 .01656 L
s
.92852 .01472 m
.92852 .01472 L
s
.92948 .01472 m
.92948 .01656 L
s
.93043 .01472 m
.93043 .01821 L
s
.93138 .01472 m
.93138 .01953 L
s
.93234 .01472 m
.93234 .02037 L
s
.93329 .01472 m
.93329 .02066 L
s
.93424 .01472 m
.93424 .02037 L
s
.9352 .01472 m
.9352 .01952 L
s
.93615 .01472 m
.93615 .01821 L
s
.9371 .01472 m
.9371 .01655 L
s
.93806 .01472 m
.93806 .01472 L
s
.93901 .01472 m
.93901 .01655 L
s
.93996 .01472 m
.93996 .0182 L
s
.94092 .01472 m
.94092 .01951 L
s
.94187 .01472 m
.94187 .02035 L
s
.94282 .01472 m
.94282 .02064 L
s
.94378 .01472 m
.94378 .02035 L
s
.94473 .01472 m
.94473 .0195 L
s
.94568 .01472 m
.94568 .01819 L
s
.94664 .01472 m
.94664 .01654 L
s
.94759 .01472 m
.94759 .01472 L
s
.94854 .01472 m
.94854 .01654 L
s
.9495 .01472 m
.9495 .01819 L
s
.95045 .01472 m
.95045 .01949 L
s
.9514 .01472 m
.9514 .02033 L
s
.95236 .01472 m
.95236 .02062 L
s
.95331 .01472 m
.95331 .02033 L
s
.95426 .01472 m
.95426 .01949 L
s
.95522 .01472 m
.95522 .01818 L
s
.95617 .01472 m
.95617 .01654 L
s
.95712 .01472 m
.95712 .01472 L
s
.95808 .01472 m
.95808 .01654 L
s
.95903 .01472 m
.95903 .01818 L
s
.95998 .01472 m
.95998 .01948 L
s
.96094 .01472 m
.96094 .02032 L
s
.96189 .01472 m
.96189 .02061 L
s
.96284 .01472 m
.96284 .02032 L
s
.9638 .01472 m
.9638 .01948 L
s
.96475 .01472 m
.96475 .01818 L
s
.9657 .01472 m
.9657 .01654 L
s
.96666 .01472 m
.96666 .01472 L
s
.96761 .01472 m
.96761 .01653 L
s
.96856 .01472 m
.96856 .01818 L
s
.96952 .01472 m
.96952 .01948 L
s
.97047 .01472 m
.97047 .02031 L
s
.97142 .01472 m
.97142 .0206 L
s
.97238 .01472 m
.97238 .02031 L
s
.97333 .01472 m
.97333 .01948 L
s
.97428 .01472 m
.97428 .01817 L
s
.97524 .01472 m
.97524 .01653 L
s
.97619 .01472 m
.97619 .01472 L
s
.015 w
.02381 .01653 Mdot
.02476 .01817 Mdot
.02572 .01948 Mdot
.02667 .02031 Mdot
.02762 .0206 Mdot
.02858 .02031 Mdot
.02953 .01948 Mdot
.03048 .01818 Mdot
.03144 .01653 Mdot
.03239 .01472 Mdot
.03334 .01654 Mdot
.0343 .01818 Mdot
.03525 .01948 Mdot
.0362 .02032 Mdot
.03716 .02061 Mdot
.03811 .02032 Mdot
.03906 .01948 Mdot
.04002 .01818 Mdot
.04097 .01654 Mdot
.04192 .01472 Mdot
.04288 .01654 Mdot
.04383 .01818 Mdot
.04478 .01949 Mdot
.04574 .02033 Mdot
.04669 .02062 Mdot
.04764 .02033 Mdot
.0486 .01949 Mdot
.04955 .01819 Mdot
.0505 .01654 Mdot
.05146 .01472 Mdot
.05241 .01654 Mdot
.05336 .01819 Mdot
.05432 .0195 Mdot
.05527 .02035 Mdot
.05622 .02064 Mdot
.05718 .02035 Mdot
.05813 .01951 Mdot
.05908 .0182 Mdot
.06004 .01655 Mdot
.06099 .01472 Mdot
.06194 .01655 Mdot
.0629 .01821 Mdot
.06385 .01952 Mdot
.0648 .02037 Mdot
.06576 .02066 Mdot
.06671 .02037 Mdot
.06766 .01953 Mdot
.06862 .01821 Mdot
.06957 .01656 Mdot
.07052 .01472 Mdot
.07148 .01656 Mdot
.07243 .01822 Mdot
.07338 .01954 Mdot
.07434 .02039 Mdot
.07529 .02069 Mdot
.07624 .0204 Mdot
.0772 .01955 Mdot
.07815 .01823 Mdot
.0791 .01657 Mdot
.08006 .01472 Mdot
.08101 .01657 Mdot
.08196 .01824 Mdot
.08292 .01957 Mdot
.08387 .02043 Mdot
.08482 .02073 Mdot
.08578 .02044 Mdot
.08673 .01958 Mdot
.08768 .01826 Mdot
.08864 .01658 Mdot
.08959 .01472 Mdot
.09054 .01658 Mdot
.0915 .01827 Mdot
.09245 .01961 Mdot
.0934 .02047 Mdot
.09436 .02077 Mdot
.09531 .02048 Mdot
.09626 .01962 Mdot
.09722 .01828 Mdot
.09817 .01659 Mdot
.09912 .01472 Mdot
.10008 .01659 Mdot
.10103 .01829 Mdot
.10198 .01964 Mdot
.10294 .02051 Mdot
.10389 .02082 Mdot
.10484 .02052 Mdot
.1058 .01966 Mdot
.10675 .01831 Mdot
.1077 .01661 Mdot
.10866 .01472 Mdot
.10961 .01661 Mdot
.11056 .01832 Mdot
.11152 .01969 Mdot
.11247 .02057 Mdot
.11342 .02087 Mdot
.11438 .02058 Mdot
.11533 .01971 Mdot
.11628 .01835 Mdot
.11724 .01663 Mdot
.11819 .01472 Mdot
.11914 .01663 Mdot
.1201 .01836 Mdot
.12105 .01974 Mdot
.122 .02063 Mdot
.12296 .02094 Mdot
.12391 .02064 Mdot
.12486 .01976 Mdot
.12582 .01838 Mdot
.12677 .01665 Mdot
.12772 .01472 Mdot
.12868 .01665 Mdot
.12963 .0184 Mdot
.13058 .01979 Mdot
.13154 .02069 Mdot
.13249 .02101 Mdot
.13344 .02071 Mdot
.1344 .01982 Mdot
.13535 .01843 Mdot
.1363 .01667 Mdot
.13726 .01472 Mdot
.13821 .01667 Mdot
.13916 .01845 Mdot
.14012 .01986 Mdot
.14107 .02077 Mdot
.14202 .02109 Mdot
.14298 .02078 Mdot
.14393 .01988 Mdot
.14488 .01847 Mdot
.14584 .01669 Mdot
.14679 .01472 Mdot
.14774 .0167 Mdot
.1487 .0185 Mdot
.14965 .01993 Mdot
.1506 .02085 Mdot
.15156 .02117 Mdot
.15251 .02087 Mdot
.15346 .01995 Mdot
.15442 .01853 Mdot
.15537 .01672 Mdot
.15632 .01472 Mdot
.15728 .01673 Mdot
.15823 .01855 Mdot
.15918 .02 Mdot
.16014 .02094 Mdot
.16109 .02127 Mdot
.16204 .02096 Mdot
.163 .02003 Mdot
.16395 .01859 Mdot
.1649 .01675 Mdot
.16586 .01472 Mdot
.16681 .01676 Mdot
.16776 .01861 Mdot
.16872 .02009 Mdot
.16967 .02104 Mdot
.17062 .02138 Mdot
.17158 .02106 Mdot
.17253 .02012 Mdot
.17348 .01865 Mdot
.17444 .01679 Mdot
.17539 .01472 Mdot
.17634 .01679 Mdot
.1773 .01868 Mdot
.17825 .02018 Mdot
.1792 .02115 Mdot
.18016 .02149 Mdot
.18111 .02117 Mdot
.18206 .02022 Mdot
.18302 .01872 Mdot
.18397 .01682 Mdot
.18492 .01472 Mdot
.18588 .01683 Mdot
.18683 .01875 Mdot
.18778 .02028 Mdot
.18874 .02127 Mdot
.18969 .02162 Mdot
.19064 .02129 Mdot
.1916 .02032 Mdot
.19255 .0188 Mdot
.1935 .01687 Mdot
.19446 .01472 Mdot
.19541 .01687 Mdot
.19636 .01883 Mdot
.19732 .02039 Mdot
.19827 .0214 Mdot
.19922 .02176 Mdot
.20018 .02143 Mdot
.20113 .02044 Mdot
.20208 .01888 Mdot
.20304 .01691 Mdot
.20399 .01472 Mdot
.20494 .01692 Mdot
.2059 .01892 Mdot
.20685 .02051 Mdot
.2078 .02154 Mdot
.20876 .02191 Mdot
.20971 .02157 Mdot
.21066 .02056 Mdot
.21162 .01897 Mdot
.21257 .01696 Mdot
.21352 .01472 Mdot
.21448 .01697 Mdot
.21543 .01901 Mdot
.21638 .02064 Mdot
.21734 .0217 Mdot
.21829 .02208 Mdot
.21924 .02173 Mdot
.2202 .0207 Mdot
.22115 .01907 Mdot
.2221 .01701 Mdot
.22306 .01472 Mdot
.22401 .01702 Mdot
.22496 .01912 Mdot
.22592 .02079 Mdot
.22687 .02187 Mdot
.22782 .02226 Mdot
.22878 .02191 Mdot
.22973 .02085 Mdot
.23068 .01918 Mdot
.23164 .01707 Mdot
.23259 .01472 Mdot
.23354 .01708 Mdot
.2345 .01923 Mdot
.23545 .02094 Mdot
.2364 .02206 Mdot
.23736 .02246 Mdot
.23831 .0221 Mdot
.23926 .02101 Mdot
.24022 .0193 Mdot
.24117 .01713 Mdot
.24212 .01472 Mdot
.24308 .01715 Mdot
.24403 .01935 Mdot
.24498 .02112 Mdot
.24594 .02226 Mdot
.24689 .02267 Mdot
.24784 .02231 Mdot
.2488 .02119 Mdot
.24975 .01943 Mdot
.2507 .0172 Mdot
.25166 .01472 Mdot
.25261 .01722 Mdot
.25356 .01949 Mdot
.25452 .02131 Mdot
.25547 .02249 Mdot
.25642 .02291 Mdot
.25738 .02253 Mdot
.25833 .02139 Mdot
.25928 .01958 Mdot
.26024 .01728 Mdot
.26119 .01472 Mdot
.26214 .0173 Mdot
.2631 .01964 Mdot
.26405 .02151 Mdot
.265 .02273 Mdot
.26596 .02317 Mdot
.26691 .02279 Mdot
.26786 .0216 Mdot
.26882 .01974 Mdot
.26977 .01736 Mdot
.27072 .01472 Mdot
.27168 .01738 Mdot
.27263 .0198 Mdot
.27358 .02174 Mdot
.27454 .023 Mdot
.27549 .02346 Mdot
.27644 .02306 Mdot
.2774 .02184 Mdot
.27835 .01991 Mdot
.2793 .01746 Mdot
.28026 .01472 Mdot
.28121 .01748 Mdot
.28216 .01998 Mdot
.28312 .02199 Mdot
.28407 .0233 Mdot
.28502 .02378 Mdot
.28598 .02337 Mdot
.28693 .0221 Mdot
.28788 .0201 Mdot
.28884 .01756 Mdot
.28979 .01472 Mdot
.29074 .01758 Mdot
.2917 .02018 Mdot
.29265 .02227 Mdot
.2936 .02363 Mdot
.29456 .02413 Mdot
.29551 .0237 Mdot
.29646 .02239 Mdot
.29742 .02031 Mdot
.29837 .01767 Mdot
.29932 .01472 Mdot
.30028 .01769 Mdot
.30123 .02041 Mdot
.30218 .02258 Mdot
.30314 .024 Mdot
.30409 .02452 Mdot
.30504 .02408 Mdot
.306 .02271 Mdot
.30695 .02055 Mdot
.3079 .0178 Mdot
.30886 .01472 Mdot
.30981 .01782 Mdot
.31076 .02065 Mdot
.31172 .02292 Mdot
.31267 .02441 Mdot
.31362 .02495 Mdot
.31458 .02449 Mdot
.31553 .02307 Mdot
.31648 .02081 Mdot
.31744 .01794 Mdot
.31839 .01472 Mdot
.31934 .01797 Mdot
.3203 .02093 Mdot
.32125 .02331 Mdot
.3222 .02486 Mdot
.32316 .02544 Mdot
.32411 .02496 Mdot
.32506 .02347 Mdot
.32602 .02111 Mdot
.32697 .01809 Mdot
.32792 .01472 Mdot
.32888 .01813 Mdot
.32983 .02124 Mdot
.33078 .02374 Mdot
.33174 .02537 Mdot
.33269 .02598 Mdot
.33364 .02548 Mdot
.3346 .02392 Mdot
.33555 .02144 Mdot
.3365 .01827 Mdot
.33746 .01472 Mdot
.33841 .01831 Mdot
.33936 .02158 Mdot
.34032 .02422 Mdot
.34127 .02595 Mdot
.34222 .0266 Mdot
.34318 .02608 Mdot
.34413 .02443 Mdot
.34508 .02182 Mdot
.34604 .01847 Mdot
.34699 .01472 Mdot
.34794 .01851 Mdot
.3489 .02198 Mdot
.34985 .02477 Mdot
.3508 .02661 Mdot
.35176 .02729 Mdot
.35271 .02675 Mdot
.35366 .02501 Mdot
.35462 .02224 Mdot
.35557 .0187 Mdot
.35652 .01472 Mdot
.35748 .01875 Mdot
.35843 .02243 Mdot
.35938 .0254 Mdot
.36034 .02736 Mdot
.36129 .02809 Mdot
.36224 .02752 Mdot
.3632 .02568 Mdot
.36415 .02273 Mdot
.3651 .01896 Mdot
.36606 .01472 Mdot
.36701 .01902 Mdot
.36796 .02295 Mdot
.36892 .02613 Mdot
.36987 .02822 Mdot
.37082 .02902 Mdot
.37178 .02841 Mdot
.37273 .02645 Mdot
.37368 .0233 Mdot
.37464 .01926 Mdot
.37559 .01472 Mdot
.37654 .01933 Mdot
.3775 .02356 Mdot
.37845 .02697 Mdot
.3794 .02923 Mdot
.38036 .0301 Mdot
.38131 .02946 Mdot
.38226 .02735 Mdot
.38322 .02397 Mdot
.38417 .01962 Mdot
.38512 .01472 Mdot
.38608 .0197 Mdot
.38703 .02427 Mdot
.38798 .02797 Mdot
.38894 .03042 Mdot
.38989 .03137 Mdot
.39084 .03068 Mdot
.3918 .02841 Mdot
.39275 .02475 Mdot
.3937 .02004 Mdot
.39466 .01472 Mdot
.39561 .02013 Mdot
.39656 .02511 Mdot
.39752 .02915 Mdot
.39847 .03184 Mdot
.39942 .03289 Mdot
.40038 .03216 Mdot
.40133 .02969 Mdot
.40228 .0257 Mdot
.40324 .02054 Mdot
.40419 .01472 Mdot
.40514 .02066 Mdot
.4061 .02613 Mdot
.40705 .03059 Mdot
.408 .03356 Mdot
.40896 .03473 Mdot
.40991 .03395 Mdot
.41086 .03125 Mdot
.41182 .02685 Mdot
.41277 .02116 Mdot
.41372 .01472 Mdot
.41468 .02131 Mdot
.41563 .02739 Mdot
.41658 .03236 Mdot
.41754 .03569 Mdot
.41849 .03702 Mdot
.41944 .03618 Mdot
.4204 .03319 Mdot
.42135 .02829 Mdot
.4223 .02194 Mdot
.42326 .01472 Mdot
.42421 .02212 Mdot
.42516 .02898 Mdot
.42612 .03459 Mdot
.42707 .03839 Mdot
.42802 .03993 Mdot
.42898 .03901 Mdot
.42993 .03566 Mdot
.43088 .03014 Mdot
.43184 .02294 Mdot
.43279 .01472 Mdot
.43374 .02317 Mdot
.4347 .03103 Mdot
.43565 .03751 Mdot
.4366 .04191 Mdot
.43756 .04374 Mdot
.43851 .04275 Mdot
.43946 .03893 Mdot
.44042 .03259 Mdot
.44137 .02426 Mdot
.44232 .01472 Mdot
.44328 .02458 Mdot
.44423 .03381 Mdot
.44518 .04145 Mdot
.44614 .0467 Mdot
.44709 .04895 Mdot
.44804 .04787 Mdot
.449 .04345 Mdot
.44995 .03599 Mdot
.4509 .02612 Mdot
.45186 .01472 Mdot
.45281 .02658 Mdot
.45376 .03775 Mdot
.45472 .04708 Mdot
.45567 .05359 Mdot
.45662 .05649 Mdot
.45758 .05534 Mdot
.45853 .05007 Mdot
.45948 .04101 Mdot
.46044 .02888 Mdot
.46139 .01472 Mdot
.46234 .0296 Mdot
.4633 .04376 Mdot
.46425 .05577 Mdot
.4652 .06432 Mdot
.46616 .06835 Mdot
.46711 .06722 Mdot
.46806 .06073 Mdot
.46902 .04919 Mdot
.46997 .03342 Mdot
.47092 .01472 Mdot
.47188 .03471 Mdot
.47283 .0541 Mdot
.47378 .07092 Mdot
.47474 .08333 Mdot
.47569 .08974 Mdot
.47664 .08903 Mdot
.4776 .08068 Mdot
.47855 .06481 Mdot
.4795 .04231 Mdot
.48046 .01472 Mdot
.48141 .04521 Mdot
.48236 .07593 Mdot
.48332 .10392 Mdot
.48427 .12613 Mdot
.48522 .13967 Mdot
.48618 .14203 Mdot
.48713 .13134 Mdot
.48808 .10651 Mdot
.48904 .06736 Mdot
.48999 .01472 Mdot
.49094 .07905 Mdot
.4919 .15239 Mdot
.49285 .23127 Mdot
.4938 .31171 Mdot
.49476 .38945 Mdot
.49571 .4602 Mdot
.49666 .51998 Mdot
.49762 .56535 Mdot
.49857 .59369 Mdot
.49952 .60332 Mdot
.50048 .59369 Mdot
.50143 .56535 Mdot
.50238 .51998 Mdot
.50334 .4602 Mdot
.50429 .38945 Mdot
.50524 .31171 Mdot
.5062 .23127 Mdot
.50715 .15239 Mdot
.5081 .07905 Mdot
.50906 .01472 Mdot
.51001 .06736 Mdot
.51096 .10651 Mdot
.51192 .13134 Mdot
.51287 .14203 Mdot
.51382 .13967 Mdot
.51478 .12613 Mdot
.51573 .10392 Mdot
.51668 .07593 Mdot
.51764 .04521 Mdot
.51859 .01472 Mdot
.51954 .04231 Mdot
.5205 .06481 Mdot
.52145 .08068 Mdot
.5224 .08903 Mdot
.52336 .08974 Mdot
.52431 .08333 Mdot
.52526 .07092 Mdot
.52622 .0541 Mdot
.52717 .03471 Mdot
.52812 .01472 Mdot
.52908 .03342 Mdot
.53003 .04919 Mdot
.53098 .06073 Mdot
.53194 .06722 Mdot
.53289 .06835 Mdot
.53384 .06432 Mdot
.5348 .05577 Mdot
.53575 .04376 Mdot
.5367 .0296 Mdot
.53766 .01472 Mdot
.53861 .02888 Mdot
.53956 .04101 Mdot
.54052 .05007 Mdot
.54147 .05534 Mdot
.54242 .05649 Mdot
.54338 .05359 Mdot
.54433 .04708 Mdot
.54528 .03775 Mdot
.54624 .02658 Mdot
.54719 .01472 Mdot
.54814 .02612 Mdot
.5491 .03599 Mdot
.55005 .04345 Mdot
.551 .04787 Mdot
.55196 .04895 Mdot
.55291 .0467 Mdot
.55386 .04145 Mdot
.55482 .03381 Mdot
.55577 .02458 Mdot
.55672 .01472 Mdot
.55768 .02426 Mdot
.55863 .03259 Mdot
.55958 .03893 Mdot
.56054 .04275 Mdot
.56149 .04374 Mdot
.56244 .04191 Mdot
.5634 .03751 Mdot
.56435 .03103 Mdot
.5653 .02317 Mdot
.56626 .01472 Mdot
.56721 .02294 Mdot
.56816 .03014 Mdot
.56912 .03566 Mdot
.57007 .03901 Mdot
.57102 .03993 Mdot
.57198 .03839 Mdot
.57293 .03459 Mdot
.57388 .02898 Mdot
.57484 .02212 Mdot
.57579 .01472 Mdot
.57674 .02194 Mdot
.5777 .02829 Mdot
.57865 .03319 Mdot
.5796 .03618 Mdot
.58056 .03702 Mdot
.58151 .03569 Mdot
.58246 .03236 Mdot
.58342 .02739 Mdot
.58437 .02131 Mdot
.58532 .01472 Mdot
.58628 .02116 Mdot
.58723 .02685 Mdot
.58818 .03125 Mdot
.58914 .03395 Mdot
.59009 .03473 Mdot
.59104 .03356 Mdot
.592 .03059 Mdot
.59295 .02613 Mdot
.5939 .02066 Mdot
.59486 .01472 Mdot
.59581 .02054 Mdot
.59676 .0257 Mdot
.59772 .02969 Mdot
.59867 .03216 Mdot
.59962 .03289 Mdot
.60058 .03184 Mdot
.60153 .02915 Mdot
.60248 .02511 Mdot
.60344 .02013 Mdot
.60439 .01472 Mdot
.60534 .02004 Mdot
.6063 .02475 Mdot
.60725 .02841 Mdot
.6082 .03068 Mdot
.60916 .03137 Mdot
.61011 .03042 Mdot
.61106 .02797 Mdot
.61202 .02427 Mdot
.61297 .0197 Mdot
.61392 .01472 Mdot
.61488 .01962 Mdot
.61583 .02397 Mdot
.61678 .02735 Mdot
.61774 .02946 Mdot
.61869 .0301 Mdot
.61964 .02923 Mdot
.6206 .02697 Mdot
.62155 .02356 Mdot
.6225 .01933 Mdot
.62346 .01472 Mdot
.62441 .01926 Mdot
.62536 .0233 Mdot
.62632 .02645 Mdot
.62727 .02841 Mdot
.62822 .02902 Mdot
.62918 .02822 Mdot
.63013 .02613 Mdot
.63108 .02295 Mdot
.63204 .01902 Mdot
.63299 .01472 Mdot
.63394 .01896 Mdot
.6349 .02273 Mdot
.63585 .02568 Mdot
.6368 .02752 Mdot
.63776 .02809 Mdot
.63871 .02736 Mdot
.63966 .0254 Mdot
.64062 .02243 Mdot
.64157 .01875 Mdot
.64252 .01472 Mdot
.64348 .0187 Mdot
.64443 .02224 Mdot
.64538 .02501 Mdot
.64634 .02675 Mdot
.64729 .02729 Mdot
.64824 .02661 Mdot
.6492 .02477 Mdot
.65015 .02198 Mdot
.6511 .01851 Mdot
.65206 .01472 Mdot
.65301 .01847 Mdot
.65396 .02182 Mdot
.65492 .02443 Mdot
.65587 .02608 Mdot
.65682 .0266 Mdot
.65778 .02595 Mdot
.65873 .02422 Mdot
.65968 .02158 Mdot
.66064 .01831 Mdot
.66159 .01472 Mdot
.66254 .01827 Mdot
.6635 .02144 Mdot
.66445 .02392 Mdot
.6654 .02548 Mdot
.66636 .02598 Mdot
.66731 .02537 Mdot
.66826 .02374 Mdot
.66922 .02124 Mdot
.67017 .01813 Mdot
.67112 .01472 Mdot
.67208 .01809 Mdot
.67303 .02111 Mdot
.67398 .02347 Mdot
.67494 .02496 Mdot
.67589 .02544 Mdot
.67684 .02486 Mdot
.6778 .02331 Mdot
.67875 .02093 Mdot
.6797 .01797 Mdot
.68066 .01472 Mdot
.68161 .01794 Mdot
.68256 .02081 Mdot
.68352 .02307 Mdot
.68447 .02449 Mdot
.68542 .02495 Mdot
.68638 .02441 Mdot
.68733 .02292 Mdot
.68828 .02065 Mdot
.68924 .01782 Mdot
.69019 .01472 Mdot
.69114 .0178 Mdot
.6921 .02055 Mdot
.69305 .02271 Mdot
.694 .02408 Mdot
.69496 .02452 Mdot
.69591 .024 Mdot
.69686 .02258 Mdot
.69782 .02041 Mdot
.69877 .01769 Mdot
.69972 .01472 Mdot
.70068 .01767 Mdot
.70163 .02031 Mdot
.70258 .02239 Mdot
.70354 .0237 Mdot
.70449 .02413 Mdot
.70544 .02363 Mdot
.7064 .02227 Mdot
.70735 .02018 Mdot
.7083 .01758 Mdot
.70926 .01472 Mdot
.71021 .01756 Mdot
.71116 .0201 Mdot
.71212 .0221 Mdot
.71307 .02337 Mdot
.71402 .02378 Mdot
.71498 .0233 Mdot
.71593 .02199 Mdot
.71688 .01998 Mdot
.71784 .01748 Mdot
.71879 .01472 Mdot
.71974 .01746 Mdot
.7207 .01991 Mdot
.72165 .02184 Mdot
.7226 .02306 Mdot
.72356 .02346 Mdot
.72451 .023 Mdot
.72546 .02174 Mdot
.72642 .0198 Mdot
.72737 .01738 Mdot
.72832 .01472 Mdot
.72928 .01736 Mdot
.73023 .01974 Mdot
.73118 .0216 Mdot
.73214 .02279 Mdot
.73309 .02317 Mdot
.73404 .02273 Mdot
.735 .02151 Mdot
.73595 .01964 Mdot
.7369 .0173 Mdot
.73786 .01472 Mdot
.73881 .01728 Mdot
.73976 .01958 Mdot
.74072 .02139 Mdot
.74167 .02253 Mdot
.74262 .02291 Mdot
.74358 .02249 Mdot
.74453 .02131 Mdot
.74548 .01949 Mdot
.74644 .01722 Mdot
.74739 .01472 Mdot
.74834 .0172 Mdot
.7493 .01943 Mdot
.75025 .02119 Mdot
.7512 .02231 Mdot
.75216 .02267 Mdot
.75311 .02226 Mdot
.75406 .02112 Mdot
.75502 .01935 Mdot
.75597 .01715 Mdot
.75692 .01472 Mdot
.75788 .01713 Mdot
.75883 .0193 Mdot
.75978 .02101 Mdot
.76074 .0221 Mdot
.76169 .02246 Mdot
.76264 .02206 Mdot
.7636 .02094 Mdot
.76455 .01923 Mdot
.7655 .01708 Mdot
.76646 .01472 Mdot
.76741 .01707 Mdot
.76836 .01918 Mdot
.76932 .02085 Mdot
.77027 .02191 Mdot
.77122 .02226 Mdot
.77218 .02187 Mdot
.77313 .02079 Mdot
.77408 .01912 Mdot
.77504 .01702 Mdot
.77599 .01472 Mdot
.77694 .01701 Mdot
.7779 .01907 Mdot
.77885 .0207 Mdot
.7798 .02173 Mdot
.78076 .02208 Mdot
.78171 .0217 Mdot
.78266 .02064 Mdot
.78362 .01901 Mdot
.78457 .01697 Mdot
.78552 .01472 Mdot
.78648 .01696 Mdot
.78743 .01897 Mdot
.78838 .02056 Mdot
.78934 .02157 Mdot
.79029 .02191 Mdot
.79124 .02154 Mdot
.7922 .02051 Mdot
.79315 .01892 Mdot
.7941 .01692 Mdot
.79506 .01472 Mdot
.79601 .01691 Mdot
.79696 .01888 Mdot
.79792 .02044 Mdot
.79887 .02143 Mdot
.79982 .02176 Mdot
.80078 .0214 Mdot
.80173 .02039 Mdot
.80268 .01883 Mdot
.80364 .01687 Mdot
.80459 .01472 Mdot
.80554 .01687 Mdot
.8065 .0188 Mdot
.80745 .02032 Mdot
.8084 .02129 Mdot
.80936 .02162 Mdot
.81031 .02127 Mdot
.81126 .02028 Mdot
.81222 .01875 Mdot
.81317 .01683 Mdot
.81412 .01472 Mdot
.81508 .01682 Mdot
.81603 .01872 Mdot
.81698 .02022 Mdot
.81794 .02117 Mdot
.81889 .02149 Mdot
.81984 .02115 Mdot
.8208 .02018 Mdot
.82175 .01868 Mdot
.8227 .01679 Mdot
.82366 .01472 Mdot
.82461 .01679 Mdot
.82556 .01865 Mdot
.82652 .02012 Mdot
.82747 .02106 Mdot
.82842 .02138 Mdot
.82938 .02104 Mdot
.83033 .02009 Mdot
.83128 .01861 Mdot
.83224 .01676 Mdot
.83319 .01472 Mdot
.83414 .01675 Mdot
.8351 .01859 Mdot
.83605 .02003 Mdot
.837 .02096 Mdot
.83796 .02127 Mdot
.83891 .02094 Mdot
.83986 .02 Mdot
.84082 .01855 Mdot
.84177 .01673 Mdot
.84272 .01472 Mdot
.84368 .01672 Mdot
.84463 .01853 Mdot
.84558 .01995 Mdot
.84654 .02087 Mdot
.84749 .02117 Mdot
.84844 .02085 Mdot
.8494 .01993 Mdot
.85035 .0185 Mdot
.8513 .0167 Mdot
.85226 .01472 Mdot
.85321 .01669 Mdot
.85416 .01847 Mdot
.85512 .01988 Mdot
.85607 .02078 Mdot
.85702 .02109 Mdot
.85798 .02077 Mdot
.85893 .01986 Mdot
.85988 .01845 Mdot
.86084 .01667 Mdot
.86179 .01472 Mdot
.86274 .01667 Mdot
.8637 .01843 Mdot
.86465 .01982 Mdot
.8656 .02071 Mdot
.86656 .02101 Mdot
.86751 .02069 Mdot
.86846 .01979 Mdot
.86942 .0184 Mdot
.87037 .01665 Mdot
.87132 .01472 Mdot
.87228 .01665 Mdot
.87323 .01838 Mdot
.87418 .01976 Mdot
.87514 .02064 Mdot
.87609 .02094 Mdot
.87704 .02063 Mdot
.878 .01974 Mdot
.87895 .01836 Mdot
.8799 .01663 Mdot
.88086 .01472 Mdot
.88181 .01663 Mdot
.88276 .01835 Mdot
.88372 .01971 Mdot
.88467 .02058 Mdot
.88562 .02087 Mdot
.88658 .02057 Mdot
.88753 .01969 Mdot
.88848 .01832 Mdot
.88944 .01661 Mdot
.89039 .01472 Mdot
.89134 .01661 Mdot
.8923 .01831 Mdot
.89325 .01966 Mdot
.8942 .02052 Mdot
.89516 .02082 Mdot
.89611 .02051 Mdot
.89706 .01964 Mdot
.89802 .01829 Mdot
.89897 .01659 Mdot
.89992 .01472 Mdot
.90088 .01659 Mdot
.90183 .01828 Mdot
.90278 .01962 Mdot
.90374 .02048 Mdot
.90469 .02077 Mdot
.90564 .02047 Mdot
.9066 .01961 Mdot
.90755 .01827 Mdot
.9085 .01658 Mdot
.90946 .01472 Mdot
.91041 .01658 Mdot
.91136 .01826 Mdot
.91232 .01958 Mdot
.91327 .02044 Mdot
.91422 .02073 Mdot
.91518 .02043 Mdot
.91613 .01957 Mdot
.91708 .01824 Mdot
.91804 .01657 Mdot
.91899 .01472 Mdot
.91994 .01657 Mdot
.9209 .01823 Mdot
.92185 .01955 Mdot
.9228 .0204 Mdot
.92376 .02069 Mdot
.92471 .02039 Mdot
.92566 .01954 Mdot
.92662 .01822 Mdot
.92757 .01656 Mdot
.92852 .01472 Mdot
.92948 .01656 Mdot
.93043 .01821 Mdot
.93138 .01953 Mdot
.93234 .02037 Mdot
.93329 .02066 Mdot
.93424 .02037 Mdot
.9352 .01952 Mdot
.93615 .01821 Mdot
.9371 .01655 Mdot
.93806 .01472 Mdot
.93901 .01655 Mdot
.93996 .0182 Mdot
.94092 .01951 Mdot
.94187 .02035 Mdot
.94282 .02064 Mdot
.94378 .02035 Mdot
.94473 .0195 Mdot
.94568 .01819 Mdot
.94664 .01654 Mdot
.94759 .01472 Mdot
.94854 .01654 Mdot
.9495 .01819 Mdot
.95045 .01949 Mdot
.9514 .02033 Mdot
.95236 .02062 Mdot
.95331 .02033 Mdot
.95426 .01949 Mdot
.95522 .01818 Mdot
.95617 .01654 Mdot
.95712 .01472 Mdot
.95808 .01654 Mdot
.95903 .01818 Mdot
.95998 .01948 Mdot
.96094 .02032 Mdot
.96189 .02061 Mdot
.96284 .02032 Mdot
.9638 .01948 Mdot
.96475 .01818 Mdot
.9657 .01654 Mdot
.96666 .01472 Mdot
.96761 .01653 Mdot
.96856 .01818 Mdot
.96952 .01948 Mdot
.97047 .02031 Mdot
.97142 .0206 Mdot
.97238 .02031 Mdot
.97333 .01948 Mdot
.97428 .01817 Mdot
.97524 .01653 Mdot
.97619 .01472 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00<?ooool3o`0000?ooooo0_l00004ooooo`;o00008oooool5o`0000?ooooo0_l00004oooo
o`;o00009oooool2o`0002Wooooo1Ol00003ooooo`;o00001?ooool2o`0002Gooooo0ol00003oooo
o`;o00001?ooool2o`0001[ooooo000aooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Gooooo00Co0000oooooooo
oooo0000:Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00009Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0Gooooo`00:?ooool5o`000003ooooool0003o000000?o
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001cooooo1Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000Uooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0002;ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00006Oooool002kooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08ooo
ool01?l0003oooooooooool0000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000_ooooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Rooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Gooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Iooooo`00<?oo
ool2o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Rooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0002Gooooo00Co0000oooooooooooo0000:?ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Tooooo`;o00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Wooooo000aooooo`03o`000?oo
oooooooo00;ooooo0_l00004ooooo`;o00009?ooool3o`0000Cooooo0_l00004ooooo`;o00009ooo
ool2o`0002[ooooo0ol00004ooooo`;o00001?ooool2o`0002Kooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo0_l0000Jooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`005Ooooooo000000/000000Oooool000kooooo0_l00005ooooo`0300000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo0@000001ooooo`003Oooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo01cooooo00?o0000ooooooooool0<?ooool00`00003oooooooooo`0_ooooo`0300000?oooooo
oooo033ooooo00?o0000ooooooooool0<?ooool00`00003oooooooooo`0Looooo`4000000Oooool0
00gooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`04oooooggoo`000_oooomo
ool000Cooooo0@000001ooooo`003Oooool01?l0003oooooooooool00004ooooo`<000000_oooomo
ool00080o`00Oooo0003ooooo`7o00000@000001ooooo`003Oooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo00;oooooOooo00020?l007ooo`001?ooool10000007ooooo000=oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00_oooomeool001D0o`00MOoo0005
ooooo`4000000Oooool000kooooo0_l00005ooooo`0300000?oooooooooo00?oooooM_oo000A0?l0
07Ooo`001Oooool10000007ooooo000Eooooo`0300000?oooooooooo04Gooooo=_oo000=0?l003Ko
o`00B?ooool10000007ooooo000Eooooo`0300000?oooooooooo05Wooooo8ooo000;0?l002?oo`00
G?ooool10000007ooooo000Eooooo`0300000?oooooooooo06?ooooo6Ooo000;0?l001Woo`00I_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo06Sooooo5_oo00070?l001Koo`00Joooool1
0000007ooooo000Eooooo`0300000?l0003ooooo06gooooo4Ooo00070?l0017oo`00Koooool1o`00
004000000Oooool001Gooooo00<00000ooooooooool0L?ooool>ool000L0o`003_oo001cooooo`40
00000Oooool001Gooooo00<00000ooooooooool0L_ooool:ool000/0o`002_oo001eooooo`400000
0Oooool001Gooooo00<00000ooooooooool0M?ooool8ool000/0o`002?oo001gooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0M?ooool8ool000/0o`002?oo001gooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0Moooool9ool000<0o`002Ooo001jooooo`4000000Oooool001Go
oooo00<00000ooooooooool0Moooool9ool000<0o`002Ooo001jooooo`4000000Oooool001Gooooo
00<00000o`000?ooool0Moooool9ool000<0o`002Ooo001iooooo`7o00000@000001ooooo`005Ooo
ool00`00003oooooooooo`1iooooo`Soo`0000<0o`00ool00?oo00001_oo001looooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0NOooool8ool000030?l00?oo003oo`0000Koo`00O?ooool1
0000007ooooo000Eooooo`0300000?oooooooooo07Wooooo1?oo00001@3o003oo`00ool00?oo0000
o`0000?oo`0000<0o`00ool00?oo00000_oo001looooo`4000000Oooool001Gooooo00<00000oooo
ooooool0NOooool4ool000L0o`0000?ooooo0?l00?oo00000ooo001looooo`4000000Oooool001Go
oooo00<00000ooooooooool0N_ooool3ool000L0o`0000?ooooo0?l00?oo00000_oo001mooooo`40
00000Oooool001Gooooo00<00000ooooooooool0N_ooool3ool000L0o`0000?ooooo0?l00?oo0000
0_oo001mooooo`4000000Oooool001Gooooo00<00000ooooooooool0OOooool70?l00003ooooo`3o
0000o`0007oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1looooo`?oo`001@3o0003
ool007kooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo07cooooo1?oo00030?l0
00Coo`00Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07cooooo1?oo00030?l000Co
o`00Ooooool10000007ooooo000Eooooo`0300000?oooooooooo07gooooo0ooo00030?l000?oo`00
00<0o`00ooooooooool0OOooool10000007ooooo000Eooooo`0300000?oooooooooo07gooooo1`3o
00000oooool0o`000?l0001oooooo`4000000Oooool001Gooooo00<00000ooooooooool0OOooool7
0?l00003ooooo`3o0000o`0007oooooo0@000001ooooo`001_ooool5o`0000?ooooo0_l00005oooo
o`0300000?oooooooooo07cooooo0ooo00050?l000?oo`00Ooooool10000007ooooo0007ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1l
ooooo`Coo`000`3o0004ool007oooooo0@000001ooooo`002?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000o`000?l00000O?ooool4ool000<0o`001?oo001n
ooooo`7o00000@000001ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool00`00003oooooooooo`1looooo`Coo`000`3o0004ool007oooooo0@000001
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`1looooo`?oo`001@3o0003ool007oooooo0@000001ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`1looooo`?oo`001@3o0003ool007oooooo0@000001ooooo`001oooool3o`0000Cooooo0_l0
0005ooooo`0300000?oooooooooo07cooooo0ooo00050?l000?oo`00Ooooool10000007ooooo000E
ooooo`0300000?oooooooooo07kooooo0ooo0000103o003oo`00ool00?oo0021ooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0O_ooool3ool000040?l00?oo003oo`00ool0087ooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1nooooo`?oo`0000@0o`00ool00?oo003oo`00POoo
ool10000007ooooo000Eooooo`0300000?l0003ooooo083ooooo103o0021ooooo`7o00000@000001
ooooo`005Oooool00`00003oooooooooo`20ooooo`@0o`00P_ooool10000007ooooo000Eooooo`03
00000?oooooooooo083ooooo103o0022ooooo`4000000Oooool001Gooooo00<00000ooooooooool0
P?ooool40?l008;ooooo0@000001ooooo`005Oooool00`00003oooooooooo`20ooooo`@0o`00P_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo083ooooo103o0022ooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0P?ooool40?l008;ooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`20ooooo`@0o`00P_ooool10000007ooooo000Eooooo`0300000?l0003ooooo083ooooo
103o0021ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`20ooooo`@0o`00P_oo
ool10000007ooooo000Eooooo`0300000?oooooooooo083ooooo103o0022ooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0P?ooool40?l008;ooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`20ooooo`@0o`00P_ooool10000007ooooo000Eooooo`0300000?oooooooooo083ooooo
103o0022ooooo`4000000Oooool001Gooooo00<00000ooooooooool0P?ooool40?l008;ooooo0@00
0001ooooo`005Oooool00`00003o0000ooooo`20ooooo`@0o`00POooool1o`00004000000Oooool0
01Gooooo00<00000ooooooooool0P?ooool40?l008;ooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`20ooooo`@0o`00P_ooool10000007ooooo000Eooooo`0300000?oooooooooo07kooooo
0ooo0000103o003oo`00ool00?oo0021ooooo`4000000Oooool001Gooooo00<00000ooooooooool0
O_ooool3ool000040?l00?oo003oo`00ool0087ooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`1nooooo`?oo`0000@0o`00ool00?oo003oo`00POooool10000007ooooo0008ooooo`?o0000
0oooool2o`0000Gooooo00<00000ooooooooool0P?ooool40?l008;ooooo0@000001ooooo`002Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00`00003ooooo
ooooo`20ooooo`@0o`00P_ooool10000007ooooo0006ooooo`Go00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?l0003o0000083ooooo103o0021ooooo`7o00000@000001ooooo`001_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool0P?ooool40?l008;ooooo0@000001ooooo`001oooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool0P?ooool40?l008;ooooo0@000001ooooo`00
2?ooool2o`0000?ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`20ooooo`@0
o`00P_ooool10000007ooooo0009ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`030000
0?oooooooooo083ooooo103o0022ooooo`4000000Oooool001Gooooo00<00000ooooooooool0P?oo
ool40?l008;ooooo0@000001ooooo`005Oooool00`00003oooooooooo`20ooooo`@0o`00P_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo083ooooo103o0022ooooo`4000000Oooool001Go
oooo00<00000o`000?ooool0P?ooool40?l0087ooooo0Ol000010000007ooooo000Eooooo`030000
0?oooooooooo083ooooo103o0022ooooo`4000000Oooool001Gooooo00<00000ooooooooool0P?oo
ool40?l008;ooooo0@000001ooooo`005Oooool00`00003oooooooooo`20ooooo`@0o`00P_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo083ooooo103o0022ooooo`4000000Oooool001Go
oooo00<00000ooooooooool0P?ooool40?l008;ooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`20ooooo`@0o`00P_ooool10000007ooooo000Eooooo`0300000?oooooooooo083ooooo103o
0022ooooo`4000000Oooool001Gooooo00<00000o`000?ooool0Ooooool6ool0083ooooo0Ol00001
0000007ooooo000Eooooo`0300000?oooooooooo07oooooo1_oo0021ooooo`4000000Oooool001Go
oooo00<00000ooooooooool0Ooooool6ool0087ooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`20ooooo`@0o`00P_ooool10000007ooooo000Eooooo`0300000?oooooooooo083ooooo103o
0022ooooo`4000000Oooool001Gooooo00<00000ooooooooool0P?ooool40?l008;ooooo0@000001
ooooo`005Oooool00`00003oooooooooo`20ooooo`@0o`00P_ooool10000007ooooo000Eooooo`03
00000?oooooooooo083ooooo103o0022ooooo`4000000Oooool001Gooooo00<00000o`000?ooool0
P?ooool40?l0087ooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo083ooooo103o
0022ooooo`4000000Oooool001Gooooo00<00000ooooooooool0P?ooool40?l008;ooooo0@000001
ooooo`005Oooool00`00003oooooooooo`20ooooo`@0o`00P_ooool10000007ooooo000Eooooo`03
00000?oooooooooo083ooooo103o0022ooooo`4000000Oooool000Oooooo0ol00004ooooo`;o0000
1Oooool00`00003oooooooooo`20ooooo`@0o`00P_ooool10000007ooooo0006ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo083o
oooo103o0022ooooo`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0P?ooool40?l008;ooooo0@000001oooo
o`001_ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00`00003o0000o`000020oooo
o`@0o`00POooool1o`00004000000Oooool000Kooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo083ooooo103o0022ooooo`4000000Oooool000Oo
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
083ooooo103o0022ooooo`4000000Oooool000Sooooo0_l00004ooooo`;o00001Oooool00`00003o
ooooooooo`20ooooo`@0o`00P_ooool10000007ooooo000Eooooo`0300000?oooooooooo083ooooo
103o0022ooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool5ool008;ooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1oooooo`Goo`00P_ooool10000007ooooo000Eoooo
o`0300000?l0003ooooo07oooooo1Ooo0021ooooo`7o00000@000001ooooo`005Oooool00`00003o
ooooooooo`20ooooo`<0o`00Poooool10000007ooooo000Eooooo`0300000?oooooooooo083ooooo
0`3o0023ooooo`4000000Oooool001Gooooo00<00000ooooooooool0P?ooool30?l008?ooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`20ooooo`<0o`00Poooool10000007ooooo000Eoooo
o`0300000?oooooooooo083ooooo0`3o0023ooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0P?ooool30?l008?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`20ooooo`<0o`00
Poooool10000007ooooo000Eooooo`0300000?l0003ooooo083ooooo0`3o0022ooooo`7o00000@00
0001ooooo`005Oooool00`00003oooooooooo`20ooooo`<0o`00Poooool10000007ooooo000Eoooo
o`0300000?oooooooooo083ooooo0`3o0023ooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0P?ooool30?l008?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`20ooooo`<0o`00
Poooool10000007ooooo000Eooooo`0300000?oooooooooo083ooooo0`3o0023ooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0P?ooool30?l008?ooooo0@000001ooooo`005Oooool00`00
003oooooooooo`20ooooo`<0o`00Poooool10000007ooooo000Eooooo`0300000?l0003ooooo07oo
oooo1Ooo0021ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`Goo`00
P_ooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo1Ooo0022ooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0POooool20?l008?ooooo0@000001ooooo`005Oooool00`00
003oooooooooo`21ooooo`80o`00Poooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Go
oooo00<00000ooooooooool0POooool20?l008?ooooo0@000001ooooo`001_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`21oooo
o`80o`00Poooool10000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00004ooooo`0300000?oooooooooo087ooooo0P3o0023ooooo`4000000Oooool0
00Oooooo0ol00003ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000?l00000POooool2
0?l008;ooooo0Ol000010000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00004ooooo`0300000?oooooooooo087ooooo0P3o0023ooooo`4000000Ooo
ool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool0POooool20?l008?ooooo0@000001ooooo`001oooool3o`0000Cooooo0_l0
0005ooooo`0300000?oooooooooo087ooooo0P3o0023ooooo`4000000Oooool001Gooooo00<00000
ooooooooool0POooool20?l008?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`21oooo
o`80o`00Poooool10000007ooooo000Eooooo`0300000?oooooooooo087ooooo0P3o0023ooooo`40
00000Oooool001Gooooo00<00000ooooooooool0POooool20?l008?ooooo0@000001ooooo`005Ooo
ool00`00003o0000ooooo`1oooooo`Goo`00POooool1o`00004000000Oooool001Gooooo00<00000
ooooooooool0Ooooool5ool008;ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1ooooo
o`Goo`00P_ooool10000007ooooo000Eooooo`0300000?oooooooooo087ooooo0P3o0023ooooo`40
00000Oooool001Gooooo00<00000ooooooooool0POooool20?l008?ooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`21ooooo`80o`00Poooool10000007ooooo000Eooooo`0300000?oooooo
oooo087ooooo0P3o0023ooooo`4000000Oooool001Gooooo00<00000o`000?ooool0POooool20?l0
08;ooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo087ooooo0P3o0023ooooo`40
00000Oooool001Gooooo00<00000ooooooooool0POooool20?l008?ooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`21ooooo`80o`00Poooool10000007ooooo000Eooooo`0300000?oooooo
oooo087ooooo0P3o0023ooooo`4000000Oooool001Gooooo00<00000ooooooooool0P?ooool4ool0
08;ooooo0@000001ooooo`005Oooool00`00003oooooooooo`20ooooo`Coo`00P_ooool10000007o
oooo000Eooooo`0300000?oooooooooo083ooooo1?oo0022ooooo`4000000Oooool001Gooooo00<0
0000o`000?ooool0POooool20?l008;ooooo0Ol000010000007ooooo000Eooooo`0300000?oooooo
oooo087ooooo0P3o0023ooooo`4000000Oooool001Gooooo00<00000ooooooooool0POooool20?l0
08?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`21ooooo`80o`00Poooool10000007o
oooo000Eooooo`0300000?oooooooooo087ooooo0P3o0023ooooo`4000000Oooool00004ooooool0
003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`20ooooo`?oo`00
Poooool10000007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo083ooooo0ooo0023ooooo`40
00000Oooool000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0P?ooool3ool008?ooooo0@000001oooo
o`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003o0000o`000020ooooo`?oo`00P_ooool1o`00004000000Oooool0
00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool0P?ooool3ool008?ooooo0@000001ooooo`0000?ooooo
o`000?l000001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool07?ooool00`00003oooooooooo`0`ooooo`0300000?oooooooooo02oooooo
00<00000ooooooooool0<?ooool00`00003oooooooooo`0`ooooo`0300000?oooooooooo01cooooo
0@000001ooooo`000_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00<0
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00<0
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00<0
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool10000007ooooo000Eooooool000002`000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-608.55, -10.3856, 3.9524, \
0.640152}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[g1, PlotRange \[Rule] {{\(-50\), 50}, All}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.01 0.0147151 0.00588604 [
[.1 -0.0125 -9 -9 ]
[.1 -0.0125 9 0 ]
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -12 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -12 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -12 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -12 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-40)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-20)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(20)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(40)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(20)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(40)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(60)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(80)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(100)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.1 .61178 m
.1 .61803 L
s
.3 .61178 m
.3 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7 .61178 m
.7 .61803 L
s
.9 .61178 m
.9 .61803 L
s
.125 Mabswid
.15 .61428 m
.15 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .01472 m
0 .01472 L
s
.01 .01472 m
.01 .02658 L
s
.02 .01472 m
.02 .03775 L
s
.03 .01472 m
.03 .04708 L
s
.04 .01472 m
.04 .05359 L
s
.05 .01472 m
.05 .05649 L
s
.06 .01472 m
.06 .05534 L
s
.07 .01472 m
.07 .05007 L
s
.08 .01472 m
.08 .04101 L
s
.09 .01472 m
.09 .02888 L
s
.1 .01472 m
.1 .01472 L
s
.11 .01472 m
.11 .0296 L
s
.12 .01472 m
.12 .04376 L
s
.13 .01472 m
.13 .05577 L
s
.14 .01472 m
.14 .06432 L
s
.15 .01472 m
.15 .06835 L
s
.16 .01472 m
.16 .06722 L
s
.17 .01472 m
.17 .06073 L
s
.18 .01472 m
.18 .04919 L
s
.19 .01472 m
.19 .03342 L
s
.2 .01472 m
.2 .01472 L
s
.21 .01472 m
.21 .03471 L
s
.22 .01472 m
.22 .0541 L
s
.23 .01472 m
.23 .07092 L
s
.24 .01472 m
.24 .08333 L
s
.25 .01472 m
.25 .08974 L
s
.26 .01472 m
.26 .08903 L
s
.27 .01472 m
.27 .08068 L
s
.28 .01472 m
.28 .06481 L
s
.29 .01472 m
.29 .04231 L
s
.3 .01472 m
.3 .01472 L
s
.31 .01472 m
.31 .04521 L
s
.32 .01472 m
.32 .07593 L
s
.33 .01472 m
.33 .10392 L
s
.34 .01472 m
.34 .12613 L
s
.35 .01472 m
.35 .13967 L
s
.36 .01472 m
.36 .14203 L
s
.37 .01472 m
.37 .13134 L
s
.38 .01472 m
.38 .10651 L
s
.39 .01472 m
.39 .06736 L
s
.4 .01472 m
.4 .01472 L
s
.41 .01472 m
.41 .07905 L
s
.42 .01472 m
.42 .15239 L
s
.43 .01472 m
.43 .23127 L
s
.44 .01472 m
.44 .31171 L
s
.45 .01472 m
.45 .38945 L
s
.46 .01472 m
.46 .4602 L
s
.47 .01472 m
.47 .51998 L
s
.48 .01472 m
.48 .56535 L
s
.49 .01472 m
.49 .59369 L
s
.5 .01472 m
.5 .60332 L
s
.51 .01472 m
.51 .59369 L
s
.52 .01472 m
.52 .56535 L
s
.53 .01472 m
.53 .51998 L
s
.54 .01472 m
.54 .4602 L
s
.55 .01472 m
.55 .38945 L
s
.56 .01472 m
.56 .31171 L
s
.57 .01472 m
.57 .23127 L
s
.58 .01472 m
.58 .15239 L
s
.59 .01472 m
.59 .07905 L
s
.6 .01472 m
.6 .01472 L
s
.61 .01472 m
.61 .06736 L
s
.62 .01472 m
.62 .10651 L
s
.63 .01472 m
.63 .13134 L
s
.64 .01472 m
.64 .14203 L
s
.65 .01472 m
.65 .13967 L
s
.66 .01472 m
.66 .12613 L
s
.67 .01472 m
.67 .10392 L
s
.68 .01472 m
.68 .07593 L
s
.69 .01472 m
.69 .04521 L
s
.7 .01472 m
.7 .01472 L
s
.71 .01472 m
.71 .04231 L
s
.72 .01472 m
.72 .06481 L
s
.73 .01472 m
.73 .08068 L
s
.74 .01472 m
.74 .08903 L
s
.75 .01472 m
.75 .08974 L
s
.76 .01472 m
.76 .08333 L
s
.77 .01472 m
.77 .07092 L
s
.78 .01472 m
.78 .0541 L
s
.79 .01472 m
.79 .03471 L
s
.8 .01472 m
.8 .01472 L
s
.81 .01472 m
.81 .03342 L
s
.82 .01472 m
.82 .04919 L
s
.83 .01472 m
.83 .06073 L
s
.84 .01472 m
.84 .06722 L
s
.85 .01472 m
.85 .06835 L
s
.86 .01472 m
.86 .06432 L
s
.87 .01472 m
.87 .05577 L
s
.88 .01472 m
.88 .04376 L
s
.89 .01472 m
.89 .0296 L
s
.9 .01472 m
.9 .01472 L
s
.91 .01472 m
.91 .02888 L
s
.92 .01472 m
.92 .04101 L
s
.93 .01472 m
.93 .05007 L
s
.94 .01472 m
.94 .05534 L
s
.95 .01472 m
.95 .05649 L
s
.96 .01472 m
.96 .05359 L
s
.97 .01472 m
.97 .04708 L
s
.98 .01472 m
.98 .03775 L
s
.99 .01472 m
.99 .02658 L
s
1 .01472 m
1 .01472 L
s
.015 w
0 .01472 Mdot
.01 .02658 Mdot
.02 .03775 Mdot
.03 .04708 Mdot
.04 .05359 Mdot
.05 .05649 Mdot
.06 .05534 Mdot
.07 .05007 Mdot
.08 .04101 Mdot
.09 .02888 Mdot
.1 .01472 Mdot
.11 .0296 Mdot
.12 .04376 Mdot
.13 .05577 Mdot
.14 .06432 Mdot
.15 .06835 Mdot
.16 .06722 Mdot
.17 .06073 Mdot
.18 .04919 Mdot
.19 .03342 Mdot
.2 .01472 Mdot
.21 .03471 Mdot
.22 .0541 Mdot
.23 .07092 Mdot
.24 .08333 Mdot
.25 .08974 Mdot
.26 .08903 Mdot
.27 .08068 Mdot
.28 .06481 Mdot
.29 .04231 Mdot
.3 .01472 Mdot
.31 .04521 Mdot
.32 .07593 Mdot
.33 .10392 Mdot
.34 .12613 Mdot
.35 .13967 Mdot
.36 .14203 Mdot
.37 .13134 Mdot
.38 .10651 Mdot
.39 .06736 Mdot
.4 .01472 Mdot
.41 .07905 Mdot
.42 .15239 Mdot
.43 .23127 Mdot
.44 .31171 Mdot
.45 .38945 Mdot
.46 .4602 Mdot
.47 .51998 Mdot
.48 .56535 Mdot
.49 .59369 Mdot
.5 .60332 Mdot
.51 .59369 Mdot
.52 .56535 Mdot
.53 .51998 Mdot
.54 .4602 Mdot
.55 .38945 Mdot
.56 .31171 Mdot
.57 .23127 Mdot
.58 .15239 Mdot
.59 .07905 Mdot
.6 .01472 Mdot
.61 .06736 Mdot
.62 .10651 Mdot
.63 .13134 Mdot
.64 .14203 Mdot
.65 .13967 Mdot
.66 .12613 Mdot
.67 .10392 Mdot
.68 .07593 Mdot
.69 .04521 Mdot
.7 .01472 Mdot
.71 .04231 Mdot
.72 .06481 Mdot
.73 .08068 Mdot
.74 .08903 Mdot
.75 .08974 Mdot
.76 .08333 Mdot
.77 .07092 Mdot
.78 .0541 Mdot
.79 .03471 Mdot
.8 .01472 Mdot
.81 .03342 Mdot
.82 .04919 Mdot
.83 .06073 Mdot
.84 .06722 Mdot
.85 .06835 Mdot
.86 .06432 Mdot
.87 .05577 Mdot
.88 .04376 Mdot
.89 .0296 Mdot
.9 .01472 Mdot
.91 .02888 Mdot
.92 .04101 Mdot
.93 .05007 Mdot
.94 .05534 Mdot
.95 .05649 Mdot
.96 .05359 Mdot
.97 .04708 Mdot
.98 .03775 Mdot
.99 .02658 Mdot
1 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00;_ooool3o`0000?ooooo0_l0000/ooooo`Go00000oooool2o`0002gooooo0_l0000^oooo
o`Go00000oooool2o`0002gooooo0ol00003ooooo`;o00006?ooool002oooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000[ooooo`04o`000?ooooooooooo`0002kooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0000]ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0Eooooo`009_ooool5o`000003ooooool0003o000000?o00000_ooool01?l0
003oooooooooool0000Uooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002_ooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0002[ooooo1Ol00002ooooo`04o`000?ooooooooooo`0001Oooooo000/ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000;_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooool0000`ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00005oooool002gooooo00?o0000ooooool000000oooool01?l0
003oooooooooool0000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000[ooooo`04o`000?ooooooooooo`0002gooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0002_ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0
000Gooooo`00;_ooool2o`0000?ooooo00Co0000oooooooooooo0000:oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo0000:oooool01?l0003oooooooooool0000]oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000/ooooo`;o00000ooo
ool01?l0003oooooooooool0000Gooooo`00;oooool00ol0003oooooooooo`02ooooo`;o0000;Ooo
ool3o`0000Cooooo0_l0000]ooooo`;o0000;oooool3o`0000Cooooo0_l0000^ooooo`03o`000?oo
oooooooo00;ooooo0_l0000Hooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`005Oooool00`00003o0000o`00003oo`0000Oo00000@000001ooooo`003_ooool2
o`0000Gooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`0300000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00`00003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`4000000Oooool0
00gooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Gooooo`0300000?oooooo
oooo03?ooooo00<00000ooooooooool0<_ooool00`00003oooooooooo`0booooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool05oooool10000007ooooo000=ooooo`04o`000?oooooooooo
o`0000;ooooo0ooo000Hooooo`?oo`006?ooool3ool001Oooooo0ooo000Hooooo`?oo`00<_ooool3
ool001Oooooo0ooo000Hooooo`?oo`005oooool3ool001Sooooo0ooo000000gooooo00Co0000oooo
oooooooo00000_ooool3ool000;o000000<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool0103o003oooooooooo`3o0003ool00007
ooooo`3o003oooooooooo`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01`3o003oooooooooo`3o003ooooo0?l00?ooool00ooo00001?ooool0o`00ooooo`3o0002
ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l0
00;ooooo00H0o`00ool00?oo003oo`00ooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`070?l00?oooooooooo0?l00?ooool0o`00ooooo`03
ool00004ooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo
00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool0103o003ooooo0?l00?ooool3ool00004ooooo`3o003ooooo0?l000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oo`00
ool00?oo003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o0003ool00007ooooo`3o003ooooo
ooooo`3o003ooooo0?l00002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`060?l00?oo003oo`00ool00?ooool0o`000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`040?l00?oooooooooo
0?l000?oo`00000=ooooo`04o`000?ooooooooooo`0000;ooooo0ooo0002ooooo`030?l00?ooool0
o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo
00@0o`00ooooooooool0o`000ooo00001oooool0o`00ooooooooool0o`00ooooo`3o00000_ooool0
1P3o003oooooooooo`3o003ooooo0?l000;ooooo00L0o`00ooooooooool0o`00ooooo`3o003ooooo
00?oo`0000Cooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo
00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oo003oo`00ool00?ooool0o`000_oo
ool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01`3o003o
ooooooooo`3o003ooooo0?l00?ooool00ooo00001?ooool0o`00ooooo`3o0002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00@0o`00ooooo`3o003ooooo0ooo00001?ooool0o`00
ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ool00?oo003oo`00ooooo`3o0002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00@0o`00oooooooo
ool0o`000ooo00001oooool0o`00ooooooooool0o`00ooooo`3o00000_ooool00`3o003ooooo0?l0
0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oo`00ool00?oo003ooooo
0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?oo
ool0o`000_ooool0103o003oooooooooo`3o0003ool000003Oooool01?l0003oooooooooool00004
ooooo`0600000?oo003oo`00ool00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l0
00;ooooo00<0o`00ooooo`3o00000_ooool0103o003oooooooooo`3o0004ooooo`060?l00?oooooo
oooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooo
ooooool0o`00ooooo`3o0005ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`02
ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l0
00;ooooo00H0o`00ooooooooool0o`00ooooo`3o0005ooooo`030?l00?ooool0o`0000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0
1P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003ooooo0?l00005ooooo`030?l00?oo
ool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`000_ooool00`3o003oooooooooo`02ooooo`040?l00?oooooooooo0?l000;ooooo00<0
o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00@0o`00oooooooo
ool0o`001?ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00ooooo`3o00000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00ooooooooool00_ooool0103o003o
ooooooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o
0002ooooo`060?l00?oo003oo`00ool00?ooool000000Oooool000kooooo0_l00005ooooo`060000
0?oo003oo`00ool00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0
o`00ooooo`3o00000_ooool0103o003oo`00ool00?oo0003ooooo`?oo`0000Cooooo0?l00?ooool0
o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00oooo
o`3o0005ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`02ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0005ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0
o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003ooooooooo
o`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooo
oooo0?l00?ooool0o`000_ooool00`3o003ooooo0?l00005ooooo`030?l00?ooool0o`0000;ooooo
00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool00`3o003oooooooooo`02ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o0000
0_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00@0o`00ooooooooool0o`001?ooool0
1P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool01`3o003ooooo
ooooo`3o003ooooo0?l00?ooool00ooo0002ooooo`?oo`0000Oooooo0?l00?oooooooooo0?l00?oo
ool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oo003oo`00ool0
0?ooool000000Oooool001Gooooo00H00000ool00?oo003oo`00ooooo`3o0002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool00`3o003ooooo0?l00002ooooo`040?l00?oo003oo`00ool0
00?ooooo0ooo00001?ooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool0103o003oooooooooo`3o0003ool000Cooooo00<0o`00ooooo`3o00000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l0
0?oooooooooo00;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000Gooooo00<0o`00ooooo`3o
00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00oooo
o`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003o
oooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l00?ooool0o`0000Go
oooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`030?l00?oooooooooo00;ooooo00@0o`00ooooooooool0
o`000_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0
103o003oooooooooo`3o0002ooooo`?oo`000_ooool00`3o003ooooo0?l00002ooooo`030?l00?oo
ool0o`0000;ooooo00L0o`00ooooooooool0o`00ooooo`3o003ooooo00?oo`000_ooool3ool00007
ooooo`3o003oooooooooo`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01P3o003oo`00ool00?oo003ooooo0000007ooooo000Eooooo`0400000?oooooooooooooo
o`?oo`0000Oooooo0?l00?oooooooooo0?l00?ooool0o`0000;ooooo00<0o`00ooooo`3o00000_oo
ool0103o003oo`00ool00?oo0003ooooo`?oo`0000Cooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00@0o`00ooooooooool0o`000ooo0002ooooo`?oo`0000Go
oooo0?l00?oooooooooo0?l00002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0
o`00ooooo`3o0002ooooo`030?l00?oooooooooo00;ooooo00H0o`00ooooooooool0o`00ooooo`3o
0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo
0?l000Gooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo
00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`030?l00?ooool0o`0000Gooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l00?oooooooooo
00;ooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooo
oooo0?l00?ooool0o`000_ooool0103o003oo`00ool00?oo0002ooooo`?oo`000_ooool00`3o003o
oooo0?l00002ooooo`030?l00?ooool0o`0000;ooooo00L0o`00ooooooooool0o`00ooooo`3o003o
oooo00?oo`000_ooool3ool00007ooooo`3o003oooooooooo`3o003ooooo0?l00002ooooo`070?l0
0?oooooooooo0?l00?ooool0o`00ooooo`03ool000?ooooo0@000001ooooo`005Oooool01000003o
ooooooooooooool3ool00007ooooo`3o003oooooooooo`3o003ooooo0?l00002ooooo`040?l00?oo
ool0o`00ooooo`?oo`002Oooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?oo
ool0o`000_ooool0103o003oooooooooo`3o0003ool000;ooooo0ooo00001Oooool0o`00oooooooo
ool0o`0000;ooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00<0o`00ooooooooool00_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`001Oooool00`3o
003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003ooooooooo
o`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooo
oooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00oooo
o`3o00001Oooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00ooooooooool00_ooool0103o003o
ooooooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o
0002ooooo`040?l00?oo003oo`00ool000;ooooo0ooo0002ooooo`030?l00?ooool0o`0000;ooooo
00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000Wooooo0ooo00001?oo
ool0o`00ooooo`3o0002ooooo`070?l00?oooooooooo0?l00?ooool0o`00ooooo`03ool000?ooooo
0@000001ooooo`005Oooool01000003oooooooooooooool3ool00007ooooo`3o003oooooooooo`3o
003ooooo0?l00002ooooo`040?l00?ooool0o`00ooooo`?oo`001oooool3ool00005ooooo`3o003o
ooooooooo`3o00000_ooool00`3o003ooooo0?l00002ooooo`040?l00?oooooooooo0?l000Gooooo
0ooo00001Oooool0o`00ooooooooool0o`0000;ooooo00<0o`00ooooo`3o00000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000?oo`000oooool3ool00004ooooo`3o003ooooo0?l000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`001Oooool0
0`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003ooooo
ooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00
ooooo`3o00001Oooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01`3o003oooooooooo`3o003ooooo0?l00?ooool00ooo0002ooooo`?oo`0000Oooooo0?l0
0?oooooooooo0?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`04
0?l00?oo003oo`00ool000Oooooo00<0o`00ooooo`3o00000_ooool00`3o003ooooo0?l00002oooo
o`040?l00?oooooooooo0?l000?oo`002?ooool3ool00004ooooo`3o003ooooo0?l000;ooooo00L0
o`00ooooooooool0o`00ooooo`3o003ooooo00?oo`000oooool10000007ooooo000Eooooo`030000
0?l0003ooooo00?ooooo0ooo0002ooooo`030?l00?ooool0o`0000;ooooo00@0o`00ooooo`3o003o
oooo0ooo0007ooooo`?oo`0000Gooooo0?l00?oooooooooo0?l00002ooooo`030?l00?ooool0o`00
00;ooooo00@0o`00ool00?oo003oo`002Oooool0103o003oooooooooo`3o0002ooooo`030?l00?oo
ool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0003ool000?ooooo0ooo00001?ooool0
o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003ooooooooo
o`3o003ooooo0?l000Gooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo
0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?oo
ool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`030?l00?ooool0o`0000Gooooo00<0o`00ooooo`3o00000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00L0o`00ooooooooool0o`00ooooo`3o003ooooo00?oo`00
0_ooool3ool00007ooooo`3o003oooooooooo`3o003ooooo0?l00002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool00`3o003oooooooooo`06ooooo`?oo`0000Oooooo0?l00?oooooooooo
0?l00?ooool0o`0000;ooooo00@0o`00ooooooooool0o`000ooo0008ooooo`?oo`0000Cooooo0?l0
0?ooool0o`000_ooool0103o003oooooooooo`3o0003ool000Gooooo0Ol000010000007ooooo000E
ooooo`0300000?oooooooooo00?ooooo0ooo0002ooooo`030?l00?ooool0o`0000;ooooo00@0o`00
ool00?oo003oo`002_ooool3ool00005ooooo`3o003oooooooooo`3o00000_ooool00`3o003ooooo
0?l00002ooooo`040?l00?oo003oo`00ool000Wooooo00@0o`00ooooooooool0o`000_ooool00`3o
003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000ooo0003ooooo`?oo`0000Co
oooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooo
ooooool0o`00ooooo`3o0005ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool00`3o003ooooo0?l00005ooooo`030?l00?ooool0o`0000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`070?l00?oooooooooo0?l00?ooool0o`00ooooo`03
ool000;ooooo0ooo00001oooool0o`00ooooooooool0o`00ooooo`3o00000_ooool01P3o003ooooo
ooooo`3o003ooooo0?l000;ooooo00<0o`00ooooooooool01_ooool3ool00007ooooo`3o003ooooo
ooooo`3o003ooooo0?l00002ooooo`040?l00?oooooooooo0?l000?oo`002_ooool3ool00005oooo
o`3o003oooooooooo`3o00000_ooool0103o003oo`00ool00?oo0006ooooo`4000000Oooool001Go
oooo00<00000ooooooooool00oooool>ool000gooooo0ooo00001oooool0o`00ooooooooool0o`00
ooooo`3o00000_ooool0103o003oo`00ool00?oo0008ooooo`?oo`0000Oooooo0?l00?oooooooooo
0?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o000:ooooo`030?l00?ooool0
o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?oo
ool0o`001Oooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l0
00;ooooo00<0o`00ooooo`3o00001Oooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000[ooooo00H0o`00oooooooo
ool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000ooo0008ooooo`?oo`00
00Oooooo0?l00?oooooooooo0?l00?ooool0o`0000;ooooo00@0o`00ool00?oo003oo`003Oooool>
ool000Kooooo0@000001ooooo`005Oooool00`00003oooooooooo`06ooooo`_oo`003Oooool3ool0
0008ooooo`3o003oooooooooo`3o003ooooo0?l00?ooool3ool000[ooooo0ooo00001oooool0o`00
ooooooooool0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000[ooooo00<0
o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o0005ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00oooo
o`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003o
oooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`000_ooool00`3o003ooooo0?l00005ooooo`030?l00?ooool0o`0000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`002_ooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0003ool000_o
oooo0ooo00001?ooool0o`00ooooo`3o0002ooooo`040?l00?oo003oo`00ool000gooooo2ooo0009
ooooo`4000000Oooool001Gooooo00<00000ooooooooool01_ooool8ool0013ooooo1_oo00001Ooo
ool0o`00ooooo`3o003ooooo00?oo`002_ooool3ool00007ooooo`3o003oooooooooo`3o003ooooo
0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`002_ooool00`3o003ooooo0?l00002oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000Go
oooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`03
0?l00?ooool0o`0000Gooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo
0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o000:ooooo`060?l00?oooooooooo0?l00?oo
ool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000?oo`002oooool3ool00005ooooo`3o
003ooooo0?l00?ooool01Ooo000@ooooo`Soo`002Oooool10000007ooooo000Eooooo`0300000?oo
oooooooo027ooooo2ooo000>ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003o
ooooooooo`3o0003ool000Wooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003o
oooo0?l000;ooooo00@0o`00ooooooooool0o`000ooo0004ooooo`030?l00?ooool0o`0000;ooooo
00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003ooooo0?l00003ooooo`?oo`00
00Gooooo0?l00?oooooooooo0?l00002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o0009ooooo`?oo`0000Cooooo0?l00?ooool0o`000_ooool01P3o003ooooooooo
o`3o003ooooo0?l000kooooo2ooo000Sooooo`4000000Oooool001Gooooo00<00000ooooooooool0
8Oooool8ool0013ooooo0ooo00001?ooool0o`00ooooo`3o0002ooooo`040?l00?oooooooooo0?l0
00?oo`002Oooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool0103o003oooooooooo`3o0003ool000Cooooo00<0o`00ooooo`3o00000_ooool01P3o003ooooo
ooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`030?l00?ooool0o`0000?ooooo0ooo00001Oooool0o`00
ooooooooool0o`0000;ooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo
0?l000Wooooo0ooo00001?ooool0o`00ooooo`3o0002ooooo`040?l00?oooooooooo0?l000?oo`00
3oooool9ool002?ooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Sooooo`Koo`004?oo
ool3ool00004ooooo`3o003ooooo0?l000;ooooo00@0o`00ooooooooool0o`000ooo0007ooooo`?o
o`0000Gooooo0?l00?oooooooooo0?l00002ooooo`030?l00?ooool0o`0000;ooooo00@0o`00oooo
ooooool0o`000ooo0004ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00oooo
o`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003o
oooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`000_ooool00`3o003ooooo0?l00003ooooo`?oo`0000Gooooo0?l00?oooooooooo0?l0
0002ooooo`030?l00?ooool0o`0000;ooooo00@0o`00ooooooooool0o`000ooo0008ooooo`?oo`00
00Cooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o0003ool000oooooo1_oo000Uoooo
o`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0iooooo`?oo`0000Cooooo0?l00?oo
ool0o`000_ooool0103o003oooooooooo`3o000:ooooo`?oo`0000Gooooo0?l00?oooooooooo0?l0
0002ooooo`030?l00?ooool0o`0000;ooooo00@0o`00ooooooooool0o`001Oooool3ool00005oooo
o`3o003oooooooooo`3o00000_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0
o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003oo`00ool0
0?oo0006ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool0103o003o
ooooooooo`3o0003ool000cooooo00<0o`00ooooo`3o00000_ooool0103o003oooooooooo`3o0003
ool003_ooooo0@000001ooooo`005Oooool00`00003oooooooooo`0kooooo`?oo`0000Gooooo0?l0
0?oooooooooo0?l00003ool000[ooooo0ooo00001Oooool0o`00ooooooooool0o`0000;ooooo00<0
o`00ooooo`3o00000_ooool0103o003oooooooooo`3o0005ooooo`?oo`0000Gooooo0?l00?oooooo
oooo0?l00002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l0
00;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`040?l00?oo003oo`00ool000Kooooo
00@0o`00ooooooooool0o`000_ooool00`3o003ooooo0?l00002ooooo`040?l00?oooooooooo0?l0
00?oo`002_ooool3ool00005ooooo`3o003oooooooooo`3o00000ooo000nooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0>oooool3ool00005ooooo`3o003oooooooooo`3o00000ooo000>
ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool0103o003ooooooooo
o`3o0005ooooo`?oo`0000Gooooo0?l00?oooooooooo0?l00002ooooo`030?l00?ooool0o`0000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o
0002ooooo`040?l00?oo003oo`00ool000Kooooo00@0o`00ooooooooool0o`000_ooool00`3o003o
oooo0?l00002ooooo`040?l00?oooooooooo0?l000gooooo0ooo00001Oooool0o`00ooooooooool0
o`0000?oo`00?_ooool10000007ooooo000Eooooo`0300000?oooooooooo03_ooooo2ooo000>oooo
o`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool0103o003oooooooooo`3o
0009ooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool01P3o003ooooo
ooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00
ooooooooool01oooool0103o003oooooooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo00@0
o`00ooooooooool0o`003Oooool;ool003kooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`0nooooo`Goo`004Oooool0103o003oooooooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo
00@0o`00ooooooooool0o`002Oooool0103o003oooooooooo`3o0002ooooo`030?l00?ooool0o`00
00;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0
o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00oooo
o`3o0002ooooo`030?l00?oooooooooo00Oooooo00@0o`00ooooooooool0o`000_ooool00`3o003o
oooo0?l00002ooooo`040?l00?oooooooooo0?l0013ooooo1_oo0010ooooo`4000000Oooool001Go
oooo00<00000ooooooooool0?_ooool5ool0017ooooo00@0o`00ooooooooool0o`000_ooool00`3o
003ooooo0?l00002ooooo`040?l00?oooooooooo0?l000Wooooo00@0o`00ooooooooool0o`000_oo
ool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l0
0?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`07ooooo`040?l00?oooooooooo
0?l000;ooooo00<0o`00ooooo`3o00000_ooool0103o003oooooooooo`3o000@ooooo`Koo`00@?oo
ool10000007ooooo000Eooooo`0300000?oooooooooo05Cooooo00@0o`00ooooooooool0o`000_oo
ool00`3o003ooooo0?l00002ooooo`040?l00?oooooooooo0?l000Wooooo00@0o`00ooooooooool0
o`000_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0
1P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`07ooooo`040?l00?oo
oooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool0103o003oooooooooo`3o001Fooooo`40
00000Oooool001Gooooo00<00000o`000?ooool0Doooool3ool00007ooooo`3o003oooooooooo`3o
003ooooo0?l00002ooooo`040?l00?oooooooooo0?l000Wooooo00@0o`00ooooooooool0o`000_oo
ool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l0
0?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`07ooooo`040?l00?oooooooooo
0?l000;ooooo00<0o`00ooooo`3o00000_ooool0103o003oo`00ool00?oo001Eooooo`7o00000@00
0001ooooo`005Oooool00`00003oooooooooo`1Cooooo`?oo`0000Oooooo0?l00?oooooooooo0?l0
0?ooool0o`0000;ooooo00@0o`00ool00?oo003oo`002Oooool0103o003oooooooooo`3o0002oooo
o`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`030?l00?oooooooooo00Kooooo0ooo00001oooool0o`00
ooooooooool0o`00ooooo`3o00000_ooool0103o003oo`00ool00?oo001Fooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0Doooool3ool00007ooooo`3o003oooooooooo`3o003ooooo0?l0
0002ooooo`040?l00?oo003oo`00ool000Wooooo00@0o`00ooooooooool0o`000_ooool00`3o003o
oooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool00`3o003oooooooooo`06ooooo`?oo`0000Oooooo0?l00?oooooooooo
0?l00?ooool0o`0000;ooooo00@0o`00ool00?oo003oo`00E_ooool10000007ooooo000Eooooo`03
00000?oooooooooo05Oooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`040?l00?oo003o
o`00ool000Wooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo0?l00002ooooo`060?l0
0?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0
0`3o003oooooooooo`06ooooo`?oo`0000Oooooo0?l00?oooooooooo0?l00?ooool0o`0000;ooooo
00<0o`00ooooooooool0Eoooool10000007ooooo000Eooooo`0300000?oooooooooo05Oooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l00?oooooooooo00[ooooo00@0o`00oooooooo
ool0o`000_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`0:ooooo`060?l0
0?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`1Gooooo`4000000Oooool001Go
oooo00<00000ooooooooool0Eoooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00
ooooooooool02_ooool0103o003oooooooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0
1P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002oooo
o`030?l00?oooooooooo00[ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l00?oo
oooooooo05Oooooo0@000001ooooo`001_ooool5o`0000?ooooo0_l00005ooooo`0300000?oooooo
oooo05Kooooo0ooo00001?ooool0o`00ooooo`3o0002ooooo`030?l00?oooooooooo00[ooooo00@0
o`00ooooooooool0o`000_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?oo
ool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`0:
ooooo`070?l00?oooooooooo0?l00?ooool0o`00ooooo`03ool005Sooooo0@000001ooooo`001ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool0E_ooool3ool00005ooooo`3o003ooooo0?l00?ooool00ooo000;ooooo`040?l00?oooooooooo
0?l000;ooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo
00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00ooooooooool02Oooool3ool00005
ooooo`3o003ooooo0?l00?ooool00ooo001Hooooo`4000000Oooool000Sooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00004ooooo`0300000?l0003o000005Kooooo0ooo00001Ooo
ool0o`00ooooo`3o003ooooo00?oo`002oooool0103o003oooooooooo`3o0002ooooo`030?l00?oo
ool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0
o`00ooooo`3o0002ooooo`030?l00?oooooooooo00Wooooo0ooo00001Oooool0o`00ooooo`3o003o
oooo00?oo`00Eoooool1o`00004000000Oooool000Wooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0F?ooool3ool00003ooooo`3o003o
oooo00?oo`002oooool0103o003oooooooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0
1P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002oooo
o`030?l00?oooooooooo00Wooooo0ooo00000oooool0o`00ool00002ool005_ooooo0@000001oooo
o`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool0
0`00003oooooooooo`1Hooooo`Koo`003_ooool0103o003oooooooooo`3o0002ooooo`030?l00?oo
ool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0
o`00ooooo`3o0002ooooo`030?l00?oooooooooo00_ooooo1_oo001Kooooo`4000000Oooool000Ko
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool0F?ooool6ool000kooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo0?l0
0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo
0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?oo
ool0o`000_ooool00`3o003oooooooooo`0;ooooo`Koo`00Foooool10000007ooooo0007ooooo`?o
00001?ooool2o`0000Gooooo00<00000ooooooooool0Foooool3ool000kooooo00@0o`00oooooooo
ool0o`000_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`0;ooooo`?oo`00
G_ooool10000007ooooo000Eooooo`0300000?oooooooooo06_ooooo0ooo00001oooool0o`00oooo
ooooool0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o
003oooooooooo`3o003ooooo0?l000?oo`00K_ooool10000007ooooo000Eooooo`0300000?oooooo
oooo06_ooooo0ooo00001oooool0o`00ooooooooool0o`00ooooo`3o00000_ooool01P3o003ooooo
ooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000?oo`00K_ooool1
0000007ooooo000Eooooo`0300000?oooooooooo06_ooooo0ooo00001oooool0o`00ooooooooool0
o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003ooooo
ooooo`3o003ooooo0?l000?oo`00K_ooool10000007ooooo000Eooooo`0300000?l0003ooooo06oo
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o
0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00L?ooool1o`00004000000Oooool001Gooooo
00<00000ooooooooool0Koooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooo
ooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o001aooooo`400000
0Oooool001Gooooo00<00000ooooooooool0Koooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o
001aooooo`4000000Oooool001Gooooo00<00000ooooooooool0Koooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o001aooooo`4000000Oooool001Gooooo00<00000ooooooooool0Koooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo
00H0o`00ooooooooool0o`00ooooo`3o001aooooo`4000000Oooool001Gooooo00<00000oooooooo
ool0Koooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00oooo
o`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003o
oooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o001aooooo`4000000Oooool001Gooooo
00<00000ooooooooool0Koooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooo
ooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o001aooooo`400000
0Oooool001Gooooo00<00000ooooooooool0Koooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o
001aooooo`4000000Oooool001Gooooo00<00000o`000?ooool0Koooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o001`ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1_oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01P3o003oooooooooo`3o003ooooo0?l0077ooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`1_ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l0077ooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`1_ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l0077ooooo
0@000001ooooo`005Oooool00`00003oooooooooo`1_ooooo`060?l00?oooooooooo0?l00?ooool0
o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00oooo
o`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003o
oooo0?l0077ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1_ooooo`060?l00?oooooo
oooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooo
ooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l0077ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1_oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01P3o003oooooooooo`3o003ooooo0?l0077ooooo0@000001ooooo`005Oooool00`00003o
0000ooooo`1_ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l0073ooooo0Ol000010000007o
oooo000Eooooo`0300000?oooooooooo06oooooo00H0o`00ooooooooool0o`00ooooo`3o0002oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
LOooool10000007ooooo000Eooooo`0300000?oooooooooo06oooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo
0?l00?ooool0o`00LOooool10000007ooooo000Eooooo`0300000?oooooooooo06kooooo0ooo0000
1?ooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`040?l0
0?oooooooooo0?l000?oo`00L?ooool10000007ooooo000Eooooo`0300000?oooooooooo06kooooo
0ooo00001?ooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0
1P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002oooo
o`040?l00?oooooooooo0?l000?oo`00L?ooool10000007ooooo000Eooooo`0300000?oooooooooo
06kooooo0ooo00001?ooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o
0002ooooo`040?l00?oooooooooo0?l000?oo`00L?ooool10000007ooooo0008ooooo`?o00000ooo
ool2o`0000Gooooo00<00000ooooooooool0L_ooool00`3o003ooooo0?l00002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`040?l00?oooooooooo0?l007?ooooo0@000001ooooo`00
2Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00`00003o
ooooooooo`1booooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l0
00;ooooo00@0o`00ooooooooool0o`00Loooool10000007ooooo0006ooooo`Go00000_ooool01?l0
003oooooooooool00004ooooo`0300000?l0003o000007;ooooo00<0o`00ooooo`3o00000_ooool0
1P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o001booooo`7o0000
0@000001ooooo`001_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Co
oooo00<00000ooooooooool0L_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0
o`00ooooo`3o0002ooooo`040?l00?oooooooooo0?l007?ooooo0@000001ooooo`001oooool00ol0
003oooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0L_ooool0
0`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003ooooo
ooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`040?l00?oo
oooooooo0?l007?ooooo0@000001ooooo`002?ooool2o`0000?ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`1booooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0
o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003ooooooooo
o`3o003ooooo0?l000;ooooo00@0o`00ooooooooool0o`00Loooool10000007ooooo0009ooooo`03
o`000?oooooooooo00;ooooo0_l00005ooooo`0300000?oooooooooo07;ooooo00<0o`00ooooo`3o
00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00oooo
o`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o001c
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0L_ooool00`3o003ooooo0?l00002oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`040?l00?oooooooooo0?l007?ooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1booooo`030?l00?ooool0o`0000;ooooo00H0o`00
ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00@0o`00ooooooooool0o`00Loooool10000007ooooo
000Eooooo`0300000?oooooooooo07;ooooo00<0o`00ooooo`3o00000_ooool01P3o003ooooooooo
o`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooo
oooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o001cooooo`4000000Oooool001Gooooo
00<00000o`000?ooool0L_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?oo
ool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`040?l00?oooooooooo0?l007;ooooo0Ol000010000007ooooo000Eooooo`03
00000?oooooooooo07;ooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo
0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?oo
ool0o`000_ooool0103o003oooooooooo`3o001cooooo`4000000Oooool001Gooooo00<00000oooo
ooooool0L_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`040?l00?oooooooooo0?l007?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1b
ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l0
0?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00@0
o`00ooooooooool0o`00Loooool10000007ooooo000Eooooo`0300000?oooooooooo07;ooooo00<0
o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003ooooo
ooooo`3o001cooooo`4000000Oooool001Gooooo00<00000ooooooooool0L_ooool00`3o003ooooo
0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003o
oooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`040?l00?oooooooooo0?l0
07?ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1booooo`030?l00?ooool0o`0000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00
0_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00@0o`00ooooooooool0o`00Loooool1
0000007ooooo000Eooooo`0300000?oooooooooo07;ooooo00<0o`00ooooo`3o00000_ooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o001cooooo`4000000Ooo
ool001Gooooo00<00000o`000?ooool0L?ooool3ool00005ooooo`3o003oooooooooo`3o00000_oo
ool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00@0o`00ool00?oo003oo`00L_ooool1o`00004000000Ooo
ool001Gooooo00<00000ooooooooool0L?ooool3ool00005ooooo`3o003oooooooooo`3o00000_oo
ool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l000;ooooo00@0o`00ool00?oo003oo`00Loooool10000007ooooo000E
ooooo`0300000?oooooooooo073ooooo0ooo00001Oooool0o`00ooooooooool0o`0000;ooooo00<0
o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o0002ooooo`040?l00?oo003oo`00ool007?ooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`1dooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o00000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`030?l00?oooooooooo07Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`1doooo
o`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o
003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l00?oooooooooo
07Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`1dooooo`040?l00?oooooooooo0?l0
00;ooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l00?oooooooooo07Cooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`1dooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o
00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00oooo
o`3o0002ooooo`030?l00?oooooooooo07Cooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`1dooooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool01P3o003ooooo
ooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l00?oo
oooooooo07Cooooo0@000001ooooo`005Oooool00`00003o0000ooooo`1dooooo`040?l00?oooooo
oooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`030?l00?oooooooooo07?ooooo0Ol00001
0000007ooooo000Eooooo`0300000?oooooooooo07Cooooo00@0o`00ooooooooool0o`000_ooool0
0`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003ooooo
ooooo`3o003ooooo0?l000;ooooo00<0o`00ooooooooool0M?ooool10000007ooooo000Eooooo`03
00000?oooooooooo07Cooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo0?l00002oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00<0o`00ooooooooool0M?ooool10000007ooooo000Eooooo`0300000?oooooooooo07Cooooo
00@0o`00ooooooooool0o`000_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00ooooooooool0
M?ooool10000007ooooo000Eooooo`0300000?oooooooooo07Cooooo00@0o`00ooooooooool0o`00
0_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00ooooooooool0M?ooool10000007ooooo0007
ooooo`?o00001?ooool2o`0000Gooooo00<00000ooooooooool0M?ooool0103o003oooooooooo`3o
0002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`1dooooo`4000000Oooool0
00Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool0M?ooool0103o003oooooooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo
00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool00`3o003oooooooooo`1dooooo`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0M?ooool0103o003ooooo
ooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002
ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`1dooooo`400000
0Oooool000Kooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000?l00000
M?ooool0103o003oooooooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003ooooo
ooooo`1cooooo`7o00000@000001ooooo`001_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00<00000ooooooooool0M?ooool0103o003oooooooooo`3o0002ooooo`03
0?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooo
oooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`1dooooo`4000000Oooool000Oooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07Cooooo
00@0o`00ooooooooool0o`000_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00<0o`00ooooooooool0
M?ooool10000007ooooo0008ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0M?oo
ool0103o003oooooooooo`3o0002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0
o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003ooooooooo
o`1dooooo`4000000Oooool001Gooooo00<00000ooooooooool0M?ooool0103o003oooooooooo`3o
0002ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`000_ooool00`3o003oooooooooo`1dooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0Loooool3ool00007ooooo`3o003oooooooooo`3o003ooooo0?l0
0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo
0?l000?oo`00M_ooool10000007ooooo000Eooooo`0300000?oooooooooo07?ooooo0ooo00001ooo
ool0o`00ooooooooool0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o0003ool007Kooooo0@000001ooooo`005Oooool00`00
003o0000ooooo`1cooooo`?oo`0000Oooooo0?l00?oooooooooo0?l00?ooool0o`0000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000ooo001e
ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`1gooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o001iooooo`4000000Oooool001Gooooo00<00000ooooooooool0Moooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`00NOooool10000007ooooo000Eooooo`0300000?oooooooooo
07Oooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0
o`000_ooool01P3o003oooooooooo`3o003ooooo0?l007Wooooo0@000001ooooo`005Oooool00`00
003oooooooooo`1gooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003ooooooooo
o`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o001iooooo`4000000Oooool0
01Gooooo00<00000ooooooooool0Moooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0
o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00NOooool1
0000007ooooo000Eooooo`0300000?oooooooooo07Oooooo00H0o`00ooooooooool0o`00ooooo`3o
0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo
0?l007Wooooo0@000001ooooo`005Oooool00`00003oooooooooo`1gooooo`060?l00?oooooooooo
0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o001iooooo`4000000Oooool001Gooooo00<00000o`000?ooool0Moooool01P3o
003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`00N?ooool1o`00004000000Oooool001Gooooo00<00000oooo
ooooool0Moooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00NOooool10000007ooooo000Eoooo
o`0300000?oooooooooo07Oooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l007Wooooo0@000001
ooooo`005Oooool00`00003oooooooooo`1gooooo`060?l00?oooooooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o001i
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0Moooool01P3o003oooooooooo`3o003o
oooo0?l000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l0
0?ooool0o`00NOooool10000007ooooo000Eooooo`0300000?oooooooooo07Oooooo00H0o`00oooo
ooooool0o`00ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003o
ooooooooo`3o003ooooo0?l007Wooooo0@000001ooooo`005Oooool00`00003oooooooooo`1goooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool01P3o003oooooooooo`3o003ooooo0?l000;o
oooo00H0o`00ooooooooool0o`00ooooo`3o001iooooo`4000000Oooool001Gooooo00<00000oooo
ooooool0Moooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`060?l00?oooooooooo0?l00?ooool0o`00NOooool10000007ooooo000Eoooo
o`0300000?l0003ooooo07Kooooo0ooo00001?ooool0o`00ooooo`3o0002ooooo`060?l00?oooooo
oooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o0003ool007Oooooo0Ol000010000007o
oooo000Eooooo`0300000?oooooooooo07Kooooo0ooo00001?ooool0o`00ooooo`3o0002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o0003ool007Sooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`1fooooo`?oo`0000Cooooo0?l00?ooool0o`000_oo
ool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00@0o`00ooooooooool0o`000ooo001hoooo
o`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003ooooo0?l00002ooooo`06
0?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o001kooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool0N_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooo
oooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o001kooooo`4000000Oooool000Oooooo
0ol00004ooooo`;o00001Oooool00`00003oooooooooo`1jooooo`030?l00?ooool0o`0000;ooooo
00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`040?l00?oooooooooo0?l007_ooooo0@000001
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`1jooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00
ooooo`3o0002ooooo`040?l00?oooooooooo0?l007_ooooo0@000001ooooo`001_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1j
ooooo`030?l00?ooool0o`0000;ooooo00H0o`00ooooooooool0o`00ooooo`3o0002ooooo`040?l0
0?oooooooooo0?l007_ooooo0@000001ooooo`001oooool3o`0000?ooooo00Co0000oooooooooooo
00001?ooool00`00003o0000o`00001jooooo`030?l00?ooool0o`0000;ooooo00H0o`00oooooooo
ool0o`00ooooo`3o0002ooooo`040?l00?oooooooooo0?l007[ooooo0Ol000010000007ooooo0006
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo07[ooooo00<0o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l0
00;ooooo00@0o`00ooooooooool0o`00Noooool10000007ooooo0006ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07[ooooo00<0
o`00ooooo`3o00000_ooool01P3o003oooooooooo`3o003ooooo0?l000;ooooo00@0o`00oooooooo
ool0o`00Noooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Gooooo00<00000oooooooo
ool0N_ooool00`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0
103o003oooooooooo`3o001kooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool0
0`3o003ooooo0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003ooooo
ooooo`3o001kooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003ooooo
0?l00002ooooo`060?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o001k
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003ooooo0?l00002oooo
o`060?l00?oooooooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o001kooooo`400000
0Oooool001Gooooo00<00000ooooooooool0N_ooool00`3o003ooooo0?l00002ooooo`060?l00?oo
oooooooo0?l00?ooool0o`000_ooool0103o003oooooooooo`3o001kooooo`4000000Oooool001Go
oooo00<00000o`000?ooool0N?ooool3ool00005ooooo`3o003oooooooooo`3o00000_ooool00`3o
003ooooo0?l00002ooooo`040?l00?oo003oo`00ool007[ooooo0Ol000010000007ooooo000Eoooo
o`0300000?oooooooooo07Sooooo0ooo00001Oooool0o`00ooooooooool0o`0000;ooooo00<0o`00
ooooo`3o00000_ooool0103o003oo`00ool00?oo001kooooo`4000000Oooool001Gooooo00<00000
ooooooooool0N?ooool3ool00005ooooo`3o003oooooooooo`3o00000_ooool00`3o003ooooo0?l0
0002ooooo`040?l00?oo003oo`00ool007_ooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`1looooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool00`3o003ooooo
ooooo`1looooo`4000000Oooool001Gooooo00<00000ooooooooool0O?ooool0103o003ooooooooo
o`3o0002ooooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo
000Eooooo`0300000?oooooooooo07cooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo
0?l00002ooooo`030?l00?oooooooooo07cooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`1looooo`040?l00?oooooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool00`3o003ooooo
ooooo`1looooo`4000000Oooool001Gooooo00<00000o`000?ooool0O?ooool0103o003ooooooooo
o`3o0002ooooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool0Noooool1o`0000400000
0Oooool001Gooooo00<00000ooooooooool0O?ooool0103o003oooooooooo`3o0002ooooo`030?l0
0?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo000Eooooo`0300000?oo
oooooooo07cooooo00@0o`00ooooooooool0o`000_ooool00`3o003ooooo0?l00002ooooo`030?l0
0?oooooooooo07cooooo0@000001ooooo`005Oooool00`00003oooooooooo`1looooo`040?l00?oo
oooooooo0?l000;ooooo00<0o`00ooooo`3o00000_ooool00`3o003oooooooooo`1looooo`400000
0Oooool001Gooooo00<00000ooooooooool0O?ooool0103o003oooooooooo`3o0002ooooo`030?l0
0?ooool0o`0000;ooooo00<0o`00ooooooooool0O?ooool10000007ooooo000Eooooo`0300000?oo
oooooooo07_ooooo0ooo00001oooool0o`00ooooooooool0o`00ooooo`3o00000ooo001nooooo`40
00000Oooool001Gooooo00<00000ooooooooool0Noooool3ool00007ooooo`3o003oooooooooo`3o
003ooooo0?l00003ool007kooooo0@000001ooooo`005Oooool00`00003oooooooooo`1kooooo`?o
o`0000Oooooo0?l00?oooooooooo0?l00?ooool0o`0000?oo`00O_ooool10000007ooooo000Eoooo
o`0300000?l0003ooooo07oooooo00H0o`00ooooooooool0o`00ooooo`3o0020ooooo`7o00000@00
0001ooooo`005Oooool00`00003oooooooooo`1oooooo`060?l00?oooooooooo0?l00?ooool0o`00
POooool10000007ooooo000Eooooo`0300000?oooooooooo07oooooo00H0o`00ooooooooool0o`00
ooooo`3o0021ooooo`4000000Oooool001Gooooo00<00000ooooooooool0Ooooool01P3o003ooooo
ooooo`3o003ooooo0?l0087ooooo0@000001ooooo`005Oooool00`00003oooooooooo`1oooooo`06
0?l00?oooooooooo0?l00?ooool0o`00POooool10000007ooooo00001?oooooo0000o`000?l00004
ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0O_ooool3ool00003ooooo`3o003o
o`0000;oo`00P?ooool10000007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07kooooo0ooo
00000oooool0o`00ool00002ool0083ooooo0@000001ooooo`000_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooo
ooooo`1nooooo`Soo`00P?ooool10000007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l0003o0000083o
oooo0ooo0022ooooo`7o00000@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`20oooo
o`?oo`00Poooool10000007ooooo00000ooooooo0000o`000004ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Gooooo`0300000?oooooo
oooo03?ooooo00<00000ooooooooool0<_ooool00`00003oooooooooo`0booooo`0300000?oooooo
oooo03;ooooo00<00000ooooooooool05oooool10000007ooooo0002ooooo`03o`000?oooooooooo
00?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00<00000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`0300000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00_ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo0@000001ooooo`005Ooooooo000000/000000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-58.0629, -10.3856, \
0.376796, 0.640152}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowSize->{661, 636},
WindowMargins->{{37, Automatic}, {Automatic, 27}},
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 52, 0, 62, "Title"],

Cell[CellGroupData[{
Cell[1782, 54, 99, 4, 59, "Section"],

Cell[CellGroupData[{
Cell[1906, 62, 60, 0, 49, "Subsection"],
Cell[1969, 64, 121, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2127, 71, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2189, 75, 59, 0, 43, "Subsubsection"],
Cell[2251, 77, 118, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2406, 84, 67, 0, 43, "Subsubsection"],
Cell[2476, 86, 440, 7, 111, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2965, 99, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3035, 103, 62, 0, 43, "Subsubsection"],
Cell[3100, 105, 330, 6, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3467, 116, 67, 0, 43, "Subsubsection"],
Cell[3537, 118, 227, 4, 28, "Text"],
Cell[3767, 124, 551, 10, 143, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4355, 139, 48, 0, 43, "Subsubsection"],
Cell[4406, 141, 367, 8, 46, "Text"],
Cell[4776, 151, 302, 4, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5115, 160, 83, 1, 43, "Subsubsection"],
Cell[5201, 163, 683, 12, 191, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5933, 181, 43, 0, 33, "Subsection"],
Cell[5979, 183, 333, 7, 46, "Text"],
Cell[6315, 192, 541, 10, 127, "Input"],
Cell[6859, 204, 216, 4, 28, "Text"],
Cell[7078, 210, 651, 12, 159, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7778, 228, 33, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[7836, 232, 36, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[7897, 236, 35, 0, 43, "Subsubsection"],
Cell[7935, 238, 63, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[8023, 243, 171, 3, 63, "Input"],
Cell[8197, 248, 34802, 843, 186, 6376, 488, "GraphicsData", "PostScript", \
"Graphics"],
Cell[43002, 1093, 83, 1, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[43134, 1100, 35, 0, 43, "Subsubsection"],
Cell[43172, 1102, 76, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[43273, 1107, 203, 3, 63, "Input"],
Cell[43479, 1112, 88749, 4512, 186, 64583, 4209, "GraphicsData", \
"PostScript", "Graphics"],
Cell[132231, 5626, 86, 1, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132354, 5632, 57, 1, 47, "Input"],
Cell[132414, 5635, 223195, 2886, 186, 33936, 475, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[355658, 8527, 35, 0, 43, "Subsubsection"],
Cell[355696, 8529, 79, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[355800, 8534, 175, 3, 63, "Input"],
Cell[355978, 8539, 75224, 2007, 186, 19258, 1312, "GraphicsData", \
"PostScript", "Graphics"],
Cell[431205, 10548, 118, 2, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[431360, 10555, 123, 3, 47, "Input"],
Cell[431486, 10560, 168243, 2209, 186, 33936, 475, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[599790, 12776, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[599850, 12780, 40, 0, 43, "Subsubsection"],
Cell[599893, 12782, 105, 3, 28, "Text"],
Cell[600001, 12787, 188, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[600214, 12795, 131, 2, 63, "Input"],
Cell[600348, 12799, 189, 4, 23, "Print"],
Cell[600540, 12805, 219, 4, 23, "Print"],
Cell[600762, 12811, 143, 3, 23, "Print"],
Cell[600908, 12816, 161, 3, 23, "Print"],
Cell[601072, 12821, 157, 3, 23, "Print"],
Cell[601232, 12826, 190, 4, 23, "Print"],
Cell[601425, 12832, 169, 3, 23, "Print"]
}, Open  ]],
Cell[601609, 12838, 57, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[601703, 12844, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[601771, 12848, 84, 1, 47, "Input"],
Cell[601858, 12851, 180874, 2505, 186, 87168, 1166, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[782747, 15359, 82, 3, 28, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[782866, 15367, 43, 0, 43, "Subsubsection"],
Cell[782912, 15369, 41, 0, 28, "Text"],
Cell[782956, 15371, 156, 2, 63, "Input"],
Cell[783115, 15375, 43, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[783183, 15379, 112, 2, 47, "Input"],
Cell[783298, 15383, 726171, 44340, 186, 687250, 43855, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1509518, 59729, 41, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1509584, 59733, 136, 2, 63, "Input"],
Cell[1509723, 59737, 75154, 2019, 186, 19473, 1327, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1584926, 61762, 45, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1584996, 61766, 154, 3, 63, "Input"],
Cell[1585153, 61771, 70206, 1295, 186, 6316, 502, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1655408, 63072, 72, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1655505, 63076, 205, 4, 63, "Input"],
Cell[1655713, 63082, 69423, 1542, 186, 9955, 803, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1725197, 64631, 34, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1725256, 64635, 40, 0, 43, "Subsubsection"],
Cell[1725299, 64637, 105, 3, 28, "Text"],
Cell[1725407, 64642, 197, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[1725629, 64650, 131, 2, 63, "Input"],
Cell[1725763, 64654, 189, 4, 23, "Print"],
Cell[1725955, 64660, 211, 4, 23, "Print"],
Cell[1726169, 64666, 143, 3, 23, "Print"],
Cell[1726315, 64671, 161, 3, 23, "Print"],
Cell[1726479, 64676, 159, 3, 23, "Print"],
Cell[1726641, 64681, 194, 4, 23, "Print"],
Cell[1726838, 64687, 171, 3, 23, "Print"]
}, Open  ]],
Cell[1727024, 64693, 57, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1727118, 64699, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1727186, 64703, 103, 2, 47, "Input"],
Cell[1727292, 64707, 2598317, 36115, 186, 1495783, 19460, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4325624, 100825, 82, 3, 28, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4325755, 100834, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4325815, 100838, 41, 0, 43, "Subsubsection"],
Cell[4325859, 100840, 105, 3, 28, "Text"],
Cell[4325967, 100845, 191, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[4326183, 100853, 164, 3, 79, "Input"],
Cell[4326350, 100858, 256267, 3527, 277, 127514, 1934, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4582666, 104391, 36, 0, 43, "Subsubsection"],
Cell[4582705, 104393, 105, 3, 28, "Text"],
Cell[4582813, 104398, 194, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[4583032, 104406, 164, 3, 79, "Input"],
Cell[4583199, 104411, 843410, 11168, 248, 468097, 6531, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5426682, 115587, 60, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[5426767, 115591, 47, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5426839, 115595, 188, 4, 63, "Input"],
Cell[5427030, 115601, 145, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5427212, 115609, 138, 3, 47, "Input"],
Cell[5427353, 115614, 42678, 1185, 186, 11254, 792, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5470080, 116805, 105, 3, 49, "Subsection"],
Cell[5470188, 116810, 95, 3, 28, "Text"],
Cell[5470286, 116815, 86, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[5470397, 116821, 347, 8, 95, "Input"],

Cell[CellGroupData[{
Cell[5470769, 116833, 41099, 1161, 186, 9418, 765, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5511871, 117996, 49421, 1542, 186, 15511, 1119, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5561353, 119545, 124, 3, 49, "Subsection"],
Cell[5561480, 119550, 95, 3, 28, "Text"],
Cell[5561578, 119555, 85, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[5561688, 119561, 347, 8, 95, "Input"],

Cell[CellGroupData[{
Cell[5562060, 119573, 24557, 710, 186, 5718, 473, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5586620, 120285, 45166, 1275, 186, 12163, 863, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5631847, 121567, 47, 0, 49, "Subsection"],
Cell[5631897, 121569, 206, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[5632128, 121577, 135, 3, 47, "Input"],
Cell[5632266, 121582, 47208, 962, 186, 5715, 445, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5679523, 122550, 83, 1, 49, "Subsection"],
Cell[5679609, 122553, 95, 3, 28, "Text"],
Cell[5679707, 122558, 85, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[5679817, 122564, 368, 8, 95, "Input"],

Cell[CellGroupData[{
Cell[5680210, 122576, 67958, 1226, 186, 5531, 451, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5748171, 123804, 83869, 1501, 186, 7048, 548, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5832113, 125313, 43, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[5832181, 125317, 39, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5832245, 125321, 40, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[5832310, 125325, 76, 1, 47, "Input"],
Cell[5832389, 125328, 180074, 2353, 186, 33936, 475, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6012512, 127687, 40, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[6012577, 127691, 76, 1, 47, "Input"],
Cell[6012656, 127694, 186737, 2436, 186, 33936, 475, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6199442, 130136, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[6199506, 130140, 77, 1, 47, "Input"],
Cell[6199586, 130143, 210563, 2730, 186, 33936, 475, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6410210, 132880, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6410280, 132884, 46, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[6410351, 132888, 322, 6, 95, "Input"],

Cell[CellGroupData[{
Cell[6410698, 132898, 78923, 1651, 186, 11490, 814, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6489624, 134551, 165924, 2179, 186, 33936, 475, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6655563, 136733, 114, 2, 61, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6655726, 136741, 51, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[6655802, 136745, 240, 4, 79, "Input"],
Cell[6656045, 136751, 153085, 2020, 186, 33936, 475, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6809133, 138773, 117, 2, 61, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6809323, 138783, 75, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[6809423, 138787, 52, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6809500, 138791, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[6809574, 138795, 250, 4, 79, "Input"],
Cell[6809827, 138801, 100280, 1866, 186, 10601, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6910110, 140669, 84, 1, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6910243, 140676, 57, 0, 43, "Subsubsection"],
Cell[6910303, 140678, 88, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[6910416, 140684, 182, 3, 63, "Input"],
Cell[6910601, 140689, 110865, 2498, 186, 20192, 1374, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7021515, 143193, 72, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7021612, 143197, 218, 4, 79, "Input"],
Cell[7021833, 143203, 80820, 4678, 186, 57097, 4381, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7102690, 147886, 88, 1, 47, "Input"],
Cell[7102781, 147889, 35493, 1020, 186, 7359, 668, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7138335, 148916, 67, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[7138427, 148920, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7138501, 148924, 254, 4, 79, "Input"],
Cell[7138758, 148930, 102405, 1889, 186, 10580, 751, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7241166, 150821, 88, 1, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7241303, 150828, 57, 0, 43, "Subsubsection"],
Cell[7241363, 150830, 88, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[7241476, 150836, 182, 3, 63, "Input"],
Cell[7241661, 150841, 113173, 2527, 186, 20191, 1374, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7354883, 153374, 72, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7354980, 153378, 218, 4, 79, "Input"],
Cell[7355201, 153384, 78370, 4621, 186, 56870, 4351, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7433608, 158010, 88, 1, 47, "Input"],
Cell[7433699, 158013, 34704, 984, 186, 7072, 638, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7468464, 159004, 54, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[7468543, 159008, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7468617, 159012, 300, 6, 79, "Input"],
Cell[7468920, 159020, 145335, 2705, 186, 15822, 1102, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7614258, 161727, 118, 2, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7614425, 161735, 57, 0, 43, "Subsubsection"],
Cell[7614485, 161737, 88, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[7614598, 161743, 182, 3, 63, "Input"],
Cell[7614783, 161748, 150916, 3025, 186, 20510, 1410, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7765748, 164779, 72, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7765845, 164783, 218, 4, 79, "Input"],
Cell[7766066, 164789, 84392, 4697, 186, 56769, 4351, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7850495, 169491, 88, 1, 47, "Input"],
Cell[7850586, 169494, 41383, 1201, 186, 9078, 798, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7892030, 170702, 58, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[7892113, 170706, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7892187, 170710, 277, 5, 79, "Input"],
Cell[7892467, 170717, 111398, 2257, 186, 15482, 1068, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8003868, 172976, 119, 2, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8004036, 172984, 57, 0, 43, "Subsubsection"],
Cell[8004096, 172986, 88, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[8004209, 172992, 182, 3, 63, "Input"],
Cell[8004394, 172997, 118991, 2599, 186, 20165, 1374, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8123434, 175602, 72, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8123531, 175606, 218, 4, 79, "Input"],
Cell[8123752, 175612, 80501, 4674, 186, 57166, 4381, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8204290, 180291, 82, 1, 47, "Input"],
Cell[8204375, 180294, 35382, 1019, 186, 7349, 668, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8239806, 181319, 46, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8239877, 181323, 114, 2, 47, "Input"],
Cell[8239994, 181327, 123, 2, 63, "Output"]
}, Open  ]],
Cell[8240132, 181332, 210, 4, 46, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8240391, 181342, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8240461, 181346, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8240535, 181350, 334, 7, 79, "Input"],
Cell[8240872, 181359, 101674, 1800, 186, 9025, 652, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8342595, 183165, 57, 0, 43, "Subsubsection"],
Cell[8342655, 183167, 88, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[8342768, 183173, 215, 4, 63, "Input"],
Cell[8342986, 183179, 115493, 2554, 186, 20274, 1374, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8458528, 185739, 72, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8458625, 185743, 218, 4, 79, "Input"],
Cell[8458846, 185749, 93266, 4870, 186, 57669, 4426, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8552173, 190626, 46, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8552244, 190630, 49, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8552318, 190634, 230, 5, 63, "Input"],
Cell[8552551, 190641, 28496, 755, 186, 6330, 477, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8581096, 191402, 65, 2, 43, "Subsubsection"],
Cell[8581164, 191406, 88, 2, 47, "Input"],

Cell[CellGroupData[{
Cell[8581277, 191412, 195, 4, 63, "Input"],
Cell[8581475, 191418, 45043, 1686, 186, 20355, 1377, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8626567, 193110, 72, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[8626664, 193114, 218, 4, 79, "Input"],
Cell[8626885, 193120, 74468, 4574, 186, 56748, 4351, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8701390, 197699, 86, 1, 47, "Input"],
Cell[8701479, 197702, 64853, 1446, 186, 8263, 743, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

